%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%                                                                  %%%%%
%%%%    IEEE PES Power Grid Library - Optimal Power Flow - v23.07     %%%%%
%%%%          (https://github.com/power-grid-lib/pglib-opf)           %%%%%
%%%%               Benchmark Group - Typical Operations               %%%%%
%%%%                         23 - July - 2023                         %%%%%
%%%%                                                                  %%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%CASE13659PEGASE  Power flow data for European system with step-up transformers.
%   Please see CASEFORMAT for details on the case file format.
%
%   This case accurately represents the size and complexity of the European
%   high voltage transmission network. The network contains 13,659 buses,
%   4,092 generators, and 20,467 branches and it operates at 750, 400, 380,
%   330, 220, 154, 150, 120, and 110 kV. Low voltage buses ranging from 
%   27,000 to 400 V are used to model step-up transformers which connect 
%   generators to the high-voltage network. Please note that the data are
%   fictitious and do not correspond to real world data. They can thus be
%   used to validate methods and tools but should not be used for operation
%   and planning of the European grid.
%
%   The data stems from the Pan European Grid Advanced Simulation and State
%   Estimation (PEGASE) project, part of the 7th Framework Program of the
%   European Union (http://www.fp7-pegase.com/). When publishing results
%   based on this data, please cite:
%
%     C. Josz, S. Fliscounakis, J. Maeght, and P. Panciatici,
%     "AC Power Flow Data in MATPOWER and QCQP Format: iTesla, RTE Snapshots, and PEGASE"
%     http://arxiv.org/abs/1603.01533
% 
%     S. Fliscounakis, P. Panciatici, F. Capitanescu, and L. Wehenkel,
%     "Contingency ranking with respect to overloads in very large power
%     systems taking into account uncertainty, preventive and corrective
%     actions", Power Systems, IEEE Trans. on, (28)4:4909-4917, 2013.
%     http://dx.doi.org/10.1109/TPWRS.2013.2251015
%
%   Remarks:
%
%   1. Line flow limits are the current flow limits found in PEGASE data.
%
%   2. PEGASE data contains asymmetric shunt conductance and susceptance in
%   the PI transmission line model of branches. Thus total line charging
%   susceptance of branches is set to 0 p.u. and the nodal representation
%   of shunt condutance and susceptance is used. As a result, power flow
%   equations are left unchanged compared with original PEGASE data.
%   However, line flow constraints in the optimal flow problem are
%   modified.
%
%   3. Identical linear costs are used for all generators to form a loss
%   minimizing OPF objective function.
%
%   4. Since some parts of the network are aggregated, some generators
%   (e.g. with negative PMIN) represent aggregations of multiple loads
%   and generators.
%
%   Cedric Josz, Jean Maeght, Stephane Fliscounakis, and Patrick Panciatici
%   firstname.lastname@rte-france.com
%   Reseau de Transport d'Electricite (French Transmission System Operator)
%   Departement Expertise Systeme, Immeuble "Le Colbert"
%   9 rue de la Porte de Buc, 78000 Versailles Cedex, France
%   March 4th, 2016
%
%   Copyright (c) 2016 by Cedric Josz, Jean Maeght, Stephane Fliscounakis,
%   and Patrick Panciatici
%   Licensed under the Creative Commons Attribution 4.0 International license,
%   http://creativecommons.org/licenses/by/4.0/
%
function mpc = pglib_opf_case13659_pegase
mpc.version = '2';
mpc.baseMVA = 100.0;

%% bus data
%	bus_i	type	Pd	Qd	Gs	Bs	area	Vm	Va	baseKV	zone	Vmax	Vmin
mpc.bus = [
	1	 3	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	2	 1	 72.68	 45.0	 0.0	 6.61	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3	 1	 378.4	 98.5	 0.0	 16.61	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	4	 1	 134.0	 19.1	 0.0	 0.08	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5	 1	 151.0	 48.8	 0.0	 4.69	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6	 1	 171.41	 23.4	 0.0	 2.1	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7	 1	 45.95	 14.0	 0.0	 13.34	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	8	 1	 343.4	 53.1	 0.70508	 36.832433	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	9	 1	 -0.0	 -0.0	 0.0	 75.076713	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	10	 1	 31.03	 10.3	 0.0	 0.65	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	11	 1	 0.0	 -0.0	 0.0	 3.41	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	12	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	13	 1	 14.3	 2.0	 0.0	 1.91	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	14	 1	 134.0	 24.7	 0.0	 12.44	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	15	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	16	 1	 -6.11	 2.0	 0.0	 0.47	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	17	 1	 -22.74	 -8.32	 0.0	 6.5	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	18	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	19	 1	 59.67	 26.7	 0.0	 12.84	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	20	 1	 30.6	 4.3	 0.0	 5.15	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	21	 1	 0.0	 -0.0	 0.234457	 -0.195381	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	22	 1	 67.67	 12.1	 0.0	 2.18	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	23	 1	 0.0	 0.0	 0.295874	 20.603438	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	24	 1	 25.33	 7.5	 0.0	 2.39	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	25	 1	 1.4	 0.2	 0.0	 4.93	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	26	 1	 161.2	 39.3	 0.0	 30.71	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	27	 1	 0.0	 -0.0	 0.0	 0.85	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	28	 1	 19.62	 7.1	 0.0	 1.15	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	29	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	30	 1	 31.94	 8.8	 0.0	 0.73	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	31	 1	 0.0	 -0.0	 0.235277	 0.313936	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	32	 1	 167.3	 54.8	 0.0	 110.54	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	33	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	34	 1	 -0.0	 0.0	 0.0	 14.82	 0	    1.00000	    0.00000	 380.0	 13	    1.10000	    0.90000;
	35	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	36	 1	 152.9	 49.4	 0.0	 27.65	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	37	 1	 -0.0	 0.0	 0.0	 0.56	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	38	 1	 69.68	 43.2	 0.0	 6.3	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	39	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 9	    1.10000	    0.90000;
	40	 1	 0.0	 -0.0	 0.0	 37.54	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	41	 1	 0.0	 -0.0	 0.0	 0.25	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	42	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	43	 1	 13.51	 4.9	 0.0	 1.8	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	44	 1	 10.51	 3.5	 0.0	 0.31	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	45	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	46	 1	 -0.0	 0.0	 0.12	 15.34	 0	    1.00000	    0.00000	 220.0	 19	    1.10000	    0.90000;
	47	 1	 9.21	 2.6	 0.0	 2.0	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	48	 1	 42.75	 12.8	 0.0	 13.3	 0	    1.00000	    0.00000	 220.0	 8	    1.10000	    0.90000;
	49	 1	 -0.0	 0.0	 0.019959	 0.320041	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	50	 1	 16.02	 4.54	 0.0	 0.1	 0	    1.00000	    0.00000	 110.0	 23	    1.10000	    0.90000;
	51	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 14.4	 1	    1.10000	    0.90000;
	52	 1	 27.9	 4.0	 0.0	 4.23	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	53	 1	 20.82	 7.9	 0.0	 26.89	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	54	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	55	 1	 0.0	 0.0	 0.0	 7.27	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	56	 1	 10.11	 3.7	 0.0	 0.81	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	57	 1	 10.01	 2.7	 0.0	 1.14	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	58	 1	 6.31	 -0.0	 0.0	 0.67	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	59	 1	 2.9	 0.9	 0.0	 0.6	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	60	 1	 -0.0	 0.0	 0.318913	 17.760815	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	61	 1	 -0.0	 -0.0	 0.549745	 0.432068	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	62	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	63	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	64	 1	 151.8	 48.3	 0.0	 5.53	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	65	 1	 127.6	 31.8	 0.0	 20.51	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	66	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 22	    1.10000	    0.90000;
	67	 1	 0.0	 0.0	 0.0	 0.84	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	68	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	69	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	70	 1	 110.5	 -26.8	 0.0	 16.37	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	71	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	72	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	73	 1	 0.0	 0.0	 0.0	 1.23	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	74	 1	 0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	75	 1	 0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	76	 1	 0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	77	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	78	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	79	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	80	 1	 140.0	 79.7	 0.0	 6.5	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	81	 1	 21.6	 3.0	 0.0	 3.54	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	82	 1	 0.0	 -0.0	 0.0	 2.31	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	83	 1	 119.2	 20.7	 0.0	 3.31	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	84	 1	 26.43	 9.9	 0.0	 9.57	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	85	 1	 0.24	 -1.66	 0.0	 0.65	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	86	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	87	 1	 -0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	88	 1	 -0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	89	 1	 0.0	 0.0	 0.0	 58.57	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	90	 1	 -0.0	 0.0	 0.0	 1.34	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	91	 1	 187.9	 110.2	 0.0	 21.25	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	92	 1	 14.92	 5.5	 0.0	 1.31	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	93	 1	 -18.52	 6.1	 0.0	 0.79	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	94	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	95	 1	 4.61	 1.7	 0.0	 2.32	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	96	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	97	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	98	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	99	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	100	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	101	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	102	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	103	 1	 62.87	 20.5	 0.0	 1.15	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	104	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	105	 1	 13.5	 14.8	 0.0	 132.435168	 0	    1.00000	    0.00000	 380.0	 9	    1.20000	    0.80000;
	106	 1	 126.3	 42.4	 0.0	 55.24	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	107	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	108	 1	 6.91	 -4.6	 0.0	 5.75	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	109	 1	 15.72	 5.2	 0.0	 0.11	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	110	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	111	 1	 16.12	 4.3	 0.0	 0.49	 0	    1.00000	    0.00000	 110.0	 23	    1.10000	    0.90000;
	112	 1	 38.74	 6.1	 0.0	 1.17	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	113	 1	 22.13	 10.7	 0.0	 14.21	 0	    1.00000	    0.00000	 220.0	 8	    1.10000	    0.90000;
	114	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	115	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	116	 1	 0.0	 -0.0	 0.0	 0.73	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	117	 1	 0.0	 0.0	 0.0	 0.83	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	118	 1	 138.8	 136.7	 0.0	 8.76	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	119	 1	 137.3	 66.4	 0.174767	 14.17407	 0	    1.00000	    0.00000	 220.0	 23	    1.10000	    0.90000;
	120	 1	 67.76	 19.18	 0.0	 1.47	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	121	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	122	 1	 0.0	 -0.0	 0.0	 6.62	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	123	 1	 -0.0	 -0.0	 0.0	 7.22	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	124	 1	 1.0	 0.3	 0.0	 0.19	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	125	 1	 20.9	 3.0	 0.0	 5.74	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	126	 1	 0.0	 0.0	 0.0	 0.12	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	127	 1	 21.52	 5.1	 0.0	 0.5	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	128	 1	 71.98	 28.8	 0.0	 11.0	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	129	 1	 0.0	 0.0	 0.205132	 4.470744	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	130	 1	 363.25	 115.39	 0.0	 3.95	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	131	 1	 192.9	 73.3	 0.0	 20.75	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	132	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	133	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	134	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	135	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	136	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	137	 1	 17.52	 6.3	 0.0	 0.26	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	138	 1	 33.14	 12.0	 0.0	 0.65	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	139	 1	 40.44	 25.0	 0.0	 9.82	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	140	 1	 193.17	 53.37	 0.0	 4.58	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	141	 1	 90.7	 25.5	 0.0	 3.11	 0	    1.00000	    0.00000	 220.0	 3	    1.20000	    0.80000;
	142	 1	 176.3	 -58.9	 0.0	 24.77	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	143	 1	 35.94	 22.3	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	144	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	145	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	146	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	147	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	148	 1	 143.9	 123.2	 0.0	 72.64	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	149	 1	 -0.0	 -0.0	 0.0	 3.77	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	150	 1	 -0.0	 8.4	 0.0	 15.72	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	151	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	152	 1	 51.36	 -8.8	 0.0	 2.15	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	153	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	154	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	155	 1	 -0.0	 -0.0	 0.0	 82.55	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	156	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	157	 1	 322.7	 11.9	 0.0	 10.28	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	158	 1	 303.6	 79.8	 0.019533	 1.690467	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	159	 1	 3.8	 1.3	 0.0	 0.4	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	160	 1	 137.0	 19.5	 0.0	 4.9	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	161	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	162	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	163	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	164	 1	 61.07	 36.0	 0.0	 3.09	 0	    1.00000	    0.00000	 220.0	 11	    1.10000	    0.90000;
	165	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	166	 1	 -0.0	 0.0	 0.0	 3.24	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	167	 1	 0.0	 0.0	 0.0	 6.520303	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	168	 1	 55.7	 7.9	 0.0	 4.21	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	169	 1	 0.0	 0.0	 0.0	 4.21	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	170	 1	 1.8	 0.7	 0.0	 0.3	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	171	 1	 0.0	 -0.0	 0.0	 0.71	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	172	 1	 2.5	 0.0	 0.0	 0.96	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	173	 1	 0.0	 0.0	 0.0	 0.09	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	174	 1	 38.94	 11.0	 0.0	 0.64	 0	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	175	 1	 45.15	 14.1	 0.0	 0.19	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	176	 1	 0.0	 -0.0	 0.0	 5.75	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	177	 1	 0.0	 0.0	 0.019004	 4.360996	 0	    1.00000	    0.00000	 220.0	 11	    1.10000	    0.90000;
	178	 1	 0.0	 -0.0	 0.566322	 -0.241138	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	179	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	180	 1	 17.22	 5.7	 0.0	 1.22	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	181	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	182	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 20	    1.10000	    0.90000;
	183	 1	 0.0	 0.0	 0.0	 4.3	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	184	 1	 23.73	 12.7	 0.0	 0.52	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	185	 1	 121.9	 7.4	 0.0	 1.34	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	186	 1	 0.0	 -0.0	 0.135375	 47.750675	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	187	 1	 47.35	 16.4	 0.0	 4.08	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	188	 1	 -0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	189	 1	 -0.0	 -0.0	 0.0	 21.39	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	190	 1	 38.14	 12.5	 0.0	 6.28	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	191	 1	 54.2	 7.8	 0.0	 94.9	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	192	 1	 130.6	 84.9	 0.0	 4.22	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	193	 1	 7.91	 2.6	 0.0	 0.74	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	194	 1	 42.1	 74.61	 0.0	 37.58	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	195	 1	 -75.38	 7.8	 0.0	 29.9	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	196	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	197	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	198	 1	 41.05	 14.3	 0.0	 11.53	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	199	 1	 -0.0	 -0.0	 0.0	 4.14	 0	    1.00000	    0.00000	 220.0	 8	    1.10000	    0.90000;
	200	 1	 100.9	 49.3	 0.020067	 4.329933	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	201	 1	 -0.0	 0.0	 0.116699	 1.102475	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	202	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	203	 1	 -0.0	 0.0	 0.0	 2.03	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	204	 1	 -0.0	 0.0	 0.0	 98.53	 0	    1.00000	    0.00000	 380.0	 14	    1.10000	    0.90000;
	205	 1	 2.8	 264.7	 0.529803	 56.537931	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	206	 1	 38.34	 5.6	 0.0	 7.64	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	207	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	208	 1	 269.6	 65.7	 0.0	 0.0	 0	    1.00000	    0.00000	 120.0	 20	    1.20000	    0.80000;
	209	 1	 -8.71	 -19.54	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	210	 1	 160.0	 3.3	 0.076728	 5.693272	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	211	 1	 32.34	 12.0	 0.0	 6.1	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	212	 1	 100.1	 45.1	 0.0	 1.11	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	213	 1	 12.31	 3.9	 0.076917	 5.053083	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	214	 1	 131.75	 24.35	 0.0	 4.48	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	215	 1	 0.0	 0.0	 0.0	 107.29	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	216	 1	 0.0	 -0.0	 0.0	 20.96	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	217	 1	 0.0	 0.0	 0.0	 0.56	 0	    1.00000	    0.00000	 150.0	 7	    1.10000	    0.90000;
	218	 1	 0.0	 0.0	 0.0	 1.29	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	219	 1	 0.0	 -0.0	 0.0	 1.7	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	220	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	221	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	222	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	223	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	224	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	225	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	226	 1	 9.21	 3.3	 0.0	 1.2	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	227	 1	 0.0	 -0.0	 0.488616	 70.580637	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	228	 1	 166.0	 60.3	 0.0	 0.57	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	229	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	230	 1	 -0.0	 0.0	 0.0	 0.1	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	231	 1	 79.4	 11.3	 0.0	 4.92	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	232	 1	 0.0	 0.0	 0.0	 0.16	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	233	 1	 -0.0	 -0.0	 0.0	 66.65	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	234	 1	 -597.44	 -326.86	 0.0	 0.0	 0	    1.00000	    0.00000	 27.0	 3	    1.10000	    0.90000;
	235	 1	 147.76	 32.73	 0.0	 8.34	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	236	 1	 0.0	 -0.0	 0.0	 5.17	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	237	 1	 26.8	 -3.7	 0.0	 51.261678	 0	    1.00000	    0.00000	 380.0	 9	    1.10000	    0.90000;
	238	 1	 -0.0	 0.0	 0.176128	 3.073227	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	239	 1	 257.5	 131.1	 0.0	 1.08	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	240	 1	 16.7	 2.4	 0.0	 6.09	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	241	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	242	 1	 -0.0	 -0.0	 0.0	 1.91	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	243	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	244	 1	 100.8	 13.2	 0.0	 5.24	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	245	 1	 111.7	 10.96	 0.0	 4.22	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	246	 1	 90.38	 -5.05	 0.0	 8.49	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	247	 1	 370.5	 -17.0	 0.0	 9.91	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	248	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	249	 1	 41.05	 -46.0	 0.056872	 19.253128	 0	    1.00000	    0.00000	 220.0	 11	    1.10000	    0.90000;
	250	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	251	 1	 9.91	 3.2	 0.0	 0.67	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	252	 1	 -0.69	 -5.46	 0.0	 5.07	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	253	 1	 55.46	 8.4	 0.0	 5.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	254	 1	 94.9	 36.2	 0.0	 16.46	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	255	 1	 81.09	 48.0	 0.0	 0.03	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	256	 1	 0.0	 0.0	 0.0	 113.7	 0	    1.00000	    0.00000	 380.0	 18	    1.20000	    0.80000;
	257	 1	 210.4	 159.2	 0.100208	 131.579896	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	258	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 10.6	 1	    1.10000	    0.90000;
	259	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	260	 1	 19.32	 26.0	 0.0	 0.69	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	261	 1	 29.83	 7.3	 0.0	 6.49	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	262	 1	 -0.0	 -0.0	 0.0	 2.42	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	263	 1	 20.9	 3.0	 0.0	 4.11	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	264	 1	 19.92	 6.6	 0.0	 0.56	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	265	 1	 57.16	 2.0	 0.0	 1.48	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	266	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	267	 1	 36.84	 13.9	 0.0	 3.3	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	268	 1	 -15.04	 -5.12	 0.0	 0.43	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	269	 1	 9.21	 6.0	 0.060012	 0.149988	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	270	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 10.6	 1	    1.10000	    0.90000;
	271	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	272	 1	 -0.0	 0.0	 0.114032	 0.684974	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	273	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	274	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	275	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	276	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	277	 1	 119.9	 3.7	 0.0	 3.33	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	278	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 21.0	 1	    1.10000	    0.90000;
	279	 1	 -0.0	 -0.0	 0.172756	 -0.134366	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	280	 1	 -0.0	 0.0	 0.039023	 0.210733	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	281	 1	 73.14	 21.55	 0.0	 8.52	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	282	 1	 -0.0	 -0.0	 0.0	 12.48	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	283	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	284	 1	 0.0	 -0.0	 0.401208	 101.317571	 0	    1.00000	    0.00000	 380.0	 3	    1.20000	    0.80000;
	285	 1	 39.74	 11.8	 0.0	 1.44	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	286	 1	 44.35	 5.1	 0.0	 4.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	287	 1	 86.8	 28.4	 0.0	 1.34	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	288	 1	 50.56	 5.9	 0.0	 10.58	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	289	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	290	 1	 0.0	 0.0	 0.0	 4.73	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	291	 1	 110.9	 32.7	 0.0	 15.4	 0	    1.00000	    0.00000	 220.0	 14	    1.10000	    0.90000;
	292	 1	 18.2	 2.6	 0.0	 12.38	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	293	 1	 0.0	 0.0	 0.181549	 14.690889	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	294	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 14.4	 1	    1.10000	    0.90000;
	295	 1	 46.15	 18.2	 0.0	 1.29	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	296	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 6.3	 1	    1.10000	    0.90000;
	297	 1	 55.46	 15.7	 0.0	 13.46	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	298	 1	 34.04	 12.3	 0.0	 0.23	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	299	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	300	 1	 321.98	 84.4	 0.0	 1.34	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	301	 1	 42.55	 8.2	 0.0	 2.06	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	302	 1	 33.44	 10.0	 0.0	 1.36	 0	    1.00000	    0.00000	 110.0	 3	    1.10000	    0.90000;
	303	 1	 -0.0	 0.0	 0.019646	 0.570354	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	304	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	305	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	306	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	307	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	308	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	309	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	310	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	311	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	312	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	313	 1	 -24.99	 -4.94	 0.0	 6.99	 0	    1.00000	    0.00000	 220.0	 3	    1.20000	    0.80000;
	314	 1	 95.69	 24.54	 0.0	 2.85	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	315	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 6.3	 1	    1.10000	    0.90000;
	316	 1	 37.34	 10.9	 0.0	 0.63	 0	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	317	 1	 340.0	 93.8	 0.230291	 74.777686	 0	    1.00000	    0.00000	 380.0	 13	    1.10000	    0.90000;
	318	 1	 -0.0	 0.0	 0.0	 2.04	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	319	 1	 155.6	 54.7	 0.0	 2.21	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	320	 1	 105.2	 0.1	 0.0	 7.36	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	321	 1	 69.83	 15.12	 0.0	 2.23	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	322	 1	 -0.0	 0.0	 1.107693	 6.867601	 0	    1.00000	    0.00000	 380.0	 7	    1.10000	    0.90000;
	323	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	324	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	325	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 6.3	 1	    1.10000	    0.90000;
	326	 1	 -0.0	 -0.0	 0.197696	 3.784535	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	327	 1	 176.2	 20.8	 0.019425	 4.590288	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	328	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	329	 1	 27.03	 8.8	 0.0	 1.84	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	330	 1	 0.0	 -0.0	 0.0	 0.28	 0	    1.00000	    0.00000	 150.0	 6	    1.10000	    0.90000;
	331	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	332	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 6.3	 1	    1.10000	    0.90000;
	333	 1	 -0.0	 0.0	 0.0	 1.15	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	334	 1	 0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	335	 1	 14.62	 4.8	 0.0	 1.02	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	336	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	337	 1	 0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	338	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	339	 1	 -0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	340	 1	 45.05	 -2.2	 0.0	 3.96	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	341	 1	 0.0	 -0.0	 0.0	 2.55	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	342	 1	 -23.43	 57.4	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	343	 1	 426.6	 93.7	 0.0	 80.94	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	344	 1	 152.07	 22.52	 0.0	 7.87	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	345	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	346	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	347	 1	 0.0	 0.0	 0.0	 0.7	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	348	 1	 2.5	 3.8	 0.0	 0.15	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	349	 1	 30.53	 10.9	 0.589029	 2.678252	 0	    1.00000	    0.00000	 220.0	 19	    1.10000	    0.90000;
	350	 1	 34.04	 4.4	 0.0	 1.25	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	351	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	352	 1	 45.85	 7.0	 0.0	 1.05	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	353	 1	 -0.0	 0.0	 0.0	 30.97	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	354	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	355	 1	 46.05	 16.9	 0.03829	 0.29171	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	356	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	357	 1	 0.0	 0.0	 0.0	 3.95	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	358	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	359	 1	 -876.96	 -325.87	 0.0	 0.0	 0	    1.00000	    0.00000	 27.0	 3	    1.10000	    0.90000;
	360	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	361	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	362	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	363	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	364	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	365	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 15.75	 1	    1.10000	    0.90000;
	366	 1	 167.9	 18.2	 0.0	 5.97	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	367	 1	 0.0	 -0.0	 0.0	 13.49	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	368	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	369	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	370	 1	 -0.0	 -0.0	 0.0	 0.68	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	371	 1	 44.35	 14.8	 0.0	 1.94	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	372	 1	 131.9	 31.1	 0.457733	 14.047628	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	373	 1	 0.0	 -0.0	 0.0	 0.72	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	374	 1	 224.2	 73.9	 0.039171	 84.090829	 0	    1.00000	    0.00000	 380.0	 13	    1.10000	    0.90000;
	375	 1	 -0.0	 0.0	 0.0	 26.3	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	376	 1	 128.9	 73.7	 0.0	 25.37	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	377	 1	 0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 22	    1.10000	    0.90000;
	378	 1	 0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 22	    1.10000	    0.90000;
	379	 1	 -0.0	 -0.0	 0.0	 13.85	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	380	 1	 118.4	 16.9	 0.0	 8.02	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	381	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 22	    1.10000	    0.90000;
	382	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 22	    1.10000	    0.90000;
	383	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 22	    1.10000	    0.90000;
	384	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 22	    1.10000	    0.90000;
	385	 1	 -0.0	 -0.0	 0.0	 2.66	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	386	 1	 -0.0	 0.0	 0.0	 4.06	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	387	 1	 0.0	 0.0	 0.135493	 12.74062	 0	    1.00000	    0.00000	 380.0	 21	    1.10000	    0.90000;
	388	 1	 -0.0	 0.0	 0.276837	 2.240894	 0	    1.00000	    0.00000	 380.0	 16	    1.10000	    0.90000;
	389	 1	 -0.0	 -0.0	 0.0	 7.09	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	390	 1	 113.9	 24.5	 0.0	 6.72	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	391	 1	 88.0	 12.6	 0.0	 22.25	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	392	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 6.3	 1	    1.10000	    0.90000;
	393	 1	 42.67	 12.1	 0.0	 14.84	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	394	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	395	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	396	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	397	 1	 0.0	 -0.0	 0.0	 1.29	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	398	 1	 -0.0	 -0.0	 0.0	 9.41	 0	    1.00000	    0.00000	 220.0	 18	    1.20000	    0.80000;
	399	 1	 160.8	 10.6	 0.039515	 21.960485	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	400	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 10.3	 1	    1.10000	    0.90000;
	401	 1	 126.8	 21.4	 0.0	 11.43	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	402	 1	 48.8	 6.9	 0.0	 3.11	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	403	 1	 38.74	 9.0	 0.0	 0.57	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	404	 1	 350.4	 29.3	 0.0	 19.31	 0	    1.00000	    0.00000	 220.0	 11	    1.10000	    0.90000;
	405	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	406	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	407	 1	 103.8	 2.7	 0.0	 3.33	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	408	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	409	 1	 -0.13	 -1.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 8	    1.10000	    0.90000;
	410	 1	 0.0	 -0.0	 0.0	 0.66	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	411	 1	 0.0	 0.0	 0.0	 6.34	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	412	 1	 96.7	 26.8	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	413	 1	 0.0	 0.0	 0.0	 19.54	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	414	 1	 -0.0	 -0.0	 0.0	 14.87	 0	    1.00000	    0.00000	 220.0	 23	    1.10000	    0.90000;
	415	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	416	 1	 19.02	 6.0	 0.0	 0.25	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	417	 1	 102.1	 25.3	 0.0	 1.11	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	418	 1	 -0.0	 0.0	 0.0	 2.44	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	419	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	420	 1	 113.3	 30.2	 0.039525	 2.140475	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	421	 1	 8.31	 3.0	 0.0	 0.99	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	422	 1	 119.6	 29.6	 0.0	 5.34	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	423	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 6.3	 1	    1.10000	    0.90000;
	424	 1	 -0.0	 0.0	 0.0	 18.07	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	425	 1	 49.9	 144.0	 1.091586	 80.060431	 0	    1.00000	    0.00000	 380.0	 18	    1.20000	    0.80000;
	426	 1	 27.33	 11.9	 0.0	 1.17	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	427	 1	 191.2	 -3.4	 0.0	 19.21	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	428	 1	 -0.0	 -0.0	 0.028663	 18.318528	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	429	 1	 101.6	 14.5	 0.0	 1.94	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	430	 1	 177.1	 66.9	 0.0	 71.03	 0	    1.00000	    0.00000	 380.0	 16	    1.10000	    0.90000;
	431	 1	 0.0	 -0.0	 0.0	 0.3	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	432	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 6.3	 1	    1.10000	    0.90000;
	433	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 23	    1.10000	    0.90000;
	434	 1	 0.0	 -0.0	 0.038538	 -0.028903	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	435	 1	 53.46	 18.7	 0.0	 1.64	 0	    1.00000	    0.00000	 220.0	 20	    1.10000	    0.90000;
	436	 1	 0.0	 -0.0	 0.0	 12.73	 0	    1.00000	    0.00000	 220.0	 14	    1.10000	    0.90000;
	437	 1	 344.7	 -31.1	 0.0	 39.129841	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	438	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	439	 1	 -0.0	 -0.0	 0.0	 1.98	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	440	 1	 85.1	 67.0	 0.0	 0.18	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	441	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	442	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	443	 1	 -0.0	 0.0	 0.0	 0.08	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	444	 1	 189.3	 76.7	 0.0	 3.24	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	445	 1	 23.73	 9.4	 0.0	 1.45	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	446	 1	 10.01	 -21.0	 0.0	 8.59	 0	    1.00000	    0.00000	 220.0	 11	    1.10000	    0.90000;
	447	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	448	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	449	 1	 228.1	 131.8	 0.95374	 3.934956	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	450	 1	 -0.0	 -0.0	 0.0	 1.05	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	451	 1	 -14.85	 -4.95	 0.0	 0.37	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	452	 1	 20.9	 3.0	 0.0	 2.65	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	453	 1	 431.7	 121.6	 0.0	 1.14	 0	    1.00000	    0.00000	 220.0	 21	    1.10000	    0.90000;
	454	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	455	 1	 17.62	 7.7	 0.0	 0.59	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	456	 1	 0.0	 0.0	 0.0	 109.27	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	457	 1	 103.0	 12.0	 0.0	 0.63	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	458	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 9	    1.10000	    0.90000;
	459	 1	 0.0	 0.0	 0.0	 4.76	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	460	 1	 0.0	 0.0	 0.0	 25.85	 0	    1.00000	    0.00000	 380.0	 1	    1.20000	    0.80000;
	461	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.20000	    0.80000;
	462	 1	 0.0	 -0.0	 0.060508	 3.079577	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	463	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 9	    1.20000	    0.80000;
	464	 1	 42.05	 17.2	 0.0	 1.31	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	465	 1	 -0.16	 -2.91	 0.0	 0.43	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	466	 1	 0.0	 -0.0	 0.0	 0.06	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	467	 1	 163.1	 46.3	 0.0	 10.6	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	468	 1	 0.0	 -0.0	 0.0	 2.13	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	469	 1	 -0.0	 -0.0	 0.0	 2.81	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	470	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	471	 1	 0.0	 0.0	 0.049626	 -1.990412	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	472	 1	 -0.0	 -0.0	 0.0	 1.05	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	473	 1	 153.3	 21.8	 0.0	 18.25	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	474	 1	 -0.0	 0.0	 0.0	 141.93	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	475	 1	 67.17	 -23.9	 0.0	 0.93	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	476	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	477	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	478	 1	 -0.0	 0.0	 0.114166	 11.294861	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	479	 1	 382.4	 86.3	 0.0	 22.29	 0	    1.00000	    0.00000	 220.0	 11	    1.10000	    0.90000;
	480	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	481	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	482	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	483	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	484	 1	 33.5	 4.8	 0.0	 5.48	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	485	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	486	 1	 0.01	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 8	    1.10000	    0.90000;
	487	 1	 0.0	 0.0	 0.0	 12.29	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	488	 1	 291.5	 51.3	 0.244436	 12.636488	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	489	 1	 24.23	 7.1	 0.0	 1.64	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	490	 1	 108.6	 2.6	 0.0	 31.8	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	491	 1	 4.0	 2.4	 0.0	 0.03	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	492	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	493	 1	 30.03	 10.9	 0.0	 1.45	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	494	 1	 0.0	 0.0	 0.0	 45.39	 0	    1.00000	    0.00000	 380.0	 15	    1.20000	    0.80000;
	495	 1	 524.5	 43.0	 0.0	 6.85	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	496	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	497	 1	 129.9	 18.5	 0.0	 0.38	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	498	 1	 -0.0	 0.0	 0.0	 1.92	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	499	 1	 4.4	 0.0	 0.0	 0.51	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	500	 1	 9.22	 1.2	 0.0	 0.8	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	501	 1	 0.0	 0.0	 0.059058	 0.120942	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	502	 1	 -0.0	 0.0	 0.0	 0.14	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	503	 1	 -0.0	 0.0	 0.0	 0.36	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	504	 1	 0.0	 -0.0	 0.0	 0.81	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	505	 1	 35.41	 20.3	 0.0	 10.07	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	506	 1	 3.2	 1.2	 0.0	 0.69	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	507	 1	 372.8	 147.5	 0.0	 27.73	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	508	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	509	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	510	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	511	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	512	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	513	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	514	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	515	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	516	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	517	 1	 -0.0	 0.0	 0.080024	 -0.240071	 0	    1.00000	    0.00000	 220.0	 11	    1.10000	    0.90000;
	518	 1	 197.5	 48.3	 0.0	 0.71	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	519	 1	 -0.0	 0.0	 0.0	 0.22	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	520	 1	 -0.0	 -0.0	 0.0	 15.15	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	521	 1	 110.4	 26.2	 0.0	 5.62	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	522	 1	 -0.15	 -1.93	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 8	    1.10000	    0.90000;
	523	 1	 -0.0	 0.0	 1.138771	 10.122844	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	524	 1	 -0.0	 -0.0	 0.0	 14.6	 0	    1.00000	    0.00000	 220.0	 12	    1.10000	    0.90000;
	525	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	526	 1	 -4.86	 -2.15	 0.0	 0.31	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	527	 1	 141.1	 2.1	 0.0	 4.78	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	528	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	529	 1	 52.96	 32.8	 0.0	 14.14	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	530	 1	 149.2	 -74.6	 0.227896	 49.239582	 0	    1.00000	    0.00000	 380.0	 13	    1.10000	    0.90000;
	531	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 7	    1.10000	    0.90000;
	532	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	533	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 22	    1.10000	    0.90000;
	534	 1	 10.81	 5.1	 0.0	 1.09	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	535	 1	 -0.0	 0.0	 0.0	 2.37	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	536	 1	 35.54	 11.5	 0.0	 3.65	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	537	 1	 -0.0	 -0.0	 0.230877	 22.907222	 0	    1.00000	    0.00000	 380.0	 13	    1.10000	    0.90000;
	538	 1	 48.93	 14.52	 0.0	 2.85	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	539	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 15.0	 1	    1.10000	    0.90000;
	540	 1	 0.0	 -0.0	 0.0	 26.52	 0	    1.00000	    0.00000	 150.0	 9	    1.20000	    0.80000;
	541	 1	 10.01	 4.0	 0.0	 8.11	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	542	 1	 0.0	 0.0	 0.0	 0.82	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	543	 1	 109.7	 15.0	 0.0	 30.97	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	544	 1	 65.17	 -51.5	 0.0	 4.85	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	545	 1	 66.97	 14.1	 0.0	 5.58	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	546	 1	 0.0	 0.0	 0.0	 7.11	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	547	 1	 -0.0	 -0.0	 0.0	 3.78	 0	    1.00000	    0.00000	 220.0	 8	    1.10000	    0.90000;
	548	 1	 56.76	 23.2	 0.0	 0.49	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	549	 1	 0.0	 -0.0	 0.0	 0.7	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	550	 1	 10.81	 3.9	 0.0	 1.64	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	551	 1	 0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	552	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	553	 1	 373.7	 125.6	 0.341257	 71.244578	 0	    1.00000	    0.00000	 380.0	 14	    1.10000	    0.90000;
	554	 1	 0.0	 -0.0	 0.0	 0.16	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	555	 1	 0.0	 -0.0	 0.0	 2.27	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	556	 1	 0.0	 -0.0	 0.0	 1.61	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	557	 1	 -0.0	 0.0	 0.0	 35.09	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	558	 1	 -0.18	 -1.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	559	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	560	 1	 9.91	 3.3	 0.0	 6.72	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	561	 1	 221.35	 51.8	 0.0	 8.81	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	562	 1	 23.83	 7.9	 0.0	 0.72	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	563	 1	 -95.71	 -2.8	 0.0	 7.25	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	564	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 20	    1.10000	    0.90000;
	565	 1	 44.05	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 7	    1.10000	    0.90000;
	566	 1	 16.52	 3.0	 0.03836	 11.50164	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	567	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 7	    1.10000	    0.90000;
	568	 1	 -0.0	 -0.0	 0.0	 19.63	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	569	 1	 0.0	 -0.0	 0.0	 0.3	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	570	 1	 0.0	 -0.0	 0.0	 105.84	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	571	 1	 -0.0	 0.0	 0.0	 28.09	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	572	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	573	 1	 -0.0	 0.0	 0.258771	 12.056323	 0	    1.00000	    0.00000	 220.0	 19	    1.10000	    0.90000;
	574	 1	 -0.0	 0.0	 0.059384	 0.280616	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	575	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	576	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	577	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	578	 1	 34.94	 21.6	 0.0	 0.18	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	579	 1	 134.1	 34.2	 0.0	 0.75	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	580	 1	 17.72	 5.9	 0.0	 0.32	 0	    1.00000	    0.00000	 220.0	 21	    1.10000	    0.90000;
	581	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	582	 1	 -0.0	 -0.0	 1.560224	 77.024822	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	583	 1	 0.0	 0.0	 0.0	 7.85	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	584	 1	 -0.51	 -20.69	 0.0	 2.07	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	585	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	586	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	587	 1	 77.79	 -40.8	 0.0	 12.06	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	588	 1	 0.0	 -0.0	 0.0	 2.09	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	589	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	590	 1	 5.01	 2.0	 0.0	 0.13	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	591	 1	 -19.66	 -10.83	 0.0	 0.06	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	592	 1	 56.5	 36.29	 0.0	 3.08	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	593	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	594	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	595	 1	 -0.0	 -0.0	 0.090774	 7.330444	 0	    1.00000	    0.00000	 220.0	 18	    1.20000	    0.80000;
	596	 1	 3.81	 0.24	 0.0	 0.23	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	597	 1	 254.7	 79.4	 0.0	 9.43	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	598	 1	 20.9	 3.0	 0.0	 2.54	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	599	 1	 77.99	 30.8	 0.0	 2.41	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	600	 1	 -0.15	 -1.0	 0.0	 0.38	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	601	 1	 129.1	 7.4	 0.0	 0.04	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	602	 1	 126.3	 17.9	 0.0	 2.59	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	603	 1	 151.5	 7.9	 0.0	 5.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	604	 1	 -0.0	 0.0	 0.019593	 1.150407	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	605	 1	 26.4	 3.8	 0.0	 4.65	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	606	 1	 0.0	 -0.0	 0.139186	 6.210814	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	607	 1	 20.52	 10.3	 0.0	 0.04	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	608	 1	 4.71	 0.7	 0.0	 11.39	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	609	 1	 70.68	 13.5	 0.0	 6.96	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	610	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	611	 1	 234.3	 105.9	 0.020294	 5.479706	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	612	 1	 24.43	 8.7	 0.0	 0.17	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	613	 1	 -0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	614	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	615	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	616	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	617	 1	 46.15	 11.2	 0.0	 10.16	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	618	 1	 33.74	 20.9	 0.0	 1.1	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	619	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	620	 1	 35.84	 12.5	 0.0	 0.26	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	621	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	622	 1	 -0.0	 0.0	 0.646492	 4.682923	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	623	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	624	 1	 -0.0	 -0.0	 0.0	 2.72	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	625	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	626	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	627	 1	 123.1	 6.5	 0.0	 3.25	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	628	 1	 -0.0	 -0.0	 0.0	 1.24	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	629	 1	 83.9	 11.9	 0.0	 1.14	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	630	 1	 0.1	 -0.0	 0.0	 0.57	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	631	 1	 26.93	 -22.4	 0.0	 4.95	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	632	 1	 29.03	 9.0	 0.0	 0.56	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	633	 1	 188.42	 106.93	 0.0	 4.89	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	634	 1	 0.0	 0.0	 0.0	 68.575723	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	635	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	636	 1	 -0.0	 0.0	 0.0	 0.69	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	637	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	638	 1	 0.0	 -0.0	 0.295061	 0.304116	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	639	 1	 9.7	 1.4	 0.0	 4.89	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	640	 1	 176.2	 -46.9	 0.0	 5.47	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	641	 1	 33.14	 11.6	 0.0	 0.22	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	642	 1	 18.3	 8.2	 0.0	 35.421268	 0	    1.00000	    0.00000	 380.0	 9	    1.20000	    0.80000;
	643	 1	 69.08	 24.0	 0.0	 1.0	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	644	 1	 -0.0	 -0.0	 0.057082	 3.172432	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	645	 1	 -0.0	 0.0	 0.22164	 16.9353	 0	    1.00000	    0.00000	 220.0	 3	    1.20000	    0.80000;
	646	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	647	 1	 -0.0	 -0.0	 0.199768	 27.888516	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	648	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	649	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	650	 1	 44.85	 7.1	 0.0	 5.65	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	651	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 23	    1.10000	    0.90000;
	652	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 23	    1.10000	    0.90000;
	653	 1	 -12.61	 4.1	 0.0	 1.83	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	654	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	655	 1	 0.0	 0.0	 0.0	 2.45	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	656	 1	 36.74	 10.3	 0.0	 8.1	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	657	 1	 100.53	 43.37	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 24	    1.10000	    0.90000;
	658	 1	 2.2	 1.3	 0.019376	 1.050624	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	659	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	660	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	661	 1	 -0.0	 -0.0	 0.0	 29.42	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	662	 1	 42.04	 43.0	 0.0	 0.02	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	663	 1	 0.0	 0.0	 0.0	 22.71	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	664	 1	 104.4	 27.6	 0.039809	 1.850191	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	665	 1	 0.0	 -0.0	 0.362004	 3.698497	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	666	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 9	    1.10000	    0.90000;
	667	 1	 23.7	 3.4	 0.0	 8.13	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	668	 1	 274.32	 5.66	 0.0	 13.24	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	669	 1	 2.5	 0.0	 0.0	 0.64	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	670	 1	 1.8	 0.7	 0.0	 0.18	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	671	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	672	 1	 -0.0	 0.0	 0.189164	 35.274722	 0	    1.00000	    0.00000	 380.0	 11	    1.10000	    0.90000;
	673	 1	 97.0	 40.3	 0.0	 16.79	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	674	 1	 0.0	 -0.0	 0.0	 0.88	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	675	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	676	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	677	 1	 15.22	 5.1	 0.0	 1.34	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	678	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	679	 1	 -0.0	 -0.0	 0.31285	 13.426672	 0	    1.00000	    0.00000	 380.0	 9	    1.20000	    0.80000;
	680	 1	 108.5	 35.3	 0.0	 49.63	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	681	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 24	    1.10000	    0.90000;
	682	 1	 24.33	 7.6	 0.0	 1.18	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	683	 1	 44.75	 0.9	 0.0	 6.67	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	684	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	685	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	686	 1	 40.5	 5.7	 0.0	 3.9	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	687	 1	 -0.0	 -0.0	 0.0	 27.85	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	688	 1	 9.01	 6.8	 0.0	 0.44	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	689	 1	 81.09	 48.0	 0.0	 0.03	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	690	 1	 0.0	 0.0	 0.0	 0.43	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	691	 1	 11.01	 5.5	 0.0	 1.12	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	692	 1	 -0.0	 0.0	 0.0	 1.47	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	693	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	694	 1	 336.2	 131.6	 0.0	 64.01	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	695	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	696	 1	 -22.95	 -3.72	 0.0	 14.34	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	697	 1	 0.0	 0.0	 0.0	 0.97	 0	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	698	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	699	 1	 0.0	 0.0	 0.0	 9.41	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	700	 1	 67.3	 94.8	 0.0	 7.96	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	701	 1	 -0.0	 0.0	 0.0	 70.37	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	702	 1	 0.0	 0.0	 0.0	 33.23	 0	    1.00000	    0.00000	 380.0	 3	    1.20000	    0.80000;
	703	 1	 16.62	 3.1	 0.0	 1.14	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	704	 1	 5.81	 1.1	 0.0	 4.02	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	705	 1	 0.0	 -0.0	 0.0	 6.31	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	706	 1	 -0.0	 -0.0	 0.0	 17.44	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	707	 1	 113.4	 11.9	 0.0	 5.4	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	708	 1	 0.0	 -0.0	 0.0	 1.05	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	709	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	710	 1	 23.26	 3.01	 0.0	 9.29	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	711	 1	 57.26	 15.6	 0.0	 3.43	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	712	 1	 0.0	 0.0	 0.17102	 25.167483	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	713	 1	 7.0	 1.0	 0.0	 1.3	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	714	 1	 7.01	 2.0	 0.0	 0.44	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	715	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	716	 1	 87.8	 12.5	 0.0	 0.38	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	717	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	718	 1	 6.61	 2.92	 0.0	 1.17	 0	    1.00000	    0.00000	 220.0	 14	    1.10000	    0.90000;
	719	 1	 115.9	 14.7	 0.019966	 2.9	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	720	 1	 20.52	 4.0	 0.0	 2.77	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	721	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	722	 1	 0.0	 -0.0	 0.366153	 32.651054	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	723	 1	 68.18	 22.0	 0.0	 2.42	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	724	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	725	 1	 23.23	 7.6	 0.0	 0.76	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	726	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	727	 1	 181.7	 51.0	 0.0	 73.49	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	728	 1	 -0.0	 0.0	 0.0	 10.04	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	729	 1	 40.0	 5.7	 0.0	 2.06	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	730	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	731	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	732	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	733	 1	 287.31	 -5.58	 0.0	 19.9	 0	    1.00000	    0.00000	 380.0	 13	    1.10000	    0.90000;
	734	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	735	 1	 144.4	 35.5	 0.0	 7.66	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	736	 1	 -0.0	 0.0	 0.0	 1.49	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	737	 1	 0.0	 0.0	 0.0	 0.25	 0	    1.00000	    0.00000	 110.0	 3	    1.10000	    0.90000;
	738	 1	 0.0	 -0.0	 0.0	 1.96	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	739	 1	 4.1	 -607.0	 0.290423	 85.788781	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	740	 1	 18.62	 6.2	 0.0	 1.07	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	741	 1	 0.0	 0.0	 0.0	 1.32	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	742	 1	 -0.0	 0.0	 0.0	 0.4	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	743	 1	 23.43	 8.5	 0.0	 0.33	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	744	 1	 23.92	 7.75	 0.0	 1.91	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	745	 1	 77.29	 7.0	 0.0	 17.6	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	746	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	747	 1	 0.0	 -0.0	 0.0	 1.5	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	748	 1	 0.0	 -0.0	 0.385462	 139.767007	 0	    1.00000	    0.00000	 380.0	 3	    1.20000	    0.80000;
	749	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	750	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	751	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	752	 1	 0.0	 -0.0	 0.0	 13.16	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	753	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	754	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	755	 1	 9.61	 3.1	 0.0	 0.77	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	756	 1	 -195.22	 -19.0	 0.078938	 7.621062	 0	    1.00000	    0.00000	 220.0	 11	    1.10000	    0.90000;
	757	 1	 27.03	 9.0	 0.0	 0.98	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	758	 1	 7.71	 16.7	 0.0	 3.59	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	759	 1	 602.9	 201.4	 0.118737	 39.321052	 0	    1.00000	    0.00000	 380.0	 14	    1.10000	    0.90000;
	760	 1	 207.2	 9.4	 0.0	 8.77	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	761	 1	 118.5	 20.4	 0.0	 2.57	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	762	 1	 14.72	 5.3	 0.0	 0.76	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	763	 1	 100.5	 37.0	 0.0	 14.95	 0	    1.00000	    0.00000	 380.0	 18	    1.20000	    0.80000;
	764	 1	 11.61	 7.2	 0.0	 28.77	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	765	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	766	 1	 189.9	 74.7	 0.0	 26.2	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	767	 1	 0.0	 -0.0	 0.0	 0.09	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	768	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	769	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	770	 1	 0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	771	 1	 0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	772	 1	 36.54	 27.4	 0.0	 0.15	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	773	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	774	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	775	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	776	 1	 0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	777	 1	 277.7	 45.4	 0.0	 0.7	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	778	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	779	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 10.0	 1	    1.10000	    0.90000;
	780	 1	 -0.0	 0.0	 0.0	 28.16	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	781	 1	 25.0	 3.6	 0.0	 4.73	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	782	 1	 -0.0	 -0.0	 0.0	 47.4	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	783	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	784	 1	 -0.0	 0.0	 0.0	 1.98	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	785	 1	 16.52	 3.8	 0.0	 0.98	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	786	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	787	 1	 118.1	 16.8	 0.0	 2.94	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	788	 1	 11.51	 3.8	 0.0	 1.21	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	789	 1	 87.8	 -1.4	 0.079073	 36.047349	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	790	 1	 27.53	 17.0	 0.0	 0.76	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	791	 1	 21.02	 13.0	 0.0	 1.17	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	792	 1	 57.96	 18.9	 0.0	 14.91	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	793	 1	 166.9	 86.1	 0.0	 4.06	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	794	 1	 -5.51	 1.8	 0.0	 0.91	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	795	 1	 86.5	 29.0	 0.0	 1.45	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	796	 1	 2.0	 0.7	 0.0	 0.02	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	797	 1	 -0.0	 -0.0	 0.0	 35.78	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	798	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 9	    1.10000	    0.90000;
	799	 1	 72.0	 10.3	 0.0	 6.24	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	800	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	801	 1	 79.69	 39.6	 0.0	 18.83	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	802	 1	 -0.0	 0.0	 0.0	 8.48	 0	    1.00000	    0.00000	 220.0	 18	    1.20000	    0.80000;
	803	 1	 0.0	 -0.0	 0.0	 29.89	 0	    1.00000	    0.00000	 150.0	 9	    1.20000	    0.80000;
	804	 1	 30.03	 14.0	 0.0	 0.61	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	805	 1	 30.93	 8.9	 0.0	 0.45	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	806	 1	 0.0	 -0.0	 0.0	 5.15	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	807	 1	 0.0	 -0.0	 0.0	 10.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	808	 1	 17.72	 5.9	 0.0	 0.52	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	809	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	810	 1	 180.8	 90.8	 0.0	 2.42	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	811	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	812	 1	 0.0	 -0.0	 0.0	 1.97	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	813	 1	 0.0	 0.0	 0.0	 7.35	 0	    1.00000	    0.00000	 220.0	 11	    1.10000	    0.90000;
	814	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	815	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	816	 1	 16.52	 9.0	 0.0	 1.17	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	817	 1	 -0.0	 -0.0	 0.0	 12.14	 0	    1.00000	    0.00000	 220.0	 19	    1.10000	    0.90000;
	818	 1	 -0.18	 -3.57	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	819	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	820	 1	 0.0	 -0.0	 0.0	 0.32	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	821	 1	 0.0	 -0.0	 0.0	 0.48	 0	    1.00000	    0.00000	 220.0	 14	    1.10000	    0.90000;
	822	 1	 -0.0	 -0.0	 0.0	 0.55	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	823	 1	 58.56	 -0.1	 0.0	 7.38	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	824	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 9	    1.10000	    0.90000;
	825	 1	 47.55	 -1.41	 0.0	 0.76	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	826	 1	 -0.0	 -0.0	 0.0	 14.5	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	827	 1	 20.22	 7.3	 0.0	 0.59	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	828	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	829	 1	 -0.0	 0.0	 0.0	 35.364539	 0	    1.00000	    0.00000	 380.0	 20	    1.20000	    0.80000;
	830	 1	 47.95	 29.7	 0.0	 1.59	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	831	 1	 120.63	 56.2	 0.0	 3.0	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	832	 1	 27.13	 8.9	 0.0	 1.37	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	833	 1	 10.71	 3.5	 0.0	 0.82	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	834	 1	 82.89	 26.8	 0.0	 0.65	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	835	 1	 -0.0	 -0.0	 0.0	 0.05	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	836	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	837	 1	 0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	838	 1	 108.6	 38.7	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	839	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	840	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	841	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	842	 1	 -0.13	 -1.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 8	    1.10000	    0.90000;
	843	 1	 166.0	 -8.8	 0.03964	 5.26027	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	844	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	845	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	846	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	847	 1	 17.32	 6.6	 0.0	 16.52	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	848	 1	 0.0	 -0.0	 0.0	 0.17	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	849	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	850	 1	 -0.0	 0.0	 0.0	 31.19	 0	    1.00000	    0.00000	 380.0	 23	    1.20000	    0.80000;
	851	 1	 48.8	 6.9	 0.0	 0.12	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	852	 1	 51.16	 18.2	 0.0	 5.23	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	853	 1	 0.0	 -0.0	 0.33357	 58.172025	 0	    1.00000	    0.00000	 380.0	 3	    1.20000	    0.80000;
	854	 1	 151.2	 72.4	 0.0	 4.57	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	855	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	856	 1	 9.51	 3.2	 0.0	 0.34	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	857	 1	 3.0	 0.2	 0.230913	 0.257194	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	858	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	859	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	860	 1	 91.1	 33.5	 0.0	 1.8	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	861	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	862	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	863	 1	 27.03	 9.8	 0.0	 1.01	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	864	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	865	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	866	 1	 300.1	 126.3	 0.454323	 17.960328	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	867	 1	 0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	868	 1	 0.0	 -0.0	 0.0	 0.56	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	869	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	870	 1	 0.0	 0.0	 0.0	 0.27	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	871	 1	 0.0	 0.0	 0.0	 29.2	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	872	 1	 67.57	 17.0	 0.0	 5.75	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	873	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	874	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	875	 1	 47.55	 5.3	 0.0	 7.59	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	876	 1	 49.91	 23.81	 0.0	 0.17	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	877	 1	 33.34	 15.7	 0.0	 64.15	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	878	 1	 0.0	 -0.0	 0.0	 0.82	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	879	 1	 -0.0	 -0.0	 0.0	 37.635138	 0	    1.00000	    0.00000	 220.0	 24	    1.10000	    0.90000;
	880	 1	 -0.0	 0.0	 0.0	 8.72	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	881	 1	 140.6	 42.6	 0.0	 5.71	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	882	 1	 110.8	 -8.8	 0.0	 3.15	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	883	 1	 -0.0	 0.0	 0.370251	 146.807945	 0	    1.00000	    0.00000	 380.0	 18	    1.20000	    0.80000;
	884	 1	 48.9	 28.6	 0.0	 98.806507	 0	    1.00000	    0.00000	 380.0	 9	    1.20000	    0.80000;
	885	 1	 33.24	 4.4	 0.0	 24.54	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	886	 1	 23.4	 3.3	 0.0	 1.91	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	887	 1	 0.0	 0.0	 0.0	 19.56	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	888	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 9	    1.10000	    0.90000;
	889	 1	 150.9	 10.4	 0.0	 4.77	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	890	 1	 0.0	 0.0	 0.0	 5.67	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	891	 1	 0.0	 -0.0	 0.0	 0.91	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	892	 1	 -0.0	 0.0	 0.094944	 0.903407	 0	    1.00000	    0.00000	 380.0	 7	    1.10000	    0.90000;
	893	 1	 -0.0	 0.0	 0.0	 0.52	 0	    1.00000	    0.00000	 110.0	 3	    1.10000	    0.90000;
	894	 1	 163.5	 44.9	 0.0	 1.17	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	895	 1	 18.5	 3.7	 0.0	 0.01	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	896	 1	 0.0	 0.0	 0.019388	 0.670612	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	897	 1	 -0.0	 -0.0	 0.233419	 2.686581	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	898	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	899	 1	 -0.92	 -4.99	 0.0	 1.86	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	900	 1	 0.9	 74.1	 0.47996	 33.190034	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	901	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 24	    1.10000	    0.90000;
	902	 1	 72.88	 14.4	 0.0	 2.96	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	903	 1	 15.42	 5.8	 0.0	 0.57	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	904	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	905	 1	 21.42	 8.1	 0.0	 7.38	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	906	 1	 0.0	 -0.0	 0.0	 11.57	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	907	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	908	 1	 36.1	 5.2	 0.0	 11.12	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	909	 1	 111.4	 36.5	 0.0	 70.21	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	910	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 9	    1.20000	    0.80000;
	911	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	912	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 22	    1.10000	    0.90000;
	913	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	914	 1	 116.8	 60.3	 0.0	 9.09	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	915	 1	 0.0	 0.0	 0.122539	 8.948096	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	916	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 15.0	 1	    1.10000	    0.90000;
	917	 1	 177.2	 32.3	 0.0	 6.57	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	918	 1	 23.8	 3.4	 0.0	 6.09	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	919	 1	 -0.0	 -0.0	 0.0	 17.07	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	920	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 22	    1.10000	    0.90000;
	921	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	922	 1	 40.04	 16.0	 0.0	 0.52	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	923	 1	 -0.0	 0.0	 0.0	 0.23	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	924	 1	 -0.0	 0.0	 0.0	 36.493989	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	925	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	926	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	927	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	928	 1	 0.2	 0.9	 0.0	 0.04	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	929	 1	 7.91	 2.5	 0.058378	 1.241622	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	930	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 22	    1.10000	    0.90000;
	931	 1	 0.0	 -0.0	 0.0	 1.18	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	932	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	933	 1	 181.41	 16.52	 0.0	 4.07	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	934	 1	 179.9	 -18.1	 0.142401	 12.4776	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	935	 1	 102.0	 26.6	 0.0	 2.31	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	936	 1	 45.32	 18.5	 0.0	 0.74	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	937	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	938	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	939	 1	 15.52	 6.3	 0.0	 0.6	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	940	 1	 192.3	 27.4	 0.0	 30.64	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	941	 1	 103.0	 40.2	 0.0	 1.13	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	942	 1	 26.33	 9.5	 0.0	 1.85	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	943	 1	 -0.59	 -0.83	 0.0	 5.79	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	944	 1	 48.05	 15.8	 0.0	 6.08	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	945	 1	 0.0	 -0.0	 0.038966	 3.071034	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	946	 1	 40.94	 19.2	 0.0	 5.2	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	947	 1	 17.22	 4.4	 0.0	 1.71	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	948	 1	 62.46	 7.15	 0.0	 10.06	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	949	 1	 -0.0	 0.0	 0.0	 5.12	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	950	 1	 205.6	 74.0	 0.0	 5.56	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	951	 1	 9.7	 1.4	 0.0	 6.56	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	952	 1	 -0.15	 -1.93	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 8	    1.10000	    0.90000;
	953	 1	 3.42	 2.68	 0.0	 1.46	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	954	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	955	 1	 0.0	 0.0	 0.0	 11.68	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	956	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	957	 1	 -0.0	 -0.0	 0.0	 4.74	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	958	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	959	 1	 65.27	 30.9	 0.0	 3.1	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	960	 1	 0.0	 0.0	 0.058795	 0.011205	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	961	 1	 258.4	 66.7	 0.0	 5.87	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	962	 1	 -0.0	 0.0	 0.187983	 73.848631	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	963	 1	 9.91	 3.3	 0.0	 0.66	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	964	 1	 40.24	 16.0	 0.0	 17.25	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	965	 1	 -0.0	 0.0	 0.0	 0.6	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	966	 1	 14.82	 0.0	 0.0	 4.07	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	967	 1	 -0.0	 0.0	 0.12	 12.89	 0	    1.00000	    0.00000	 220.0	 21	    1.10000	    0.90000;
	968	 1	 38.04	 11.7	 0.0	 0.18	 0	    1.00000	    0.00000	 110.0	 3	    1.10000	    0.90000;
	969	 1	 0.0	 -0.0	 0.0	 7.2	 0	    1.00000	    0.00000	 220.0	 19	    1.10000	    0.90000;
	970	 1	 -5.61	 -2.79	 0.0	 150.93	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	971	 1	 0.0	 0.0	 0.0	 2.76	 0	    1.00000	    0.00000	 220.0	 11	    1.10000	    0.90000;
	972	 1	 48.8	 6.9	 0.0	 5.14	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	973	 1	 -0.0	 -0.0	 0.0	 29.29	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	974	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	975	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	976	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	977	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	978	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	979	 1	 0.0	 -0.0	 0.0	 12.75	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	980	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	981	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	982	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	983	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	984	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	985	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	986	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	987	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	988	 1	 109.3	 35.4	 0.0	 1.91	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	989	 1	 30.83	 10.8	 0.0	 2.59	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	990	 1	 232.1	 89.8	 0.0	 0.09	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	991	 1	 -0.0	 -0.0	 0.0	 3.94	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	992	 1	 79.59	 50.5	 0.0	 14.31	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	993	 1	 0.0	 -0.0	 0.0	 14.54	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	994	 1	 -0.0	 0.0	 0.038933	 0.331067	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	995	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	996	 1	 169.8	 55.5	 0.0	 3.3	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	997	 1	 60.07	 28.0	 0.0	 4.13	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	998	 1	 -0.0	 0.0	 0.0	 47.77	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	999	 1	 42.35	 13.1	 0.05007	 3.85993	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1000	 1	 0.0	 -0.0	 0.0	 5.6	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1001	 1	 -3.4	 -1.3	 0.0	 2.27	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	1002	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	1003	 1	 22.42	 8.2	 0.0	 0.53	 0	    1.00000	    0.00000	 110.0	 3	    1.10000	    0.90000;
	1004	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	1005	 1	 6.11	 2.2	 0.0	 0.88	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	1006	 1	 83.6	 11.9	 0.0	 3.53	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1007	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	1008	 1	 -0.0	 0.0	 0.226936	 -0.189114	 0	    1.00000	    0.00000	 120.0	 6	    1.10000	    0.90000;
	1009	 1	 0.0	 -0.0	 0.0	 93.75	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	1010	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 15.75	 1	    1.10000	    0.90000;
	1011	 1	 0.0	 -0.0	 0.12	 6.65	 0	    1.00000	    0.00000	 220.0	 21	    1.10000	    0.90000;
	1012	 1	 96.41	 26.5	 0.0	 0.08	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1013	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	1014	 1	 12.4	 6.89	 0.0	 0.63	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1015	 1	 -0.0	 0.0	 0.466209	 1.440918	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	1016	 1	 0.0	 0.0	 0.180903	 10.599297	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	1017	 1	 0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	1018	 1	 36.54	 8.4	 0.0	 6.58	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1019	 1	 62.7	 9.0	 0.0	 3.22	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1020	 1	 12.71	 0.8	 0.0	 0.51	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1021	 1	 20.32	 6.7	 0.0	 0.32	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	1022	 1	 0.0	 0.0	 0.0	 0.48	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	1023	 1	 0.0	 -0.0	 0.0	 7.84	 0	    1.00000	    0.00000	 380.0	 9	    1.20000	    0.80000;
	1024	 1	 -0.0	 -0.0	 0.0	 3.14	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1025	 1	 156.9	 122.5	 0.0	 17.71	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	1026	 1	 114.8	 22.8	 0.0	 5.66	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1027	 1	 83.99	 21.2	 0.0	 5.36	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1028	 1	 0.0	 0.0	 0.0	 9.21	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	1029	 1	 0.0	 0.0	 0.038515	 61.381485	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	1030	 1	 76.38	 5.1	 0.0	 3.97	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1031	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	1032	 1	 423.4	 215.2	 0.474782	 27.554131	 0	    1.00000	    0.00000	 380.0	 14	    1.10000	    0.90000;
	1033	 1	 110.4	 41.9	 0.0	 1.88	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	1034	 1	 -0.0	 0.0	 0.058557	 -0.008557	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1035	 1	 0.0	 -0.0	 0.471052	 0.847084	 0	    1.00000	    0.00000	 380.0	 14	    1.10000	    0.90000;
	1036	 1	 0.0	 -0.0	 0.0	 113.86	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	1037	 1	 29.63	 10.8	 0.0	 2.39	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	1038	 1	 4.5	 -5.6	 0.0	 0.09	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1039	 1	 135.11	 41.0	 0.0	 5.31	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1040	 1	 -0.54	 -0.99	 0.0	 1.13	 0	    1.00000	    0.00000	 220.0	 18	    1.20000	    0.80000;
	1041	 1	 0.0	 0.0	 0.0	 23.550494	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1042	 1	 0.0	 0.0	 0.0	 1.49	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	1043	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	1044	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	1045	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	1046	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	1047	 1	 -0.0	 0.0	 0.0	 0.78	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	1048	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	1049	 1	 104.6	 14.9	 0.0	 7.35	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1050	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	1051	 1	 30.83	 6.6	 0.0	 3.19	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	1052	 1	 -0.0	 0.0	 0.0	 34.82	 0	    1.00000	    0.00000	 380.0	 9	    1.20000	    0.80000;
	1053	 1	 400.3	 189.9	 0.0	 0.53	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1054	 1	 34.94	 -32.3	 0.418254	 37.168883	 0	    1.00000	    0.00000	 380.0	 19	    1.20000	    0.80000;
	1055	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	1056	 1	 -0.0	 0.0	 0.0	 2.17	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1057	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	1058	 1	 20.62	 6.5	 0.0	 0.72	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	1059	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 10.6	 1	    1.10000	    0.90000;
	1060	 1	 -0.0	 0.0	 0.0	 61.48	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	1061	 1	 0.0	 0.0	 0.0	 11.12	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	1062	 1	 58.36	 10.7	 0.0	 8.41	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	1063	 1	 109.23	 66.36	 0.0	 5.44	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	1064	 1	 0.0	 -0.0	 0.0	 4.58	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1065	 1	 45.56	 -1.51	 0.0	 19.94	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1066	 1	 8.11	 2.0	 0.0	 1.95	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1067	 1	 11.01	 3.3	 0.178397	 1.531336	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	1068	 1	 1.3	 59.6	 0.29248	 128.206266	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	1069	 1	 22.22	 13.7	 0.0	 0.12	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1070	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	1071	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	1072	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 9	    1.10000	    0.90000;
	1073	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	1074	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	1075	 1	 0.0	 0.0	 0.0	 2.83	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1076	 1	 5.01	 2.0	 0.0	 2.99	 0	    1.00000	    0.00000	 220.0	 23	    1.10000	    0.90000;
	1077	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	1078	 1	 6.51	 4.1	 0.0	 1.27	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1079	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	1080	 1	 90.4	 15.2	 0.0	 0.07	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	1081	 1	 2.5	 1.3	 0.0	 0.07	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1082	 1	 69.58	 16.0	 0.0	 3.03	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1083	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	1084	 1	 -0.0	 -0.0	 0.0	 5.2	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	1085	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 19.0	 1	    1.10000	    0.90000;
	1086	 1	 16.52	 7.8	 0.116495	 10.493505	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1087	 1	 0.0	 -0.0	 0.0	 18.63	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1088	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	1089	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	1090	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	1091	 1	 2.5	 1.3	 0.0	 1.55	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1092	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	1093	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	1094	 1	 -0.0	 0.0	 0.0	 4.15	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	1095	 1	 1.9	 0.6	 0.0	 0.38	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1096	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 9	    1.10000	    0.90000;
	1097	 1	 132.1	 32.4	 0.0	 58.29	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	1098	 1	 28.9	 4.2	 0.0	 2.09	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1099	 1	 36.74	 8.9	 0.0	 0.63	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1100	 1	 -0.0	 0.0	 0.060092	 103.572441	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1101	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1102	 1	 -0.0	 -0.0	 0.0	 9.58	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	1103	 1	 0.0	 0.0	 0.0	 1.5	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1104	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	1105	 1	 -0.0	 0.0	 0.0	 0.08	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1106	 1	 0.0	 -0.0	 0.038914	 0.380814	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	1107	 1	 223.4	 107.8	 0.23317	 7.325407	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	1108	 1	 0.0	 -0.0	 0.120942	 -0.040706	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	1109	 1	 -0.0	 0.0	 0.0	 7.85	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1110	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1111	 1	 -0.0	 -0.0	 0.0	 0.45	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1112	 1	 0.0	 0.0	 0.0	 36.92	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	1113	 1	 152.57	 40.0	 0.0	 6.12	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1114	 1	 -0.0	 -0.0	 0.0	 1.23	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	1115	 1	 46.15	 20.9	 0.0	 1.4	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	1116	 1	 343.9	 141.9	 0.0	 5.55	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1117	 1	 349.6	 96.3	 0.0	 105.72	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	1118	 1	 -14.87	 -4.17	 0.0	 0.58	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1119	 1	 -0.0	 -0.0	 0.0	 1.54	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1120	 1	 -55.14	 -27.14	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	1121	 1	 45.05	 19.2	 0.0	 0.21	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1122	 1	 142.2	 29.6	 0.020088	 4.449912	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1123	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	1124	 1	 -0.0	 -0.0	 0.0	 1.44	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1125	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 9	    1.10000	    0.90000;
	1126	 1	 -0.0	 0.0	 0.019802	 4.940198	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1127	 1	 -0.0	 0.0	 0.510485	 8.332978	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1128	 1	 0.0	 0.0	 0.019363	 0.980637	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	1129	 1	 0.0	 0.0	 0.040037	 -3.7e-05	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	1130	 1	 34.04	 11.0	 0.0	 0.49	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	1131	 1	 0.0	 0.0	 0.0	 7.28	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	1132	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1133	 1	 -26.0	 -14.72	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	1134	 1	 0.0	 0.0	 0.0	 4.03	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	1135	 1	 0.0	 -0.0	 0.0	 0.79	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1136	 1	 -0.0	 -0.0	 0.0	 2.47	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	1137	 1	 18.02	 6.4	 0.0	 0.79	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1138	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 15.75	 1	    1.10000	    0.90000;
	1139	 1	 -0.0	 0.0	 0.0	 6.63	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1140	 1	 0.0	 0.0	 0.0	 0.65	 0	    1.00000	    0.00000	 150.0	 7	    1.10000	    0.90000;
	1141	 1	 52.06	 -0.0	 0.683815	 82.738646	 0	    1.00000	    0.00000	 380.0	 13	    1.10000	    0.90000;
	1142	 1	 295.3	 41.9	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	1143	 1	 9.7	 1.4	 0.0	 4.22	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1144	 1	 0.0	 0.0	 0.0	 1.653516	 0	    1.00000	    0.00000	 220.0	 24	    1.10000	    0.90000;
	1145	 1	 -0.0	 0.0	 0.0	 1.86	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	1146	 1	 0.0	 -0.0	 0.039425	 2.320575	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	1147	 1	 2.0	 114.6	 0.0	 16.15	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1148	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	1149	 1	 235.2	 41.1	 0.0	 10.01	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	1150	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 15.75	 1	    1.10000	    0.90000;
	1151	 1	 9.71	 3.0	 0.0	 0.95	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	1152	 1	 200.4	 60.5	 0.080512	 8.569488	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1153	 1	 -0.0	 -0.0	 0.0	 7.26	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1154	 1	 312.2	 28.0	 0.0	 48.6	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1155	 1	 -0.0	 0.0	 0.0	 32.02	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	1156	 1	 222.5	 262.8	 1.155017	 156.145612	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	1157	 1	 24.53	 8.6	 0.0	 7.01	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1158	 1	 0.0	 0.0	 0.0	 58.081854	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1159	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1160	 1	 17.83	 -9.5	 0.0	 2.79	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	1161	 1	 0.0	 0.0	 0.0	 66.22	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	1162	 1	 68.08	 13.6	 0.039413	 27.260587	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1163	 1	 287.7	 16.3	 0.0	 12.86	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	1164	 1	 25.27	 5.71	 0.0	 0.67	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	1165	 1	 234.7	 -12.0	 0.0	 23.35	 0	    1.00000	    0.00000	 380.0	 17	    1.10000	    0.90000;
	1166	 1	 333.1	 17.5	 0.0	 18.86	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	1167	 1	 -0.0	 0.0	 0.0	 8.73	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	1168	 1	 0.0	 -0.0	 0.0	 0.22	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1169	 1	 12.6	 1.8	 0.0	 1.89	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1170	 1	 15.02	 6.0	 0.0	 6.06	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	1171	 1	 -0.0	 0.0	 0.0	 22.93	 0	    1.00000	    0.00000	 150.0	 9	    1.20000	    0.80000;
	1172	 1	 -16.84	 -7.96	 0.0	 53.85	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	1173	 1	 -0.0	 -0.0	 1.147464	 -0.494081	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1174	 1	 32.1	 4.5	 0.0	 8.93	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1175	 1	 38.64	 23.9	 0.0	 0.94	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1176	 1	 31.94	 7.7	 0.0	 1.11	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	1177	 1	 167.8	 77.0	 0.0	 12.66	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	1178	 1	 0.0	 0.0	 0.0	 0.01	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1179	 1	 113.6	 122.7	 0.0	 8.74	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	1180	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	1181	 1	 0.01	 0.01	 0.358775	 5.700953	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	1182	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	1183	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	1184	 1	 15.02	 10.0	 0.0	 0.55	 0	    1.00000	    0.00000	 110.0	 23	    1.10000	    0.90000;
	1185	 1	 -17.17	 -7.1	 0.0	 57.020535	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1186	 1	 0.0	 0.0	 0.0	 24.4	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	1187	 1	 0.0	 -0.0	 0.0	 56.7	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	1188	 1	 -0.0	 -0.0	 0.03986	 2.050105	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	1189	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	1190	 1	 0.0	 -0.0	 0.0	 8.17514	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1191	 1	 -0.0	 -0.0	 0.0	 2.7	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1192	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 7	    1.10000	    0.90000;
	1193	 1	 -0.0	 -0.0	 0.135375	 32.572175	 0	    1.00000	    0.00000	 380.0	 18	    1.20000	    0.80000;
	1194	 1	 0.0	 0.0	 0.349307	 35.121782	 0	    1.00000	    0.00000	 380.0	 7	    1.10000	    0.90000;
	1195	 1	 -0.0	 -0.0	 0.0	 2.5	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	1196	 1	 -0.0	 -0.0	 0.0	 0.64	 0	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1197	 1	 -0.0	 -0.0	 0.05873	 0.55127	 0	    1.00000	    0.00000	 380.0	 14	    1.10000	    0.90000;
	1198	 1	 -0.0	 0.0	 0.0	 1.11	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1199	 1	 159.2	 59.9	 0.0	 37.33	 0	    1.00000	    0.00000	 380.0	 16	    1.10000	    0.90000;
	1200	 1	 13.9	 1.9	 0.0	 7.37	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1201	 1	 62.77	 0.7	 0.078743	 2.090943	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1202	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	1203	 1	 0.0	 -0.0	 0.019624	 56.1	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	1204	 1	 18.5	 2.7	 0.0	 0.11	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1205	 1	 -0.0	 -0.0	 0.0	 0.47	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1206	 1	 34.44	 4.4	 0.10038	 1.41962	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1207	 1	 0.0	 0.0	 0.0	 5.46	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1208	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	1209	 1	 190.0	 43.3	 0.0	 12.94	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	1210	 1	 49.95	 7.5	 0.0	 8.86	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1211	 1	 10.01	 3.3	 0.0	 0.24	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	1212	 1	 45.05	 50.5	 0.039751	 5.610187	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1213	 1	 -28.93	 9.5	 0.0	 0.38	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1214	 1	 21.72	 4.8	 0.0	 1.26	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1215	 1	 0.0	 -0.0	 0.574719	 1.882173	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1216	 1	 0.0	 0.0	 0.0	 0.28	 0	    1.00000	    0.00000	 150.0	 9	    1.20000	    0.80000;
	1217	 1	 242.08	 59.98	 0.0	 5.6	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1218	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	1219	 1	 0.0	 -0.0	 0.058902	 0.151098	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	1220	 1	 40.44	 13.3	 0.0	 0.94	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	1221	 1	 111.4	 15.9	 0.0	 2.36	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1222	 1	 1.3	 0.6	 0.0	 1.23	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1223	 1	 43.45	 26.9	 0.0	 3.56	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1224	 1	 0.0	 -0.0	 0.0	 20.07	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	1225	 1	 25.13	 14.0	 0.0	 0.04	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	1226	 1	 13.82	 5.0	 0.0	 0.11	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	1227	 1	 94.2	 5.5	 0.0	 6.51	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1228	 1	 108.89	 -21.76	 0.0	 3.72	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1229	 1	 -0.0	 0.0	 0.0	 42.212329	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1230	 1	 -0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	1231	 1	 -0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	1232	 1	 -0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	1233	 1	 0.0	 -0.0	 0.295925	 2.563236	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	1234	 1	 42.25	 13.9	 0.0	 0.95	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	1235	 1	 75.68	 18.4	 0.050059	 6.269941	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1236	 1	 0.0	 0.0	 0.0	 25.28	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	1237	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	1238	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	1239	 1	 0.0	 -0.0	 0.0	 2.0	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	1240	 1	 -0.0	 0.0	 0.0	 1.47	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1241	 1	 394.9	 77.0	 0.0	 44.93	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	1242	 1	 192.5	 78.3	 0.0	 6.65	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1243	 1	 13.82	 5.0	 0.0	 0.63	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	1244	 1	 23.03	 14.3	 0.0	 6.61	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1245	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	1246	 1	 -2.85	 -7.24	 0.0	 0.07	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	1247	 1	 51.86	 19.2	 0.0	 1.07	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	1248	 1	 17.42	 11.9	 0.293436	 14.435105	 0	    1.00000	    0.00000	 220.0	 19	    1.10000	    0.90000;
	1249	 1	 3.9	 1.4	 0.0	 0.78	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	1250	 1	 8.91	 3.8	 0.0	 0.38	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1251	 1	 -0.0	 0.0	 1.414448	 10.672156	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1252	 1	 452.5	 113.2	 0.059992	 16.270008	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1253	 1	 -0.0	 -0.0	 0.0	 1.77	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	1254	 1	 0.0	 0.0	 0.0	 1.32	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	1255	 1	 -0.0	 -0.0	 0.234854	 36.333138	 0	    1.00000	    0.00000	 380.0	 21	    1.10000	    0.90000;
	1256	 1	 0.0	 -0.0	 0.0	 1.81	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1257	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	1258	 1	 153.5	 21.9	 0.0	 7.79	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1259	 1	 25.63	 7.9	 0.0	 0.77	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	1260	 1	 0.0	 -0.0	 0.0	 59.04	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	1261	 1	 -0.0	 0.0	 0.0	 0.15	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1262	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	1263	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	1264	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 15.75	 1	    1.10000	    0.90000;
	1265	 1	 0.0	 0.0	 0.0	 0.05	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1266	 1	 82.69	 20.1	 0.0	 1.36	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1267	 1	 146.9	 60.6	 0.0	 26.49	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	1268	 1	 -0.0	 0.0	 0.13389	 0.01611	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1269	 1	 0.0	 0.0	 0.0	 18.004129	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1270	 1	 0.0	 0.0	 0.0	 0.23	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1271	 1	 0.0	 0.0	 0.0	 0.05	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1272	 1	 26.53	 7.1	 0.0	 11.02	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	1273	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	1274	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	1275	 1	 125.9	 -0.5	 0.0	 0.21	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1276	 1	 12.61	 4.5	 0.0	 2.63	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	1277	 1	 6.3	 0.9	 0.0	 3.82	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1278	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 9	    1.10000	    0.90000;
	1279	 1	 13.21	 2.2	 0.0	 10.05	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	1280	 1	 48.8	 6.9	 0.0	 6.16	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1281	 1	 22.02	 13.2	 0.0	 0.03	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1282	 1	 0.0	 0.0	 0.997827	 10.627573	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	1283	 1	 0.0	 0.0	 0.0	 89.51	 0	    1.00000	    0.00000	 380.0	 9	    1.10000	    0.90000;
	1284	 1	 24.53	 7.9	 0.0	 0.63	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	1285	 1	 0.8	 18.6	 0.197474	 3.171894	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1286	 1	 -0.0	 -0.0	 0.019316	 0.720684	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	1287	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	1288	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	1289	 1	 -0.0	 0.0	 0.0	 13.89	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	1290	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	1291	 1	 34.44	 8.5	 0.0	 1.11	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1292	 1	 -0.0	 -0.0	 0.126343	 6.455031	 0	    1.00000	    0.00000	 220.0	 19	    1.10000	    0.90000;
	1293	 1	 15.22	 7.6	 0.0	 1.56	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1294	 1	 48.95	 14.9	 0.0	 4.04	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1295	 1	 10.01	 5.0	 0.0	 0.11	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	1296	 1	 8.01	 4.1	 0.0	 2.25	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1297	 1	 -0.0	 -0.0	 0.0	 110.25	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	1298	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	1299	 1	 0.0	 0.0	 0.038839	 -0.029129	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	1300	 1	 112.9	 19.3	 0.0	 17.34	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	1301	 1	 43.75	 12.4	 0.0	 9.35	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1302	 1	 30.03	 15.0	 0.0	 0.81	 0	    1.00000	    0.00000	 110.0	 23	    1.10000	    0.90000;
	1303	 1	 1.1	 61.2	 0.524876	 46.291763	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	1304	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	1305	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	1306	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	1307	 1	 64.0	 9.1	 0.0	 12.23	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1308	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 9	    1.20000	    0.80000;
	1309	 1	 474.3	 203.4	 0.0	 47.469681	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	1310	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	1311	 1	 77.59	 12.3	 0.0	 5.1	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1312	 1	 40.34	 25.0	 0.0	 1.14	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1313	 1	 0.0	 0.0	 0.0	 17.82055	 0	    1.00000	    0.00000	 220.0	 20	    1.10000	    0.90000;
	1314	 1	 0.0	 -0.0	 0.0	 22.75	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1315	 1	 -0.0	 0.0	 0.0	 6.66	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1316	 1	 2.5	 1.3	 0.0	 2.33	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1317	 1	 0.0	 -0.0	 0.0	 9.46	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1318	 1	 -0.0	 0.0	 0.0	 1.93	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1319	 1	 -12.51	 4.1	 0.0	 0.09	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1320	 1	 0.0	 -0.0	 0.0	 31.47	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	1321	 1	 150.1	 35.0	 0.0	 3.55	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	1322	 1	 50.06	 16.3	 0.0	 0.26	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	1323	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 9	    1.20000	    0.80000;
	1324	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 9	    1.10000	    0.90000;
	1325	 1	 26.03	 9.8	 0.0	 0.82	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1326	 1	 -0.0	 -0.0	 0.0	 34.26	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	1327	 1	 -0.0	 0.0	 0.0	 3.37	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	1328	 1	 30.33	 11.0	 0.0	 1.43	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	1329	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 6.3	 1	    1.10000	    0.90000;
	1330	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	1331	 1	 0.2	 0.1	 0.0	 0.5	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	1332	 1	 189.1	 -11.9	 0.0	 27.462397	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	1333	 1	 7.41	 1.8	 0.0	 0.3	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	1334	 1	 90.7	 5.8	 0.0	 4.1	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1335	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	1336	 1	 4.81	 2.2	 0.0	 0.62	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1337	 1	 69.08	 22.6	 0.0	 0.54	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	1338	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	1339	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	1340	 1	 0.5	 -271.9	 0.0	 3.12	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	1341	 1	 -0.0	 0.0	 0.0	 0.38	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1342	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	1343	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	1344	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 24	    1.10000	    0.90000;
	1345	 1	 108.7	 -12.15	 0.0	 37.11	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1346	 1	 66.27	 13.6	 0.0	 0.67	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1347	 1	 -13.91	 4.6	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1348	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	1349	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	1350	 1	 244.2	 152.7	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	1351	 1	 19.42	 11.6	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 24	    1.10000	    0.90000;
	1352	 1	 65.77	 16.1	 0.0	 1.66	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1353	 1	 -0.0	 0.0	 0.0	 51.29	 0	    1.00000	    0.00000	 380.0	 11	    1.10000	    0.90000;
	1354	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	1355	 1	 166.6	 8.1	 0.0	 10.11	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	1356	 1	 0.01	 -0.01	 0.0	 108.728602	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1357	 1	 32.94	 20.4	 0.0	 8.95	 0	    1.00000	    0.00000	 150.0	 9	    1.20000	    0.80000;
	1358	 1	 42.55	 17.1	 0.0	 1.67	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1359	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	1360	 1	 0.0	 -0.0	 0.0	 12.74	 0	    1.00000	    0.00000	 220.0	 12	    1.10000	    0.90000;
	1361	 1	 88.5	 16.5	 0.0	 146.44	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1362	 1	 45.05	 9.9	 0.0	 0.24	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	1363	 1	 190.91	 55.46	 0.0	 14.77	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	1364	 1	 1.3	 0.4	 0.0	 0.64	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1365	 1	 0.0	 -0.0	 0.0	 49.26	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	1366	 1	 0.4	 1.1	 0.0	 1.99	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	1367	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	1368	 1	 62.27	 -2.1	 0.0	 8.01	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1369	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	1370	 1	 100.9	 2.9	 0.029966	 6.760034	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1371	 1	 -0.0	 -0.0	 0.099501	 68.573595	 0	    1.00000	    0.00000	 380.0	 18	    1.20000	    0.80000;
	1372	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	1373	 1	 0.0	 -0.0	 1.049905	 7.793635	 0	    1.00000	    0.00000	 380.0	 5	    1.20000	    0.80000;
	1374	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1375	 1	 6.71	 2.2	 0.058526	 1.221474	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	1376	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	1377	 1	 0.0	 -0.0	 0.05054	 43.31946	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	1378	 1	 0.0	 -0.0	 0.211519	 1.118481	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	1379	 1	 95.58	 -14.0	 0.0	 4.48	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	1380	 1	 -0.0	 -0.0	 0.009683	 0.180317	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1381	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	1382	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	1383	 1	 -0.0	 -0.0	 0.181549	 5.810889	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	1384	 1	 21.12	 7.7	 0.0	 1.48	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	1385	 1	 14.72	 4.6	 0.0	 7.88	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1386	 1	 0.0	 -0.0	 0.0	 0.84	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1387	 1	 62.7	 9.0	 0.0	 2.94	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1388	 1	 13.8	 461.3	 1.731993	 405.420277	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	1389	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	1390	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	1391	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	1392	 1	 0.0	 0.0	 0.0	 0.31	 0	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	1393	 1	 -0.0	 0.0	 1.111071	 86.974909	 0	    1.00000	    0.00000	 380.0	 3	    1.20000	    0.80000;
	1394	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	1395	 1	 -0.0	 0.0	 0.933942	 3.100629	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	1396	 1	 17.52	 4.6	 0.0	 11.82	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	1397	 1	 15.98	 0.86	 0.0	 5.96	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1398	 1	 0.0	 -0.0	 0.0	 1.18	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	1399	 1	 -0.0	 0.0	 0.0	 8.62	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1400	 1	 32.34	 10.6	 0.0	 0.64	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	1401	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	1402	 1	 -0.0	 0.0	 0.0	 8.19	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1403	 1	 18.12	 5.6	 0.019734	 2.520266	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1404	 1	 38.34	 51.8	 0.039559	 5.52033	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	1405	 1	 171.0	 69.2	 0.020113	 28.479887	 0	    1.00000	    0.00000	 380.0	 13	    1.10000	    0.90000;
	1406	 1	 0.0	 0.0	 0.0	 25.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	1407	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	1408	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	1409	 1	 -0.0	 -0.0	 0.0	 7.66	 0	    1.00000	    0.00000	 220.0	 11	    1.10000	    0.90000;
	1410	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	1411	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	1412	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	1413	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	1414	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	1415	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	1416	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	1417	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	1418	 1	 0.0	 0.0	 0.0	 1.8	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1419	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	1420	 1	 0.0	 -0.0	 0.059141	 23.820859	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1421	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 6.3	 1	    1.10000	    0.90000;
	1422	 1	 -0.0	 0.0	 0.098001	 0.521999	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1423	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	1424	 1	 24.03	 8.0	 0.0	 0.33	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	1425	 1	 0.0	 -0.0	 0.060427	 0.599644	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	1426	 1	 -0.0	 0.0	 0.0	 0.81	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1427	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	1428	 1	 -0.0	 0.0	 0.0	 45.31	 0	    1.00000	    0.00000	 380.0	 9	    1.10000	    0.90000;
	1429	 1	 0.0	 -0.0	 0.0	 1.51	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1430	 1	 -5.01	 0.0	 0.0	 3.54	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	1431	 1	 0.0	 -0.0	 0.0	 11.4	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	1432	 1	 0.2	 0.4	 0.0	 0.73	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	1433	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	1434	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	1435	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	1436	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	1437	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	1438	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	1439	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	1440	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	1441	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	1442	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	1443	 1	 136.06	 40.4	 0.0	 12.08	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1444	 1	 0.0	 -0.0	 0.0	 1.07	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1445	 1	 44.55	 -0.0	 0.0	 4.78	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1446	 1	 -0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1447	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	1448	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	1449	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	1450	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	1451	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	1452	 1	 -0.0	 -0.0	 0.0	 2.35	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1453	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	1454	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	1455	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 9	    1.10000	    0.90000;
	1456	 1	 8.2	 3.3	 0.0	 8.38	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	1457	 1	 227.9	 36.1	 0.060304	 13.069696	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1458	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	1459	 1	 0.0	 0.0	 0.0	 0.32	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1460	 1	 -0.0	 -0.0	 0.0	 0.93	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1461	 1	 27.9	 4.0	 0.0	 0.29	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1462	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	1463	 1	 241.4	 -2.5	 0.224624	 31.280331	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	1464	 1	 201.4	 53.0	 0.0	 9.67	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1465	 1	 -5.91	 -2.33	 0.0	 30.388612	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1466	 1	 13.82	 5.0	 0.0	 0.45	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	1467	 1	 0.0	 -0.0	 0.113517	 5.325402	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	1468	 1	 178.9	 9.1	 0.0	 15.71	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1469	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 6.3	 1	    1.10000	    0.90000;
	1470	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	1471	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	1472	 1	 -34.54	 2.7	 0.078778	 9.951222	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1473	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	1474	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	1475	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	1476	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	1477	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	1478	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	1479	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	1480	 1	 0.0	 -0.0	 0.0	 22.91	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1481	 1	 0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	1482	 1	 0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	1483	 1	 0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	1484	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	1485	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	1486	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	1487	 1	 0.0	 -0.0	 0.0	 14.23	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	1488	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 6.3	 1	    1.10000	    0.90000;
	1489	 1	 382.5	 57.9	 0.0	 8.16	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1490	 1	 -0.0	 -0.0	 0.173429	 1.295476	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	1491	 1	 0.0	 -0.0	 0.0	 0.55	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	1492	 1	 3.7	 -0.0	 0.0	 0.64	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1493	 1	 34.64	 -0.0	 0.0	 0.91	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1494	 1	 31.94	 8.8	 0.0	 3.79	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1495	 1	 12.11	 4.4	 0.0	 0.95	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	1496	 1	 2.5	 0.6	 0.0	 0.61	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1497	 1	 34.2	 4.9	 0.0	 9.08	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1498	 1	 0.0	 0.0	 0.0	 11.44	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1499	 1	 0.0	 0.0	 0.540258	 -0.140201	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1500	 1	 40.5	 5.7	 0.0	 3.2	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1501	 1	 47.05	 19.3	 0.0	 0.04	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	1502	 1	 1.9	 0.8	 0.0	 0.65	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1503	 1	 27.8	 -2.03	 0.0	 0.5	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1504	 1	 0.0	 0.0	 0.0	 28.8	 0	    1.00000	    0.00000	 380.0	 1	    1.20000	    0.80000;
	1505	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	1506	 1	 28.19	 -23.24	 0.226891	 11.120378	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	1507	 1	 0.0	 0.0	 0.0	 3.79	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1508	 1	 67.47	 32.6	 0.0	 13.11	 0	    1.00000	    0.00000	 220.0	 8	    1.10000	    0.90000;
	1509	 1	 84.99	 19.6	 0.0	 4.32	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1510	 1	 83.6	 11.9	 0.0	 6.56	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1511	 1	 0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	1512	 1	 -0.0	 -0.0	 0.0	 29.27	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	1513	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1514	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	1515	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1516	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 7	    1.10000	    0.90000;
	1517	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	1518	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	1519	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	1520	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	1521	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	1522	 1	 -0.0	 -0.0	 0.0	 11.96	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	1523	 1	 0.0	 0.0	 0.0	 62.76	 0	    1.00000	    0.00000	 380.0	 9	    1.10000	    0.90000;
	1524	 1	 0.0	 -0.0	 0.0	 75.38	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	1525	 1	 0.01	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1526	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 10.5	 1	    1.10000	    0.90000;
	1527	 1	 84.89	 32.4	 0.0	 7.77	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	1528	 1	 50.06	 17.0	 0.0	 1.61	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	1529	 1	 215.2	 -7.6	 0.0	 1.24	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1530	 1	 89.6	 20.0	 0.0	 9.07	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1531	 1	 0.0	 -0.0	 0.332671	 -0.258744	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	1532	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	1533	 1	 -0.0	 0.0	 0.0	 9.67	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	1534	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	1535	 1	 279.4	 22.9	 0.0	 15.24	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	1536	 1	 35.24	 11.6	 0.0	 1.72	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	1537	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 8	    1.10000	    0.90000;
	1538	 1	 -0.0	 -0.0	 0.0	 8.72	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1539	 1	 1.6	 -0.0	 0.0	 0.44	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1540	 1	 83.3	 47.9	 0.0	 6.19	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1541	 1	 0.0	 -0.0	 0.0	 68.81	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	1542	 1	 21.92	 7.2	 0.0	 3.14	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	1543	 1	 403.9	 -0.1	 0.0	 143.1	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	1544	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 8	    1.10000	    0.90000;
	1545	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 8	    1.10000	    0.90000;
	1546	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 8	    1.10000	    0.90000;
	1547	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1548	 1	 0.0	 0.0	 0.0	 0.1	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1549	 1	 -0.0	 0.0	 0.0	 4.74	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1550	 1	 0.2	 1.3	 0.355669	 10.384433	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	1551	 1	 48.8	 6.9	 0.0	 7.95	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1552	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	1553	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	1554	 1	 277.86	 58.95	 0.0	 182.880644	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1555	 1	 -0.0	 -0.0	 0.239685	 3.640263	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	1556	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	1557	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	1558	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	1559	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 20	    1.20000	    0.80000;
	1560	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	1561	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	1562	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 6.3	 1	    1.10000	    0.90000;
	1563	 1	 -0.0	 -0.0	 0.058263	 -0.008263	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1564	 1	 -30.03	 9.9	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1565	 1	 42.15	 14.2	 0.0	 1.71	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	1566	 1	 162.1	 43.2	 0.0	 3.32	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	1567	 1	 12.01	 5.6	 0.0	 39.29	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	1568	 1	 0.0	 -0.0	 0.0	 3.75	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	1569	 1	 39.1	 5.5	 0.0	 3.82	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1570	 1	 -7.61	 2.5	 0.0	 0.13	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1571	 1	 56.06	 18.7	 0.0	 4.24	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1572	 1	 -24.85	 -3.56	 0.0	 1.31	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1573	 1	 30.93	 -46.6	 0.0	 1.62	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	1574	 1	 -0.0	 -0.0	 0.710079	 -0.032146	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1575	 1	 28.53	 11.3	 0.0	 3.25	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	1576	 1	 0.0	 0.0	 0.0	 43.02	 0	    1.00000	    0.00000	 380.0	 1	    1.20000	    0.80000;
	1577	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	1578	 1	 -0.0	 0.0	 0.0	 0.16	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1579	 1	 0.0	 -0.0	 0.0	 4.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1580	 1	 46.25	 21.0	 0.116588	 2.262843	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	1581	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1582	 1	 0.0	 0.0	 0.039225	 0.280775	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1583	 1	 0.0	 0.0	 0.0	 2.05	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1584	 1	 0.0	 0.0	 0.0	 0.32	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1585	 1	 13.31	 8.1	 0.455742	 65.649204	 0	    1.00000	    0.00000	 380.0	 13	    1.10000	    0.90000;
	1586	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	1587	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	1588	 1	 0.0	 -0.0	 0.0	 1.83	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1589	 1	 192.4	 63.9	 0.0	 10.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	1590	 1	 1.8	 0.6	 0.0	 0.52	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	1591	 1	 -0.0	 -0.0	 0.0	 0.27	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1592	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	1593	 1	 -0.0	 -0.0	 0.0	 59.43	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	1594	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 10.5	 1	    1.10000	    0.90000;
	1595	 1	 -0.0	 0.0	 0.0	 0.4	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1596	 1	 -54.06	 13.1	 0.0	 14.23	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	1597	 1	 227.34	 236.13	 0.0	 66.84	 0	    1.00000	    0.00000	 380.0	 13	    1.10000	    0.90000;
	1598	 1	 0.0	 0.0	 0.0	 1.1	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1599	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 6.3	 1	    1.10000	    0.90000;
	1600	 1	 10.91	 3.6	 0.0	 0.4	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	1601	 1	 20.9	 3.0	 0.0	 5.46	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1602	 1	 59.27	 5.1	 0.0	 26.03	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	1603	 1	 7.01	 1.0	 0.0	 0.92	 0	    1.00000	    0.00000	 150.0	 7	    1.10000	    0.90000;
	1604	 1	 -40.55	 9.3	 0.0	 3.05	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1605	 1	 70.28	 58.9	 0.0	 7.33	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	1606	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 9	    1.20000	    0.80000;
	1607	 1	 -20.94	 -6.16	 0.0	 11.99	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1608	 1	 0.0	 -0.0	 0.0	 6.12	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	1609	 1	 0.0	 -0.0	 0.0	 12.28	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	1610	 1	 22.22	 13.8	 0.0	 3.11	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1611	 1	 244.8	 119.3	 0.0	 3.78	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	1612	 1	 11.41	 36.1	 0.236629	 9.002529	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1613	 1	 -0.0	 -0.0	 0.098235	 8.531765	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	1614	 1	 -9.0	 -10.19	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	1615	 1	 -0.0	 -0.0	 0.039398	 30.749631	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	1616	 1	 0.0	 0.0	 0.116733	 7.623267	 0	    1.00000	    0.00000	 220.0	 12	    1.10000	    0.90000;
	1617	 1	 64.21	 5.59	 0.0	 2.57	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1618	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	1619	 1	 0.0	 -0.0	 0.086633	 0.514111	 0	    1.00000	    0.00000	 220.0	 18	    1.20000	    0.80000;
	1620	 1	 -0.0	 -0.0	 0.475577	 28.946605	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	1621	 1	 190.47	 55.03	 0.0	 6.7	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1622	 1	 22.5	 3.2	 0.0	 5.11	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1623	 1	 0.0	 -0.0	 0.540344	 -0.140268	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	1624	 1	 7.8	 50.9	 0.0	 87.765989	 0	    1.00000	    0.00000	 380.0	 9	    1.20000	    0.80000;
	1625	 1	 115.2	 319.2	 0.0	 290.91	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	1626	 1	 118.2	 -33.0	 0.0	 12.02	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	1627	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 23	    1.10000	    0.90000;
	1628	 1	 103.9	 14.8	 0.0	 1.91	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1629	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	1630	 1	 1.4	 0.6	 0.0	 0.41	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1631	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	1632	 1	 16.22	 2.0	 0.0	 0.71	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1633	 1	 -0.0	 -0.0	 0.0	 0.05	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1634	 1	 0.0	 -0.0	 0.526084	 0.520916	 0	    1.00000	    0.00000	 380.0	 14	    1.20000	    0.80000;
	1635	 1	 18.92	 9.0	 0.116297	 -0.026297	 0	    1.00000	    0.00000	 220.0	 21	    1.10000	    0.90000;
	1636	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	1637	 1	 -0.0	 0.0	 0.0	 1.78	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	1638	 1	 0.0	 -0.0	 0.0	 23.36	 0	    1.00000	    0.00000	 380.0	 7	    1.10000	    0.90000;
	1639	 1	 45.9	 36.8	 0.0	 55.224909	 0	    1.00000	    0.00000	 380.0	 9	    1.10000	    0.90000;
	1640	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 15.0	 1	    1.10000	    0.90000;
	1641	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	1642	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	1643	 1	 0.0	 0.0	 0.210571	 8.306088	 0	    1.00000	    0.00000	 220.0	 19	    1.10000	    0.90000;
	1644	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	1645	 1	 39.04	 -5.0	 0.0	 1.31	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	1646	 1	 -62.07	 -37.0	 0.267849	 0.328679	 0	    1.00000	    0.00000	 220.0	 11	    1.10000	    0.90000;
	1647	 1	 32.84	 0.0	 0.0	 1.41	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1648	 1	 20.02	 15.0	 0.0	 1.56	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	1649	 1	 141.4	 123.0	 0.0	 8.52	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	1650	 1	 0.0	 0.0	 0.0	 0.32	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1651	 1	 0.0	 -0.0	 0.0	 24.6	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	1652	 1	 0.0	 -0.0	 0.0	 46.01	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	1653	 1	 12.41	 3.9	 0.0	 2.23	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1654	 1	 55.7	 7.9	 0.0	 2.62	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1655	 1	 -0.0	 -0.0	 0.0	 1.91	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	1656	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	1657	 1	 65.67	 24.0	 0.0	 9.95	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1658	 1	 -0.0	 0.0	 0.0	 14.19	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	1659	 1	 3.7	 0.6	 0.0	 0.01	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1660	 1	 24.13	 12.7	 0.0	 0.1	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1661	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	1662	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	1663	 1	 -0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	1664	 1	 0.1	 0.5	 0.0	 0.48	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	1665	 1	 170.2	 60.8	 0.0	 16.27	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	1666	 1	 0.0	 0.0	 0.0	 2.22	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	1667	 1	 -0.0	 0.0	 0.0	 47.06	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	1668	 1	 0.0	 0.0	 0.0	 16.04	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	1669	 1	 26.43	 16.4	 0.0	 0.02	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1670	 1	 -0.0	 -0.0	 0.0	 14.13	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	1671	 1	 -39.81	 -10.9	 0.0	 3.37	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1672	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1673	 1	 -0.0	 -0.0	 0.0	 89.06	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	1674	 1	 116.2	 16.5	 0.0	 7.8	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1675	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	1676	 1	 -9.51	 -3.32	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	1677	 1	 79.89	 29.0	 0.0	 1.42	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	1678	 1	 -0.0	 0.0	 0.0	 0.1	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	1679	 1	 0.0	 -0.0	 0.0	 2.3	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1680	 1	 129.1	 5.8	 0.0	 3.59	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1681	 1	 0.0	 0.0	 0.019971	 0.640029	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	1682	 1	 -128.74	 38.0	 0.155644	 13.673267	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1683	 1	 92.7	 -11.6	 0.116434	 0.152972	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1684	 1	 -2.35	 -2.06	 0.0	 3.38	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	1685	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	1686	 1	 86.6	 23.4	 0.0	 0.39	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1687	 1	 43.75	 16.8	 0.0	 0.42	 0	    1.00000	    0.00000	 110.0	 3	    1.10000	    0.90000;
	1688	 1	 0.1	 -19.3	 0.0	 0.25	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	1689	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	1690	 1	 25.1	 3.6	 0.0	 6.2	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1691	 1	 -0.0	 -0.0	 0.232698	 1.796085	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	1692	 1	 150.4	 15.3	 0.0	 8.09	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1693	 1	 62.7	 9.0	 0.0	 3.18	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1694	 1	 67.58	 21.2	 0.0	 5.71	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1695	 1	 30.93	 6.6	 0.0	 9.09	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1696	 1	 96.41	 18.1	 0.0	 2.04	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	1697	 1	 14.62	 5.6	 0.0	 0.25	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1698	 1	 37.3	 5.4	 0.0	 0.12	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1699	 1	 13.21	 9.2	 0.0	 0.69	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1700	 1	 181.5	 21.2	 0.0	 64.45	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	1701	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	1702	 1	 129.6	 13.3	 0.0	 13.98	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1703	 1	 5.5	 0.8	 0.0	 1.19	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1704	 1	 -0.0	 -0.0	 0.0	 1.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1705	 1	 -0.0	 -0.0	 0.181549	 8.450889	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	1706	 1	 25.23	 10.6	 0.0	 1.44	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1707	 1	 -0.0	 0.0	 0.0	 30.644542	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1708	 1	 -0.0	 -0.0	 0.052811	 29.652975	 0	    1.00000	    0.00000	 380.0	 19	    1.10000	    0.90000;
	1709	 1	 124.8	 7.9	 0.0	 48.99	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	1710	 1	 114.1	 23.5	 0.0	 1.08	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1711	 1	 0.0	 -0.0	 0.0	 46.28	 0	    1.00000	    0.00000	 380.0	 9	    1.20000	    0.80000;
	1712	 1	 41.8	 5.9	 0.0	 1.75	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1713	 1	 -0.0	 0.0	 0.0	 0.72	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1714	 1	 -0.19	 -1.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	1715	 1	 27.13	 16.8	 0.0	 0.3	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1716	 1	 70.18	 28.7	 0.0	 0.8	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	1717	 1	 13.9	 1.9	 0.0	 0.38	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1718	 1	 78.49	 48.6	 0.0	 1.05	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1719	 1	 -15.82	 5.2	 0.0	 1.76	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1720	 1	 -0.59	 -2.55	 0.04975	 111.131798	 0	    1.00000	    0.00000	 380.0	 18	    1.20000	    0.80000;
	1721	 1	 -0.0	 0.0	 0.0	 35.18	 0	    1.00000	    0.00000	 380.0	 1	    1.20000	    0.80000;
	1722	 1	 29.8	 4.3	 0.0	 2.04	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1723	 1	 105.0	 412.0	 0.0	 37.57	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	1724	 1	 -0.0	 0.0	 0.0	 0.34	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1725	 1	 0.0	 -0.0	 0.0	 4.93	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1726	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	1727	 1	 30.83	 13.2	 0.0	 1.12	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	1728	 1	 1.4	 0.5	 0.0	 1.87	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	1729	 1	 -0.0	 0.0	 0.169548	 2.78813	 0	    1.00000	    0.00000	 380.0	 14	    1.10000	    0.90000;
	1730	 1	 230.5	 91.0	 0.0	 57.67	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	1731	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	1732	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	1733	 1	 26.4	 3.8	 0.0	 0.7	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1734	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	1735	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	1736	 1	 0.0	 -0.0	 0.134584	 4.575416	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	1737	 1	 -0.0	 -0.0	 0.0	 0.21	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1738	 1	 -0.18	 -1.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	1739	 1	 53.16	 17.7	 0.0	 0.48	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	1740	 1	 7.41	 2.7	 0.0	 1.39	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	1741	 1	 0.0	 0.0	 0.0	 2.25	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1742	 1	 0.0	 -0.01	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1743	 1	 -0.0	 0.0	 0.0	 81.52	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	1744	 1	 259.3	 91.5	 0.06021	 6.83979	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1745	 1	 71.78	 17.9	 0.0	 1.96	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1746	 1	 4.3	 0.6	 0.0	 4.43	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1747	 1	 -0.0	 -0.0	 0.0	 14.29	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	1748	 1	 -0.0	 -0.0	 1.059066	 6.756337	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1749	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 9	    1.10000	    0.90000;
	1750	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 8	    1.10000	    0.90000;
	1751	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 8	    1.10000	    0.90000;
	1752	 1	 60.37	 35.4	 0.0	 14.88	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	1753	 1	 103.6	 16.01	 0.0	 11.22	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1754	 1	 -0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	1755	 1	 23.53	 4.0	 0.0	 9.39	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1756	 1	 -30.13	 -22.3	 0.040189	 13.549811	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1757	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	1758	 1	 226.3	 51.7	 0.0	 3.86	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	1759	 1	 -0.0	 -0.0	 0.056124	 49.56323	 0	    1.00000	    0.00000	 380.0	 3	    1.20000	    0.80000;
	1760	 1	 44.6	 6.4	 0.0	 0.17	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1761	 1	 -4.57	 -1.31	 0.0	 1.12	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1762	 1	 2.0	 1.0	 0.0	 0.61	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	1763	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	1764	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 22	    1.10000	    0.90000;
	1765	 1	 -0.0	 0.0	 0.0	 1.17	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1766	 1	 141.26	 30.6	 0.0	 18.01	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1767	 1	 39.44	 24.9	 0.0	 4.18	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	1768	 1	 -0.0	 0.0	 0.710067	 0.007863	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1769	 1	 -0.0	 -0.0	 0.0	 6.56	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	1770	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	1771	 1	 186.6	 155.8	 0.0	 28.99	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	1772	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	1773	 1	 -0.0	 0.0	 0.0	 0.4	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1774	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	1775	 1	 20.62	 8.2	 0.0	 6.62	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	1776	 1	 138.2	 40.3	 0.0	 1.15	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	1777	 1	 25.13	 -61.6	 0.0	 3.68	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1778	 1	 -0.0	 0.0	 0.0	 13.02	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	1779	 1	 0.0	 0.0	 0.039102	 6.540898	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	1780	 1	 -0.0	 -0.0	 0.0	 39.46	 0	    1.00000	    0.00000	 380.0	 9	    1.20000	    0.80000;
	1781	 1	 50.86	 36.6	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	1782	 1	 279.5	 25.8	 0.0	 20.3	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	1783	 1	 -0.0	 0.0	 0.0	 10.73	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1784	 1	 0.0	 -0.0	 0.256113	 11.74089	 0	    1.00000	    0.00000	 220.0	 19	    1.10000	    0.90000;
	1785	 1	 224.9	 -32.5	 0.0	 63.28	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	1786	 1	 173.0	 -21.3	 0.0	 5.93	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1787	 1	 15.42	 2.2	 0.0	 1.46	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	1788	 1	 -18.69	 -7.9	 0.0	 2.09	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	1789	 1	 151.2	 96.4	 0.302056	 38.856615	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	1790	 1	 112.8	 27.6	 0.0	 35.18	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	1791	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	1792	 1	 1.8	 0.7	 0.0	 0.17	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	1793	 1	 119.6	 26.9	 0.050934	 6.129066	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1794	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	1795	 1	 -0.0	 -0.0	 0.0	 0.23	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1796	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	1797	 1	 7.01	 2.3	 0.0	 0.69	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	1798	 1	 130.4	 44.33	 0.0	 5.22	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1799	 1	 149.9	 53.2	 0.0	 1.07	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1800	 1	 31.74	 6.3	 0.0	 0.5	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1801	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	1802	 1	 0.0	 0.0	 0.0	 0.48	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1803	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	1804	 1	 -0.2	 -1.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	1805	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	1806	 1	 0.0	 0.0	 0.0	 28.5	 0	    1.00000	    0.00000	 380.0	 7	    1.10000	    0.90000;
	1807	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	1808	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	1809	 1	 -0.0	 -0.0	 0.0	 1.56	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	1810	 1	 0.0	 -0.0	 0.0	 107.39	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	1811	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1812	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	1813	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 23	    1.10000	    0.90000;
	1814	 1	 202.0	 34.1	 0.0	 1.94	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1815	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	1816	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 23	    1.10000	    0.90000;
	1817	 1	 42.75	 15.2	 0.0	 0.54	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	1818	 1	 19.02	 9.1	 0.0	 0.52	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1819	 1	 0.0	 -0.2	 0.0	 0.15	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1820	 1	 71.58	 48.2	 0.288552	 130.762047	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	1821	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 14.4	 1	    1.10000	    0.90000;
	1822	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	1823	 1	 -0.19	 -78.58	 0.0	 2.31	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	1824	 1	 9.61	 5.9	 0.0	 1.11	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1825	 1	 0.0	 0.0	 0.0	 0.02	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1826	 1	 18.82	 6.2	 0.0	 0.65	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	1827	 1	 22.32	 7.3	 0.0	 0.72	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	1828	 1	 124.1	 17.6	 0.0	 6.03	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1829	 1	 180.9	 33.2	 0.0	 29.17	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1830	 1	 23.4	 3.3	 0.0	 6.88	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1831	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 23	    1.10000	    0.90000;
	1832	 1	 26.63	 9.7	 0.0	 0.37	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	1833	 1	 6.11	 -0.0	 0.0	 2.51	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1834	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	1835	 1	 181.1	 78.7	 0.040042	 0.959958	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1836	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	1837	 1	 0.0	 -0.0	 0.0	 0.3	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1838	 1	 19.02	 8.0	 0.0	 2.05	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1839	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 24	    1.10000	    0.90000;
	1840	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	1841	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1842	 1	 30.53	 10.0	 0.0	 0.64	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	1843	 1	 42.95	 26.6	 0.0	 2.95	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1844	 1	 479.0	 99.2	 0.0	 10.68	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1845	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 15.75	 1	    1.10000	    0.90000;
	1846	 1	 -19.83	 -6.01	 0.0	 0.38	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1847	 1	 -0.0	 -0.0	 0.0	 3.47	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	1848	 1	 75.28	 19.2	 0.0	 1.9	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	1849	 1	 191.7	 6.8	 0.0	 11.58	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	1850	 1	 0.0	 0.0	 0.0	 4.34	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1851	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	1852	 1	 8.51	 6.4	 0.0	 0.39	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1853	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	1854	 1	 479.3	 127.6	 0.039325	 50.220675	 0	    1.00000	    0.00000	 380.0	 14	    1.10000	    0.90000;
	1855	 1	 71.38	 10.3	 0.0	 4.56	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	1856	 1	 16.7	 2.4	 0.0	 0.87	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1857	 1	 17.72	 3.8	 0.0	 0.94	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1858	 1	 -0.0	 -0.0	 0.0	 0.2	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1859	 1	 37.94	 15.2	 0.0	 35.31	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1860	 1	 18.2	 2.6	 0.0	 1.51	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1861	 1	 18.72	 7.7	 0.019611	 1.710389	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	1862	 1	 -0.0	 0.0	 0.0	 2.79	 0	    1.00000	    0.00000	 220.0	 19	    1.10000	    0.90000;
	1863	 1	 13.82	 3.6	 0.0	 0.72	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1864	 1	 32.64	 11.8	 0.0	 2.07	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	1865	 1	 0.2	 0.8	 0.0	 0.05	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	1866	 1	 -0.0	 0.0	 0.0	 0.08	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1867	 1	 0.0	 -0.0	 0.238928	 0.940804	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	1868	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	1869	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	1870	 1	 11.41	 5.1	 0.0	 1.04	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1871	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1872	 1	 118.9	 129.2	 0.0	 10.49	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	1873	 1	 37.14	 11.6	 0.0	 1.8	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	1874	 1	 37.69	 -19.49	 0.0	 0.11	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	1875	 1	 0.0	 0.0	 0.0	 0.98	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1876	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	1877	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	1878	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	1879	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	1880	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	1881	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	1882	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	1883	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	1884	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	1885	 1	 0.0	 0.0	 0.0	 50.16	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	1886	 1	 105.8	 15.1	 0.0	 4.91	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1887	 1	 100.6	 15.3	 0.0	 1.28	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	1888	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1889	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	1890	 1	 0.0	 0.0	 0.0	 4.93	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1891	 1	 -9.61	 3.2	 0.0	 0.75	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1892	 1	 -0.0	 0.0	 1.160978	 -0.444847	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1893	 1	 -0.0	 -0.0	 0.0	 0.59	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1894	 1	 -0.0	 -0.0	 0.647865	 2.624819	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	1895	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 20	    1.10000	    0.90000;
	1896	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	1897	 1	 13.9	 1.9	 0.0	 1.02	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1898	 1	 0.0	 -0.0	 0.232141	 72.996222	 0	    1.00000	    0.00000	 380.0	 16	    1.10000	    0.90000;
	1899	 1	 29.03	 9.4	 0.0	 5.11	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	1900	 1	 108.4	 -2.4	 0.0	 80.12	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	1901	 1	 7.61	 0.0	 0.0	 6.6	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1902	 1	 -0.0	 -0.0	 0.058904	 3.471096	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1903	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	1904	 1	 5.41	 2.81	 0.0	 1.9	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1905	 1	 -0.0	 -0.0	 0.0	 58.3	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1906	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	1907	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	1908	 1	 -0.0	 -0.0	 0.0	 2.13	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1909	 1	 1.91	 3.95	 0.0	 0.02	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1910	 1	 -0.0	 -0.0	 0.0	 1.87	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	1911	 1	 0.0	 -0.0	 0.0	 12.2	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1912	 1	 34.9	 5.0	 0.0	 6.35	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1913	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	1914	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	1915	 1	 30.53	 13.8	 0.0	 2.19	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	1916	 1	 -0.0	 0.0	 0.0	 0.46	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1917	 1	 28.93	 11.9	 0.0	 3.84	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	1918	 1	 6.41	 2.3	 0.0	 0.85	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	1919	 1	 291.9	 91.9	 0.040252	 1.189748	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1920	 1	 -3.29	 -1.32	 0.0	 190.704588	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	1921	 1	 538.3	 90.8	 0.0	 21.34	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	1922	 1	 2.1	 0.3	 0.0	 2.83	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1923	 1	 100.3	 4.8	 0.0	 0.15	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	1924	 1	 60.17	 30.6	 0.0	 0.12	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	1925	 1	 -0.0	 0.0	 0.27075	 68.09435	 0	    1.00000	    0.00000	 380.0	 18	    1.20000	    0.80000;
	1926	 1	 211.8	 87.9	 0.119912	 0.300074	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1927	 1	 0.0	 -0.0	 0.0	 6.93	 0	    1.00000	    0.00000	 220.0	 8	    1.10000	    0.90000;
	1928	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	1929	 1	 0.0	 -0.0	 0.352132	 27.727388	 0	    1.00000	    0.00000	 380.0	 11	    1.10000	    0.90000;
	1930	 1	 40.85	 14.5	 0.0	 0.59	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1931	 1	 0.0	 0.0	 0.233608	 -0.194673	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	1932	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	1933	 1	 -0.0	 -0.0	 0.0	 0.88	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1934	 1	 -0.0	 0.0	 0.527187	 -0.130034	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	1935	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	1936	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	1937	 1	 -0.0	 0.0	 0.156456	 -1.292742	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	1938	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1939	 1	 0.0	 -0.0	 0.245037	 32.163304	 0	    1.00000	    0.00000	 380.0	 7	    1.10000	    0.90000;
	1940	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 8	    1.10000	    0.90000;
	1941	 1	 46.55	 28.8	 0.0	 1.08	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1942	 1	 100.9	 14.4	 0.0	 0.06	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1943	 1	 -0.0	 0.0	 0.0	 0.29	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1944	 1	 0.0	 0.0	 0.077274	 2.812726	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1945	 1	 10.11	 8.9	 0.0	 0.12	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	1946	 1	 36.44	 12.0	 0.0	 1.39	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	1947	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1948	 1	 18.02	 6.0	 0.0	 0.41	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	1949	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1950	 1	 60.37	 54.7	 0.0	 0.62	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	1951	 1	 2.91	 -1.45	 0.0	 5.1	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1952	 1	 89.5	 12.8	 0.0	 5.08	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1953	 1	 -0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	1954	 1	 -0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	1955	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	1956	 1	 93.9	 13.4	 0.0	 5.87	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1957	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	1958	 1	 10.81	 3.5	 0.0	 0.98	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	1959	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	1960	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	1961	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	1962	 1	 39.04	 12.0	 0.019755	 3.180245	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1963	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	1964	 1	 0.0	 0.0	 0.0	 14.34	 0	    1.00000	    0.00000	 380.0	 3	    1.20000	    0.80000;
	1965	 1	 14.75	 -0.07	 0.0	 3.07	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1966	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	1967	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	1968	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1969	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 22	    1.10000	    0.90000;
	1970	 1	 20.32	 6.7	 0.0	 1.11	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	1971	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1972	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	1973	 1	 -0.0	 -0.0	 0.019477	 11.600523	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1974	 1	 -0.0	 -0.0	 0.0	 4.2	 0	    1.00000	    0.00000	 220.0	 8	    1.10000	    0.90000;
	1975	 1	 2.4	 0.7	 0.0	 10.69	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1976	 1	 30.93	 7.6	 0.0	 4.69	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1977	 1	 0.0	 -0.0	 0.0	 3.36	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	1978	 1	 52.96	 15.2	 0.0	 0.56	 0	    1.00000	    0.00000	 110.0	 3	    1.10000	    0.90000;
	1979	 1	 0.0	 -6.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1980	 1	 0.0	 0.0	 0.0	 2.14	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1981	 1	 196.7	 44.2	 0.0	 0.1	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1982	 1	 185.5	 62.3	 0.02989	 30.86011	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	1983	 1	 39.25	 71.7	 0.0	 33.75	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	1984	 1	 11.91	 2.9	 0.0	 5.27	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	1985	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	1986	 1	 0.0	 -0.0	 0.176224	 0.082937	 0	    1.00000	    0.00000	 220.0	 20	    1.10000	    0.90000;
	1987	 1	 -22.07	 -1.97	 0.0	 13.85	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	1988	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	1989	 1	 69.3	 9.9	 0.0	 0.03	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	1990	 1	 -1401.62	 -585.3	 0.0	 0.0	 0	    1.00000	    0.00000	 27.0	 3	    1.10000	    0.90000;
	1991	 1	 -0.0	 0.0	 0.0	 12.98	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	1992	 1	 157.9	 26.0	 0.0	 3.74	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	1993	 1	 0.0	 -0.0	 0.0	 4.15	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	1994	 1	 15.52	 5.2	 0.0	 0.29	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	1995	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	1996	 1	 138.2	 153.5	 0.473187	 29.995678	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	1997	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	1998	 1	 62.97	 57.7	 0.459488	 11.506239	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	1999	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	2000	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	2001	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	2002	 1	 5.11	 0.9	 0.0	 0.37	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2003	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	2004	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	2005	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	2006	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	2007	 1	 144.7	 20.3	 0.0	 6.35	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2008	 1	 -0.0	 0.0	 0.0	 0.3	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2009	 1	 7.81	 2.6	 0.0	 0.3	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	2010	 1	 4.81	 1.5	 0.039642	 1.450358	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2011	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	2012	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	2013	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	2014	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	2015	 1	 42.95	 19.8	 0.0	 3.85	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2016	 1	 132.2	 32.8	 0.020137	 12.049863	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2017	 1	 0.0	 -0.0	 0.0	 8.53	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	2018	 1	 -4.89	 -2.35	 0.0	 0.13	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2019	 1	 106.1	 -6.8	 0.0	 22.23	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	2020	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	2021	 1	 -0.0	 -0.0	 0.284748	 10.36271	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	2022	 1	 0.0	 0.0	 0.0	 1.85	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	2023	 1	 22.83	 7.5	 0.0	 0.36	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	2024	 1	 -0.0	 -0.0	 0.0	 121.27	 0	    1.00000	    0.00000	 380.0	 22	    1.10000	    0.90000;
	2025	 1	 20.82	 7.9	 0.0	 5.62	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2026	 1	 -8.31	 2.7	 0.0	 0.18	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2027	 1	 193.2	 121.7	 0.0	 11.94	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	2028	 1	 39.54	 14.3	 0.0	 0.23	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	2029	 1	 45.95	 7.5	 0.0	 8.39	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2030	 1	 178.0	 33.8	 0.0	 2.73	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	2031	 1	 0.0	 -0.0	 0.0	 4.88	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2032	 1	 -0.0	 -0.0	 0.0	 3.85	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2033	 1	 -0.0	 0.0	 0.039816	 0.010184	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2034	 1	 204.6	 53.2	 0.0	 7.4	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2035	 1	 0.0	 -0.0	 0.31	 25.37	 0	    1.00000	    0.00000	 220.0	 19	    1.10000	    0.90000;
	2036	 1	 110.1	 2.0	 0.0	 13.85	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2037	 1	 -0.0	 -0.0	 0.0	 2.25	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2038	 1	 53.86	 -15.3	 0.0	 2.87	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2039	 1	 89.3	 12.8	 0.0	 4.33	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2040	 1	 171.96	 40.73	 0.0	 23.47	 0	    1.00000	    0.00000	 380.0	 13	    1.10000	    0.90000;
	2041	 1	 -0.0	 -0.0	 0.0	 4.56	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2042	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2043	 1	 -0.0	 -0.0	 0.287012	 9.86039	 0	    1.00000	    0.00000	 220.0	 11	    1.10000	    0.90000;
	2044	 1	 238.4	 210.9	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 2	    1.10000	    0.90000;
	2045	 1	 0.0	 0.0	 0.0	 -0.73	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2046	 1	 10.91	 3.0	 0.0	 0.88	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2047	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 8	    1.10000	    0.90000;
	2048	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	2049	 1	 -0.0	 -0.0	 0.0	 27.56	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	2050	 1	 -0.0	 -0.0	 0.0	 9.49	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2051	 1	 0.0	 -0.0	 0.0	 6.65	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2052	 1	 302.1	 216.0	 0.944202	 84.972507	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	2053	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	2054	 1	 20.52	 6.7	 0.0	 0.13	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	2055	 1	 0.0	 0.0	 0.0	 2.3	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	2056	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 7	    1.10000	    0.90000;
	2057	 1	 80.09	 26.3	 0.0	 0.37	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	2058	 1	 57.16	 19.7	 0.0	 22.17	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2059	 1	 199.2	 22.8	 0.0	 27.54	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2060	 1	 18.02	 4.8	 0.0	 0.43	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2061	 1	 -0.0	 -0.0	 0.0	 0.37	 0	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2062	 1	 20.82	 36.0	 0.0	 0.97	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2063	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	2064	 1	 4.0	 172.7	 1.18784	 144.149627	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	2065	 1	 -0.0	 -0.0	 0.0	 3.38	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2066	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	2067	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 8	    1.20000	    0.80000;
	2068	 1	 0.0	 0.0	 0.0	 1.44	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2069	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	2070	 1	 35.24	 11.4	 0.0	 1.84	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	2071	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 14.4	 1	    1.10000	    0.90000;
	2072	 1	 109.6	 36.4	 0.0	 13.24	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	2073	 1	 162.0	 83.6	 0.0	 5.32	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	2074	 1	 22.73	 6.4	 0.0	 2.1	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	2075	 1	 -11.03	 -5.11	 0.0	 29.703251	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	2076	 1	 42.95	 26.6	 0.0	 3.11	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2077	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	2078	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	2079	 1	 50.06	 16.0	 0.0	 0.65	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	2080	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	2081	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2082	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	2083	 1	 -0.0	 -0.0	 0.0	 17.6	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	2084	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 7	    1.10000	    0.90000;
	2085	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	2086	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	2087	 1	 0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	2088	 1	 0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	2089	 1	 -0.0	 -0.0	 0.0	 6.4	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	2090	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	2091	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	2092	 1	 18.12	 -11.6	 0.0	 14.14	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	2093	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	2094	 1	 0.0	 0.0	 0.0	 0.98	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2095	 1	 -0.0	 -0.0	 0.15	 6.49	 0	    1.00000	    0.00000	 220.0	 21	    1.10000	    0.90000;
	2096	 1	 39.2	 5.5	 0.0	 7.25	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2097	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	2098	 1	 117.13	 33.86	 0.0	 6.04	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	2099	 1	 -0.0	 0.0	 0.0	 0.77	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	2100	 1	 30.63	 19.0	 0.0	 2.33	 0	    1.00000	    0.00000	 150.0	 9	    1.20000	    0.80000;
	2101	 1	 -0.0	 0.0	 0.0	 5.51	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	2102	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	2103	 1	 30.03	 10.0	 0.0	 0.08	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	2104	 1	 -0.0	 0.0	 0.038912	 2.611088	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2105	 1	 82.19	 23.4	 0.0	 17.91	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	2106	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 15.0	 1	    1.10000	    0.90000;
	2107	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	2108	 1	 100.1	 45.6	 0.0	 0.23	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	2109	 1	 627.8	 293.4	 0.698702	 7.516861	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	2110	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2111	 1	 -28.21	 -6.0	 0.0	 0.05	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2112	 1	 0.0	 -0.0	 0.0	 19.36	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	2113	 1	 -0.0	 0.0	 0.175191	 0.074008	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	2114	 1	 144.9	 87.7	 0.213866	 36.224477	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	2115	 1	 79.59	 18.8	 0.0	 6.78	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2116	 1	 -29.03	 -4.0	 0.191321	 4.088679	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	2117	 1	 64.0	 9.1	 0.0	 9.94	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2118	 1	 0.0	 0.0	 0.0	 2.54	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	2119	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	2120	 1	 117.5	 -3.0	 0.0	 5.38	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2121	 1	 193.8	 27.3	 0.462162	 21.334122	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	2122	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 10.6	 1	    1.10000	    0.90000;
	2123	 1	 1.1	 2.5	 0.263627	 23.900622	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	2124	 1	 -1.85	 -1.63	 0.0	 31.424588	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	2125	 1	 76.18	 13.2	 0.0	 7.4	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2126	 1	 -0.0	 -0.0	 0.0	 0.94	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2127	 1	 0.7	 0.2	 0.0	 0.22	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	2128	 1	 0.0	 -0.0	 0.0	 11.44	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	2129	 1	 -0.0	 -0.0	 0.0	 103.07	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	2130	 1	 -0.0	 -0.0	 0.0	 56.53	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	2131	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 10.5	 1	    1.10000	    0.90000;
	2132	 1	 0.0	 0.0	 0.119399	 8.830601	 0	    1.00000	    0.00000	 220.0	 22	    1.10000	    0.90000;
	2133	 1	 13.82	 5.0	 0.0	 0.47	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	2134	 1	 -0.0	 0.0	 0.0	 12.57	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2135	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	2136	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	2137	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	2138	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	2139	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	2140	 1	 142.8	 -6.4	 0.0	 12.36	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2141	 1	 -0.0	 -0.0	 0.0	 1.84	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2142	 1	 6.71	 3.3	 0.0	 1.31	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2143	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	2144	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	2145	 1	 -0.0	 -0.0	 0.0	 149.14	 0	    1.00000	    0.00000	 380.0	 19	    1.10000	    0.90000;
	2146	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	2147	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	2148	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	2149	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	2150	 1	 0.3	 -34.1	 0.0	 0.25	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	2151	 1	 -0.0	 -0.0	 0.0	 1.12	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2152	 1	 196.6	 28.1	 0.0	 0.52	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2153	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	2154	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	2155	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	2156	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	2157	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	2158	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	2159	 1	 339.1	 89.0	 0.0	 80.71	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	2160	 1	 0.0	 -0.0	 0.0	 4.31	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	2161	 1	 -0.0	 0.0	 0.0	 1.18	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2162	 1	 -0.0	 -0.0	 0.0	 28.31	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	2163	 1	 0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	2164	 1	 0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	2165	 1	 22.02	 9.0	 0.0	 0.24	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	2166	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	2167	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	2168	 1	 7.41	 2.7	 0.0	 0.98	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	2169	 1	 -0.0	 -0.0	 0.0	 0.1	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2170	 1	 -10.51	 3.5	 0.0	 0.8	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2171	 1	 173.6	 72.9	 0.0	 2.5	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2172	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	2173	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2174	 1	 72.1	 71.8	 0.0	 22.0	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	2175	 1	 135.0	 19.3	 0.0	 3.31	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2176	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	2177	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	2178	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	2179	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	2180	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 14.4	 1	    1.10000	    0.90000;
	2181	 1	 115.2	 38.9	 0.0	 2.96	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	2182	 1	 0.0	 -0.0	 0.0	 17.24	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	2183	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	2184	 1	 -10.86	 -5.93	 0.0	 12.54	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2185	 1	 0.0	 0.0	 0.0	 5.38	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2186	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	2187	 1	 5.81	 2.0	 0.0	 0.2	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	2188	 1	 35.3	 5.0	 0.0	 0.89	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2189	 1	 0.0	 8.4	 0.0	 15.21	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2190	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	2191	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	2192	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 6.3	 1	    1.10000	    0.90000;
	2193	 1	 2.5	 1.3	 0.0	 0.85	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2194	 1	 43.8	 20.7	 0.0	 133.678646	 0	    1.00000	    0.00000	 380.0	 9	    1.10000	    0.90000;
	2195	 1	 0.0	 0.0	 0.261953	 32.381259	 0	    1.00000	    0.00000	 380.0	 21	    1.10000	    0.90000;
	2196	 1	 129.5	 51.8	 0.0	 107.08	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	2197	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 20	    1.10000	    0.90000;
	2198	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	2199	 1	 -0.0	 -0.0	 0.0	 0.63	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2200	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2201	 1	 0.0	 0.0	 1.025363	 33.6215	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	2202	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	2203	 1	 73.58	 3.24	 0.0	 52.35	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2204	 1	 0.0	 0.0	 0.27075	 74.70435	 0	    1.00000	    0.00000	 380.0	 18	    1.20000	    0.80000;
	2205	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	2206	 1	 125.4	 45.8	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2207	 1	 8.0	 1.1	 0.0	 3.65	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2208	 1	 116.7	 64.0	 0.0	 10.41	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	2209	 1	 0.0	 -0.0	 0.0	 44.56	 0	    1.00000	    0.00000	 380.0	 23	    1.20000	    0.80000;
	2210	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	2211	 1	 0.0	 -0.0	 0.233775	 -0.194812	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	2212	 1	 25.13	 9.4	 0.039154	 0.480846	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2213	 1	 7.61	 2.5	 0.0	 0.72	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2214	 1	 300.2	 -3.1	 0.0	 29.94	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	2215	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.5	 1	    1.10000	    0.90000;
	2216	 1	 -0.0	 0.0	 0.220588	 73.145368	 0	    1.00000	    0.00000	 380.0	 18	    1.20000	    0.80000;
	2217	 1	 0.0	 -0.0	 0.0	 7.99	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2218	 1	 20.42	 8.1	 0.0	 35.15	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	2219	 1	 -21.62	 -3.9	 0.0	 4.01	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	2220	 1	 0.0	 0.0	 0.0	 4.96	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2221	 1	 0.0	 -0.0	 0.471052	 0.677084	 0	    1.00000	    0.00000	 380.0	 14	    1.10000	    0.90000;
	2222	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	2223	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 10.6	 1	    1.10000	    0.90000;
	2224	 1	 -0.58	 -53.03	 0.0	 6.85	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2225	 1	 -0.0	 -0.0	 0.846571	 39.359754	 0	    1.00000	    0.00000	 380.0	 7	    1.10000	    0.90000;
	2226	 1	 20.9	 3.0	 0.0	 4.18	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2227	 1	 -0.0	 0.0	 0.0	 2.62	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2228	 1	 -0.5	 -1.0	 0.0	 0.68	 0	    1.00000	    0.00000	 220.0	 19	    1.10000	    0.90000;
	2229	 1	 175.2	 82.4	 0.0	 0.21	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	2230	 1	 77.38	 24.1	 0.0	 2.67	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2231	 1	 56.56	 3.5	 0.0	 0.63	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2232	 1	 140.4	 49.4	 0.0	 4.5	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	2233	 1	 16.7	 2.4	 0.0	 3.57	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2234	 1	 156.9	 -4.0	 0.0	 2.48	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2235	 1	 60.07	 27.0	 0.0	 0.48	 0	    1.00000	    0.00000	 110.0	 23	    1.10000	    0.90000;
	2236	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	2237	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	2238	 1	 69.08	 21.5	 0.0	 1.65	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2239	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2240	 1	 0.0	 0.0	 0.113849	 6.775126	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	2241	 1	 329.4	 12.9	 0.0	 34.36	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	2242	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	2243	 1	 12.6	 1.8	 0.0	 1.96	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2244	 1	 34.04	 4.4	 0.0	 0.22	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	2245	 1	 -0.0	 0.0	 0.0	 2.18	 0	    1.00000	    0.00000	 220.0	 22	    1.10000	    0.90000;
	2246	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 22	    1.10000	    0.90000;
	2247	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	2248	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	2249	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	2250	 1	 32.04	 19.8	 0.0	 0.72	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2251	 1	 -0.0	 0.0	 0.0	 1.38	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2252	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	2253	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	2254	 1	 -0.0	 0.0	 0.0	 16.56	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	2255	 1	 0.0	 -0.0	 0.0	 0.19	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2256	 1	 146.6	 3.3	 0.0	 18.83	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	2257	 1	 -0.0	 -0.0	 0.228851	 8.919291	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	2258	 1	 -4.14	 -1.83	 0.0	 0.46	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2259	 1	 -0.0	 -0.0	 0.0	 3.24	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2260	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 15.75	 1	    1.10000	    0.90000;
	2261	 1	 30.53	 10.4	 0.0	 0.56	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	2262	 1	 0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 3	    1.10000	    0.90000;
	2263	 1	 0.0	 -0.0	 0.0	 21.01	 0	    1.00000	    0.00000	 380.0	 7	    1.10000	    0.90000;
	2264	 1	 78.5	 137.8	 0.0	 3.01	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	2265	 1	 104.5	 -56.4	 0.0	 23.22	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	2266	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2267	 1	 0.9	 0.3	 0.0	 1.48	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	2268	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	2269	 1	 -0.16	 -11.88	 0.0	 16.12	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	2270	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 10.5	 1	    1.10000	    0.90000;
	2271	 1	 28.33	 44.8	 0.0	 0.51	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2272	 1	 -0.0	 -0.0	 0.0	 3.01	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	2273	 1	 -0.0	 -0.0	 0.0	 288.0	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	2274	 1	 71.77	 13.57	 0.0	 3.84	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2275	 1	 76.29	 45.7	 0.0	 10.89	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	2276	 1	 51.96	 13.4	 0.0	 0.65	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	2277	 1	 58.87	 36.4	 0.0	 3.38	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2278	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 6.3	 1	    1.10000	    0.90000;
	2279	 1	 -0.0	 0.0	 0.0	 0.48	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2280	 1	 38.74	 14.1	 0.0	 12.78	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2281	 1	 -0.0	 -0.0	 0.0	 4.63	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	2282	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	2283	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	2284	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	2285	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	2286	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 23	    1.10000	    0.90000;
	2287	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 23	    1.10000	    0.90000;
	2288	 1	 45.75	 4.2	 0.0	 4.9	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2289	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	2290	 1	 137.2	 16.1	 0.0	 5.26	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	2291	 1	 -0.0	 0.0	 0.04006	 0.11994	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2292	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	2293	 1	 -0.0	 0.0	 0.224579	 1.042208	 0	    1.00000	    0.00000	 380.0	 14	    1.10000	    0.90000;
	2294	 1	 73.78	 -0.0	 0.0	 2.69	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	2295	 1	 25.13	 15.6	 0.0	 4.45	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2296	 1	 0.0	 0.0	 0.0	 6.55	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2297	 1	 164.8	 42.5	 0.0	 32.849681	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	2298	 1	 274.1	 166.5	 0.0	 0.56	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	2299	 1	 18.5	 2.6	 0.0	 3.05	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2300	 1	 149.8	 63.1	 0.0	 34.02	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	2301	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	2302	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	2303	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 22	    1.10000	    0.90000;
	2304	 1	 0.0	 -0.0	 0.0	 14.45	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	2305	 1	 14.72	 5.3	 0.0	 0.47	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	2306	 1	 152.1	 194.4	 0.039528	 79.820472	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	2307	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	2308	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 15.75	 1	    1.10000	    0.90000;
	2309	 1	 20.32	 2.5	 0.0	 5.2	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2310	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	2311	 1	 4.0	 0.6	 0.0	 3.36	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2312	 1	 -0.22	 -0.4	 0.0	 6.67	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	2313	 1	 0.0	 -0.0	 0.0	 7.74	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	2314	 1	 164.2	 -10.7	 0.0	 11.44	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	2315	 1	 -0.02	 -0.51	 0.0	 1.61	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2316	 1	 73.18	 22.3	 0.0	 8.77	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2317	 1	 75.88	 11.2	 0.0	 4.58	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2318	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	2319	 1	 123.5	 -49.4	 0.0	 2.9	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	2320	 1	 41.95	 8.5	 0.0	 1.05	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2321	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	2322	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	2323	 1	 0.0	 0.0	 0.0	 20.95	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	2324	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	2325	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	2326	 1	 0.0	 -0.0	 0.0	 0.87	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2327	 1	 20.82	 7.9	 0.0	 1.07	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2328	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	2329	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	2330	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	2331	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	2332	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	2333	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	2334	 1	 5.31	 2.3	 0.0	 1.03	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2335	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	2336	 1	 -0.18	 -1.06	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	2337	 1	 0.0	 0.0	 0.119008	 29.381167	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	2338	 1	 -8.41	 2.7	 0.0	 0.83	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2339	 1	 7.41	 2.7	 0.0	 1.28	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	2340	 1	 70.08	 11.1	 0.0	 9.84	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2341	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 6.3	 1	    1.10000	    0.90000;
	2342	 1	 0.0	 0.0	 0.0	 36.99	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	2343	 1	 51.66	 8.0	 0.0	 4.51	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2344	 1	 33.6	 4.8	 0.0	 5.24	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2345	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	2346	 1	 33.24	 11.5	 0.0	 1.61	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	2347	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	2348	 1	 -0.0	 0.0	 0.039624	 66.502129	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	2349	 1	 95.71	 25.9	 0.0	 11.38	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2350	 1	 -33.1	 -14.35	 0.0	 94.55	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	2351	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	2352	 1	 60.27	 9.4	 0.0	 0.62	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2353	 1	 15.34	 -1.3	 0.0	 0.71	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2354	 1	 124.5	 59.2	 0.0	 77.23	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	2355	 1	 13.31	 4.8	 0.0	 0.2	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	2356	 1	 103.7	 14.9	 0.0	 3.04	 0	    1.00000	    0.00000	 220.0	 20	    1.10000	    0.90000;
	2357	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 6.3	 1	    1.10000	    0.90000;
	2358	 1	 33.04	 15.7	 0.0	 1.5	 0	    1.00000	    0.00000	 110.0	 23	    1.10000	    0.90000;
	2359	 1	 216.8	 40.5	 0.0	 5.91	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	2360	 1	 -0.0	 0.0	 0.0	 0.73	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2361	 1	 22.02	 11.9	 0.0	 0.79	 0	    1.00000	    0.00000	 110.0	 23	    1.10000	    0.90000;
	2362	 1	 -0.0	 0.0	 0.207485	 26.23319	 0	    1.00000	    0.00000	 380.0	 7	    1.10000	    0.90000;
	2363	 1	 0.0	 0.0	 0.0	 45.19	 0	    1.00000	    0.00000	 380.0	 1	    1.20000	    0.80000;
	2364	 1	 15.22	 7.6	 0.0	 0.6	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2365	 1	 257.2	 -26.8	 0.0	 5.2	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	2366	 1	 62.07	 14.7	 0.0	 4.84	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2367	 1	 20.9	 3.0	 0.0	 1.49	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2368	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	2369	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	2370	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	2371	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	2372	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	2373	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	2374	 1	 22.02	 7.5	 0.0	 0.59	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	2375	 1	 3.67	 -1.86	 0.0	 3.89	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2376	 1	 85.39	 31.8	 0.831419	 202.607702	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	2377	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	2378	 1	 86.1	 40.6	 0.0	 7.39	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2379	 1	 125.4	 17.8	 0.0	 3.11	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2380	 1	 20.02	 6.6	 0.0	 0.74	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	2381	 1	 34.04	 -0.0	 0.0	 2.4	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2382	 1	 -0.75	 -5.36	 0.0	 10.46	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	2383	 1	 91.7	 17.0	 0.0	 2.48	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2384	 1	 -0.0	 -0.0	 0.259637	 9.774901	 0	    1.00000	    0.00000	 380.0	 19	    1.10000	    0.90000;
	2385	 1	 -0.0	 -0.0	 0.181549	 8.990889	 0	    1.00000	    0.00000	 220.0	 18	    1.20000	    0.80000;
	2386	 1	 46.45	 19.1	 0.0	 6.66	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	2387	 1	 3.3	 1.1	 0.0	 1.12	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	2388	 1	 0.0	 0.0	 0.0	 14.82	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	2389	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	2390	 1	 -28.13	 -0.83	 0.0	 0.1	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2391	 1	 4.68	 88.21	 0.0	 6.79	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2392	 1	 74.98	 19.8	 0.0	 6.47	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2393	 1	 55.26	 -11.1	 0.0	 1.45	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	2394	 1	 -0.0	 -0.0	 0.188054	 -1.648746	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	2395	 1	 -0.0	 -0.0	 0.0	 140.96	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	2396	 1	 9.21	 3.3	 0.0	 0.6	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	2397	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 6.3	 1	    1.10000	    0.90000;
	2398	 1	 -0.0	 0.0	 0.0	 15.6	 0	    1.00000	    0.00000	 150.0	 9	    1.20000	    0.80000;
	2399	 1	 -0.0	 -0.0	 0.0	 21.06	 0	    1.00000	    0.00000	 380.0	 7	    1.10000	    0.90000;
	2400	 1	 7.41	 2.7	 0.0	 1.24	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	2401	 1	 22.28	 5.67	 0.0	 1.2	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	2402	 1	 -0.0	 0.0	 0.0	 86.56	 0	    1.00000	    0.00000	 220.0	 24	    1.10000	    0.90000;
	2403	 1	 415.5	 52.5	 0.709256	 29.248637	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	2404	 1	 -0.0	 -0.0	 0.05988	 -0.02988	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	2405	 1	 0.0	 0.0	 0.37285	 19.231353	 0	    1.00000	    0.00000	 380.0	 21	    1.10000	    0.90000;
	2406	 1	 -0.0	 -0.0	 0.0	 0.94	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2407	 1	 72.18	 31.9	 0.0	 27.25	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	2408	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	2409	 1	 0.0	 0.0	 0.0	 58.96	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	2410	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	2411	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	2412	 1	 36.5	 5.2	 0.0	 1.48	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2413	 1	 83.19	 25.8	 0.0	 0.33	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2414	 1	 28.74	 1.23	 0.0	 2.15	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2415	 1	 3.9	 1.1	 0.0	 0.19	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2416	 1	 0.0	 0.0	 0.090774	 3.510444	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	2417	 1	 12.41	 4.4	 0.0	 0.34	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	2418	 1	 207.9	 9.2	 0.050393	 57.239607	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	2419	 1	 14.72	 5.3	 0.0	 1.72	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	2420	 1	 4.3	 1.8	 0.0	 0.29	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	2421	 1	 5.01	 2.0	 0.0	 0.6	 0	    1.00000	    0.00000	 110.0	 23	    1.10000	    0.90000;
	2422	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 6.3	 1	    1.10000	    0.90000;
	2423	 1	 47.45	 18.7	 0.0	 1.36	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	2424	 1	 0.0	 -0.0	 1.151541	 -0.347329	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	2425	 1	 62.16	 8.0	 0.0	 2.99	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2426	 1	 0.0	 0.0	 0.0	 0.4	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2427	 1	 0.0	 0.0	 0.0	 12.18	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	2428	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	2429	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	2430	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 15.0	 1	    1.10000	    0.90000;
	2431	 1	 92.61	 36.3	 0.0	 4.51	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	2432	 1	 0.0	 0.0	 0.574318	 0.092492	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	2433	 1	 -15.38	 -4.94	 0.0	 33.04827	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	2434	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	2435	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	2436	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	2437	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	2438	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	2439	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	2440	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	2441	 1	 92.1	 29.5	 0.0	 3.14	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2442	 1	 2.5	 0.6	 0.0	 0.51	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2443	 1	 4.91	 1.4	 0.0	 1.32	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2444	 1	 53.56	 17.2	 0.0	 1.76	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	2445	 1	 48.25	 6.4	 0.039744	 0.680256	 0	    1.00000	    0.00000	 110.0	 3	    1.10000	    0.90000;
	2446	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	2447	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	2448	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	2449	 1	 -0.0	 -0.0	 0.0	 16.62	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	2450	 1	 0.0	 -0.0	 0.019574	 0.340426	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2451	 1	 -14.32	 4.7	 0.0	 0.35	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2452	 1	 157.64	 115.5	 0.462433	 27.713907	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	2453	 1	 0.0	 -0.0	 0.683135	 2.569185	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	2454	 1	 0.0	 0.0	 0.019235	 0.030765	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2455	 1	 -0.2	 -1.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	2456	 1	 -0.0	 0.0	 0.0	 57.29	 0	    1.00000	    0.00000	 380.0	 16	    1.10000	    0.90000;
	2457	 1	 8.01	 4.9	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2458	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	2459	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	2460	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	2461	 1	 38.04	 29.0	 0.057188	 20.082812	 0	    1.00000	    0.00000	 220.0	 11	    1.10000	    0.90000;
	2462	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 7	    1.10000	    0.90000;
	2463	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2464	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	2465	 1	 34.44	 14.4	 0.0	 48.56	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	2466	 1	 68.38	 42.4	 0.0	 1.39	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2467	 1	 -17.18	 -4.35	 0.0	 44.421484	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	2468	 1	 19.92	 6.6	 0.0	 1.32	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	2469	 1	 0.0	 0.0	 0.135375	 28.222175	 0	    1.00000	    0.00000	 380.0	 18	    1.20000	    0.80000;
	2470	 1	 16.02	 5.3	 0.0	 0.67	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	2471	 1	 0.0	 -0.0	 0.0	 3.65	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	2472	 1	 -0.0	 -0.0	 0.0	 1.2	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2473	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 7	    1.10000	    0.90000;
	2474	 1	 0.0	 0.0	 0.115864	 -0.096553	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	2475	 1	 9.71	 3.5	 0.0	 1.44	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	2476	 1	 0.0	 0.0	 0.0	 11.14	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	2477	 1	 0.0	 -0.0	 0.0	 62.36	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	2478	 1	 -0.0	 0.0	 0.0	 5.09	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	2479	 1	 10.11	 2.5	 0.0	 0.47	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2480	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	2481	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	2482	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	2483	 1	 0.0	 -0.0	 0.0	 6.68	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2484	 1	 0.0	 -0.1	 0.08029	 -0.060218	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	2485	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 9	    1.10000	    0.90000;
	2486	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	2487	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	2488	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	2489	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	2490	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	2491	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2492	 1	 0.0	 0.0	 0.0	 1.86	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2493	 1	 -0.0	 -0.0	 0.511956	 7.711812	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	2494	 1	 -0.0	 0.0	 0.235883	 0.243431	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	2495	 1	 39.24	 24.3	 0.0	 0.07	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2496	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 7	    1.10000	    0.90000;
	2497	 1	 58.46	 6.6	 0.0	 10.13	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2498	 1	 5.41	 1.8	 0.0	 0.72	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	2499	 1	 11.51	 2.3	 0.0	 0.66	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2500	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 23	    1.10000	    0.90000;
	2501	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 23	    1.10000	    0.90000;
	2502	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 23	    1.10000	    0.90000;
	2503	 1	 85.8	 13.4	 0.0	 3.23	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2504	 1	 0.0	 -0.0	 0.0	 3.13	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2505	 1	 0.0	 0.0	 0.12	 1.51	 0	    1.00000	    0.00000	 220.0	 21	    1.10000	    0.90000;
	2506	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	2507	 1	 0.0	 -0.0	 0.020109	 133.82196	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	2508	 1	 199.4	 -19.9	 0.0	 6.68	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2509	 1	 -1.5	 -41.98	 0.0	 36.76	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	2510	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	2511	 1	 0.0	 0.0	 0.232565	 17.73498	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	2512	 1	 80.09	 20.0	 0.0	 3.08	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	2513	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	2514	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	2515	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	2516	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	2517	 1	 0.0	 -0.0	 0.0	 220.46	 0	    1.00000	    0.00000	 380.0	 18	    1.20000	    0.80000;
	2518	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	2519	 1	 0.0	 0.0	 0.0	 1.15	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	2520	 1	 328.9	 30.4	 0.0	 66.79	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	2521	 1	 11.11	 6.9	 0.0	 1.35	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2522	 1	 45.75	 20.1	 0.0	 0.41	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2523	 1	 0.0	 0.0	 0.0	 0.28	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	2524	 1	 25.43	 14.7	 0.0	 7.79	 0	    1.00000	    0.00000	 220.0	 18	    1.20000	    0.80000;
	2525	 1	 122.2	 68.9	 0.0	 0.58	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	2526	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 0.4	 1	    1.10000	    0.90000;
	2527	 1	 26.03	 8.7	 0.0	 0.29	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2528	 1	 333.5	 -1.4	 0.0	 8.37	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2529	 1	 73.98	 22.5	 0.0	 1.15	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2530	 1	 3.0	 1.5	 0.0	 0.4	 0	    1.00000	    0.00000	 110.0	 23	    1.10000	    0.90000;
	2531	 1	 -0.0	 0.0	 0.0	 2.55	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	2532	 1	 -0.0	 0.0	 0.0	 0.54	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	2533	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	2534	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	2535	 1	 12.6	 1.8	 0.0	 3.8	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2536	 1	 -0.0	 0.0	 0.0	 11.49	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	2537	 1	 226.4	 -13.0	 0.0	 15.2	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2538	 1	 -0.0	 -0.0	 0.0	 1.64	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2539	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	2540	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	2541	 1	 101.3	 17.6	 0.0	 0.12	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2542	 1	 -0.18	 -3.85	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	2543	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	2544	 1	 5.51	 2.0	 0.0	 0.79	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	2545	 1	 -1.8	 -4.8	 0.0	 0.44	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2546	 1	 16.52	 5.5	 0.0	 1.59	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	2547	 1	 28.63	 10.0	 0.0	 1.34	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	2548	 1	 0.0	 -0.8	 0.0	 0.46	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2549	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2550	 1	 169.8	 -19.6	 0.0	 53.619841	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	2551	 1	 18.4	 10.1	 0.672256	 21.491354	 0	    1.00000	    0.00000	 380.0	 9	    1.20000	    0.80000;
	2552	 1	 32.94	 10.1	 0.0	 0.41	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	2553	 1	 -0.0	 0.0	 0.353382	 20.075147	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	2554	 1	 0.0	 -0.0	 0.0	 2.19	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	2555	 1	 -19.32	 6.4	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2556	 1	 -0.0	 -0.0	 0.0	 6.8	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	2557	 1	 166.1	 64.9	 0.039665	 2.130335	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2558	 1	 -0.0	 -0.0	 1.139646	 11.552147	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	2559	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	2560	 1	 71.18	 23.8	 0.0	 0.07	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	2561	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	2562	 1	 13.31	 7.9	 0.0	 0.45	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2563	 1	 12.31	 0.2	 0.039377	 3.700623	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2564	 1	 -0.63	 -0.83	 0.0	 22.772633	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	2565	 1	 0.0	 -0.0	 0.0	 1.46	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2566	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	2567	 1	 8.3	 1.2	 0.0	 4.96	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2568	 1	 -0.0	 0.0	 0.0	 0.67	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2569	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 23	    1.10000	    0.90000;
	2570	 1	 8.51	 3.2	 0.0	 2.93	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2571	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	2572	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	2573	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	2574	 1	 -0.0	 -0.0	 0.0	 0.05	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2575	 1	 23.03	 10.5	 0.0	 3.96	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	2576	 1	 112.6	 16.1	 0.0	 3.38	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2577	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	2578	 1	 -4.17	 -2.16	 0.0	 0.66	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2579	 1	 25.43	 8.3	 0.0	 1.35	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	2580	 1	 -3.55	 -1.43	 0.0	 11.839519	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	2581	 1	 166.2	 55.1	 0.117826	 7.712174	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2582	 1	 -0.0	 -0.0	 0.0	 239.779558	 0	    1.00000	    0.00000	 750.0	 20	    1.10000	    0.90000;
	2583	 1	 0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	2584	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	2585	 1	 52.46	 11.3	 0.0	 0.27	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	2586	 1	 99.51	 1.5	 0.0	 32.89	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	2587	 1	 44.65	 8.8	 0.0	 20.17	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2588	 1	 0.0	 -0.0	 0.116549	 -0.087411	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	2589	 1	 13.9	 1.9	 0.0	 3.95	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2590	 1	 88.92	 19.79	 0.0	 2.81	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2591	 1	 34.14	 -2.8	 0.239003	 18.790831	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	2592	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 22	    1.10000	    0.90000;
	2593	 1	 63.66	 9.7	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 2	    1.10000	    0.90000;
	2594	 1	 335.3	 -101.3	 0.0	 32.69	 0	    1.00000	    0.00000	 380.0	 11	    1.10000	    0.90000;
	2595	 1	 108.91	 33.7	 0.0	 56.24	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	2596	 1	 -29.73	 9.8	 0.0	 2.31	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2597	 1	 -0.0	 -0.0	 0.198366	 -0.008774	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	2598	 1	 0.0	 0.0	 0.0	 0.06	 0	    1.00000	    0.00000	 220.0	 19	    1.10000	    0.90000;
	2599	 1	 14.62	 2.0	 0.0	 10.89	 0	    1.00000	    0.00000	 220.0	 18	    1.20000	    0.80000;
	2600	 1	 -0.0	 0.0	 0.0	 3.33	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	2601	 1	 0.0	 0.0	 0.467058	 2.950246	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	2602	 1	 -0.0	 0.0	 0.438658	 64.65877	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	2603	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 10.5	 1	    1.10000	    0.90000;
	2604	 1	 -0.65	 -1.81	 0.0	 1.52	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2605	 1	 0.0	 0.0	 0.0	 0.38	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	2606	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	2607	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	2608	 1	 56.46	 22.0	 0.0	 41.96	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	2609	 1	 114.2	 16.3	 0.0	 57.91	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	2610	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	2611	 1	 5.01	 13.0	 0.0	 30.48	 0	    1.00000	    0.00000	 220.0	 11	    1.10000	    0.90000;
	2612	 1	 17.82	 6.7	 0.0	 0.09	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	2613	 1	 -0.0	 -0.0	 0.0	 0.51	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2614	 1	 34.14	 21.1	 0.0	 0.35	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2615	 1	 0.0	 -0.0	 0.0	 3.33	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2616	 1	 8.21	 2.5	 0.0	 0.12	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2617	 1	 44.23	 22.19	 0.0	 4.35	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	2618	 1	 62.37	 25.5	 0.0	 3.98	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	2619	 1	 113.27	 27.67	 0.0	 3.61	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	2620	 1	 0.4	 -170.2	 0.0	 3.04	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	2621	 1	 112.0	 19.7	 0.0	 38.04	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2622	 1	 -0.0	 0.0	 0.0	 0.62	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2623	 1	 0.0	 -0.0	 0.0	 25.22	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2624	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	2625	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	2626	 1	 30.53	 15.1	 0.061431	 0.888569	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	2627	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	2628	 1	 123.9	 17.6	 0.0	 11.56	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2629	 1	 0.0	 0.0	 0.0	 3.07	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2630	 1	 154.8	 -47.1	 0.0	 4.18	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2631	 1	 22.02	 21.8	 0.0	 10.29	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	2632	 1	 5.11	 2.4	 0.0	 1.34	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2633	 1	 7.81	 5.8	 0.030123	 9.949877	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2634	 1	 -0.0	 0.0	 0.019998	 0.030002	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2635	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	2636	 1	 25.73	 8.9	 0.0	 1.29	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2637	 1	 0.2	 0.5	 0.0	 0.42	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	2638	 1	 0.0	 -0.0	 0.0	 1.94	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	2639	 1	 -41.65	 13.7	 0.0	 0.3	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2640	 1	 5.51	 2.0	 0.0	 0.95	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	2641	 1	 0.0	 -0.0	 0.0	 1.53	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2642	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	2643	 1	 369.5	 16.7	 0.0	 10.6	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	2644	 1	 14.0	 2.0	 0.0	 3.32	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2645	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.5	 1	    1.10000	    0.90000;
	2646	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	2647	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	2648	 1	 -0.0	 0.0	 0.0	 19.01	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	2649	 1	 177.4	 41.7	 0.0	 2.98	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	2650	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	2651	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	2652	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	2653	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	2654	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	2655	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	2656	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	2657	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	2658	 1	 -19.62	 28.6	 0.0	 1.69	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2659	 1	 55.26	 23.2	 0.0	 8.01	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	2660	 1	 209.2	 23.5	 0.0	 6.44	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2661	 1	 0.0	 0.0	 0.0	 0.06	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	2662	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 9	    1.10000	    0.90000;
	2663	 1	 11.71	 3.8	 0.0	 2.96	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2664	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	2665	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	2666	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	2667	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	2668	 1	 -0.0	 -0.0	 0.0	 0.74	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	2669	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	2670	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	2671	 1	 15.57	 9.59	 0.0	 0.41	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2672	 1	 94.3	 13.8	 0.0	 5.3	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2673	 1	 83.29	 30.1	 0.0	 4.68	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	2674	 1	 223.9	 72.6	 0.0	 2.04	 0	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2675	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2676	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	2677	 1	 0.0	 0.0	 0.0	 6.262609	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	2678	 1	 1.2	 0.8	 0.114435	 4.545565	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2679	 1	 -0.0	 -0.0	 0.0	 0.13	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2680	 1	 -0.0	 0.0	 0.0	 0.57	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2681	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	2682	 1	 50.26	 16.4	 0.0	 0.23	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	2683	 1	 -0.0	 -0.0	 0.0	 50.2	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	2684	 1	 0.2	 108.3	 0.167319	 83.060568	 0	    1.00000	    0.00000	 380.0	 3	    1.20000	    0.80000;
	2685	 1	 27.33	 5.0	 0.0	 6.77	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2686	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	2687	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	2688	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	2689	 1	 2.2	 1.1	 0.0	 1.57	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	2690	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	2691	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	2692	 1	 -0.75	 -0.93	 0.0	 0.26	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	2693	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	2694	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	2695	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	2696	 1	 182.32	 35.4	 0.524537	 0.022886	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2697	 1	 57.16	 -0.0	 0.0	 6.58	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	2698	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	2699	 1	 0.0	 -0.0	 0.925827	 -0.732946	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	2700	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	2701	 1	 28.63	 17.8	 0.0	 0.06	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2702	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	2703	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	2704	 1	 29.4	 4.2	 0.0	 2.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2705	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	2706	 1	 32.34	 14.1	 0.0	 0.24	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2707	 1	 22.22	 5.9	 0.0	 10.28	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2708	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	2709	 1	 1.4	 0.5	 0.0	 0.89	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	2710	 1	 20.82	 -0.0	 0.0	 0.14	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2711	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	2712	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.5	 1	    1.10000	    0.90000;
	2713	 1	 53.96	 4.9	 0.0	 4.21	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2714	 1	 0.5	 21.5	 0.190226	 30.657331	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	2715	 1	 0.0	 0.0	 0.202076	 48.319777	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	2716	 1	 -0.0	 0.0	 0.334631	 25.761141	 0	    1.00000	    0.00000	 380.0	 3	    1.20000	    0.80000;
	2717	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 14.4	 1	    1.10000	    0.90000;
	2718	 1	 0.2	 1.4	 0.0	 0.49	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	2719	 1	 -0.0	 -0.0	 0.0	 35.14	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	2720	 1	 26.43	 7.7	 0.0	 7.88	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	2721	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	2722	 1	 0.0	 -0.0	 0.0	 3.15	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2723	 1	 16.02	 5.3	 0.0	 0.67	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	2724	 1	 17.5	 502.7	 0.319765	 0.651294	 0	    1.00000	    0.00000	 380.0	 19	    1.20000	    0.80000;
	2725	 1	 25.0	 3.6	 0.0	 2.17	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2726	 1	 0.0	 0.0	 0.057077	 -0.047564	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	2727	 1	 -11.95	 -3.92	 0.0	 0.18	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2728	 1	 99.4	 35.8	 0.605414	 57.517845	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	2729	 1	 0.0	 -0.0	 0.0	 6.21	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2730	 1	 39.54	 14.3	 0.0	 0.91	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	2731	 1	 62.17	 0.7	 0.0	 5.98	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2732	 1	 52.06	 14.3	 0.0	 1.59	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2733	 1	 91.1	 54.8	 0.0	 30.59	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	2734	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	2735	 1	 -0.0	 0.0	 0.241629	 -0.061629	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2736	 1	 33.64	 3.9	 0.0	 3.37	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	2737	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2738	 1	 10.51	 3.5	 0.0	 0.66	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	2739	 1	 -0.0	 -0.0	 0.0	 13.33	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	2740	 1	 197.5	 -31.0	 0.0	 17.34	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2741	 1	 -0.0	 -0.0	 0.0	 21.97	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	2742	 1	 -0.0	 -0.0	 0.361262	 2.649018	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	2743	 1	 0.0	 -0.0	 0.0	 0.3	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2744	 1	 49.25	 4.9	 0.0	 1.06	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2745	 1	 0.0	 0.0	 0.126343	 10.705031	 0	    1.00000	    0.00000	 220.0	 19	    1.20000	    0.80000;
	2746	 1	 192.11	 45.5	 0.0	 68.04	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	2747	 1	 108.3	 62.0	 0.0	 36.65	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	2748	 1	 192.3	 27.4	 0.0	 120.83	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	2749	 1	 0.0	 0.0	 0.0	 21.18	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	2750	 1	 64.37	 38.3	 0.291893	 16.726756	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	2751	 1	 -0.0	 -0.0	 0.0	 2.16	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	2752	 1	 45.6	 6.5	 0.0	 95.24	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	2753	 1	 14.8	 6.6	 0.0	 84.333648	 0	    1.00000	    0.00000	 380.0	 9	    1.20000	    0.80000;
	2754	 1	 177.4	 85.5	 0.040271	 8.399796	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	2755	 1	 51.86	 13.9	 0.0	 0.67	 0	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	2756	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	2757	 1	 -0.0	 0.0	 0.0	 45.35	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	2758	 1	 0.0	 0.0	 0.0	 4.29	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	2759	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 15.75	 1	    1.10000	    0.90000;
	2760	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	2761	 1	 -0.0	 -0.0	 0.0	 0.07	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2762	 1	 98.6	 14.0	 0.0	 0.31	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2763	 1	 -0.0	 -0.0	 0.0	 30.78	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	2764	 1	 0.0	 0.0	 0.0	 4.76	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	2765	 1	 -0.0	 -0.0	 0.0	 13.03	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2766	 1	 -11.44	 -3.29	 0.0	 0.04	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	2767	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	2768	 1	 0.0	 0.0	 0.0	 1.19	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2769	 1	 0.0	 -0.0	 0.113836	 13.934623	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	2770	 1	 44.75	 4.1	 0.0	 3.12	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2771	 1	 4.4	 99.7	 0.0	 40.45	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	2772	 1	 -0.0	 -0.0	 0.0	 0.27	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	2773	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2774	 1	 19.42	 -0.8	 0.0	 0.78	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	2775	 1	 21.82	 10.3	 0.0	 32.61	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	2776	 1	 32.2	 4.6	 0.0	 2.54	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2777	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 9	    1.10000	    0.90000;
	2778	 1	 0.0	 0.0	 0.0	 4.96	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	2779	 1	 159.8	 45.0	 0.0	 5.6	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	2780	 1	 0.0	 -0.0	 0.0	 2.1	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	2781	 1	 -0.0	 -0.0	 0.0	 0.76	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2782	 1	 115.1	 10.4	 0.0	 6.12	 0	    1.00000	    0.00000	 220.0	 11	    1.10000	    0.90000;
	2783	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	2784	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	2785	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	2786	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 7	    1.10000	    0.90000;
	2787	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	2788	 1	 21.62	 13.4	 0.0	 1.79	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2789	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	2790	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	2791	 1	 0.0	 0.0	 0.0	 10.51	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	2792	 1	 0.0	 0.0	 0.0	 51.66	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	2793	 1	 -0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	2794	 1	 76.28	 2.9	 0.0	 7.28	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2795	 1	 23.13	 8.8	 0.0	 0.95	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	2796	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	2797	 1	 -0.0	 -0.0	 0.01938	 0.48062	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2798	 1	 -0.0	 0.0	 0.0	 1.94	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	2799	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	2800	 1	 3.2	 1.5	 0.0	 1.81	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2801	 1	 -0.0	 -0.0	 0.0	 0.27	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	2802	 1	 179.5	 85.21	 0.04028	 0.53979	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	2803	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	2804	 1	 248.7	 8.1	 0.0	 12.46	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2805	 1	 -20.6	 -9.4	 0.0	 1.12	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2806	 1	 46.05	 16.7	 0.0	 0.49	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	2807	 1	 28.83	 10.4	 0.0	 0.26	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	2808	 1	 0.0	 -0.0	 0.0	 0.86	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2809	 1	 -0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	2810	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	2811	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	2812	 1	 1.8	 4.9	 0.0	 92.20984	 0	    1.00000	    0.00000	 380.0	 9	    1.20000	    0.80000;
	2813	 1	 210.1	 66.2	 0.0	 59.36	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2814	 1	 241.9	 38.8	 0.0	 12.46	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	2815	 1	 23.33	 9.1	 0.0	 15.36	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	2816	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	2817	 1	 0.0	 -0.0	 0.0	 12.41	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	2818	 1	 0.0	 0.0	 0.135493	 29.07062	 0	    1.00000	    0.00000	 380.0	 21	    1.20000	    0.80000;
	2819	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	2820	 1	 -0.0	 0.0	 0.0	 0.14	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2821	 1	 39.64	 9.6	 0.0	 1.8	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2822	 1	 19.32	 6.4	 0.0	 3.74	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	2823	 1	 12.41	 3.9	 0.0	 1.14	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	2824	 1	 41.8	 5.9	 0.0	 2.76	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2825	 1	 188.1	 26.8	 0.0	 5.85	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2826	 1	 -0.0	 0.0	 0.0	 1.66	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2827	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	2828	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	2829	 1	 147.4	 -55.9	 0.0	 1.12	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2830	 1	 -0.0	 0.0	 0.0	 1.83	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2831	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.5	 1	    1.10000	    0.90000;
	2832	 1	 70.18	 44.7	 0.0	 8.09	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2833	 1	 50.26	 5.5	 0.0	 1.3	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2834	 1	 69.78	 20.3	 0.0	 10.26	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	2835	 1	 61.87	 -12.4	 0.0	 0.83	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	2836	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	2837	 1	 -0.0	 -0.0	 0.03986	 2.100105	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	2838	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	2839	 1	 89.5	 33.9	 0.0	 1.52	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	2840	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	2841	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	2842	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	2843	 1	 -0.0	 -0.0	 0.427339	 57.506029	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	2844	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	2845	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	2846	 1	 0.0	 -0.0	 0.121579	 0.048816	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	2847	 1	 25.73	 7.3	 0.0	 2.82	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2848	 1	 -0.0	 -0.0	 0.113571	 -0.085178	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	2849	 1	 0.0	 0.0	 0.0	 102.579963	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	2850	 1	 54.0	 29.1	 0.0	 204.291522	 0	    1.00000	    0.00000	 380.0	 9	    1.10000	    0.90000;
	2851	 1	 -0.0	 -0.0	 0.0	 0.4	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2852	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	2853	 1	 0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 8	    1.20000	    0.80000;
	2854	 1	 139.1	 60.4	 0.0	 1.98	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	2855	 1	 0.0	 -0.0	 0.0	 3.72	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	2856	 1	 -61.76	 -31.85	 0.0	 0.0	 0	    1.00000	    0.00000	 27.0	 9	    1.10000	    0.90000;
	2857	 1	 54.66	 0.0	 0.0	 2.97	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	2858	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	2859	 1	 -40.44	 1.5	 0.0	 14.2	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	2860	 1	 82.1	 11.7	 0.0	 3.76	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2861	 1	 0.0	 -0.0	 0.0	 0.26	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2862	 1	 -0.0	 0.0	 0.039441	 0.080559	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2863	 1	 302.5	 65.1	 0.0	 8.87	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2864	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2865	 1	 -0.0	 -0.0	 0.0	 0.85	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2866	 1	 41.45	 4.9	 0.0	 18.43	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2867	 1	 0.0	 0.0	 0.0	 18.99	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	2868	 1	 0.0	 -0.0	 0.0	 0.34	 0	    1.00000	    0.00000	 380.0	 1	    1.20000	    0.80000;
	2869	 1	 95.91	 -15.4	 0.0	 1.51	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	2870	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	2871	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	2872	 1	 119.0	 -315.3	 0.0	 41.89	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	2873	 1	 0.0	 0.0	 0.29374	 2.585217	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	2874	 1	 -0.0	 0.0	 0.039591	 0.130409	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2875	 1	 72.08	 21.3	 0.0	 7.19	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2876	 1	 -0.0	 0.0	 0.0	 9.98	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2877	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	2878	 1	 3.9	 1.0	 0.0	 3.81	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2879	 1	 8.11	 2.9	 0.0	 0.52	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	2880	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	2881	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	2882	 1	 89.1	 2.3	 0.0	 1.68	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	2883	 1	 16.02	 4.0	 0.0	 5.56	 0	    1.00000	    0.00000	 220.0	 11	    1.10000	    0.90000;
	2884	 1	 -0.0	 -0.0	 0.181549	 5.390889	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	2885	 1	 110.9	 15.8	 0.0	 30.2	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	2886	 1	 90.1	 12.7	 0.0	 10.61	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	2887	 1	 0.0	 0.0	 0.330327	 -0.256921	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	2888	 1	 25.83	 9.4	 0.0	 0.56	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	2889	 1	 134.0	 19.1	 0.0	 1.55	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2890	 1	 0.0	 -0.0	 0.0	 0.66	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	2891	 1	 153.64	 29.2	 0.0	 7.65	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	2892	 1	 -0.0	 0.0	 0.575637	 1.661442	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	2893	 1	 6.31	 3.8	 0.0	 0.36	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2894	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	2895	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 9	    1.20000	    0.80000;
	2896	 1	 28.83	 9.6	 0.0	 0.8	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	2897	 1	 0.0	 0.0	 0.0	 14.4	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	2898	 1	 297.7	 258.6	 0.0	 65.78	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	2899	 1	 178.4	 69.1	 0.0	 14.2	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	2900	 1	 -0.0	 -0.0	 0.32223	 108.252095	 0	    1.00000	    0.00000	 380.0	 19	    1.10000	    0.90000;
	2901	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	2902	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	2903	 1	 3.2	 1.7	 0.0	 0.05	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2904	 1	 8.51	 3.2	 0.0	 0.96	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2905	 1	 0.0	 0.0	 0.0	 0.74	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2906	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	2907	 1	 83.59	 21.6	 0.0	 25.51	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2908	 1	 -0.65	 -1.44	 0.0	 0.16	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2909	 1	 19.22	 6.9	 0.0	 1.16	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	2910	 1	 29.3	 4.2	 0.0	 5.26	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2911	 1	 39.84	 24.6	 0.0	 13.99	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2912	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.5	 1	    1.10000	    0.90000;
	2913	 1	 0.0	 -0.0	 0.154629	 1.135371	 0	    1.00000	    0.00000	 380.0	 16	    1.10000	    0.90000;
	2914	 1	 0.0	 0.0	 0.0	 5.39	 0	    1.00000	    0.00000	 220.0	 12	    1.10000	    0.90000;
	2915	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2916	 1	 0.0	 0.0	 0.0	 2.99	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	2917	 1	 -0.0	 -0.0	 0.0	 0.06	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	2918	 1	 52.66	 21.5	 0.0	 0.04	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	2919	 1	 0.0	 0.0	 0.0	 7.196658	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	2920	 1	 120.2	 20.5	 0.0	 19.94	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2921	 1	 -0.0	 0.0	 0.0	 1.31	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	2922	 1	 -0.0	 -0.0	 0.0	 16.08	 0	    1.00000	    0.00000	 380.0	 9	    1.20000	    0.80000;
	2923	 1	 115.1	 23.5	 0.0	 3.78	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2924	 1	 0.0	 -0.0	 0.0	 0.31	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2925	 1	 -0.61	 -1.33	 0.0	 0.43	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	2926	 1	 108.7	 10.3	 0.087306	 1.402394	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	2927	 1	 14.4	 2.0	 0.0	 4.17	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2928	 1	 98.6	 14.0	 0.0	 12.86	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2929	 1	 19.82	 7.3	 0.0	 0.25	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	2930	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2931	 1	 50.16	 18.0	 0.0	 0.1	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	2932	 1	 1.4	 -2.0	 0.0	 5.05	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	2933	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 6.3	 1	    1.10000	    0.90000;
	2934	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	2935	 1	 -0.0	 -0.0	 0.0	 2.88	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	2936	 1	 0.0	 -0.0	 0.0	 149.047157	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	2937	 1	 101.2	 2.1	 0.0	 38.43	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	2938	 1	 -0.0	 0.0	 0.060224	 0.419776	 0	    1.00000	    0.00000	 220.0	 14	    1.10000	    0.90000;
	2939	 1	 86.9	 30.3	 0.0	 1.32	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	2940	 1	 50.56	 4.6	 0.0	 1.74	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2941	 1	 32.54	 10.6	 0.0	 1.22	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	2942	 1	 -0.0	 -0.0	 0.0	 0.23	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	2943	 1	 88.3	 2.8	 0.0	 5.21	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2944	 1	 7.0	 1.0	 0.0	 1.54	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2945	 1	 10.21	 -3.2	 0.0	 5.15	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2946	 1	 125.1	 44.0	 0.0	 6.04	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2947	 1	 -0.0	 0.0	 0.0	 0.29	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2948	 1	 163.7	 94.1	 0.0	 18.55	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	2949	 1	 30.93	 2.8	 0.0	 2.11	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2950	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	2951	 1	 121.4	 20.2	 0.0	 16.61	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2952	 1	 -0.0	 -0.0	 0.0	 6.01	 0	    1.00000	    0.00000	 380.0	 14	    1.10000	    0.90000;
	2953	 1	 -0.0	 -0.0	 0.096544	 0.473456	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	2954	 1	 0.0	 0.0	 0.037641	 3.052359	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	2955	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 20	    1.10000	    0.90000;
	2956	 1	 -0.0	 0.0	 0.126829	 38.306912	 0	    1.00000	    0.00000	 380.0	 7	    1.10000	    0.90000;
	2957	 1	 199.86	 56.93	 0.0	 46.83	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2958	 1	 218.7	 -9.1	 0.0	 49.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	2959	 1	 -0.0	 -0.0	 0.019608	 2.610392	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2960	 1	 110.09	 53.32	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2961	 1	 -5.64	 -2.84	 0.0	 34.641229	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	2962	 1	 65.87	 31.4	 0.0	 3.46	 0	    1.00000	    0.00000	 220.0	 3	    1.20000	    0.80000;
	2963	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	2964	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 7	    1.10000	    0.90000;
	2965	 1	 3.3	 313.7	 0.705985	 162.230901	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	2966	 1	 54.26	 19.5	 0.0	 0.05	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	2967	 1	 -0.0	 -0.0	 0.117169	 2.552359	 0	    1.00000	    0.00000	 380.0	 14	    1.10000	    0.90000;
	2968	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	2969	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	2970	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 9	    1.10000	    0.90000;
	2971	 1	 -3.7	 -8.0	 0.0	 19.02	 0	    1.00000	    0.00000	 380.0	 7	    1.10000	    0.90000;
	2972	 1	 -0.0	 0.0	 0.0	 5.19	 0	    1.00000	    0.00000	 220.0	 23	    1.10000	    0.90000;
	2973	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	2974	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	2975	 1	 -0.0	 0.0	 0.0	 38.32	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	2976	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 24	    1.10000	    0.90000;
	2977	 1	 -0.0	 -0.0	 0.0	 3.95	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	2978	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	2979	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	2980	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	2981	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	2982	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	2983	 1	 0.0	 0.0	 0.0	 6.22	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	2984	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	2985	 1	 -0.0	 -0.0	 0.865147	 27.25011	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	2986	 1	 0.0	 -0.0	 0.090774	 10.830444	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	2987	 1	 529.9	 23.3	 0.0	 57.66	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	2988	 1	 10.01	 3.0	 0.0	 0.84	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	2989	 1	 12.81	 4.4	 0.0	 0.47	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2990	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 10.5	 1	    1.10000	    0.90000;
	2991	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	2992	 1	 60.67	 37.6	 0.0	 0.92	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	2993	 1	 -0.0	 0.0	 0.207683	 8.945585	 0	    1.00000	    0.00000	 380.0	 9	    1.20000	    0.80000;
	2994	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	2995	 1	 5.71	 2.0	 0.0	 1.03	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2996	 1	 11.0	 3.15	 0.0	 0.63	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	2997	 1	 53.36	 7.1	 0.0	 6.02	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	2998	 1	 -0.2	 -1.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	2999	 1	 0.0	 -0.0	 0.0	 3.61	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3000	 1	 4.0	 0.6	 0.0	 3.46	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3001	 1	 -0.19	 -3.76	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	3002	 1	 4.4	 2.2	 0.0	 1.79	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	3003	 1	 -0.0	 0.0	 0.0	 2.33	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3004	 1	 19.82	 6.0	 0.0	 1.68	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	3005	 1	 8.07	 1.23	 0.0	 3.91	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3006	 1	 -0.0	 0.0	 0.0	 1.81	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3007	 1	 92.3	 14.6	 0.0	 1.14	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3008	 1	 30.33	 11.0	 0.0	 2.29	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	3009	 1	 79.09	 18.7	 0.0	 10.8	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3010	 1	 -0.0	 0.0	 0.0	 56.686515	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	3011	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	3012	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	3013	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	3014	 1	 16.22	 4.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3015	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	3016	 1	 8.91	 8.9	 0.0	 0.58	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3017	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	3018	 1	 107.3	 14.2	 0.0	 20.23	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3019	 1	 -0.0	 0.0	 0.0	 11.63	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	3020	 1	 0.0	 -0.0	 0.0	 25.72	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3021	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	3022	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	3023	 1	 78.69	 56.7	 0.0	 10.47	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	3024	 1	 23.2	 3.3	 0.0	 3.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3025	 1	 -0.0	 -0.0	 0.0	 4.52	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	3026	 1	 137.8	 64.5	 0.0	 18.2	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	3027	 1	 4.69	 1.89	 0.0	 2.45	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3028	 1	 101.5	 -18.3	 0.0	 8.47	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3029	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	3030	 1	 -0.0	 -0.0	 0.0	 1.2	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	3031	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	3032	 1	 20.02	 6.8	 0.01945	 0.80055	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	3033	 1	 29.4	 4.2	 0.0	 5.52	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3034	 1	 -0.0	 0.0	 0.0	 7.63	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3035	 1	 129.5	 38.3	 0.0	 5.42	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3036	 1	 -0.0	 -0.0	 0.0	 0.44	 0	    1.00000	    0.00000	 220.0	 20	    1.10000	    0.90000;
	3037	 1	 126.98	 12.83	 0.0	 9.13	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	3038	 1	 130.9	 37.8	 0.0	 0.27	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	3039	 1	 6.11	 0.0	 0.0	 0.92	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3040	 1	 0.0	 -0.0	 0.0	 0.3	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3041	 1	 17.62	 5.8	 0.0	 0.48	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	3042	 1	 101.9	 24.3	 0.0	 8.53	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3043	 1	 439.0	 254.8	 0.0	 148.04	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	3044	 1	 0.0	 0.0	 0.338538	 -0.263307	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	3045	 1	 0.0	 0.0	 0.0	 116.62	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	3046	 1	 -2.23	 -1.27	 0.0	 3.64	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3047	 1	 -0.0	 0.0	 0.181549	 4.450889	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	3048	 1	 0.0	 -0.0	 0.0	 1.01	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3049	 1	 0.0	 0.0	 0.29	 13.47	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	3050	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	3051	 1	 6.01	 2.2	 0.0	 1.91	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3052	 1	 -0.0	 0.0	 0.0	 3.6	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	3053	 1	 -0.0	 0.0	 0.0	 1.12	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3054	 1	 51.96	 32.2	 0.0	 0.84	 0	    1.00000	    0.00000	 150.0	 9	    1.20000	    0.80000;
	3055	 1	 304.2	 114.1	 0.0	 26.84	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	3056	 1	 -0.0	 -0.0	 0.0	 1.02	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3057	 1	 12.21	 4.4	 0.0	 1.03	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	3058	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	3059	 1	 0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	3060	 1	 6.61	 2.4	 0.019921	 0.740079	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	3061	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	3062	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	3063	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	3064	 1	 15.82	 9.8	 0.0	 4.86	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3065	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	3066	 1	 0.0	 -0.0	 0.0	 10.34	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	3067	 1	 20.92	 7.7	 0.0	 1.21	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3068	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	3069	 1	 29.93	 9.9	 0.117792	 0.22184	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	3070	 1	 8.6	 -1.48	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	3071	 1	 120.1	 30.5	 0.0	 5.26	 0	    1.00000	    0.00000	 220.0	 17	    1.10000	    0.90000;
	3072	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	3073	 1	 -0.0	 0.0	 0.0	 1.33	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3074	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	3075	 1	 37.6	 5.4	 0.0	 2.24	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3076	 1	 114.2	 34.4	 0.0	 10.29	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3077	 1	 396.7	 62.8	 0.0	 0.0	 0	    1.00000	    0.00000	 120.0	 20	    1.10000	    0.90000;
	3078	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	3079	 1	 106.4	 24.2	 0.0	 0.11	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	3080	 1	 95.1	 35.0	 0.040461	 2.159654	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	3081	 1	 -1397.75	 -894.7	 0.416616	 123.667654	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	3082	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 10.6	 1	    1.10000	    0.90000;
	3083	 1	 171.1	 49.1	 0.058585	 15.741415	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3084	 1	 40.65	 13.2	 0.0	 1.27	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	3085	 1	 50.86	 -23.0	 0.0	 16.36	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	3086	 1	 -0.0	 -0.0	 0.0	 0.3	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3087	 1	 -15.8	 -2.8	 0.0	 7.6	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3088	 1	 -0.0	 -0.0	 0.0	 69.27	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	3089	 1	 0.0	 0.0	 0.0	 0.04	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	3090	 1	 -0.0	 -0.0	 0.0	 32.802252	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	3091	 1	 -0.0	 -0.0	 0.0	 1.29	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3092	 1	 0.0	 0.0	 0.056531	 4.133469	 0	    1.00000	    0.00000	 220.0	 18	    1.20000	    0.80000;
	3093	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	3094	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	3095	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	3096	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	3097	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	3098	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	3099	 1	 14.22	 6.3	 0.0	 0.38	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3100	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	3101	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	3102	 1	 156.5	 31.2	 0.536484	 34.842734	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	3103	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	3104	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	3105	 1	 -0.0	 0.0	 0.0	 0.18	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3106	 1	 -14.27	 -6.6	 0.0	 0.91	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	3107	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	3108	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	3109	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	3110	 1	 0.0	 -0.0	 0.0	 9.9	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	3111	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	3112	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	3113	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	3114	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	3115	 1	 -19.79	 -21.11	 0.153249	 65.355488	 0	    1.00000	    0.00000	 380.0	 3	    1.20000	    0.80000;
	3116	 1	 -0.0	 -0.0	 0.0	 5.95	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3117	 1	 -0.0	 0.0	 0.0	 23.66	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3118	 1	 55.46	 18.5	 0.0	 2.23	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	3119	 1	 0.0	 0.0	 0.0	 5.14	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	3120	 1	 7.29	 -0.73	 0.0	 0.73	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	3121	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	3122	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	3123	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 8	    1.10000	    0.90000;
	3124	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 8	    1.10000	    0.90000;
	3125	 1	 34.14	 11.4	 0.0	 0.8	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3126	 1	 297.2	 93.2	 0.0	 23.74	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	3127	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 8	    1.10000	    0.90000;
	3128	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 8	    1.10000	    0.90000;
	3129	 1	 137.3	 -2.8	 0.0	 16.39	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	3130	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 8	    1.10000	    0.90000;
	3131	 1	 29.03	 9.6	 0.0	 0.53	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	3132	 1	 213.0	 39.6	 0.0	 20.63	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	3133	 1	 -0.0	 -0.0	 0.352533	 27.156463	 0	    1.00000	    0.00000	 380.0	 11	    1.10000	    0.90000;
	3134	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	3135	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	3136	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	3137	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	3138	 1	 11.01	 3.6	 0.0	 0.84	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	3139	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	3140	 1	 -0.0	 -0.0	 0.177225	 2.972313	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	3141	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	3142	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	3143	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	3144	 1	 17.52	 10.4	 0.039249	 -0.019249	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3145	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	3146	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	3147	 1	 74.98	 26.9	 0.0	 2.96	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3148	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	3149	 1	 6.01	 4.1	 0.0	 0.19	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3150	 1	 -0.0	 -7.5	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3151	 1	 44.55	 16.1	 0.0	 1.18	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	3152	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	3153	 1	 60.07	 45.0	 0.0	 2.53	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	3154	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	3155	 1	 0.0	 0.0	 0.0	 0.3	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3156	 1	 -0.0	 0.0	 0.17315	 3.835328	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	3157	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3158	 1	 23.7	 3.4	 0.0	 2.51	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3159	 1	 -0.0	 -0.0	 0.0	 47.343052	 0	    1.00000	    0.00000	 380.0	 13	    1.10000	    0.90000;
	3160	 1	 3.9	 0.9	 0.0	 0.3	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3161	 1	 0.0	 -0.0	 0.0	 0.41	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3162	 1	 0.0	 -0.0	 0.0	 1.6	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	3163	 1	 20.32	 6.7	 0.0	 0.27	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	3164	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	3165	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	3166	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	3167	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	3168	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	3169	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	3170	 1	 0.0	 -0.0	 0.0	 2.67	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	3171	 1	 142.8	 19.5	 0.0	 10.53	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	3172	 1	 78.79	 27.4	 0.0	 2.37	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	3173	 1	 88.7	 25.5	 0.0	 3.07	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3174	 1	 128.7	 25.6	 0.0	 1.32	 0	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3175	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3176	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	3177	 1	 143.1	 18.9	 0.0	 3.42	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	3178	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 15.0	 1	    1.10000	    0.90000;
	3179	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 19.0	 1	    1.10000	    0.90000;
	3180	 1	 -0.0	 0.0	 0.0	 2.91	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3181	 1	 -0.0	 0.0	 0.0	 1.71	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3182	 1	 -0.0	 0.0	 0.0	 0.45	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3183	 1	 0.0	 -0.0	 0.148489	 25.143031	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	3184	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 10.6	 1	    1.10000	    0.90000;
	3185	 1	 -0.0	 -0.0	 0.0	 1.68	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3186	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	3187	 1	 0.0	 0.0	 0.927753	 28.525838	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	3188	 1	 63.67	 39.5	 0.0	 0.38	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3189	 1	 125.5	 22.5	 0.0	 9.17	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3190	 1	 13.9	 1.9	 0.0	 0.62	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3191	 1	 43.75	 16.7	 0.0	 2.83	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3192	 1	 10.71	 17.7	 0.0	 10.58	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	3193	 1	 0.0	 -0.0	 0.115814	 4.423488	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	3194	 1	 65.77	 27.3	 0.0	 0.49	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3195	 1	 0.0	 -0.0	 0.0	 0.57	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3196	 1	 69.08	 24.0	 0.0	 4.79	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	3197	 1	 66.87	 21.8	 0.0	 12.3	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	3198	 1	 -0.0	 -0.0	 0.0	 144.15	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	3199	 1	 0.0	 -0.0	 0.0	 2.76	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3200	 1	 55.6	 7.9	 0.0	 5.4	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3201	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	3202	 1	 -0.0	 -0.0	 0.0	 0.24	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3203	 1	 33.5	 4.8	 0.0	 6.37	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3204	 1	 47.46	 11.54	 0.0	 14.15	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3205	 1	 110.3	 28.7	 0.0	 0.65	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3206	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	3207	 1	 1.8	 0.7	 0.0	 0.22	 0	    1.00000	    0.00000	 110.0	 19	    1.20000	    0.80000;
	3208	 1	 162.9	 93.6	 0.040274	 1.169794	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	3209	 1	 -5.15	 -16.03	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	3210	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	3211	 1	 100.7	 -4.2	 0.0	 1.57	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3212	 1	 0.0	 0.01	 0.434555	 9.815977	 0	    1.00000	    0.00000	 380.0	 21	    1.20000	    0.80000;
	3213	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	3214	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	3215	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	3216	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	3217	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	3218	 1	 -0.0	 -8.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3219	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	3220	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	3221	 1	 23.03	 8.3	 0.0	 1.14	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	3222	 1	 97.0	 18.7	 0.0	 21.46	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	3223	 1	 0.0	 -0.0	 0.0	 29.88	 0	    1.00000	    0.00000	 380.0	 1	    1.20000	    0.80000;
	3224	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	3225	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	3226	 1	 -0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	3227	 1	 0.0	 0.0	 0.0	 7.75	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	3228	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	3229	 1	 305.6	 207.3	 0.0	 52.37	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	3230	 1	 0.0	 -0.0	 0.0	 20.5	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	3231	 1	 -0.0	 0.0	 0.0	 1.55	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3232	 1	 1.9	 0.7	 0.0	 0.42	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	3233	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	3234	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	3235	 1	 27.9	 4.0	 0.0	 2.16	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3236	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	3237	 1	 -0.0	 -0.0	 0.0	 0.39	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3238	 1	 0.0	 -0.0	 0.385832	 0.591127	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	3239	 1	 -0.0	 0.0	 0.197033	 22.516441	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	3240	 1	 -0.0	 0.0	 0.0	 2.59	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3241	 1	 0.0	 0.0	 0.0	 0.33	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3242	 1	 -0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	3243	 1	 73.68	 15.4	 0.0	 3.73	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	3244	 1	 -0.0	 0.0	 0.0	 26.22	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	3245	 1	 -0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	3246	 1	 141.3	 32.4	 0.0	 7.29	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3247	 1	 34.04	 21.1	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3248	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	3249	 1	 25.33	 8.9	 0.0	 5.26	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3250	 1	 91.9	 5.5	 0.0	 7.02	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3251	 1	 0.0	 0.0	 0.058997	 1.431003	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3252	 1	 -0.0	 -0.0	 0.0	 15.57	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	3253	 1	 -0.0	 -0.0	 0.0	 2.08	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3254	 1	 73.18	 22.2	 0.0	 0.32	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	3255	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	3256	 1	 11.61	 5.8	 0.0	 0.43	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	3257	 1	 30.6	 4.3	 0.0	 7.74	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3258	 1	 0.0	 0.0	 0.0	 0.75	 0	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3259	 1	 1.4	 0.5	 0.0	 0.63	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	3260	 1	 50.65	 56.5	 0.0	 6.86	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	3261	 1	 0.0	 -0.0	 0.0	 3.82	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3262	 1	 208.88	 60.8	 0.0	 6.68	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3263	 1	 -6.7	 -7.5	 0.0	 1.48	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3264	 1	 4.3	 1.4	 0.0	 1.59	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	3265	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	3266	 1	 74.68	 46.3	 0.0	 4.98	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3267	 1	 -0.0	 0.0	 0.0	 15.02	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	3268	 1	 0.0	 0.0	 0.097763	 8.512237	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3269	 1	 13.04	 7.4	 0.0	 5.33	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3270	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	3271	 1	 -0.0	 -0.0	 0.0	 1.32	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3272	 1	 71.88	 51.3	 0.0	 24.75	 0	    1.00000	    0.00000	 380.0	 16	    1.10000	    0.90000;
	3273	 1	 15.02	 5.0	 0.0	 0.39	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	3274	 1	 30.83	 4.4	 0.0	 0.46	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	3275	 1	 93.2	 13.6	 0.0	 14.9	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3276	 1	 162.7	 23.2	 0.0	 1.7	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3277	 1	 402.1	 110.2	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	3278	 1	 -0.0	 0.0	 0.0	 13.21	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	3279	 1	 82.39	 12.3	 0.0	 9.02	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3280	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 22	    1.10000	    0.90000;
	3281	 1	 628.5	 91.8	 0.0	 19.83	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	3282	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	3283	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	3284	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	3285	 1	 -0.0	 0.0	 0.0	 7.94	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3286	 1	 88.7	 -0.1	 0.0	 2.83	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3287	 1	 21.22	 8.3	 0.0	 19.1	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	3288	 1	 -27.25	 -9.38	 0.0	 18.78	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	3289	 1	 45.75	 3.3	 0.0	 0.37	 0	    1.00000	    0.00000	 110.0	 3	    1.10000	    0.90000;
	3290	 1	 32.04	 6.6	 0.0	 0.44	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3291	 1	 -1.8	 -12.01	 0.290423	 159.398781	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	3292	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	3293	 1	 8.41	 3.0	 0.0	 1.2	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3294	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 15.75	 1	    1.10000	    0.90000;
	3295	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3296	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	3297	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	3298	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	3299	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	3300	 1	 13.9	 1.9	 0.0	 0.03	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3301	 1	 55.46	 16.9	 0.0	 1.92	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3302	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	3303	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	3304	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	3305	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	3306	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	3307	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	3308	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	3309	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	3310	 1	 39.64	 20.9	 0.0	 0.65	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3311	 1	 -0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	3312	 1	 8.41	 2.8	 0.0	 0.67	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	3313	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3314	 1	 0.0	 -0.0	 0.0	 3.3	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3315	 1	 0.0	 -0.0	 0.0	 4.16	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3316	 1	 -0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	3317	 1	 0.0	 0.0	 0.0	 101.48	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	3318	 1	 24.23	 6.6	 0.0	 1.05	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	3319	 1	 114.5	 25.2	 0.0	 17.57	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3320	 1	 0.0	 -0.0	 0.0	 0.4	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3321	 1	 66.77	 19.8	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 24	    1.10000	    0.90000;
	3322	 1	 -0.0	 -0.0	 0.0	 28.53	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	3323	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	3324	 1	 -0.2	 -1.33	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	3325	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	3326	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	3327	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	3328	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	3329	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	3330	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	3331	 1	 0.0	 -0.0	 0.0	 0.5	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	3332	 1	 27.93	 6.4	 0.0	 0.89	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3333	 1	 0.0	 -0.0	 0.0	 0.35	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3334	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	3335	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	3336	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	3337	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	3338	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	3339	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	3340	 1	 0.0	 -0.0	 0.0	 0.76	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3341	 1	 103.4	 27.0	 0.0	 1.41	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3342	 1	 12.71	 4.9	 0.0	 0.83	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3343	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	3344	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 8	    1.10000	    0.90000;
	3345	 1	 50.36	 -36.2	 0.0	 1.25	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3346	 1	 0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	3347	 1	 24.33	 15.0	 0.0	 0.31	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3348	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	3349	 1	 96.91	 13.9	 0.0	 3.98	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3350	 1	 -0.0	 -0.0	 0.0	 3.28	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3351	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	3352	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	3353	 1	 -0.0	 -0.0	 0.0	 12.77	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	3354	 1	 33.04	 5.6	 0.0	 14.55	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3355	 1	 0.0	 -0.0	 0.0	 426.57	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	3356	 1	 -0.0	 0.0	 0.0	 2.92	 0	    1.00000	    0.00000	 220.0	 21	    1.10000	    0.90000;
	3357	 1	 53.3	 7.6	 0.0	 10.7	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3358	 1	 -0.0	 -0.0	 0.0	 0.5	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3359	 1	 208.24	 11.9	 0.0	 24.11	 0	    1.00000	    0.00000	 220.0	 2	    1.10000	    0.90000;
	3360	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	3361	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	3362	 1	 118.4	 7.1	 0.0	 11.11	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3363	 1	 -0.0	 0.0	 0.0	 7.03	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	3364	 1	 84.89	 6.1	 0.058904	 3.850913	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3365	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	3366	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	3367	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	3368	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	3369	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	3370	 1	 179.4	 25.6	 0.0	 0.42	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3371	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	3372	 1	 54.46	 11.9	 0.0	 3.93	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3373	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3374	 1	 225.9	 50.0	 0.03945	 54.16055	 0	    1.00000	    0.00000	 380.0	 14	    1.10000	    0.90000;
	3375	 1	 52.96	 8.2	 0.0	 5.68	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3376	 1	 -0.0	 -0.0	 0.040027	 17.005662	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	3377	 1	 215.5	 31.3	 0.0	 14.23	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3378	 1	 16.9	 3.85	 0.0	 25.09	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3379	 1	 -0.0	 0.0	 0.0	 0.81	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3380	 1	 -0.0	 -0.0	 0.471697	 3.616573	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	3381	 1	 0.0	 -0.0	 0.0	 5.71	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3382	 1	 -0.0	 -0.0	 0.0	 2.59	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	3383	 1	 37.94	 15.4	 0.0	 117.402115	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	3384	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	3385	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 10.0	 1	    1.10000	    0.90000;
	3386	 1	 0.0	 0.0	 0.0	 4.24	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	3387	 1	 5.5	 0.8	 0.0	 1.57	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3388	 1	 -15.92	 5.2	 0.0	 0.3	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3389	 1	 178.5	 65.8	 0.0	 93.42	 0	    1.00000	    0.00000	 380.0	 20	    1.10000	    0.90000;
	3390	 1	 0.0	 -0.0	 0.113993	 4.365006	 0	    1.00000	    0.00000	 220.0	 19	    1.10000	    0.90000;
	3391	 1	 110.7	 26.9	 0.097905	 10.552095	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3392	 1	 0.0	 -0.0	 0.0	 2.53	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3393	 1	 -0.0	 -0.0	 0.0	 8.48	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	3394	 1	 0.0	 -0.0	 0.0	 28.65	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	3395	 1	 -0.0	 -0.0	 0.0	 14.525048	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	3396	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	3397	 1	 153.3	 21.8	 0.0	 10.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3398	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3399	 1	 131.1	 18.7	 0.0	 6.53	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3400	 1	 17.12	 3.8	 0.0	 1.0	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3401	 1	 101.7	 17.6	 0.0	 13.14	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3402	 1	 -41.25	 13.5	 0.0	 0.48	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3403	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	3404	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	3405	 1	 1.4	 0.5	 0.0	 0.35	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	3406	 1	 0.0	 -0.0	 0.0	 2.9	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3407	 1	 -0.0	 0.0	 0.0	 5.43	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3408	 1	 32.94	 13.0	 0.0	 4.04	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	3409	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	3410	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	3411	 1	 52.26	 44.2	 0.181549	 9.190889	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	3412	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	3413	 1	 0.0	 0.0	 0.0	 9.85	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	3414	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	3415	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	3416	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	3417	 1	 122.1	 16.7	 0.0	 27.05	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	3418	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	3419	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	3420	 1	 24.13	 8.7	 0.083411	 0.134843	 0	    1.00000	    0.00000	 220.0	 19	    1.10000	    0.90000;
	3421	 1	 0.1	 1.0	 0.0	 0.06	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	3422	 1	 57.56	 24.0	 0.0	 1.01	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	3423	 1	 -0.0	 0.0	 0.0	 4.02	 0	    1.00000	    0.00000	 220.0	 22	    1.10000	    0.90000;
	3424	 1	 55.54	 15.06	 0.0	 6.28	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3425	 1	 0.0	 0.0	 0.0	 0.79	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	3426	 1	 20.12	 12.5	 0.0	 2.83	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3427	 1	 173.7	 23.0	 0.0	 18.4	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	3428	 1	 20.82	 -0.0	 0.0	 0.13	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3429	 1	 200.5	 85.0	 0.454272	 18.990368	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	3430	 1	 80.29	 28.4	 0.0	 8.67	 0	    1.00000	    0.00000	 220.0	 20	    1.10000	    0.90000;
	3431	 1	 72.4	 10.3	 0.0	 8.67	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3432	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	3433	 1	 0.0	 0.0	 0.0	 0.52	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3434	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	3435	 1	 3.1	 -5.2	 0.0	 0.86	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3436	 1	 69.38	 43.0	 0.0	 3.22	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3437	 1	 0.0	 -0.0	 0.0	 3.99	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3438	 1	 -0.0	 0.0	 0.0	 0.16	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3439	 1	 0.0	 0.0	 0.094628	 0.435372	 0	    1.00000	    0.00000	 220.0	 21	    1.10000	    0.90000;
	3440	 1	 27.23	 8.9	 0.0	 0.72	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	3441	 1	 37.24	 5.3	 0.0	 14.78	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3442	 1	 0.0	 -0.0	 0.0	 0.96	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3443	 1	 -0.0	 -0.0	 0.0	 3.79	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3444	 1	 0.0	 0.0	 0.0	 1.69	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3445	 1	 117.13	 52.4	 0.0	 7.51	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	3446	 1	 30.6	 4.3	 0.0	 2.82	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3447	 1	 64.8	 99.1	 0.0	 4.28	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	3448	 1	 -0.0	 0.0	 0.0	 91.163618	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	3449	 1	 -0.0	 -0.0	 0.0	 9.14	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3450	 1	 0.0	 -0.0	 0.237418	 13.951937	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3451	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	3452	 1	 93.9	 51.9	 0.120858	 3.729285	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	3453	 1	 30.6	 4.3	 0.0	 7.3	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3454	 1	 5.51	 2.0	 0.0	 1.3	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	3455	 1	 253.4	 57.4	 0.039029	 5.000971	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3456	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	3457	 1	 14.32	 5.6	 0.0	 88.82	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	3458	 1	 -0.54	 -1.0	 0.0	 0.81	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	3459	 1	 14.0	 1.9	 0.0	 1.33	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3460	 1	 -0.0	 0.0	 0.0	 7.15	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	3461	 1	 70.58	 60.4	 0.277205	 6.192096	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3462	 1	 3.4	 123.8	 0.0	 64.94	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	3463	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	3464	 1	 262.1	 13.9	 0.0	 10.23	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	3465	 1	 -0.0	 0.0	 0.379958	 52.33965	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	3466	 1	 373.8	 55.6	 0.039614	 6.550386	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3467	 1	 10.51	 1.3	 0.0	 0.18	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3468	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	3469	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	3470	 1	 523.3	 137.2	 0.0	 65.61	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	3471	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 20	    1.10000	    0.90000;
	3472	 1	 44.55	 16.8	 0.0	 2.31	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3473	 1	 197.4	 52.4	 0.057873	 1.402127	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3474	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 7	    1.10000	    0.90000;
	3475	 1	 119.4	 23.6	 0.15878	 12.06122	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3476	 1	 -0.0	 0.0	 0.27075	 102.13435	 0	    1.00000	    0.00000	 380.0	 18	    1.20000	    0.80000;
	3477	 1	 0.0	 -0.0	 0.0	 0.47	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	3478	 1	 73.18	 23.4	 0.0	 0.17	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	3479	 1	 -0.0	 -0.0	 0.0	 50.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	3480	 1	 68.38	 6.2	 0.039608	 2.410392	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3481	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 17	    1.10000	    0.90000;
	3482	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 24	    1.10000	    0.90000;
	3483	 1	 0.0	 0.0	 0.0	 0.57	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3484	 1	 291.2	 35.4	 0.0	 21.87	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3485	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	3486	 1	 0.0	 0.0	 0.0	 2.31	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	3487	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	3488	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 10.6	 1	    1.10000	    0.90000;
	3489	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	3490	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	3491	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	3492	 1	 0.0	 -8.6	 0.0	 297.94	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	3493	 1	 -0.0	 0.0	 0.0	 0.64	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3494	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	3495	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	3496	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	3497	 1	 -0.0	 -0.0	 0.0	 8.66	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	3498	 1	 0.0	 0.0	 0.0	 10.21	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	3499	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 9.0	 1	    1.10000	    0.90000;
	3500	 1	 -0.0	 0.0	 0.254277	 1.046433	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	3501	 1	 2.43	 0.49	 0.0	 0.17	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3502	 1	 52.86	 13.0	 0.0	 6.04	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3503	 1	 45.6	 142.0	 0.0	 3.17	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	3504	 1	 0.0	 0.0	 0.0	 18.25	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	3505	 1	 -0.0	 -0.0	 0.0	 0.19	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3506	 1	 -0.0	 0.0	 1.106166	 14.878817	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	3507	 1	 69.7	 9.9	 0.0	 0.12	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3508	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	3509	 1	 34.24	 16.5	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 8	    1.10000	    0.90000;
	3510	 1	 301.9	 -103.2	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 2	    1.20000	    0.80000;
	3511	 1	 20.3	 3.7	 0.0	 0.06	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3512	 1	 -0.0	 -0.0	 0.0	 3.62	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3513	 1	 -0.0	 -0.0	 0.0	 6.96	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3514	 1	 98.36	 -0.47	 0.0	 5.44	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	3515	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	3516	 1	 0.0	 0.0	 0.0	 1.55	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3517	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	3518	 1	 488.7	 118.4	 0.0	 75.45	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	3519	 1	 262.5	 18.9	 0.0	 39.85	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	3520	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	3521	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	3522	 1	 30.74	 9.6	 0.0	 2.75	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3523	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	3524	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	3525	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	3526	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	3527	 1	 179.6	 3.0	 0.059781	 6.140219	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3528	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	3529	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	3530	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	3531	 1	 -0.0	 0.0	 0.0	 145.98	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	3532	 1	 6.81	 23.8	 0.040939	 2.299061	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	3533	 1	 3.3	 1.9	 0.0	 0.25	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	3534	 1	 -5.22	 -3.77	 0.0	 0.91	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3535	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	3536	 1	 0.0	 0.0	 0.0	 32.55	 0	    1.00000	    0.00000	 380.0	 3	    1.20000	    0.80000;
	3537	 1	 1.5	 0.4	 0.0	 0.89	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3538	 1	 314.65	 87.51	 0.0	 42.61	 0	    1.00000	    0.00000	 380.0	 14	    1.10000	    0.90000;
	3539	 1	 -0.0	 0.5	 0.0	 1.82	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3540	 1	 -0.0	 0.0	 0.0	 11.65	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3541	 1	 -0.0	 0.0	 0.039385	 0.140615	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3542	 1	 0.0	 -0.0	 0.0	 1.12	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3543	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	3544	 1	 0.0	 -0.0	 0.0	 1.31	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3545	 1	 103.5	 21.7	 0.0	 8.88	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3546	 1	 76.58	 14.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	3547	 1	 -0.0	 -0.0	 0.0	 8.94	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3548	 1	 40.44	 12.8	 0.0	 1.04	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	3549	 1	 35.04	 16.0	 0.0	 12.14	 0	    1.00000	    0.00000	 220.0	 23	    1.10000	    0.90000;
	3550	 1	 -0.0	 -0.0	 0.0	 0.21	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3551	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	3552	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3553	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	3554	 1	 4.2	 0.6	 0.0	 4.73	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3555	 1	 50.96	 6.8	 0.0	 9.13	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	3556	 1	 -2.65	 -1.17	 0.0	 65.704714	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	3557	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	3558	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	3559	 1	 -0.0	 -0.0	 0.039181	 2.830819	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3560	 1	 0.0	 -0.0	 0.0	 11.69	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3561	 1	 -0.21	 -1.98	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	3562	 1	 26.6	 3.8	 0.0	 6.43	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3563	 1	 0.0	 0.0	 0.0	 2.43	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	3564	 1	 2.0	 0.5	 0.0	 1.13	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3565	 1	 33.5	 4.8	 0.0	 1.52	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3566	 1	 79.09	 -36.9	 0.0	 4.58	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	3567	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	3568	 1	 0.0	 0.0	 0.0	 13.39	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	3569	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	3570	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	3571	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	3572	 1	 0.0	 -0.0	 0.176084	 1.383916	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3573	 1	 42.2	 6.0	 0.0	 5.22	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3574	 1	 48.8	 6.9	 0.0	 3.23	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3575	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	3576	 1	 74.18	 22.6	 0.0	 0.31	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	3577	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 7	    1.10000	    0.90000;
	3578	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	3579	 1	 39.34	 -10.7	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	3580	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	3581	 1	 -0.0	 0.0	 0.0	 59.04	 0	    1.00000	    0.00000	 380.0	 19	    1.20000	    0.80000;
	3582	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	3583	 1	 127.2	 40.8	 0.0	 0.2	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3584	 1	 0.0	 0.0	 0.0	 9.36	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	3585	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	3586	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	3587	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	3588	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	3589	 1	 36.34	 3.3	 0.0	 2.16	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3590	 1	 65.07	 40.3	 0.0	 5.54	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3591	 1	 0.0	 0.0	 0.038998	 2.651002	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	3592	 1	 0.0	 -0.0	 0.0	 84.7	 0	    1.00000	    0.00000	 380.0	 22	    1.10000	    0.90000;
	3593	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.5	 1	    1.10000	    0.90000;
	3594	 1	 11.91	 3.8	 0.0	 0.46	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3595	 1	 119.2	 32.1	 0.0	 4.14	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3596	 1	 0.0	 0.0	 0.0	 18.62	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	3597	 1	 48.75	 16.2	 0.0	 0.77	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	3598	 1	 -14.9	 -4.81	 0.0	 0.45	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3599	 1	 0.0	 -0.0	 0.0	 36.17	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	3600	 1	 41.8	 5.9	 0.0	 4.74	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3601	 1	 133.7	 10.4	 0.039058	 3.540942	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	3602	 1	 115.87	 29.41	 0.0	 7.92	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3603	 1	 174.1	 -519.7	 0.0	 54.02	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	3604	 1	 0.0	 0.0	 0.0	 18.83	 0	    1.00000	    0.00000	 380.0	 12	    1.10000	    0.90000;
	3605	 1	 0.0	 -0.0	 0.0	 29.79	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	3606	 1	 18.2	 2.6	 0.0	 1.75	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3607	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 22	    1.10000	    0.90000;
	3608	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	3609	 1	 180.4	 71.6	 0.0	 81.042938	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	3610	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	3611	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	3612	 1	 -0.0	 -0.0	 0.019731	 0.480269	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3613	 1	 0.0	 0.0	 0.0	 6.66	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	3614	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	3615	 1	 42.25	 12.2	 0.149786	 10.010142	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3616	 1	 -5.29	 -1.91	 0.0	 42.657632	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	3617	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 20	    1.10000	    0.90000;
	3618	 1	 -0.0	 0.0	 0.058188	 3.780311	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	3619	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	3620	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	3621	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	3622	 1	 -0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	3623	 1	 33.5	 4.8	 0.0	 3.47	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3624	 1	 11.2	 1.6	 0.0	 3.05	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3625	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	3626	 1	 18.32	 14.1	 0.0	 3.12	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3627	 1	 238.45	 46.86	 0.0	 125.534496	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	3628	 1	 59.77	 16.7	 0.0	 0.64	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3629	 1	 -10.41	 -3.3	 0.0	 4.11	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3630	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3631	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	3632	 1	 77.39	 20.7	 0.0	 0.46	 0	    1.00000	    0.00000	 110.0	 3	    1.10000	    0.90000;
	3633	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	3634	 1	 1.3	 0.0	 0.0	 0.58	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3635	 1	 -0.0	 -0.0	 0.108686	 4.920557	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	3636	 1	 107.0	 43.0	 0.0	 8.34	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	3637	 1	 0.0	 0.0	 0.28908	 8.031674	 0	    1.00000	    0.00000	 220.0	 18	    1.20000	    0.80000;
	3638	 1	 51.56	 2.1	 0.0	 0.18	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3639	 1	 15.12	 9.4	 0.0	 0.69	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3640	 1	 70.28	 16.2	 0.0	 0.12	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3641	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	3642	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	3643	 1	 118.8	 39.5	 0.0	 2.61	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3644	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	3645	 1	 24.33	 15.0	 0.0	 2.11	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3646	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	3647	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	3648	 1	 278.35	 90.4	 0.0	 12.1	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	3649	 1	 0.0	 0.0	 0.078072	 -0.078072	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3650	 1	 0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	3651	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	3652	 1	 72.68	 45.0	 0.0	 8.25	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3653	 1	 38.44	 13.2	 0.0	 1.73	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	3654	 1	 27.33	 5.0	 0.0	 0.15	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3655	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	3656	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	3657	 1	 0.0	 0.0	 0.0	 10.78	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	3658	 1	 0.0	 -0.0	 0.0	 0.23	 0	    1.00000	    0.00000	 110.0	 23	    1.10000	    0.90000;
	3659	 1	 -0.6	 -0.5	 0.039759	 1.07012	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	3660	 1	 -4.88	 5.51	 0.0	 1.38	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3661	 1	 -0.0	 -0.0	 0.0	 3.86	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3662	 1	 0.0	 0.0	 0.059074	 -0.019074	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3663	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	3664	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	3665	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	3666	 1	 28.53	 11.3	 0.0	 6.81	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	3667	 1	 25.77	 -36.0	 0.0	 9.85	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	3668	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	3669	 1	 69.5	 9.9	 0.0	 98.63	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	3670	 1	 0.0	 -0.0	 0.0	 2.75	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	3671	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	3672	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	3673	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	3674	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	3675	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	3676	 1	 17.02	 5.9	 0.0	 0.52	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	3677	 1	 6.51	 1.4	 0.0	 0.54	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3678	 1	 1.8	 0.7	 0.0	 0.59	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	3679	 1	 -88.6	 -24.2	 0.0	 5.66	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	3680	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	3681	 1	 7.71	 3.3	 0.0	 0.56	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	3682	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 6.3	 1	    1.10000	    0.90000;
	3683	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	3684	 1	 0.0	 -0.0	 0.0	 0.93	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3685	 1	 -0.0	 -0.0	 0.0	 1.27	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3686	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	3687	 1	 0.0	 -0.0	 0.0	 68.93	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	3688	 1	 25.43	 7.1	 0.0	 0.22	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3689	 1	 78.59	 21.4	 0.10048	 1.61952	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	3690	 1	 42.25	 10.6	 0.019696	 23.820304	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3691	 1	 -28.96	 -8.62	 0.0	 3.08	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	3692	 1	 0.0	 0.0	 0.0	 1.16	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3693	 1	 0.0	 0.0	 0.336549	 -0.261761	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	3694	 1	 152.18	 23.99	 0.0	 14.75	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	3695	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	3696	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	3697	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	3698	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	3699	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	3700	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	3701	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	3702	 1	 62.97	 17.4	 0.0	 0.3	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3703	 1	 27.05	 22.7	 0.0	 14.74	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3704	 1	 0.0	 0.0	 0.0	 87.06	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	3705	 1	 -0.0	 0.0	 0.0	 -0.3	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	3706	 1	 34.34	 12.2	 0.0	 0.34	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	3707	 1	 9.51	 3.1	 0.0	 0.52	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	3708	 1	 -0.0	 -0.0	 0.0	 1.61	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3709	 1	 -15.72	 5.2	 0.0	 1.02	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3710	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	3711	 1	 2.3	 0.8	 0.0	 0.59	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	3712	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	3713	 1	 13.9	 1.9	 0.0	 6.37	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3714	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	3715	 1	 0.0	 -0.0	 0.1083	 35.537525	 0	    1.00000	    0.00000	 380.0	 21	    1.20000	    0.80000;
	3716	 1	 -0.0	 -0.0	 0.0	 0.36	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3717	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	3718	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	3719	 1	 39.04	 24.2	 0.0	 13.22	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3720	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	3721	 1	 235.1	 54.6	 0.020343	 41.409657	 0	    1.00000	    0.00000	 220.0	 14	    1.10000	    0.90000;
	3722	 1	 0.0	 -0.0	 0.356558	 0.802869	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	3723	 1	 -0.0	 -0.0	 0.0	 0.98	 0	    1.00000	    0.00000	 220.0	 14	    1.10000	    0.90000;
	3724	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	3725	 1	 253.77	 84.6	 0.0	 20.71	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3726	 1	 28.13	 14.2	 0.0	 0.49	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3727	 1	 -9.51	 3.1	 0.0	 0.83	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3728	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	3729	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	3730	 1	 -0.0	 -0.0	 0.0	 68.01	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	3731	 1	 -0.0	 0.0	 0.039158	 1.040842	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	3732	 1	 0.0	 -0.0	 0.690439	 2.503402	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	3733	 1	 -0.0	 0.0	 0.0	 2.08	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3734	 1	 14.72	 5.4	 0.0	 0.72	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3735	 1	 25.63	 12.7	 0.0	 8.42	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3736	 1	 48.8	 6.9	 0.0	 9.44	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3737	 1	 16.32	 3.0	 0.078645	 0.171355	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3738	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	3739	 1	 0.0	 0.0	 0.0	 3.86	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3740	 1	 -23.13	 -8.4	 0.0	 1.01	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	3741	 1	 0.0	 -0.0	 0.0	 5.09	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3742	 1	 187.19	 1.8	 0.0	 20.47	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	3743	 1	 115.3	 -8.8	 0.0	 16.22	 0	    1.00000	    0.00000	 220.0	 3	    1.20000	    0.80000;
	3744	 1	 -0.0	 0.0	 0.176135	 2.543221	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	3745	 1	 -0.0	 0.0	 0.0	 11.54	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	3746	 1	 226.8	 53.2	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	3747	 1	 14.92	 4.4	 0.0	 1.32	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3748	 1	 499.8	 110.3	 0.0	 4.21	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	3749	 1	 -0.0	 -0.0	 0.0	 29.89	 0	    1.00000	    0.00000	 150.0	 9	    1.20000	    0.80000;
	3750	 1	 -0.0	 -0.0	 0.0	 31.53	 0	    1.00000	    0.00000	 220.0	 12	    1.10000	    0.90000;
	3751	 1	 0.0	 0.0	 0.0	 7.61	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	3752	 1	 -0.0	 -0.0	 0.0	 23.88	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	3753	 1	 -0.0	 0.0	 0.0	 1.46	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	3754	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	3755	 1	 14.74	 14.7	 0.0	 7.86	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3756	 1	 69.7	 9.9	 0.0	 2.89	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3757	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	3758	 1	 -0.0	 0.0	 0.0	 1.01	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	3759	 1	 0.0	 0.0	 0.118268	 1.771732	 0	    1.00000	    0.00000	 220.0	 12	    1.10000	    0.90000;
	3760	 1	 112.1	 16.0	 0.0	 0.89	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3761	 1	 0.0	 0.0	 0.0	 6.91	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	3762	 1	 64.4	 9.1	 0.0	 1.61	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3763	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	3764	 1	 -0.0	 -0.0	 0.058857	 2.061143	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	3765	 1	 9.7	 1.4	 0.0	 2.74	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3766	 1	 10.61	 3.5	 0.0	 1.61	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	3767	 1	 5.51	 2.0	 0.0	 0.8	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	3768	 1	 0.0	 -0.0	 1.107803	 9.437513	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	3769	 1	 -0.0	 -0.0	 0.0	 1.39	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3770	 1	 203.1	 65.2	 0.0	 0.64	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3771	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	3772	 1	 166.7	 87.6	 0.0	 60.34	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	3773	 1	 29.93	 -4.2	 0.0	 1.47	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	3774	 1	 15.12	 5.4	 0.0	 0.63	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	3775	 1	 655.8	 72.8	 0.0	 10.76	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	3776	 1	 29.33	 9.6	 0.0	 0.6	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	3777	 1	 -0.0	 0.0	 0.0	 44.86	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	3778	 1	 42.95	 26.6	 0.0	 3.89	 0	    1.00000	    0.00000	 150.0	 9	    1.20000	    0.80000;
	3779	 1	 98.3	 25.9	 0.0	 3.37	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	3780	 1	 33.04	 12.1	 0.0	 0.55	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	3781	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	3782	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	3783	 1	 45.05	 -4.5	 0.0	 1.57	 0	    1.00000	    0.00000	 110.0	 23	    1.10000	    0.90000;
	3784	 1	 37.6	 5.4	 0.0	 4.56	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3785	 1	 -0.0	 0.0	 0.0	 1.72	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3786	 1	 87.8	 492.1	 1.132565	 159.277787	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	3787	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	3788	 1	 0.0	 0.0	 0.0	 6.12	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3789	 1	 -0.0	 0.0	 0.0	 0.19	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3790	 1	 37.94	 7.5	 0.0	 11.89	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3791	 1	 123.1	 3.9	 0.0	 59.08	 0	    1.00000	    0.00000	 380.0	 16	    1.10000	    0.90000;
	3792	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	3793	 1	 70.18	 30.5	 0.0	 0.48	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	3794	 1	 46.65	 15.1	 0.0	 9.79	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	3795	 1	 0.0	 0.0	 0.168574	 70.609522	 0	    1.00000	    0.00000	 380.0	 22	    1.20000	    0.80000;
	3796	 1	 0.0	 -0.0	 0.079037	 0.070722	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	3797	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 1	    1.10000	    0.90000;
	3798	 1	 -0.0	 -0.0	 0.0	 0.39	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3799	 1	 0.2	 0.2	 0.0	 0.3	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	3800	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	3801	 1	 32.24	 4.8	 0.0	 0.85	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3802	 1	 71.47	 24.0	 0.058852	 26.531148	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3803	 1	 207.1	 50.4	 0.0	 4.93	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3804	 1	 0.0	 -0.0	 0.0	 1.38	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	3805	 1	 -0.72	 0.0	 0.0	 69.582294	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	3806	 1	 0.0	 0.0	 0.0	 1.28	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	3807	 1	 -10.81	 35.4	 0.198284	 15.121287	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3808	 1	 0.0	 -0.0	 0.0	 64.39	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	3809	 1	 -0.0	 -0.0	 0.118987	 1.05076	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	3810	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	3811	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	3812	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	3813	 1	 62.67	 7.7	 0.039244	 5.490567	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	3814	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	3815	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	3816	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	3817	 1	 150.0	 104.3	 0.0	 9.21	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	3818	 1	 7.21	 4.4	 0.236348	 9.252891	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3819	 1	 -0.0	 0.0	 0.0	 2.73	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	3820	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	3821	 1	 30.6	 4.3	 0.0	 8.67	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3822	 1	 70.68	 10.7	 0.0	 1.24	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3823	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	3824	 1	 223.5	 48.0	 0.0	 12.74	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	3825	 1	 20.92	 1.1	 0.0	 1.18	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	3826	 1	 16.82	 5.5	 0.0	 0.11	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	3827	 1	 303.8	 85.4	 0.0	 3.63	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	3828	 1	 13.21	 4.4	 0.0	 1.17	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	3829	 1	 -0.0	 0.0	 0.0	 0.12	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3830	 1	 0.0	 0.0	 0.0	 11.28	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	3831	 1	 295.8	 90.9	 0.0593	 5.9207	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3832	 1	 123.24	 23.65	 0.0	 6.44	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3833	 1	 18.72	 6.6	 0.0	 0.51	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	3834	 1	 0.0	 -0.0	 0.252685	 32.19909	 0	    1.00000	    0.00000	 220.0	 19	    1.10000	    0.90000;
	3835	 1	 10.61	 3.8	 0.0	 0.96	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	3836	 1	 27.93	 10.1	 0.0	 0.44	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	3837	 1	 -0.0	 -0.0	 0.0	 100.092366	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	3838	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	3839	 1	 -0.0	 0.0	 0.0	 29.87	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	3840	 1	 0.0	 -0.0	 0.0	 0.47	 0	    1.00000	    0.00000	 220.0	 12	    1.10000	    0.90000;
	3841	 1	 -0.0	 0.0	 0.0	 23.22	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	3842	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 6.3	 1	    1.10000	    0.90000;
	3843	 1	 394.9	 45.9	 0.0	 19.569841	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	3844	 1	 -0.0	 -0.0	 0.118846	 3.070866	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	3845	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	3846	 1	 107.4	 37.3	 0.118459	 11.111541	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3847	 1	 2.0	 1.0	 0.0	 0.17	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	3848	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 10.6	 1	    1.10000	    0.90000;
	3849	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3850	 1	 -0.0	 -0.0	 0.0	 0.45	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3851	 1	 -0.0	 0.0	 0.0	 0.85	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3852	 1	 -5.89	 -3.59	 0.0	 0.51	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3853	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	3854	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 9	    1.10000	    0.90000;
	3855	 1	 149.6	 21.3	 0.0	 2.09	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3856	 1	 681.5	 57.7	 0.0	 66.36	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	3857	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	3858	 1	 -0.0	 -0.0	 0.0	 0.24	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3859	 1	 0.0	 0.0	 0.0	 0.06	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3860	 1	 -0.0	 -1.2	 0.0	 0.41	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	3861	 1	 83.6	 11.9	 0.0	 3.51	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3862	 1	 0.0	 -0.0	 0.0	 3.08	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	3863	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3864	 1	 149.9	 -0.0	 0.0	 28.38	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	3865	 1	 151.7	 27.6	 0.0	 6.49	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3866	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	3867	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	3868	 1	 -0.2	 -4.97	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	3869	 1	 22.32	 4.0	 0.0	 0.45	 0	    1.00000	    0.00000	 110.0	 3	    1.10000	    0.90000;
	3870	 1	 117.4	 12.1	 0.0	 1.14	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	3871	 1	 118.0	 37.8	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3872	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 6.3	 1	    1.10000	    0.90000;
	3873	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3874	 1	 47.75	 18.8	 0.0	 4.42	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	3875	 1	 189.7	 51.99	 0.0	 30.21	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	3876	 1	 349.6	 96.7	 0.950871	 42.896884	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	3877	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	3878	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	3879	 1	 96.5	 -43.0	 0.0	 0.91	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	3880	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	3881	 1	 104.8	 22.0	 0.0	 6.99	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	3882	 1	 -0.0	 0.0	 0.0	 0.27	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	3883	 1	 -0.0	 8.4	 0.0	 12.47	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3884	 1	 90.5	 27.8	 0.0	 7.85	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	3885	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	3886	 1	 -0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	3887	 1	 32.04	 11.0	 0.0	 0.57	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	3888	 1	 48.8	 6.9	 0.0	 5.48	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3889	 1	 -0.0	 -0.0	 0.098631	 1.841369	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3890	 1	 13.02	 14.2	 0.0	 15.78	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	3891	 1	 0.0	 0.0	 0.0	 10.022192	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	3892	 1	 -0.0	 0.0	 0.0	 56.39	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	3893	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	3894	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 6.3	 1	    1.10000	    0.90000;
	3895	 1	 151.2	 81.3	 0.0	 50.19	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	3896	 1	 43.35	 26.9	 0.078763	 7.571237	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3897	 1	 -0.0	 -0.0	 0.0	 4.68	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	3898	 1	 32.54	 11.7	 0.0	 1.02	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	3899	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	3900	 1	 -0.13	 -1.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 8	    1.10000	    0.90000;
	3901	 1	 26.63	 -1.3	 0.058336	 1.721664	 0	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	3902	 1	 0.0	 -0.0	 0.0	 30.05	 0	    1.00000	    0.00000	 220.0	 21	    1.10000	    0.90000;
	3903	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	3904	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	3905	 1	 0.1	 152.7	 0.0	 233.41	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	3906	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	3907	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	3908	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	3909	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	3910	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	3911	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	3912	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	3913	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	3914	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	3915	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	3916	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	3917	 1	 85.59	 20.72	 0.0	 142.79	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	3918	 1	 36.19	 10.75	 0.0	 0.58	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	3919	 1	 -61.67	 -0.9	 0.0	 12.33	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	3920	 1	 29.5	 4.3	 0.0	 21.5	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3921	 1	 -0.0	 -0.0	 0.173354	 13.795539	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	3922	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 20	    1.10000	    0.90000;
	3923	 1	 -0.0	 -0.0	 0.12635	 9.466325	 0	    1.00000	    0.00000	 380.0	 21	    1.20000	    0.80000;
	3924	 1	 -0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3925	 1	 -0.0	 -0.0	 0.0	 4.52	 0	    1.00000	    0.00000	 220.0	 12	    1.10000	    0.90000;
	3926	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 15.75	 1	    1.10000	    0.90000;
	3927	 1	 0.0	 -0.0	 0.0	 0.6	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3928	 1	 36.24	 5.7	 0.0	 15.06	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3929	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	3930	 1	 148.5	 21.2	 0.0	 1.26	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3931	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3932	 1	 0.0	 0.0	 0.038726	 11.471274	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	3933	 1	 -9.82	 -3.4	 0.0	 0.21	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3934	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	3935	 1	 0.0	 0.0	 0.0	 56.27	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	3936	 1	 27.9	 4.0	 0.0	 2.58	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3937	 1	 -11.77	 -3.81	 0.0	 0.23	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3938	 1	 65.47	 26.7	 0.0	 18.6	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	3939	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 15.75	 1	    1.10000	    0.90000;
	3940	 1	 55.56	 26.5	 0.0	 1.09	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3941	 1	 118.4	 16.9	 0.0	 41.52	 0	    1.00000	    0.00000	 154.0	 1	    1.20000	    0.80000;
	3942	 1	 34.54	 8.6	 0.0	 5.05	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3943	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	3944	 1	 12.21	 1.0	 0.0	 0.96	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3945	 1	 -0.63	 -1.17	 0.0	 1.92	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3946	 1	 0.0	 0.0	 0.0	 3.72	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3947	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 20	    1.10000	    0.90000;
	3948	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	3949	 1	 159.3	 13.5	 0.0	 62.36	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	3950	 1	 9.21	 6.6	 0.059997	 0.120003	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	3951	 1	 20.12	 7.6	 0.0	 0.89	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3952	 1	 263.3	 21.9	 0.933649	 45.680861	 0	    1.00000	    0.00000	 380.0	 13	    1.10000	    0.90000;
	3953	 1	 90.4	 13.8	 0.0	 0.35	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	3954	 1	 64.87	 25.6	 0.0	 14.89	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	3955	 1	 8.51	 2.8	 0.0	 1.35	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	3956	 1	 59.9	 8.5	 0.0	 1.27	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3957	 1	 16.52	 6.0	 0.0	 0.55	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	3958	 1	 0.9	 49.1	 0.530904	 186.067075	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	3959	 1	 40.5	 5.7	 0.0	 4.13	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3960	 1	 142.2	 33.7	 0.0	 6.58	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	3961	 1	 136.6	 29.0	 0.0	 2.05	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3962	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 9	    1.20000	    0.80000;
	3963	 1	 0.0	 0.0	 0.0	 0.47	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3964	 1	 34.9	 5.0	 0.0	 2.1	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3965	 1	 98.6	 28.3	 0.0	 4.76	 0	    1.00000	    0.00000	 220.0	 8	    1.10000	    0.90000;
	3966	 1	 85.39	 14.3	 0.0	 0.35	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3967	 1	 57.21	 -7.12	 0.0	 6.86	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	3968	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 10.5	 1	    1.10000	    0.90000;
	3969	 1	 103.1	 3.1	 0.0	 61.7	 0	    1.00000	    0.00000	 380.0	 11	    1.10000	    0.90000;
	3970	 1	 4.7	 1.8	 0.0	 0.17	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3971	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 24	    1.10000	    0.90000;
	3972	 1	 1.5	 0.3	 0.0	 0.47	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3973	 1	 0.0	 -0.0	 0.0	 56.49	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	3974	 1	 16.76	 -0.51	 0.0	 0.35	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	3975	 1	 26.63	 7.6	 0.0	 0.1	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3976	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3977	 1	 35.34	 21.9	 0.0	 3.03	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3978	 1	 2.9	 0.8	 0.0	 0.68	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3979	 1	 -9.41	 3.1	 0.0	 0.87	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3980	 1	 -28.13	 -0.81	 0.0	 0.1	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3981	 1	 0.0	 -0.0	 0.0	 14.23	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3982	 1	 0.3	 1.3	 0.0	 0.28	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	3983	 1	 189.4	 25.8	 0.0	 3.62	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	3984	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	3985	 1	 0.0	 0.0	 0.0	 1.77	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	3986	 1	 129.5	 26.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	3987	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	3988	 1	 55.16	 19.8	 0.0	 135.46	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	3989	 1	 0.0	 0.0	 0.0	 0.87	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	3990	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	3991	 1	 3.0	 0.1	 0.0	 0.42	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3992	 1	 54.56	 16.7	 0.0	 0.91	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	3993	 1	 16.7	 2.4	 0.0	 2.21	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	3994	 1	 0.0	 0.0	 0.0	 0.39	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3995	 1	 0.0	 -0.0	 0.0	 1.94	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3996	 1	 100.7	 17.5	 0.0	 6.54	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	3997	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	3998	 1	 274.1	 69.3	 0.098089	 7.591911	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	3999	 1	 8.91	 2.7	 0.0	 1.01	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4000	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	4001	 1	 10.11	 3.7	 0.0	 0.52	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	4002	 1	 -0.0	 0.0	 0.078843	 -0.028843	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4003	 1	 1.0	 128.0	 0.717304	 71.222097	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	4004	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	4005	 1	 0.0	 -0.0	 0.0	 12.17	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4006	 1	 24.63	 8.1	 0.0	 0.93	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	4007	 1	 69.08	 68.0	 0.0	 2.93	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	4008	 1	 31.33	 9.6	 0.0	 1.86	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	4009	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	4010	 1	 390.8	 79.5	 0.0	 20.79	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	4011	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	4012	 1	 0.0	 0.0	 0.0	 0.39	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4013	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	4014	 1	 327.4	 125.3	 0.0	 34.36	 0	    1.00000	    0.00000	 380.0	 16	    1.10000	    0.90000;
	4015	 1	 72.0	 10.3	 0.0	 5.5	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	4016	 1	 27.53	 11.0	 0.0	 2.49	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	4017	 1	 0.0	 0.0	 0.0	 5.37	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	4018	 1	 6.91	 2.3	 0.0	 0.74	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	4019	 1	 97.0	 18.6	 0.0	 1.25	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	4020	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	4021	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	4022	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	4023	 1	 32.94	 11.8	 0.0	 0.83	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	4024	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	4025	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	4026	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	4027	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	4028	 1	 -0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	4029	 1	 -0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	4030	 1	 205.8	 66.8	 0.0	 3.65	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	4031	 1	 0.0	 -0.0	 1.139177	 12.19252	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	4032	 1	 -0.0	 0.0	 0.0	 0.25	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4033	 1	 -0.0	 0.0	 0.040549	 -0.040549	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	4034	 1	 76.6	 10.9	 0.0	 2.96	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	4035	 1	 22.02	 2.2	 0.0	 2.4	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	4036	 1	 0.0	 0.0	 0.0	 1.28	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4037	 1	 81.19	 31.4	 0.0	 2.04	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	4038	 1	 0.0	 -0.0	 0.0785	 7.691125	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	4039	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	4040	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	4041	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	4042	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	4043	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	4044	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	4045	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	4046	 1	 -0.0	 -0.0	 0.0	 31.79	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4047	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	4048	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	4049	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	4050	 1	 0.0	 -0.0	 0.0	 8.74	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	4051	 1	 8.91	 4.9	 0.0	 4.58	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	4052	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	4053	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	4054	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	4055	 1	 166.7	 87.6	 0.0	 4.22	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	4056	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	4057	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	4058	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	4059	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	4060	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	4061	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	4062	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	4063	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	4064	 1	 46.55	 9.1	 0.0	 0.68	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4065	 1	 7.41	 2.7	 0.0	 0.56	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	4066	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	4067	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	4068	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	4069	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	4070	 1	 3.8	 1.3	 0.0	 0.11	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4071	 1	 75.08	 4.0	 0.693752	 69.270779	 0	    1.00000	    0.00000	 380.0	 13	    1.10000	    0.90000;
	4072	 1	 31.28	 5.34	 0.0	 8.75	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4073	 1	 0.0	 0.0	 0.0	 21.27	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4074	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	4075	 1	 0.0	 -0.0	 0.038874	 12.290844	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4076	 1	 330.9	 51.9	 0.0	 0.0	 0	    1.00000	    0.00000	 120.0	 20	    1.20000	    0.80000;
	4077	 1	 0.0	 -0.0	 0.057699	 0.382301	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4078	 1	 -0.0	 0.0	 0.020032	 0.069968	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4079	 1	 25.13	 15.6	 0.0	 0.04	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4080	 1	 179.0	 50.5	 0.0	 3.08	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4081	 1	 21.22	 5.3	 0.0	 1.25	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4082	 1	 42.25	 4.4	 0.0	 9.58843	 0	    1.00000	    0.00000	 220.0	 16	    1.10000	    0.90000;
	4083	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	4084	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	4085	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 6.3	 1	    1.10000	    0.90000;
	4086	 1	 40.14	 8.8	 0.0	 0.82	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4087	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	4088	 1	 453.23	 139.16	 0.0	 25.584498	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	4089	 1	 -0.0	 0.0	 0.0	 70.11	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	4090	 1	 -0.0	 -0.0	 0.0	 4.76	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4091	 1	 0.0	 0.0	 0.0	 0.3	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4092	 1	 0.2	 77.4	 0.112312	 70.516407	 0	    1.00000	    0.00000	 220.0	 3	    1.20000	    0.80000;
	4093	 1	 -0.0	 0.0	 0.080375	 -0.060375	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	4094	 1	 -12.33	 -2.65	 0.0	 69.323028	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	4095	 1	 -0.0	 0.0	 0.234854	 45.08542	 0	    1.00000	    0.00000	 380.0	 21	    1.20000	    0.80000;
	4096	 1	 7.11	 4.4	 0.0	 0.97	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4097	 1	 4.2	 1.1	 0.0	 0.73	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4098	 1	 -0.0	 0.0	 0.0	 0.54	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4099	 1	 192.3	 84.6	 0.0	 38.41	 0	    1.00000	    0.00000	 220.0	 20	    1.10000	    0.90000;
	4100	 1	 -57.0	 -24.9	 0.0	 8.1	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4101	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4102	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	4103	 1	 17.72	 5.9	 0.0	 0.17	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	4104	 1	 157.2	 14.5	 0.039215	 12.000785	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	4105	 1	 37.73	 13.84	 0.0	 0.09	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4106	 1	 30.03	 10.0	 0.0	 0.66	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	4107	 1	 46.35	 16.8	 0.0	 8.35	 0	    1.00000	    0.00000	 220.0	 19	    1.10000	    0.90000;
	4108	 1	 0.0	 -0.0	 0.0	 4.21	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4109	 1	 235.3	 75.0	 0.158009	 38.121991	 0	    1.00000	    0.00000	 220.0	 11	    1.10000	    0.90000;
	4110	 1	 134.1	 24.8	 0.0	 13.73	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4111	 1	 18.8	 8.5	 0.0	 75.218793	 0	    1.00000	    0.00000	 380.0	 9	    1.20000	    0.80000;
	4112	 1	 0.0	 -0.0	 0.0	 0.62	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	4113	 1	 59.32	 -20.32	 0.0	 4.86	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	4114	 1	 -0.0	 0.0	 0.0	 0.37	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4115	 1	 33.36	 20.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.20000	    0.80000;
	4116	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	4117	 1	 69.28	 23.1	 0.0	 4.86	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	4118	 1	 24.13	 15.0	 0.0	 3.86	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4119	 1	 29.93	 0.0	 0.0	 0.46	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4120	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	4121	 1	 43.55	 12.0	 0.119294	 3.440706	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4122	 1	 13.82	 5.0	 0.0	 0.24	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	4123	 1	 0.0	 0.0	 0.0	 14.2	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	4124	 1	 46.2	 6.6	 0.0	 0.12	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	4125	 1	 -7.47	 -6.45	 0.0	 1.08	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4126	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	4127	 1	 205.9	 38.3	 0.0	 6.54	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	4128	 1	 282.5	 17.4	 0.0	 20.04	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	4129	 1	 -0.0	 0.0	 0.0	 24.73	 0	    1.00000	    0.00000	 380.0	 1	    1.20000	    0.80000;
	4130	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	4131	 1	 57.66	 61.0	 0.0	 6.46	 0	    1.00000	    0.00000	 220.0	 17	    1.10000	    0.90000;
	4132	 1	 0.0	 0.0	 0.0	 2.48	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4133	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	4134	 1	 0.0	 -0.0	 0.0	 3.2	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4135	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	4136	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	4137	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	4138	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	4139	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	4140	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	4141	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	4142	 1	 0.0	 0.0	 0.0	 2.82	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4143	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	4144	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	4145	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	4146	 1	 -0.0	 -0.0	 0.0	 0.64	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	4147	 1	 151.0	 45.7	 0.0	 3.02	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	4148	 1	 23.43	 14.5	 0.0	 1.05	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4149	 1	 227.0	 5.0	 0.0	 8.46	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4150	 1	 -0.0	 -0.0	 0.115534	 0.36335	 0	    1.00000	    0.00000	 110.0	 23	    1.10000	    0.90000;
	4151	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	4152	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	4153	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	4154	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	4155	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	4156	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	4157	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	4158	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	4159	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	4160	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	4161	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	4162	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	4163	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	4164	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	4165	 1	 -0.0	 0.0	 0.019473	 0.030527	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4166	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	4167	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	4168	 1	 133.7	 59.0	 0.0	 2.48	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	4169	 1	 -0.0	 0.0	 0.37905	 21.97435	 0	    1.00000	    0.00000	 380.0	 18	    1.20000	    0.80000;
	4170	 1	 -0.0	 -0.0	 0.0	 0.43	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	4171	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	4172	 1	 255.8	 144.8	 0.0	 52.33	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	4173	 1	 241.0	 32.3	 0.0	 34.74	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4174	 1	 203.8	 61.0	 0.0	 0.6	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	4175	 1	 -9.87	 -3.76	 0.0	 0.21	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4176	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	4177	 1	 -0.0	 0.0	 0.0	 5.21	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	4178	 1	 0.0	 0.0	 0.0	 2.87	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4179	 1	 10.91	 3.6	 0.0	 1.21	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	4180	 1	 46.25	 32.2	 0.0	 1.5	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	4181	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	4182	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	4183	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	4184	 1	 51.96	 9.4	 0.0	 42.51	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	4185	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	4186	 1	 0.0	 0.0	 0.0	 3.43	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	4187	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	4188	 1	 0.0	 0.0	 0.0	 0.66	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4189	 1	 63.47	 30.2	 0.0	 81.36	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	4190	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	4191	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	4192	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4193	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	4194	 1	 -0.0	 0.0	 0.0	 32.046949	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	4195	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	4196	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	4197	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	4198	 1	 37.24	 7.1	 0.0	 1.07	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4199	 1	 -669.84	 -285.73	 0.0	 0.0	 0	    1.00000	    0.00000	 27.0	 3	    1.10000	    0.90000;
	4200	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	4201	 1	 34.04	 12.3	 0.0	 0.25	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	4202	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 15.75	 1	    1.10000	    0.90000;
	4203	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	4204	 1	 -0.0	 0.0	 0.700348	 17.865558	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	4205	 1	 19.92	 7.4	 0.0	 17.28	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4206	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	4207	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	4208	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 15.0	 1	    1.10000	    0.90000;
	4209	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	4210	 1	 61.97	 14.3	 0.0	 8.38	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	4211	 1	 0.0	 -0.0	 0.0	 26.18	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	4212	 1	 0.0	 -0.01	 0.0	 92.38	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4213	 1	 -0.0	 0.0	 0.0	 0.34	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4214	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	4215	 1	 -0.0	 0.0	 0.039814	 0.000186	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4216	 1	 230.7	 19.3	 0.0	 4.56	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4217	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	4218	 1	 17.7	 -333.3	 0.134221	 89.130826	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	4219	 1	 70.08	 10.0	 0.0	 33.04	 0	    1.00000	    0.00000	 380.0	 11	    1.10000	    0.90000;
	4220	 1	 0.0	 -0.0	 0.0	 0.26	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4221	 1	 43.15	 11.1	 0.0	 0.4	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	4222	 1	 -0.0	 -0.0	 0.0	 -4.4045	 0	    1.00000	    0.00000	 380.0	 1	    1.20000	    0.80000;
	4223	 1	 -0.0	 -0.0	 0.0	 3.9	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4224	 1	 16.72	 6.1	 0.0	 0.41	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	4225	 1	 -0.0	 0.0	 0.0	 137.29	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	4226	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	4227	 1	 -0.0	 0.0	 0.26	 6.5	 0	    1.00000	    0.00000	 220.0	 21	    1.10000	    0.90000;
	4228	 1	 103.0	 28.7	 0.0	 2.88	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4229	 1	 0.0	 0.0	 0.0	 35.93	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	4230	 1	 17.5	 502.7	 0.319748	 0.671307	 0	    1.00000	    0.00000	 380.0	 19	    1.20000	    0.80000;
	4231	 1	 10.91	 3.6	 0.0	 0.55	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	4232	 1	 -0.0	 0.0	 0.0	 0.75	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4233	 1	 -0.0	 -0.0	 0.0	 2.32	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	4234	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	4235	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	4236	 1	 41.95	 26.0	 0.0	 12.42	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4237	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	4238	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	4239	 1	 0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	4240	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	4241	 1	 -21.38	 -13.23	 0.0	 2.52	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	4242	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	4243	 1	 215.7	 60.28	 0.0	 97.42	 0	    1.00000	    0.00000	 380.0	 13	    1.10000	    0.90000;
	4244	 1	 -632.1	 -447.0	 0.0	 6.4	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	4245	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	4246	 1	 0.0	 -0.0	 0.0	 11.03	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4247	 1	 16.22	 5.7	 0.0	 4.68	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	4248	 1	 104.6	 40.7	 0.0	 1.42	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4249	 1	 94.3	 13.4	 0.0	 0.9	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	4250	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4251	 1	 4.81	 1.2	 0.0	 0.13	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	4252	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 7	    1.10000	    0.90000;
	4253	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	4254	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	4255	 1	 -0.0	 0.0	 0.0	 32.63	 0	    1.00000	    0.00000	 220.0	 12	    1.10000	    0.90000;
	4256	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	4257	 1	 81.19	 24.4	 0.0	 0.6	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4258	 1	 16.72	 5.5	 0.0	 0.66	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	4259	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	4260	 1	 -0.45	 -0.03	 0.0	 0.46	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4261	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	4262	 1	 0.1	 -0.9	 0.0	 0.91	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	4263	 1	 82.6	 11.7	 0.0	 0.38	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	4264	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	4265	 1	 -0.13	 -1.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	4266	 1	 -0.0	 0.0	 0.0	 70.905048	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	4267	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 10.6	 1	    1.10000	    0.90000;
	4268	 1	 93.5	 42.5	 0.0	 133.56	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	4269	 1	 0.0	 0.0	 0.0	 22.54	 0	    1.00000	    0.00000	 380.0	 7	    1.10000	    0.90000;
	4270	 1	 -0.0	 0.0	 0.0	 0.68	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4271	 1	 20.9	 3.0	 0.0	 2.5	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	4272	 1	 4.4	 1.5	 0.0	 0.58	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4273	 1	 -0.0	 -0.0	 0.0	 0.19	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4274	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	4275	 1	 112.51	 16.51	 0.0	 1.63	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4276	 1	 9.31	 3.0	 0.0	 0.08	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	4277	 1	 30.33	 11.0	 0.0	 0.56	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	4278	 1	 -0.0	 0.0	 0.0	 0.22	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4279	 1	 97.82	 20.59	 0.0	 6.67	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4280	 1	 -0.0	 0.0	 0.526076	 0.520923	 0	    1.00000	    0.00000	 380.0	 14	    1.20000	    0.80000;
	4281	 1	 65.47	 26.7	 0.0	 0.6	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	4282	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	4283	 1	 53.86	 15.4	 0.019415	 0.900585	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	4284	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	4285	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	4286	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	4287	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	4288	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	4289	 1	 -0.0	 -0.0	 0.0	 0.93	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	4290	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	4291	 1	 5.81	 1.3	 0.0	 0.83	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	4292	 1	 -0.0	 -0.0	 0.0	 2.47	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4293	 1	 13.9	 1.9	 0.0	 1.5	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	4294	 1	 -0.0	 0.0	 0.0	 0.42	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	4295	 1	 0.0	 -0.0	 0.040033	 -0.020033	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	4296	 1	 26.83	 13.0	 0.0	 0.36	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	4297	 1	 17.35	 -0.8	 0.0	 1.21	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4298	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 7	    1.10000	    0.90000;
	4299	 1	 137.0	 22.8	 0.311343	 10.796493	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4300	 1	 -0.0	 -0.0	 0.0	 4.11	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4301	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	4302	 1	 0.0	 -0.0	 0.0	 21.88	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	4303	 1	 -0.0	 -0.0	 0.153209	 9.466791	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	4304	 1	 27.03	 9.0	 0.0	 0.2	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	4305	 1	 -0.0	 -0.0	 0.0	 5.51	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	4306	 1	 629.0	 184.3	 0.059643	 27.270357	 0	    1.00000	    0.00000	 380.0	 14	    1.10000	    0.90000;
	4307	 1	 0.0	 0.0	 0.0	 12.22	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	4308	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.20000	    0.80000;
	4309	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	4310	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 9	    1.10000	    0.90000;
	4311	 1	 -0.0	 -0.0	 0.223411	 1.033133	 0	    1.00000	    0.00000	 380.0	 12	    1.20000	    0.80000;
	4312	 1	 17.72	 7.3	 0.0	 0.13	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4313	 1	 5.81	 1.9	 0.0	 3.45	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	4314	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	4315	 1	 -0.0	 0.0	 0.0	 3.9	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4316	 1	 101.2	 45.2	 0.039705	 18.570221	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	4317	 1	 31.84	 5.5	 0.0	 0.25	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4318	 1	 193.9	 221.1	 1.827014	 194.933614	 0	    1.00000	    0.00000	 380.0	 13	    1.10000	    0.90000;
	4319	 1	 17.02	 6.2	 0.0	 0.87	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	4320	 1	 48.8	 6.9	 0.0	 14.55	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	4321	 1	 139.6	 68.4	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	4322	 1	 87.73	 23.17	 0.0	 2.68	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	4323	 1	 435.2	 1.3	 0.0	 3.25	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4324	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	4325	 1	 339.7	 106.8	 0.460071	 4.885777	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	4326	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	4327	 1	 -0.0	 0.0	 0.0	 0.77	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4328	 1	 -0.0	 0.0	 0.0	 2.03	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	4329	 1	 87.6	 27.4	 0.0	 0.99	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	4330	 1	 108.8	 33.2	 0.358716	 45.62985	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	4331	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	4332	 1	 0.0	 0.0	 0.0	 22.7	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	4333	 1	 146.9	 2.0	 0.058721	 4.921066	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4334	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4335	 1	 80.8	 11.6	 0.0	 6.96	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	4336	 1	 33.34	 11.0	 0.0	 1.16	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	4337	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.5	 1	    1.10000	    0.90000;
	4338	 1	 -0.0	 -0.0	 0.685544	 54.443768	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	4339	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	4340	 1	 2.2	 1.1	 0.0	 0.67	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4341	 1	 12.81	 3.9	 0.0	 0.66	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	4342	 1	 -2.35	 -2.06	 0.0	 18.45	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	4343	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	4344	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	4345	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	4346	 1	 30.23	 10.0	 0.0	 0.31	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	4347	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	4348	 1	 -0.0	 0.0	 0.0	 90.194994	 0	    1.00000	    0.00000	 380.0	 20	    1.20000	    0.80000;
	4349	 1	 -0.0	 -0.0	 0.100924	 -0.050924	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4350	 1	 0.0	 -0.0	 0.0	 1.37	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4351	 1	 -0.0	 0.0	 0.0	 0.64	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	4352	 1	 74.38	 8.8	 0.0	 6.1	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4353	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	4354	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	4355	 1	 0.0	 -0.0	 0.0	 27.69	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	4356	 1	 -0.0	 -0.0	 0.0	 1.57	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	4357	 1	 0.0	 0.0	 0.176454	 40.472414	 0	    1.00000	    0.00000	 380.0	 11	    1.10000	    0.90000;
	4358	 1	 0.0	 0.0	 0.0	 0.9	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	4359	 1	 -0.0	 0.0	 0.0	 1.54	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4360	 1	 -0.0	 -0.0	 0.57572	 1.921376	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	4361	 1	 28.73	 9.9	 0.038964	 7.091036	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4362	 1	 78.59	 25.6	 0.0	 1.0	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4363	 1	 6.61	 2.4	 0.0	 0.61	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4364	 1	 -0.0	 0.0	 0.0	 2.37	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	4365	 1	 41.15	 5.7	 0.0	 4.11	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4366	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	4367	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	4368	 1	 -0.0	 0.0	 0.70365	 1.442944	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	4369	 1	 116.93	 33.6	 0.0	 3.35	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4370	 1	 221.0	 146.8	 0.0	 8.35	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4371	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	4372	 1	 -0.0	 0.0	 0.176371	 0.133024	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	4373	 1	 96.41	 4.7	 0.019462	 10.010539	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	4374	 1	 -0.0	 0.0	 0.0	 0.86	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4375	 1	 -0.0	 0.0	 0.0	 0.91	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	4376	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	4377	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	4378	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	4379	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	4380	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	4381	 1	 118.4	 137.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	4382	 1	 -0.0	 0.0	 0.0	 50.0	 0	    1.00000	    0.00000	 380.0	 7	    1.10000	    0.90000;
	4383	 1	 26.93	 8.0	 0.0	 0.27	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4384	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	4385	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	4386	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	4387	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	4388	 1	 2.2	 0.8	 0.0	 1.31	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4389	 1	 118.4	 16.9	 0.0	 2.57	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	4390	 1	 0.0	 -0.0	 0.0	 4.21	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4391	 1	 -0.0	 -0.0	 0.0	 3.84	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	4392	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	4393	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	4394	 1	 25.93	 8.0	 0.0	 1.24	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	4395	 1	 -0.0	 -0.0	 0.0	 0.5	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4396	 1	 -0.54	 -0.77	 0.181549	 1.270889	 0	    1.00000	    0.00000	 220.0	 18	    1.20000	    0.80000;
	4397	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4398	 1	 0.0	 0.0	 0.0	 8.21	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	4399	 1	 0.0	 -0.0	 0.224497	 70.910941	 0	    1.00000	    0.00000	 380.0	 7	    1.10000	    0.90000;
	4400	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	4401	 1	 181.9	 -68.8	 0.240365	 23.269711	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	4402	 1	 1.4	 0.2	 0.0	 5.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	4403	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	4404	 1	 22.5	 9.5	 0.0	 29.37436	 0	    1.00000	    0.00000	 380.0	 9	    1.20000	    0.80000;
	4405	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	4406	 1	 0.0	 -0.0	 0.0	 1.11	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	4407	 1	 84.09	 52.09	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4408	 1	 0.0	 0.0	 0.0	 0.82	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	4409	 1	 -14.85	 -4.99	 0.0	 0.6	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4410	 1	 0.0	 0.0	 0.0	 1.62	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	4411	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	4412	 1	 493.4	 53.5	 0.0	 58.09	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	4413	 1	 8.71	 1.6	 0.0	 1.23	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	4414	 1	 38.64	 6.0	 0.0	 3.26	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4415	 1	 71.28	 6.9	 0.0	 1.93	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4416	 1	 -15.25	 -6.42	 0.0	 43.956703	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	4417	 1	 -0.0	 0.0	 0.0	 61.58	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	4418	 1	 55.86	 8.8	 0.0	 4.2	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4419	 1	 119.7	 3.7	 0.0	 0.88	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4420	 1	 272.3	 58.5	 0.0	 23.57	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	4421	 1	 566.1	 54.2	 0.0	 44.559841	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	4422	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	4423	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 6.3	 1	    1.10000	    0.90000;
	4424	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	4425	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	4426	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	4427	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	4428	 1	 -0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	4429	 1	 -0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	4430	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	4431	 1	 -0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	4432	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	4433	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	4434	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	4435	 1	 89.6	 22.7	 0.0	 4.06	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4436	 1	 -0.0	 0.0	 0.0	 4.27	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4437	 1	 0.0	 -0.0	 0.0	 2.83	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4438	 1	 92.9	 27.7	 0.0	 5.22	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4439	 1	 0.0	 0.0	 0.0	 39.58	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	4440	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	4441	 1	 100.7	 -23.3	 0.0	 2.97	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	4442	 1	 0.0	 -0.0	 0.0	 0.51	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4443	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 9	    1.20000	    0.80000;
	4444	 1	 4.0	 1.3	 0.0	 0.62	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	4445	 1	 30.33	 10.5	 0.0	 0.33	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4446	 1	 164.0	 42.3	 0.0	 8.07	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4447	 1	 14.02	 7.6	 0.0	 0.33	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4448	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 9	    1.20000	    0.80000;
	4449	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	4450	 1	 -0.0	 0.0	 0.298417	 1.071319	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	4451	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	4452	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	4453	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	4454	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	4455	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	4456	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	4457	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	4458	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	4459	 1	 0.0	 0.0	 0.0	 0.24	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4460	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	4461	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	4462	 1	 567.97	 130.73	 0.0	 1.09	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4463	 1	 300.83	 65.8	 0.232481	 3.525953	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	4464	 1	 64.67	 24.5	 0.0	 1.46	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4465	 1	 0.0	 -0.0	 0.0	 0.93	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4466	 1	 49.15	 12.8	 0.120373	 25.479751	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4467	 1	 0.0	 -0.0	 0.0	 3.64	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4468	 1	 0.0	 -0.0	 0.116426	 5.513574	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	4469	 1	 159.9	 53.2	 0.0	 7.99	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4470	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	4471	 1	 15.22	 4.2	 0.0	 1.35	 0	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	4472	 1	 0.0	 0.0	 0.038802	 -0.038802	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	4473	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	4474	 1	 -0.0	 0.0	 0.0	 1.23	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	4475	 1	 28.63	 12.1	 0.0	 0.77	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	4476	 1	 11.21	 3.7	 0.0	 0.49	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	4477	 1	 4.1	 1.5	 0.0	 0.52	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	4478	 1	 69.78	 15.3	 0.0	 1.34	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4479	 1	 30.73	 6.3	 0.079865	 1.130135	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4480	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 20	    1.10000	    0.90000;
	4481	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	4482	 1	 128.11	 64.9	 0.0	 19.1	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	4483	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 20	    1.10000	    0.90000;
	4484	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	4485	 1	 -0.0	 -0.0	 0.0	 6.1	 0	    1.00000	    0.00000	 220.0	 12	    1.10000	    0.90000;
	4486	 1	 380.9	 85.1	 0.0	 57.449841	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	4487	 1	 0.0	 -0.0	 0.0	 4.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4488	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	4489	 1	 65.07	 40.3	 0.0	 5.43	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4490	 1	 125.2	 105.4	 0.0	 76.73	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	4491	 1	 0.0	 -0.0	 0.06	 11.38	 0	    1.00000	    0.00000	 220.0	 21	    1.10000	    0.90000;
	4492	 1	 2.3	 0.8	 0.0	 0.8	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	4493	 1	 30.63	 11.6	 0.0	 52.28	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	4494	 1	 0.0	 -0.0	 0.0	 2.65	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4495	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	4496	 1	 0.0	 -0.0	 0.0	 0.39	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4497	 1	 -0.0	 0.0	 0.0	 8.33	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4498	 1	 -0.19	 -73.31	 0.0	 2.36	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	4499	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 24	    1.10000	    0.90000;
	4500	 1	 7.0	 1.0	 0.0	 4.69	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	4501	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	4502	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4503	 1	 36.4	 356.1	 0.040327	 38.479673	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	4504	 1	 0.0	 0.0	 0.019653	 0.620347	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4505	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	4506	 1	 57.86	 70.5	 0.549606	 217.978967	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	4507	 1	 0.0	 0.0	 0.0	 4.36	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	4508	 1	 99.9	 20.1	 0.0	 17.41	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	4509	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	4510	 1	 0.0	 -0.0	 0.181549	 15.300889	 0	    1.00000	    0.00000	 220.0	 18	    1.20000	    0.80000;
	4511	 1	 242.16	 73.64	 0.0	 12.79	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4512	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	4513	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	4514	 1	 0.0	 -0.0	 0.0	 0.33	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4515	 1	 115.5	 71.5	 0.0	 150.47	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	4516	 1	 0.0	 -0.0	 0.0	 3.13	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	4517	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 15.75	 1	    1.10000	    0.90000;
	4518	 1	 -0.0	 -0.0	 0.0	 3.25	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4519	 1	 104.78	 20.92	 0.0	 6.17	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4520	 1	 0.7	 270.7	 0.334521	 197.981232	 0	    1.00000	    0.00000	 380.0	 3	    1.20000	    0.80000;
	4521	 1	 58.97	 11.1	 0.0	 1.05	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4522	 1	 0.0	 -0.0	 0.0	 2.48	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4523	 1	 0.0	 -0.0	 0.348552	 2.288904	 0	    1.00000	    0.00000	 380.0	 20	    1.10000	    0.90000;
	4524	 1	 3.5	 1.4	 0.0	 0.83	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4525	 1	 285.7	 31.9	 0.193667	 29.236333	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	4526	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	4527	 1	 -14.9	 -4.6	 0.0	 0.14	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4528	 1	 56.06	 17.1	 0.11629	 9.96371	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4529	 1	 278.3	 174.6	 0.084108	 5.365892	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4530	 1	 -0.0	 0.0	 0.0	 16.06	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	4531	 1	 56.86	 35.2	 0.0	 2.29	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4532	 1	 7.61	 2.5	 0.0	 1.2	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	4533	 1	 0.0	 0.0	 0.0	 0.03	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4534	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 23	    1.10000	    0.90000;
	4535	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 23	    1.10000	    0.90000;
	4536	 1	 20.72	 6.3	 0.0	 0.37	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	4537	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 23	    1.10000	    0.90000;
	4538	 1	 91.7	 13.0	 0.0	 2.25	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	4539	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	4540	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	4541	 1	 0.0	 0.0	 0.0	 1.83	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4542	 1	 19.82	 7.2	 0.0	 0.36	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	4543	 1	 -0.0	 0.0	 0.0	 24.9092	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	4544	 1	 49.86	 14.1	 0.0	 11.33	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4545	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	4546	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	4547	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	4548	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	4549	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	4550	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	4551	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	4552	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	4553	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	4554	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	4555	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	4556	 1	 80.09	 -1.8	 0.0	 4.09	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	4557	 1	 40.34	 7.8	 0.019977	 4.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4558	 1	 8.31	 3.0	 0.0	 0.87	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	4559	 1	 0.0	 -0.0	 0.056825	 3.423175	 0	    1.00000	    0.00000	 220.0	 11	    1.10000	    0.90000;
	4560	 1	 68.68	 19.1	 0.0	 0.1	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4561	 1	 0.0	 -0.0	 0.0	 0.21	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4562	 1	 19.02	 11.5	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4563	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	4564	 1	 149.0	 99.8	 0.0	 9.27	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4565	 1	 123.8	 17.6	 0.0	 4.03	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	4566	 1	 0.0	 -0.0	 0.019918	 2.4	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4567	 1	 205.0	 24.6	 0.176296	 18.672881	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4568	 1	 -0.0	 0.0	 0.912692	 19.247452	 0	    1.00000	    0.00000	 380.0	 9	    1.10000	    0.90000;
	4569	 1	 136.7	 19.3	 0.0	 37.5	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	4570	 1	 10.61	 51.2	 0.231109	 8.234819	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	4571	 1	 59.98	 15.54	 0.0	 0.49	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4572	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	4573	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	4574	 1	 8.31	 2.5	 0.0	 0.8	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	4575	 1	 -0.0	 -8.2	 0.120069	 9.499931	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4576	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	4577	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	4578	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	4579	 1	 -16.5	 3.6	 0.0	 1.54	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4580	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	4581	 1	 184.91	 32.8	 0.0	 8.35	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4582	 1	 11.11	 3.6	 0.0	 3.36	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	4583	 1	 0.0	 -0.0	 0.0	 0.49	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	4584	 1	 -0.0	 0.0	 0.0	 75.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	4585	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	4586	 1	 39.64	 9.8	 0.0	 1.08	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	4587	 1	 13.84	 1.85	 0.0	 0.2	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	4588	 1	 -0.0	 -0.0	 0.0	 1.98	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4589	 1	 -0.0	 0.0	 0.22	 21.48	 0	    1.00000	    0.00000	 220.0	 19	    1.10000	    0.90000;
	4590	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	4591	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4592	 1	 -0.0	 0.0	 0.0	 1.58	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4593	 1	 132.9	 40.5	 0.0	 6.92	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	4594	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	4595	 1	 39.34	 11.2	 0.0	 0.85	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	4596	 1	 180.2	 46.4	 0.0	 9.7	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4597	 1	 23.63	 7.8	 0.0	 0.62	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	4598	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	4599	 1	 -0.0	 -0.0	 0.0	 62.76	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	4600	 1	 0.0	 0.0	 0.0	 0.54	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4601	 1	 31.94	 12.6	 0.0	 10.67	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	4602	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	4603	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	4604	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	4605	 1	 -0.0	 0.0	 0.058973	 0.731027	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4606	 1	 9.51	 2.8	 0.0	 0.5	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4607	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	4608	 1	 14.12	 7.7	 0.0	 1.42	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4609	 1	 -20.92	 2.5	 0.0	 16.42	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	4610	 1	 107.0	 34.7	 0.0	 1.54	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4611	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 6.3	 1	    1.10000	    0.90000;
	4612	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	4613	 1	 75.58	 30.3	 0.0	 34.66	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	4614	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	4615	 1	 -0.0	 0.0	 0.058106	 46.651578	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	4616	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	4617	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	4618	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	4619	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	4620	 1	 14.01	 6.5	 0.0	 0.09	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4621	 1	 127.8	 15.2	 0.0	 9.34	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4622	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	4623	 1	 -0.0	 0.0	 0.0	 207.85	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	4624	 1	 0.0	 -0.0	 0.0	 54.23	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	4625	 1	 104.5	 31.8	 0.0	 0.71	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	4626	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 22	    1.10000	    0.90000;
	4627	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 22	    1.10000	    0.90000;
	4628	 1	 398.0	 11.5	 0.0	 7.749841	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	4629	 1	 15.92	 12.0	 0.0	 6.79	 0	    1.00000	    0.00000	 220.0	 16	    1.10000	    0.90000;
	4630	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 22	    1.10000	    0.90000;
	4631	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 22	    1.10000	    0.90000;
	4632	 1	 86.2	 19.9	 0.0	 5.43	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4633	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 22	    1.10000	    0.90000;
	4634	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 22	    1.10000	    0.90000;
	4635	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 22	    1.10000	    0.90000;
	4636	 1	 -0.0	 0.0	 0.354092	 -0.245076	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4637	 1	 -0.0	 0.0	 0.0	 0.14	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4638	 1	 -0.0	 0.0	 0.343964	 110.768913	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	4639	 1	 0.0	 0.0	 0.0	 15.04	 0	    1.00000	    0.00000	 220.0	 3	    1.20000	    0.80000;
	4640	 1	 146.7	 20.7	 0.0	 62.64	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	4641	 1	 98.01	 16.6	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4642	 1	 -0.0	 0.0	 0.0	 104.11	 0	    1.00000	    0.00000	 380.0	 22	    1.20000	    0.80000;
	4643	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	4644	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	4645	 1	 2.3	 0.8	 0.0	 0.42	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	4646	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	4647	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	4648	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	4649	 1	 0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	4650	 1	 0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	4651	 1	 0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	4652	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	4653	 1	 -0.0	 0.0	 0.0	 47.99	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	4654	 1	 0.0	 0.0	 0.0	 5.21	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	4655	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	4656	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	4657	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	4658	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	4659	 1	 -0.0	 -0.0	 0.0	 1.43	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4660	 1	 63.07	 25.8	 0.0	 18.63	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	4661	 1	 73.58	 30.1	 0.0	 6.02	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	4662	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	4663	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	4664	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	4665	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	4666	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	4667	 1	 165.2	 64.5	 0.040447	 7.159553	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4668	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 9.0	 1	    1.10000	    0.90000;
	4669	 1	 341.2	 46.6	 0.229484	 12.678325	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	4670	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	4671	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 7	    1.10000	    0.90000;
	4672	 1	 76.38	 24.8	 0.0	 3.24	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4673	 1	 -0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	4674	 1	 9.01	 1.1	 0.0	 1.26	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	4675	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	4676	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	4677	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	4678	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	4679	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	4680	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	4681	 1	 0.0	 -0.0	 0.0	 0.6	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4682	 1	 -0.0	 -0.0	 0.039193	 0.350807	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4683	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	4684	 1	 177.3	 36.4	 0.0	 0.7	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4685	 1	 81.2	 89.3	 0.0	 15.55	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	4686	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	4687	 1	 -0.0	 -0.0	 0.233641	 -0.194701	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	4688	 1	 0.0	 -0.0	 0.0	 3.58	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	4689	 1	 -0.0	 0.0	 0.242346	 2.448045	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	4690	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	4691	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	4692	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 20	    1.10000	    0.90000;
	4693	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	4694	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	4695	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	4696	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	4697	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	4698	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	4699	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	4700	 1	 251.3	 42.6	 0.0	 5.47	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4701	 1	 133.9	 32.4	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	4702	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	4703	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	4704	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	4705	 1	 374.1	 61.4	 0.281144	 7.339142	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4706	 1	 -38.84	 -17.0	 0.07874	 3.110945	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	4707	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	4708	 1	 -6.58	 -1.67	 0.0	 1.14	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4709	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	4710	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	4711	 1	 -0.0	 -0.0	 0.239102	 7.690711	 0	    1.00000	    0.00000	 220.0	 12	    1.10000	    0.90000;
	4712	 1	 16.42	 5.9	 0.0	 0.17	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	4713	 1	 -0.0	 0.0	 0.0	 6.19	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	4714	 1	 -5.06	 -1.84	 0.0	 187.314047	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	4715	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	4716	 1	 132.0	 27.0	 0.0	 4.66	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4717	 1	 89.0	 -1.8	 0.0	 6.15	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	4718	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	4719	 1	 -0.0	 0.0	 0.0	 1.18	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	4720	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4721	 1	 0.0	 -0.0	 0.0	 3.03	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	4722	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	4723	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	4724	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	4725	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	4726	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	4727	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	4728	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	4729	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	4730	 1	 20.9	 -171.5	 0.0	 0.21	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4731	 1	 113.0	 56.5	 0.0	 4.12	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4732	 1	 84.19	 17.3	 0.0	 6.2	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4733	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	4734	 1	 -0.0	 0.0	 0.0	 17.65	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	4735	 1	 81.79	 51.1	 0.0	 3.06	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	4736	 1	 142.4	 87.8	 0.4624	 9.223933	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	4737	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4738	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	4739	 1	 0.0	 -0.0	 0.0	 2.19	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	4740	 1	 0.0	 -0.0	 0.0	 45.7	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	4741	 1	 0.0	 0.0	 0.0	 1.44	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4742	 1	 0.0	 0.0	 0.0	 1.87	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	4743	 1	 0.0	 0.0	 0.0	 3.71	 0	    1.00000	    0.00000	 220.0	 8	    1.10000	    0.90000;
	4744	 1	 -11.71	 3.8	 0.0	 0.13	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4745	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	4746	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 6.3	 1	    1.10000	    0.90000;
	4747	 1	 -0.0	 0.0	 0.0	 53.64	 0	    1.00000	    0.00000	 380.0	 15	    1.20000	    0.80000;
	4748	 1	 83.6	 11.9	 0.0	 5.03	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	4749	 1	 87.0	 29.6	 0.0	 4.95	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	4750	 1	 0.0	 0.0	 0.2166	 10.9704	 0	    1.00000	    0.00000	 380.0	 1	    1.20000	    0.80000;
	4751	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	4752	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	4753	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	4754	 1	 9.21	 3.5	 0.037778	 0.662222	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	4755	 1	 0.0	 -0.0	 0.0	 23.92	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	4756	 1	 -0.0	 -0.0	 0.019362	 1.140638	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	4757	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	4758	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4759	 1	 0.0	 -0.0	 0.0	 4.62	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	4760	 1	 0.0	 -0.0	 0.0	 0.23	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4761	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	4762	 1	 -0.0	 -0.0	 0.0	 21.82	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	4763	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	4764	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	4765	 1	 176.7	 25.6	 0.0	 2.01	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	4766	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4767	 1	 -0.0	 -0.0	 0.0	 5.12	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	4768	 1	 -0.0	 -0.0	 0.0	 2.13	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	4769	 1	 -0.0	 0.0	 0.668421	 4.480834	 0	    1.00000	    0.00000	 380.0	 18	    1.20000	    0.80000;
	4770	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	4771	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	4772	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	4773	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	4774	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	4775	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	4776	 1	 165.55	 72.35	 0.039777	 8.820223	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4777	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 7	    1.10000	    0.90000;
	4778	 1	 0.0	 -0.0	 0.417783	 38.745174	 0	    1.00000	    0.00000	 380.0	 11	    1.10000	    0.90000;
	4779	 1	 -0.0	 0.0	 0.0	 17.75	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	4780	 1	 0.0	 -0.0	 0.0	 0.13	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4781	 1	 0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	4782	 1	 -0.0	 -0.0	 0.294847	 40.776932	 0	    1.00000	    0.00000	 380.0	 7	    1.10000	    0.90000;
	4783	 1	 66.67	 33.3	 0.059554	 3.910446	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	4784	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	4785	 1	 -0.0	 -0.0	 0.0	 2.08	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	4786	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	4787	 1	 10.61	 3.8	 0.0	 0.66	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	4788	 1	 1.8	 0.7	 0.0	 0.85	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	4789	 1	 -0.0	 0.0	 0.0	 9.66	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4790	 1	 180.7	 71.8	 0.0	 2.46	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4791	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	4792	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	4793	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	4794	 1	 -0.0	 0.0	 0.118845	 -0.089134	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	4795	 1	 0.0	 -0.0	 0.470875	 11.647224	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	4796	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	4797	 1	 178.62	 14.44	 0.0	 136.23	 0	    1.00000	    0.00000	 380.0	 14	    1.20000	    0.80000;
	4798	 1	 -0.0	 -0.0	 0.0	 16.34	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	4799	 1	 27.8	 4.0	 0.0	 9.38	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	4800	 1	 -0.57	 -0.91	 0.0	 0.09	 0	    1.00000	    0.00000	 220.0	 21	    1.10000	    0.90000;
	4801	 1	 11.01	 6.0	 0.0	 0.04	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4802	 1	 0.0	 -0.0	 0.113921	 102.294559	 0	    1.00000	    0.00000	 380.0	 14	    1.10000	    0.90000;
	4803	 1	 0.6	 28.7	 0.298623	 22.851147	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4804	 1	 0.0	 -0.0	 0.0	 84.85	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	4805	 1	 33.14	 11.6	 0.0	 4.51	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4806	 1	 5.51	 2.0	 0.0	 0.39	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	4807	 1	 0.0	 -0.0	 0.0	 30.55	 0	    1.00000	    0.00000	 150.0	 9	    1.20000	    0.80000;
	4808	 1	 -0.0	 -0.0	 0.0	 1.08	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4809	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	4810	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	4811	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	4812	 1	 -0.0	 0.0	 0.0	 0.8	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4813	 1	 22.12	 13.7	 0.113069	 1.716931	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4814	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	4815	 1	 332.9	 99.6	 0.0	 0.53	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	4816	 1	 33.24	 11.1	 0.0	 0.27	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	4817	 1	 72.08	 29.5	 0.0	 1.06	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	4818	 1	 34.9	 5.0	 0.0	 11.17	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	4819	 1	 -0.0	 0.0	 0.0	 3.25	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	4820	 1	 0.0	 0.0	 0.0	 10.72	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	4821	 1	 13.9	 1.9	 0.0	 3.4	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	4822	 1	 0.0	 0.0	 0.573452	 -0.326818	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4823	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 10.5	 1	    1.10000	    0.90000;
	4824	 1	 0.0	 0.0	 0.0	 1.84	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4825	 1	 0.0	 0.0	 0.0	 7.75	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	4826	 1	 149.3	 -2.0	 0.0	 20.77	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	4827	 1	 0.0	 0.0	 0.039049	 0.520475	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4828	 1	 -0.0	 -0.0	 0.0	 5.18	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	4829	 1	 -10.11	 3.3	 0.0	 0.53	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4830	 1	 0.0	 0.0	 0.0	 34.49	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	4831	 1	 5.61	 2.2	 0.195552	 45.454448	 0	    1.00000	    0.00000	 380.0	 7	    1.10000	    0.90000;
	4832	 1	 -0.2	 -1.64	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	4833	 1	 31.23	 11.3	 0.0	 0.33	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	4834	 1	 0.0	 -0.0	 0.0	 0.05	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4835	 1	 59.7	 26.3	 0.0	 37.680934	 0	    1.00000	    0.00000	 380.0	 9	    1.10000	    0.90000;
	4836	 1	 50.56	 16.6	 0.0	 2.02	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	4837	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	4838	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4839	 1	 120.4	 39.5	 0.0	 47.2	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	4840	 1	 0.0	 0.0	 0.0	 0.83	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4841	 1	 -0.0	 0.0	 0.0	 2.22	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	4842	 1	 78.19	 27.0	 0.058553	 4.621206	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	4843	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	4844	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	4845	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	4846	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	4847	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	4848	 1	 70.48	 16.4	 0.040466	 4.649534	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4849	 1	 -0.0	 -0.0	 0.0	 0.91	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4850	 1	 219.22	 70.1	 0.685037	 32.787679	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	4851	 1	 -0.0	 -0.0	 0.0	 2.27	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4852	 1	 14.72	 4.6	 0.0	 0.33	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4853	 1	 2.3	 0.8	 0.0	 0.6	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	4854	 1	 13.62	 8.4	 0.0	 2.67	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4855	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 8	    1.10000	    0.90000;
	4856	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 8	    1.10000	    0.90000;
	4857	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 8	    1.10000	    0.90000;
	4858	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 8	    1.10000	    0.90000;
	4859	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 8	    1.10000	    0.90000;
	4860	 1	 -10.59	 -5.25	 0.0	 3.59	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	4861	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 8	    1.10000	    0.90000;
	4862	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 8	    1.10000	    0.90000;
	4863	 1	 34.04	 11.0	 0.0	 0.96	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	4864	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 8	    1.10000	    0.90000;
	4865	 1	 120.5	 37.5	 0.039658	 3.410342	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4866	 1	 67.4	 9.6	 0.0	 4.68	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	4867	 1	 48.8	 6.9	 0.0	 4.64	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	4868	 1	 236.2	 116.4	 0.0	 16.22	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	4869	 1	 36.84	 14.1	 0.048813	 44.261187	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	4870	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	4871	 1	 0.0	 0.0	 0.0	 0.76	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	4872	 1	 379.5	 113.3	 0.06172	 22.14828	 0	    1.00000	    0.00000	 220.0	 14	    1.10000	    0.90000;
	4873	 1	 46.85	 16.6	 0.0	 2.08	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	4874	 1	 2.0	 0.6	 0.0	 0.53	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	4875	 1	 18.02	 6.0	 0.0	 0.98	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	4876	 1	 38.54	 49.6	 0.276138	 0.922896	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4877	 1	 379.9	 73.0	 0.0	 59.58	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	4878	 1	 83.29	 24.1	 0.0	 1.23	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4879	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4880	 1	 0.0	 -0.0	 0.040009	 346.717844	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	4881	 1	 38.04	 20.0	 0.0	 0.03	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	4882	 1	 0.0	 -0.0	 0.0	 0.68	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	4883	 1	 0.0	 0.0	 0.114098	 0.674918	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	4884	 1	 1.3	 0.4	 0.0	 0.24	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4885	 1	 20.32	 8.9	 0.0	 1.29	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4886	 1	 -0.0	 -0.0	 0.0	 5.22	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	4887	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	4888	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	4889	 1	 -0.0	 0.0	 0.0	 1.02	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4890	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4891	 1	 -0.0	 0.0	 0.0	 5.14	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	4892	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	4893	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	4894	 1	 -0.0	 -0.0	 0.185125	 56.232473	 0	    1.00000	    0.00000	 380.0	 18	    1.20000	    0.80000;
	4895	 1	 36.54	 27.4	 0.0	 0.16	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	4896	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	4897	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	4898	 1	 -0.0	 -0.0	 0.0	 0.82	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4899	 1	 -0.0	 0.0	 0.0	 6.1	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	4900	 1	 0.0	 0.0	 0.0	 7.68	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	4901	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	4902	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	4903	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	4904	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	4905	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	4906	 1	 155.8	 38.4	 0.0	 3.77	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	4907	 1	 0.0	 0.0	 0.089212	 -0.009474	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4908	 1	 -0.0	 0.0	 0.090774	 0.080444	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	4909	 1	 3.8	 1.3	 0.0	 0.99	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4910	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 17	    1.10000	    0.90000;
	4911	 1	 143.79	 106.96	 0.0	 99.84	 0	    1.00000	    0.00000	 380.0	 13	    1.10000	    0.90000;
	4912	 1	 -0.0	 0.0	 0.0	 0.19	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4913	 1	 3.4	 1.4	 0.0	 0.62	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4914	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	4915	 1	 0.0	 0.0	 0.039148	 4.840852	 0	    1.00000	    0.00000	 220.0	 22	    1.10000	    0.90000;
	4916	 1	 0.0	 -0.0	 0.0	 1.58	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4917	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 6.3	 1	    1.10000	    0.90000;
	4918	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	4919	 1	 0.5	 0.5	 0.0	 0.74	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4920	 1	 156.2	 24.5	 0.0	 2.22	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	4921	 1	 322.1	 131.9	 0.241556	 9.808768	 0	    1.00000	    0.00000	 220.0	 14	    1.10000	    0.90000;
	4922	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	4923	 1	 15.22	 2.5	 0.0	 0.63	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	4924	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	4925	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	4926	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	4927	 1	 77.49	 21.4	 0.0	 0.05	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4928	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	4929	 1	 -0.0	 0.0	 0.0	 13.02	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4930	 1	 13.9	 1.9	 0.0	 5.68	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	4931	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	4932	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	4933	 1	 50.76	 17.5	 0.0	 8.97	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	4934	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	4935	 1	 50.06	 19.7	 0.0	 0.84	 0	    1.00000	    0.00000	 110.0	 23	    1.10000	    0.90000;
	4936	 1	 8.31	 3.0	 0.0	 0.69	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	4937	 1	 115.0	 -4.5	 0.0	 15.05	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4938	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	4939	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 23	    1.10000	    0.90000;
	4940	 1	 47.15	 15.2	 0.0	 0.17	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	4941	 1	 -0.0	 0.0	 0.0	 5.7	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	4942	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	4943	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	4944	 1	 0.0	 -0.0	 0.0	 30.28	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	4945	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	4946	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	4947	 1	 4.61	 1.7	 0.0	 0.19	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	4948	 1	 -0.0	 -0.0	 0.0	 19.57	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	4949	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	4950	 1	 -0.2	 -1.64	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	4951	 1	 -0.0	 -0.0	 0.060584	 0.479416	 0	    1.00000	    0.00000	 220.0	 14	    1.10000	    0.90000;
	4952	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	4953	 1	 91.8	 18.6	 0.05911	 1.87089	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4954	 1	 88.8	 -3.2	 0.0	 13.63	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4955	 1	 93.7	 29.9	 0.0	 2.1	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	4956	 1	 -0.0	 0.0	 0.0	 4.79	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	4957	 1	 -0.0	 -0.0	 0.0	 0.67	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4958	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	4959	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	4960	 1	 27.13	 9.0	 0.0	 0.42	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	4961	 1	 0.0	 0.0	 0.0	 0.54	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4962	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	4963	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	4964	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	4965	 1	 103.1	 14.7	 0.0	 4.43	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	4966	 1	 -0.0	 -0.0	 0.0	 17.31	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4967	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	4968	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	4969	 1	 23.23	 6.3	 0.0	 0.66	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4970	 1	 115.0	 16.4	 0.0	 3.94	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	4971	 1	 234.2	 33.3	 0.0	 0.88	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	4972	 1	 140.93	 18.71	 0.0	 12.73	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	4973	 1	 -0.76	 -0.86	 0.0	 6.15	 0	    1.00000	    0.00000	 220.0	 12	    1.10000	    0.90000;
	4974	 1	 -0.0	 -0.0	 0.0	 13.94	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4975	 1	 108.7	 26.3	 0.0	 2.06	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	4976	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4977	 1	 0.0	 -0.0	 0.0	 16.4	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	4978	 1	 52.06	 17.0	 0.0	 0.24	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	4979	 1	 29.43	 10.7	 0.0	 0.2	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	4980	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4981	 1	 19.42	 7.0	 0.0	 0.6	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	4982	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	4983	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 6.3	 1	    1.10000	    0.90000;
	4984	 1	 78.09	 27.0	 0.0	 0.83	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	4985	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 20	    1.10000	    0.90000;
	4986	 1	 14.72	 5.3	 0.0	 0.58	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	4987	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	4988	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	4989	 1	 0.0	 0.0	 0.0	 1.78	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4990	 1	 0.0	 -0.0	 0.0	 0.24	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	4991	 1	 1.9	 0.7	 0.0	 0.19	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	4992	 1	 6.71	 2.4	 0.0	 0.2	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	4993	 1	 11.51	 4.2	 0.0	 3.64	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	4994	 1	 24.23	 6.4	 0.0	 3.9	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	4995	 1	 173.1	 4.6	 0.0	 2.57	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	4996	 1	 11.5	 1.7	 0.0	 3.11	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	4997	 1	 -0.0	 -0.0	 0.171753	 9.136873	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	4998	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 24	    1.10000	    0.90000;
	4999	 1	 0.0	 0.0	 1.191402	 16.470917	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	5000	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	5001	 1	 146.9	 26.6	 0.0	 11.95	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5002	 1	 0.0	 0.0	 0.0	 17.92	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	5003	 1	 90.2	 5.8	 0.0	 18.69	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	5004	 1	 77.19	 18.6	 0.0	 2.22	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5005	 1	 -0.0	 0.0	 0.113531	 6.215391	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	5006	 1	 39.05	 -11.82	 0.0	 1.12	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	5007	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	5008	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	5009	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	5010	 1	 179.8	 5.67	 0.0	 12.83	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5011	 1	 314.5	 83.9	 0.710505	 9.997517	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5012	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	5013	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	5014	 1	 0.0	 0.0	 0.0	 0.04	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	5015	 1	 140.1	 10.0	 0.0386	 8.2714	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	5016	 1	 9.7	 1.4	 0.0	 4.51	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5017	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	5018	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	5019	 1	 0.0	 0.0	 0.0	 80.21	 0	    1.00000	    0.00000	 380.0	 19	    1.10000	    0.90000;
	5020	 1	 0.0	 0.0	 0.29461	 7.926671	 0	    1.00000	    0.00000	 220.0	 18	    1.20000	    0.80000;
	5021	 1	 54.96	 12.2	 0.0	 7.05	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5022	 1	 0.0	 0.0	 0.0	 0.74	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	5023	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	5024	 1	 5.11	 1.3	 0.0	 0.67	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5025	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	5026	 1	 -7.63	 -4.3	 0.0	 94.012267	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	5027	 1	 271.43	 74.55	 0.0	 78.4	 0	    1.00000	    0.00000	 380.0	 14	    1.10000	    0.90000;
	5028	 1	 0.0	 -0.0	 0.0	 6.02	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5029	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	5030	 1	 -0.0	 0.0	 0.0	 2.24	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	5031	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	5032	 1	 137.4	 23.9	 0.0	 7.26	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5033	 1	 20.82	 9.5	 0.0	 1.16	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5034	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	5035	 1	 15.63	 4.8	 0.0	 1.21	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5036	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	5037	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 9	    1.10000	    0.90000;
	5038	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 23	    1.10000	    0.90000;
	5039	 1	 -0.0	 -0.0	 0.0	 33.22	 0	    1.00000	    0.00000	 380.0	 13	    1.10000	    0.90000;
	5040	 1	 -18.8	 -5.9	 0.0	 6.23	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5041	 1	 25.63	 51.6	 0.0	 2.79	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5042	 1	 23.13	 8.8	 0.0	 1.42	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	5043	 1	 4.2	 0.6	 0.0	 4.02	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5044	 1	 76.6	 10.9	 0.0	 9.96	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5045	 1	 0.0	 0.0	 0.0	 1.38	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5046	 1	 -0.0	 0.0	 0.039816	 0.010184	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5047	 1	 119.1	 60.5	 0.0	 2.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5048	 1	 43.75	 17.3	 0.0	 7.73	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	5049	 1	 209.5	 95.0	 0.0	 24.39	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	5050	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	5051	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	5052	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	5053	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	5054	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	5055	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	5056	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	5057	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	5058	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	5059	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	5060	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	5061	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 15.0	 1	    1.10000	    0.90000;
	5062	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	5063	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	5064	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	5065	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	5066	 1	 7.71	 2.2	 0.0	 0.81	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	5067	 1	 1.5	 0.5	 0.0	 0.59	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	5068	 1	 3.8	 1.3	 0.0	 0.65	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5069	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	5070	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	5071	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	5072	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	5073	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	5074	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	5075	 1	 -0.0	 0.0	 0.0	 0.27	 0	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	5076	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	5077	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	5078	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	5079	 1	 123.1	 51.8	 0.0	 1.68	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	5080	 1	 18.72	 5.5	 0.0	 1.15	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	5081	 1	 18.02	 -15.7	 0.0	 1.03	 0	    1.00000	    0.00000	 110.0	 23	    1.10000	    0.90000;
	5082	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	5083	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5084	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	5085	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	5086	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	5087	 1	 23.93	 8.7	 0.0	 0.52	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	5088	 1	 -0.0	 -0.0	 0.0	 64.67	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	5089	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	5090	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	5091	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	5092	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	5093	 1	 22.12	 7.9	 0.0	 0.7	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	5094	 1	 -3.4	 -0.5	 0.0	 0.23	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	5095	 1	 124.9	 104.0	 0.0	 4.31	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	5096	 1	 -0.0	 -0.0	 0.236401	 -0.027001	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	5097	 1	 142.5	 23.6	 0.0	 4.24	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5098	 1	 22.02	 13.7	 0.0	 0.44	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5099	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	5100	 1	 3.9	 -35.8	 0.0	 4.71	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	5101	 1	 0.0	 -0.0	 0.0	 37.1	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	5102	 1	 4.61	 1.4	 0.0	 0.83	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5103	 1	 16.32	 7.6	 0.0	 3.15	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5104	 1	 36.34	 22.5	 0.0	 2.39	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5105	 1	 55.66	 4.5	 0.0	 1.33	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5106	 1	 -0.0	 0.0	 0.0	 75.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	5107	 1	 -0.0	 -0.0	 0.0	 12.24	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5108	 1	 12.51	 4.1	 0.0	 0.71	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	5109	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	5110	 1	 15.92	 5.2	 0.0	 0.58	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	5111	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	5112	 1	 473.4	 113.1	 0.058293	 10.341707	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5113	 1	 12.11	 4.7	 0.020109	 0.529891	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	5114	 1	 226.3	 61.1	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	5115	 1	 -0.0	 -0.0	 0.243936	 107.503604	 0	    1.00000	    0.00000	 380.0	 7	    1.10000	    0.90000;
	5116	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.5	 1	    1.10000	    0.90000;
	5117	 1	 -0.0	 0.0	 0.0	 4.8	 0	    1.00000	    0.00000	 380.0	 23	    1.20000	    0.80000;
	5118	 1	 99.3	 23.3	 0.0	 1.88	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5119	 1	 100.5	 32.0	 0.0	 1.89	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	5120	 1	 138.5	 19.3	 0.0	 5.26	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5121	 1	 0.0	 -0.0	 0.0	 2.34	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5122	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	5123	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	5124	 1	 94.2	 21.6	 0.0	 2.88	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5125	 1	 0.0	 0.0	 0.0	 7.06	 0	    1.00000	    0.00000	 220.0	 8	    1.10000	    0.90000;
	5126	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	5127	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	5128	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	5129	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	5130	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	5131	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	5132	 1	 0.0	 -0.0	 0.0	 1.93	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5133	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	5134	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	5135	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	5136	 1	 0.0	 -0.0	 0.0	 3.49	 0	    1.00000	    0.00000	 220.0	 19	    1.10000	    0.90000;
	5137	 1	 -0.0	 -0.0	 0.0	 0.6	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	5138	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	5139	 1	 0.0	 -0.0	 0.081141	 2.229144	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	5140	 1	 0.0	 0.0	 0.491069	 77.396812	 0	    1.00000	    0.00000	 380.0	 11	    1.10000	    0.90000;
	5141	 1	 23.63	 16.5	 0.0	 8.39	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	5142	 1	 0.0	 0.0	 0.0	 43.87	 0	    1.00000	    0.00000	 380.0	 18	    1.20000	    0.80000;
	5143	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	5144	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 22	    1.10000	    0.90000;
	5145	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 22	    1.10000	    0.90000;
	5146	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 22	    1.10000	    0.90000;
	5147	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 22	    1.10000	    0.90000;
	5148	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 22	    1.10000	    0.90000;
	5149	 1	 65.64	 -0.98	 0.0	 11.55	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5150	 1	 -0.0	 -0.0	 0.54037	 57.959712	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	5151	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 22	    1.10000	    0.90000;
	5152	 1	 -0.64	 -3.53	 0.0	 8.84	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	5153	 1	 123.8	 41.4	 0.039325	 4.960675	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	5154	 1	 102.7	 39.0	 0.0	 135.53	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	5155	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	5156	 1	 -0.0	 -0.0	 0.0	 3.48	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	5157	 1	 0.0	 0.0	 0.0	 42.71	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	5158	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 14.4	 1	    1.10000	    0.90000;
	5159	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	5160	 1	 -0.0	 0.0	 0.0	 68.053762	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	5161	 1	 7.01	 2.3	 0.0	 0.81	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	5162	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 6.3	 1	    1.10000	    0.90000;
	5163	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	5164	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	5165	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	5166	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	5167	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	5168	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	5169	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	5170	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	5171	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	5172	 1	 29.93	 10.8	 0.0	 0.46	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	5173	 1	 0.0	 -0.0	 0.041301	 0.708772	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5174	 1	 33.34	 13.2	 0.0	 0.76	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5175	 1	 0.0	 -0.0	 0.0	 0.9	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5176	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5177	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	5178	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	5179	 1	 0.0	 0.0	 0.0	 2.47	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5180	 1	 118.5	 21.0	 0.0	 2.19	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	5181	 1	 7.81	 2.8	 0.0	 0.77	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	5182	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5183	 1	 159.1	 -28.7	 0.0	 2.31	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	5184	 1	 8.61	 3.1	 0.0	 0.48	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	5185	 1	 0.0	 -0.0	 0.0	 0.49	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5186	 1	 -0.48	 0.1	 0.0	 0.91	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	5187	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	5188	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	5189	 1	 0.0	 0.0	 0.0	 4.17	 0	    1.00000	    0.00000	 220.0	 8	    1.10000	    0.90000;
	5190	 1	 97.0	 -52.1	 0.0	 3.95	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	5191	 1	 6.01	 3.0	 0.0	 0.05	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	5192	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 23	    1.10000	    0.90000;
	5193	 1	 0.0	 0.0	 0.0	 0.09	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	5194	 1	 -0.0	 -0.0	 0.0	 3.34	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5195	 1	 0.0	 0.0	 0.0	 0.98	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	5196	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 23	    1.10000	    0.90000;
	5197	 1	 0.0	 0.0	 0.0	 14.09776	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	5198	 1	 0.0	 -0.0	 0.0	 83.96	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	5199	 1	 0.0	 -0.0	 0.0	 1.56	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5200	 1	 -0.0	 0.0	 0.0	 48.46	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	5201	 1	 4.2	 1.2	 0.0	 30.55	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	5202	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	5203	 1	 -0.0	 0.0	 0.115596	 2.11367	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	5204	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	5205	 1	 -0.0	 -0.0	 0.136871	 2.413044	 0	    1.00000	    0.00000	 220.0	 19	    1.10000	    0.90000;
	5206	 1	 0.0	 -0.0	 0.0	 3.91	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5207	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	5208	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	5209	 1	 0.0	 0.0	 0.174825	 7.755175	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	5210	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	5211	 1	 387.1	 138.9	 0.239691	 22.220245	 0	    1.00000	    0.00000	 220.0	 14	    1.10000	    0.90000;
	5212	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	5213	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	5214	 1	 0.0	 0.0	 0.0	 18.31	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	5215	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	5216	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	5217	 1	 362.2	 -10.5	 0.0	 19.86	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	5218	 1	 0.0	 -0.0	 0.0	 1.33	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5219	 1	 31.23	 12.9	 0.0	 0.36	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	5220	 1	 87.2	 31.8	 0.0	 5.96	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5221	 1	 41.65	 13.6	 0.0	 0.31	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	5222	 1	 -0.0	 -0.0	 0.0	 2.51	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5223	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	5224	 1	 4.1	 0.9	 0.0	 0.09	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5225	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	5226	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	5227	 1	 152.5	 -0.1	 0.0	 2.66	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	5228	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	5229	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	5230	 1	 31.43	 10.6	 0.0	 1.61	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5231	 1	 6.31	 1.3	 0.0	 0.43	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5232	 1	 392.8	 70.6	 0.0	 13.309841	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	5233	 1	 0.0	 -0.0	 0.0	 5.34	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5234	 1	 19.72	 9.4	 0.038541	 3.531459	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5235	 1	 5.21	 1.5	 0.0	 1.1	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5236	 1	 0.0	 -0.0	 0.0	 53.268666	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	5237	 1	 30.6	 4.3	 0.0	 8.4	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5238	 1	 215.3	 37.7	 0.0	 14.36	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	5239	 1	 19.04	 7.9	 0.0	 4.53	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5240	 1	 -0.0	 0.0	 0.161328	 3.849004	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	5241	 1	 8.31	 3.0	 0.0	 0.24	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	5242	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	5243	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	5244	 1	 0.0	 0.0	 0.0	 0.53	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5245	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	5246	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	5247	 1	 24.43	 8.7	 0.0	 0.46	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	5248	 1	 1.4	 0.5	 0.0	 0.85	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	5249	 1	 -38.7	 -12.99	 0.0	 13.393621	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	5250	 1	 -0.0	 0.0	 0.0	 11.06	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	5251	 1	 277.72	 7.35	 0.0	 3.58	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5252	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	5253	 1	 -0.0	 0.0	 0.393538	 -0.195154	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5254	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	5255	 1	 -10.61	 3.5	 0.0	 1.3	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5256	 1	 353.0	 20.7	 0.099975	 37.760025	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	5257	 1	 -0.0	 -0.0	 0.019671	 18.610329	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	5258	 1	 115.0	 34.8	 0.03998	 3.70001	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5259	 1	 -0.0	 0.0	 0.040038	 0.009962	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	5260	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	5261	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	5262	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	5263	 1	 0.0	 0.0	 0.0	 78.22	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	5264	 1	 -0.0	 -0.0	 0.0	 1.6	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5265	 1	 37.54	 18.3	 0.0	 0.22	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5266	 1	 46.0	 6.6	 0.0	 3.11	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5267	 1	 -0.0	 0.0	 0.0	 0.49	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5268	 1	 13.9	 1.9	 0.0	 4.47	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5269	 1	 -0.0	 0.0	 0.0	 5.85	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5270	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	5271	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	5272	 1	 102.7	 77.5	 0.0	 4.89	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5273	 1	 -17.8	 -3.68	 0.109667	 41.234333	 0	    1.00000	    0.00000	 380.0	 3	    1.20000	    0.80000;
	5274	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	5275	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	5276	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	5277	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	5278	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	5279	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	5280	 1	 31.43	 6.6	 0.0	 3.32	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5281	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 14.4	 1	    1.10000	    0.90000;
	5282	 1	 0.0	 -0.0	 0.0	 2.09	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5283	 1	 11.91	 3.0	 0.0	 1.22	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5284	 1	 0.0	 0.0	 0.0	 0.06	 0	    1.00000	    0.00000	 220.0	 21	    1.10000	    0.90000;
	5285	 1	 68.78	 13.0	 0.0	 10.45	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5286	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	5287	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	5288	 1	 129.2	 13.4	 0.04047	 13.81953	 0	    1.00000	    0.00000	 220.0	 14	    1.10000	    0.90000;
	5289	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	5290	 1	 0.0	 -0.0	 0.0	 0.38	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5291	 1	 0.0	 0.0	 0.0	 0.23	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5292	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 7	    1.10000	    0.90000;
	5293	 1	 86.6	 14.9	 0.0	 1.34	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5294	 1	 0.0	 0.0	 0.0	 0.74	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5295	 1	 124.3	 39.4	 0.0	 6.43	 0	    1.00000	    0.00000	 380.0	 20	    1.10000	    0.90000;
	5296	 1	 0.0	 0.0	 0.117165	 11.642126	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	5297	 1	 194.3	 27.9	 0.0	 3.53	 0	    1.00000	    0.00000	 220.0	 3	    1.20000	    0.80000;
	5298	 1	 95.1	 -19.36	 0.0	 12.46	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	5299	 1	 0.0	 -0.0	 0.0	 58.144073	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	5300	 1	 -28.13	 -0.82	 0.0	 0.1	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5301	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	5302	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	5303	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	5304	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	5305	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	5306	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	5307	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	5308	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	5309	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	5310	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	5311	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	5312	 1	 217.8	 60.5	 0.059037	 2.290963	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5313	 1	 -0.0	 0.0	 0.0	 4.48	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5314	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 15.75	 1	    1.10000	    0.90000;
	5315	 1	 152.5	 14.4	 0.0	 24.61	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	5316	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 6.3	 1	    1.10000	    0.90000;
	5317	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	5318	 1	 9.21	 3.3	 0.0	 1.13	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	5319	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 9	    1.10000	    0.90000;
	5320	 1	 0.0	 0.0	 0.0	 13.51	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	5321	 1	 108.43	 31.33	 0.0	 0.88	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	5322	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	5323	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	5324	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	5325	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	5326	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	5327	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	5328	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	5329	 1	 11.31	 4.0	 0.038744	 1.291256	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	5330	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	5331	 1	 0.0	 0.0	 0.0	 61.52	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	5332	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 23	    1.10000	    0.90000;
	5333	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	5334	 1	 35.14	 16.1	 0.0	 0.45	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	5335	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	5336	 1	 58.97	 27.1	 0.197746	 0.841691	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5337	 1	 21.12	 8.3	 0.0	 4.26	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	5338	 1	 -0.0	 -0.0	 0.0	 53.84	 0	    1.00000	    0.00000	 380.0	 12	    1.20000	    0.80000;
	5339	 1	 -0.0	 -0.0	 0.0	 4.08	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	5340	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5341	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 9	    1.10000	    0.90000;
	5342	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	5343	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	5344	 1	 70.48	 33.9	 0.112194	 3.176505	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	5345	 1	 -0.0	 0.0	 0.0	 0.39	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5346	 1	 34.34	 12.5	 0.0	 0.23	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	5347	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	5348	 1	 -0.0	 -0.0	 0.0	 93.58	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	5349	 1	 24.63	 16.7	 0.080106	 8.659894	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5350	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	5351	 1	 21.52	 7.6	 0.0	 0.18	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5352	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	5353	 1	 -0.0	 0.0	 0.0	 11.98	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	5354	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	5355	 1	 -12.3	 -10.6	 0.0	 3.54	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5356	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	5357	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	5358	 1	 -0.0	 0.0	 0.0	 15.23	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5359	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	5360	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 23	    1.10000	    0.90000;
	5361	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 23	    1.10000	    0.90000;
	5362	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 23	    1.10000	    0.90000;
	5363	 1	 0.0	 0.0	 0.0	 2.61	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5364	 1	 0.0	 0.0	 0.0	 10.82	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	5365	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 23	    1.10000	    0.90000;
	5366	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 23	    1.10000	    0.90000;
	5367	 1	 0.0	 0.0	 0.0	 12.4	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5368	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	5369	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	5370	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	5371	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	5372	 1	 0.0	 0.0	 0.0	 7.1	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	5373	 1	 30.33	 11.0	 0.0	 0.58	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	5374	 1	 1.3	 0.4	 0.0	 1.7	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5375	 1	 -0.0	 0.0	 0.058227	 -0.008227	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5376	 1	 -5.01	 -1.81	 0.0	 15.16	 0	    1.00000	    0.00000	 220.0	 11	    1.10000	    0.90000;
	5377	 1	 0.0	 -5.5	 0.039787	 12.430213	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5378	 1	 42.55	 17.6	 0.0	 17.28	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5379	 1	 32.24	 11.7	 0.0	 0.1	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	5380	 1	 -0.0	 -0.0	 0.709066	 -1.750701	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	5381	 1	 1.5	 0.8	 0.0	 0.55	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5382	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	5383	 1	 -0.0	 0.0	 0.0	 57.87	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	5384	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 6.3	 1	    1.10000	    0.90000;
	5385	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	5386	 1	 -0.0	 0.0	 0.0	 4.86	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5387	 1	 0.0	 -0.0	 0.0	 4.68	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5388	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	5389	 1	 -0.0	 0.0	 0.0	 11.87	 0	    1.00000	    0.00000	 380.0	 1	    1.20000	    0.80000;
	5390	 1	 61.4	 8.8	 0.0	 3.53	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5391	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	5392	 1	 -0.0	 0.0	 0.0	 0.04	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5393	 1	 20.72	 5.0	 0.0	 6.64	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5394	 1	 114.8	 121.5	 0.0	 24.25	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	5395	 1	 138.4	 39.5	 0.118033	 13.031967	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5396	 1	 131.0	 1.3	 0.0	 120.45	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5397	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	5398	 1	 0.0	 -0.0	 0.0	 2.8	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5399	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	5400	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	5401	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	5402	 1	 -0.0	 -0.0	 1.294898	 -0.826149	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	5403	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5404	 1	 0.0	 0.0	 0.573222	 0.203366	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	5405	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	5406	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	5407	 1	 50.2	 7.1	 0.0	 8.14	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5408	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	5409	 1	 295.4	 42.0	 0.0	 0.83	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5410	 1	 0.0	 -0.0	 0.0	 0.74	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5411	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	5412	 1	 141.5	 70.8	 0.0	 4.92	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	5413	 1	 0.0	 -0.0	 0.0	 13.93	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	5414	 1	 -0.0	 -0.0	 0.0	 2.04	 0	    1.00000	    0.00000	 110.0	 19	    1.20000	    0.80000;
	5415	 1	 28.03	 6.5	 0.0	 6.32	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5416	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	5417	 1	 22.83	 9.7	 0.0	 5.07	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5418	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 10.5	 1	    1.10000	    0.90000;
	5419	 1	 132.3	 135.6	 0.358583	 4.131181	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5420	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 9	    1.10000	    0.90000;
	5421	 1	 95.0	 10.43	 0.0	 89.57	 0	    1.00000	    0.00000	 380.0	 13	    1.10000	    0.90000;
	5422	 1	 5.51	 2.2	 0.0	 0.59	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	5423	 1	 -0.0	 -0.0	 0.0	 9.51	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	5424	 1	 24.83	 7.6	 0.0	 0.23	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5425	 1	 1.7	 0.3	 0.0	 0.21	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5426	 1	 -0.0	 -0.0	 0.0	 0.02	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5427	 1	 2.5	 1.3	 0.0	 0.12	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5428	 1	 0.0	 -0.0	 0.0	 16.73	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5429	 1	 28.93	 10.5	 0.0	 0.88	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	5430	 1	 182.3	 65.9	 0.0	 62.49	 0	    1.00000	    0.00000	 380.0	 20	    1.20000	    0.80000;
	5431	 1	 52.79	 2.64	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5432	 1	 -0.0	 0.01	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5433	 1	 -0.0	 0.0	 0.0	 70.71	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	5434	 1	 -0.0	 0.0	 0.1	 5.73	 0	    1.00000	    0.00000	 220.0	 21	    1.10000	    0.90000;
	5435	 1	 -0.0	 0.0	 0.0	 8.99	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5436	 1	 -17.62	 5.8	 0.0	 0.23	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5437	 1	 -0.0	 0.0	 0.172737	 -0.134351	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	5438	 1	 223.4	 143.1	 0.280648	 4.559514	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5439	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	5440	 1	 -0.0	 -0.0	 0.0	 1.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5441	 1	 16.4	 2.3	 0.0	 3.43	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5442	 1	 -0.0	 0.0	 0.0	 0.56	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5443	 1	 -0.0	 -0.0	 0.473225	 52.235363	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	5444	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 22	    1.10000	    0.90000;
	5445	 1	 -32.71	 -13.76	 0.0	 135.135902	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	5446	 1	 74.58	 12.3	 0.039447	 21.250553	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5447	 1	 16.62	 -10.3	 0.0	 0.1	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	5448	 1	 -4.86	 -2.12	 0.0	 0.64	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5449	 1	 0.0	 0.0	 0.0	 0.43	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5450	 1	 0.0	 -0.0	 0.0	 13.3	 0	    1.00000	    0.00000	 220.0	 11	    1.10000	    0.90000;
	5451	 1	 0.0	 -0.0	 0.0	 1.53	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5452	 1	 -0.0	 -0.0	 0.0	 1.12	 0	    1.00000	    0.00000	 220.0	 12	    1.10000	    0.90000;
	5453	 1	 120.7	 24.3	 0.0	 4.51	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	5454	 1	 2.5	 -0.0	 0.0	 0.57	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5455	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 23	    1.10000	    0.90000;
	5456	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	5457	 1	 -0.0	 0.0	 0.019585	 4.410415	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5458	 1	 32.1	 4.5	 0.0	 2.53	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5459	 1	 0.0	 -0.01	 0.0	 1.2	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	5460	 1	 -0.0	 -0.0	 0.0	 7.4	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5461	 1	 0.0	 0.0	 0.040055	 2.829945	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	5462	 1	 -0.19	 -0.87	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	5463	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	5464	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	5465	 1	 24.03	 8.0	 0.0	 0.75	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	5466	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	5467	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	5468	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	5469	 1	 115.3	 16.4	 0.0	 2.45	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5470	 1	 85.1	 -122.4	 0.0	 6.67	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	5471	 1	 0.0	 0.0	 0.0	 4.67	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5472	 1	 179.4	 58.3	 0.0	 0.64	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5473	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	5474	 1	 104.0	 51.2	 0.020067	 3.329933	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	5475	 1	 0.0	 -0.0	 0.0	 0.87	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	5476	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	5477	 1	 65.1	 26.4	 0.0	 0.58	 0	    1.00000	    0.00000	 110.0	 23	    1.10000	    0.90000;
	5478	 1	 0.0	 0.0	 0.683996	 -0.541497	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	5479	 1	 0.0	 -0.0	 0.0588	 -0.049	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	5480	 1	 -0.0	 -0.0	 0.090774	 7.550444	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	5481	 1	 16.52	 7.1	 0.0	 1.1	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	5482	 1	 165.3	 89.2	 0.0	 13.47	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	5483	 1	 -32.04	 10.3	 0.0	 82.52	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	5484	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	5485	 1	 2.3	 0.8	 0.0	 0.21	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	5486	 1	 -0.0	 -0.0	 0.090774	 3.980444	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	5487	 1	 -24.87	 -3.7	 0.0	 0.35	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5488	 1	 -0.0	 -0.0	 0.0	 0.11	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5489	 1	 51.36	 -0.7	 0.0	 0.57	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5490	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	5491	 1	 -0.0	 -0.0	 0.0	 0.09	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5492	 1	 45.15	 4.1	 0.0	 2.61	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5493	 1	 42.48	 10.36	 0.0	 0.37	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5494	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 10.6	 1	    1.10000	    0.90000;
	5495	 1	 18.42	 6.0	 0.0	 0.93	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	5496	 1	 0.3	 1.3	 0.038604	 0.101396	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	5497	 1	 40.44	 20.5	 0.0	 0.85	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5498	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	5499	 1	 -0.0	 -0.0	 0.0	 13.03	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5500	 1	 -0.0	 -0.0	 0.708649	 1.518986	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	5501	 1	 122.3	 45.9	 0.0	 4.03	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	5502	 1	 71.38	 10.9	 0.039268	 3.160549	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5503	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	5504	 1	 93.9	 10.95	 0.0	 4.98	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5505	 1	 24.03	 7.9	 0.0	 1.08	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	5506	 1	 34.14	 11.8	 0.039086	 0.950914	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	5507	 1	 39.44	 5.9	 0.0	 1.92	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5508	 1	 194.6	 48.3	 0.0	 0.85	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	5509	 1	 -0.0	 -0.0	 0.038572	 0.211071	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	5510	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	5511	 1	 69.28	 44.1	 0.39706	 -0.66706	 0	    1.00000	    0.00000	 220.0	 21	    1.10000	    0.90000;
	5512	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	5513	 1	 7.61	 0.5	 0.0	 0.59	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5514	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	5515	 1	 0.0	 0.0	 0.345747	 7.051877	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	5516	 1	 -24.93	 11.8	 0.0	 3.51	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5517	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	5518	 1	 35.54	 11.7	 0.0	 0.19	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	5519	 1	 4.0	 1.3	 0.0	 0.56	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	5520	 1	 83.49	 17.4	 0.0	 19.32	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5521	 1	 0.0	 -0.0	 0.115739	 8.593551	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	5522	 1	 181.1	 25.8	 0.0	 1.1	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5523	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	5524	 1	 71.08	 16.2	 0.0	 11.58	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	5525	 1	 338.22	 104.11	 0.0	 91.11	 0	    1.00000	    0.00000	 380.0	 13	    1.10000	    0.90000;
	5526	 1	 119.1	 61.4	 0.0	 1.9	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5527	 1	 37.84	 23.4	 0.0	 0.02	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5528	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	5529	 1	 4.0	 0.1	 0.0	 0.09	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5530	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	5531	 1	 -0.0	 0.0	 0.0	 1.04	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	5532	 1	 18.02	 6.5	 0.0	 0.64	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	5533	 1	 46.9	 6.7	 0.0	 0.07	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5534	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	5535	 1	 33.04	 21.6	 0.0	 26.59	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	5536	 1	 42.25	 5.9	 0.0	 13.07	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5537	 1	 19.82	 10.9	 0.0	 0.05	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5538	 1	 -0.0	 0.0	 0.157271	 12.642047	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	5539	 1	 34.14	 13.5	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	5540	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 23	    1.10000	    0.90000;
	5541	 1	 2.2	 -48.8	 0.0	 39.69	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	5542	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	5543	 1	 0.0	 0.0	 0.0	 30.09	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	5544	 1	 -0.0	 0.0	 0.0	 0.46	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5545	 1	 0.0	 0.0	 0.0	 2.46	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5546	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	5547	 1	 201.4	 47.5	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	5548	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 9	    1.10000	    0.90000;
	5549	 1	 -0.0	 0.0	 0.0	 5.25	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	5550	 1	 77.19	 25.4	 0.0	 4.13	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	5551	 1	 -0.0	 0.0	 0.0	 6.96	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5552	 1	 -0.0	 -0.0	 0.0	 0.57	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5553	 1	 8.41	 2.5	 0.0	 1.18	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5554	 1	 52.46	 19.0	 0.0	 0.34	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	5555	 1	 162.4	 14.4	 0.019919	 12.920081	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	5556	 1	 -0.0	 -0.0	 0.0	 10.31	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5557	 1	 46.35	 86.9	 0.0	 10.32	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	5558	 1	 27.8	 4.0	 0.0	 3.34	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5559	 1	 -0.0	 -0.0	 0.0	 26.98	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5560	 1	 80.56	 20.85	 0.0	 10.33	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	5561	 1	 23.93	 8.7	 0.0	 0.48	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	5562	 1	 0.0	 0.0	 0.0	 9.09	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	5563	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5564	 1	 24.63	 15.3	 0.0	 1.28	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5565	 1	 0.0	 -0.0	 0.060373	 1.049627	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	5566	 1	 105.4	 92.5	 0.117734	 22.942266	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5567	 1	 63.67	 20.2	 0.0	 6.13	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5568	 1	 -1.9	 -28.1	 0.0	 100.56	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	5569	 1	 -0.0	 -0.0	 0.019548	 15.600452	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	5570	 1	 0.0	 -0.0	 0.0	 0.96	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5571	 1	 2.8	 0.6	 0.0	 0.62	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	5572	 1	 272.5	 127.2	 0.039174	 55.140826	 0	    1.00000	    0.00000	 380.0	 13	    1.10000	    0.90000;
	5573	 1	 0.0	 0.0	 0.0	 17.64	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	5574	 1	 39.0	 5.5	 0.0	 18.09	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5575	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	5576	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 15.5	 1	    1.10000	    0.90000;
	5577	 1	 2.3	 0.8	 0.079208	 2.270792	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	5578	 1	 0.0	 -0.0	 0.0	 2.97	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	5579	 1	 -0.0	 0.0	 0.181549	 6.920889	 0	    1.00000	    0.00000	 220.0	 18	    1.20000	    0.80000;
	5580	 1	 23.3	 3.3	 0.0	 9.29	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5581	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 9	    1.10000	    0.90000;
	5582	 1	 39.34	 24.4	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5583	 1	 10.11	 5.6	 0.0	 0.89	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5584	 1	 -0.5	 -0.17	 0.0	 0.21	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5585	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	5586	 1	 5.01	 2.0	 0.0	 0.84	 0	    1.00000	    0.00000	 110.0	 23	    1.10000	    0.90000;
	5587	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 7	    1.10000	    0.90000;
	5588	 1	 -0.0	 0.0	 0.548295	 7.403222	 0	    1.00000	    0.00000	 380.0	 14	    1.20000	    0.80000;
	5589	 1	 90.6	 15.8	 0.0	 7.99	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5590	 1	 -9.75	 -2.74	 0.0	 0.41	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5591	 1	 159.9	 10.6	 0.0	 69.6	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	5592	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	5593	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	5594	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 23	    1.10000	    0.90000;
	5595	 1	 226.0	 55.79	 0.0	 18.2	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5596	 1	 130.5	 24.7	 0.0	 0.4	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5597	 1	 16.32	 2.8	 0.0	 1.41	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5598	 1	 77.49	 17.3	 0.0	 0.1	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5599	 1	 0.0	 -0.0	 0.0	 6.32	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	5600	 1	 35.66	 -9.39	 0.0	 7.89	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5601	 1	 44.45	 10.9	 0.0	 2.23	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5602	 1	 -0.0	 -0.0	 0.0	 35.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	5603	 1	 5.31	 1.8	 0.0	 0.72	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	5604	 1	 105.6	 70.0	 0.237412	 7.212157	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5605	 1	 -0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	5606	 1	 -0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	5607	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	5608	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	5609	 1	 -0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	5610	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	5611	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	5612	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	5613	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	5614	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	5615	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5616	 1	 0.0	 0.0	 0.0	 0.72	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5617	 1	 -0.0	 -0.0	 0.0	 9.47	 0	    1.00000	    0.00000	 220.0	 11	    1.10000	    0.90000;
	5618	 1	 40.5	 5.7	 0.0	 5.41	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5619	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	5620	 1	 18.82	 6.8	 0.0	 0.59	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	5621	 1	 0.0	 0.0	 0.0	 0.67	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5622	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	5623	 1	 -0.0	 -0.0	 0.0	 97.323975	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	5624	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	5625	 1	 130.1	 19.3	 0.0	 19.24	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	5626	 1	 14.22	 6.1	 0.0	 0.18	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5627	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 20	    1.10000	    0.90000;
	5628	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 22	    1.10000	    0.90000;
	5629	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 22	    1.10000	    0.90000;
	5630	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 22	    1.10000	    0.90000;
	5631	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 22	    1.10000	    0.90000;
	5632	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 22	    1.10000	    0.90000;
	5633	 1	 180.4	 119.2	 0.0	 53.22	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	5634	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 22	    1.10000	    0.90000;
	5635	 1	 44.15	 10.6	 0.0	 1.62	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	5636	 1	 36.74	 22.7	 0.0	 0.46	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5637	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	5638	 1	 89.1	 27.5	 0.0	 1.01	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	5639	 1	 33.04	 10.9	 0.0	 0.97	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	5640	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	5641	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	5642	 1	 44.35	 12.8	 0.049456	 6.940544	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5643	 1	 -0.0	 -0.0	 0.117943	 0.021542	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	5644	 1	 6.41	 2.3	 0.0	 0.97	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	5645	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	5646	 1	 123.9	 32.6	 0.0	 1.52	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5647	 1	 12.91	 4.7	 0.0	 0.39	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	5648	 1	 16.7	 2.4	 0.0	 2.73	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5649	 1	 -0.0	 0.0	 0.0	 5.36	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	5650	 1	 6.81	 2.3	 0.0	 1.88	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5651	 1	 123.09	 9.2	 0.0	 0.92	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	5652	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5653	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	5654	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	5655	 1	 73.08	 15.7	 0.039626	 1.900281	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5656	 1	 -0.0	 0.0	 0.0	 6.39	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	5657	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	5658	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 6.3	 1	    1.10000	    0.90000;
	5659	 1	 -0.0	 0.0	 0.224609	 28.762184	 0	    1.00000	    0.00000	 220.0	 18	    1.20000	    0.80000;
	5660	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	5661	 1	 85.5	 118.1	 0.0	 5.09	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	5662	 1	 -38.73	 -15.32	 0.0	 97.23	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5663	 1	 28.03	 8.8	 0.0	 1.05	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	5664	 1	 0.0	 0.0	 0.0	 11.68	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5665	 1	 0.0	 -0.0	 0.0	 0.13	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5666	 1	 0.0	 -0.0	 0.0	 2.07	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	5667	 1	 -0.0	 -0.0	 0.0	 0.23	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	5668	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	5669	 1	 28.03	 10.2	 0.0	 0.83	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	5670	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	5671	 1	 0.0	 0.0	 0.0	 8.07	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	5672	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	5673	 1	 -18.32	 6.0	 0.0	 0.32	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5674	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	5675	 1	 -0.0	 -0.0	 0.0	 0.73	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	5676	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	5677	 1	 -0.0	 -0.0	 0.0	 2.26	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5678	 1	 201.06	 19.46	 0.0	 2.87	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5679	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 6.3	 1	    1.10000	    0.90000;
	5680	 1	 -8.43	 -7.98	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	5681	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	5682	 1	 0.0	 -0.0	 0.0	 4.43	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5683	 1	 0.0	 -0.0	 0.574645	 1.662232	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	5684	 1	 12.8	 1.8	 0.0	 6.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5685	 1	 50.06	 23.0	 0.0	 0.24	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	5686	 1	 -2835.7	 -818.9	 0.0	 56.48	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	5687	 1	 77.0	 -239.9	 0.0	 4.21	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	5688	 1	 63.67	 21.3	 0.0	 3.69	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	5689	 1	 51.26	 -17.2	 0.0	 100.22	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	5690	 1	 11.61	 4.3	 0.0	 1.0	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	5691	 1	 102.1	 27.8	 0.039298	 0.180702	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5692	 1	 31.73	 3.8	 0.0	 1.3	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5693	 1	 0.0	 -0.0	 0.0	 9.19	 0	    1.00000	    0.00000	 220.0	 8	    1.10000	    0.90000;
	5694	 1	 -1.09	 1.5	 0.077254	 1.542746	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5695	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	5696	 1	 -28.13	 -0.82	 0.0	 0.09	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5697	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	5698	 1	 -0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	5699	 1	 -0.0	 0.0	 0.0	 0.44	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5700	 1	 56.26	 20.1	 0.0	 0.92	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	5701	 1	 4.4	 2.2	 0.0	 0.41	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	5702	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	5703	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	5704	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	5705	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	5706	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	5707	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	5708	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	5709	 1	 0.0	 0.0	 0.019798	 0.280202	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5710	 1	 94.3	 -27.5	 0.0	 2.34	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	5711	 1	 -49.05	 1.0	 0.0	 32.5	 0	    1.00000	    0.00000	 220.0	 11	    1.10000	    0.90000;
	5712	 1	 0.0	 -0.0	 0.161274	 1.883044	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	5713	 1	 -10.41	 3.4	 0.0	 0.99	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5714	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	5715	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	5716	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	5717	 1	 4.61	 1.7	 0.0	 0.49	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	5718	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	5719	 1	 0.0	 0.0	 0.090774	 6.319044	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	5720	 1	 19.62	 -3.1	 0.0	 10.98	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	5721	 1	 -0.0	 0.0	 0.0	 0.05	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5722	 1	 0.0	 -0.0	 0.0	 4.77	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5723	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	5724	 1	 0.0	 0.0	 0.0	 14.27	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	5725	 1	 -272.2	 6.6	 0.0	 29.33	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	5726	 1	 33.04	 12.1	 0.0	 1.19	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	5727	 1	 23.43	 8.4	 0.0	 0.32	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	5728	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	5729	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	5730	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	5731	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	5732	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	5733	 1	 121.5	 29.6	 0.0	 2.49	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	5734	 1	 5.11	 2.3	 0.0	 0.48	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5735	 1	 -0.0	 0.0	 0.057583	 0.542417	 0	    1.00000	    0.00000	 220.0	 21	    1.10000	    0.90000;
	5736	 1	 -0.0	 0.0	 0.0	 0.59	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5737	 1	 20.12	 8.6	 0.0	 0.18	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5738	 1	 211.1	 93.1	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5739	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 9	    1.10000	    0.90000;
	5740	 1	 -0.0	 0.0	 0.166443	 -0.391647	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	5741	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	5742	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 15.75	 1	    1.10000	    0.90000;
	5743	 1	 -0.0	 -0.0	 0.0	 69.75	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	5744	 1	 5.31	 1.9	 0.009974	 0.81	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5745	 1	 -0.0	 0.0	 0.0	 8.16	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	5746	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 23	    1.10000	    0.90000;
	5747	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 23	    1.10000	    0.90000;
	5748	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 23	    1.10000	    0.90000;
	5749	 1	 0.0	 -0.0	 0.22295	 6.573498	 0	    1.00000	    0.00000	 380.0	 14	    1.10000	    0.90000;
	5750	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	5751	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	5752	 1	 -3.3	 -0.7	 0.0	 0.7	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5753	 1	 -0.0	 0.01	 0.0	 19.73	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5754	 1	 143.9	 85.2	 0.0	 3.1	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	5755	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	5756	 1	 16.32	 5.3	 0.0	 1.04	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	5757	 1	 -0.0	 -0.0	 0.0	 2.68	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5758	 1	 0.0	 -0.0	 0.086633	 0.534111	 0	    1.00000	    0.00000	 220.0	 18	    1.20000	    0.80000;
	5759	 1	 0.0	 0.0	 0.0	 22.74	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5760	 1	 66.67	 16.9	 0.039171	 7.290829	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5761	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 20	    1.10000	    0.90000;
	5762	 1	 20.32	 6.7	 0.0	 1.0	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	5763	 1	 -11.8	 -5.47	 0.0	 88.050735	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	5764	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 7	    1.10000	    0.90000;
	5765	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 9	    1.10000	    0.90000;
	5766	 1	 67.78	 10.4	 0.0	 7.18	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5767	 1	 -0.0	 -0.0	 0.232844	 2.415665	 0	    1.00000	    0.00000	 380.0	 14	    1.10000	    0.90000;
	5768	 1	 39.34	 10.3	 0.0	 0.33	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5769	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	5770	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	5771	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	5772	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	5773	 1	 -0.0	 0.0	 0.343686	 0.573595	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	5774	 1	 11.11	 4.0	 0.0	 0.15	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	5775	 1	 227.4	 40.3	 0.0	 0.27	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	5776	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	5777	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	5778	 1	 -2.3	 -3.34	 0.0	 8.15	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5779	 1	 89.3	 25.1	 0.0	 2.98	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5780	 1	 75.78	 46.9	 0.0	 3.07	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5781	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	5782	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	5783	 1	 29.73	 0.0	 0.0	 1.34	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	5784	 1	 124.9	 77.0	 0.0	 23.05	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	5785	 1	 105.2	 24.2	 0.0	 0.25	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5786	 1	 2.4	 1.0	 0.058589	 0.961411	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5787	 1	 -0.0	 -0.0	 0.0	 0.85	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5788	 1	 0.0	 0.0	 0.0	 14.83	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	5789	 1	 0.0	 -0.0	 0.27075	 43.13435	 0	    1.00000	    0.00000	 380.0	 18	    1.20000	    0.80000;
	5790	 1	 37.94	 23.5	 0.0	 0.85	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5791	 1	 -0.0	 -0.0	 0.0	 0.78	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5792	 1	 0.0	 -0.0	 0.0	 0.89	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	5793	 1	 -0.0	 -0.0	 0.0	 0.81	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	5794	 1	 -0.0	 -0.0	 0.0	 15.55	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	5795	 1	 101.1	 6.6	 0.0	 5.66	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5796	 1	 83.19	 11.4	 0.0	 9.84	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5797	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 22	    1.10000	    0.90000;
	5798	 1	 27.9	 4.0	 0.0	 0.02	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5799	 1	 62.4	 123.4	 0.588182	 22.609849	 0	    1.00000	    0.00000	 220.0	 24	    1.10000	    0.90000;
	5800	 1	 1.1	 -0.0	 0.0	 26.91	 0	    1.00000	    0.00000	 220.0	 22	    1.10000	    0.90000;
	5801	 1	 90.5	 12.8	 0.0	 7.61	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5802	 1	 0.0	 0.0	 0.0	 4.14	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	5803	 1	 -0.0	 -0.0	 0.0	 9.05	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5804	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 17	    1.10000	    0.90000;
	5805	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	5806	 1	 20.02	 15.0	 0.0	 2.11	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	5807	 1	 74.28	 -11.3	 0.0391	 2.880675	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	5808	 1	 0.0	 -0.0	 0.096503	 3.353497	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	5809	 1	 0.4	 0.9	 0.0	 0.38	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	5810	 1	 90.4	 53.4	 0.243268	 0.817549	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5811	 1	 5.11	 3.8	 0.0	 1.06	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5812	 1	 -0.0	 -0.0	 0.0	 8.54	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	5813	 1	 310.8	 162.6	 0.0	 19.47	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	5814	 1	 -0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 16	    1.10000	    0.90000;
	5815	 1	 -0.19	 -0.92	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	5816	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	5817	 1	 0.0	 -0.0	 0.0	 7.4	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5818	 1	 25.0	 3.6	 0.0	 13.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5819	 1	 0.0	 -0.0	 0.079227	 0.08058	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	5820	 1	 -0.0	 -0.0	 0.0	 1.11	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5821	 1	 -0.0	 -0.0	 0.0	 58.09	 0	    1.00000	    0.00000	 380.0	 15	    1.20000	    0.80000;
	5822	 1	 0.0	 0.0	 0.0	 5.62	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	5823	 1	 42.35	 7.2	 0.0	 1.47	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5824	 1	 19.42	 11.8	 0.0	 2.6	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5825	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	5826	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	5827	 1	 127.8	 37.6	 0.238595	 7.981012	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	5828	 1	 1.3	 0.0	 0.0	 0.57	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5829	 1	 4.2	 0.9	 0.0	 0.12	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5830	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	5831	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	5832	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	5833	 1	 220.7	 -14.8	 0.0	 125.52	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	5834	 1	 3.9	 1.4	 0.0	 0.2	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	5835	 1	 -0.18	 -2.27	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	5836	 1	 -0.0	 -0.0	 0.0	 0.84	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5837	 1	 5.11	 1.1	 0.0	 0.33	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5838	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	5839	 1	 218.5	 93.7	 0.058873	 0.241127	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5840	 1	 70.18	 19.5	 0.0	 3.59	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5841	 1	 2.51	 -1.64	 0.0	 6.26	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	5842	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	5843	 1	 -0.18	 -1.42	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	5844	 1	 148.0	 26.1	 0.0	 9.44	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5845	 1	 159.5	 42.0	 0.0	 2.3	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5846	 1	 -2.09	 -1.43	 0.0	 48.397495	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	5847	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	5848	 1	 0.0	 -0.0	 0.0	 28.93	 0	    1.00000	    0.00000	 380.0	 1	    1.20000	    0.80000;
	5849	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	5850	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	5851	 1	 13.9	 1.9	 0.0	 3.72	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5852	 1	 0.0	 0.0	 0.359411	 37.9409	 0	    1.00000	    0.00000	 380.0	 19	    1.10000	    0.90000;
	5853	 1	 130.5	 18.6	 0.0	 4.56	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5854	 1	 -24.63	 159.9	 0.141735	 64.738265	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	5855	 1	 28.63	 7.3	 0.0	 4.36	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	5856	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	5857	 1	 77.19	 26.5	 0.0	 6.2	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5858	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	5859	 1	 14.15	 3.8	 0.0	 0.47	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5860	 1	 0.0	 -0.0	 0.039173	 0.830827	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	5861	 1	 90.5	 12.8	 0.0	 101.1	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	5862	 1	 22.73	 5.8	 0.0	 0.51	 0	    1.00000	    0.00000	 110.0	 3	    1.10000	    0.90000;
	5863	 1	 84.79	 12.5	 0.0	 2.55	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5864	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	5865	 1	 76.6	 10.9	 0.0	 1.33	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5866	 1	 7.01	 1.8	 0.0	 35.44	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	5867	 1	 262.29	 -6.21	 0.038838	 0.691162	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	5868	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	5869	 1	 34.64	 21.4	 0.0	 0.02	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5870	 1	 119.9	 17.1	 0.0	 8.99	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5871	 1	 0.0	 -0.0	 0.0	 0.66	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5872	 1	 36.34	 10.4	 0.0	 2.67	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5873	 1	 -7.91	 2.6	 0.0	 1.77	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5874	 1	 148.9	 23.5	 0.019355	 6.560645	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	5875	 1	 26.13	 9.7	 0.0	 2.37	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5876	 1	 -0.0	 0.0	 0.0	 0.99	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5877	 1	 110.8	 36.9	 0.0	 23.2	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5878	 1	 25.23	 11.9	 0.0	 18.72	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	5879	 1	 18.2	 2.6	 0.0	 6.72	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5880	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	5881	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 8	    1.10000	    0.90000;
	5882	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 8	    1.10000	    0.90000;
	5883	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 8	    1.10000	    0.90000;
	5884	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 8	    1.10000	    0.90000;
	5885	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	5886	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	5887	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 8	    1.10000	    0.90000;
	5888	 1	 171.18	 28.49	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5889	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 8	    1.10000	    0.90000;
	5890	 1	 -0.18	 -1.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	5891	 1	 76.6	 10.9	 0.0	 7.8	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5892	 1	 -0.0	 0.0	 0.649603	 14.162287	 0	    1.00000	    0.00000	 220.0	 19	    1.20000	    0.80000;
	5893	 1	 22.93	 8.6	 0.05769	 0.49231	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	5894	 1	 92.3	 13.1	 0.0	 2.09	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5895	 1	 144.8	 39.7	 0.0	 12.64	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5896	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	5897	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	5898	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	5899	 1	 0.0	 -0.0	 0.037721	 21.232279	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	5900	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	5901	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	5902	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	5903	 1	 449.4	 14.6	 0.0	 87.31	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	5904	 1	 0.0	 0.0	 0.0	 0.2	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	5905	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 14.4	 1	    1.10000	    0.90000;
	5906	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 6	    1.10000	    0.90000;
	5907	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5908	 1	 394.9	 -17.3	 0.0	 30.22	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	5909	 1	 -0.0	 -0.0	 0.0	 14.28	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	5910	 1	 158.8	 105.3	 0.0	 21.76	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	5911	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	5912	 1	 0.0	 0.0	 0.0	 154.25	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	5913	 1	 -0.0	 -0.0	 0.096569	 0.453431	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	5914	 1	 -0.0	 0.0	 0.0	 2.67	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5915	 1	 1.7	 -5.9	 0.290764	 53.977697	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	5916	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	5917	 1	 93.7	 28.5	 0.019768	 0.250232	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	5918	 1	 20.92	 10.3	 0.0	 0.68	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5919	 1	 67.27	 15.9	 0.0	 2.65	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5920	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5921	 1	 -0.0	 -0.0	 0.0	 6.42	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5922	 1	 265.7	 113.5	 0.0	 1.85	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5923	 1	 54.96	 31.7	 0.0	 8.58	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	5924	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 9	    1.10000	    0.90000;
	5925	 1	 5.51	 2.0	 0.0	 0.46	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	5926	 1	 58.56	 15.9	 0.0	 3.75	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	5927	 1	 -0.0	 -0.0	 0.0	 0.3	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	5928	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	5929	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	5930	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	5931	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	5932	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	5933	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	5934	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	5935	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	5936	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	5937	 1	 0.0	 0.0	 0.0	 1.18	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5938	 1	 37.24	 40.5	 0.0	 67.07	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	5939	 1	 0.0	 -0.0	 0.0	 19.37	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	5940	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	5941	 1	 8.9	 1.3	 0.0	 3.55	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5942	 1	 76.6	 10.9	 0.0	 3.24	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5943	 1	 1.9	 0.7	 0.0	 1.34	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	5944	 1	 0.0	 0.0	 0.0	 0.57	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5945	 1	 0.0	 0.0	 0.233271	 18.215327	 0	    1.00000	    0.00000	 380.0	 14	    1.10000	    0.90000;
	5946	 1	 -0.0	 -0.0	 0.0	 23.74	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	5947	 1	 0.0	 0.0	 0.0	 17.54	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5948	 1	 -0.0	 -0.0	 0.0	 0.89	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5949	 1	 -0.0	 -0.0	 0.0	 107.36	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	5950	 1	 27.57	 -33.38	 0.0	 13.08	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	5951	 1	 -0.0	 0.0	 0.038161	 34.951839	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	5952	 1	 0.0	 0.0	 0.0	 1.12	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5953	 1	 32.84	 20.3	 0.0	 7.23	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5954	 1	 24.93	 22.9	 0.0	 2.47	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5955	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	5956	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	5957	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	5958	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	5959	 1	 347.7	 96.6	 0.0	 101.73	 0	    1.00000	    0.00000	 380.0	 16	    1.10000	    0.90000;
	5960	 1	 123.1	 23.5	 0.039429	 0.000571	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5961	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	5962	 1	 74.78	 -31.4	 0.0	 1.74	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	5963	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	5964	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 14.4	 1	    1.10000	    0.90000;
	5965	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 15.0	 1	    1.10000	    0.90000;
	5966	 1	 0.0	 0.0	 0.0	 0.91	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5967	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 8	    1.20000	    0.80000;
	5968	 1	 44.35	 19.3	 0.0	 3.25	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	5969	 1	 0.0	 -0.0	 0.0	 5.66	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5970	 1	 6.31	 -0.0	 0.0	 0.42	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	5971	 1	 2.5	 -0.0	 0.0	 0.8	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5972	 1	 131.35	 63.6	 0.0	 8.55	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	5973	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	5974	 1	 14.72	 5.3	 0.0	 0.49	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	5975	 1	 111.4	 15.9	 0.0	 1.04	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5976	 1	 -0.0	 -0.0	 0.0	 3.51	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5977	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	5978	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	5979	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	5980	 1	 18.22	 2.3	 0.0	 0.97	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5981	 1	 79.29	 40.1	 0.040286	 34.579857	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	5982	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	5983	 1	 35.44	 22.0	 0.0	 0.61	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5984	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	5985	 1	 0.0	 -0.0	 0.0	 3.64	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	5986	 1	 4.2	 2.0	 0.0	 0.21	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5987	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	5988	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	5989	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	5990	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	5991	 1	 -0.0	 0.0	 0.0	 1.01	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	5992	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	5993	 1	 125.0	 107.2	 0.202178	 53.177543	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	5994	 1	 0.0	 -0.0	 0.0	 0.53	 0	    1.00000	    0.00000	 110.0	 3	    1.10000	    0.90000;
	5995	 1	 0.0	 -0.1	 0.080273	 -0.060205	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	5996	 1	 2.5	 -0.0	 0.0	 0.11	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	5997	 1	 0.0	 0.0	 0.119927	 0.900061	 0	    1.00000	    0.00000	 220.0	 14	    1.10000	    0.90000;
	5998	 1	 0.0	 0.0	 0.0	 23.27	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	5999	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	6000	 1	 -0.0	 -0.0	 0.16	 31.35	 0	    1.00000	    0.00000	 380.0	 7	    1.10000	    0.90000;
	6001	 1	 0.0	 0.0	 0.0	 1.51	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6002	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	6003	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	6004	 1	 0.0	 -0.0	 0.0	 6.9	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6005	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	6006	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	6007	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	6008	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	6009	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 6.3	 1	    1.10000	    0.90000;
	6010	 1	 113.0	 57.3	 0.0	 12.82	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6011	 1	 135.9	 4.0	 0.392133	 6.065901	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6012	 1	 0.0	 0.0	 0.117038	 0.062468	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	6013	 1	 62.7	 9.0	 0.0	 8.02	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6014	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	6015	 1	 -0.0	 -0.0	 0.0	 0.88	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6016	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	6017	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 8	    1.10000	    0.90000;
	6018	 1	 195.2	 92.2	 0.0	 11.67	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	6019	 1	 204.0	 29.0	 0.0	 2.28	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6020	 1	 0.0	 -0.0	 0.0	 28.29	 0	    1.00000	    0.00000	 380.0	 1	    1.20000	    0.80000;
	6021	 1	 0.0	 -0.0	 0.0	 0.05	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	6022	 1	 40.24	 24.9	 0.0	 1.81	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6023	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 8	    1.10000	    0.90000;
	6024	 1	 225.8	 123.0	 0.305983	 9.235014	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	6025	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	6026	 1	 65.27	 6.0	 0.0	 3.89	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6027	 1	 47.65	 7.1	 0.0	 7.3	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6028	 1	 0.0	 -0.0	 0.0	 4.05	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	6029	 1	 61.67	 28.3	 0.0	 0.1	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	6030	 1	 173.0	 11.3	 0.0	 8.41	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	6031	 1	 0.0	 -0.0	 0.0	 1.23	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6032	 1	 128.0	 72.9	 0.0	 14.95	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	6033	 1	 5.31	 2.0	 0.0	 0.17	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6034	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 9	    1.10000	    0.90000;
	6035	 1	 40.34	 10.4	 0.0	 7.02	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	6036	 1	 0.5	 12.4	 0.0	 0.25	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	6037	 1	 4.2	 0.6	 0.0	 2.84	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6038	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 15.75	 1	    1.10000	    0.90000;
	6039	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	6040	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	6041	 1	 -0.0	 -0.0	 0.0	 0.34	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6042	 1	 -0.0	 0.0	 0.0	 5.16	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6043	 1	 13.01	 3.8	 0.0	 3.59	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6044	 1	 0.0	 0.0	 0.009025	 43.164575	 0	    1.00000	    0.00000	 380.0	 16	    1.10000	    0.90000;
	6045	 1	 64.77	 6.4	 0.0	 3.84	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6046	 1	 -0.0	 -0.0	 0.0	 84.33	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	6047	 1	 9.91	 5.4	 0.0	 4.6	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6048	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	6049	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 7	    1.10000	    0.90000;
	6050	 1	 2.2	 0.5	 0.0	 2.31	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	6051	 1	 0.0	 0.0	 0.0	 18.49	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	6052	 1	 -0.0	 0.0	 0.039884	 3.820116	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6053	 1	 -0.0	 0.0	 0.0	 19.2	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	6054	 1	 -0.54	 -1.0	 0.0	 4.8	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6055	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	6056	 1	 0.0	 0.0	 0.18226	 20.898116	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	6057	 1	 0.0	 0.0	 0.0	 1.18	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	6058	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 7	    1.10000	    0.90000;
	6059	 1	 230.42	 -7.87	 0.0	 5.13	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6060	 1	 44.05	 14.6	 0.0	 0.6	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	6061	 1	 -0.0	 0.0	 0.039589	 50.801364	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	6062	 1	 -0.0	 -0.0	 0.0	 1.48	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	6063	 1	 39.14	 7.7	 0.0	 11.68	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6064	 1	 -0.0	 -0.0	 0.060014	 -0.060014	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6065	 1	 132.4	 -10.4	 0.0	 3.02	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	6066	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	6067	 1	 0.0	 0.01	 0.0	 2.1	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	6068	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	6069	 1	 39.84	 17.6	 0.231215	 2.096955	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	6070	 1	 25.43	 7.9	 0.0	 1.03	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	6071	 1	 145.8	 42.4	 0.0	 2.34	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	6072	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	6073	 1	 -0.0	 -0.0	 0.0	 0.09	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6074	 1	 52.6	 7.5	 0.0	 3.66	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6075	 1	 0.0	 0.0	 0.0	 49.86	 0	    1.00000	    0.00000	 380.0	 19	    1.10000	    0.90000;
	6076	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	6077	 1	 13.64	 9.0	 0.0	 1.7	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6078	 1	 137.8	 22.9	 0.0	 6.55	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	6079	 1	 0.0	 0.0	 0.0	 20.86	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	6080	 1	 0.0	 0.0	 0.0	 11.85	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	6081	 1	 -0.62	 -0.0	 0.0	 75.073626	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	6082	 1	 0.0	 -0.0	 0.0	 30.64	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	6083	 1	 11.11	 4.1	 0.0	 0.8	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6084	 1	 310.2	 4.5	 0.0	 8.51	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6085	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	6086	 1	 128.18	 35.03	 0.0	 1.76	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6087	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	6088	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	6089	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	6090	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	6091	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	6092	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	6093	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	6094	 1	 6.71	 1.3	 0.0	 0.34	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6095	 1	 -0.0	 8.5	 0.0	 0.67	 0	    1.00000	    0.00000	 150.0	 9	    1.20000	    0.80000;
	6096	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	6097	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	6098	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	6099	 1	 91.4	 -88.2	 0.0	 0.29	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	6100	 1	 0.0	 -0.0	 0.0	 1.41	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	6101	 1	 -0.0	 -0.0	 0.0	 0.67	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6102	 1	 -0.0	 0.0	 0.0	 2.69	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	6103	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 9	    1.10000	    0.90000;
	6104	 1	 110.7	 94.3	 0.0	 6.43	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	6105	 1	 153.4	 86.8	 0.0	 53.98	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	6106	 1	 0.2	 109.4	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 3	    1.20000	    0.80000;
	6107	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	6108	 1	 121.4	 40.0	 0.0	 11.16	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	6109	 1	 175.2	 70.7	 0.0	 109.1	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	6110	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6111	 1	 29.03	 10.1	 0.0	 2.41	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	6112	 1	 -0.0	 -0.0	 0.0	 4.37	 0	    1.00000	    0.00000	 380.0	 9	    1.20000	    0.80000;
	6113	 1	 27.03	 69.9	 0.230833	 9.787258	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	6114	 1	 0.0	 0.0	 0.0	 14.62	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	6115	 1	 325.2	 38.1	 0.0	 19.99	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	6116	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6117	 1	 113.4	 61.9	 0.0	 1.51	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	6118	 1	 200.19	 90.59	 0.0	 24.07	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	6119	 1	 62.07	 20.0	 0.0	 0.25	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	6120	 1	 0.0	 0.0	 0.0	 12.88	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	6121	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	6122	 1	 7.91	 3.8	 0.0	 0.22	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6123	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	6124	 1	 0.0	 -0.0	 0.019597	 0.530403	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	6125	 1	 34.9	 5.0	 0.0	 1.72	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6126	 1	 0.0	 -0.0	 0.0	 0.71	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6127	 1	 -0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	6128	 1	 -0.0	 -0.0	 1.098741	 87.634731	 0	    1.00000	    0.00000	 380.0	 3	    1.20000	    0.80000;
	6129	 1	 144.5	 40.9	 0.0	 17.35	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	6130	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	6131	 1	 20.22	 5.7	 0.0	 3.25	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6132	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	6133	 1	 -0.0	 -0.0	 0.349725	 3.347992	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	6134	 1	 0.0	 -0.0	 0.058236	 0.481764	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6135	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 20	    1.10000	    0.90000;
	6136	 1	 195.6	 -1.0	 0.0	 3.19	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6137	 1	 29.3	 90.5	 0.475938	 17.413385	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	6138	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	6139	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	6140	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	6141	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	6142	 1	 -42.25	 2.8	 0.0	 0.7	 0	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	6143	 1	 26.73	 9.6	 0.0	 2.19	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	6144	 1	 -0.0	 0.0	 0.0	 5.06	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6145	 1	 -0.0	 -0.3	 0.119513	 -0.089635	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	6146	 1	 -0.0	 -0.0	 0.090774	 6.020444	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	6147	 1	 59.17	 19.3	 0.0	 1.16	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	6148	 1	 200.65	 30.72	 0.0	 9.72	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6149	 1	 -0.0	 0.0	 0.0	 42.131932	 0	    1.00000	    0.00000	 380.0	 24	    1.10000	    0.90000;
	6150	 1	 12.71	 2.5	 0.0	 0.83	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6151	 1	 0.0	 -0.0	 0.497694	 -0.387095	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	6152	 1	 0.0	 0.0	 0.0	 2.06	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6153	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6154	 1	 1110.6	 290.8	 0.535741	 178.433223	 0	    1.00000	    0.00000	 380.0	 14	    1.10000	    0.90000;
	6155	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	6156	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	6157	 1	 -3.2	 -1.05	 0.0	 48.471563	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	6158	 1	 9.01	 4.9	 0.0	 0.64	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6159	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	6160	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	6161	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	6162	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	6163	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	6164	 1	 50.3	 7.2	 0.0	 8.06	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6165	 1	 -0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	6166	 1	 -0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	6167	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	6168	 1	 -0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	6169	 1	 172.5	 48.7	 0.0	 54.92	 0	    1.00000	    0.00000	 380.0	 14	    1.10000	    0.90000;
	6170	 1	 -0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	6171	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	6172	 1	 54.32	 7.98	 0.0	 13.58	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6173	 1	 318.3	 76.8	 0.140637	 63.274356	 0	    1.00000	    0.00000	 380.0	 7	    1.10000	    0.90000;
	6174	 1	 53.86	 18.7	 0.0	 3.48	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	6175	 1	 5.11	 -0.1	 0.0	 3.73	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6176	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6177	 1	 52.46	 5.2	 0.0	 11.9	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6178	 1	 5.81	 1.7	 0.0	 0.42	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6179	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	6180	 1	 -0.0	 0.0	 0.0	 39.36	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	6181	 1	 67.07	 34.0	 0.436529	 7.949365	 0	    1.00000	    0.00000	 220.0	 11	    1.10000	    0.90000;
	6182	 1	 0.0	 -0.0	 0.0	 10.1	 0	    1.00000	    0.00000	 380.0	 15	    1.20000	    0.80000;
	6183	 1	 0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	6184	 1	 -2.29	 0.3	 0.077775	 2.712225	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6185	 1	 0.0	 0.0	 0.01953	 10.17047	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	6186	 1	 -0.0	 0.0	 0.0	 0.79	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6187	 1	 149.0	 19.8	 0.0	 23.89	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	6188	 1	 -806.3	 -50.1	 0.0	 4.19	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	6189	 1	 -0.0	 0.0	 0.0	 17.29	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6190	 1	 -0.17	 -8.06	 0.0	 0.83	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	6191	 1	 0.0	 0.0	 0.1161	 64.50319	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	6192	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	6193	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	6194	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	6195	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	6196	 1	 -0.0	 -0.0	 0.0	 7.6	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	6197	 1	 27.63	 9.2	 0.0	 0.58	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	6198	 1	 6.73	 14.7	 0.0	 11.51	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6199	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	6200	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 6.3	 1	    1.10000	    0.90000;
	6201	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	6202	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	6203	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	6204	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	6205	 1	 0.0	 0.0	 0.0	 1.44	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6206	 1	 -20.56	 -3.88	 0.0	 1.72	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6207	 1	 0.0	 -0.0	 0.0	 122.87	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	6208	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	6209	 1	 119.3	 106.3	 0.058752	 6.33104	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6210	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	6211	 1	 57.76	 16.0	 0.0	 2.39	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6212	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	6213	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	6214	 1	 11.01	 3.1	 0.0	 0.14	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	6215	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	6216	 1	 14.26	 -1.13	 0.0	 0.65	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6217	 1	 0.0	 0.0	 0.0	 8.95	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6218	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	6219	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	6220	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	6221	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	6222	 1	 19.52	 6.4	 0.0	 0.03	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6223	 1	 0.0	 -0.0	 0.0	 42.02	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	6224	 1	 -0.0	 -0.0	 0.0	 8.08	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6225	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 7	    1.10000	    0.90000;
	6226	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	6227	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	6228	 1	 190.7	 52.0	 0.0	 20.57	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6229	 1	 44.35	 14.8	 0.0	 0.36	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	6230	 1	 -0.0	 -0.0	 0.0	 93.61	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	6231	 1	 269.22	 97.24	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 24	    1.10000	    0.90000;
	6232	 1	 188.48	 128.3	 0.0	 18.06	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	6233	 1	 72.18	 49.6	 0.0	 37.52	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	6234	 1	 24.93	 9.6	 0.0	 0.09	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6235	 1	 24.23	 5.5	 0.0	 1.18	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	6236	 1	 33.54	 20.8	 0.0	 2.42	 0	    1.00000	    0.00000	 150.0	 9	    1.20000	    0.80000;
	6237	 1	 0.0	 -0.0	 0.0	 3.24	 0	    1.00000	    0.00000	 220.0	 8	    1.10000	    0.90000;
	6238	 1	 57.06	 15.6	 0.0	 2.03	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6239	 1	 -10.71	 3.5	 0.0	 0.58	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6240	 1	 47.15	 15.7	 0.0	 5.41	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6241	 1	 0.0	 -0.0	 0.0	 0.56	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6242	 1	 105.0	 18.0	 0.0	 5.41	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6243	 1	 44.55	 27.6	 0.0	 1.86	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6244	 1	 2.7	 0.4	 0.0	 4.05	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6245	 1	 -0.0	 0.0	 0.0	 6.76	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	6246	 1	 100.42	 58.37	 0.0	 40.35	 0	    1.00000	    0.00000	 380.0	 13	    1.10000	    0.90000;
	6247	 1	 9.51	 5.9	 0.0	 0.7	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6248	 1	 0.0	 -0.0	 0.019898	 2.400102	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	6249	 1	 -0.0	 0.0	 0.0	 0.54	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6250	 1	 -0.0	 0.0	 0.0	 7.91	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	6251	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6252	 1	 -0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	6253	 1	 -11.81	 -4.02	 0.0	 0.37	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6254	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	6255	 1	 -0.0	 -0.0	 0.0	 0.74	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6256	 1	 -0.0	 -0.0	 0.0	 0.88	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6257	 1	 61.4	 8.8	 0.0	 4.24	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6258	 1	 70.78	 19.6	 0.0	 7.9	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6259	 1	 303.7	 247.8	 0.0	 8.79	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	6260	 1	 24.93	 8.2	 0.0	 0.6	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	6261	 1	 145.7	 83.6	 0.135375	 53.822175	 0	    1.00000	    0.00000	 380.0	 18	    1.20000	    0.80000;
	6262	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	6263	 1	 66.97	 45.1	 0.0	 2.04	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6264	 1	 184.7	 71.5	 0.0	 95.42	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	6265	 1	 70.78	 28.0	 0.0	 1.49	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6266	 1	 35.49	 11.53	 0.0	 1.31	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6267	 1	 5.71	 2.1	 0.0	 0.31	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	6268	 1	 -0.0	 -0.0	 0.0	 60.39	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	6269	 1	 -0.0	 0.0	 0.0	 1.63	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	6270	 1	 5.5	 0.8	 0.0	 9.28	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6271	 1	 9.61	 62.4	 0.353037	 29.405802	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6272	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	6273	 1	 11.91	 4.3	 0.0	 0.47	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	6274	 1	 -0.0	 0.0	 0.0	 11.4	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6275	 1	 35.84	 14.1	 0.0	 50.11	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	6276	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	6277	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	6278	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	6279	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	6280	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	6281	 1	 22.22	 6.0	 0.0	 0.43	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6282	 1	 0.0	 0.0	 0.0	 8.45	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	6283	 1	 214.4	 52.9	 0.0	 2.59	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	6284	 1	 124.8	 23.5	 0.0	 5.84	 0	    1.00000	    0.00000	 220.0	 16	    1.10000	    0.90000;
	6285	 1	 0.0	 -0.0	 0.0	 14.49	 0	    1.00000	    0.00000	 380.0	 3	    1.20000	    0.80000;
	6286	 1	 -253.24	 -29.59	 0.0	 10.61	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6287	 1	 0.5	 0.3	 0.0	 0.07	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6288	 1	 -0.0	 0.0	 0.0	 1.09	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	6289	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6290	 1	 197.7	 67.65	 0.0	 13.58	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6291	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 17	    1.10000	    0.90000;
	6292	 1	 -0.0	 -0.0	 0.0	 7.3	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6293	 1	 80.59	 7.3	 0.0	 18.92	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6294	 1	 199.6	 24.4	 0.0	 10.6	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6295	 1	 -0.18	 -1.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	6296	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	6297	 1	 165.3	 7.4	 0.0	 28.32	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	6298	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	6299	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	6300	 1	 26.63	 9.7	 0.0	 0.75	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	6301	 1	 46.55	 -18.9	 0.0	 14.78	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	6302	 1	 -0.0	 -0.0	 0.0	 3.56	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6303	 1	 81.49	 25.1	 0.0	 0.36	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6304	 1	 2.5	 0.6	 0.0	 1.06	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6305	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 10.5	 1	    1.20000	    0.80000;
	6306	 1	 0.0	 -0.0	 0.0	 2.27	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6307	 1	 30.53	 9.0	 0.0	 1.9	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	6308	 1	 90.5	 12.8	 0.0	 15.77	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6309	 1	 2.4	 0.9	 0.0	 1.18	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	6310	 1	 42.45	 -10.2	 0.0	 10.02	 0	    1.00000	    0.00000	 220.0	 23	    1.10000	    0.90000;
	6311	 1	 -0.0	 -0.0	 0.0	 0.3	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	6312	 1	 131.7	 32.9	 0.0	 108.56	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	6313	 1	 33.5	 4.8	 0.0	 3.33	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6314	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 6.3	 1	    1.10000	    0.90000;
	6315	 1	 60.07	 -4.7	 0.0	 0.25	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	6316	 1	 0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 11	    1.10000	    0.90000;
	6317	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 7	    1.10000	    0.90000;
	6318	 1	 8.91	 2.5	 0.0	 0.68	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6319	 1	 11.41	 -3.7	 0.0	 0.1	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6320	 1	 133.4	 29.4	 0.0	 10.87	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6321	 1	 26.13	 2.7	 0.0	 1.7	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6322	 1	 -113.33	 45.2	 0.0	 67.52	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	6323	 1	 -9.01	 21.8	 0.0	 4.58	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6324	 1	 -0.0	 0.0	 0.0	 3.81	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6325	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	6326	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	6327	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	6328	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	6329	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	6330	 1	 51.06	 16.5	 0.0	 2.37	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	6331	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	6332	 1	 -0.0	 -0.0	 0.0	 16.38	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	6333	 1	 50.36	 24.3	 0.0	 3.64	 0	    1.00000	    0.00000	 220.0	 8	    1.10000	    0.90000;
	6334	 1	 -0.0	 -0.0	 0.0	 28.03	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6335	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	6336	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	6337	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	6338	 1	 19.52	 11.0	 0.0	 1.11	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	6339	 1	 0.0	 -0.0	 0.0	 18.33	 0	    1.00000	    0.00000	 380.0	 1	    1.20000	    0.80000;
	6340	 1	 366.6	 57.4	 0.0	 60.78	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	6341	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	6342	 1	 10.81	 3.6	 0.0	 0.26	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	6343	 1	 0.0	 0.0	 0.054465	 9.927347	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	6344	 1	 0.0	 0.0	 0.0	 12.64	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	6345	 1	 -0.0	 0.0	 0.0	 1.58	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6346	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	6347	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	6348	 1	 96.2	 37.3	 0.0	 0.19	 0	    1.00000	    0.00000	 110.0	 23	    1.10000	    0.90000;
	6349	 1	 269.9	 12.4	 0.0	 4.09	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	6350	 1	 -0.0	 0.0	 0.040436	 -0.040436	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6351	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 8	    1.10000	    0.90000;
	6352	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 8	    1.10000	    0.90000;
	6353	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 8	    1.10000	    0.90000;
	6354	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 8	    1.10000	    0.90000;
	6355	 1	 0.0	 -0.0	 0.0	 7.13	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	6356	 1	 -0.0	 0.0	 0.120861	 4.779355	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	6357	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 8	    1.10000	    0.90000;
	6358	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 8	    1.10000	    0.90000;
	6359	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	6360	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 8	    1.10000	    0.90000;
	6361	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 8	    1.10000	    0.90000;
	6362	 1	 0.0	 -0.0	 0.569185	 79.269885	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	6363	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	6364	 1	 -0.0	 0.0	 0.135375	 8.900675	 0	    1.00000	    0.00000	 380.0	 18	    1.20000	    0.80000;
	6365	 1	 193.1	 69.9	 0.0	 28.91	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	6366	 1	 0.0	 -0.0	 0.699934	 14.325886	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	6367	 1	 92.4	 22.0	 0.019713	 6.930287	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6368	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	6369	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	6370	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	6371	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	6372	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	6373	 1	 -0.0	 0.0	 0.0	 4.03	 0	    1.00000	    0.00000	 220.0	 8	    1.10000	    0.90000;
	6374	 1	 18.62	 6.8	 0.0	 0.92	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	6375	 1	 14.32	 7.2	 0.0	 3.62	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	6376	 1	 39.94	 13.3	 0.0	 0.85	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	6377	 1	 43.55	 14.3	 0.0	 1.63	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	6378	 1	 0.0	 -0.0	 0.0	 3.4	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	6379	 1	 68.48	 -10.6	 0.0	 2.65	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	6380	 1	 -0.0	 0.0	 0.0	 18.8	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	6381	 1	 57.0	 39.9	 0.0	 153.693557	 0	    1.00000	    0.00000	 380.0	 9	    1.20000	    0.80000;
	6382	 1	 31.2	 4.4	 0.0	 1.61	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6383	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	6384	 1	 -0.0	 -0.0	 0.0	 31.35	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	6385	 1	 24.13	 29.4	 0.0	 146.51	 0	    1.00000	    0.00000	 380.0	 3	    1.20000	    0.80000;
	6386	 1	 -0.0	 -0.0	 0.116759	 0.732701	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	6387	 1	 0.0	 -0.0	 0.0	 0.57	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6388	 1	 163.63	 23.0	 0.0	 5.11	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	6389	 1	 165.8	 44.0	 0.0	 6.15	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6390	 1	 -0.73	 -1.93	 0.0	 0.36	 0	    1.00000	    0.00000	 220.0	 12	    1.10000	    0.90000;
	6391	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	6392	 1	 65.07	 15.0	 0.0	 1.37	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6393	 1	 22.12	 6.5	 0.0	 0.94	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	6394	 1	 235.0	 58.9	 0.0	 14.47	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6395	 1	 -0.0	 0.0	 0.0	 104.15	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	6396	 1	 3.7	 0.6	 0.0	 5.81	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6397	 1	 5.11	 2.3	 0.0	 0.94	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6398	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	6399	 1	 20.82	 8.2	 0.0	 2.96	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6400	 1	 220.79	 13.21	 0.039607	 8.600393	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6401	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	6402	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	6403	 1	 0.0	 -0.0	 0.0	 18.66	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	6404	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	6405	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	6406	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	6407	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	6408	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	6409	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	6410	 1	 1.3	 -0.0	 0.0	 1.48	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6411	 1	 -13.71	 4.5	 0.0	 0.08	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6412	 1	 8.3	 1.2	 0.0	 1.6	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6413	 1	 23.23	 7.6	 0.0	 0.88	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	6414	 1	 -1235.46	 -43.0	 0.0	 90.6	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	6415	 1	 0.0	 -0.0	 0.255719	 9.892154	 0	    1.00000	    0.00000	 220.0	 18	    1.20000	    0.80000;
	6416	 1	 306.5	 57.7	 0.411758	 4.816868	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6417	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	6418	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	6419	 1	 72.28	 6.6	 0.0	 1.42	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6420	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	6421	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	6422	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	6423	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6424	 1	 -0.0	 0.0	 0.038061	 1.491939	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	6425	 1	 -0.0	 0.0	 0.174934	 1.86394	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6426	 1	 37.6	 5.4	 0.0	 5.37	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6427	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	6428	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	6429	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	6430	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	6431	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	6432	 1	 -0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	6433	 1	 -0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	6434	 1	 0.0	 -0.0	 0.0	 0.51	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6435	 1	 -0.0	 -0.0	 0.0	 9.57	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	6436	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 9	    1.10000	    0.90000;
	6437	 1	 -67.31	 -44.04	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	6438	 1	 0.0	 0.0	 0.0	 3.16	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	6439	 1	 35.24	 12.7	 0.0	 3.4	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	6440	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	6441	 1	 17.82	 5.9	 0.0	 0.64	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	6442	 1	 33.74	 11.8	 0.0	 1.66	 0	    1.00000	    0.00000	 110.0	 3	    1.10000	    0.90000;
	6443	 1	 60.97	 19.7	 0.0	 2.22	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	6444	 1	 16.7	 2.4	 0.0	 3.18	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6445	 1	 10.91	 3.6	 0.0	 0.26	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	6446	 1	 -0.0	 0.0	 0.26	 6.56	 0	    1.00000	    0.00000	 220.0	 19	    1.20000	    0.80000;
	6447	 1	 -0.0	 0.0	 0.0	 20.48	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	6448	 1	 -0.0	 -0.0	 0.0	 72.64	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	6449	 1	 0.0	 0.0	 0.0	 1.23	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6450	 1	 62.07	 20.7	 0.0	 6.92	 0	    1.00000	    0.00000	 220.0	 21	    1.10000	    0.90000;
	6451	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	6452	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	6453	 1	 0.0	 0.0	 0.135375	 53.752175	 0	    1.00000	    0.00000	 380.0	 18	    1.20000	    0.80000;
	6454	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	6455	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	6456	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	6457	 1	 0.0	 0.0	 0.27735	 33.218875	 0	    1.00000	    0.00000	 380.0	 3	    1.20000	    0.80000;
	6458	 1	 0.0	 0.0	 0.278651	 111.707791	 0	    1.00000	    0.00000	 380.0	 3	    1.20000	    0.80000;
	6459	 1	 0.0	 0.0	 0.0	 91.64	 0	    1.00000	    0.00000	 380.0	 20	    1.20000	    0.80000;
	6460	 1	 193.0	 17.6	 0.0	 4.74	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6461	 1	 0.0	 0.0	 0.194155	 -0.145616	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	6462	 1	 266.0	 62.8	 0.0	 1.95	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6463	 1	 -0.0	 0.0	 0.224562	 1.022222	 0	    1.00000	    0.00000	 380.0	 14	    1.10000	    0.90000;
	6464	 1	 -0.0	 -0.0	 0.0	 8.33	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	6465	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 7	    1.10000	    0.90000;
	6466	 1	 0.0	 0.0	 0.0	 1.02	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6467	 1	 35.24	 12.3	 0.0	 0.3	 0	    1.00000	    0.00000	 110.0	 3	    1.10000	    0.90000;
	6468	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6469	 1	 -15.02	 4.9	 0.0	 0.26	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6470	 1	 99.1	 -98.6	 0.0	 6.83	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6471	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	6472	 1	 -0.0	 0.0	 0.0	 51.43	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	6473	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	6474	 1	 25.33	 12.7	 0.181549	 6.830889	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	6475	 1	 45.05	 13.2	 0.0	 44.93	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6476	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	6477	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	6478	 1	 -0.0	 0.0	 0.0	 6.72	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	6479	 1	 19.4	 2.8	 0.0	 2.53	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6480	 1	 -0.0	 -0.0	 0.0	 13.44	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	6481	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	6482	 1	 303.6	 47.5	 0.0	 14.96	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	6483	 1	 30.03	 9.7	 0.0	 4.1	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	6484	 1	 117.4	 12.5	 0.0	 5.16	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	6485	 1	 -0.0	 -0.0	 0.0	 5.12	 0	    1.00000	    0.00000	 220.0	 22	    1.10000	    0.90000;
	6486	 1	 -0.0	 -0.0	 0.0	 0.05	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6487	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	6488	 1	 -0.0	 -0.0	 0.0	 28.168167	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	6489	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6490	 1	 0.0	 0.0	 0.0	 3.01	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6491	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 10.5	 1	    1.10000	    0.90000;
	6492	 1	 32.84	 9.3	 0.0	 0.76	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6493	 1	 77.19	 47.8	 0.0	 2.08	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6494	 1	 0.0	 0.0	 0.0	 0.33	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	6495	 1	 0.0	 0.0	 0.0	 0.51	 0	    1.00000	    0.00000	 220.0	 3	    1.20000	    0.80000;
	6496	 1	 -0.0	 0.0	 0.0	 3.22	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	6497	 1	 485.5	 -63.38	 0.0	 34.92	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6498	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	6499	 1	 296.8	 77.7	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	6500	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	6501	 1	 -0.0	 -0.0	 0.03995	 11.24005	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6502	 1	 11.21	 4.4	 0.0	 0.25	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	6503	 1	 50.06	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 7	    1.10000	    0.90000;
	6504	 1	 39.0	 5.5	 0.0	 1.3	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6505	 1	 -0.0	 -0.0	 0.0	 0.68	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6506	 1	 19.52	 5.6	 0.0	 1.46	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	6507	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 9	    1.10000	    0.90000;
	6508	 1	 -0.0	 0.0	 0.0	 0.8	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6509	 1	 142.5	 523.5	 0.0	 34.96	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	6510	 1	 97.0	 -539.3	 0.0	 50.89	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	6511	 1	 60.07	 45.0	 0.0	 0.12	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	6512	 1	 0.0	 0.0	 0.0	 102.31354	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	6513	 1	 -0.0	 -0.0	 0.0	 420.1	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	6514	 1	 0.0	 -0.0	 0.17	 11.68	 0	    1.00000	    0.00000	 220.0	 21	    1.10000	    0.90000;
	6515	 1	 5.51	 2.0	 0.0	 0.69	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	6516	 1	 13.82	 4.5	 0.0	 0.25	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	6517	 1	 141.2	 33.5	 0.118053	 1.231623	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6518	 1	 1.3	 0.4	 0.0	 1.43	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6519	 1	 31.54	 12.5	 0.050337	 32.519663	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	6520	 1	 5.21	 1.0	 0.0	 0.94	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6521	 1	 16.52	 4.8	 0.0	 0.33	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6522	 1	 0.0	 -0.0	 0.039415	 12.270585	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	6523	 1	 0.0	 -0.0	 0.452023	 8.088382	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	6524	 1	 -0.0	 0.0	 0.0	 9.25	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	6525	 1	 27.43	 13.7	 0.21794	 -0.012536	 0	    1.00000	    0.00000	 380.0	 21	    1.20000	    0.80000;
	6526	 1	 28.13	 10.2	 0.0	 1.73	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	6527	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	6528	 1	 32.8	 4.7	 0.0	 8.02	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6529	 1	 140.2	 11.2	 0.0	 9.1	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6530	 1	 98.2	 19.1	 0.0	 10.92	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6531	 1	 1.0	 1.0	 0.0	 0.27	 0	    1.00000	    0.00000	 110.0	 23	    1.10000	    0.90000;
	6532	 1	 -0.0	 -0.0	 0.0	 0.03	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6533	 1	 52.6	 110.6	 0.0	 2.72	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	6534	 1	 0.0	 0.0	 0.0	 1.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6535	 1	 -0.0	 -0.0	 0.0	 30.98	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	6536	 1	 0.0	 0.0	 0.0	 2.06	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6537	 1	 55.7	 7.9	 0.0	 2.29	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6538	 1	 413.0	 -353.0	 0.0	 8.88	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	6539	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 9	    1.10000	    0.90000;
	6540	 1	 -14.83	 -3.56	 0.0	 0.06	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6541	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	6542	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	6543	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	6544	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	6545	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	6546	 1	 -0.0	 0.0	 0.0	 39.29	 0	    1.00000	    0.00000	 380.0	 9	    1.20000	    0.80000;
	6547	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	6548	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	6549	 1	 22.42	 4.8	 0.0	 0.53	 0	    1.00000	    0.00000	 110.0	 3	    1.10000	    0.90000;
	6550	 1	 0.0	 -0.0	 0.0	 14.69	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	6551	 1	 0.0	 -0.0	 0.057073	 0.012927	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6552	 1	 88.5	 27.4	 0.0	 0.04	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	6553	 1	 5.71	 1.6	 0.0	 0.48	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6554	 1	 -0.0	 0.0	 0.0	 2.06	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	6555	 1	 -0.0	 0.0	 0.0	 7.22	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6556	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6557	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	6558	 1	 -0.0	 0.0	 0.0	 0.54	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6559	 1	 227.6	 37.8	 0.0	 39.33	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	6560	 1	 0.0	 -0.0	 0.0	 6.45	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6561	 1	 37.44	 -28.3	 0.0	 9.28	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	6562	 1	 0.0	 -0.0	 0.0	 31.6	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	6563	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 9.0	 1	    1.10000	    0.90000;
	6564	 1	 0.0	 0.0	 0.0	 9.72	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	6565	 1	 49.45	 30.6	 0.0	 1.57	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6566	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	6567	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	6568	 1	 24.93	 15.4	 0.0	 5.48	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6569	 1	 -0.2	 -1.64	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	6570	 1	 -0.0	 -0.0	 0.287402	 10.710498	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	6571	 1	 0.0	 -0.0	 0.0	 2.13	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6572	 1	 0.0	 0.0	 0.5735	 -0.316856	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6573	 1	 0.0	 0.0	 0.0	 2.7	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6574	 1	 -0.0	 -0.0	 0.0	 53.24	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	6575	 1	 -0.0	 0.0	 0.039781	 0.460219	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6576	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6577	 1	 69.78	 25.0	 0.0	 14.24	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6578	 1	 -0.0	 0.0	 0.0	 18.32	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	6579	 1	 1.1	 0.4	 0.019452	 1.410548	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6580	 1	 -0.0	 0.0	 0.0	 0.24	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	6581	 1	 71.88	 -2.2	 0.0	 0.07	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	6582	 1	 -0.0	 0.0	 0.0	 5.9	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6583	 1	 0.0	 0.0	 0.0	 12.29	 0	    1.00000	    0.00000	 220.0	 22	    1.10000	    0.90000;
	6584	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 14.0	 1	    1.10000	    0.90000;
	6585	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	6586	 1	 -0.0	 0.0	 0.0	 1.75	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6587	 1	 -0.0	 0.0	 0.0	 18.07	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	6588	 1	 15.32	 18.2	 0.0	 27.62	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6589	 1	 -0.0	 -0.0	 0.0	 55.517991	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	6590	 1	 336.3	 104.4	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	6591	 1	 0.0	 0.0	 0.0	 2.91	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	6592	 1	 0.0	 -0.0	 0.304554	 30.256205	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	6593	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	6594	 1	 -0.0	 -0.0	 0.0	 0.7	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6595	 1	 -0.0	 -0.0	 0.587783	 334.58331	 0	    1.00000	    0.00000	 380.0	 3	    1.20000	    0.80000;
	6596	 1	 80.09	 20.0	 0.0	 6.98	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	6597	 1	 199.3	 53.7	 0.0	 12.54	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	6598	 1	 65.6	 -382.0	 0.202178	 57.724057	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	6599	 1	 -37.34	 -13.33	 0.0	 251.33835	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	6600	 1	 -0.0	 0.0	 0.078724	 6.200957	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	6601	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	6602	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	6603	 1	 20.72	 6.8	 0.0	 0.69	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	6604	 1	 170.1	 -9.3	 0.0	 5.97	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6605	 1	 95.51	 17.1	 0.0	 8.5	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6606	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	6607	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	6608	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	6609	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	6610	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	6611	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	6612	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	6613	 1	 219.6	 62.5	 0.039623	 5.500377	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6614	 1	 -0.0	 -0.0	 0.0	 43.44	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	6615	 1	 55.98	 18.47	 0.0	 9.45	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6616	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 10.5	 1	    1.10000	    0.90000;
	6617	 1	 75.38	 21.8	 0.0	 0.63	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6618	 1	 74.98	 46.4	 0.0	 2.74	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6619	 1	 0.0	 -0.0	 0.0	 12.9	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	6620	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	6621	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	6622	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	6623	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	6624	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	6625	 1	 0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 3	    1.10000	    0.90000;
	6626	 1	 -0.0	 0.0	 0.236449	 45.072959	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	6627	 1	 7.0	 1.0	 0.0	 3.58	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6628	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	6629	 1	 12.91	 4.0	 0.0	 1.66	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	6630	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	6631	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	6632	 1	 160.0	 69.2	 0.0	 0.19	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6633	 1	 -0.0	 0.0	 0.0	 1.1	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6634	 1	 97.5	 13.9	 0.0	 29.65	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	6635	 1	 -0.0	 -0.0	 0.0	 0.94	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6636	 1	 349.6	 22.0	 0.0	 10.29	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	6637	 1	 91.1	 36.1	 0.0	 1.01	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	6638	 1	 114.2	 16.3	 0.0	 2.85	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6639	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	6640	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	6641	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	6642	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	6643	 1	 41.05	 31.8	 0.039111	 1.370667	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	6644	 1	 268.56	 29.72	 0.0	 6.5	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	6645	 1	 3.2	 8.3	 0.0	 0.38	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6646	 1	 48.48	 8.7	 0.0	 10.14	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6647	 1	 113.6	 16.2	 0.0	 1.83	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6648	 1	 15.32	 9.5	 0.0	 5.33	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6649	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 10.6	 1	    1.10000	    0.90000;
	6650	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	6651	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	6652	 1	 5.11	 1.9	 0.0	 2.31	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6653	 1	 405.5	 247.2	 1.369347	 107.995934	 0	    1.00000	    0.00000	 380.0	 13	    1.10000	    0.90000;
	6654	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	6655	 1	 3.2	 0.4	 0.0	 0.65	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6656	 1	 -0.0	 -0.0	 0.199592	 35.580613	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	6657	 1	 7.71	 1.3	 0.0	 2.44	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6658	 1	 -14.82	 -5.03	 0.0	 0.15	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6659	 1	 -15.88	 -4.9	 0.0	 0.29	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	6660	 1	 0.0	 0.0	 0.0	 14.72	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	6661	 1	 0.0	 -0.0	 0.0	 150.649311	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	6662	 1	 0.0	 0.0	 0.0	 38.49	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	6663	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	6664	 1	 -0.0	 -0.0	 0.0	 2.32	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	6665	 1	 0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	6666	 1	 0.0	 -0.0	 0.0	 14.64	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6667	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	6668	 1	 21.12	 13.1	 0.0	 0.18	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6669	 1	 2.8	 0.5	 0.0	 2.37	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6670	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	6671	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	6672	 1	 20.02	 9.0	 0.0	 0.67	 0	    1.00000	    0.00000	 110.0	 23	    1.10000	    0.90000;
	6673	 1	 0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	6674	 1	 -0.0	 0.0	 0.0	 0.3	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6675	 1	 -0.0	 0.0	 0.0	 124.2	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	6676	 1	 0.0	 -0.0	 0.0	 1.33	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6677	 1	 -8.71	 2.9	 0.0	 0.42	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6678	 1	 179.8	 76.5	 0.0	 8.05	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	6679	 1	 119.0	 21.9	 0.0	 0.95	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6680	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	6681	 1	 48.45	 16.0	 0.0	 0.47	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	6682	 1	 138.2	 21.3	 0.0	 2.33	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6683	 1	 93.0	 66.0	 0.0	 2.25	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	6684	 1	 6.41	 2.3	 0.0	 0.78	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	6685	 1	 17.02	 5.6	 0.0	 0.19	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	6686	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	6687	 1	 13.92	 6.3	 0.0	 0.37	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6688	 1	 101.0	 20.6	 0.0	 54.5	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	6689	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	6690	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	6691	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	6692	 1	 130.5	 25.7	 0.0	 2.27	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6693	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	6694	 1	 -9.87	 -3.77	 0.0	 0.42	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6695	 1	 -0.0	 -0.0	 0.20225	 3.148312	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	6696	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	6697	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	6698	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	6699	 1	 77.59	 -6.1	 0.039393	 2.780607	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6700	 1	 92.4	 13.1	 0.0	 98.17	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	6701	 1	 -0.0	 -0.0	 0.0	 0.31	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6702	 1	 0.0	 0.0	 0.165633	 -1.064787	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	6703	 1	 11.91	 4.3	 0.0	 1.68	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	6704	 1	 73.28	 9.4	 0.0	 24.65	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	6705	 1	 47.95	 16.3	 0.0	 3.46	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	6706	 1	 27.9	 4.0	 0.0	 2.96	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6707	 1	 -31.26	 -13.2	 0.0	 2.81	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	6708	 1	 8.51	 2.8	 0.0	 1.16	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	6709	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	6710	 1	 311.4	 43.0	 0.0	 37.55	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	6711	 1	 2.2	 0.6	 0.0	 0.04	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	6712	 1	 100.7	 12.8	 0.038981	 0.661019	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	6713	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	6714	 1	 19.52	 6.4	 0.0	 0.03	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6715	 1	 11.01	 3.9	 0.0	 7.98	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6716	 1	 36.28	 -45.18	 0.0	 0.84	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	6717	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 6.3	 1	    1.10000	    0.90000;
	6718	 1	 13.9	 1.9	 0.0	 4.25	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6719	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	6720	 1	 -0.0	 -0.0	 0.0	 2.07	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	6721	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	6722	 1	 -0.0	 0.0	 0.0	 0.52	 0	    1.00000	    0.00000	 110.0	 18	    1.20000	    0.80000;
	6723	 1	 -0.0	 0.0	 0.0	 0.16	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6724	 1	 672.7	 107.6	 0.115285	 0.563929	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	6725	 1	 12.21	 7.9	 0.0	 0.56	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6726	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 8	    1.10000	    0.90000;
	6727	 1	 0.0	 -0.0	 0.0	 75.38	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	6728	 1	 5.77	 2.68	 0.0	 1.72	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6729	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	6730	 1	 11.2	 1.6	 0.0	 9.91	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6731	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	6732	 1	 -0.0	 -0.0	 0.0	 3.16	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	6733	 1	 183.8	 2.2	 0.0	 2.98	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6734	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	6735	 1	 20.32	 -24.8	 0.0	 7.45	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	6736	 1	 -1.73	 -1.71	 0.0	 22.069454	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	6737	 1	 84.59	 42.82	 0.0	 0.86	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	6738	 1	 170.9	 39.0	 0.0	 11.25	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6739	 1	 -0.0	 -0.0	 0.0	 0.98	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6740	 1	 0.0	 -0.0	 0.0	 4.25	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	6741	 1	 0.0	 0.0	 0.0	 52.958443	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	6742	 1	 0.0	 -0.0	 0.0	 1.27	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	6743	 1	 19.12	 7.4	 0.0	 21.97	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	6744	 1	 0.0	 -0.0	 0.0	 37.74	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6745	 1	 37.94	 18.9	 0.436494	 1.944442	 0	    1.00000	    0.00000	 380.0	 21	    1.20000	    0.80000;
	6746	 1	 70.28	 10.3	 0.0	 13.73	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6747	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 15.75	 1	    1.10000	    0.90000;
	6748	 1	 0.0	 0.0	 0.0	 4.36	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6749	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	6750	 1	 10.11	 3.7	 0.0	 2.15	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	6751	 1	 -0.0	 0.0	 0.0	 1.69	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	6752	 1	 10.11	 -0.0	 0.0	 0.32	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6753	 1	 0.0	 -0.0	 0.0	 4.45	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6754	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 9	    1.10000	    0.90000;
	6755	 1	 8.3	 1.2	 0.0	 2.32	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6756	 1	 -0.0	 -0.0	 0.0	 16.93	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	6757	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	6758	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	6759	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	6760	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	6761	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	6762	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	6763	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	6764	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	6765	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	6766	 1	 42.55	 17.6	 0.0	 1.2	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6767	 1	 135.0	 25.7	 0.0	 43.01	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	6768	 1	 37.94	 51.4	 0.0	 0.55	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	6769	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	6770	 1	 1.9	 0.6	 0.0	 1.06	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	6771	 1	 -0.0	 0.0	 0.0	 1.5	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6772	 1	 -0.0	 -0.0	 0.109969	 70.058359	 0	    1.00000	    0.00000	 380.0	 3	    1.20000	    0.80000;
	6773	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	6774	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	6775	 1	 26.03	 16.1	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6776	 1	 40.04	 15.0	 0.0	 1.59	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	6777	 1	 0.0	 0.0	 0.0	 80.389436	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	6778	 1	 -0.0	 -0.0	 0.039145	 0.050855	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6779	 1	 162.1	 73.0	 0.0	 0.3	 0	    1.00000	    0.00000	 110.0	 23	    1.10000	    0.90000;
	6780	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 7	    1.10000	    0.90000;
	6781	 1	 44.6	 6.4	 0.0	 2.31	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6782	 1	 7.0	 1.0	 0.0	 0.87	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6783	 1	 194.1	 27.6	 0.0	 3.26	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6784	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 6.3	 1	    1.10000	    0.90000;
	6785	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	6786	 1	 16.7	 2.4	 0.0	 14.37	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6787	 1	 18.2	 2.6	 0.0	 1.59	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6788	 1	 21.62	 7.8	 0.0	 1.43	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	6789	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	6790	 1	 -0.0	 -0.0	 0.0	 3.21	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6791	 1	 111.1	 15.7	 0.0	 4.13	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6792	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	6793	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	6794	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	6795	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	6796	 1	 137.8	 64.5	 0.0	 5.41	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	6797	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	6798	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	6799	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 9	    1.10000	    0.90000;
	6800	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6801	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	6802	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	6803	 1	 -0.0	 0.0	 0.0	 0.11	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	6804	 1	 75.58	 -7.5	 0.0	 8.08	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	6805	 1	 280.7	 53.7	 0.038299	 42.191701	 0	    1.00000	    0.00000	 380.0	 13	    1.10000	    0.90000;
	6806	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	6807	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	6808	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	6809	 1	 0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	6810	 1	 0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	6811	 1	 0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	6812	 1	 0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	6813	 1	 17.92	 7.2	 0.0	 0.8	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	6814	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	6815	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	6816	 1	 -0.0	 0.0	 0.0	 1.59	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6817	 1	 1.7	 0.6	 0.0	 0.51	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6818	 1	 0.0	 -0.0	 0.0	 1.45	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6819	 1	 3.7	 1.3	 0.0	 0.9	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	6820	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	6821	 1	 18.22	 8.6	 0.0	 34.7	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	6822	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 15.75	 1	    1.10000	    0.90000;
	6823	 1	 0.0	 -0.0	 0.334497	 0.149596	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	6824	 1	 -0.0	 -0.0	 0.0	 3.72	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	6825	 1	 0.0	 0.0	 0.058975	 11.000854	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	6826	 1	 41.75	 13.2	 0.0	 3.36	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	6827	 1	 5.01	 2.0	 0.0	 0.77	 0	    1.00000	    0.00000	 110.0	 23	    1.10000	    0.90000;
	6828	 1	 -0.0	 0.0	 0.0	 8.1	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6829	 1	 -0.0	 -0.0	 0.0	 165.63	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	6830	 1	 0.0	 -0.0	 0.0	 0.84	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6831	 1	 0.0	 0.0	 0.0	 5.63	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6832	 1	 28.83	 9.6	 0.0	 0.85	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	6833	 1	 4.61	 1.7	 0.0	 0.88	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	6834	 1	 93.9	 -0.4	 0.0	 3.66	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6835	 1	 68.38	 -24.4	 0.195436	 7.063423	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6836	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 15.75	 1	    1.10000	    0.90000;
	6837	 1	 27.13	 16.8	 0.0	 0.28	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6838	 1	 16.52	 3.2	 0.0	 0.9	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6839	 1	 100.6	 15.7	 0.019802	 5.520198	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6840	 1	 87.9	 75.0	 1.087555	 58.933642	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	6841	 1	 204.2	 41.1	 0.059977	 12.500023	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6842	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	6843	 1	 13.21	 4.4	 0.0	 0.38	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	6844	 1	 390.5	 62.5	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	6845	 1	 0.0	 -0.0	 0.304942	 0.015882	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	6846	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 20	    1.10000	    0.90000;
	6847	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	6848	 1	 -0.58	 -2.28	 0.0	 0.56	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	6849	 1	 11.41	 5.1	 0.0	 0.15	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6850	 1	 0.3	 97.4	 0.556326	 52.18058	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	6851	 1	 16.62	 5.5	 0.0	 1.34	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	6852	 1	 91.2	 56.1	 0.0	 8.3	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	6853	 1	 0.0	 0.0	 0.0	 1.06	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6854	 1	 124.0	 29.2	 0.0	 0.53	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6855	 1	 0.2	 0.8	 0.0	 0.04	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	6856	 1	 0.0	 -0.0	 0.442888	 6.15938	 0	    1.00000	    0.00000	 380.0	 18	    1.20000	    0.80000;
	6857	 1	 -0.0	 0.0	 0.0	 0.66	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	6858	 1	 25.13	 8.2	 0.0	 0.89	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	6859	 1	 102.7	 17.8	 0.0	 48.05	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6860	 1	 13.82	 1.4	 0.0	 0.7	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6861	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	6862	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	6863	 1	 -0.0	 0.0	 0.0	 0.6	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	6864	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 6.3	 1	    1.10000	    0.90000;
	6865	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	6866	 1	 84.09	 1.0	 0.0	 32.3	 0	    1.00000	    0.00000	 380.0	 11	    1.10000	    0.90000;
	6867	 1	 142.6	 50.6	 0.197772	 31.051671	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6868	 1	 0.0	 -0.0	 0.0	 23.94	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	6869	 1	 186.6	 56.6	 0.0	 30.24	 0	    1.00000	    0.00000	 380.0	 20	    1.20000	    0.80000;
	6870	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	6871	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 14.4	 1	    1.10000	    0.90000;
	6872	 1	 16.02	 5.1	 0.0	 0.63	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	6873	 1	 -0.0	 0.0	 0.0	 8.67	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	6874	 1	 0.0	 -0.0	 0.0	 43.7	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	6875	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	6876	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	6877	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	6878	 1	 0.8	 45.3	 0.545381	 16.735815	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	6879	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	6880	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	6881	 1	 -0.0	 8.3	 0.0	 10.19	 0	    1.00000	    0.00000	 150.0	 9	    1.20000	    0.80000;
	6882	 1	 -0.0	 0.0	 0.0	 50.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	6883	 1	 29.38	 -14.09	 0.0	 1.33	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	6884	 1	 10.81	 3.9	 0.0	 0.61	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	6885	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 9	    1.20000	    0.80000;
	6886	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	6887	 1	 124.3	 42.0	 0.039324	 3.310676	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	6888	 1	 15.82	 7.2	 0.0	 1.9	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6889	 1	 0.0	 0.0	 0.147967	 92.214944	 0	    1.00000	    0.00000	 380.0	 18	    1.20000	    0.80000;
	6890	 1	 25.33	 8.8	 0.0	 1.39	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	6891	 1	 0.0	 -0.0	 0.0	 3.4	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6892	 1	 -0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	6893	 1	 -0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	6894	 1	 8.81	 3.2	 0.0	 1.12	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	6895	 1	 0.0	 -0.0	 0.178742	 3.270839	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	6896	 1	 136.8	 4.8	 0.0	 10.0	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	6897	 1	 19.72	 7.1	 0.0	 0.28	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	6898	 1	 -0.0	 0.0	 0.058489	 3.001511	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6899	 1	 19.62	 7.4	 0.0	 0.76	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	6900	 1	 0.0	 0.0	 0.0	 20.81	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	6901	 1	 59.2	 8.4	 0.0	 2.26	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6902	 1	 54.76	 33.9	 0.0	 0.46	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6903	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 22	    1.10000	    0.90000;
	6904	 1	 -0.0	 0.0	 0.06009	 0.19991	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6905	 1	 21.42	 11.8	 0.0	 28.85	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	6906	 1	 195.4	 76.84	 0.0	 8.59	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6907	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6908	 1	 14.22	 5.1	 0.0	 0.39	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	6909	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	6910	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	6911	 1	 57.46	 17.1	 0.0	 1.61	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6912	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	6913	 1	 -0.0	 0.0	 0.0	 23.37	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	6914	 1	 392.0	 177.7	 0.181549	 10.880889	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	6915	 1	 -0.0	 -0.0	 0.0	 46.25	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	6916	 1	 97.0	 57.4	 0.0	 93.82	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	6917	 1	 -2.91	 -0.6	 0.0	 0.02	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	6918	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	6919	 1	 -0.0	 -0.0	 0.0	 4.51	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	6920	 1	 -0.0	 0.0	 0.0	 6.11	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	6921	 1	 92.1	 38.0	 0.0	 4.93	 0	    1.00000	    0.00000	 220.0	 16	    1.10000	    0.90000;
	6922	 1	 0.0	 -0.0	 0.178535	 0.81114	 0	    1.00000	    0.00000	 220.0	 20	    1.10000	    0.90000;
	6923	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6924	 1	 4.91	 1.6	 0.0	 4.15	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6925	 1	 5.81	 3.8	 0.0	 0.94	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6926	 1	 2.0	 0.6	 0.0	 0.53	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	6927	 1	 66.97	 18.6	 0.0	 18.5	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6928	 1	 3.1	 0.1	 0.0	 1.34	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6929	 1	 0.0	 -0.0	 0.0	 2.38	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6930	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	6931	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	6932	 1	 -0.0	 0.0	 0.0	 2.42	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6933	 1	 17.7	 -334.5	 0.131772	 55.711176	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	6934	 1	 -0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	6935	 1	 -0.0	 -0.0	 0.135375	 4.892175	 0	    1.00000	    0.00000	 380.0	 18	    1.20000	    0.80000;
	6936	 1	 0.0	 -0.0	 0.0	 0.41	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	6937	 1	 0.0	 0.0	 0.0	 25.368606	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	6938	 1	 -0.0	 -0.0	 0.0	 13.59	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	6939	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 15.0	 1	    1.10000	    0.90000;
	6940	 1	 110.6	 20.4	 0.0	 26.9	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	6941	 1	 0.0	 -0.0	 0.099501	 43.903596	 0	    1.00000	    0.00000	 380.0	 18	    1.20000	    0.80000;
	6942	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 6.3	 1	    1.10000	    0.90000;
	6943	 1	 101.89	 25.72	 0.0	 5.11	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6944	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	6945	 1	 0.4	 0.3	 0.039289	 1.170711	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6946	 1	 -0.15	 -0.9	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	6947	 1	 17.12	 6.3	 0.0	 0.51	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6948	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	6949	 1	 0.0	 -0.0	 0.0	 2.03	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	6950	 1	 13.77	 18.73	 0.0	 0.46	 0	    1.00000	    0.00000	 150.0	 9	    1.20000	    0.80000;
	6951	 1	 2.2	 -0.0	 0.0	 4.81	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	6952	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 10.6	 1	    1.10000	    0.90000;
	6953	 1	 58.97	 18.1	 0.0	 0.32	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6954	 1	 0.0	 -0.0	 0.181549	 17.630889	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	6955	 1	 93.3	 27.8	 0.0	 6.1	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6956	 1	 0.0	 -0.0	 0.0	 1.49	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6957	 1	 264.0	 40.1	 0.0	 9.489841	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	6958	 1	 0.0	 -0.0	 0.0	 3.65	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6959	 1	 615.8	 286.7	 0.0	 101.04	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	6960	 1	 120.1	 2.5	 0.0	 6.6	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6961	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	6962	 1	 101.1	 19.8	 0.0	 3.62	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6963	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	6964	 1	 -0.0	 0.0	 0.0	 1.4	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	6965	 1	 59.17	 14.0	 0.0	 4.07	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	6966	 1	 -0.0	 0.0	 0.0	 1.67	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6967	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	6968	 1	 10.97	 -6.31	 0.0	 1.14	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6969	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	6970	 1	 -0.0	 -0.0	 0.0	 5.57	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6971	 1	 0.0	 -0.0	 0.34708	 0.510766	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	6972	 1	 12.51	 3.3	 0.0	 1.7	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6973	 1	 63.5	 -381.2	 0.514139	 207.080426	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	6974	 1	 65.07	 30.0	 0.0	 0.99	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	6975	 1	 173.4	 31.0	 0.0	 1.91	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	6976	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	6977	 1	 -0.15	 -1.0	 0.0	 0.42	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	6978	 1	 31.94	 10.5	 0.0	 1.02	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	6979	 1	 14.92	 5.1	 0.0	 0.65	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	6980	 1	 33.04	 10.1	 0.0	 0.43	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	6981	 1	 121.9	 -0.2	 0.0	 12.83	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	6982	 1	 -0.0	 -0.0	 0.0	 1.04	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	6983	 1	 8.41	 2.6	 0.0	 1.77	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	6984	 1	 0.0	 -0.0	 0.078399	 0.891201	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	6985	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	6986	 1	 13.9	 1.9	 0.0	 3.89	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	6987	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	6988	 1	 -0.0	 -0.0	 0.0	 0.6	 0	    1.00000	    0.00000	 110.0	 3	    1.10000	    0.90000;
	6989	 1	 0.0	 -0.0	 0.3205	 28.133148	 0	    1.00000	    0.00000	 380.0	 18	    1.20000	    0.80000;
	6990	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	6991	 1	 24.93	 13.7	 0.155083	 -0.105083	 0	    1.00000	    0.00000	 220.0	 21	    1.10000	    0.90000;
	6992	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	6993	 1	 87.5	 25.9	 0.098609	 24.561391	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6994	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	6995	 1	 -0.0	 0.0	 0.039707	 7.680293	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	6996	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	6997	 1	 63.27	 28.9	 0.0	 2.19	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	6998	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	6999	 1	 153.2	 31.5	 0.0	 12.56	 0	    1.00000	    0.00000	 220.0	 11	    1.10000	    0.90000;
	7000	 1	 0.0	 -0.0	 0.506518	 -0.393958	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	7001	 1	 97.5	 13.9	 0.0	 1.24	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7002	 1	 -0.0	 0.0	 0.0	 0.01	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7003	 1	 0.0	 -0.0	 0.0	 3.52	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	7004	 1	 2.5	 1.5	 0.0	 0.83	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7005	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	7006	 1	 40.14	 24.9	 0.0	 5.71	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7007	 1	 21.02	 14.8	 0.0	 0.1	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7008	 1	 -0.0	 -0.0	 0.573295	 -0.286693	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7009	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 10.5	 1	    1.10000	    0.90000;
	7010	 1	 69.78	 22.4	 0.0	 2.72	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	7011	 1	 -0.0	 0.0	 0.0	 6.26	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	7012	 1	 89.9	 40.2	 0.0	 0.37	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	7013	 1	 71.98	 27.1	 0.0	 7.2	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	7014	 1	 146.9	 -5.1	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 3	    1.20000	    0.80000;
	7015	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7016	 1	 9.11	 3.0	 0.0	 1.24	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	7017	 1	 -0.0	 0.0	 0.0	 29.91	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7018	 1	 336.9	 81.0	 0.0	 19.53	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	7019	 1	 11.41	 3.8	 0.0	 0.36	 0	    1.00000	    0.00000	 110.0	 18	    1.20000	    0.80000;
	7020	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	7021	 1	 -0.0	 0.0	 0.0	 81.29	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	7022	 1	 0.0	 0.0	 0.0	 11.82	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	7023	 1	 -9.6	 -2.5	 0.0	 2.15	 0	    1.00000	    0.00000	 150.0	 9	    1.20000	    0.80000;
	7024	 1	 0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 8	    1.20000	    0.80000;
	7025	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7026	 1	 0.0	 -0.0	 0.0	 2.62	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	7027	 1	 0.0	 -0.0	 0.0	 0.34	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7028	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	7029	 1	 -0.0	 0.0	 0.252818	 66.30157	 0	    1.00000	    0.00000	 380.0	 21	    1.20000	    0.80000;
	7030	 1	 3.2	 1.2	 0.0	 0.3	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	7031	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	7032	 1	 20.12	 4.9	 0.0	 1.61	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7033	 1	 -0.0	 0.0	 0.0	 2.03	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	7034	 1	 9.71	 3.2	 0.0	 0.26	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	7035	 1	 118.6	 43.4	 0.0	 0.8	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	7036	 1	 66.67	 0.0	 0.0	 0.11	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	7037	 1	 210.8	 -0.7	 0.0	 4.14	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7038	 1	 39.84	 6.4	 0.0	 34.58	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	7039	 1	 0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	7040	 1	 69.98	 21.3	 0.039275	 3.360725	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7041	 1	 151.0	 7.1	 0.0	 4.24	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7042	 1	 0.0	 -0.0	 0.0	 40.13	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	7043	 1	 11.2	 1.6	 0.0	 4.75	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7044	 1	 141.36	 53.5	 0.0	 2.76	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	7045	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	7046	 1	 41.25	 13.5	 0.0	 0.39	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	7047	 1	 0.0	 0.0	 0.0	 0.15	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	7048	 1	 112.4	 13.0	 0.0	 3.99	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7049	 1	 270.5	 77.8	 0.0	 81.25	 0	    1.00000	    0.00000	 380.0	 20	    1.10000	    0.90000;
	7050	 1	 110.2	 15.7	 0.0	 2.3	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7051	 1	 0.0	 -0.0	 0.574676	 1.582208	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	7052	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 10.6	 1	    1.10000	    0.90000;
	7053	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	7054	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	7055	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	7056	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	7057	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 17	    1.10000	    0.90000;
	7058	 1	 -0.0	 -0.0	 0.0	 0.06	 0	    1.00000	    0.00000	 120.0	 6	    1.20000	    0.80000;
	7059	 1	 -0.15	 -1.4	 0.0	 0.01	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	7060	 1	 -0.0	 -0.0	 0.0	 0.83	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7061	 1	 183.03	 15.7	 0.0	 1.83	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	7062	 1	 -0.0	 0.0	 0.009921	 -0.009921	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7063	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	7064	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 9	    1.10000	    0.90000;
	7065	 1	 -0.0	 -0.0	 0.670574	 55.699129	 0	    1.00000	    0.00000	 380.0	 21	    1.20000	    0.80000;
	7066	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	7067	 1	 -0.0	 0.0	 0.0	 46.7	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	7068	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	7069	 1	 0.0	 0.0	 0.176261	 1.013116	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	7070	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	7071	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	7072	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	7073	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 22	    1.10000	    0.90000;
	7074	 1	 0.0	 0.0	 0.0	 3.38	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	7075	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	7076	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7077	 1	 171.9	 39.1	 0.0	 4.23	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7078	 1	 -0.0	 0.0	 0.122915	 25.570901	 0	    1.00000	    0.00000	 380.0	 7	    1.10000	    0.90000;
	7079	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	7080	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	7081	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	7082	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	7083	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	7084	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	7085	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	7086	 1	 19.22	 6.4	 0.0	 31.78	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	7087	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	7088	 1	 -0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	7089	 1	 5.11	 2.5	 0.0	 0.57	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7090	 1	 0.0	 0.0	 0.0	 0.81	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7091	 1	 34.14	 21.1	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.20000	    0.80000;
	7092	 1	 -0.0	 0.0	 0.11	 4.95	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	7093	 1	 -10.28	 -2.68	 0.0	 0.9	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7094	 1	 19.82	 6.5	 0.0	 1.47	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7095	 1	 121.6	 49.3	 0.0	 10.0	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	7096	 1	 151.1	 66.9	 0.0	 0.41	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	7097	 1	 25.23	 15.6	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7098	 1	 54.96	 16.9	 0.0	 3.37	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	7099	 1	 0.0	 0.0	 0.340119	 -0.264537	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	7100	 1	 -0.0	 0.0	 0.0	 31.14	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	7101	 1	 173.2	 -7.0	 0.495294	 14.757893	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	7102	 1	 0.0	 0.0	 0.0	 1.36	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7103	 1	 -0.0	 -0.0	 0.172715	 -0.134334	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	7104	 1	 347.3	 105.6	 0.230364	 23.317628	 0	    1.00000	    0.00000	 380.0	 13	    1.10000	    0.90000;
	7105	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 7	    1.10000	    0.90000;
	7106	 1	 58.06	 4.1	 0.231528	 17.426707	 0	    1.00000	    0.00000	 220.0	 23	    1.10000	    0.90000;
	7107	 1	 90.5	 12.8	 0.0	 0.78	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7108	 1	 0.2	 0.5	 0.688989	 47.290598	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	7109	 1	 0.0	 -0.0	 0.0	 0.43	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7110	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	7111	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 9	    1.10000	    0.90000;
	7112	 1	 45.55	 -59.9	 0.0	 30.04	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7113	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	7114	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.5	 1	    1.10000	    0.90000;
	7115	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 17	    1.10000	    0.90000;
	7116	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	7117	 1	 125.7	 17.9	 0.0	 0.2	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7118	 1	 127.9	 -34.0	 0.0	 19.86	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7119	 1	 -0.0	 0.0	 0.0	 1.92	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7120	 1	 78.69	 19.6	 0.0	 0.87	 0	    1.00000	    0.00000	 110.0	 3	    1.10000	    0.90000;
	7121	 1	 0.0	 0.0	 0.0	 12.69	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	7122	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	7123	 1	 261.2	 105.6	 0.0	 28.53	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	7124	 1	 0.0	 -0.0	 0.0	 29.32	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	7125	 1	 0.0	 -0.0	 0.09	 7.22	 0	    1.00000	    0.00000	 220.0	 21	    1.10000	    0.90000;
	7126	 1	 0.1	 2.2	 0.0	 1.22	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	7127	 1	 -5.88	 -3.76	 0.0	 0.39	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7128	 1	 -0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	7129	 1	 0.0	 -0.0	 0.0	 4.86	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7130	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.20000	    0.80000;
	7131	 1	 169.0	 56.4	 0.0	 8.06	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	7132	 1	 -0.0	 0.0	 0.0	 9.74	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7133	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	7134	 1	 50.56	 18.0	 0.0	 0.11	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7135	 1	 2.2	 0.5	 0.0	 2.88	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	7136	 1	 0.0	 0.0	 0.0	 8.1	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	7137	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 8	    1.10000	    0.90000;
	7138	 1	 0.0	 -0.0	 0.0	 0.28	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7139	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	7140	 1	 65.5	 9.3	 0.0	 5.31	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7141	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	7142	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	7143	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	7144	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	7145	 1	 15.42	 3.9	 0.0	 0.79	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	7146	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	7147	 1	 262.6	 31.8	 0.0	 8.13	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	7148	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 15.75	 1	    1.10000	    0.90000;
	7149	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	7150	 1	 0.0	 -0.0	 0.0	 0.95	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7151	 1	 -0.0	 -0.0	 0.0	 2.74	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	7152	 1	 230.9	 42.6	 0.0	 12.62	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	7153	 1	 25.73	 9.3	 0.0	 0.12	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	7154	 1	 5.11	 1.7	 0.0	 0.48	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	7155	 1	 0.0	 0.0	 0.0	 3.48	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	7156	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	7157	 1	 135.9	 24.7	 0.078499	 1.141501	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7158	 1	 5.11	 -0.0	 0.0	 4.97	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7159	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7160	 1	 -0.0	 0.0	 0.0	 1.26	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7161	 1	 0.0	 0.0	 0.51746	 3.458783	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	7162	 1	 -0.0	 0.0	 0.0	 3.08	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	7163	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	7164	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 20	    1.10000	    0.90000;
	7165	 1	 45.45	 7.1	 0.0	 1.05	 0	    1.00000	    0.00000	 110.0	 3	    1.10000	    0.90000;
	7166	 1	 186.9	 26.6	 0.0	 11.96	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	7167	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	7168	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	7169	 1	 16.92	 5.6	 0.0	 0.2	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	7170	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	7171	 1	 185.0	 43.6	 0.0	 6.3	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7172	 1	 25.1	 3.6	 0.0	 1.74	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7173	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 9	    1.20000	    0.80000;
	7174	 1	 -0.0	 -0.0	 0.0	 39.21	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	7175	 1	 21.62	 7.8	 0.0	 0.68	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	7176	 1	 0.0	 0.0	 0.0	 0.34	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7177	 1	 -7.61	 2.5	 0.0	 0.5	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7178	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	7179	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	7180	 1	 329.7	 32.4	 0.0	 4.5	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7181	 1	 32.24	 8.9	 0.039602	 1.700398	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7182	 1	 55.7	 7.9	 0.0	 0.1	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7183	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	7184	 1	 -0.0	 0.0	 0.12	 12.76	 0	    1.00000	    0.00000	 220.0	 21	    1.10000	    0.90000;
	7185	 1	 -0.0	 -0.0	 0.0	 2.8	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7186	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 6.3	 1	    1.10000	    0.90000;
	7187	 1	 -0.0	 0.0	 0.0	 0.88	 0	    1.00000	    0.00000	 110.0	 3	    1.10000	    0.90000;
	7188	 1	 1.9	 0.0	 0.0	 0.5	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7189	 1	 -0.0	 0.0	 0.0	 121.29	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	7190	 1	 96.0	 33.3	 0.0	 16.89	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	7191	 1	 17.12	 5.6	 0.0	 1.12	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	7192	 1	 185.6	 62.3	 0.118766	 18.421234	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7193	 1	 175.8	 70.7	 0.0	 19.08	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7194	 1	 125.16	 29.2	 0.0	 2.69	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7195	 1	 50.06	 9.9	 0.0	 11.56	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7196	 1	 220.6	 83.4	 0.0	 17.73	 0	    1.00000	    0.00000	 380.0	 20	    1.10000	    0.90000;
	7197	 1	 0.0	 -0.0	 0.0	 1.37	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7198	 1	 0.0	 0.0	 0.0	 0.95	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7199	 1	 -0.0	 -0.0	 0.0	 1.09	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7200	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	7201	 1	 -0.0	 -0.0	 0.0	 0.45	 0	    1.00000	    0.00000	 220.0	 20	    1.10000	    0.90000;
	7202	 1	 -24.03	 7.9	 0.0	 0.25	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7203	 1	 14.92	 -8.73	 0.0	 34.66	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7204	 1	 -0.0	 0.0	 0.0	 0.31	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7205	 1	 10.51	 4.7	 0.0	 1.54	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7206	 1	 71.6	 10.2	 0.0	 58.47	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	7207	 1	 13.11	 4.9	 0.038998	 12.341002	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7208	 1	 15.82	 9.8	 0.0	 7.61	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7209	 1	 -0.0	 -0.0	 0.0	 145.62	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	7210	 1	 -0.0	 -0.0	 0.0	 1.17	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	7211	 1	 -0.0	 0.0	 0.0	 18.54	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	7212	 1	 0.0	 0.0	 0.0	 2.57	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	7213	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 6.3	 1	    1.10000	    0.90000;
	7214	 1	 0.0	 0.0	 0.0	 26.0	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	7215	 1	 0.0	 0.0	 0.0	 94.945914	 0	    1.00000	    0.00000	 380.0	 17	    1.10000	    0.90000;
	7216	 1	 195.3	 87.6	 0.0	 9.53	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	7217	 1	 3.8	 1.1	 0.0	 10.69	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	7218	 1	 46.2	 6.6	 0.0	 1.24	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7219	 1	 -0.0	 -0.0	 0.0	 98.2	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	7220	 1	 40.04	 10.0	 0.0	 23.59	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	7221	 1	 37.0	 8.7	 0.075047	 50.85006	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	7222	 1	 2.5	 1.3	 0.0	 0.16	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7223	 1	 -0.0	 -0.0	 0.049332	 27.640668	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	7224	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7225	 1	 -19.22	 6.3	 0.0	 1.02	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7226	 1	 22.42	 7.3	 0.0	 0.77	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	7227	 1	 -0.0	 0.0	 0.0	 15.76	 0	    1.00000	    0.00000	 220.0	 12	    1.10000	    0.90000;
	7228	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	7229	 1	 124.5	 29.6	 0.0	 15.4	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7230	 1	 11.61	 2.5	 0.0	 0.42	 0	    1.00000	    0.00000	 110.0	 3	    1.10000	    0.90000;
	7231	 1	 -0.0	 0.0	 1.258518	 11.87411	 0	    1.00000	    0.00000	 380.0	 7	    1.10000	    0.90000;
	7232	 1	 56.76	 31.1	 0.0	 0.37	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7233	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	7234	 1	 0.0	 0.0	 0.0	 5.5	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7235	 1	 59.67	 25.6	 0.0	 11.54	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	7236	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	7237	 1	 109.9	 33.6	 0.0	 3.72	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7238	 1	 0.0	 -0.0	 0.0	 0.83	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	7239	 1	 36.84	 14.0	 0.020146	 0.269854	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	7240	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	7241	 1	 0.1	 35.9	 0.29124	 18.2273	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	7242	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	7243	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 6.3	 1	    1.10000	    0.90000;
	7244	 1	 329.7	 220.4	 0.0	 46.92	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	7245	 1	 -0.0	 -0.0	 0.0	 20.79	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	7246	 1	 72.18	 44.9	 0.0	 6.34	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	7247	 1	 -0.0	 0.0	 0.057201	 0.402799	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7248	 1	 11.2	 1.6	 0.0	 4.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7249	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	7250	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	7251	 1	 67.37	 31.4	 0.039096	 2.300904	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7252	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	7253	 1	 66.77	 11.1	 0.0	 2.7	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7254	 1	 52.76	 5.9	 0.059373	 5.140627	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7255	 1	 27.9	 4.0	 0.0	 5.34	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7256	 1	 -0.0	 -0.0	 0.0	 0.99	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7257	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	7258	 1	 1.8	 91.2	 0.703792	 89.782606	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	7259	 1	 0.0	 -0.0	 0.0	 1.94	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7260	 1	 -119.4	 -359.4	 0.0	 39.39	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	7261	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 6.3	 1	    1.10000	    0.90000;
	7262	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 22	    1.10000	    0.90000;
	7263	 1	 12.91	 7.1	 0.0	 0.84	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7264	 1	 62.97	 68.0	 0.0	 13.59	 0	    1.00000	    0.00000	 220.0	 16	    1.10000	    0.90000;
	7265	 1	 29.13	 18.0	 0.0	 0.06	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7266	 1	 -0.0	 -0.0	 0.0	 0.29	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7267	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	7268	 1	 -0.0	 -0.0	 0.0	 29.32	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	7269	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7270	 1	 110.7	 78.7	 0.0	 5.27	 0	    1.00000	    0.00000	 220.0	 17	    1.10000	    0.90000;
	7271	 1	 292.0	 81.8	 0.275203	 1.863598	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7272	 1	 -0.0	 -0.0	 0.0	 16.57	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	7273	 1	 0.0	 -0.0	 0.471049	 0.717086	 0	    1.00000	    0.00000	 380.0	 14	    1.10000	    0.90000;
	7274	 1	 0.0	 -0.0	 0.0	 171.844376	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	7275	 1	 130.0	 128.0	 0.0	 7.73	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	7276	 1	 13.9	 1.9	 0.0	 4.71	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7277	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7278	 1	 268.2	 -257.9	 0.0	 42.56	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	7279	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7280	 1	 -15.89	 -6.42	 0.0	 38.662969	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	7281	 1	 -0.0	 0.0	 0.181549	 24.230889	 0	    1.00000	    0.00000	 220.0	 18	    1.20000	    0.80000;
	7282	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	7283	 1	 -0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	7284	 1	 -0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	7285	 1	 0.0	 0.0	 0.0	 0.31	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7286	 1	 -0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	7287	 1	 -0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	7288	 1	 -0.0	 -0.0	 0.198366	 -0.008774	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	7289	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	7290	 1	 4.81	 1.6	 0.0	 0.53	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	7291	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	7292	 1	 0.0	 -0.0	 0.0	 2.34	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7293	 1	 0.0	 0.0	 0.0	 16.87	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7294	 1	 88.4	 -5.9	 0.0	 3.32	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7295	 1	 10.11	 1.6	 0.0	 0.66	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7296	 1	 9.31	 0.8	 0.0	 0.9	 0	    1.00000	    0.00000	 110.0	 3	    1.10000	    0.90000;
	7297	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	7298	 1	 32.5	 30.5	 0.0	 265.721081	 0	    1.00000	    0.00000	 380.0	 9	    1.20000	    0.80000;
	7299	 1	 -22.8	 -16.4	 0.0	 0.19	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	7300	 1	 -4.66	 1.11	 0.0	 0.19	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7301	 1	 11.41	 3.8	 0.0	 1.01	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7302	 1	 -4.89	 -2.4	 0.0	 0.25	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7303	 1	 0.0	 0.0	 0.090774	 3.730444	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	7304	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	7305	 1	 501.1	 10.7	 0.0	 18.07	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	7306	 1	 58.36	 42.7	 0.0	 1.29	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7307	 1	 -0.12	 -1.74	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 8	    1.20000	    0.80000;
	7308	 1	 -0.0	 -0.0	 0.232315	 -0.193596	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	7309	 1	 190.7	 13.3	 0.0	 4.61	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	7310	 1	 -0.0	 0.0	 0.077493	 3.252507	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	7311	 1	 0.0	 0.0	 0.0	 0.06	 0	    1.00000	    0.00000	 220.0	 21	    1.10000	    0.90000;
	7312	 1	 110.0	 6.83	 0.0	 13.51	 0	    1.00000	    0.00000	 220.0	 14	    1.10000	    0.90000;
	7313	 1	 -0.0	 -0.0	 0.090774	 2.110444	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	7314	 1	 -28.14	 -0.76	 0.0	 0.1	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7315	 1	 53.86	 33.4	 0.0	 12.95	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	7316	 1	 27.03	 13.0	 0.0	 2.32	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	7317	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	7318	 1	 82.49	 24.5	 0.0	 0.62	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	7319	 1	 -0.0	 0.0	 0.0	 4.34	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7320	 1	 17.87	 -8.59	 0.0	 0.21	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7321	 1	 -0.0	 0.0	 0.120181	 7.369819	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7322	 1	 -0.0	 0.0	 0.287116	 4.880736	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	7323	 1	 -58.77	 18.7	 0.0	 4.23	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	7324	 1	 -0.0	 0.0	 0.0	 40.291745	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	7325	 1	 0.0	 -0.0	 0.0	 23.76	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	7326	 1	 0.0	 0.0	 0.27075	 87.43435	 0	    1.00000	    0.00000	 380.0	 18	    1.20000	    0.80000;
	7327	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	7328	 1	 0.0	 -0.0	 0.0	 45.86	 0	    1.00000	    0.00000	 380.0	 13	    1.10000	    0.90000;
	7329	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	7330	 1	 -0.0	 0.0	 0.0	 11.27	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	7331	 1	 5.11	 2.5	 0.0	 0.52	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7332	 1	 5.11	 3.8	 0.0	 0.88	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7333	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	7334	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	7335	 1	 0.0	 0.0	 0.0	 1.15	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7336	 1	 70.08	 35.0	 0.0	 1.45	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	7337	 1	 27.13	 9.8	 0.0	 0.17	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	7338	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	7339	 1	 0.0	 0.0	 0.0	 8.155532	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	7340	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 10.5	 1	    1.10000	    0.90000;
	7341	 1	 0.1	 -9.6	 0.0	 1.3	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	7342	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	7343	 1	 159.27	 38.31	 0.0	 2.18	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7344	 1	 0.0	 -0.0	 0.03846	 5.16154	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7345	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	7346	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	7347	 1	 -0.0	 0.0	 0.0	 29.76	 0	    1.00000	    0.00000	 220.0	 22	    1.10000	    0.90000;
	7348	 1	 -0.0	 -0.0	 0.0	 2.81	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7349	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	7350	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	7351	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	7352	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	7353	 1	 162.6	 36.4	 0.0	 26.03	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7354	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	7355	 1	 130.1	 40.5	 0.112754	 0.266039	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	7356	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 9	    1.10000	    0.90000;
	7357	 1	 38.1	 5.5	 0.0	 3.32	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7358	 1	 -12.92	 -1.53	 0.0	 0.96	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7359	 1	 30.33	 18.8	 0.0	 1.35	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7360	 1	 0.0	 0.0	 0.0	 1.31	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7361	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	7362	 1	 174.7	 35.0	 0.0	 2.14	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	7363	 1	 14.32	 4.4	 0.0	 0.74	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	7364	 1	 18.9	 2.7	 0.0	 2.81	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7365	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	7366	 1	 93.1	 43.7	 0.0	 11.87	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7367	 1	 0.0	 0.0	 0.0	 13.25	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	7368	 1	 -0.0	 0.0	 0.038705	 1.011295	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	7369	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	7370	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	7371	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	7372	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	7373	 1	 20.32	 10.1	 0.0	 0.14	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7374	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	7375	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	7376	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	7377	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	7378	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	7379	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	7380	 1	 0.0	 8.8	 0.0	 18.87	 0	    1.00000	    0.00000	 150.0	 9	    1.20000	    0.80000;
	7381	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 15.5	 1	    1.10000	    0.90000;
	7382	 1	 24.33	 10.0	 0.0	 84.57	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	7383	 1	 303.1	 75.5	 0.0	 22.74	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	7384	 1	 -0.0	 0.0	 0.0	 12.01	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	7385	 1	 11.41	 2.5	 0.0	 0.22	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7386	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	7387	 1	 0.0	 0.0	 0.073897	 1.024333	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7388	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 22	    1.10000	    0.90000;
	7389	 1	 0.0	 0.0	 0.0	 39.95	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	7390	 1	 4.61	 1.3	 0.0	 0.53	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7391	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	7392	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 9	    1.10000	    0.90000;
	7393	 1	 0.0	 -0.0	 0.0	 9.59	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	7394	 1	 -0.0	 -0.0	 0.0	 12.96	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	7395	 1	 -0.0	 -0.0	 0.181549	 18.620889	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	7396	 1	 21.32	 7.9	 0.081251	 7.368749	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7397	 1	 0.0	 0.0	 0.0	 5.173673	 0	    1.00000	    0.00000	 220.0	 24	    1.10000	    0.90000;
	7398	 1	 190.0	 72.7	 0.0	 30.78	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	7399	 1	 43.45	 26.9	 0.0	 6.37	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7400	 1	 31.74	 17.4	 0.0	 0.89	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7401	 1	 0.0	 0.0	 0.263214	 3.036617	 0	    1.00000	    0.00000	 220.0	 19	    1.10000	    0.90000;
	7402	 1	 62.7	 9.0	 0.0	 4.93	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7403	 1	 0.0	 0.0	 0.0	 0.06	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	7404	 1	 295.2	 39.3	 0.0	 7.3	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7405	 1	 9.51	 0.5	 0.0	 0.04	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7406	 1	 0.0	 0.0	 0.11885	 -0.089137	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	7407	 1	 -0.0	 0.0	 0.029104	 22.310896	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	7408	 1	 25.33	 14.2	 0.0	 4.05	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7409	 1	 160.6	 51.2	 0.0	 46.39	 0	    1.00000	    0.00000	 380.0	 20	    1.10000	    0.90000;
	7410	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7411	 1	 22.32	 7.3	 0.0	 0.46	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	7412	 1	 0.0	 -0.0	 0.670766	 -0.531023	 0	    1.00000	    0.00000	 380.0	 8	    1.20000	    0.80000;
	7413	 1	 35.64	 22.0	 0.0	 4.46	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7414	 1	 0.0	 0.0	 0.404001	 4.446629	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	7415	 1	 3.8	 1.3	 0.0	 0.78	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7416	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 10.6	 1	    1.10000	    0.90000;
	7417	 1	 -19.07	 -6.06	 0.0	 16.68	 0	    1.00000	    0.00000	 220.0	 11	    1.10000	    0.90000;
	7418	 1	 50.06	 25.0	 0.0	 1.21	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	7419	 1	 36.44	 22.6	 0.0	 2.32	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7420	 1	 -0.0	 -0.0	 0.0	 22.93	 0	    1.00000	    0.00000	 150.0	 9	    1.20000	    0.80000;
	7421	 1	 49.8	 7.1	 0.0	 1.4	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7422	 1	 5.11	 2.5	 0.0	 1.5	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7423	 1	 148.3	 12.1	 0.039183	 7.280613	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	7424	 1	 19.12	 2.8	 0.0	 0.97	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7425	 1	 -0.0	 0.0	 0.037961	 6.562039	 0	    1.00000	    0.00000	 220.0	 11	    1.10000	    0.90000;
	7426	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	7427	 1	 -0.0	 0.0	 0.0	 0.04	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7428	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	7429	 1	 3.7	 1.3	 0.0	 0.98	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	7430	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 10.6	 1	    1.10000	    0.90000;
	7431	 1	 80.39	 10.8	 0.0	 0.35	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7432	 1	 53.26	 29.5	 0.0	 41.35	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	7433	 1	 6.61	 3.3	 0.0	 2.67	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	7434	 1	 -0.0	 -0.0	 0.0	 -0.46	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	7435	 1	 7.41	 2.7	 0.0	 1.08	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	7436	 1	 -14.81	 -0.52	 0.0	 0.13	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7437	 1	 87.38	 -90.15	 0.0	 16.05	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	7438	 1	 155.25	 23.3	 0.0	 3.74	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	7439	 1	 -0.0	 -0.0	 0.0	 4.74	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7440	 1	 71.58	 57.6	 0.233839	 24.774621	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	7441	 1	 0.0	 -0.0	 0.278965	 11.049132	 0	    1.00000	    0.00000	 380.0	 16	    1.10000	    0.90000;
	7442	 1	 -29.96	 -21.31	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	7443	 1	 0.0	 -0.0	 0.0	 5.02	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	7444	 1	 -0.0	 -0.0	 0.0	 11.55	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	7445	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7446	 1	 -2.27	 -1.81	 0.0	 42.76	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	7447	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 7	    1.10000	    0.90000;
	7448	 1	 0.0	 0.0	 0.0	 38.24	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	7449	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 15.75	 1	    1.10000	    0.90000;
	7450	 1	 0.0	 -0.0	 0.0	 9.34	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7451	 1	 117.7	 115.0	 0.0	 12.29	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	7452	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	7453	 1	 0.0	 -0.0	 0.091693	 56.645921	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	7454	 1	 99.4	 -347.1	 0.0	 31.86	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	7455	 1	 10.81	 1.9	 0.0	 1.6	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7456	 1	 0.0	 -0.0	 0.0	 9.06	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	7457	 1	 37.0	 5.3	 0.0	 1.74	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7458	 1	 39.94	 13.0	 0.0	 2.47	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7459	 1	 122.9	 19.3	 0.0	 68.84	 0	    1.00000	    0.00000	 380.0	 16	    1.10000	    0.90000;
	7460	 1	 -55.83	 -31.99	 0.0	 2.88	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	7461	 1	 213.1	 -12.3	 0.0	 30.87	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	7462	 1	 94.71	 15.6	 0.040271	 2.879729	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7463	 1	 139.9	 1.1	 0.0	 5.58	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7464	 1	 305.04	 77.16	 0.0	 17.43	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7465	 1	 41.35	 25.6	 0.0	 9.9	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7466	 1	 0.0	 -0.0	 0.0	 11.9	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7467	 1	 0.0	 0.0	 0.0	 3.41	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	7468	 1	 2.47	 -0.62	 0.0	 2.54	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7469	 1	 35.64	 22.0	 0.0	 5.67	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7470	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	7471	 1	 46.25	 13.1	 0.0	 1.29	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7472	 1	 0.0	 0.0	 0.0	 1.23	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	7473	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	7474	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	7475	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	7476	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	7477	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	7478	 1	 48.95	 11.6	 0.0	 2.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7479	 1	 23.4	 8.38	 0.0	 1.07	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7480	 1	 163.1	 23.2	 0.0	 3.36	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7481	 1	 -15.91	 -6.11	 0.0	 0.21	 0	    1.00000	    0.00000	 110.0	 23	    1.10000	    0.90000;
	7482	 1	 0.0	 0.0	 0.0	 0.66	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	7483	 1	 123.9	 46.5	 0.039444	 12.660556	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	7484	 1	 17.82	 7.3	 0.0	 0.14	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7485	 1	 66.47	 22.1	 0.0	 0.46	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	7486	 1	 -0.0	 -0.0	 0.0	 2.74	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	7487	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	7488	 1	 -0.0	 0.0	 0.0	 1.23	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	7489	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 19.0	 1	    1.10000	    0.90000;
	7490	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	7491	 1	 -0.0	 0.0	 0.0	 4.86	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	7492	 1	 572.3	 159.7	 0.0	 19.88	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	7493	 1	 -0.0	 0.0	 0.0	 7.84	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7494	 1	 236.2	 45.1	 0.0	 2.88	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	7495	 1	 12.31	 3.0	 0.0	 0.98	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7496	 1	 -0.0	 -0.0	 0.0	 0.16	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7497	 1	 0.0	 -0.0	 0.0	 0.93	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7498	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	7499	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 20	    1.10000	    0.90000;
	7500	 1	 52.96	 32.8	 0.0	 5.79	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7501	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	7502	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	7503	 1	 16.92	 -0.0	 0.0	 0.57	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7504	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	7505	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	7506	 1	 0.0	 -0.0	 0.234321	 -0.195267	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	7507	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	7508	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	7509	 1	 -0.0	 0.0	 0.0	 0.19	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7510	 1	 26.35	 30.0	 0.0	 1.82	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7511	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 22	    1.10000	    0.90000;
	7512	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	7513	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	7514	 1	 0.0	 0.0	 0.0	 1.66	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7515	 1	 -0.0	 -0.0	 1.175023	 84.993965	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	7516	 1	 0.0	 0.0	 0.714478	 10.088417	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	7517	 1	 229.9	 48.9	 0.0	 8.36	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7518	 1	 292.8	 114.2	 0.0	 22.01	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	7519	 1	 -0.0	 -0.0	 0.0	 17.81	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	7520	 1	 1.63	 8.8	 0.0	 0.16	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7521	 1	 0.2	 1.6	 0.0	 0.23	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	7522	 1	 -0.0	 0.0	 0.0	 1.33	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7523	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	7524	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	7525	 1	 0.0	 0.0	 0.0	 0.32	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7526	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	7527	 1	 0.0	 0.0	 0.037754	 6.272246	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	7528	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	7529	 1	 18.52	 6.1	 0.0	 1.24	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	7530	 1	 82.39	 12.8	 0.039396	 0.060453	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7531	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	7532	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7533	 1	 -0.0	 -0.0	 0.0	 0.23	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7534	 1	 48.35	 62.8	 0.460556	 14.875393	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	7535	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 10.5	 1	    1.10000	    0.90000;
	7536	 1	 21.12	 7.7	 0.0	 0.52	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	7537	 1	 0.0	 0.0	 0.094757	 -0.276956	 0	    1.00000	    0.00000	 220.0	 19	    1.10000	    0.90000;
	7538	 1	 -0.0	 -0.0	 0.252685	 6.907589	 0	    1.00000	    0.00000	 220.0	 19	    1.10000	    0.90000;
	7539	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	7540	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 22	    1.10000	    0.90000;
	7541	 1	 55.26	 -0.0	 0.0	 1.05	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7542	 1	 -11.81	 -12.0	 0.0	 19.39	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7543	 1	 -0.0	 -0.0	 0.390917	 96.684236	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	7544	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	7545	 1	 0.0	 -0.0	 0.0	 35.06	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	7546	 1	 0.0	 -0.0	 0.0	 0.48	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7547	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	7548	 1	 12.01	 0.7	 0.0	 0.5	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	7549	 1	 -0.0	 -0.0	 0.0	 0.45	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	7550	 1	 82.6	 11.7	 0.0	 1.75	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7551	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 7	    1.10000	    0.90000;
	7552	 1	 106.8	 28.8	 0.0502	 4.2998	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7553	 1	 3.0	 1.7	 0.0	 0.53	 0	    1.00000	    0.00000	 110.0	 23	    1.10000	    0.90000;
	7554	 1	 182.18	 36.4	 0.0	 7.79	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	7555	 1	 0.0	 0.0	 0.0	 8.19	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7556	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 10.3	 1	    1.10000	    0.90000;
	7557	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	7558	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	7559	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	7560	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	7561	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	7562	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	7563	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	7564	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	7565	 1	 0.0	 0.0	 0.44806	 95.507515	 0	    1.00000	    0.00000	 380.0	 11	    1.10000	    0.90000;
	7566	 1	 175.4	 28.8	 0.0	 2.03	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	7567	 1	 0.0	 0.0	 0.0	 10.13	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7568	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	7569	 1	 39.0	 5.5	 0.0	 3.4	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7570	 1	 45.05	 15.3	 0.0	 12.29	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	7571	 1	 0.0	 -0.0	 0.0	 0.18	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7572	 1	 0.0	 -0.0	 0.0	 2.18	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7573	 1	 -0.0	 0.2	 0.0	 0.12	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	7574	 1	 -22.2	 -5.79	 0.0	 5.28	 0	    1.00000	    0.00000	 380.0	 3	    1.20000	    0.80000;
	7575	 1	 0.0	 -0.0	 0.090774	 3.340444	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	7576	 1	 153.9	 11.5	 0.565068	 6.959861	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7577	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	7578	 1	 10.8	 1.6	 0.0	 2.88	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7579	 1	 107.9	 17.6	 0.0	 1.03	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	7580	 1	 24.33	 5.8	 0.0	 13.48	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7581	 1	 -0.0	 -0.0	 0.0	 0.53	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	7582	 1	 67.98	 9.2	 0.0	 7.77	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7583	 1	 -0.0	 -0.0	 0.117944	 0.021542	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	7584	 1	 11.31	 4.6	 0.038844	 2.201156	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7585	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 9.0	 1	    1.10000	    0.90000;
	7586	 1	 33.24	 11.1	 0.0	 1.14	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	7587	 1	 0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	7588	 1	 35.14	 12.6	 0.0	 0.97	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	7589	 1	 7.41	 2.7	 0.0	 0.8	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	7590	 1	 76.08	 17.1	 0.0	 5.78	 0	    1.00000	    0.00000	 220.0	 20	    1.10000	    0.90000;
	7591	 1	 35.94	 26.0	 0.0	 8.07	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7592	 1	 85.09	 13.4	 0.0	 0.23	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7593	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	7594	 1	 18.8	 2.7	 0.0	 0.31	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7595	 1	 -0.0	 -0.0	 0.0	 2.84	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7596	 1	 -0.0	 0.0	 0.0	 4.99	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7597	 1	 11.71	 3.9	 0.0	 0.77	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	7598	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	7599	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	7600	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	7601	 1	 158.79	 39.45	 0.0	 63.31	 0	    1.00000	    0.00000	 380.0	 13	    1.10000	    0.90000;
	7602	 1	 347.61	 74.37	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 2	    1.10000	    0.90000;
	7603	 1	 -0.0	 -7.5	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7604	 1	 -0.0	 0.0	 0.0	 0.2	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7605	 1	 246.8	 36.3	 0.0	 16.01	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7606	 1	 -0.0	 0.0	 0.0	 0.89	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7607	 1	 12.51	 4.2	 0.020558	 0.199442	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	7608	 1	 -11.01	 3.6	 0.0	 0.55	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7609	 1	 -0.0	 0.0	 0.117914	 10.521738	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	7610	 1	 12.11	 -0.0	 0.0	 0.6	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7611	 1	 68.68	 21.0	 0.0	 0.56	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	7612	 1	 23.03	 8.3	 0.0	 0.09	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	7613	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	7614	 1	 58.5	 8.3	 0.0	 4.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7615	 1	 29.53	 25.1	 0.0	 0.8	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7616	 1	 13.9	 1.9	 0.0	 3.05	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7617	 1	 71.88	 44.5	 0.0	 0.04	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7618	 1	 4.61	 1.7	 0.0	 0.49	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	7619	 1	 8.31	 3.0	 0.0	 1.37	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	7620	 1	 27.73	 17.2	 0.0	 0.36	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7621	 1	 75.58	 26.1	 0.15448	 6.28552	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	7622	 1	 14.5	 3.1	 0.154498	 -0.265705	 0	    1.00000	    0.00000	 380.0	 9	    1.10000	    0.90000;
	7623	 1	 1.9	 1.4	 0.0	 1.07	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7624	 1	 44.95	 18.7	 0.0	 5.36	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	7625	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 17	    1.10000	    0.90000;
	7626	 1	 0.0	 -0.0	 0.294914	 17.471387	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	7627	 1	 102.3	 14.5	 0.0	 22.12	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7628	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	7629	 1	 8.21	 0.5	 0.115193	 3.024006	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7630	 1	 53.46	 15.4	 0.0	 0.45	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	7631	 1	 -0.0	 0.0	 0.0	 14.04	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7632	 1	 264.3	 111.6	 0.0	 34.93	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	7633	 1	 14.22	 4.7	 0.0	 2.05	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	7634	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	7635	 1	 5.51	 17.7	 0.0	 0.58	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7636	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	7637	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	7638	 1	 -0.0	 -0.0	 0.07741	 7.45259	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7639	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	7640	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	7641	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 10.6	 1	    1.10000	    0.90000;
	7642	 1	 27.6	 4.0	 0.0	 6.91	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7643	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 10.5	 1	    1.10000	    0.90000;
	7644	 1	 0.0	 -0.0	 0.0	 49.26	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	7645	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	7646	 1	 0.0	 0.0	 0.0	 2.59	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	7647	 1	 -0.0	 0.0	 0.0	 29.01	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	7648	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	7649	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	7650	 1	 20.9	 3.0	 0.0	 3.58	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7651	 1	 -0.0	 0.0	 0.0	 0.05	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7652	 1	 -0.0	 0.0	 0.0	 1.06	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	7653	 1	 0.0	 -0.0	 0.0	 0.22	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	7654	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	7655	 1	 -0.0	 0.0	 0.0	 0.4	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	7656	 1	 -4.88	 -2.79	 0.0	 0.38	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7657	 1	 101.2	 48.9	 0.0	 7.78	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7658	 1	 1.4	 0.2	 0.0	 0.81	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7659	 1	 0.0	 -0.0	 0.0	 0.18	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7660	 1	 69.18	 38.1	 0.0	 28.66	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	7661	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7662	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 15.75	 1	    1.10000	    0.90000;
	7663	 1	 43.95	 8.5	 0.0	 29.29	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	7664	 1	 91.0	 36.0	 0.0	 5.47	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7665	 1	 0.0	 0.0	 0.0	 0.18	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7666	 1	 0.0	 0.0	 0.0	 14.79	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	7667	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	7668	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 9	    1.10000	    0.90000;
	7669	 1	 -17.8	 -3.78	 0.0	 0.08	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7670	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	7671	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	7672	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	7673	 1	 0.0	 -0.0	 0.0	 2.24	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7674	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	7675	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	7676	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	7677	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	7678	 1	 -0.0	 -0.0	 0.278403	 6.279598	 0	    1.00000	    0.00000	 380.0	 16	    1.10000	    0.90000;
	7679	 1	 0.0	 0.0	 0.0	 0.23	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	7680	 1	 -0.0	 -0.0	 0.0	 1.06	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7681	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 14.0	 1	    1.10000	    0.90000;
	7682	 1	 18.12	 11.2	 0.0	 2.96	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7683	 1	 2.2	 0.5	 0.0	 0.06	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	7684	 1	 72.18	 44.7	 0.0	 2.72	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7685	 1	 66.97	 41.5	 0.0	 0.39	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7686	 1	 36.44	 12.5	 0.0	 0.59	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	7687	 1	 0.0	 -0.0	 0.0	 1.18	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7688	 1	 69.18	 19.7	 0.0	 6.99	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	7689	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 9	    1.10000	    0.90000;
	7690	 1	 108.31	 14.23	 0.0	 8.47	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	7691	 1	 117.5	 40.0	 0.0	 3.69	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	7692	 1	 46.05	 1.0	 0.058848	 3.14096	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7693	 1	 2.2	 0.5	 0.0	 1.84	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	7694	 1	 66.47	 14.14	 0.0	 0.17	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	7695	 1	 143.2	 5.9	 0.0	 5.79	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7696	 1	 1.8	 0.6	 0.0	 0.43	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	7697	 1	 78.5	 11.2	 0.0	 1.65	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7698	 1	 0.0	 -0.0	 0.059142	 1.940858	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7699	 1	 28.93	 0.2	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	7700	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	7701	 1	 0.0	 0.0	 0.0	 53.04	 0	    1.00000	    0.00000	 380.0	 12	    1.20000	    0.80000;
	7702	 1	 19.82	 12.3	 0.0	 0.06	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7703	 1	 63.5	 9.1	 0.0	 51.96	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7704	 1	 0.39	 -0.24	 0.0	 0.15	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7705	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.5	 1	    1.10000	    0.90000;
	7706	 1	 0.0	 -0.0	 0.0	 26.46055	 0	    1.00000	    0.00000	 220.0	 20	    1.10000	    0.90000;
	7707	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	7708	 1	 0.0	 0.0	 0.096104	 1.033896	 0	    1.00000	    0.00000	 220.0	 12	    1.10000	    0.90000;
	7709	 1	 339.9	 70.5	 0.0	 28.91	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7710	 1	 7.0	 1.0	 0.0	 8.71	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7711	 1	 0.0	 0.0	 0.0	 3.06	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	7712	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	7713	 1	 0.0	 -0.0	 0.0	 165.34	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	7714	 1	 -40.34	 18.3	 0.235962	 27.853028	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7715	 1	 25.0	 3.6	 0.0	 1.15	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7716	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	7717	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	7718	 1	 -0.0	 -0.0	 0.0	 0.86	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	7719	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	7720	 1	 -0.0	 -0.0	 0.0	 62.49	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	7721	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	7722	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	7723	 1	 31.2	 4.4	 0.0	 0.35	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7724	 1	 -0.0	 -0.0	 0.0	 2.08	 0	    1.00000	    0.00000	 220.0	 8	    1.10000	    0.90000;
	7725	 1	 16.02	 4.7	 0.0	 0.94	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	7726	 1	 55.26	 11.0	 0.0	 7.68	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7727	 1	 0.0	 -0.0	 0.432051	 21.130097	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	7728	 1	 -0.0	 -0.0	 0.0	 0.48	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7729	 1	 -0.0	 -0.0	 0.936444	 -0.728345	 0	    1.00000	    0.00000	 380.0	 8	    1.20000	    0.80000;
	7730	 1	 0.0	 -0.0	 0.0	 1.3	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7731	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 6.3	 1	    1.10000	    0.90000;
	7732	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	7733	 1	 -0.0	 0.0	 0.115812	 4.47349	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	7734	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	7735	 1	 267.1	 57.4	 0.0	 13.64	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	7736	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	7737	 1	 40.04	 20.0	 0.0	 0.05	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	7738	 1	 415.8	 126.6	 0.183094	 18.897593	 0	    1.00000	    0.00000	 220.0	 14	    1.10000	    0.90000;
	7739	 1	 -0.0	 0.0	 0.0	 4.87	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7740	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	7741	 1	 180.2	 24.7	 0.230883	 6.557217	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	7742	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	7743	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 15.0	 1	    1.10000	    0.90000;
	7744	 1	 -0.47	 0.1	 0.0	 0.35	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7745	 1	 89.6	 13.1	 0.0	 8.14	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7746	 1	 0.0	 0.0	 0.0	 6.4	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7747	 1	 185.6	 26.4	 0.0	 32.78	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7748	 1	 -0.0	 0.0	 0.264114	 2.943924	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	7749	 1	 97.06	 -0.33	 0.0	 1.24	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	7750	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 15.0	 1	    1.10000	    0.90000;
	7751	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 14.4	 1	    1.10000	    0.90000;
	7752	 1	 -0.0	 -0.0	 0.0	 7.85	 0	    1.00000	    0.00000	 220.0	 8	    1.10000	    0.90000;
	7753	 1	 1.1	 0.0	 0.0	 1.53	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	7754	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	7755	 1	 -0.0	 -0.0	 0.0	 29.25	 0	    1.00000	    0.00000	 380.0	 1	    1.20000	    0.80000;
	7756	 1	 0.0	 0.0	 0.0	 3.86	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	7757	 1	 0.0	 -0.0	 0.0	 30.04	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	7758	 1	 -0.0	 0.0	 0.0	 4.55	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7759	 1	 46.95	 54.6	 0.0	 29.46	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7760	 1	 21.12	 7.7	 0.0	 0.7	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	7761	 1	 111.0	 36.6	 0.0	 2.21	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7762	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7763	 1	 185.2	 26.4	 0.0	 12.41	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7764	 1	 41.2	 56.52	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7765	 1	 0.0	 0.0	 0.039358	 8.480642	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	7766	 1	 -0.0	 0.0	 0.0	 15.14	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	7767	 1	 -0.0	 -0.0	 0.0	 6.93	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	7768	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	7769	 1	 0.0	 0.0	 0.0	 138.24	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	7770	 1	 0.0	 -0.0	 0.0	 34.13	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	7771	 1	 0.0	 -0.0	 0.225625	 26.287525	 0	    1.00000	    0.00000	 380.0	 21	    1.10000	    0.90000;
	7772	 1	 288.7	 117.3	 0.0	 183.57	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	7773	 1	 55.4	 7.9	 0.0	 0.12	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7774	 1	 -12.61	 4.1	 0.0	 0.33	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7775	 1	 0.0	 -0.0	 0.0	 0.23	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	7776	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	7777	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	7778	 1	 83.59	 -7.2	 0.0	 12.95	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	7779	 1	 17.52	 6.6	 0.0	 3.79	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7780	 1	 -0.0	 0.0	 0.0	 1.79	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	7781	 1	 -0.0	 -0.0	 0.0	 0.57	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7782	 1	 -0.0	 -0.0	 0.090774	 1.480444	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	7783	 1	 19.4	 2.8	 0.0	 4.73	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7784	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	7785	 1	 -16.62	 8.7	 0.0	 7.68	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	7786	 1	 0.0	 -0.0	 0.05	 4.54	 0	    1.00000	    0.00000	 220.0	 21	    1.10000	    0.90000;
	7787	 1	 64.27	 17.5	 0.0	 0.43	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7788	 1	 0.0	 0.0	 0.0	 3.36	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7789	 1	 0.0	 -0.0	 0.0	 0.81	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	7790	 1	 -0.0	 0.0	 0.030084	 3.709916	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7791	 1	 5.5	 0.8	 0.0	 7.28	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7792	 1	 0.0	 0.0	 0.573568	 0.23309	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	7793	 1	 -0.0	 -0.0	 0.0	 3.28	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7794	 1	 28.93	 8.3	 0.0	 0.42	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	7795	 1	 -0.0	 -0.0	 0.0	 0.34	 0	    1.00000	    0.00000	 110.0	 3	    1.10000	    0.90000;
	7796	 1	 419.5	 114.1	 0.0	 55.629522	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	7797	 1	 229.0	 77.1	 0.0	 36.732397	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	7798	 1	 78.0	 11.1	 0.0	 1.33	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7799	 1	 7.0	 1.0	 0.0	 4.5	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7800	 1	 0.0	 0.0	 0.0	 53.34	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	7801	 1	 -0.0	 -0.0	 0.0	 55.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	7802	 1	 -0.0	 -0.0	 0.0	 0.43	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7803	 1	 -0.0	 -0.0	 0.0	 1.54	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7804	 1	 58.16	 16.5	 0.0	 6.24	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7805	 1	 173.6	 105.6	 0.0	 21.26	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	7806	 1	 0.0	 0.0	 0.0	 2.77	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	7807	 1	 152.73	 -17.2	 0.0	 45.85	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7808	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	7809	 1	 79.79	 49.4	 0.0	 2.24	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7810	 1	 110.6	 38.1	 0.0	 0.98	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	7811	 1	 11.11	 3.0	 0.019465	 22.220535	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7812	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	7813	 1	 66.07	 12.5	 0.0	 2.08	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7814	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	7815	 1	 40.5	 5.7	 0.0	 5.29	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7816	 1	 0.0	 0.0	 0.173707	 0.774894	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	7817	 1	 118.5	 18.3	 0.038959	 6.891041	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	7818	 1	 93.59	 77.1	 0.0	 91.89	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	7819	 1	 0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	7820	 1	 0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	7821	 1	 0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	7822	 1	 0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	7823	 1	 -13.32	 20.6	 0.0	 1.16	 0	    1.00000	    0.00000	 150.0	 9	    1.20000	    0.80000;
	7824	 1	 0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	7825	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	7826	 1	 21.02	 8.0	 0.0	 13.14	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	7827	 1	 120.94	 25.23	 0.0	 5.9	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7828	 1	 13.2	 3.25	 0.0	 5.66	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7829	 1	 48.8	 6.9	 0.0	 1.59	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7830	 1	 408.3	 84.5	 0.0	 18.02	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	7831	 1	 -0.0	 -0.0	 0.0	 2.96	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7832	 1	 13.21	 4.4	 0.0	 0.86	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	7833	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	7834	 1	 -0.0	 -0.0	 1.063676	 6.592665	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	7835	 1	 127.3	 90.5	 0.0	 6.8	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	7836	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7837	 1	 0.8	 0.5	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7838	 1	 -0.0	 -0.0	 0.0	 24.7	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7839	 1	 48.05	 28.8	 0.0	 0.02	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7840	 1	 -0.0	 -0.0	 0.0	 17.83	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	7841	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	7842	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	7843	 1	 243.45	 104.28	 0.0	 4.66	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	7844	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	7845	 1	 -0.0	 -0.0	 0.0	 4.39	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	7846	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	7847	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	7848	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	7849	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 23	    1.10000	    0.90000;
	7850	 1	 0.0	 0.0	 0.0	 55.700331	 0	    1.00000	    0.00000	 220.0	 24	    1.10000	    0.90000;
	7851	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	7852	 1	 39.34	 24.3	 0.0	 3.06	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7853	 1	 0.0	 0.0	 0.0	 3.62	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7854	 1	 57.06	 11.9	 0.0	 1.68	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7855	 1	 0.0	 0.0	 0.0	 0.62	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7856	 1	 0.0	 0.0	 0.0	 9.43	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7857	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 6.3	 1	    1.10000	    0.90000;
	7858	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	7859	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	7860	 1	 0.0	 0.0	 0.0	 2.77	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7861	 1	 -0.0	 -0.0	 0.0	 9.1	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7862	 1	 -0.0	 -0.0	 0.0	 1.52	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7863	 1	 186.2	 3.7	 0.039901	 0.100099	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	7864	 1	 -0.0	 -0.0	 0.233672	 -0.194726	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	7865	 1	 20.9	 3.0	 0.0	 2.4	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7866	 1	 241.62	 52.78	 0.0	 0.82	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7867	 1	 -0.0	 -0.0	 0.057655	 27.001954	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	7868	 1	 -0.0	 0.0	 0.0	 0.64	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7869	 1	 -0.0	 -0.0	 0.29412	 8.4749	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	7870	 1	 5.21	 1.7	 0.0	 0.87	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	7871	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7872	 1	 -0.0	 0.0	 0.0	 36.42	 0	    1.00000	    0.00000	 380.0	 9	    1.20000	    0.80000;
	7873	 1	 6.61	 2.4	 0.0	 0.81	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7874	 1	 11.91	 4.3	 0.0	 0.66	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	7875	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 9	    1.10000	    0.90000;
	7876	 1	 0.9	 27.4	 0.158479	 16.541141	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7877	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	7878	 1	 69.78	 26.0	 0.0	 5.18	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7879	 1	 0.0	 0.0	 0.0	 3.79	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7880	 1	 -0.0	 0.0	 0.226101	 1.121004	 0	    1.00000	    0.00000	 380.0	 14	    1.10000	    0.90000;
	7881	 1	 147.0	 56.3	 0.0	 0.51	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	7882	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7883	 1	 16.7	 2.4	 0.0	 0.02	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7884	 1	 -0.0	 0.0	 0.0	 25.13	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	7885	 1	 2.8	 1.0	 0.0	 0.18	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	7886	 1	 0.0	 -0.0	 0.0	 3.96	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7887	 1	 349.3	 144.3	 0.0	 0.54	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7888	 1	 56.96	 1.94	 0.0	 26.48	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	7889	 1	 -0.0	 0.0	 0.0	 0.92	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	7890	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	7891	 1	 0.0	 -0.0	 0.174657	 -0.135844	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	7892	 1	 143.3	 71.4	 0.0	 11.16	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	7893	 1	 104.5	 14.9	 0.0	 0.67	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7894	 1	 33.34	 20.7	 0.0	 0.02	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7895	 1	 0.0	 0.0	 0.0	 2.04	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	7896	 1	 0.5	 17.9	 0.151979	 42.926015	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	7897	 1	 -0.0	 0.0	 0.0	 6.07	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	7898	 1	 152.8	 38.0	 0.0	 1.46	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	7899	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	7900	 1	 233.8	 33.4	 0.0	 1.22	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7901	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	7902	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	7903	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	7904	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	7905	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	7906	 1	 26.4	 3.8	 0.0	 9.18	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7907	 1	 58.5	 8.3	 0.0	 1.2	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7908	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	7909	 1	 0.01	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.20000	    0.80000;
	7910	 1	 69.5	 9.8	 0.0	 1.91	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7911	 1	 103.3	 24.1	 0.0	 9.41	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7912	 1	 -4.86	 -2.12	 0.0	 0.26	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7913	 1	 -0.0	 -0.0	 0.0	 11.59	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	7914	 1	 104.7	 -12.8	 0.0	 2.25	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	7915	 1	 0.0	 0.0	 0.0	 2.72	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	7916	 1	 116.4	 -8.8	 0.0	 8.39	 0	    1.00000	    0.00000	 220.0	 3	    1.20000	    0.80000;
	7917	 1	 138.01	 34.55	 0.0	 8.44	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7918	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	7919	 1	 -0.17	 -0.84	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	7920	 1	 2.8	 1.0	 0.0	 0.95	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	7921	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 10.5	 1	    1.10000	    0.90000;
	7922	 1	 -0.0	 0.0	 0.0	 9.77	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	7923	 1	 53.56	 33.2	 0.0	 3.77	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7924	 1	 8.91	 1.8	 0.0	 1.78	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7925	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	7926	 1	 9.61	 1.8	 0.0	 2.84	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7927	 1	 3.33	 2.95	 0.0	 1.5	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7928	 1	 0.0	 -0.0	 0.0	 1.06	 0	    1.00000	    0.00000	 150.0	 7	    1.10000	    0.90000;
	7929	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	7930	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 9	    1.20000	    0.80000;
	7931	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	7932	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	7933	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	7934	 1	 -0.0	 0.0	 0.0	 1.82	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	7935	 1	 82.09	 39.8	 0.0	 2.35	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	7936	 1	 45.58	 -1.95	 0.0	 1.8	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	7937	 1	 -0.0	 0.0	 0.0	 1.43	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7938	 1	 -0.0	 0.0	 0.0	 5.27	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7939	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	7940	 1	 -0.0	 0.0	 0.0	 1.84	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	7941	 1	 6.01	 2.2	 0.03841	 1.04159	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	7942	 1	 -0.0	 -0.0	 0.0	 9.09	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7943	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	7944	 1	 211.3	 69.3	 0.0	 7.96	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	7945	 1	 0.0	 -0.0	 0.0	 1.77	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7946	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	7947	 1	 -0.0	 -0.0	 0.0	 0.12	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7948	 1	 -0.0	 0.0	 0.039529	 24.367428	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	7949	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	7950	 1	 -0.0	 -0.0	 0.0	 16.92	 0	    1.00000	    0.00000	 380.0	 1	    1.20000	    0.80000;
	7951	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	7952	 1	 25.23	 3.3	 0.0	 35.45	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	7953	 1	 -0.0	 -0.0	 0.0	 91.66	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	7954	 1	 0.0	 0.0	 0.05035	 5.60965	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7955	 1	 67.5	 9.6	 0.0	 26.5	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	7956	 1	 1.0	 0.3	 0.0	 0.46	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	7957	 1	 0.0	 -0.0	 0.0	 1.408086	 0	    1.00000	    0.00000	 220.0	 20	    1.10000	    0.90000;
	7958	 1	 106.6	 -18.8	 0.0	 4.1	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7959	 1	 3.3	 1.1	 0.0	 0.25	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	7960	 1	 0.0	 -0.0	 0.0	 20.81	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	7961	 1	 1.3	 -0.0	 0.0	 0.41	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7962	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 6.3	 1	    1.10000	    0.90000;
	7963	 1	 0.0	 0.0	 0.0	 4.42	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	7964	 1	 8.91	 2.5	 0.0	 0.7	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7965	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	7966	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	7967	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	7968	 1	 0.0	 0.0	 0.0	 90.33	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	7969	 1	 0.0	 0.0	 0.0	 18.02	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7970	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	7971	 1	 -0.0	 -0.0	 0.0	 11.04	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7972	 1	 0.0	 -0.0	 0.0	 91.78	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	7973	 1	 15.72	 9.7	 0.0	 1.61	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	7974	 1	 30.93	 5.8	 0.0	 4.45	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7975	 1	 -0.0	 0.0	 1.16103	 -0.644889	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	7976	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	7977	 1	 144.0	 56.6	 0.0	 5.61	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	7978	 1	 -0.0	 0.0	 0.059659	 26.507268	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	7979	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	7980	 1	 -0.0	 -0.0	 0.0	 30.55	 0	    1.00000	    0.00000	 150.0	 9	    1.20000	    0.80000;
	7981	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	7982	 1	 0.0	 0.0	 0.0	 5.75	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	7983	 1	 0.0	 -0.0	 0.573252	 0.193341	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	7984	 1	 0.0	 0.0	 0.209041	 8.836502	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	7985	 1	 148.2	 31.2	 0.040188	 16.499812	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	7986	 1	 11.81	 2.4	 0.0	 0.16	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	7987	 1	 0.0	 0.0	 2.296299	 56.527719	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	7988	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	7989	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	7990	 1	 0.0	 0.0	 0.425362	 83.915128	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	7991	 1	 102.3	 14.6	 0.0	 1.1	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	7992	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	7993	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	7994	 1	 -0.0	 0.0	 0.0	 3.21	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	7995	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	7996	 1	 -0.0	 -0.0	 0.0	 4.69	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	7997	 1	 195.74	 -32.87	 0.0	 0.83	 0	    1.00000	    0.00000	 380.0	 3	    1.20000	    0.80000;
	7998	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	7999	 1	 139.77	 41.14	 0.0	 15.57	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	8000	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	8001	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	8002	 1	 -0.0	 0.0	 0.0	 6.89	 0	    1.00000	    0.00000	 220.0	 22	    1.10000	    0.90000;
	8003	 1	 574.3	 94.6	 0.0	 16.63	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	8004	 1	 20.12	 7.9	 0.0	 0.08	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	8005	 1	 111.5	 24.8	 0.0	 9.65	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8006	 1	 0.0	 0.0	 0.0	 16.84	 0	    1.00000	    0.00000	 220.0	 22	    1.10000	    0.90000;
	8007	 1	 0.0	 -0.0	 0.0	 0.58	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8008	 1	 342.7	 82.2	 0.0	 75.02	 0	    1.00000	    0.00000	 380.0	 16	    1.10000	    0.90000;
	8009	 1	 17.62	 5.5	 0.038856	 1.361144	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	8010	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 6.3	 1	    1.10000	    0.90000;
	8011	 1	 92.59	 8.37	 0.0	 16.58	 0	    1.00000	    0.00000	 380.0	 13	    1.10000	    0.90000;
	8012	 1	 -0.0	 -0.0	 0.0	 0.2	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	8013	 1	 17.62	 7.7	 0.0	 10.73	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	8014	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8015	 1	 0.0	 -0.0	 0.0	 50.54	 0	    1.00000	    0.00000	 220.0	 22	    1.10000	    0.90000;
	8016	 1	 499.0	 191.1	 0.0	 60.73	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	8017	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	8018	 1	 67.68	 6.2	 0.0	 6.83	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8019	 1	 73.18	 13.1	 0.078753	 5.501247	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8020	 1	 456.0	 123.8	 0.23482	 16.044101	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	8021	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	8022	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	8023	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 10.6	 1	    1.10000	    0.90000;
	8024	 1	 22.12	 8.0	 0.0	 0.14	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	8025	 1	 18.22	 6.0	 0.0	 0.14	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	8026	 1	 -0.0	 0.0	 0.0	 61.88	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	8027	 1	 34.24	 -19.6	 0.0	 3.59	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	8028	 1	 4.4	 2.2	 0.0	 1.19	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	8029	 1	 0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	8030	 1	 -0.0	 -0.0	 0.0	 1.98	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8031	 1	 471.79	 140.6	 0.266552	 16.151011	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	8032	 1	 30.43	 10.1	 0.0	 1.07	 0	    1.00000	    0.00000	 110.0	 19	    1.20000	    0.80000;
	8033	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	8034	 1	 -0.0	 -0.0	 0.0	 1.18	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8035	 1	 150.2	 25.5	 0.0	 42.49	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	8036	 1	 14.52	 5.3	 0.0	 0.49	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	8037	 1	 0.0	 0.0	 0.0	 4.11	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8038	 1	 236.33	 59.35	 0.0	 18.71	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8039	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	8040	 1	 49.65	 12.3	 0.0	 2.2	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8041	 1	 0.0	 -0.0	 0.0	 58.79	 0	    1.00000	    0.00000	 380.0	 7	    1.10000	    0.90000;
	8042	 1	 13.92	 4.1	 0.0	 2.27	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	8043	 1	 0.0	 -0.0	 0.0	 0.36	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8044	 1	 154.9	 18.7	 0.039758	 6.560242	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	8045	 1	 -0.0	 0.0	 0.0	 0.82	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	8046	 1	 51.8	 7.4	 0.0	 3.41	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8047	 1	 0.0	 -0.0	 0.09832	 1.38168	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8048	 1	 0.0	 -0.0	 0.0	 0.6	 0	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	8049	 1	 68.08	 42.2	 0.0	 4.4	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8050	 1	 85.8	 12.2	 0.0	 1.7	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8051	 1	 -0.53	 -0.91	 0.090774	 7.680444	 0	    1.00000	    0.00000	 220.0	 18	    1.20000	    0.80000;
	8052	 1	 91.9	 13.1	 0.0	 7.35	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8053	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	8054	 1	 12.21	 4.4	 0.0	 2.77	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	8055	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	8056	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	8057	 1	 0.0	 0.0	 0.0	 0.94	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	8058	 1	 11.71	 2.2	 0.0	 0.48	 0	    1.00000	    0.00000	 110.0	 3	    1.10000	    0.90000;
	8059	 1	 6.71	 3.0	 0.0	 1.3	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	8060	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	8061	 1	 -0.0	 -0.0	 0.0	 7.08	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	8062	 1	 47.65	 29.5	 0.0	 4.19	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8063	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	8064	 1	 33.04	 8.1	 0.0	 1.55	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	8065	 1	 -0.0	 -0.0	 0.019551	 0.530449	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8066	 1	 10.01	 3.0	 0.0	 0.47	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	8067	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	8068	 1	 30.03	 12.2	 0.0	 0.93	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	8069	 1	 -0.0	 0.0	 0.0	 0.92	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	8070	 1	 -0.0	 -0.0	 0.0	 24.052379	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	8071	 1	 15.12	 5.0	 0.0	 0.69	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	8072	 1	 23.93	 8.7	 0.0	 0.42	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	8073	 1	 2.22	 7.8	 0.0	 19.16	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8074	 1	 21.22	 6.7	 0.0	 0.2	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	8075	 1	 0.0	 0.0	 0.0	 17.79	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	8076	 1	 88.93	 16.75	 0.0	 6.75	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	8077	 1	 0.0	 -0.0	 0.343895	 2.96342	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	8078	 1	 50.26	 16.5	 0.0	 0.69	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	8079	 1	 -0.0	 -0.0	 0.0	 10.43	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	8080	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8081	 1	 0.0	 -0.0	 0.0	 15.17	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	8082	 1	 0.0	 -0.0	 0.0	 2.66	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	8083	 1	 -0.0	 -0.0	 0.0	 1.56	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8084	 1	 31.13	 12.0	 0.0	 1.03	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	8085	 1	 -0.0	 0.0	 0.19855	 29.549	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	8086	 1	 21.62	 7.8	 0.0	 1.21	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	8087	 1	 0.0	 0.0	 0.038832	 0.271168	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8088	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 8	    1.10000	    0.90000;
	8089	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	8090	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 8	    1.10000	    0.90000;
	8091	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	8092	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	8093	 1	 5.11	 1.8	 0.0	 0.62	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	8094	 1	 0.0	 -0.0	 0.0	 1.59	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	8095	 1	 0.0	 0.0	 0.0	 3.59	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8096	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 9	    1.10000	    0.90000;
	8097	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	8098	 1	 82.89	 41.3	 0.0	 36.2	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	8099	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	8100	 1	 -0.0	 0.0	 0.0	 6.29	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8101	 1	 -0.0	 0.0	 0.0	 0.45	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	8102	 1	 23.53	 8.5	 0.0	 0.64	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	8103	 1	 0.0	 -0.0	 0.0	 1.01	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8104	 1	 -0.0	 -0.1	 0.080282	 -0.060211	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	8105	 1	 0.0	 -0.0	 0.0	 2.94	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8106	 1	 99.7	 6.0	 0.0	 2.06	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8107	 1	 0.0	 -0.0	 0.0	 59.52	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	8108	 1	 220.0	 68.3	 0.0	 3.09	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	8109	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	8110	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	8111	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	8112	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	8113	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	8114	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	8115	 1	 26.63	 8.6	 0.0	 4.44	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	8116	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	8117	 1	 16.22	 5.3	 0.0	 0.25	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	8118	 1	 130.7	 89.1	 0.0	 0.08	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	8119	 1	 0.0	 -0.0	 0.0	 88.66	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	8120	 1	 -0.0	 0.0	 0.0	 0.17	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8121	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.5	 1	    1.10000	    0.90000;
	8122	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 6.3	 1	    1.10000	    0.90000;
	8123	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	8124	 1	 3.2	 1.0	 0.0	 0.64	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	8125	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	8126	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	8127	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	8128	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	8129	 1	 1.9	 0.7	 0.0	 0.48	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	8130	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	8131	 1	 0.0	 8.5	 0.0	 12.99	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8132	 1	 -0.19	 -14.8	 0.0	 3.08	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	8133	 1	 -0.0	 -0.0	 0.0	 0.17	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	8134	 1	 0.0	 -0.0	 0.080305	 -0.240916	 0	    1.00000	    0.00000	 220.0	 11	    1.10000	    0.90000;
	8135	 1	 0.0	 0.0	 0.0	 0.33	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	8136	 1	 0.0	 -0.0	 0.0	 0.05	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8137	 1	 -0.0	 0.0	 0.0	 173.790366	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	8138	 1	 55.4	 7.9	 0.0	 6.35	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8139	 1	 118.6	 41.5	 0.0	 0.58	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	8140	 1	 13.9	 1.9	 0.0	 3.36	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8141	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	8142	 1	 19.32	 6.0	 0.0	 1.38	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	8143	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	8144	 1	 20.82	 7.9	 0.0	 18.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8145	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	8146	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	8147	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	8148	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	8149	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	8150	 1	 19.52	 7.0	 0.0	 1.73	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	8151	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	8152	 1	 275.3	 55.2	 0.019768	 17.370232	 0	    1.00000	    0.00000	 220.0	 11	    1.10000	    0.90000;
	8153	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	8154	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	8155	 1	 168.5	 54.8	 0.0	 5.34	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	8156	 1	 172.8	 11.3	 0.0	 8.61	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	8157	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 10.6	 1	    1.10000	    0.90000;
	8158	 1	 0.0	 0.0	 0.0	 14.53	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	8159	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 17	    1.10000	    0.90000;
	8160	 1	 8.3	 1.2	 0.0	 4.2	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8161	 1	 -0.0	 0.0	 0.06177	 8.002243	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	8162	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	8163	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	8164	 1	 -0.0	 0.0	 0.0	 12.61	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	8165	 1	 0.0	 0.0	 0.0	 2.6	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8166	 1	 -0.0	 -0.0	 0.0	 2.95	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8167	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	8168	 1	 0.0	 0.0	 0.0	 0.17	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	8169	 1	 83.4	 11.9	 0.0	 1.4	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8170	 1	 0.0	 0.0	 0.0	 20.96	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	8171	 1	 0.0	 -0.0	 0.0	 0.74	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8172	 1	 34.14	 12.4	 0.0	 0.4	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	8173	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	8174	 1	 23.31	 -6.67	 0.0	 2.15	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	8175	 1	 -0.0	 -0.0	 0.0	 7.17	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8176	 1	 0.0	 0.0	 0.019018	 15.280983	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	8177	 1	 0.3	 10.5	 0.059307	 6.200693	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8178	 1	 76.6	 10.9	 0.0	 3.49	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8179	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 14.4	 1	    1.10000	    0.90000;
	8180	 1	 0.0	 0.0	 0.0	 0.59	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	8181	 1	 48.8	 6.9	 0.0	 6.29	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8182	 1	 0.0	 -0.0	 0.0	 2.42	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8183	 1	 225.2	 35.2	 0.0	 11.99	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8184	 1	 38.04	 3.4	 0.0	 3.43	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8185	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	8186	 1	 0.0	 -0.0	 0.181549	 16.110889	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	8187	 1	 301.6	 122.3	 0.116416	 34.512688	 0	    1.00000	    0.00000	 380.0	 14	    1.10000	    0.90000;
	8188	 1	 6.51	 3.7	 0.0	 0.24	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	8189	 1	 158.3	 -20.5	 0.0	 2.07	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	8190	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8191	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 7	    1.10000	    0.90000;
	8192	 1	 513.4	 199.8	 0.0	 90.272366	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	8193	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 10.5	 1	    1.10000	    0.90000;
	8194	 1	 152.7	 6.0	 0.0	 0.36	 0	    1.00000	    0.00000	 120.0	 20	    1.20000	    0.80000;
	8195	 1	 0.0	 0.0	 0.0	 80.0	 0	    1.00000	    0.00000	 380.0	 12	    1.10000	    0.90000;
	8196	 1	 13.72	 4.7	 0.0	 0.22	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	8197	 1	 -0.0	 0.0	 0.0	 0.53	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8198	 1	 -4.43	 -3.56	 0.0	 0.26	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	8199	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	8200	 1	 0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	8201	 1	 -0.0	 0.0	 0.0	 1.36	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	8202	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	8203	 1	 -0.0	 0.0	 0.0	 11.52	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8204	 1	 105.5	 31.1	 0.0	 9.63	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8205	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	8206	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	8207	 1	 27.46	 5.87	 0.0	 0.8	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	8208	 1	 50.56	 8.1	 0.0	 8.02	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8209	 1	 29.13	 13.5	 0.0	 3.62	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	8210	 1	 21.12	 13.1	 0.0	 0.36	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8211	 1	 25.03	 18.8	 0.0	 1.46	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	8212	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8213	 1	 1.38	 -1.15	 0.0	 0.5	 0	    1.00000	    0.00000	 110.0	 19	    1.20000	    0.80000;
	8214	 1	 0.0	 0.0	 0.0	 4.06	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8215	 1	 -0.0	 0.0	 0.0	 0.35	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	8216	 1	 64.33	 -57.14	 0.0	 8.9	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	8217	 1	 0.0	 -0.0	 0.0	 5.98	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8218	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	8219	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	8220	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	8221	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	8222	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	8223	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	8224	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	8225	 1	 72.78	 45.1	 0.0	 11.93	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8226	 1	 61.67	 16.3	 0.0	 0.05	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8227	 1	 -0.0	 0.0	 0.0	 1.1	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	8228	 1	 45.05	 40.0	 0.0	 1.79	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	8229	 1	 26.43	 21.7	 0.081155	 5.149134	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	8230	 1	 0.0	 -0.0	 0.181156	 1.859101	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	8231	 1	 6.31	 2.5	 0.0	 0.81	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	8232	 1	 -0.0	 -0.0	 0.0	 115.512343	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	8233	 1	 55.7	 7.9	 0.0	 5.77	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8234	 1	 0.0	 0.0	 0.0	 18.66	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	8235	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8236	 1	 45.05	 5.0	 0.0	 33.8	 0	    1.00000	    0.00000	 380.0	 11	    1.10000	    0.90000;
	8237	 1	 96.59	 7.28	 0.0	 2.52	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8238	 1	 -0.14	 -1.51	 0.0	 1.85	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	8239	 1	 -0.21	 -1.04	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	8240	 1	 198.71	 60.3	 0.232451	 12.675977	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	8241	 1	 -0.0	 0.0	 0.0	 0.58	 0	    1.00000	    0.00000	 220.0	 23	    1.10000	    0.90000;
	8242	 1	 0.0	 0.0	 0.0	 19.73	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	8243	 1	 -0.0	 -0.0	 0.125321	 170.820083	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	8244	 1	 -27.43	 9.0	 0.0	 0.28	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8245	 1	 30.03	 9.9	 0.0	 0.22	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	8246	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	8247	 1	 185.7	 18.4	 0.0	 23.68	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	8248	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8249	 1	 0.0	 0.0	 0.077486	 0.462514	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8250	 1	 0.0	 -0.0	 0.0	 6.53	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	8251	 1	 124.8	 34.7	 0.0	 3.66	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8252	 1	 75.2	 10.7	 0.0	 3.89	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8253	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	8254	 1	 89.7	 7.9	 0.23657	 2.722572	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	8255	 1	 64.27	 20.1	 0.0	 5.4	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	8256	 1	 -0.0	 0.0	 0.040084	 2.749916	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8257	 1	 25.03	 1.4	 0.0	 0.26	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	8258	 1	 43.25	 15.7	 0.0	 0.37	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	8259	 1	 139.7	 9.7	 0.0	 12.61	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	8260	 1	 67.27	 1.5	 0.0	 16.46	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	8261	 1	 0.0	 -0.0	 0.0	 41.27	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	8262	 1	 54.96	 17.6	 0.0	 0.17	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	8263	 1	 6.21	 2.2	 0.0	 0.46	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	8264	 1	 43.45	 7.0	 0.078324	 13.181257	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	8265	 1	 25.13	 8.8	 0.0	 0.44	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	8266	 1	 77.89	 11.2	 0.038961	 16.120779	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	8267	 1	 153.5	 46.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	8268	 1	 198.1	 33.9	 0.0	 22.82	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8269	 1	 -0.0	 0.0	 0.0	 6.1	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	8270	 1	 0.0	 0.0	 0.0	 64.07	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	8271	 1	 0.0	 0.0	 0.0	 71.79	 0	    1.00000	    0.00000	 380.0	 21	    1.20000	    0.80000;
	8272	 1	 34.74	 16.3	 0.0	 33.38	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	8273	 1	 52.26	 19.6	 0.0	 2.64	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8274	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	8275	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	8276	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	8277	 1	 14.12	 5.2	 0.0	 1.44	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8278	 1	 -0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	8279	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	8280	 1	 41.8	 5.9	 0.0	 5.81	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8281	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 18	    1.20000	    0.80000;
	8282	 1	 195.1	 -14.2	 0.0	 12.89	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8283	 1	 -0.0	 0.0	 0.468397	 8.309186	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	8284	 1	 -0.0	 0.0	 0.0	 6.13	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	8285	 1	 -0.0	 0.0	 0.0	 0.06	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	8286	 1	 40.24	 14.4	 0.0	 1.52	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	8287	 1	 23.33	 4.0	 0.180843	 0.479438	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8288	 1	 131.6	 33.8	 0.0	 6.55	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8289	 1	 3.7	 1.3	 0.0	 0.91	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	8290	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 10.5	 1	    1.10000	    0.90000;
	8291	 1	 11.81	 4.2	 0.0	 1.07	 0	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	8292	 1	 -0.0	 -0.0	 0.0	 0.59	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8293	 1	 31.94	 4.4	 0.0	 0.29	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	8294	 1	 20.9	 3.0	 0.0	 5.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8295	 1	 0.0	 0.0	 0.0	 0.91	 0	    1.00000	    0.00000	 110.0	 3	    1.10000	    0.90000;
	8296	 1	 29.03	 18.0	 0.0	 0.02	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8297	 1	 119.6	 10.6	 0.0	 0.9	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	8298	 1	 0.0	 0.0	 0.037238	 0.032071	 0	    1.00000	    0.00000	 120.0	 6	    1.20000	    0.80000;
	8299	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	8300	 1	 32.24	 11.7	 0.0	 0.85	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	8301	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	8302	 1	 0.0	 0.0	 0.0	 0.51	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8303	 1	 30.5	 4.3	 0.0	 2.99	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8304	 1	 0.4	 0.3	 0.0	 1.46	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	8305	 1	 0.0	 -0.0	 0.0	 32.63	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	8306	 1	 352.6	 193.5	 0.0	 39.3	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	8307	 1	 -0.0	 -0.0	 0.0	 8.78	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8308	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	8309	 1	 183.07	 44.65	 0.0	 2.77	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8310	 1	 20.72	 -2.5	 0.0	 0.7	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	8311	 1	 15.52	 4.1	 0.0	 0.63	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	8312	 1	 89.51	 -12.51	 0.0	 7.04	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	8313	 1	 -0.0	 -0.0	 0.0	 21.85	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	8314	 1	 0.0	 0.0	 0.056559	 13.942868	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	8315	 1	 -0.0	 0.0	 0.0	 5.05	 0	    1.00000	    0.00000	 220.0	 12	    1.10000	    0.90000;
	8316	 1	 0.0	 -0.0	 0.0	 2.57	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	8317	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	8318	 1	 337.6	 -15.4	 0.0	 6.27	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8319	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	8320	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	8321	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8322	 1	 141.2	 45.4	 0.0	 7.55	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8323	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	8324	 1	 20.12	 8.6	 0.0	 0.17	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	8325	 1	 19.42	 6.3	 0.0	 0.48	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	8326	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	8327	 1	 0.5	 -0.0	 0.049772	 8.070228	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8328	 1	 42.45	 14.0	 0.0	 0.44	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	8329	 1	 4.61	 0.9	 0.0	 0.54	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	8330	 1	 -0.0	 0.0	 0.0	 1.67	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8331	 1	 -0.0	 -0.0	 0.0	 0.61	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	8332	 1	 -0.0	 -0.0	 0.0	 0.8	 0	    1.00000	    0.00000	 220.0	 21	    1.10000	    0.90000;
	8333	 1	 37.14	 4.02	 0.0	 3.32	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	8334	 1	 0.0	 -0.0	 0.0	 42.8	 0	    1.00000	    0.00000	 220.0	 21	    1.10000	    0.90000;
	8335	 1	 34.9	 5.0	 0.0	 5.14	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8336	 1	 161.3	 10.04	 0.0	 4.38	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8337	 1	 31.73	 5.4	 0.039366	 4.720634	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	8338	 1	 -0.0	 0.0	 0.0	 8.13	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8339	 1	 0.0	 -0.0	 0.0	 2.69	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8340	 1	 0.0	 -0.0	 0.0	 1.26	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	8341	 1	 38.64	 13.8	 0.0	 0.11	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	8342	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	8343	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	8344	 1	 0.0	 0.0	 0.0	 1.55	 0	    1.00000	    0.00000	 220.0	 22	    1.10000	    0.90000;
	8345	 1	 -0.0	 0.0	 0.0	 4.28	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8346	 1	 -0.0	 0.0	 0.0	 4.96	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8347	 1	 13.72	 4.5	 0.0	 0.16	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	8348	 1	 71.98	 28.8	 0.0	 4.88	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	8349	 1	 371.2	 73.5	 0.0	 39.869841	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	8350	 1	 -0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8351	 1	 0.0	 0.0	 0.0	 4.27	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	8352	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	8353	 1	 -928.0	 -491.4	 0.0	 0.73	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	8354	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	8355	 1	 174.0	 47.7	 0.177451	 1.142124	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	8356	 1	 175.6	 25.0	 0.0	 20.78	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	8357	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	8358	 1	 52.96	 50.3	 0.0	 0.71	 0	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	8359	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 6.3	 1	    1.10000	    0.90000;
	8360	 1	 0.0	 0.0	 0.0	 1.81	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8361	 1	 222.6	 62.6	 0.0	 30.19	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	8362	 1	 0.0	 -0.0	 0.0	 5.45	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8363	 1	 16.7	 2.4	 0.0	 3.27	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8364	 1	 210.7	 30.0	 0.0	 116.98	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	8365	 1	 -0.0	 -0.0	 0.0	 9.34	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8366	 1	 -0.0	 0.0	 0.446415	 2.766588	 0	    1.00000	    0.00000	 380.0	 18	    1.20000	    0.80000;
	8367	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	8368	 1	 0.0	 -0.0	 0.0	 0.49	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8369	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	8370	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 17	    1.10000	    0.90000;
	8371	 1	 -0.0	 0.0	 0.0	 2.23	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	8372	 1	 -0.0	 0.0	 0.0	 4.95	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	8373	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	8374	 1	 99.4	 4.3	 0.0	 3.69	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8375	 1	 9.8	 1.4	 0.0	 0.06	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8376	 1	 176.4	 17.2	 0.0	 18.37	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	8377	 1	 -0.0	 -0.0	 0.0	 1.87	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8378	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	8379	 1	 0.0	 0.0	 0.0	 22.54	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	8380	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	8381	 1	 -0.0	 0.0	 0.0	 3.23	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8382	 1	 -0.0	 0.0	 0.0	 0.44	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8383	 1	 190.5	 70.9	 0.0	 21.3	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	8384	 1	 38.34	 12.5	 0.0	 1.59	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	8385	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	8386	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	8387	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 24	    1.10000	    0.90000;
	8388	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 19.0	 1	    1.10000	    0.90000;
	8389	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	8390	 1	 -0.0	 -0.0	 0.0	 0.36	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	8391	 1	 0.0	 -0.0	 0.0	 8.92	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	8392	 1	 30.03	 10.0	 0.0	 0.26	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	8393	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	8394	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 15.75	 1	    1.10000	    0.90000;
	8395	 1	 222.7	 80.5	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	8396	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	8397	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	8398	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8399	 1	 -0.0	 0.0	 0.0	 2.16	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	8400	 1	 0.0	 -0.0	 0.0	 32.28	 0	    1.00000	    0.00000	 380.0	 1	    1.20000	    0.80000;
	8401	 1	 0.0	 -0.0	 0.0	 0.95	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8402	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	8403	 1	 -0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	8404	 1	 -0.0	 0.0	 1.044962	 67.708163	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	8405	 1	 -0.0	 -0.0	 0.0	 19.08	 0	    1.00000	    0.00000	 150.0	 9	    1.20000	    0.80000;
	8406	 1	 69.08	 -49.6	 0.0	 3.42	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	8407	 1	 0.0	 -0.0	 0.0	 0.94	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	8408	 1	 54.2	 7.8	 0.0	 21.9	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8409	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	8410	 1	 43.25	 19.5	 0.157072	 16.902196	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8411	 1	 12.6	 1.8	 0.0	 3.18	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8412	 1	 0.0	 0.0	 0.0	 0.35	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8413	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	8414	 1	 4.4	 1.1	 0.0	 0.41	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	8415	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	8416	 1	 -0.0	 0.0	 0.0	 0.85	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	8417	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	8418	 1	 40.95	 13.4	 0.0	 51.25	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	8419	 1	 6.11	 -0.0	 0.0	 1.17	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8420	 1	 0.0	 -0.0	 0.0	 4.64	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	8421	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	8422	 1	 124.6	 15.9	 0.0	 2.29	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	8423	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	8424	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	8425	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	8426	 1	 -0.0	 0.0	 0.0	 2.47	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8427	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	8428	 1	 0.0	 -0.0	 0.0	 1.38	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8429	 1	 12.6	 1.8	 0.0	 3.66	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8430	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	8431	 1	 -0.0	 -0.0	 0.0	 0.65	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8432	 1	 0.0	 -0.0	 0.0	 7.67	 0	    1.00000	    0.00000	 220.0	 16	    1.10000	    0.90000;
	8433	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.5	 1	    1.10000	    0.90000;
	8434	 1	 -0.0	 -0.0	 0.0	 0.35	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8435	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	8436	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	8437	 1	 167.6	 -9.0	 0.0	 0.39	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	8438	 1	 15.82	 4.0	 0.0	 0.7	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	8439	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	8440	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	8441	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	8442	 1	 -0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	8443	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8444	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	8445	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	8446	 1	 -7.91	 2.6	 0.0	 1.72	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8447	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	8448	 1	 0.0	 -0.0	 0.248071	 0.263274	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	8449	 1	 -0.0	 0.0	 0.0	 10.45	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8450	 1	 32.04	 14.9	 0.019626	 3.350374	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	8451	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	8452	 1	 50.46	 -10.8	 0.0	 42.99	 0	    1.00000	    0.00000	 380.0	 1	    1.20000	    0.80000;
	8453	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 21.0	 1	    1.10000	    0.90000;
	8454	 1	 -0.0	 -0.0	 0.173635	 2.565304	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	8455	 1	 -0.0	 0.0	 0.0	 0.14	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	8456	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	8457	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	8458	 1	 0.0	 0.0	 0.0	 4.12	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	8459	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	8460	 1	 190.6	 51.6	 0.215561	 8.284439	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8461	 1	 5.21	 1.3	 0.0	 24.85	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	8462	 1	 0.0	 -0.0	 0.0	 93.78	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	8463	 1	 13.01	 2.4	 0.0	 0.42	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	8464	 1	 7.0	 1.0	 0.0	 4.33	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8465	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8466	 1	 343.1	 109.5	 0.0	 41.33	 0	    1.00000	    0.00000	 380.0	 16	    1.10000	    0.90000;
	8467	 1	 72.0	 10.3	 0.0	 5.95	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8468	 1	 0.0	 -0.0	 0.0	 2.02	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	8469	 1	 96.81	 19.4	 0.059957	 4.650043	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8470	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	8471	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	8472	 1	 145.7	 -38.0	 0.228661	 28.338977	 0	    1.00000	    0.00000	 380.0	 13	    1.10000	    0.90000;
	8473	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	8474	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	8475	 1	 0.9	 28.3	 0.288059	 37.479951	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	8476	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	8477	 1	 0.0	 0.0	 0.697821	 27.39675	 0	    1.00000	    0.00000	 380.0	 17	    1.10000	    0.90000;
	8478	 1	 -0.18	 -1.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	8479	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	8480	 1	 -91.6	 -4.9	 0.151656	 24.068758	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	8481	 1	 50.2	 7.1	 0.0	 7.26	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8482	 1	 87.7	 22.2	 0.0	 7.35	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	8483	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 15.75	 1	    1.10000	    0.90000;
	8484	 1	 0.0	 0.0	 0.02947	 3.16053	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8485	 1	 0.0	 0.0	 0.0	 0.68	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8486	 1	 155.5	 38.3	 0.0	 52.84	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	8487	 1	 53.86	 17.7	 0.0	 0.33	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	8488	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	8489	 1	 183.1	 33.9	 0.0	 42.16	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	8490	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 9	    1.10000	    0.90000;
	8491	 1	 -0.0	 -0.0	 0.0	 0.86	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8492	 1	 -46.15	 15.1	 0.0	 0.64	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8493	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	8494	 1	 -4.73	 4.23	 0.0	 0.42	 0	    1.00000	    0.00000	 110.0	 23	    1.10000	    0.90000;
	8495	 1	 0.0	 -0.0	 0.0	 3.32	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	8496	 1	 244.09	 48.92	 0.0	 5.96	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8497	 1	 -0.0	 -0.0	 0.0	 132.047128	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	8498	 1	 222.0	 90.5	 0.0	 0.16	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8499	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 15.0	 1	    1.10000	    0.90000;
	8500	 1	 -0.0	 0.0	 0.079222	 9.330583	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	8501	 1	 -0.0	 0.0	 0.0	 8.78	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8502	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	8503	 1	 -0.0	 -0.0	 0.0	 0.19	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	8504	 1	 -0.0	 -0.0	 0.0	 8.58	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	8505	 1	 0.0	 0.0	 0.460713	 22.766073	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	8506	 1	 26.93	 9.5	 0.0	 7.65	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	8507	 1	 23.7	 3.4	 0.0	 2.1	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8508	 1	 129.4	 18.4	 0.0	 24.68	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	8509	 1	 -0.0	 0.0	 0.0	 15.97	 0	    1.00000	    0.00000	 220.0	 11	    1.10000	    0.90000;
	8510	 1	 0.0	 -0.0	 0.29	 -0.42	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	8511	 1	 47.3	 6.7	 0.0	 2.54	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8512	 1	 20.52	 7.6	 0.0	 2.15	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	8513	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	8514	 1	 0.9	 0.1	 0.0	 8.74	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8515	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	8516	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	8517	 1	 122.5	 38.9	 0.0	 0.84	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8518	 1	 18.42	 1.2	 0.0	 0.12	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	8519	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	8520	 1	 -0.0	 -0.0	 0.47104	 0.487094	 0	    1.00000	    0.00000	 380.0	 14	    1.10000	    0.90000;
	8521	 1	 105.9	 29.5	 0.237858	 25.422142	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8522	 1	 78.39	 21.2	 0.0	 0.97	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8523	 1	 0.0	 -0.0	 0.0	 0.2	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8524	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 7	    1.10000	    0.90000;
	8525	 1	 2.2	 -0.48	 0.0	 3.47	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8526	 1	 0.0	 -0.0	 0.0	 12.5	 0	    1.00000	    0.00000	 380.0	 9	    1.10000	    0.90000;
	8527	 1	 18.52	 11.5	 0.0	 4.41	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8528	 1	 0.0	 -0.0	 0.0	 0.1	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8529	 1	 0.0	 -0.0	 0.03816	 38.09184	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	8530	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	8531	 1	 0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	8532	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8533	 1	 0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	8534	 1	 0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	8535	 1	 0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	8536	 1	 19.82	 5.8	 0.0	 4.99	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	8537	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	8538	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	8539	 1	 -0.0	 -0.0	 0.0	 0.4	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8540	 1	 20.72	 6.8	 0.0	 0.65	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	8541	 1	 10.01	 -30.0	 0.0	 0.74	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	8542	 1	 55.26	 34.2	 0.0	 0.51	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8543	 1	 145.7	 122.2	 0.0	 4.5	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	8544	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	8545	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	8546	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	8547	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	8548	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	8549	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	8550	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	8551	 1	 0.0	 -0.0	 0.0	 3.45	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8552	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	8553	 1	 28.83	 -3.8	 0.0	 7.4	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	8554	 1	 177.5	 72.5	 0.0	 46.35	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	8555	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	8556	 1	 0.0	 -0.0	 0.0	 132.84	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	8557	 1	 39.84	 13.8	 0.058009	 12.81166	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	8558	 1	 2.0	 1.0	 0.0	 0.3	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	8559	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	8560	 1	 56.53	 15.4	 0.0	 0.12	 0	    1.00000	    0.00000	 110.0	 24	    1.10000	    0.90000;
	8561	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	8562	 1	 -0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	8563	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	8564	 1	 -0.0	 -0.0	 0.0	 0.71	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8565	 1	 38.54	 12.0	 0.0	 16.52	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8566	 1	 0.0	 -0.0	 0.0	 8.17	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	8567	 1	 0.0	 -0.0	 0.0	 0.41	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	8568	 1	 -0.0	 0.0	 0.0	 0.67	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8569	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	8570	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	8571	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	8572	 1	 0.0	 0.0	 0.03922	 0.76078	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8573	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	8574	 1	 -0.0	 0.0	 0.056963	 3.583037	 0	    1.00000	    0.00000	 380.0	 14	    1.10000	    0.90000;
	8575	 1	 25.2	 18.5	 0.616465	 136.433067	 0	    1.00000	    0.00000	 380.0	 9	    1.20000	    0.80000;
	8576	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	8577	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	8578	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	8579	 1	 -0.0	 -0.0	 0.078399	 4.4512	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	8580	 1	 22.4	 3.1	 0.0	 3.4	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8581	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	8582	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	8583	 1	 -0.0	 0.0	 0.0	 93.07	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	8584	 1	 27.9	 4.0	 0.0	 3.43	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8585	 1	 0.0	 -0.0	 0.0	 3.66	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8586	 1	 14.02	 5.5	 0.0	 3.3	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8587	 1	 26.03	 10.6	 0.0	 2.14	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	8588	 1	 0.0	 -0.0	 0.116781	 -0.097317	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	8589	 1	 0.0	 0.0	 0.0	 45.02	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	8590	 1	 106.6	 15.2	 0.0	 0.34	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8591	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8592	 1	 0.0	 0.0	 0.040225	 12.359775	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	8593	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	8594	 1	 16.72	 5.5	 0.0	 0.89	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	8595	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	8596	 1	 7.21	 3.3	 0.0	 0.91	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	8597	 1	 -0.0	 -0.0	 0.0	 0.19	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8598	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	8599	 1	 -0.0	 -7.2	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8600	 1	 64.4	 9.1	 0.0	 2.29	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8601	 1	 196.3	 -10.4	 0.0	 8.97	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	8602	 1	 33.24	 11.1	 0.0	 1.56	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	8603	 1	 0.1	 -19.1	 0.0	 0.26	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	8604	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	8605	 1	 186.1	 14.8	 0.0	 17.28	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8606	 1	 17.52	 6.5	 0.0	 0.74	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	8607	 1	 -0.0	 0.0	 0.0	 0.69	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	8608	 1	 181.9	 92.6	 0.0	 4.15	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	8609	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	8610	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	8611	 1	 42.55	 14.0	 0.0	 7.52	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	8612	 1	 0.0	 0.0	 0.0	 9.84	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	8613	 1	 0.0	 0.0	 0.0	 0.89	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	8614	 1	 25.63	 6.5	 0.0	 0.52	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8615	 1	 80.99	 30.1	 0.0	 29.8	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	8616	 1	 94.1	 39.0	 0.0	 27.61	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	8617	 1	 -0.0	 0.0	 0.0	 4.34	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8618	 1	 -57.59	 -30.52	 0.0	 2.45	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	8619	 1	 61.67	 17.4	 0.0	 0.29	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	8620	 1	 73.83	 16.41	 0.0	 15.77	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8621	 1	 -0.0	 0.0	 0.0	 1.75	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	8622	 1	 0.0	 0.0	 0.0	 33.03	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	8623	 1	 0.0	 0.0	 0.0	 30.48	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	8624	 1	 0.0	 0.0	 0.0	 34.98	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	8625	 1	 26.43	 6.6	 0.01945	 0.32055	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	8626	 1	 74.08	 10.7	 0.0	 13.55	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8627	 1	 29.03	 18.0	 0.0	 0.02	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8628	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8629	 1	 -0.0	 -0.0	 0.0	 3.98	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8630	 1	 0.0	 0.0	 0.0	 1.44	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	8631	 1	 0.0	 0.0	 0.0	 1.39	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8632	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 9	    1.20000	    0.80000;
	8633	 1	 41.8	 5.9	 0.0	 7.64	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8634	 1	 0.0	 -0.0	 0.0	 1.74	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	8635	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	8636	 1	 53.06	 17.4	 0.0	 0.11	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	8637	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	8638	 1	 22.3	 3.1	 0.0	 0.54	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8639	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	8640	 1	 78.49	 18.5	 0.0	 6.91	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8641	 1	 -0.0	 0.0	 0.0	 37.02	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	8642	 1	 -0.0	 -0.0	 0.0	 5.75	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8643	 1	 0.0	 -0.0	 0.0	 0.38	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8644	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 10.3	 1	    1.10000	    0.90000;
	8645	 1	 0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8646	 1	 -0.0	 -0.0	 0.0	 3.6	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	8647	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	8648	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	8649	 1	 -0.0	 -0.0	 0.0	 15.14	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	8650	 1	 0.0	 0.0	 0.0	 0.65	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8651	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	8652	 1	 114.4	 34.2	 0.019661	 4.460339	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8653	 1	 -0.0	 0.0	 0.038809	 40.691191	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	8654	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 6.3	 1	    1.10000	    0.90000;
	8655	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 24	    1.10000	    0.90000;
	8656	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	8657	 1	 5.21	 1.7	 0.0	 1.37	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	8658	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	8659	 1	 15.12	 7.5	 0.0	 0.33	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	8660	 1	 71.88	 21.7	 0.0	 9.63	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8661	 1	 -0.0	 0.0	 0.0	 5.96	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8662	 1	 -0.0	 0.0	 0.0	 1.4	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8663	 1	 57.06	 13.3	 0.0	 19.18	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8664	 1	 160.7	 40.3	 0.0	 3.04	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	8665	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	8666	 1	 26.03	 -14.1	 0.0	 0.84	 0	    1.00000	    0.00000	 110.0	 23	    1.10000	    0.90000;
	8667	 1	 0.0	 -0.0	 0.0	 0.55	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8668	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	8669	 1	 40.34	 15.9	 0.0	 1.31	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	8670	 1	 -7.97	 6.3	 0.0	 2.73	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8671	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	8672	 1	 106.7	 33.6	 0.0	 3.28	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	8673	 1	 80.09	 23.4	 0.03907	 0.62093	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	8674	 1	 -0.0	 -0.0	 0.0	 0.18	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8675	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	8676	 1	 208.06	 36.6	 0.0	 3.55	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8677	 1	 209.8	 102.6	 0.0	 24.31	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	8678	 1	 160.0	 50.0	 0.0	 23.19	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	8679	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	8680	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	8681	 1	 113.5	 11.5	 0.0	 5.53	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8682	 1	 64.27	 22.9	 0.0	 3.06	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	8683	 1	 -0.0	 0.0	 0.0	 11.87	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	8684	 1	 43.25	 15.2	 0.03938	 0.18062	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	8685	 1	 144.5	 67.8	 0.0	 2.43	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	8686	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	8687	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	8688	 1	 62.57	 22.7	 0.0	 0.47	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	8689	 1	 -0.0	 0.0	 0.0	 0.86	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8690	 1	 89.8	 5.9	 0.039177	 15.480617	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	8691	 1	 99.5	 28.1	 0.0	 6.23	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	8692	 1	 24.23	 9.3	 0.23794	 6.201545	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8693	 1	 22.22	 5.6	 0.019675	 0.800325	 0	    1.00000	    0.00000	 380.0	 7	    1.10000	    0.90000;
	8694	 1	 148.2	 65.3	 0.0	 10.51	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	8695	 1	 -0.0	 -0.0	 0.076637	 2.763363	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	8696	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	8697	 1	 -0.0	 -0.0	 0.038657	 0.031343	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	8698	 1	 0.0	 -0.0	 0.0	 6.35	 0	    1.00000	    0.00000	 220.0	 23	    1.10000	    0.90000;
	8699	 1	 -0.0	 -0.0	 0.228692	 3.068952	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	8700	 1	 3.5	 0.9	 0.0	 1.12	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	8701	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	8702	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	8703	 1	 17.12	 1.3	 0.0	 0.99	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	8704	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 9	    1.10000	    0.90000;
	8705	 1	 90.5	 12.9	 0.0	 2.99	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8706	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	8707	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	8708	 1	 0.0	 -0.0	 0.0	 0.29	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	8709	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	8710	 1	 157.7	 39.7	 0.039543	 53.100457	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	8711	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	8712	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	8713	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	8714	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	8715	 1	 198.6	 63.0	 1.058228	 72.887005	 0	    1.00000	    0.00000	 380.0	 3	    1.20000	    0.80000;
	8716	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	8717	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	8718	 1	 24.04	 1.68	 0.0	 4.02	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8719	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	8720	 1	 83.1	 26.1	 0.0	 23.95	 0	    1.00000	    0.00000	 220.0	 23	    1.10000	    0.90000;
	8721	 1	 -0.0	 -0.0	 0.0	 4.53	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8722	 1	 241.4	 116.9	 0.713357	 23.885167	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8723	 1	 408.9	 77.3	 0.0	 13.58	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	8724	 1	 0.0	 -0.0	 0.0	 2.75	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8725	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	8726	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	8727	 1	 18.52	 6.1	 0.0	 0.09	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	8728	 1	 48.8	 6.9	 0.0	 8.71	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8729	 1	 0.0	 0.0	 0.170406	 3.942552	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	8730	 1	 25.83	 12.5	 0.0	 0.2	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	8731	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	8732	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	8733	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	8734	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	8735	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	8736	 1	 36.04	 -8.0	 0.0	 32.73	 0	    1.00000	    0.00000	 220.0	 11	    1.10000	    0.90000;
	8737	 1	 0.0	 -0.0	 0.495152	 -0.385118	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	8738	 1	 -0.0	 0.0	 0.0	 0.45	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8739	 1	 4.61	 1.7	 0.0	 0.9	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	8740	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	8741	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	8742	 1	 7.01	 2.3	 0.0	 0.61	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	8743	 1	 0.0	 0.0	 0.0	 2.37	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	8744	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	8745	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	8746	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	8747	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	8748	 1	 -0.0	 0.0	 0.0	 50.27	 0	    1.00000	    0.00000	 380.0	 9	    1.20000	    0.80000;
	8749	 1	 -0.0	 -0.0	 0.25	 20.36	 0	    1.00000	    0.00000	 220.0	 19	    1.20000	    0.80000;
	8750	 1	 191.96	 38.57	 0.0	 122.89	 0	    1.00000	    0.00000	 380.0	 14	    1.10000	    0.90000;
	8751	 1	 -0.0	 0.0	 0.0	 219.65	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	8752	 1	 20.82	 7.9	 0.0	 6.73	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8753	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	8754	 1	 -0.0	 -0.0	 0.0	 1.35	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8755	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	8756	 1	 11.41	 0.7	 0.0	 0.24	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	8757	 1	 -8.81	 2.9	 0.0	 0.65	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8758	 1	 -0.0	 -0.0	 0.341219	 69.634607	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	8759	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	8760	 1	 -0.0	 -0.0	 0.538544	 40.619042	 0	    1.00000	    0.00000	 380.0	 11	    1.10000	    0.90000;
	8761	 1	 105.8	 51.8	 0.0	 5.31	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8762	 1	 0.04	 -0.05	 0.0	 20.75	 0	    1.00000	    0.00000	 220.0	 14	    1.10000	    0.90000;
	8763	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 9	    1.10000	    0.90000;
	8764	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	8765	 1	 -0.0	 0.0	 0.0	 9.72	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	8766	 1	 92.1	 45.0	 0.0	 0.4	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	8767	 1	 0.0	 -0.0	 0.0	 65.82	 0	    1.00000	    0.00000	 380.0	 1	    1.20000	    0.80000;
	8768	 1	 -0.0	 -0.0	 0.0	 23.15	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	8769	 1	 27.53	 17.0	 0.0	 0.86	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8770	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	8771	 1	 0.0	 -0.0	 0.0	 10.52	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	8772	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	8773	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	8774	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	8775	 1	 -0.0	 -0.0	 0.0	 35.66	 0	    1.00000	    0.00000	 380.0	 9	    1.20000	    0.80000;
	8776	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	8777	 1	 0.1	 -19.3	 0.0	 0.27	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	8778	 1	 0.0	 -0.0	 0.0	 76.15	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	8779	 1	 -0.0	 -0.0	 0.0	 5.5	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8780	 1	 9.01	 3.0	 0.0	 0.51	 0	    1.00000	    0.00000	 110.0	 23	    1.10000	    0.90000;
	8781	 1	 0.0	 0.0	 0.0	 0.37	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8782	 1	 -0.16	 -1.92	 0.0	 0.45	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	8783	 1	 -0.0	 0.0	 0.0	 0.05	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8784	 1	 61.27	 11.0	 0.0	 50.16	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	8785	 1	 0.0	 0.0	 0.0	 3.24	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	8786	 1	 23.03	 7.6	 0.0	 0.78	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	8787	 1	 48.8	 6.9	 0.0	 12.07	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8788	 1	 0.0	 0.0	 0.0	 2.22	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8789	 1	 0.0	 0.0	 0.0	 2.06	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8790	 1	 23.03	 9.2	 0.058901	 1.221099	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	8791	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	8792	 1	 -0.0	 -0.0	 0.0	 0.19	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	8793	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 9	    1.10000	    0.90000;
	8794	 1	 0.0	 0.0	 0.0	 0.84	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8795	 1	 22.32	 13.8	 0.0	 2.96	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8796	 1	 -18.52	 6.1	 0.0	 0.26	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8797	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	8798	 1	 21.62	 9.8	 0.0	 0.14	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	8799	 1	 43.55	 -20.5	 0.0	 2.53	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8800	 1	 165.9	 154.6	 0.0	 15.17	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	8801	 1	 -57.46	 -30.3	 0.0	 5.4	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8802	 1	 0.0	 0.0	 0.0	 0.53	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8803	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 8	    1.10000	    0.90000;
	8804	 1	 20.02	 6.8	 0.0	 0.48	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	8805	 1	 49.76	 15.0	 0.0	 1.22	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	8806	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	8807	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	8808	 1	 117.5	 16.7	 0.0	 3.35	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8809	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	8810	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	8811	 1	 -0.2	 -0.98	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	8812	 1	 60.57	 39.0	 0.585626	 26.746283	 0	    1.00000	    0.00000	 220.0	 19	    1.10000	    0.90000;
	8813	 1	 79.49	 22.7	 0.0	 9.26	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	8814	 1	 6.61	 1.9	 0.0	 0.67	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	8815	 1	 -0.0	 0.0	 0.0	 3.23	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	8816	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 15.75	 1	    1.10000	    0.90000;
	8817	 1	 -0.0	 -0.0	 0.0	 42.02	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	8818	 1	 5.61	 2.0	 0.0	 0.96	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	8819	 1	 0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	8820	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	8821	 1	 412.1	 79.3	 0.0	 7.73	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8822	 1	 4.11	 1.4	 0.0	 0.4	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	8823	 1	 19.32	 7.0	 0.0	 0.39	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	8824	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	8825	 1	 0.0	 0.0	 0.0	 1.43	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8826	 1	 47.65	 19.4	 0.0	 0.79	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	8827	 1	 0.0	 -0.0	 0.0	 1.73	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	8828	 1	 35.14	 14.3	 0.0	 7.31	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	8829	 1	 0.0	 -0.0	 0.0	 1.14	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	8830	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 15.0	 1	    1.10000	    0.90000;
	8831	 1	 15.02	 9.0	 0.0	 0.01	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8832	 1	 13.31	 2.8	 0.0	 0.88	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	8833	 1	 61.36	 23.66	 0.0	 0.16	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	8834	 1	 -0.0	 0.0	 0.0	 14.03	 0	    1.00000	    0.00000	 380.0	 1	    1.20000	    0.80000;
	8835	 1	 25.73	 9.3	 0.0	 0.59	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	8836	 1	 -0.0	 0.0	 0.0	 30.94	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	8837	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 10.0	 1	    1.10000	    0.90000;
	8838	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	8839	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	8840	 1	 -0.0	 0.0	 0.0	 -0.44	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	8841	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	8842	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	8843	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	8844	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	8845	 1	 -0.0	 0.0	 0.0	 33.08	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	8846	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 15.0	 1	    1.10000	    0.90000;
	8847	 1	 0.0	 0.0	 0.0	 0.5	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8848	 1	 0.0	 0.0	 0.304178	 52.494371	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	8849	 1	 -14.58	 -5.96	 0.0	 4.76	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	8850	 1	 -20.82	 6.8	 0.0	 0.91	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8851	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	8852	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	8853	 1	 47.6	 41.3	 0.0	 295.019105	 0	    1.00000	    0.00000	 380.0	 9	    1.20000	    0.80000;
	8854	 1	 27.9	 4.0	 0.0	 1.75	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8855	 1	 2.7	 0.9	 0.0	 1.49	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	8856	 1	 0.0	 -0.0	 0.0	 4.17	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	8857	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	8858	 1	 1.8	 0.7	 0.0	 0.32	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	8859	 1	 0.0	 0.0	 0.0	 -1.896325	 0	    1.00000	    0.00000	 380.0	 1	    1.20000	    0.80000;
	8860	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	8861	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	8862	 1	 0.0	 0.0	 0.0	 1.25	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8863	 1	 160.2	 89.9	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8864	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	8865	 1	 -0.0	 0.0	 0.361	 33.735	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	8866	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	8867	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	8868	 1	 5.81	 1.4	 0.0	 0.2	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	8869	 1	 6.01	 1.5	 0.0	 0.73	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	8870	 1	 111.5	 147.5	 0.0	 26.54	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	8871	 1	 0.0	 -0.0	 0.072134	 52.200985	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	8872	 1	 -0.0	 -0.0	 0.0	 26.36	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	8873	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	8874	 1	 -0.0	 0.0	 0.0	 22.6	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	8875	 1	 133.2	 24.8	 0.0	 74.43	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	8876	 1	 -0.0	 0.0	 0.0	 1.29	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8877	 1	 27.9	 4.0	 0.0	 3.97	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8878	 1	 353.0	 123.4	 0.038547	 42.441453	 0	    1.00000	    0.00000	 380.0	 14	    1.10000	    0.90000;
	8879	 1	 26.23	 8.6	 0.0	 6.14	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	8880	 1	 0.0	 5.9	 0.0392	 4.7208	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8881	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.5	 1	    1.10000	    0.90000;
	8882	 1	 0.0	 0.0	 0.0	 17.336728	 0	    1.00000	    0.00000	 220.0	 24	    1.10000	    0.90000;
	8883	 1	 1.8	 72.0	 0.520071	 44.685501	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	8884	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 24	    1.10000	    0.90000;
	8885	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	8886	 1	 0.0	 -0.0	 0.0	 0.45	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8887	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	8888	 1	 0.0	 -0.0	 0.0	 10.05	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	8889	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8890	 1	 0.0	 0.0	 0.0	 3.87	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	8891	 1	 -0.0	 0.0	 0.135493	 28.29062	 0	    1.00000	    0.00000	 380.0	 21	    1.20000	    0.80000;
	8892	 1	 -0.0	 -0.0	 0.0	 9.0	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	8893	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	8894	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	8895	 1	 0.3	 2.0	 0.0	 10.34	 0	    1.00000	    0.00000	 220.0	 14	    1.10000	    0.90000;
	8896	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 10.6	 1	    1.10000	    0.90000;
	8897	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	8898	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	8899	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8900	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	8901	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	8902	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	8903	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	8904	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	8905	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	8906	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	8907	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	8908	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	8909	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	8910	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	8911	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	8912	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 24	    1.10000	    0.90000;
	8913	 1	 0.0	 -0.0	 0.0	 0.14	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8914	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	8915	 1	 93.12	 4.99	 0.0	 0.18	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8916	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 6.3	 1	    1.10000	    0.90000;
	8917	 1	 0.0	 -0.0	 0.059132	 2.540868	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	8918	 1	 1.3	 3.8	 0.0	 0.09	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	8919	 1	 0.7	 1.5	 0.119605	 -0.089704	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	8920	 1	 128.6	 27.8	 0.0	 36.2	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	8921	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	8922	 1	 -0.0	 0.0	 0.0	 24.64	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	8923	 1	 176.75	 51.7	 0.0	 39.79	 0	    1.00000	    0.00000	 380.0	 13	    1.10000	    0.90000;
	8924	 1	 78.59	 16.0	 0.0	 1.87	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8925	 1	 13.9	 1.9	 0.0	 0.54	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8926	 1	 45.28	 15.27	 0.0	 7.88	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8927	 1	 0.0	 -0.0	 0.0	 0.05	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8928	 1	 10.11	 2.5	 0.0	 0.18	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	8929	 1	 0.0	 -0.0	 0.0	 1.18	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8930	 1	 55.7	 7.9	 0.0	 11.74	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8931	 1	 -0.0	 -0.0	 0.118007	 -0.299556	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	8932	 1	 0.0	 -0.0	 0.0	 1.79	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8933	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	8934	 1	 82.55	 30.58	 0.0	 4.26	 0	    1.00000	    0.00000	 220.0	 8	    1.10000	    0.90000;
	8935	 1	 221.25	 72.56	 0.0	 8.23	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8936	 1	 -0.0	 0.0	 0.038332	 7.391668	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	8937	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	8938	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	8939	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	8940	 1	 16.12	 5.8	 0.0	 0.91	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8941	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	8942	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	8943	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	8944	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	8945	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	8946	 1	 3.7	 1.4	 0.0	 0.63	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	8947	 1	 55.8	 7.9	 0.0	 11.5	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8948	 1	 21.32	 7.3	 0.0	 0.6	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	8949	 1	 0.0	 0.0	 0.0	 1.47	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8950	 1	 118.4	 16.9	 0.0	 0.02	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8951	 1	 -0.2	 -1.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	8952	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	8953	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	8954	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	8955	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	8956	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	8957	 1	 60.57	 18.9	 0.0	 1.46	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8958	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 22	    1.10000	    0.90000;
	8959	 1	 0.0	 0.0	 0.242897	 -0.202414	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	8960	 1	 0.0	 -0.0	 0.038985	 8.051015	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	8961	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	8962	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	8963	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	8964	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	8965	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	8966	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	8967	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	8968	 1	 0.0	 0.0	 0.495568	 -0.385442	 0	    1.00000	    0.00000	 150.0	 8	    1.20000	    0.80000;
	8969	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 9	    1.10000	    0.90000;
	8970	 1	 60.67	 5.9	 0.0	 5.32	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8971	 1	 109.0	 28.3	 0.0	 0.55	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	8972	 1	 42.55	 6.5	 0.0	 3.7	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8973	 1	 2.2	 0.5	 0.0	 0.5	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	8974	 1	 58.8	 8.4	 0.0	 5.06	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8975	 1	 -0.0	 -0.0	 0.0	 37.02	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	8976	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	8977	 1	 -0.0	 0.0	 0.0	 0.87	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8978	 1	 162.0	 4.8	 0.019957	 4.120043	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8979	 1	 76.89	 35.1	 0.0	 1.9	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	8980	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 10.0	 1	    1.10000	    0.90000;
	8981	 1	 11.51	 3.8	 0.0	 7.14	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	8982	 1	 205.3	 27.8	 0.0	 8.22	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8983	 1	 116.2	 16.5	 0.0	 2.4	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8984	 1	 39.0	 5.5	 0.0	 7.15	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	8985	 1	 0.0	 0.0	 0.009936	 0.8	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	8986	 1	 15.82	 22.0	 0.156398	 7.542701	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	8987	 1	 -0.0	 -0.0	 0.0	 3.15	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8988	 1	 0.0	 -0.0	 0.0	 0.61	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8989	 1	 8.71	 5.4	 0.0	 0.84	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	8990	 1	 39.04	 24.8	 0.0	 7.47	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	8991	 1	 15.32	 5.0	 0.0	 0.76	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	8992	 1	 60.67	 33.2	 0.0	 0.31	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	8993	 1	 0.0	 0.0	 0.0	 2.57	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	8994	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	8995	 1	 -0.0	 -0.0	 0.0	 0.67	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	8996	 1	 67.98	 54.6	 0.0	 3.39	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	8997	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	8998	 1	 95.9	 26.2	 0.0	 16.21	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	8999	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	9000	 1	 -0.0	 -0.2	 0.0	 0.69	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	9001	 1	 160.2	 88.7	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	9002	 1	 -0.0	 -0.0	 0.25	 2.3	 0	    1.00000	    0.00000	 220.0	 19	    1.10000	    0.90000;
	9003	 1	 -0.0	 0.0	 0.0	 2.45	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9004	 1	 81.09	 12.5	 0.0	 2.4	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9005	 1	 0.0	 -0.0	 0.0	 2.02	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	9006	 1	 0.0	 -0.0	 0.125869	 4.727092	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	9007	 1	 119.1	 22.3	 0.0	 2.71	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	9008	 1	 383.6	 -37.9	 0.0	 21.3	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	9009	 1	 0.0	 -0.0	 2.332213	 65.292136	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	9010	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	9011	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	9012	 1	 -0.0	 0.0	 0.0	 4.96	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9013	 1	 -0.0	 0.0	 0.202178	 26.042403	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	9014	 1	 0.0	 -0.0	 0.0	 0.32	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	9015	 1	 67.28	 -0.33	 0.0	 8.4	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	9016	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	9017	 1	 152.6	 61.8	 0.0	 2.35	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	9018	 1	 -0.0	 -0.0	 0.039334	 1.160333	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9019	 1	 124.8	 -14.7	 0.03948	 0.92052	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	9020	 1	 -0.0	 0.0	 0.0	 9.38	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	9021	 1	 -0.0	 0.0	 0.0	 0.29	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	9022	 1	 45.75	 27.5	 0.0	 4.37	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	9023	 1	 -6.31	 -3.18	 0.0	 7.28	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	9024	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	9025	 1	 289.1	 84.2	 0.0	 17.34	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	9026	 1	 -0.0	 -0.0	 0.0	 2.51	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	9027	 1	 16.72	 5.5	 0.0	 0.65	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	9028	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	9029	 1	 18.42	 5.3	 0.0	 0.39	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	9030	 1	 91.0	 28.4	 0.0	 10.57	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9031	 1	 4.3	 1.5	 0.038806	 4.611194	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	9032	 1	 0.0	 -0.0	 0.0	 20.11	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	9033	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	9034	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	9035	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 22	    1.10000	    0.90000;
	9036	 1	 223.5	 31.8	 0.0	 3.21	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	9037	 1	 0.0	 0.0	 0.05792	 0.38208	 0	    1.00000	    0.00000	 220.0	 22	    1.10000	    0.90000;
	9038	 1	 21.02	 7.0	 0.0	 0.42	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	9039	 1	 59.37	 12.7	 0.0	 22.18	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	9040	 1	 -0.0	 0.0	 0.0	 1.01	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	9041	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	9042	 1	 63.07	 13.4	 0.0	 15.52	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	9043	 1	 0.0	 0.0	 0.361	 25.935	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	9044	 1	 209.9	 38.0	 0.0	 5.26	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	9045	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	9046	 1	 -2.91	 -0.63	 0.0	 0.01	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	9047	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	9048	 1	 165.4	 130.5	 0.0	 28.06	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	9049	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	9050	 1	 -218.34	 -16.8	 0.040234	 16.999765	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	9051	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	9052	 1	 19.32	 7.0	 0.0	 0.65	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	9053	 1	 2.6	 0.5	 0.0	 0.14	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	9054	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 15.0	 1	    1.10000	    0.90000;
	9055	 1	 17.52	 6.1	 0.0	 0.53	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	9056	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 6.3	 1	    1.10000	    0.90000;
	9057	 1	 126.7	 46.1	 0.0	 5.58	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	9058	 1	 154.2	 22.0	 0.0	 12.1	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	9059	 1	 -4.82	 -0.88	 0.0	 224.85	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	9060	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	9061	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	9062	 1	 74.98	 10.5	 0.0	 12.96	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9063	 1	 83.79	 33.1	 0.0	 65.16	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	9064	 1	 0.0	 -0.0	 0.0	 3.78	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	9065	 1	 14.02	 5.6	 0.0	 2.34	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9066	 1	 0.0	 0.0	 0.559639	 19.414186	 0	    1.00000	    0.00000	 220.0	 20	    1.10000	    0.90000;
	9067	 1	 0.0	 -0.0	 0.0	 0.5	 0	    1.00000	    0.00000	 220.0	 3	    1.20000	    0.80000;
	9068	 1	 -7.62	 -2.52	 0.0	 33.185607	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	9069	 1	 0.0	 0.0	 0.36128	 3.039004	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	9070	 1	 253.2	 78.1	 0.0	 10.47	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	9071	 1	 48.8	 6.9	 0.0	 3.06	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	9072	 1	 117.0	 19.2	 0.0	 5.38	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	9073	 1	 -0.0	 0.0	 0.0	 2.49	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	9074	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	9075	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	9076	 1	 7.61	 2.5	 0.0	 0.57	 0	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	9077	 1	 0.0	 -0.0	 0.0	 2.18	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	9078	 1	 13.72	 4.5	 0.0	 0.91	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	9079	 1	 0.0	 -0.0	 0.0	 3.88	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	9080	 1	 88.8	 35.1	 0.0	 1.24	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	9081	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	9082	 1	 -0.0	 -0.0	 0.0	 0.22	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9083	 1	 231.9	 27.6	 0.0	 0.36	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9084	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 22	    1.10000	    0.90000;
	9085	 1	 -11.79	 -22.64	 0.093433	 0.71958	 0	    1.00000	    0.00000	 380.0	 3	    1.20000	    0.80000;
	9086	 1	 0.0	 -0.0	 0.0	 1.28	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	9087	 1	 -0.0	 -0.0	 0.0	 58.996104	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	9088	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	9089	 1	 0.0	 -0.0	 0.0	 0.8	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	9090	 1	 0.0	 -0.0	 0.0	 1.14	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	9091	 1	 88.0	 70.3	 0.0	 36.55	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	9092	 1	 26.9	 3.8	 0.0	 4.69	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	9093	 1	 26.43	 5.5	 0.0	 1.03	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	9094	 1	 -0.0	 -0.0	 0.0	 0.98	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	9095	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	9096	 1	 0.0	 -0.0	 0.0	 11.5	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9097	 1	 49.25	 12.0	 0.0	 7.28	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9098	 1	 -0.0	 -0.0	 0.680765	 0.501061	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	9099	 1	 227.6	 71.0	 0.0	 8.59	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	9100	 1	 16.51	 0.0	 0.0	 0.13	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	9101	 1	 70.58	 28.9	 0.089366	 0.450423	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	9102	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	9103	 1	 85.33	 14.98	 0.0	 4.44	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	9104	 1	 0.0	 -0.0	 0.0	 49.59	 0	    1.00000	    0.00000	 380.0	 13	    1.10000	    0.90000;
	9105	 1	 0.0	 -0.0	 0.0	 10.75	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	9106	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	9107	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	9108	 1	 -0.0	 -0.0	 0.0	 1.13	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	9109	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 7	    1.10000	    0.90000;
	9110	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	9111	 1	 -0.0	 0.0	 0.0	 0.94	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	9112	 1	 -0.0	 0.0	 0.058041	 0.191959	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	9113	 1	 -0.0	 0.0	 0.0	 10.44	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	9114	 1	 88.41	 34.42	 0.0	 3.45	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	9115	 1	 -0.0	 -0.0	 0.0	 2.44	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	9116	 1	 0.0	 -0.0	 0.27075	 34.52435	 0	    1.00000	    0.00000	 380.0	 18	    1.20000	    0.80000;
	9117	 1	 -0.0	 0.0	 0.0	 86.73	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	9118	 1	 0.0	 -0.0	 0.0	 0.3	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	9119	 1	 -0.6	 -1.58	 0.0	 0.22	 0	    1.00000	    0.00000	 380.0	 21	    1.20000	    0.80000;
	9120	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	9121	 1	 0.0	 0.0	 0.0	 1.07	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	9122	 1	 380.53	 113.37	 0.0	 115.0	 0	    1.00000	    0.00000	 380.0	 14	    1.10000	    0.90000;
	9123	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	9124	 1	 164.7	 44.5	 0.0	 3.67	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9125	 1	 128.8	 29.3	 0.0	 26.74	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9126	 1	 -0.0	 -0.0	 0.0	 9.9	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	9127	 1	 -0.01	 -0.0	 0.0	 26.52	 0	    1.00000	    0.00000	 150.0	 9	    1.20000	    0.80000;
	9128	 1	 0.0	 -0.0	 0.16245	 33.4651	 0	    1.00000	    0.00000	 380.0	 18	    1.20000	    0.80000;
	9129	 1	 -0.0	 -0.0	 0.0	 36.48	 0	    1.00000	    0.00000	 380.0	 9	    1.20000	    0.80000;
	9130	 1	 11.61	 2.5	 0.0	 3.84	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	9131	 1	 8.91	 5.1	 0.0	 1.06	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	9132	 1	 47.55	 29.4	 0.0	 5.79	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	9133	 1	 198.4	 32.7	 0.0	 31.82	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	9134	 1	 45.05	 12.7	 0.0	 1.73	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	9135	 1	 12.81	 4.7	 0.0	 0.64	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	9136	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	9137	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	9138	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	9139	 1	 46.56	 9.25	 0.0	 2.37	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	9140	 1	 83.19	 21.8	 0.0	 3.96	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	9141	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	9142	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	9143	 1	 91.3	 18.1	 0.0	 3.05	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9144	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	9145	 1	 112.17	 -11.06	 0.0	 13.68	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	9146	 1	 -0.0	 0.0	 0.0	 2.28	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	9147	 1	 -0.0	 0.0	 0.0	 96.62	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	9148	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	9149	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	9150	 1	 3.7	 2.6	 0.0	 4.45	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9151	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 10.6	 1	    1.10000	    0.90000;
	9152	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	9153	 1	 125.9	 -21.2	 0.0	 18.41	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	9154	 1	 12.11	 4.4	 0.0	 1.26	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	9155	 1	 18.62	 6.1	 0.0	 2.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9156	 1	 441.2	 200.7	 0.0	 42.12	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	9157	 1	 122.8	 37.2	 0.0	 37.13	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	9158	 1	 2.3	 0.3	 0.0	 0.29	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	9159	 1	 153.7	 21.9	 0.0	 17.71	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	9160	 1	 15.22	 4.9	 0.0	 0.18	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	9161	 1	 77.49	 24.1	 0.039371	 4.630629	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	9162	 1	 28.03	 58.8	 0.463629	 66.853939	 0	    1.00000	    0.00000	 380.0	 13	    1.10000	    0.90000;
	9163	 1	 52.9	 7.6	 0.0	 4.15	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	9164	 1	 0.0	 0.0	 0.0	 0.19	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	9165	 1	 -0.28	 -5.54	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 8	    1.10000	    0.90000;
	9166	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 10.5	 1	    1.10000	    0.90000;
	9167	 1	 -0.0	 -0.0	 0.0	 18.64	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	9168	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	9169	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	9170	 1	 100.1	 44.5	 0.0	 3.28	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	9171	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	9172	 1	 -0.0	 0.0	 0.05765	 26.341958	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	9173	 1	 19.12	 11.9	 0.0	 1.58	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	9174	 1	 51.96	 22.8	 0.0	 0.6	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	9175	 1	 91.8	 8.3	 0.0	 2.44	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	9176	 1	 0.0	 -0.0	 0.0	 1.51	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	9177	 1	 0.0	 -0.0	 0.0	 7.1	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	9178	 1	 0.0	 -0.0	 0.116795	 5.242671	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	9179	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	9180	 1	 0.0	 -0.0	 0.0	 3.19	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	9181	 1	 47.65	 20.4	 0.0	 3.63	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9182	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	9183	 1	 -0.0	 -0.0	 0.060538	 4.359462	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9184	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	9185	 1	 186.5	 49.9	 0.0	 13.17	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	9186	 1	 0.0	 0.0	 0.0	 33.66	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	9187	 1	 90.5	 12.8	 0.0	 2.68	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	9188	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	9189	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	9190	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	9191	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	9192	 1	 0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	9193	 1	 5.21	 1.7	 0.077745	 9.272255	 0	    1.00000	    0.00000	 220.0	 12	    1.10000	    0.90000;
	9194	 1	 20.02	 8.0	 0.0	 5.4	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	9195	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 15.75	 1	    1.10000	    0.90000;
	9196	 1	 0.0	 0.0	 0.274712	 52.929035	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	9197	 1	 -0.0	 -0.0	 0.0	 3.41	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	9198	 1	 0.0	 -0.0	 0.0	 2.37	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	9199	 1	 84.59	 -18.5	 0.0	 64.57	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	9200	 1	 139.1	 19.8	 0.0	 16.14	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	9201	 1	 -0.57	 -1.0	 0.0	 2.27	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	9202	 1	 -0.0	 -0.0	 0.0	 0.44	 0	    1.00000	    0.00000	 110.0	 3	    1.10000	    0.90000;
	9203	 1	 49.96	 15.6	 0.0	 2.66	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	9204	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 10.5	 1	    1.10000	    0.90000;
	9205	 1	 1.7	 0.6	 0.0	 0.56	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	9206	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	9207	 1	 127.9	 3.7	 0.0	 41.47	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	9208	 1	 31.33	 6.4	 0.0	 1.96	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	9209	 1	 0.0	 -0.0	 0.0	 2.13	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9210	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	9211	 1	 -4.94	 -3.67	 0.0	 0.11	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	9212	 1	 -0.0	 -7.5	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	9213	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	9214	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	9215	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	9216	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	9217	 1	 -0.0	 -0.0	 0.0	 2.05	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	9218	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	9219	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	9220	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	9221	 1	 -0.0	 0.0	 0.0	 1.66	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	9222	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	9223	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 6.3	 1	    1.10000	    0.90000;
	9224	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	9225	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	9226	 1	 95.71	 19.6	 0.0	 20.2	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	9227	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.5	 1	    1.10000	    0.90000;
	9228	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	9229	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	9230	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	9231	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	9232	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	9233	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	9234	 1	 -0.0	 0.0	 0.090774	 7.310444	 0	    1.00000	    0.00000	 220.0	 18	    1.20000	    0.80000;
	9235	 1	 -0.0	 -0.0	 0.0	 1.05	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	9236	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 9	    1.10000	    0.90000;
	9237	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	9238	 1	 -0.0	 -0.0	 0.135375	 10.042175	 0	    1.00000	    0.00000	 380.0	 18	    1.10000	    0.90000;
	9239	 1	 0.0	 -0.0	 0.115496	 -0.096247	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	9240	 1	 0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	9241	 1	 0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	9242	 1	 -0.2	 -1.64	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	9243	 1	 0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	9244	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	9245	 1	 128.8	 70.0	 0.0	 1.87	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	9246	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	9247	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	9248	 1	 0.0	 0.0	 0.0	 1.99	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	9249	 1	 116.1	 30.2	 0.0	 4.38	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	9250	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	9251	 1	 13.9	 1.9	 0.0	 2.05	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	9252	 1	 23.0	 3.2	 0.0	 3.05	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	9253	 1	 9.7	 1.4	 0.0	 7.89	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	9254	 1	 0.0	 -0.0	 0.0	 0.68	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	9255	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	9256	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	9257	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	9258	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	9259	 1	 -0.0	 -0.0	 0.180933	 0.399274	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	9260	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	9261	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	9262	 1	 -0.0	 0.0	 0.038902	 0.921098	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9263	 1	 -0.0	 0.0	 0.097251	 0.812749	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9264	 1	 42.75	 4.0	 0.0	 5.41	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	9265	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	9266	 1	 0.0	 -0.0	 0.080014	 -0.604253	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	9267	 1	 92.76	 -46.04	 0.0	 1.24	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	9268	 1	 245.51	 46.8	 0.0	 4.89	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	9269	 1	 -0.0	 0.0	 0.0	 8.26	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	9270	 1	 0.0	 -0.0	 0.039331	 1.250334	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	9271	 1	 7.21	 2.4	 0.0	 1.2	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	9272	 1	 0.0	 0.0	 0.0	 2.27	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	9273	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	9274	 1	 279.5	 104.7	 0.438922	 19.496498	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9275	 1	 46.55	 15.5	 0.0	 0.4	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	9276	 1	 22.73	 5.3	 0.0	 0.54	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	9277	 1	 -0.0	 0.0	 0.0	 3.25	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	9278	 1	 143.9	 123.3	 0.211368	 60.936732	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	9279	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	9280	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	9281	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 9	    1.10000	    0.90000;
	9282	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	9283	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	9284	 1	 -0.0	 -0.0	 0.0	 3.8	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	9285	 1	 0.0	 0.0	 0.171996	 8.536225	 0	    1.00000	    0.00000	 220.0	 19	    1.10000	    0.90000;
	9286	 1	 32.04	 15.0	 0.0	 0.15	 0	    1.00000	    0.00000	 110.0	 23	    1.10000	    0.90000;
	9287	 1	 55.46	 14.1	 0.0	 0.92	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	9288	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	9289	 1	 21.72	 7.5	 0.03975	 1.86025	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9290	 1	 0.0	 -0.0	 0.0	 0.68	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	9291	 1	 0.6	 -0.0	 0.0	 0.6	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	9292	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	9293	 1	 -0.0	 0.0	 0.0	 0.23	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	9294	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 8	    1.10000	    0.90000;
	9295	 1	 44.95	 12.8	 0.0	 2.61	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	9296	 1	 430.8	 107.9	 0.0	 11.64	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9297	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	9298	 1	 9.01	 6.4	 0.040942	 0.169058	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	9299	 1	 74.68	 10.8	 0.0	 5.82	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	9300	 1	 105.5	 15.1	 0.0	 3.5	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	9301	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	9302	 1	 13.41	 3.4	 0.0	 0.72	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	9303	 1	 24.03	 8.0	 0.0	 0.0	 0	    1.00000	    0.00000	 120.0	 6	    1.10000	    0.90000;
	9304	 1	 12.94	 4.9	 0.0	 0.15	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	9305	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	9306	 1	 0.0	 0.0	 0.0	 3.28	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	9307	 1	 -0.0	 0.0	 0.11875	 6.100938	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	9308	 1	 13.31	 4.4	 0.0	 1.51	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	9309	 1	 5.51	 2.0	 0.0	 0.66	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	9310	 1	 -0.0	 -0.0	 0.0	 1.72	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9311	 1	 105.5	 24.7	 0.0	 58.37	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	9312	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	9313	 1	 -0.0	 0.0	 0.0	 6.34	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	9314	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	9315	 1	 -0.0	 0.0	 0.0	 0.35	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9316	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	9317	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	9318	 1	 325.0	 75.8	 0.080802	 2.289198	 0	    1.00000	    0.00000	 220.0	 14	    1.10000	    0.90000;
	9319	 1	 0.0	 -0.0	 0.223046	 1.974129	 0	    1.00000	    0.00000	 380.0	 3	    1.20000	    0.80000;
	9320	 1	 3.1	 1.5	 0.235344	 1.033686	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	9321	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	9322	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	9323	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	9324	 1	 251.0	 100.5	 0.15739	 9.43261	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9325	 1	 11.61	 7.2	 0.0	 16.18	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	9326	 1	 11.31	 3.7	 0.0	 0.98	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	9327	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	9328	 1	 118.4	 16.9	 0.0	 27.1	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	9329	 1	 0.0	 -0.0	 0.0	 0.52	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	9330	 1	 246.2	 119.1	 0.0	 31.72	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	9331	 1	 75.43	 10.49	 0.0	 7.91	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9332	 1	 0.0	 -0.0	 0.284218	 27.033151	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	9333	 1	 15.62	 5.3	 0.0	 2.17	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	9334	 1	 159.9	 47.4	 0.0	 3.65	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9335	 1	 14.31	 0.87	 0.0	 3.79	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	9336	 1	 20.9	 3.0	 0.0	 1.96	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	9337	 1	 -0.0	 0.0	 0.0	 3.86	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	9338	 1	 -0.0	 -0.0	 0.079833	 -0.059875	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	9339	 1	 27.9	 4.0	 0.0	 6.41	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	9340	 1	 22.02	 7.7	 0.0	 0.78	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	9341	 1	 0.0	 0.0	 0.0	 0.41	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9342	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	9343	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	9344	 1	 16.52	 3.3	 0.0	 0.37	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	9345	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	9346	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	9347	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	9348	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	9349	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	9350	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	9351	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	9352	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	9353	 1	 74.32	 11.08	 0.0	 2.08	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	9354	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	9355	 1	 80.09	 19.0	 0.0	 1.88	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	9356	 1	 278.1	 95.2	 0.037933	 113.352067	 0	    1.00000	    0.00000	 380.0	 13	    1.10000	    0.90000;
	9357	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	9358	 1	 11.61	 7.6	 0.0	 6.21	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9359	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 24	    1.10000	    0.90000;
	9360	 1	 154.7	 48.2	 0.0	 5.49	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	9361	 1	 4.0	 0.1	 0.0	 0.02	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	9362	 1	 0.0	 0.0	 0.0	 27.4	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	9363	 1	 -0.0	 -0.0	 0.0	 249.594232	 0	    1.00000	    0.00000	 750.0	 24	    1.20000	    0.80000;
	9364	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 15.75	 1	    1.10000	    0.90000;
	9365	 1	 44.05	 18.0	 0.0	 0.88	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	9366	 1	 -0.0	 0.0	 0.0	 1.66	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	9367	 1	 62.7	 9.0	 0.0	 1.55	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	9368	 1	 7.91	 2.6	 0.0	 1.72	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	9369	 1	 0.0	 -0.0	 0.0	 0.04	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	9370	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 9	    1.10000	    0.90000;
	9371	 1	 0.0	 -0.0	 0.0	 0.33	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	9372	 1	 76.48	 19.8	 0.0	 5.41	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9373	 1	 2.5	 1.3	 0.0	 1.01	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	9374	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	9375	 1	 16.42	 5.9	 0.0	 0.25	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	9376	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	9377	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	9378	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	9379	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	9380	 1	 126.9	 80.5	 0.0	 46.82	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	9381	 1	 10.44	 2.73	 0.0	 0.26	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	9382	 1	 57.86	 23.2	 0.0	 2.08	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	9383	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	9384	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	9385	 1	 39.64	 11.9	 0.0	 2.86	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	9386	 1	 36.34	 15.2	 0.0	 0.3	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9387	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	9388	 1	 170.4	 81.9	 0.0	 59.64	 0	    1.00000	    0.00000	 380.0	 17	    1.10000	    0.90000;
	9389	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	9390	 1	 -119.63	 -2.7	 0.122326	 29.298062	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	9391	 1	 67.67	 16.4	 0.0	 3.7	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9392	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	9393	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	9394	 1	 43.75	 2.2	 0.0	 1.36	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	9395	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	9396	 1	 246.9	 20.3	 0.0	 4.52	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	9397	 1	 0.0	 0.0	 0.674563	 11.497864	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	9398	 1	 70.08	 43.4	 0.0	 1.83	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	9399	 1	 -0.0	 -0.0	 0.0	 5.96	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	9400	 1	 5.11	 2.5	 0.0	 0.95	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	9401	 1	 174.3	 11.8	 0.0	 0.51	 0	    1.00000	    0.00000	 220.0	 3	    1.20000	    0.80000;
	9402	 1	 17.25	 4.26	 0.0	 0.21	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	9403	 1	 -0.0	 -0.0	 0.0	 2.26	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	9404	 1	 -0.18	 -2.28	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	9405	 1	 0.0	 -0.0	 0.0	 1.08	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	9406	 1	 -13.26	 -7.13	 0.0	 23.16	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	9407	 1	 10.21	 3.8	 0.0	 4.6	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9408	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 20	    1.10000	    0.90000;
	9409	 1	 83.19	 22.9	 0.0	 28.5	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	9410	 1	 93.1	 43.7	 0.0	 2.7	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	9411	 1	 0.0	 -0.0	 0.098479	 0.231521	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9412	 1	 0.0	 0.0	 0.0	 6.03	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9413	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 6.3	 1	    1.10000	    0.90000;
	9414	 1	 1.4	 0.5	 0.0	 0.47	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	9415	 1	 -0.0	 0.0	 0.223468	 1.103777	 0	    1.00000	    0.00000	 220.0	 3	    1.20000	    0.80000;
	9416	 1	 0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	9417	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	9418	 1	 0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 7	    1.10000	    0.90000;
	9419	 1	 69.78	 35.9	 0.712912	 6.505612	 0	    1.00000	    0.00000	 220.0	 19	    1.10000	    0.90000;
	9420	 1	 28.63	 11.0	 0.0	 1.27	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	9421	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 6.3	 1	    1.10000	    0.90000;
	9422	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	9423	 1	 0.0	 -0.0	 0.0	 0.64	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	9424	 1	 -85.69	 -2.0	 0.0	 21.28	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	9425	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	9426	 1	 -23.09	 -46.44	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	9427	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	9428	 1	 47.0	 6.7	 0.0	 6.12	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	9429	 1	 59.9	 8.5	 0.0	 7.81	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	9430	 1	 163.3	 70.3	 0.0	 5.2	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	9431	 1	 43.95	 15.5	 0.0	 6.36	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	9432	 1	 193.8	 18.0	 0.0	 82.73	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	9433	 1	 1.0	 -2.3	 0.0	 6.33	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	9434	 1	 77.19	 23.0	 0.0	 63.4	 0	    1.00000	    0.00000	 380.0	 16	    1.10000	    0.90000;
	9435	 1	 54.96	 13.2	 0.0	 2.95	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	9436	 1	 27.13	 8.9	 0.0	 0.27	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	9437	 1	 127.1	 44.7	 0.040242	 4.329758	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9438	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	9439	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	9440	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	9441	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	9442	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	9443	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	9444	 1	 0.0	 -0.0	 0.0	 5.95	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	9445	 1	 8.31	 3.0	 0.0	 0.56	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	9446	 1	 0.0	 -0.0	 0.0	 11.67	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	9447	 1	 20.52	 13.3	 0.0	 0.17	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9448	 1	 159.4	 28.4	 0.0	 15.17	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	9449	 1	 -9.78	 -3.29	 0.0	 0.12	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	9450	 1	 -0.0	 0.0	 0.056243	 48.433131	 0	    1.00000	    0.00000	 380.0	 3	    1.20000	    0.80000;
	9451	 1	 -0.0	 0.0	 0.119552	 0.120336	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	9452	 1	 -0.01	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 8	    1.10000	    0.90000;
	9453	 1	 71.68	 14.8	 0.0	 13.66	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	9454	 1	 -0.0	 -0.0	 0.060112	 0.249888	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	9455	 1	 22.23	 8.0	 0.0	 5.7	 0	    1.00000	    0.00000	 220.0	 21	    1.10000	    0.90000;
	9456	 1	 11.1	 1.6	 0.0	 3.18	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	9457	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 14.4	 1	    1.10000	    0.90000;
	9458	 1	 9.41	 13.8	 0.0	 65.59	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	9459	 1	 3.2	 -0.4	 0.0	 1.76	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	9460	 1	 1.83	 -5.69	 0.0	 5.49	 0	    1.00000	    0.00000	 380.0	 3	    1.20000	    0.80000;
	9461	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	9462	 1	 25.0	 3.6	 0.0	 3.86	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	9463	 1	 -0.0	 -0.0	 0.0	 0.45	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	9464	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	9465	 1	 -0.0	 -0.0	 0.0	 2.55	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	9466	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.5	 1	    1.10000	    0.90000;
	9467	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	9468	 1	 0.0	 0.0	 0.249386	 4.993711	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	9469	 1	 200.4	 115.2	 0.0	 6.18	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	9470	 1	 0.0	 0.0	 0.0	 9.93	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9471	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	9472	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	9473	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	9474	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	9475	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	9476	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	9477	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	9478	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	9479	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	9480	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	9481	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	9482	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	9483	 1	 0.0	 0.0	 0.0	 1.99	 0	    1.00000	    0.00000	 220.0	 8	    1.10000	    0.90000;
	9484	 1	 141.2	 34.8	 0.0	 2.37	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9485	 1	 -0.0	 -0.0	 0.0	 23.58	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	9486	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	9487	 1	 0.0	 0.0	 0.192988	 25.798353	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	9488	 1	 -0.0	 0.0	 0.090774	 1.940444	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	9489	 1	 0.0	 -0.0	 0.0	 29.2	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	9490	 1	 3.7	 1.5	 0.057734	 0.922266	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	9491	 1	 2.1	 122.3	 0.724149	 28.756715	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	9492	 1	 -0.0	 -0.0	 0.713731	 106.320569	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	9493	 1	 -0.0	 -0.0	 0.057981	 20.043081	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	9494	 1	 18.36	 -0.95	 0.0	 3.83	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	9495	 1	 0.0	 -0.0	 0.0	 23.8	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	9496	 1	 -0.12	 -1.74	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 8	    1.20000	    0.80000;
	9497	 1	 84.59	 12.9	 0.0	 3.66	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	9498	 1	 -0.0	 0.0	 0.0	 17.82	 0	    1.00000	    0.00000	 380.0	 1	    1.20000	    0.80000;
	9499	 1	 174.6	 48.9	 0.0	 7.46	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	9500	 1	 0.0	 -0.0	 0.297804	 2.218894	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	9501	 1	 9.51	 4.6	 0.0	 0.16	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	9502	 1	 0.0	 -0.0	 0.0	 8.2	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	9503	 1	 0.9	 0.5	 0.0	 0.9	 0	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	9504	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	9505	 1	 0.0	 -0.0	 0.0	 24.38	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	9506	 1	 -0.0	 0.0	 0.703357	 4.645536	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	9507	 1	 0.0	 -0.0	 0.0	 3.02	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	9508	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	9509	 1	 -0.0	 0.0	 0.0	 13.86	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	9510	 1	 25.13	 9.0	 0.0	 1.46	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	9511	 1	 0.0	 0.0	 0.104186	 55.436651	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	9512	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	9513	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 8	    1.10000	    0.90000;
	9514	 1	 -0.0	 -0.0	 0.0	 2.64	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	9515	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 8	    1.10000	    0.90000;
	9516	 1	 4.61	 2.6	 0.038572	 0.121428	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	9517	 1	 13.21	 3.5	 0.0	 0.32	 0	    1.00000	    0.00000	 110.0	 18	    1.20000	    0.80000;
	9518	 1	 -0.19	 -4.38	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	9519	 1	 49.25	 30.9	 0.097351	 12.97086	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	9520	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	9521	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	9522	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 8	    1.10000	    0.90000;
	9523	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 8	    1.10000	    0.90000;
	9524	 1	 0.0	 -0.0	 0.26929	 0.080552	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	9525	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 8	    1.10000	    0.90000;
	9526	 1	 41.31	 5.96	 0.0	 0.89	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	9527	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	9528	 1	 41.8	 5.9	 0.0	 10.95	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	9529	 1	 141.5	 20.1	 0.0	 5.35	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	9530	 1	 0.0	 -0.0	 0.0	 0.22	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9531	 1	 -0.0	 -0.0	 0.0	 0.36	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	9532	 1	 88.2	 26.7	 0.0	 8.91	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9533	 1	 20.02	 9.6	 0.0	 0.17	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	9534	 1	 68.28	 39.0	 0.19855	 79.84755	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	9535	 1	 13.92	 4.3	 0.0	 1.1	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	9536	 1	 -0.18	 -1.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	9537	 1	 20.32	 8.6	 0.0	 0.94	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	9538	 1	 0.0	 -0.0	 0.133519	 0.166481	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9539	 1	 -14.73	 -9.85	 0.0	 0.51	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	9540	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 8	    1.10000	    0.90000;
	9541	 1	 -0.19	 -1.94	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	9542	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	9543	 1	 20.32	 -22.0	 0.0	 5.35	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	9544	 1	 0.0	 -0.0	 0.0	 2.3	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9545	 1	 30.43	 12.0	 0.0	 0.42	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	9546	 1	 24.83	 9.0	 0.0	 0.24	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	9547	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	9548	 1	 0.0	 0.0	 0.0	 0.74	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	9549	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	9550	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	9551	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	9552	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.5	 1	    1.10000	    0.90000;
	9553	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 14.0	 1	    1.10000	    0.90000;
	9554	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 6.3	 1	    1.10000	    0.90000;
	9555	 1	 100.1	 48.9	 0.0	 0.11	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	9556	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	9557	 1	 -3.51	 -0.52	 0.0	 0.19	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	9558	 1	 446.5	 105.6	 0.0	 38.83	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	9559	 1	 42.85	 14.3	 0.0	 0.1	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	9560	 1	 0.0	 0.0	 0.0	 31.19	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	9561	 1	 120.69	 18.1	 0.0	 15.46	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9562	 1	 37.6	 21.67	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.20000	    0.80000;
	9563	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	9564	 1	 27.9	 4.0	 0.0	 1.86	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	9565	 1	 34.9	 5.0	 0.0	 1.74	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	9566	 1	 20.72	 7.5	 0.0	 0.33	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	9567	 1	 349.2	 61.3	 0.233208	 36.974905	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	9568	 1	 68.48	 22.4	 0.0	 4.38	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	9569	 1	 0.9	 0.3	 0.0	 0.12	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	9570	 1	 0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	9571	 1	 27.43	 -36.4	 0.0	 2.2	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	9572	 1	 33.24	 11.1	 0.0	 0.62	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	9573	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 22	    1.10000	    0.90000;
	9574	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 22	    1.10000	    0.90000;
	9575	 1	 4.91	 1.4	 0.0	 0.49	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	9576	 1	 92.4	 13.1	 0.0	 0.66	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	9577	 1	 1.1	 -0.0	 0.0	 0.28	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	9578	 1	 26.33	 8.7	 0.0	 0.58	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	9579	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	9580	 1	 7.61	 1.3	 0.0	 0.58	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	9581	 1	 0.0	 -0.0	 0.0	 0.76	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	9582	 1	 75.18	 50.09	 0.678725	 45.75816	 0	    1.00000	    0.00000	 380.0	 21	    1.20000	    0.80000;
	9583	 1	 20.1	 2.9	 0.0	 10.11	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	9584	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	9585	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	9586	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	9587	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	9588	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	9589	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	9590	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	9591	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	9592	 1	 -37.81	 -21.64	 0.0	 83.358794	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	9593	 1	 0.0	 0.0	 0.0	 4.61	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9594	 1	 3.7	 1.3	 0.0	 0.2	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	9595	 1	 -0.0	 -0.0	 0.0	 17.75	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	9596	 1	 105.5	 35.3	 0.0	 1.23	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	9597	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 7	    1.10000	    0.90000;
	9598	 1	 216.0	 56.2	 0.0	 6.98	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	9599	 1	 9.08	 3.94	 0.0	 0.12	 0	    1.00000	    0.00000	 110.0	 24	    1.10000	    0.90000;
	9600	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	9601	 1	 3.7	 0.9	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	9602	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 23	    1.10000	    0.90000;
	9603	 1	 328.9	 -9.3	 0.0	 28.37	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	9604	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 7	    1.10000	    0.90000;
	9605	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 23	    1.10000	    0.90000;
	9606	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 23	    1.10000	    0.90000;
	9607	 1	 43.15	 14.4	 0.0	 1.73	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	9608	 1	 43.15	 14.8	 0.0	 17.41	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	9609	 1	 0.0	 0.0	 0.0	 1.2	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	9610	 1	 -15.12	 5.0	 0.0	 0.25	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	9611	 1	 0.0	 0.0	 0.0	 32.43	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9612	 1	 0.0	 -0.0	 0.0	 6.28	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	9613	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 24	    1.10000	    0.90000;
	9614	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	9615	 1	 114.8	 33.1	 0.0	 2.03	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	9616	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	9617	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	9618	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	9619	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	9620	 1	 -0.0	 0.0	 0.0	 24.57	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	9621	 1	 0.0	 0.0	 0.0	 26.84	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	9622	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	9623	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	9624	 1	 51.76	 21.0	 0.0	 0.57	 0	    1.00000	    0.00000	 110.0	 3	    1.10000	    0.90000;
	9625	 1	 35.34	 37.8	 0.0	 9.28	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	9626	 1	 15.14	 11.3	 0.0	 13.16	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	9627	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	9628	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	9629	 1	 -0.0	 -0.0	 0.0	 3.48	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	9630	 1	 8.91	 2.4	 0.0	 0.6	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	9631	 1	 26.63	 9.4	 0.0	 0.14	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	9632	 1	 -6.84	 -0.61	 0.0	 0.49	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	9633	 1	 153.8	 23.4	 0.0	 87.73	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	9634	 1	 -0.0	 -0.0	 0.0	 10.15	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	9635	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	9636	 1	 -22.27	 -8.9	 0.095871	 32.326698	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	9637	 1	 24.73	 6.4	 0.0	 0.64	 0	    1.00000	    0.00000	 110.0	 3	    1.10000	    0.90000;
	9638	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 6.3	 1	    1.10000	    0.90000;
	9639	 1	 0.0	 -0.0	 0.0	 1.76	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	9640	 1	 0.0	 0.0	 0.0	 34.29	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	9641	 1	 124.8	 45.6	 0.0	 3.12	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	9642	 1	 0.0	 0.0	 0.0	 0.47	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	9643	 1	 9.61	 20.2	 0.232189	 10.586184	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	9644	 1	 1.3	 -0.0	 0.0	 0.37	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	9645	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	9646	 1	 -0.0	 0.0	 0.050928	 29.839072	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	9647	 1	 8.81	 2.9	 0.0	 0.53	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	9648	 1	 109.1	 15.0	 0.0	 8.82	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	9649	 1	 52.36	 7.4	 0.0	 26.39	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	9650	 1	 16.52	 2.1	 0.0	 0.72	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	9651	 1	 10.61	 3.5	 0.0	 1.3	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	9652	 1	 69.98	 23.1	 0.0	 2.52	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	9653	 1	 25.83	 7.2	 0.0	 0.88	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	9654	 1	 77.58	 -6.54	 0.0	 10.66	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	9655	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	9656	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	9657	 1	 0.0	 -0.0	 0.0	 16.66	 0	    1.00000	    0.00000	 220.0	 12	    1.10000	    0.90000;
	9658	 1	 174.0	 49.6	 0.0	 14.84	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	9659	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	9660	 1	 15.22	 7.2	 0.0	 1.81	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	9661	 1	 137.4	 81.7	 0.0	 6.1	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	9662	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	9663	 1	 -0.0	 0.0	 0.0	 40.86	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	9664	 1	 65.77	 5.2	 0.058568	 5.441193	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	9665	 1	 483.8	 105.2	 0.0	 0.0	 0	    1.00000	    0.00000	 120.0	 20	    1.10000	    0.90000;
	9666	 1	 14.02	 6.0	 0.0	 0.57	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	9667	 1	 0.0	 -0.0	 0.0	 11.72	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	9668	 1	 76.6	 10.9	 0.0	 12.63	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	9669	 1	 41.14	 15.25	 0.0	 3.96	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9670	 1	 0.0	 -0.0	 0.0	 1.04	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	9671	 1	 13.31	 3.5	 0.0	 0.52	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	9672	 1	 -0.0	 0.0	 0.0	 1.35	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	9673	 1	 0.0	 -0.0	 0.0	 11.08	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	9674	 1	 0.0	 -0.0	 0.0	 3.06	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9675	 1	 69.7	 9.9	 0.0	 4.66	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	9676	 1	 60.7	 8.7	 0.0	 3.23	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	9677	 1	 0.0	 -0.0	 0.0	 10.67	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9678	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	9679	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	9680	 1	 0.4	 191.7	 0.172516	 29.716237	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	9681	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	9682	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	9683	 1	 0.0	 0.0	 0.0	 7.88	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	9684	 1	 62.7	 9.0	 0.0	 5.31	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	9685	 1	 -37.33	 -11.88	 0.0	 145.18	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	9686	 1	 18.82	 1.7	 0.0	 6.24	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	9687	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 9	    1.20000	    0.80000;
	9688	 1	 0.0	 -0.0	 0.019638	 0.520362	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	9689	 1	 0.0	 -0.0	 0.058048	 0.431627	 0	    1.00000	    0.00000	 110.0	 23	    1.10000	    0.90000;
	9690	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	9691	 1	 35.04	 12.9	 0.0	 0.46	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	9692	 1	 62.63	 16.3	 0.0	 2.03	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9693	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	9694	 1	 143.8	 46.45	 0.0	 3.26	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9695	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	9696	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	9697	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	9698	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	9699	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	9700	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	9701	 1	 0.0	 -0.0	 0.083053	 -0.249159	 0	    1.00000	    0.00000	 220.0	 11	    1.10000	    0.90000;
	9702	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	9703	 1	 0.0	 -0.0	 0.224628	 -0.177831	 0	    1.00000	    0.00000	 220.0	 18	    1.20000	    0.80000;
	9704	 1	 117.6	 16.7	 0.0	 10.55	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	9705	 1	 -0.0	 0.0	 0.0	 4.18	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	9706	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	9707	 1	 -0.0	 0.0	 0.0	 0.31	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9708	 1	 0.0	 0.0	 0.0	 26.92	 0	    1.00000	    0.00000	 380.0	 1	    1.20000	    0.80000;
	9709	 1	 61.65	 10.24	 0.0	 3.48	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9710	 1	 176.7	 41.2	 0.0	 10.66	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9711	 1	 20.9	 3.0	 0.0	 2.59	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	9712	 1	 -0.0	 0.0	 0.039696	 0.220304	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	9713	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	9714	 1	 4.81	 1.0	 0.0	 0.69	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	9715	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	9716	 1	 -0.0	 -0.0	 0.0	 0.27	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	9717	 1	 27.63	 17.1	 0.0	 5.89	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	9718	 1	 38.04	 18.0	 0.0	 0.15	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	9719	 1	 21.72	 7.2	 0.0	 0.76	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	9720	 1	 48.8	 6.9	 0.0	 3.56	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	9721	 1	 -5.92	 -2.24	 0.0	 1.43	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	9722	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 15.0	 1	    1.10000	    0.90000;
	9723	 1	 -0.0	 -0.0	 0.0	 0.69	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	9724	 1	 15.32	 5.0	 0.0	 1.3	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	9725	 1	 4.61	 1.7	 0.0	 0.36	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	9726	 1	 -9.32	 -10.58	 0.0	 11.38	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	9727	 1	 -0.0	 0.0	 0.060179	 66.686182	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	9728	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	9729	 1	 30.83	 80.0	 0.470063	 21.77828	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	9730	 1	 0.0	 0.0	 0.0	 1.68	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9731	 1	 0.0	 0.0	 0.197132	 5.602151	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	9732	 1	 -0.0	 -0.0	 0.0	 19.57	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	9733	 1	 29.73	 11.0	 0.0	 0.61	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	9734	 1	 199.6	 27.1	 0.0	 33.58	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	9735	 1	 48.8	 6.9	 0.0	 0.44	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	9736	 1	 -0.0	 0.0	 0.060423	 0.269647	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	9737	 1	 -0.2	 -1.64	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	9738	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 22	    1.10000	    0.90000;
	9739	 1	 74.58	 16.6	 0.0	 2.02	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	9740	 1	 0.0	 0.0	 0.0	 10.68	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9741	 1	 0.0	 0.0	 0.090774	 3.610444	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	9742	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	9743	 1	 10.31	 4.6	 0.0	 0.64	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	9744	 1	 0.0	 -0.0	 0.0	 35.98	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	9745	 1	 261.7	 104.6	 0.0	 29.76	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	9746	 1	 132.9	 13.6	 0.0	 3.44	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	9747	 1	 0.0	 0.0	 0.0	 3.87	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	9748	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	9749	 1	 207.7	 63.0	 0.100827	 232.399999	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	9750	 1	 -0.0	 0.0	 0.0	 0.42	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	9751	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	9752	 1	 406.3	 92.5	 0.0	 66.92	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	9753	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	9754	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	9755	 1	 40.5	 5.7	 0.0	 2.11	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	9756	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	9757	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	9758	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	9759	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	9760	 1	 0.0	 0.0	 0.153311	 -0.114983	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	9761	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	9762	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	9763	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	9764	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	9765	 1	 20.02	 6.0	 0.0	 1.96	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	9766	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	9767	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	9768	 1	 85.9	 12.2	 0.0	 2.77	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	9769	 1	 -0.0	 0.0	 0.0	 98.36	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	9770	 1	 109.5	 22.8	 0.0	 7.06	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	9771	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	9772	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	9773	 1	 -0.0	 0.0	 0.048383	 193.021617	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	9774	 1	 0.0	 0.0	 0.0	 0.51	 0	    1.00000	    0.00000	 110.0	 3	    1.10000	    0.90000;
	9775	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	9776	 1	 66.67	 27.8	 0.0	 0.51	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	9777	 1	 -0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	9778	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	9779	 1	 70.68	 11.9	 0.0	 4.34	 0	    1.00000	    0.00000	 220.0	 20	    1.10000	    0.90000;
	9780	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	9781	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	9782	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	9783	 1	 0.0	 0.0	 0.0	 32.21	 0	    1.00000	    0.00000	 380.0	 12	    1.20000	    0.80000;
	9784	 1	 -7.1	 -4.02	 0.0	 1.05	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	9785	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	9786	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	9787	 1	 42.55	 12.5	 0.0	 1.26	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9788	 1	 10.33	 3.3	 0.0	 4.65	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9789	 1	 -0.0	 -0.0	 0.0	 21.03	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	9790	 1	 -0.0	 0.0	 0.0	 0.82	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	9791	 1	 45.95	 16.7	 0.0	 0.34	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	9792	 1	 0.0	 0.0	 0.0	 0.35	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	9793	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	9794	 1	 219.6	 36.4	 0.0	 17.89	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9795	 1	 309.0	 74.5	 0.0	 3.69	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9796	 1	 0.0	 0.0	 0.0	 1.32	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	9797	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	9798	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	9799	 1	 54.93	 16.5	 0.0	 6.75	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9800	 1	 12.6	 1.8	 0.0	 1.98	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	9801	 1	 11.91	 1.8	 0.0	 0.37	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	9802	 1	 0.0	 -0.0	 0.0	 5.48	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	9803	 1	 115.6	 16.4	 0.0	 2.41	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	9804	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 6.3	 1	    1.10000	    0.90000;
	9805	 1	 -0.0	 -0.0	 0.212252	 0.661817	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	9806	 1	 89.2	 42.7	 0.0	 13.74	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	9807	 1	 0.1	 4.4	 0.0	 0.19	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	9808	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	9809	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	9810	 1	 119.5	 44.5	 0.0	 3.61	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	9811	 1	 46.08	 -47.15	 0.0	 11.39	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	9812	 1	 12.01	 3.9	 0.0	 0.94	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	9813	 1	 0.0	 -0.0	 0.0	 37.35	 0	    1.00000	    0.00000	 380.0	 18	    1.20000	    0.80000;
	9814	 1	 12.11	 5.4	 0.0	 0.63	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	9815	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	9816	 1	 7.61	 6.3	 0.0	 1.33	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	9817	 1	 72.48	 44.9	 0.0	 1.75	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	9818	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	9819	 1	 15.6	 2.2	 0.0	 2.31	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	9820	 1	 0.0	 -0.0	 0.019675	 28.750325	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	9821	 1	 0.0	 -0.0	 0.0	 0.38	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	9822	 1	 -20.82	 -8.8	 0.0	 9.24	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	9823	 1	 139.8	 -23.6	 0.0	 1.91	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	9824	 1	 61.07	 11.1	 0.0	 4.8	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	9825	 1	 -1.6	 -0.9	 0.0	 0.38	 0	    1.00000	    0.00000	 110.0	 3	    1.10000	    0.90000;
	9826	 1	 32.54	 11.7	 0.0	 1.17	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	9827	 1	 18.02	 5.9	 0.0	 0.3	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	9828	 1	 0.0	 0.0	 0.13	 10.79	 0	    1.00000	    0.00000	 220.0	 21	    1.10000	    0.90000;
	9829	 1	 24.03	 5.6	 0.0	 0.23	 0	    1.00000	    0.00000	 110.0	 3	    1.10000	    0.90000;
	9830	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 6.3	 1	    1.10000	    0.90000;
	9831	 1	 715.8	 24.1	 0.019472	 -0.019472	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	9832	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	9833	 1	 4.2	 0.6	 0.0	 3.9	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	9834	 1	 -0.0	 -0.0	 0.27075	 91.79435	 0	    1.00000	    0.00000	 380.0	 18	    1.20000	    0.80000;
	9835	 1	 0.0	 -0.0	 0.0	 2.18	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9836	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	9837	 1	 -6.71	 -2.4	 0.0	 0.48	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	9838	 1	 24.38	 5.91	 0.0	 0.41	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	9839	 1	 166.4	 50.4	 0.0	 1.23	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9840	 1	 0.0	 -0.0	 0.0	 0.4	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	9841	 1	 0.0	 -0.0	 0.536088	 13.763043	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	9842	 1	 -0.0	 0.0	 0.0	 9.74	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9843	 1	 -4.91	 -2.53	 0.0	 120.558401	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	9844	 1	 0.0	 -0.0	 0.0	 7.52	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	9845	 1	 -0.0	 0.0	 0.039558	 2.150442	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	9846	 1	 0.0	 0.0	 0.0	 38.84	 0	    1.00000	    0.00000	 380.0	 9	    1.20000	    0.80000;
	9847	 1	 78.99	 16.2	 0.0	 1.97	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9848	 1	 0.0	 -0.0	 0.0	 79.119351	 0	    1.00000	    0.00000	 380.0	 20	    1.20000	    0.80000;
	9849	 1	 244.12	 95.29	 0.0	 7.55	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9850	 1	 0.0	 -0.0	 0.0	 2.09	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	9851	 1	 -0.0	 -0.0	 0.0	 41.75	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	9852	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	9853	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	9854	 1	 27.9	 4.0	 0.0	 4.18	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	9855	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 6.3	 1	    1.10000	    0.90000;
	9856	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	9857	 1	 -0.0	 0.0	 0.0	 1.28	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	9858	 1	 5.91	 1.7	 0.0	 8.75	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	9859	 1	 267.1	 57.4	 0.0	 21.33	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	9860	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	9861	 1	 6.81	 2.5	 0.0	 1.0	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	9862	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	9863	 1	 0.0	 -0.0	 0.039649	 8.710351	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	9864	 1	 -0.0	 0.0	 0.0	 34.44	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	9865	 1	 18.42	 6.0	 0.0	 0.72	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	9866	 1	 -0.0	 0.0	 0.0	 13.79	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	9867	 1	 -0.0	 -0.0	 0.0	 6.57	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	9868	 1	 53.66	 19.5	 0.0	 1.26	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	9869	 1	 -0.0	 0.0	 0.0	 2.94	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	9870	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	9871	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	9872	 1	 34.35	 3.62	 0.0	 0.97	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	9873	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	9874	 1	 207.2	 28.6	 0.0	 13.85	 0	    1.00000	    0.00000	 220.0	 11	    1.10000	    0.90000;
	9875	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	9876	 1	 0.0	 -0.0	 0.009917	 0.92	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	9877	 1	 12.61	 7.8	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	9878	 1	 0.0	 0.0	 0.0	 342.15	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	9879	 1	 -0.0	 0.0	 0.0	 5.12	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	9880	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	9881	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	9882	 1	 8.3	 1.2	 0.0	 1.07	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	9883	 1	 27.53	 9.9	 0.0	 85.25	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	9884	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 9	    1.10000	    0.90000;
	9885	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	9886	 1	 99.0	 23.2	 0.0	 10.16	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	9887	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	9888	 1	 60.27	 21.3	 0.0	 1.87	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	9889	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 15.75	 1	    1.10000	    0.90000;
	9890	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	9891	 1	 -0.0	 0.0	 0.0	 0.34	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	9892	 1	 61.37	 23.2	 0.0	 0.22	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9893	 1	 -0.0	 -0.0	 0.0	 2.18	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9894	 1	 34.14	 21.1	 0.0	 0.04	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	9895	 1	 283.2	 101.8	 0.230421	 43.471474	 0	    1.00000	    0.00000	 380.0	 7	    1.10000	    0.90000;
	9896	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	9897	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	9898	 1	 -1377.93	 -320.0	 0.0	 36.89	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	9899	 1	 -0.0	 -0.0	 0.235946	 0.173378	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	9900	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	9901	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	9902	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	9903	 1	 74.68	 46.3	 0.0	 12.92	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	9904	 1	 -0.0	 -0.0	 0.018975	 3.031025	 0	    1.00000	    0.00000	 380.0	 19	    1.10000	    0.90000;
	9905	 1	 0.0	 -0.0	 0.0	 20.44	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	9906	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	9907	 1	 18.2	 2.6	 0.0	 12.22	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	9908	 1	 140.1	 25.5	 0.0	 10.78	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	9909	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	9910	 1	 11.91	 4.4	 0.0	 0.13	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	9911	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	9912	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	9913	 1	 -0.0	 -0.0	 0.0	 8.9	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9914	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	9915	 1	 -6.77	 -2.13	 0.0	 0.47	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	9916	 1	 0.0	 -0.0	 0.057943	 2.072057	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9917	 1	 50.96	 17.0	 0.0	 0.31	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	9918	 1	 0.0	 -0.0	 0.0	 4.09	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	9919	 1	 154.9	 25.0	 0.0	 72.89	 0	    1.00000	    0.00000	 380.0	 20	    1.20000	    0.80000;
	9920	 1	 46.35	 9.1	 0.0	 18.2	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9921	 1	 43.35	 16.2	 0.0	 0.77	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	9922	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	9923	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	9924	 1	 79.49	 17.0	 0.0	 29.21	 0	    1.00000	    0.00000	 220.0	 3	    1.20000	    0.80000;
	9925	 1	 -73.98	 -29.8	 0.0	 17.77	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	9926	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	9927	 1	 0.0	 0.0	 0.0	 1.56	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	9928	 1	 0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	9929	 1	 0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	9930	 1	 0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	9931	 1	 45.45	 28.1	 0.0	 0.16	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	9932	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	9933	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	9934	 1	 253.4	 81.7	 0.0	 16.85	 0	    1.00000	    0.00000	 220.0	 20	    1.10000	    0.90000;
	9935	 1	 4.81	 1.3	 0.0	 0.85	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	9936	 1	 4.2	 0.7	 0.0	 0.16	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	9937	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 10.5	 1	    1.10000	    0.90000;
	9938	 1	 -0.0	 -0.0	 0.0	 7.43	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9939	 1	 55.76	 19.9	 0.0	 1.14	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	9940	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	9941	 1	 8.91	 1.3	 0.0	 0.82	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	9942	 1	 135.84	 15.97	 0.0	 4.57	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9943	 1	 -0.0	 -0.0	 0.0	 0.05	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	9944	 1	 270.14	 57.56	 0.0	 4.32	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	9945	 1	 76.79	 30.7	 0.0	 17.7	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	9946	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	9947	 1	 20.02	 10.0	 0.0	 8.08	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	9948	 1	 0.5	 159.8	 0.113242	 99.355631	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	9949	 1	 47.35	 15.5	 0.0	 1.41	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	9950	 1	 55.7	 7.9	 0.0	 14.44	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	9951	 1	 0.0	 0.0	 0.0	 15.06	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	9952	 1	 -0.0	 -0.0	 0.0	 27.51	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	9953	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	9954	 1	 32.24	 10.1	 0.0	 0.81	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	9955	 1	 59.47	 21.4	 0.078398	 11.851602	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9956	 1	 106.0	 24.6	 0.0	 5.9	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	9957	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	9958	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	9959	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	9960	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 9	    1.20000	    0.80000;
	9961	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	9962	 1	 -0.0	 -0.0	 0.0	 0.3	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	9963	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	9964	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	9965	 1	 162.7	 23.2	 0.0	 4.81	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	9966	 1	 -0.0	 0.0	 0.198354	 -0.018766	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	9967	 1	 36.84	 14.4	 0.0	 5.09	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	9968	 1	 68.78	 28.2	 0.0	 0.26	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	9969	 1	 0.0	 -0.0	 0.0	 4.36	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9970	 1	 326.9	 -82.3	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	9971	 1	 55.46	 18.5	 0.0	 1.11	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	9972	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 15.0	 1	    1.10000	    0.90000;
	9973	 1	 46.2	 28.47	 0.0	 4.19	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	9974	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	9975	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	9976	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 20	    1.10000	    0.90000;
	9977	 1	 -0.0	 0.0	 0.0	 0.48	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	9978	 1	 0.0	 -0.0	 0.0	 8.12	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	9979	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 8	    1.10000	    0.90000;
	9980	 1	 -0.12	 -1.74	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 8	    1.20000	    0.80000;
	9981	 1	 -0.0	 0.0	 0.243713	 4.864064	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	9982	 1	 3.8	 2.8	 0.0	 0.77	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	9983	 1	 -0.15	 -1.93	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 8	    1.10000	    0.90000;
	9984	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	9985	 1	 13.94	 9.5	 0.0	 3.53	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	9986	 1	 184.89	 -21.1	 0.0	 39.26	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	9987	 1	 47.75	 11.0	 0.0	 0.05	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9988	 1	 0.0	 0.0	 0.346595	 -0.269574	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	9989	 1	 78.74	 17.8	 0.0	 0.58	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	9990	 1	 0.0	 -0.0	 0.0	 2.64	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	9991	 1	 122.8	 20.8	 0.0	 0.47	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	9992	 1	 98.0	 21.7	 0.0	 6.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9993	 1	 252.9	 95.6	 0.0	 1.22	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	9994	 1	 29.03	 11.7	 0.059952	 1.440048	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	9995	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	9996	 1	 -0.0	 0.0	 0.0	 1.04	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9997	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	9998	 1	 -0.0	 -0.0	 0.059401	 1.100599	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	9999	 1	 0.0	 -0.0	 0.0	 2.08	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	10000	 1	 0.3	 0.5	 0.911638	 17.535694	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	10001	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	10002	 1	 50.46	 36.0	 0.0	 0.57	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	10003	 1	 0.0	 -0.0	 0.0	 0.25	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	10004	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	10005	 1	 -0.0	 0.0	 0.11	 2.05	 0	    1.00000	    0.00000	 220.0	 21	    1.10000	    0.90000;
	10006	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	10007	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	10008	 1	 372.4	 121.1	 0.020615	 7.899385	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	10009	 1	 71.08	 44.0	 0.0	 3.28	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	10010	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	10011	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	10012	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	10013	 1	 -16.82	 5.5	 0.0	 0.63	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	10014	 1	 16.52	 5.5	 0.0	 3.5	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	10015	 1	 86.2	 -30.7	 0.0	 8.84	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	10016	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	10017	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	10018	 1	 -0.0	 0.0	 0.0	 74.37	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	10019	 1	 1.9	 9.2	 0.0	 7.57	 0	    1.00000	    0.00000	 220.0	 20	    1.10000	    0.90000;
	10020	 1	 118.4	 18.6	 0.038961	 10.701039	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	10021	 1	 -0.0	 -0.0	 0.0	 7.58	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	10022	 1	 -0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	10023	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	10024	 1	 43.15	 22.8	 0.039222	 0.010778	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	10025	 1	 -0.0	 0.0	 0.0	 11.39	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	10026	 1	 0.0	 -0.0	 0.039254	 45.960746	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	10027	 1	 -0.0	 -0.0	 0.0	 3.37	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	10028	 1	 6.41	 2.1	 0.0	 0.51	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	10029	 1	 1.2	 0.4	 0.0	 0.6	 0	    1.00000	    0.00000	 110.0	 19	    1.20000	    0.80000;
	10030	 1	 -0.0	 -0.0	 0.0	 17.8	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	10031	 1	 37.87	 11.59	 0.0	 1.88	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	10032	 1	 54.9	 -96.8	 0.0	 16.42	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	10033	 1	 -0.0	 -0.0	 0.0	 3.67	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	10034	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	10035	 1	 0.0	 -0.0	 0.0	 0.86	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	10036	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	10037	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	10038	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	10039	 1	 18.92	 6.6	 0.0	 1.4	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	10040	 1	 -0.0	 0.0	 0.241227	 -0.201023	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	10041	 1	 -0.0	 0.0	 0.0	 7.49	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	10042	 1	 -0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	10043	 1	 1.8	 0.6	 0.0	 0.75	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	10044	 1	 -0.0	 0.0	 0.048779	 59.541221	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	10045	 1	 161.28	 54.0	 0.0	 2.12	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	10046	 1	 25.23	 8.3	 0.0	 0.61	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	10047	 1	 63.87	 55.1	 0.0	 14.84	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	10048	 1	 -0.0	 0.0	 0.0	 1.36	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	10049	 1	 11.41	 5.1	 0.0	 1.0	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	10050	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	10051	 1	 67.47	 6.1	 0.0	 1.46	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	10052	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 6.3	 1	    1.10000	    0.90000;
	10053	 1	 -0.12	 -1.31	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 8	    1.20000	    0.80000;
	10054	 1	 25.73	 15.9	 0.0	 0.74	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	10055	 1	 119.3	 -2.8	 0.0	 0.87	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	10056	 1	 0.0	 0.0	 0.0	 3.13	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	10057	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	10058	 1	 109.0	 20.4	 0.195847	 7.494153	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	10059	 1	 -12.49	 -5.83	 0.0	 6.173378	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	10060	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	10061	 1	 0.0	 -0.0	 0.0	 5.59	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	10062	 1	 135.61	 26.86	 0.0	 1.93	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	10063	 1	 -53.06	 -100.0	 0.0	 0.06	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	10064	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	10065	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	10066	 1	 83.6	 11.9	 0.0	 1.69	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	10067	 1	 0.0	 0.0	 0.0	 50.14	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	10068	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	10069	 1	 182.5	 47.0	 0.0	 33.69	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	10070	 1	 8.31	 2.7	 0.0	 0.72	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	10071	 1	 176.8	 39.4	 0.0	 28.24	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	10072	 1	 31.03	 10.0	 0.0	 0.13	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	10073	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	10074	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	10075	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	10076	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	10077	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	10078	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	10079	 1	 8.01	 2.6	 0.0	 1.11	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	10080	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	10081	 1	 -37.84	 -19.23	 0.0	 28.136589	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	10082	 1	 0.3	 -9.0	 0.0	 1.96	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	10083	 1	 20.0	 2.9	 0.0	 2.33	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	10084	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	10085	 1	 0.0	 0.0	 0.0	 6.97	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	10086	 1	 0.0	 -0.0	 0.0	 4.4	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	10087	 1	 115.2	 55.1	 0.0	 30.49	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	10088	 1	 -9.86	 -2.8	 0.0	 0.2	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	10089	 1	 0.0	 0.0	 0.0	 0.93	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	10090	 1	 122.5	 8.7	 0.0	 15.85	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	10091	 1	 -0.0	 -0.0	 0.200856	 -0.150642	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	10092	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 20	    1.10000	    0.90000;
	10093	 1	 25.23	 47.6	 0.0	 4.21	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	10094	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 15.75	 1	    1.10000	    0.90000;
	10095	 1	 18.72	 7.7	 0.0	 1.09	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	10096	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	10097	 1	 -0.0	 -0.0	 0.0	 0.88	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	10098	 1	 18.41	 41.8	 0.0	 0.17	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	10099	 1	 -0.0	 -0.0	 0.110962	 39.477531	 0	    1.00000	    0.00000	 380.0	 3	    1.20000	    0.80000;
	10100	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 7	    1.10000	    0.90000;
	10101	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 24	    1.10000	    0.90000;
	10102	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	10103	 1	 11.71	 3.7	 0.0	 0.8	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	10104	 1	 0.0	 0.0	 0.0	 0.66	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	10105	 1	 -0.0	 0.0	 0.0	 96.89	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	10106	 1	 6.71	 1.0	 0.0	 0.39	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	10107	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	10108	 1	 21.62	 9.8	 0.0	 0.14	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	10109	 1	 52.9	 7.6	 0.0	 2.3	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	10110	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	10111	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.20000	    0.80000;
	10112	 1	 113.6	 44.7	 0.0	 1.91	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	10113	 1	 33.34	 8.6	 0.0	 3.93	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	10114	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 6.3	 1	    1.10000	    0.90000;
	10115	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	10116	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	10117	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	10118	 1	 -0.0	 0.0	 0.079002	 1.100749	 0	    1.00000	    0.00000	 220.0	 22	    1.10000	    0.90000;
	10119	 1	 -10.36	 -4.66	 0.0	 0.58	 0	    1.00000	    0.00000	 110.0	 3	    1.10000	    0.90000;
	10120	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	10121	 1	 47.3	 6.7	 0.0	 4.05	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	10122	 1	 -0.0	 0.0	 0.0	 1.16	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	10123	 1	 -92.2	 -244.4	 0.0	 7.23	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	10124	 1	 0.0	 0.0	 0.117756	 10.14187	 0	    1.00000	    0.00000	 380.0	 16	    1.10000	    0.90000;
	10125	 1	 20.9	 3.0	 0.0	 7.14	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	10126	 1	 117.0	 20.4	 0.0	 22.34	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	10127	 1	 136.1	 18.8	 0.0	 6.55	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	10128	 1	 76.38	 6.8	 0.039079	 2.110691	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	10129	 1	 0.0	 -0.0	 0.0	 2.15	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	10130	 1	 160.4	 63.9	 0.533365	 14.325161	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	10131	 1	 67.28	 -15.37	 0.23431	 15.624504	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	10132	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	10133	 1	 0.0	 0.0	 0.0	 0.71	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	10134	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	10135	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	10136	 1	 3.2	 1.1	 0.0	 0.56	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	10137	 1	 30.83	 16.5	 0.0	 3.83	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	10138	 1	 -0.0	 0.0	 0.0	 10.46	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	10139	 1	 43.7	 6.2	 0.0	 1.73	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	10140	 1	 350.0	 129.4	 0.0	 33.52	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	10141	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	10142	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	10143	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	10144	 1	 0.0	 -0.0	 0.0	 1.13	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	10145	 1	 0.0	 -0.0	 0.0	 1.6	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	10146	 1	 56.66	 15.6	 0.0	 7.45	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	10147	 1	 0.2	 1.8	 0.0	 0.43	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	10148	 1	 0.0	 -0.0	 0.0	 12.42	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	10149	 1	 -0.0	 -0.0	 0.237121	 0.012399	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	10150	 1	 35.44	 5.3	 0.0	 2.24	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	10151	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	10152	 1	 0.0	 0.0	 0.0	 0.49	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	10153	 1	 22.8	 3.2	 0.0	 9.98	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	10154	 1	 18.72	 7.9	 0.0	 1.67	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	10155	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	10156	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 15.0	 1	    1.10000	    0.90000;
	10157	 1	 61.77	 10.2	 0.0	 4.01	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	10158	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	10159	 1	 18.12	 10.0	 0.0	 1.03	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	10160	 1	 -0.0	 -0.0	 0.0	 116.64	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	10161	 1	 334.1	 103.5	 0.0	 14.78	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	10162	 1	 86.49	 29.0	 0.0	 1.48	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	10163	 1	 27.86	 14.21	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.20000	    0.80000;
	10164	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	10165	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	10166	 1	 5.04	 6.1	 0.0	 8.68	 0	    1.00000	    0.00000	 150.0	 9	    1.20000	    0.80000;
	10167	 1	 20.02	 9.0	 0.0	 0.15	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	10168	 1	 0.0	 0.0	 0.0	 4.07	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	10169	 1	 389.8	 -68.1	 0.0	 5.03	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	10170	 1	 56.56	 18.4	 0.0	 3.29	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	10171	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	10172	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	10173	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	10174	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	10175	 1	 -0.0	 0.0	 0.0	 0.69	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	10176	 1	 137.7	 32.6	 0.0	 5.17	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	10177	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 14.4	 1	    1.10000	    0.90000;
	10178	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	10179	 1	 94.4	 13.5	 0.0	 5.37	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	10180	 1	 -0.0	 0.0	 0.232388	 3.566026	 0	    1.00000	    0.00000	 220.0	 23	    1.10000	    0.90000;
	10181	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	10182	 1	 -0.0	 0.0	 0.03892	 0.39108	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	10183	 1	 0.0	 -0.0	 0.0	 27.8	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	10184	 1	 -0.0	 -0.0	 0.0	 7.51	 0	    1.00000	    0.00000	 220.0	 19	    1.10000	    0.90000;
	10185	 1	 -0.0	 0.0	 0.0	 0.32	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	10186	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	10187	 1	 83.36	 2.6	 0.0	 1.06	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	10188	 1	 92.1	 43.8	 0.0	 3.69	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	10189	 1	 -0.0	 0.0	 0.0	 0.75	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	10190	 1	 0.6	 0.1	 0.0	 0.38	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	10191	 1	 36.04	 22.3	 0.0	 4.15	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	10192	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	10193	 1	 16.22	 8.9	 0.0	 2.2	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	10194	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	10195	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	10196	 1	 53.06	 75.8	 0.0	 51.93	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	10197	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	10198	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	10199	 1	 19.4	 2.8	 0.0	 9.78	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	10200	 1	 0.0	 0.0	 0.0	 0.34	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	10201	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	10202	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	10203	 1	 195.5	 67.9	 0.0	 6.17	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	10204	 1	 89.1	 20.2	 0.05992	 24.59008	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	10205	 1	 0.0	 -0.0	 0.0	 53.97	 0	    1.00000	    0.00000	 380.0	 8	    1.20000	    0.80000;
	10206	 1	 -0.0	 -0.0	 0.0	 0.51	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	10207	 1	 125.2	 1.2	 0.0	 15.12	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	10208	 1	 -0.0	 0.0	 0.0	 0.39	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	10209	 1	 112.1	 36.3	 0.0	 6.4	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	10210	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	10211	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 15.75	 1	    1.10000	    0.90000;
	10212	 1	 0.0	 0.0	 0.0	 0.12	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	10213	 1	 13.31	 4.4	 0.0	 0.33	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	10214	 1	 0.0	 -0.0	 0.0	 4.54	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	10215	 1	 36.24	 12.8	 0.0	 2.99	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	10216	 1	 89.7	 17.5	 0.0	 4.06	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	10217	 1	 63.97	 12.8	 0.0	 0.17	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	10218	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	10219	 1	 5.41	 67.5	 0.113378	 75.955519	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	10220	 1	 -0.0	 0.0	 0.0	 11.7	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	10221	 1	 -0.0	 -0.0	 0.0	 3.42	 0	    1.00000	    0.00000	 220.0	 14	    1.10000	    0.90000;
	10222	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	10223	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	10224	 1	 -0.0	 0.0	 0.0	 46.83	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	10225	 1	 190.3	 84.7	 0.0	 7.15	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	10226	 1	 30.04	 8.6	 0.0	 21.45	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	10227	 1	 91.9	 41.9	 1.426313	 164.822572	 0	    1.00000	    0.00000	 380.0	 19	    1.10000	    0.90000;
	10228	 1	 2.3	 0.8	 0.0	 0.06	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	10229	 1	 0.0	 -0.0	 0.0	 0.61	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	10230	 1	 51.16	 12.0	 0.0	 6.02	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	10231	 1	 2.9	 -0.0	 0.0	 0.62	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	10232	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	10233	 1	 23.43	 7.5	 0.0	 0.1	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	10234	 1	 10.01	 2.0	 0.0	 0.61	 0	    1.00000	    0.00000	 150.0	 7	    1.10000	    0.90000;
	10235	 1	 -0.0	 -0.0	 0.0	 5.97	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	10236	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	10237	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	10238	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	10239	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	10240	 1	 0.0	 0.0	 0.386669	 50.203331	 0	    1.00000	    0.00000	 220.0	 22	    1.10000	    0.90000;
	10241	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	10242	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	10243	 1	 4.2	 0.6	 0.0	 7.92	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	10244	 1	 73.7	 10.5	 0.0	 4.55	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	10245	 1	 84.59	 21.7	 0.0	 7.42	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	10246	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	10247	 1	 22.42	 2.1	 0.0	 0.19	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	10248	 1	 18.5	 3.8	 0.0	 0.38	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	10249	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 7	    1.10000	    0.90000;
	10250	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 8	    1.10000	    0.90000;
	10251	 1	 -0.0	 -0.0	 0.0	 0.3	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	10252	 1	 0.0	 0.0	 0.0	 3.06	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	10253	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	10254	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	10255	 1	 8.31	 2.7	 0.0	 0.69	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	10256	 1	 -0.0	 0.0	 0.149251	 110.015393	 0	    1.00000	    0.00000	 380.0	 18	    1.10000	    0.90000;
	10257	 1	 0.0	 0.0	 0.0	 494.41	 0	    1.00000	    0.00000	 750.0	 1	    1.20000	    0.80000;
	10258	 1	 52.56	 12.8	 0.0	 2.87	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	10259	 1	 126.3	 17.9	 0.0	 4.1	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	10260	 1	 226.8	 53.3	 0.0	 3.26	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	10261	 1	 14.92	 5.4	 0.0	 0.62	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	10262	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	10263	 1	 -0.0	 0.0	 0.0	 1.76	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	10264	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	10265	 1	 235.8	 23.3	 0.020076	 8.959924	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	10266	 1	 0.0	 0.0	 0.0	 51.27	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	10267	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	10268	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	10269	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	10270	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	10271	 1	 -0.0	 -0.0	 0.297126	 6.812395	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	10272	 1	 1.7	 145.9	 0.703396	 57.442914	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	10273	 1	 24.63	 2.1	 0.0	 1.26	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	10274	 1	 19.4	 2.8	 0.0	 2.51	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	10275	 1	 -0.0	 0.0	 0.0	 42.94	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	10276	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 10.6	 1	    1.10000	    0.90000;
	10277	 1	 0.0	 -0.0	 0.0	 3.15	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	10278	 1	 16.72	 6.4	 0.205819	 3.97706	 0	    1.00000	    0.00000	 110.0	 15	    1.20000	    0.80000;
	10279	 1	 0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	10280	 1	 0.0	 -0.0	 0.379382	 23.898001	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	10281	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	10282	 1	 0.0	 -0.0	 0.038829	 0.291171	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	10283	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	10284	 1	 -0.0	 -0.0	 0.0	 2.77	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	10285	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	10286	 1	 19.52	 6.4	 0.0	 0.33	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	10287	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	10288	 1	 324.9	 37.3	 0.0	 10.15	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	10289	 1	 21.82	 6.3	 0.0	 1.14	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	10290	 1	 13.0	 8.8	 0.0	 78.85984	 0	    1.00000	    0.00000	 380.0	 9	    1.20000	    0.80000;
	10291	 1	 -175.8	 -19.6	 0.0	 14.58	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	10292	 1	 220.98	 91.0	 0.0	 1.16	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	10293	 1	 6.91	 1.9	 0.0	 1.05	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	10294	 1	 0.0	 0.0	 0.042333	 99.938012	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	10295	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.5	 1	    1.10000	    0.90000;
	10296	 1	 1.9	 -0.0	 0.0	 1.32	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	10297	 1	 -0.0	 -0.0	 0.0	 0.41	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	10298	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 6.6	 1	    1.10000	    0.90000;
	10299	 1	 17.22	 5.1	 0.0	 0.99	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	10300	 1	 12.91	 5.1	 0.0	 0.16	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	10301	 1	 -0.0	 -0.0	 0.058249	 2.901751	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	10302	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	10303	 1	 120.0	 26.0	 0.0	 22.01	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	10304	 1	 0.0	 0.0	 0.0	 21.19	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	10305	 1	 18.12	 5.9	 0.0	 1.52	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	10306	 1	 32.14	 13.1	 0.0	 1.72	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	10307	 1	 129.7	 27.1	 0.0	 0.36	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	10308	 1	 125.2	 8.5	 0.0	 0.25	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	10309	 1	 41.95	 14.8	 0.361242	 114.216909	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	10310	 1	 20.82	 0.0	 0.0	 0.17	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	10311	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	10312	 1	 -0.0	 -0.0	 0.038703	 2.301297	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	10313	 1	 0.0	 -0.0	 0.0	 27.42	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	10314	 1	 0.0	 0.0	 0.0	 0.09	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	10315	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	10316	 1	 0.0	 0.0	 0.0	 4.93	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	10317	 1	 0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	10318	 1	 -0.0	 -0.0	 0.0	 0.47	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	10319	 1	 -20.12	 6.6	 0.0	 3.24	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	10320	 1	 -0.0	 0.0	 0.276841	 2.12089	 0	    1.00000	    0.00000	 380.0	 16	    1.10000	    0.90000;
	10321	 1	 -0.0	 0.0	 0.0	 1.02	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	10322	 1	 128.1	 42.8	 0.0	 25.57	 0	    1.00000	    0.00000	 380.0	 17	    1.10000	    0.90000;
	10323	 1	 -0.0	 0.0	 0.176283	 0.063098	 0	    1.00000	    0.00000	 220.0	 20	    1.10000	    0.90000;
	10324	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	10325	 1	 41.25	 48.4	 0.0	 16.52	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	10326	 1	 6.31	 5.1	 0.0	 0.08	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	10327	 1	 32.74	 5.3	 0.0	 3.07	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	10328	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	10329	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	10330	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	10331	 1	 142.9	 25.8	 0.0	 24.18	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	10332	 1	 708.5	 228.6	 0.175428	 67.413556	 0	    1.00000	    0.00000	 380.0	 14	    1.10000	    0.90000;
	10333	 1	 80.19	 23.6	 0.0	 19.21	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	10334	 1	 62.67	 14.6	 0.0	 0.73	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	10335	 1	 -0.0	 0.0	 0.05667	 52.542775	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	10336	 1	 -0.0	 0.0	 0.0	 15.47	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	10337	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	10338	 1	 25.33	 70.8	 0.233534	 37.945119	 0	    1.00000	    0.00000	 380.0	 13	    1.10000	    0.90000;
	10339	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	10340	 1	 62.17	 16.9	 0.030139	 25.439861	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	10341	 1	 0.0	 -0.0	 0.0	 0.36	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	10342	 1	 18.82	 6.8	 0.0	 2.15	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	10343	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	10344	 1	 -13.82	 4.6	 0.0	 0.45	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	10345	 1	 0.0	 0.0	 0.0	 2.2	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	10346	 1	 7.61	 2.5	 0.0	 0.39	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	10347	 1	 0.0	 0.0	 0.0	 63.75	 0	    1.00000	    0.00000	 380.0	 22	    1.10000	    0.90000;
	10348	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	10349	 1	 152.2	 53.2	 0.0	 33.26	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	10350	 1	 76.6	 10.9	 0.0	 2.3	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	10351	 1	 -0.0	 -0.0	 0.0	 27.92	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	10352	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 7	    1.10000	    0.90000;
	10353	 1	 236.6	 33.7	 0.0	 0.14	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	10354	 1	 -0.0	 0.0	 0.172197	 2.206503	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	10355	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	10356	 1	 10.81	 3.6	 0.0	 0.08	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	10357	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	10358	 1	 88.4	 51.1	 0.164758	 133.03229	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	10359	 1	 0.0	 0.0	 0.0	 30.43	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	10360	 1	 220.6	 70.7	 0.038442	 120.281558	 0	    1.00000	    0.00000	 380.0	 13	    1.10000	    0.90000;
	10361	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	10362	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	10363	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	10364	 1	 0.0	 -0.0	 0.0	 0.66	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	10365	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	10366	 1	 296.1	 82.3	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	10367	 1	 -0.0	 0.0	 0.116788	 4.382677	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	10368	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	10369	 1	 22.3	 3.1	 0.0	 4.33	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	10370	 1	 -0.0	 -0.0	 0.0	 0.29	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	10371	 1	 -0.0	 -0.0	 0.0	 57.66	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	10372	 1	 109.5	 33.6	 0.0	 5.75	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	10373	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 23	    1.10000	    0.90000;
	10374	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	10375	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	10376	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 8.5	 1	    1.10000	    0.90000;
	10377	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	10378	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	10379	 1	 102.0	 26.6	 0.0	 2.27	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	10380	 1	 35.94	 22.3	 0.0	 1.63	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	10381	 1	 4.61	 1.7	 0.0	 0.34	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	10382	 1	 0.0	 -0.0	 0.203413	 0.430864	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	10383	 1	 0.0	 0.0	 0.0	 16.39	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	10384	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	10385	 1	 20.02	 8.5	 0.0	 1.68	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	10386	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	10387	 1	 -0.0	 -0.0	 0.0	 7.46	 0	    1.00000	    0.00000	 380.0	 12	    1.20000	    0.80000;
	10388	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	10389	 1	 0.0	 -0.0	 0.0	 0.11	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	10390	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	10391	 1	 316.0	 102.9	 0.24333	 12.017364	 0	    1.00000	    0.00000	 220.0	 14	    1.10000	    0.90000;
	10392	 1	 282.5	 56.2	 0.0	 8.6	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	10393	 1	 0.0	 -0.0	 0.0	 1.13	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	10394	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	10395	 1	 -0.0	 -0.0	 0.0	 1.49	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	10396	 1	 0.1	 -0.0	 0.0	 0.39	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	10397	 1	 -0.0	 -0.0	 0.0	 0.16	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	10398	 1	 301.6	 87.4	 0.05701	 67.292991	 0	    1.00000	    0.00000	 380.0	 14	    1.10000	    0.90000;
	10399	 1	 142.8	 20.3	 0.0	 6.77	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	10400	 1	 117.5	 91.0	 0.375992	 45.737717	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	10401	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	10402	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	10403	 1	 31.94	 10.0	 0.0	 0.18	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	10404	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	10405	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	10406	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	10407	 1	 7.51	 3.1	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	10408	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 9	    1.10000	    0.90000;
	10409	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 15.0	 1	    1.10000	    0.90000;
	10410	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	10411	 1	 149.53	 34.9	 0.0	 8.9	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	10412	 1	 3.8	 0.6	 0.0	 0.73	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	10413	 1	 0.0	 -0.0	 0.0	 6.17	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	10414	 1	 29.43	 10.7	 0.0	 0.99	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	10415	 1	 0.0	 -0.0	 0.0	 13.03	 0	    1.00000	    0.00000	 380.0	 9	    1.20000	    0.80000;
	10416	 1	 -38.01	 -22.73	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	10417	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	10418	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	10419	 1	 -0.0	 0.0	 0.0	 0.28	 0	    1.00000	    0.00000	 110.0	 3	    1.10000	    0.90000;
	10420	 1	 0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	10421	 1	 5.71	 3.0	 0.0	 0.18	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	10422	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	10423	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	10424	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	10425	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	10426	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	10427	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	10428	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	10429	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	10430	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	10431	 1	 33.34	 5.0	 0.0	 0.38	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	10432	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	10433	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	10434	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	10435	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	10436	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	10437	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	10438	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	10439	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	10440	 1	 0.9	 0.3	 0.0	 2.19	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	10441	 1	 -0.0	 0.0	 0.0	 1.04	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	10442	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	10443	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	10444	 1	 102.3	 19.0	 0.0	 1.84	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	10445	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	10446	 1	 -0.0	 0.0	 0.365093	 66.535145	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	10447	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	10448	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	10449	 1	 29.23	 9.4	 0.0	 0.68	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	10450	 1	 244.0	 97.8	 0.721852	 64.518559	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	10451	 1	 150.2	 51.6	 0.0	 2.79	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	10452	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.5	 1	    1.10000	    0.90000;
	10453	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	10454	 1	 -0.0	 0.0	 0.094706	 0.435294	 0	    1.00000	    0.00000	 220.0	 21	    1.10000	    0.90000;
	10455	 1	 99.4	 22.2	 0.0	 2.16	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	10456	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	10457	 1	 51.0	 7.3	 0.0	 6.06	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	10458	 1	 64.2	 26.4	 0.0	 1.05	 0	    1.00000	    0.00000	 110.0	 23	    1.10000	    0.90000;
	10459	 1	 32.34	 16.8	 0.0	 1.42	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	10460	 1	 -0.0	 -0.0	 0.0	 0.39	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	10461	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	10462	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	10463	 1	 8.48	 -1.82	 0.0	 0.37	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	10464	 1	 46.75	 24.4	 0.0	 3.66	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	10465	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 1	    1.20000	    0.80000;
	10466	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	10467	 1	 293.0	 -45.9	 0.0	 33.199841	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	10468	 1	 -0.0	 0.0	 0.0	 10.89	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	10469	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	10470	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	10471	 1	 6.01	 2.0	 0.0	 0.17	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	10472	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	10473	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 15.0	 1	    1.10000	    0.90000;
	10474	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	10475	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	10476	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	10477	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	10478	 1	 89.8	 19.7	 0.0	 0.36	 0	    1.00000	    0.00000	 120.0	 20	    1.20000	    0.80000;
	10479	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	10480	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	10481	 1	 73.58	 26.8	 0.0	 3.76	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	10482	 1	 -8.01	 -3.24	 0.0	 0.32	 0	    1.00000	    0.00000	 110.0	 23	    1.10000	    0.90000;
	10483	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	10484	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	10485	 1	 117.5	 36.4	 0.119432	 3.760284	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	10486	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	10487	 1	 0.0	 -0.0	 0.0	 10.34	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	10488	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	10489	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	10490	 1	 0.0	 -0.0	 0.0	 40.44	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	10491	 1	 -0.0	 -0.0	 0.57356	 0.223096	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	10492	 1	 0.0	 0.0	 0.0	 25.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	10493	 1	 122.8	 20.4	 0.0	 0.77	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	10494	 1	 -0.0	 0.0	 0.0	 2.48	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	10495	 1	 0.0	 0.0	 0.0	 1.74	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	10496	 1	 -0.0	 0.0	 0.0	 5.58	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	10497	 1	 -0.0	 0.0	 0.0	 9.26	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	10498	 1	 34.74	 9.1	 0.059151	 0.790849	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	10499	 1	 64.47	 40.0	 0.0	 5.82	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	10500	 1	 35.84	 11.8	 0.0	 0.94	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	10501	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 10.6	 1	    1.10000	    0.90000;
	10502	 1	 -0.0	 -0.0	 0.037175	 146.582825	 0	    1.00000	    0.00000	 380.0	 3	    1.20000	    0.80000;
	10503	 1	 -1083.9	 -433.7	 0.0	 2.72	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	10504	 1	 0.1	 -9.6	 0.0	 1.28	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	10505	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	10506	 1	 0.0	 0.0	 0.0	 129.47	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	10507	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	10508	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	10509	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	10510	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	10511	 1	 51.7	 7.4	 0.0	 2.07	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	10512	 1	 -0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	10513	 1	 77.91	 5.03	 0.0	 19.71	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	10514	 1	 -0.0	 0.0	 0.0	 10.22	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	10515	 1	 27.43	 15.7	 0.229924	 -0.132023	 0	    1.00000	    0.00000	 220.0	 21	    1.10000	    0.90000;
	10516	 1	 -0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	10517	 1	 10.21	 3.3	 0.0	 0.62	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	10518	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	10519	 1	 44.05	 16.0	 0.0	 1.63	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	10520	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	10521	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	10522	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	10523	 1	 0.0	 0.0	 0.240143	 4.170791	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	10524	 1	 1.0	 0.2	 0.0	 0.52	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	10525	 1	 290.8	 30.5	 0.0	 29.529841	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	10526	 1	 -0.0	 0.0	 1.064216	 6.752235	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	10527	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	10528	 1	 16.7	 2.4	 0.0	 3.56	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	10529	 1	 -18.52	 6.1	 0.0	 1.01	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	10530	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	10531	 1	 4.75	 -0.16	 0.0	 0.61	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	10532	 1	 10.81	 3.9	 0.0	 1.39	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	10533	 1	 7.21	 2.4	 0.0	 1.67	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	10534	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	10535	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 9	    1.20000	    0.80000;
	10536	 1	 0.0	 0.0	 0.234325	 6.034729	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	10537	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	10538	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	10539	 1	 0.0	 0.0	 0.0	 1.77	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	10540	 1	 0.0	 -0.0	 0.0	 0.11	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	10541	 1	 11.2	 1.6	 0.0	 3.74	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	10542	 1	 -0.0	 0.0	 0.0	 4.6	 0	    1.00000	    0.00000	 220.0	 15	    1.10000	    0.90000;
	10543	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	10544	 1	 0.0	 0.0	 0.0	 7.17	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	10545	 1	 456.6	 227.7	 0.0	 0.61	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	10546	 1	 99.9	 19.9	 0.0	 6.19	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	10547	 1	 72.68	 1.1	 0.0	 6.06	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	10548	 1	 0.0	 0.0	 0.08	 4.38	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	10549	 1	 -0.0	 0.0	 0.0	 1.8	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	10550	 1	 32.1	 4.5	 0.0	 2.82	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	10551	 1	 6.31	 1.3	 0.0	 0.52	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	10552	 1	 21.92	 14.1	 0.100168	 0.259832	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	10553	 1	 -0.0	 -0.0	 0.0	 31.34	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	10554	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 15.75	 1	    1.10000	    0.90000;
	10555	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	10556	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	10557	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 6.3	 1	    1.10000	    0.90000;
	10558	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	10559	 1	 -241.32	 -48.72	 0.0	 16.62	 0	    1.00000	    0.00000	 220.0	 23	    1.10000	    0.90000;
	10560	 1	 48.05	 23.0	 0.0	 0.78	 0	    1.00000	    0.00000	 110.0	 23	    1.10000	    0.90000;
	10561	 1	 8.3	 1.2	 0.0	 3.78	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	10562	 1	 25.23	 10.3	 0.0	 2.69	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	10563	 1	 86.7	 34.6	 0.0	 2.73	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	10564	 1	 -0.0	 0.0	 0.0	 2.21	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	10565	 1	 134.05	 13.3	 0.0	 25.19	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	10566	 1	 6.61	 1.6	 0.0	 2.13	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	10567	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	10568	 1	 20.9	 3.0	 0.0	 0.17	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	10569	 1	 0.0	 -0.0	 0.226098	 0.861006	 0	    1.00000	    0.00000	 380.0	 14	    1.10000	    0.90000;
	10570	 1	 19.22	 3.8	 0.0	 0.31	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	10571	 1	 -0.0	 -0.0	 0.0	 0.68	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	10572	 1	 0.0	 -0.0	 0.0	 3.98	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	10573	 1	 0.0	 -0.0	 0.0	 6.22	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	10574	 1	 89.7	 40.5	 0.0	 38.13	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	10575	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 20	    1.10000	    0.90000;
	10576	 1	 -0.0	 0.2	 0.0	 2.19	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	10577	 1	 17.72	 6.3	 0.0	 0.33	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	10578	 1	 0.3	 16.8	 0.272933	 10.6453	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	10579	 1	 -0.0	 -0.0	 0.0	 5.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	10580	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 6.3	 1	    1.10000	    0.90000;
	10581	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 7	    1.10000	    0.90000;
	10582	 1	 0.0	 0.0	 0.0	 1.4	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	10583	 1	 -0.0	 -0.0	 0.0	 0.37	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	10584	 1	 -0.0	 -0.0	 0.181549	 13.990889	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	10585	 1	 144.0	 31.3	 0.0	 3.18	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	10586	 1	 -0.0	 -0.0	 0.0	 17.37	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	10587	 1	 3.1	 6.8	 0.410979	 101.610403	 0	    1.00000	    0.00000	 380.0	 9	    1.20000	    0.80000;
	10588	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	10589	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 24	    1.10000	    0.90000;
	10590	 1	 -0.0	 0.0	 0.0	 0.62	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	10591	 1	 -0.0	 0.0	 0.0	 3.86	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	10592	 1	 -0.18	 -1.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	10593	 1	 0.0	 -0.0	 0.099501	 119.783595	 0	    1.00000	    0.00000	 380.0	 18	    1.20000	    0.80000;
	10594	 1	 -0.0	 -0.0	 0.0	 0.05	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	10595	 1	 7.61	 2.5	 0.0	 0.93	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	10596	 1	 0.0	 0.0	 0.0	 21.62	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	10597	 1	 388.7	 97.7	 0.0	 41.94	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	10598	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	10599	 1	 -0.0	 -0.0	 0.0	 1.99	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	10600	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	10601	 1	 106.0	 15.1	 0.0	 0.16	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	10602	 1	 34.14	 11.5	 0.0	 0.26	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	10603	 1	 0.0	 0.0	 0.0	 2.77	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	10604	 1	 11.21	 3.7	 0.0	 0.92	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	10605	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 7	    1.10000	    0.90000;
	10606	 1	 27.93	 17.3	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	10607	 1	 3.4	 1.2	 0.0	 0.19	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	10608	 1	 0.0	 0.0	 0.0	 0.76	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	10609	 1	 16.7	 2.4	 0.0	 1.21	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	10610	 1	 -0.0	 -0.0	 0.0	 1.33	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	10611	 1	 7.61	 2.5	 0.0	 0.25	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	10612	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	10613	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 0.4	 1	    1.10000	    0.90000;
	10614	 1	 7.41	 2.7	 0.0	 0.61	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	10615	 1	 0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	10616	 1	 0.0	 0.0	 0.0	 2.37	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	10617	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 24	    1.10000	    0.90000;
	10618	 1	 233.2	 39.4	 0.0	 104.569841	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	10619	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	10620	 1	 37.94	 9.8	 0.0	 2.26	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	10621	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	10622	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	10623	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	10624	 1	 220.8	 68.6	 0.0	 1.97	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	10625	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	10626	 1	 0.0	 -0.0	 0.0	 4.05	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	10627	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	10628	 1	 101.6	 4.5	 0.0	 3.59	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	10629	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	10630	 1	 392.25	 92.02	 0.0	 9.45	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	10631	 1	 -8.15	 -5.23	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	10632	 1	 117.73	 51.5	 0.537393	 7.902028	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	10633	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	10634	 1	 3.8	 2.5	 0.0	 0.74	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	10635	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	10636	 1	 82.39	 -0.0	 0.0	 0.15	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	10637	 1	 0.0	 0.0	 0.019449	 -0.019449	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	10638	 1	 96.7	 23.7	 0.0	 39.1	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	10639	 1	 -0.0	 -0.0	 0.0	 35.98	 0	    1.00000	    0.00000	 380.0	 12	    1.10000	    0.90000;
	10640	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 9	    1.10000	    0.90000;
	10641	 1	 185.0	 26.3	 0.0	 11.78	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	10642	 1	 -0.0	 -0.0	 0.0	 3.42	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	10643	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	10644	 1	 7.61	 3.8	 0.0	 0.82	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	10645	 1	 -0.0	 -0.0	 0.0	 2.12	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	10646	 1	 -0.0	 0.0	 0.0	 2.0	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	10647	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	10648	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	10649	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	10650	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 6.3	 1	    1.10000	    0.90000;
	10651	 1	 0.0	 -0.0	 0.506185	 -0.393699	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	10652	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	10653	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	10654	 1	 0.0	 -0.0	 0.090774	 6.600444	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	10655	 1	 18.62	 6.7	 0.0	 0.83	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	10656	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	10657	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	10658	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	10659	 1	 -0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	10660	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	10661	 1	 79.39	 31.3	 0.0	 2.23	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	10662	 1	 -0.0	 -0.0	 0.0	 8.38	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	10663	 1	 0.0	 -0.0	 0.0	 10.8	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	10664	 1	 -0.0	 0.0	 0.223135	 10.383351	 0	    1.00000	    0.00000	 220.0	 18	    1.20000	    0.80000;
	10665	 1	 18.12	 6.0	 0.0	 0.7	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	10666	 1	 7.41	 2.7	 0.0	 0.56	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	10667	 1	 181.1	 25.8	 0.0	 42.18	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	10668	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	10669	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	10670	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	10671	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	10672	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	10673	 1	 46.8	 6.7	 0.0	 25.55	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	10674	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	10675	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	10676	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	10677	 1	 -0.0	 -0.0	 0.0	 20.08	 0	    1.00000	    0.00000	 380.0	 12	    1.20000	    0.80000;
	10678	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	10679	 1	 11.91	 4.4	 0.0	 0.16	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	10680	 1	 -0.0	 0.0	 0.0	 46.28	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	10681	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	10682	 1	 3.4	 1.1	 0.0	 0.55	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	10683	 1	 0.0	 0.0	 0.0	 26.5	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	10684	 1	 25.83	 5.7	 0.0	 0.41	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	10685	 1	 -0.0	 0.0	 0.0	 21.32	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	10686	 1	 -0.0	 -0.0	 0.0	 49.904544	 0	    1.00000	    0.00000	 380.0	 20	    1.10000	    0.90000;
	10687	 1	 -0.0	 0.0	 0.0	 15.49	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	10688	 1	 11.71	 3.8	 0.0	 2.39	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	10689	 1	 114.7	 4.1	 0.038987	 12.311013	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	10690	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	10691	 1	 2.7	 0.8	 0.0	 1.09	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	10692	 1	 41.85	 15.2	 0.0	 0.21	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	10693	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 6.3	 1	    1.10000	    0.90000;
	10694	 1	 0.0	 0.0	 0.0	 2.63	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	10695	 1	 36.84	 13.3	 0.0	 1.05	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	10696	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	10697	 1	 97.41	 -4.48	 0.0	 16.55	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	10698	 1	 -0.0	 -0.0	 0.135375	 37.092175	 0	    1.00000	    0.00000	 380.0	 18	    1.20000	    0.80000;
	10699	 1	 -0.0	 0.0	 0.0	 1.42	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	10700	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	10701	 1	 0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	10702	 1	 36.04	 12.0	 0.0	 0.11	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	10703	 1	 -0.0	 -0.0	 0.0	 2.25	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	10704	 1	 2.5	 94.6	 0.543767	 2.75707	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	10705	 1	 0.4	 0.1	 0.0	 1.39	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	10706	 1	 82.89	 32.6	 0.0	 45.84	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	10707	 1	 -0.0	 0.0	 0.0	 5.38	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	10708	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	10709	 1	 214.8	 42.7	 0.36439	 68.73561	 0	    1.00000	    0.00000	 380.0	 17	    1.10000	    0.90000;
	10710	 1	 -0.0	 0.0	 0.0	 1.32	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	10711	 1	 256.0	 69.9	 0.0	 43.56	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	10712	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	10713	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	10714	 1	 102.6	 12.0	 0.0	 66.849841	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	10715	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	10716	 1	 11.8	 1.7	 0.0	 3.85	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	10717	 1	 -0.0	 -0.0	 0.0	 16.07	 0	    1.00000	    0.00000	 380.0	 23	    1.20000	    0.80000;
	10718	 1	 -0.0	 -0.0	 0.12635	 23.056325	 0	    1.00000	    0.00000	 380.0	 21	    1.20000	    0.80000;
	10719	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	10720	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	10721	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	10722	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	10723	 1	 29.53	 2.4	 0.0	 0.35	 0	    1.00000	    0.00000	 110.0	 3	    1.10000	    0.90000;
	10724	 1	 -0.0	 -0.0	 0.0	 0.09	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	10725	 1	 48.95	 21.4	 0.057981	 1.162019	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	10726	 1	 -0.0	 -0.0	 0.0	 106.24	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	10727	 1	 210.9	 48.3	 0.0	 9.75	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	10728	 1	 0.0	 -0.0	 0.0	 2.1	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	10729	 1	 -0.0	 -0.0	 0.0	 0.81	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	10730	 1	 0.0	 -0.0	 0.0	 0.15	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	10731	 1	 132.0	 26.0	 0.0	 27.18	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	10732	 1	 36.94	 62.6	 0.0	 0.12	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	10733	 1	 18.22	 6.3	 0.0	 0.48	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	10734	 1	 -0.0	 0.0	 0.0	 2.33	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	10735	 1	 -0.0	 -0.0	 0.0	 0.41	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	10736	 1	 69.7	 9.9	 0.0	 1.52	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	10737	 1	 34.94	 8.6	 0.078291	 0.921709	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	10738	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	10739	 1	 -0.0	 -0.0	 0.0	 6.54	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	10740	 1	 120.6	 35.1	 0.0	 20.052	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	10741	 1	 -0.0	 0.0	 0.038738	 -0.038738	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	10742	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	10743	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	10744	 1	 0.0	 -0.0	 0.205481	 71.847328	 0	    1.00000	    0.00000	 380.0	 15	    1.20000	    0.80000;
	10745	 1	 -0.0	 0.0	 0.019259	 0.270741	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	10746	 1	 258.79	 42.82	 0.0	 9.28	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	10747	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	10748	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	10749	 1	 25.13	 14.0	 0.0	 0.04	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	10750	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	10751	 1	 45.75	 15.8	 0.0	 3.42	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	10752	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	10753	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	10754	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	10755	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	10756	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	10757	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.5	 1	    1.10000	    0.90000;
	10758	 1	 0.0	 -0.0	 0.0	 0.06	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	10759	 1	 0.0	 0.0	 0.0	 2.98	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	10760	 1	 0.0	 0.0	 0.0	 8.41	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	10761	 1	 5.51	 2.1	 0.0	 1.92	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	10762	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	10763	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	10764	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	10765	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	10766	 1	 23.83	 8.6	 0.0	 3.08	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	10767	 1	 37.44	 0.0	 0.0	 0.67	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	10768	 1	 169.0	 70.8	 0.0	 5.23	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	10769	 1	 0.0	 -0.0	 0.0	 61.36	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	10770	 1	 31.03	 8.9	 0.0	 0.49	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	10771	 1	 -0.0	 0.0	 0.0	 0.61	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	10772	 1	 -0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	10773	 1	 -0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	10774	 1	 264.33	 86.69	 0.0	 91.94	 0	    1.00000	    0.00000	 380.0	 14	    1.10000	    0.90000;
	10775	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	10776	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	10777	 1	 16.7	 2.4	 0.0	 3.98	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	10778	 1	 -0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	10779	 1	 16.52	 6.3	 0.0	 0.23	 0	    1.00000	    0.00000	 110.0	 18	    1.20000	    0.80000;
	10780	 1	 75.56	 13.04	 0.0	 8.77	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	10781	 1	 -0.0	 -0.0	 0.0	 3.9	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	10782	 1	 87.5	 21.3	 0.0	 7.52	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	10783	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	10784	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	10785	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 17	    1.10000	    0.90000;
	10786	 1	 0.0	 0.0	 0.0	 4.49	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	10787	 1	 127.3	 26.7	 0.0	 7.02	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	10788	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	10789	 1	 110.1	 29.4	 0.0	 1.11	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	10790	 1	 26.33	 5.3	 0.0	 4.31	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	10791	 1	 12.71	 4.2	 0.0	 0.65	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	10792	 1	 -40.95	 -28.4	 0.0	 7.29	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	10793	 1	 0.0	 0.0	 0.077725	 20.901706	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	10794	 1	 88.2	 21.0	 0.0	 2.22	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	10795	 1	 0.0	 0.0	 0.0	 14.29	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	10796	 1	 223.31	 61.3	 0.0	 4.51	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	10797	 1	 208.9	 29.8	 0.0	 1.42	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	10798	 1	 0.0	 -0.01	 0.23465	 19.69065	 0	    1.00000	    0.00000	 380.0	 21	    1.20000	    0.80000;
	10799	 1	 6.31	 1.3	 0.0	 0.12	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	10800	 1	 70.48	 22.5	 0.0	 4.82	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	10801	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	10802	 1	 1.5	 0.4	 0.0	 0.15	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	10803	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	10804	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	10805	 1	 -0.0	 -0.0	 0.0	 0.6	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	10806	 1	 -0.0	 -0.0	 0.0	 7.35	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	10807	 1	 50.3	 7.2	 0.0	 3.22	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	10808	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	10809	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	10810	 1	 34.9	 5.0	 0.0	 2.95	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	10811	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	10812	 1	 10.01	 4.3	 0.0	 5.64	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	10813	 1	 -0.0	 -0.0	 0.0	 1.81	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	10814	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 15.5	 1	    1.10000	    0.90000;
	10815	 1	 -0.2	 -0.83	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	10816	 1	 53.06	 19.2	 0.0	 0.41	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	10817	 1	 22.02	 5.1	 0.0	 0.69	 0	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	10818	 1	 -0.0	 -0.0	 0.0	 0.63	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	10819	 1	 -0.0	 -0.0	 0.0	 14.06	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	10820	 1	 41.5	 5.9	 0.0	 8.21	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	10821	 1	 105.67	 0.56	 0.0	 18.05	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	10822	 1	 0.0	 0.0	 0.0	 0.28	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	10823	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	10824	 1	 -0.0	 -0.0	 0.059551	 4.150374	 0	    1.00000	    0.00000	 220.0	 22	    1.10000	    0.90000;
	10825	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 15.0	 1	    1.10000	    0.90000;
	10826	 1	 36.34	 45.0	 0.594241	 4.650845	 0	    1.00000	    0.00000	 330.0	 24	    1.10000	    0.90000;
	10827	 1	 0.0	 -0.0	 0.0	 4.04	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	10828	 1	 -0.0	 -0.0	 0.0	 1.55	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	10829	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 6.3	 1	    1.10000	    0.90000;
	10830	 1	 -0.0	 0.0	 0.0	 1.68	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	10831	 1	 -0.0	 0.0	 0.0	 12.79	 0	    1.00000	    0.00000	 380.0	 8	    1.20000	    0.80000;
	10832	 1	 0.0	 0.0	 0.0	 4.09	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	10833	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	10834	 1	 16.62	 5.5	 0.0	 1.68	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	10835	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	10836	 1	 -0.0	 -0.0	 0.0	 0.04	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	10837	 1	 142.0	 27.8	 0.0	 17.77	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	10838	 1	 153.3	 27.6	 0.0	 23.2	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	10839	 1	 55.66	 22.4	 0.0	 2.11	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	10840	 1	 -0.0	 -0.0	 0.0	 87.69	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	10841	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	10842	 1	 0.0	 0.0	 0.0	 5.68	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	10843	 1	 41.45	 17.3	 0.0	 0.93	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	10844	 1	 100.3	 17.2	 0.0	 6.63	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	10845	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 7	    1.10000	    0.90000;
	10846	 1	 168.9	 113.0	 0.0	 123.25	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	10847	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 9	    1.20000	    0.80000;
	10848	 1	 30.03	 18.6	 0.0	 0.47	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	10849	 1	 187.0	 108.2	 0.459362	 5.986338	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	10850	 1	 -0.0	 -0.0	 0.179185	 0.330679	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	10851	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	10852	 1	 -0.0	 0.0	 0.0	 1.13	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	10853	 1	 59.67	 6.0	 0.0	 3.6	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	10854	 1	 19.02	 5.4	 0.0	 0.63	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	10855	 1	 0.0	 -0.8	 0.0	 0.39	 0	    1.00000	    0.00000	 110.0	 3	    1.10000	    0.90000;
	10856	 1	 94.5	 -27.8	 0.0	 5.52	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	10857	 1	 46.35	 28.7	 0.0	 16.37	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	10858	 1	 0.0	 0.0	 0.0	 127.01	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	10859	 1	 50.06	 -30.4	 0.175758	 2.103299	 0	    1.00000	    0.00000	 110.0	 23	    1.10000	    0.90000;
	10860	 1	 0.0	 -0.0	 0.0	 1.03	 0	    1.00000	    0.00000	 150.0	 9	    1.20000	    0.80000;
	10861	 1	 0.0	 0.0	 0.156722	 26.853278	 0	    1.00000	    0.00000	 380.0	 7	    1.10000	    0.90000;
	10862	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	10863	 1	 0.0	 -0.0	 0.0	 0.68	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	10864	 1	 -0.0	 0.0	 0.0	 1.49	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	10865	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 9	    1.10000	    0.90000;
	10866	 1	 33.64	 13.7	 0.0	 0.75	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	10867	 1	 23.43	 8.5	 0.0	 0.28	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	10868	 1	 16.22	 5.0	 0.0	 0.18	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	10869	 1	 0.0	 0.0	 0.150434	 36.284268	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	10870	 1	 106.4	 19.0	 0.0	 4.65	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	10871	 1	 -0.0	 0.0	 0.099359	 90.374619	 0	    1.00000	    0.00000	 380.0	 18	    1.20000	    0.80000;
	10872	 1	 18.02	 12.2	 0.0	 0.53	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	10873	 1	 415.5	 103.4	 0.0	 37.13	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	10874	 1	 168.3	 -57.1	 0.0	 16.319522	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	10875	 1	 8.11	 2.7	 0.0	 2.03	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	10876	 1	 -23.83	 7.8	 0.0	 2.3	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	10877	 1	 65.67	 25.6	 0.0	 2.34	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	10878	 1	 -0.0	 -0.0	 0.0	 7.3	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	10879	 1	 123.1	 20.9	 0.0	 25.95	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	10880	 1	 4.2	 0.6	 0.0	 2.98	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	10881	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	10882	 1	 1.8	 0.6	 0.0	 0.79	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	10883	 1	 411.3	 168.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	10884	 1	 -0.0	 0.0	 0.0	 120.17	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	10885	 1	 0.0	 -0.0	 0.0	 37.39	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	10886	 1	 162.5	 48.4	 0.0	 5.73	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	10887	 1	 0.0	 0.0	 0.0	 7.21	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	10888	 1	 0.0	 -0.0	 0.526584	 7.230435	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	10889	 1	 0.0	 -0.0	 0.039495	 0.960505	 0	    1.00000	    0.00000	 220.0	 19	    1.10000	    0.90000;
	10890	 1	 116.8	 59.0	 0.0	 1.63	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	10891	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	10892	 1	 -0.0	 -0.0	 0.0	 13.33	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	10893	 1	 0.0	 -0.0	 0.0	 0.46	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	10894	 1	 -0.0	 -0.0	 0.0	 19.61	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	10895	 1	 18.32	 5.3	 0.0	 7.32	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	10896	 1	 121.3	 20.7	 0.0	 2.39	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	10897	 1	 12.71	 2.5	 0.0	 0.56	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	10898	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	10899	 1	 -0.0	 0.0	 0.0	 22.76	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	10900	 1	 5.44	 2.14	 0.0	 0.93	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	10901	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	10902	 1	 -0.0	 -0.0	 0.0	 36.77	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	10903	 1	 0.0	 0.0	 0.0	 17.05	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	10904	 1	 111.9	 118.3	 0.0	 11.48	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	10905	 1	 -0.0	 0.0	 0.0	 3.24	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	10906	 1	 -0.0	 0.0	 0.030087	 2.639913	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	10907	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	10908	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	10909	 1	 34.9	 5.0	 0.0	 3.05	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	10910	 1	 0.0	 -0.0	 0.0	 92.73	 0	    1.00000	    0.00000	 380.0	 16	    1.10000	    0.90000;
	10911	 1	 15.96	 2.18	 0.0	 3.58	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	10912	 1	 108.8	 28.1	 0.0	 30.9	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	10913	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	10914	 1	 227.49	 61.6	 0.0	 13.7	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	10915	 1	 49.45	 16.5	 0.0	 4.13	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	10916	 1	 223.1	 31.8	 0.0	 23.58	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	10917	 1	 -0.0	 -0.0	 0.0	 3.49	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	10918	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	10919	 1	 0.0	 0.0	 0.135493	 90.112445	 0	    1.00000	    0.00000	 380.0	 19	    1.20000	    0.80000;
	10920	 1	 9.01	 3.3	 0.0	 0.62	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	10921	 1	 96.2	 23.3	 0.0	 2.05	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	10922	 1	 0.0	 0.0	 0.0	 83.200565	 0	    1.00000	    0.00000	 380.0	 20	    1.10000	    0.90000;
	10923	 1	 -7.41	 -1.6	 0.0	 2.0	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	10924	 1	 0.0	 -0.0	 0.0	 37.99	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	10925	 1	 10.11	 3.7	 0.0	 0.76	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	10926	 1	 -0.0	 -0.0	 0.0	 1.77	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	10927	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	10928	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	10929	 1	 178.7	 31.3	 0.0	 5.6	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	10930	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	10931	 1	 45.45	 7.4	 0.039206	 1.230596	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	10932	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 15.0	 1	    1.10000	    0.90000;
	10933	 1	 240.63	 27.93	 0.122637	 7.217363	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	10934	 1	 -11.14	 -3.38	 0.0	 2.35	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	10935	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	10936	 1	 15.72	 5.2	 0.0	 0.76	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	10937	 1	 1.5	 0.4	 0.0	 0.66	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	10938	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	10939	 1	 13.72	 8.5	 0.0	 19.46	 0	    1.00000	    0.00000	 150.0	 9	    1.20000	    0.80000;
	10940	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	10941	 1	 -18.95	 -6.93	 0.0	 33.134947	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	10942	 1	 -0.0	 0.0	 0.0	 20.52	 0	    1.00000	    0.00000	 380.0	 7	    1.10000	    0.90000;
	10943	 1	 251.47	 90.86	 0.0	 14.54	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	10944	 1	 0.0	 0.0	 0.061301	 0.038699	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	10945	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 3.3	 1	    1.10000	    0.90000;
	10946	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	10947	 1	 6.41	 2.3	 0.0	 0.93	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	10948	 1	 59.67	 27.1	 0.0	 43.03	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	10949	 1	 67.07	 35.5	 0.0	 32.32	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	10950	 1	 47.95	 29.7	 0.0	 0.23	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	10951	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	10952	 1	 4.5	 1.1	 0.0	 12.56	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	10953	 1	 -0.18	 -3.54	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	10954	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	10955	 1	 0.0	 0.0	 0.0	 0.04	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	10956	 1	 0.0	 0.0	 0.0	 0.04	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	10957	 1	 -1316.59	 -129.9	 0.227758	 22.625182	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	10958	 1	 0.4	 0.1	 0.0	 0.93	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	10959	 1	 44.35	 10.8	 0.0	 8.72	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	10960	 1	 4.41	 2.7	 0.0	 1.58	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	10961	 1	 -0.0	 -0.0	 0.0	 5.97	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	10962	 1	 0.2	 0.7	 0.0	 0.04	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	10963	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 10.5	 1	    1.10000	    0.90000;
	10964	 1	 70.08	 35.0	 0.0	 0.33	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	10965	 1	 198.6	 282.2	 0.11228	 170.076433	 0	    1.00000	    0.00000	 380.0	 3	    1.20000	    0.80000;
	10966	 1	 -0.0	 0.0	 0.0	 4.29	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	10967	 1	 0.0	 0.0	 0.0	 43.34	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	10968	 1	 0.0	 -0.0	 0.0	 4.14	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	10969	 1	 -6.79	 -1.44	 0.0	 6.66	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	10970	 1	 139.4	 21.2	 0.0	 6.21	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	10971	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	10972	 1	 10.11	 3.7	 0.0	 0.25	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	10973	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	10974	 1	 4.4	 2.2	 0.0	 0.29	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	10975	 1	 160.9	 22.9	 0.0	 41.42	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	10976	 1	 100.6	 49.6	 0.12159	 -0.101325	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	10977	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	10978	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	10979	 1	 136.2	 4.8	 0.0	 7.58	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	10980	 1	 -2.3	 -0.8	 0.0	 0.33	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	10981	 1	 0.0	 -0.0	 0.009549	 0.550451	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	10982	 1	 -0.0	 0.0	 0.0	 1.86	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	10983	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 20	    1.10000	    0.90000;
	10984	 1	 -0.0	 0.0	 0.0	 3.51	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	10985	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	10986	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	10987	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	10988	 1	 22.3	 3.1	 0.0	 8.81	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	10989	 1	 4.0	 0.8	 0.0	 17.65	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	10990	 1	 56.26	 8.5	 0.0	 5.32	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	10991	 1	 -10.06	 -3.91	 0.0	 14.08	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	10992	 1	 46.35	 14.9	 0.0	 20.62	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	10993	 1	 0.1	 0.0	 0.0	 5.01	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	10994	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	10995	 1	 0.0	 0.0	 0.0	 2.28	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	10996	 1	 0.0	 0.0	 0.0	 38.570506	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	10997	 1	 1.4	 100.0	 0.0	 21.43	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	10998	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	10999	 1	 0.0	 -0.0	 0.090774	 3.150444	 0	    1.00000	    0.00000	 220.0	 18	    1.20000	    0.80000;
	11000	 1	 3.8	 0.6	 0.0	 0.68	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	11001	 1	 9.01	 4.0	 0.0	 1.39	 0	    1.00000	    0.00000	 110.0	 23	    1.10000	    0.90000;
	11002	 1	 -14.89	 -4.46	 0.0	 0.3	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	11003	 1	 97.97	 31.8	 0.0	 5.02	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	11004	 1	 0.0	 -0.0	 0.49396	 13.698454	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	11005	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	11006	 1	 62.7	 9.0	 0.0	 4.6	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	11007	 1	 -0.0	 -0.0	 0.15	 5.08	 0	    1.00000	    0.00000	 220.0	 21	    1.10000	    0.90000;
	11008	 1	 0.0	 -0.0	 0.07	 3.65	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	11009	 1	 107.2	 45.6	 0.0	 5.28	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	11010	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 20	    1.10000	    0.90000;
	11011	 1	 -8.66	 -6.01	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	11012	 1	 0.0	 0.0	 0.0	 1.88	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	11013	 1	 125.4	 17.8	 0.0	 7.64	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	11014	 1	 211.0	 59.3	 0.0	 3.46	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	11015	 1	 0.0	 -0.0	 0.0	 42.361623	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	11016	 1	 -0.0	 -0.0	 0.0	 13.62	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	11017	 1	 -0.0	 0.0	 0.0	 31.242294	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	11018	 1	 26.23	 8.4	 0.0	 0.96	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	11019	 1	 13.82	 5.0	 0.0	 0.43	 0	    1.00000	    0.00000	 220.0	 19	    1.20000	    0.80000;
	11020	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 6.3	 1	    1.10000	    0.90000;
	11021	 1	 43.15	 15.4	 0.0	 0.36	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	11022	 1	 20.62	 6.7	 0.0	 0.71	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	11023	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	11024	 1	 -0.0	 -0.0	 0.0	 1.98	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	11025	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	11026	 1	 -0.0	 -0.0	 0.0	 17.166964	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	11027	 1	 130.5	 17.2	 0.0	 5.65	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	11028	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	11029	 1	 40.85	 15.7	 0.0	 2.08	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	11030	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	11031	 1	 186.8	 22.9	 0.0	 9.94	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	11032	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	11033	 1	 346.42	 89.04	 0.0	 43.55	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	11034	 1	 -0.0	 -0.0	 0.0	 0.53	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	11035	 1	 72.48	 44.9	 0.0	 3.86	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	11036	 1	 29.65	 7.18	 0.0	 4.51	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	11037	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	11038	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	11039	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 20	    1.10000	    0.90000;
	11040	 1	 281.3	 40.9	 0.0	 33.56	 0	    1.00000	    0.00000	 220.0	 11	    1.10000	    0.90000;
	11041	 1	 20.92	 9.35	 0.0	 1.56	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	11042	 1	 -0.0	 -0.0	 0.0	 5.55	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	11043	 1	 101.48	 19.53	 0.0	 4.41	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	11044	 1	 0.0	 -0.0	 0.0	 0.31	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	11045	 1	 -0.0	 -0.0	 0.0	 22.68	 0	    1.00000	    0.00000	 380.0	 13	    1.10000	    0.90000;
	11046	 1	 159.98	 76.4	 0.0	 22.64	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	11047	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 14.0	 1	    1.10000	    0.90000;
	11048	 1	 0.0	 0.0	 0.0	 3.1	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	11049	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	11050	 1	 34.44	 12.1	 0.0	 0.87	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	11051	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 24	    1.10000	    0.90000;
	11052	 1	 90.5	 12.8	 0.0	 1.17	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	11053	 1	 8.98	 -3.79	 0.0	 2.86	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	11054	 1	 34.64	 12.4	 0.0	 2.66	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	11055	 1	 0.0	 -0.0	 0.0	 20.54	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	11056	 1	 218.0	 18.6	 0.0	 36.29	 0	    1.00000	    0.00000	 380.0	 16	    1.10000	    0.90000;
	11057	 1	 23.03	 8.3	 0.0	 1.05	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	11058	 1	 531.7	 -12.8	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	11059	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	11060	 1	 -0.0	 0.0	 0.0	 0.81	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	11061	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	11062	 1	 13.9	 1.9	 0.0	 2.23	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	11063	 1	 0.0	 -0.0	 0.058317	 0.581683	 0	    1.00000	    0.00000	 220.0	 12	    1.10000	    0.90000;
	11064	 1	 -0.0	 0.0	 0.0	 1.18	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	11065	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	11066	 1	 -0.0	 0.0	 0.0	 13.9	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	11067	 1	 0.0	 -0.0	 0.0	 0.73	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	11068	 1	 -0.0	 -0.0	 0.0	 48.75	 0	    1.00000	    0.00000	 380.0	 19	    1.20000	    0.80000;
	11069	 1	 126.6	 28.7	 0.0	 15.02	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	11070	 1	 -0.0	 0.0	 0.0	 12.4	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	11071	 1	 0.0	 -0.0	 0.0	 2.12	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	11072	 1	 29.03	 6.1	 0.0	 0.44	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	11073	 1	 -0.0	 0.0	 0.0	 0.5	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	11074	 1	 -0.0	 0.0	 0.0	 6.69	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	11075	 1	 45.95	 15.4	 0.0	 0.6	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	11076	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	11077	 1	 136.9	 11.4	 0.0	 3.05	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	11078	 1	 0.0	 -0.0	 0.0	 0.17	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	11079	 1	 32.1	 4.5	 0.0	 3.75	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	11080	 1	 300.1	 73.7	 0.038936	 1.881064	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	11081	 1	 5.01	 1.8	 0.0	 3.68	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	11082	 1	 127.6	 45.3	 0.0	 57.43	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	11083	 1	 -0.0	 0.0	 0.0	 68.73	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	11084	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 23	    1.10000	    0.90000;
	11085	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 23	    1.10000	    0.90000;
	11086	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 23	    1.10000	    0.90000;
	11087	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 23	    1.10000	    0.90000;
	11088	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 23	    1.10000	    0.90000;
	11089	 1	 -0.0	 -0.0	 0.0	 0.87	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	11090	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 23	    1.10000	    0.90000;
	11091	 1	 10.11	 4.4	 0.0	 0.29	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	11092	 1	 50.26	 19.3	 0.0	 2.1	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	11093	 1	 -0.0	 0.0	 0.0	 0.71	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	11094	 1	 -0.66	 -2.79	 0.0	 2.49	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	11095	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	11096	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	11097	 1	 11.21	 3.7	 0.0	 0.9	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	11098	 1	 -0.2	 -1.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	11099	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	11100	 1	 58.77	 16.1	 0.0	 4.11	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	11101	 1	 116.5	 33.4	 0.0	 0.28	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	11102	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	11103	 1	 30.43	 10.0	 0.0	 0.41	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	11104	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	11105	 1	 16.42	 5.3	 0.0	 0.43	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	11106	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	11107	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	11108	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	11109	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	11110	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	11111	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	11112	 1	 18.02	 4.0	 0.0	 3.3	 0	    1.00000	    0.00000	 220.0	 11	    1.10000	    0.90000;
	11113	 1	 0.5	 0.0	 0.0	 0.84	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	11114	 1	 0.0	 -0.0	 0.0	 2.13	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	11115	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	11116	 1	 119.0	 31.7	 0.0	 1.94	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	11117	 1	 -0.0	 -0.0	 0.0	 0.62	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	11118	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	11119	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	11120	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	11121	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	11122	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	11123	 1	 119.7	 43.4	 0.0	 0.92	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	11124	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	11125	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	11126	 1	 5.51	 2.2	 0.0	 1.43	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	11127	 1	 87.0	 30.8	 0.0	 2.43	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	11128	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	11129	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	11130	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	11131	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	11132	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	11133	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	11134	 1	 13.11	 2.8	 0.134137	 1.835863	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	11135	 1	 8.31	 3.0	 0.0	 1.27	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	11136	 1	 24.03	 -56.8	 0.0	 2.69	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	11137	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	11138	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	11139	 1	 26.82	 24.2	 0.0	 2.89	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	11140	 1	 115.4	 31.0	 0.0	 28.85	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	11141	 1	 -0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	11142	 1	 -0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	11143	 1	 -0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	11144	 1	 -0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	11145	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	11146	 1	 0.0	 -0.0	 0.0	 9.84	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	11147	 1	 6.31	 2.5	 0.0	 0.44	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	11148	 1	 41.8	 5.9	 0.0	 2.54	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	11149	 1	 70.48	 17.6	 0.0	 3.92	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	11150	 1	 -0.0	 -0.0	 0.0	 0.15	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	11151	 1	 0.0	 -0.0	 0.205709	 31.487194	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	11152	 1	 -0.0	 0.0	 0.0	 1.69	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	11153	 1	 -0.0	 0.0	 0.078682	 0.390988	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	11154	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 9	    1.10000	    0.90000;
	11155	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	11156	 1	 136.95	 87.7	 0.0	 7.84	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	11157	 1	 -0.0	 -0.0	 0.0	 0.84	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	11158	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 6.3	 1	    1.10000	    0.90000;
	11159	 1	 -0.0	 -0.0	 0.0	 14.94	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	11160	 1	 90.5	 12.8	 0.0	 6.78	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	11161	 1	 32.74	 10.5	 0.0	 1.78	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	11162	 1	 164.41	 101.14	 0.0	 61.4	 0	    1.00000	    0.00000	 380.0	 13	    1.10000	    0.90000;
	11163	 1	 78.89	 45.6	 0.0	 0.04	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	11164	 1	 0.0	 -0.0	 0.058918	 0.141082	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	11165	 1	 0.0	 0.0	 0.165195	 -0.128485	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	11166	 1	 -0.0	 0.0	 0.0	 1.15	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	11167	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	11168	 1	 10.31	 3.8	 0.090914	 4.82939	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	11169	 1	 0.0	 -0.0	 0.0	 2.82	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	11170	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 15.75	 1	    1.10000	    0.90000;
	11171	 1	 91.6	 20.3	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	11172	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	11173	 1	 5.5	 0.8	 0.0	 1.9	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	11174	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	11175	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	11176	 1	 -0.0	 -0.0	 0.0	 1.86	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	11177	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	11178	 1	 -12.61	 11.6	 0.0	 0.02	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	11179	 1	 0.0	 -0.0	 0.29	 6.18	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	11180	 1	 429.5	 163.1	 0.0	 28.67	 0	    1.00000	    0.00000	 220.0	 11	    1.10000	    0.90000;
	11181	 1	 110.1	 44.6	 0.04004	 2.98997	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	11182	 1	 68.78	 35.0	 0.0	 34.52	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	11183	 1	 0.0	 0.0	 0.494726	 0.384626	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	11184	 1	 0.0	 0.0	 0.0	 138.75	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	11185	 1	 0.0	 -0.0	 0.0	 26.93	 0	    1.00000	    0.00000	 380.0	 9	    1.20000	    0.80000;
	11186	 1	 90.3	 5.7	 0.0	 19.04	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	11187	 1	 124.1	 -30.3	 0.0	 14.26	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	11188	 1	 109.1	 15.6	 0.0	 2.47	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	11189	 1	 -0.0	 -0.0	 0.0	 33.48	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	11190	 1	 0.0	 -0.0	 0.0	 0.1	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	11191	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 22	    1.10000	    0.90000;
	11192	 1	 14.92	 5.4	 0.0	 0.97	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	11193	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 22	    1.10000	    0.90000;
	11194	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 22	    1.10000	    0.90000;
	11195	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 22	    1.10000	    0.90000;
	11196	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 22	    1.10000	    0.90000;
	11197	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 22	    1.10000	    0.90000;
	11198	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 22	    1.10000	    0.90000;
	11199	 1	 29.13	 11.3	 0.0	 0.16	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	11200	 1	 20.62	 7.5	 0.0	 0.79	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	11201	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	11202	 1	 61.97	 38.4	 0.0	 7.42	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	11203	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	11204	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	11205	 1	 255.3	 78.7	 0.0	 6.5	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	11206	 1	 33.94	 11.4	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	11207	 1	 41.8	 5.9	 0.0	 3.29	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	11208	 1	 117.0	 15.2	 0.0	 2.87	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	11209	 1	 -0.0	 -0.0	 0.179063	 9.690781	 0	    1.00000	    0.00000	 220.0	 22	    1.10000	    0.90000;
	11210	 1	 -0.0	 0.0	 0.216888	 13.908297	 0	    1.00000	    0.00000	 380.0	 9	    1.20000	    0.80000;
	11211	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	11212	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	11213	 1	 142.3	 19.2	 0.079316	 13.420684	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	11214	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	11215	 1	 -0.0	 0.0	 0.090774	 5.169044	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	11216	 1	 0.0	 -0.0	 0.11613	 2.442903	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	11217	 1	 4.81	 1.6	 0.0	 0.19	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	11218	 1	 -0.21	 -2.37	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	11219	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	11220	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	11221	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	11222	 1	 37.14	 2.7	 0.0	 2.33	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	11223	 1	 256.8	 -61.8	 0.0	 36.73	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	11224	 1	 16.52	 5.5	 0.0	 1.15	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	11225	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	11226	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	11227	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	11228	 1	 93.4	 27.8	 0.0	 29.52	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	11229	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	11230	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	11231	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	11232	 1	 42.66	 -22.22	 0.0	 0.66	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	11233	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	11234	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	11235	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	11236	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	11237	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	11238	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	11239	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	11240	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	11241	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	11242	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	11243	 1	 67.07	 25.2	 0.0	 8.11	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	11244	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	11245	 1	 63.07	 7.1	 0.039913	 1.170065	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	11246	 1	 0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	11247	 1	 0.0	 0.0	 0.0	 35.53	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	11248	 1	 20.82	 7.9	 0.0	 42.36	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	11249	 1	 0.0	 -0.0	 0.24033	 46.858516	 0	    1.00000	    0.00000	 380.0	 1	    1.20000	    0.80000;
	11250	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	11251	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	11252	 1	 0.0	 -0.0	 0.0	 52.89	 0	    1.00000	    0.00000	 380.0	 9	    1.10000	    0.90000;
	11253	 1	 66.07	 21.6	 0.0	 0.75	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	11254	 1	 0.0	 0.0	 0.037655	 48.632345	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	11255	 1	 -0.0	 0.0	 0.0	 5.24	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	11256	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	11257	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	11258	 1	 -17.32	 5.7	 0.0	 1.52	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	11259	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	11260	 1	 36.94	 15.2	 0.196151	 15.653849	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	11261	 1	 -0.0	 -0.0	 0.0	 0.09	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	11262	 1	 0.0	 -0.0	 0.0	 0.44	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	11263	 1	 0.0	 0.0	 0.0	 1.59	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	11264	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	11265	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	11266	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	11267	 1	 49.45	 6.5	 0.0	 3.53	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	11268	 1	 -0.0	 0.0	 0.0	 48.77	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	11269	 1	 90.2	 30.3	 0.039983	 2.510017	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	11270	 1	 12.71	 5.1	 0.0	 15.31	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	11271	 1	 95.6	 13.6	 0.0	 21.47	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	11272	 1	 -0.0	 -0.0	 0.0	 5.28	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	11273	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	11274	 1	 0.0	 -0.0	 0.0	 96.48	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	11275	 1	 -0.0	 -0.0	 0.160142	 3.503537	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	11276	 1	 -0.0	 0.0	 0.0	 9.54	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	11277	 1	 25.13	 15.6	 0.0	 4.51	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	11278	 1	 -14.96	 -4.7	 0.0	 0.04	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	11279	 1	 -0.0	 0.0	 0.0	 10.69	 0	    1.00000	    0.00000	 220.0	 12	    1.10000	    0.90000;
	11280	 1	 10.91	 2.5	 0.0	 1.34	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	11281	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	11282	 1	 18.9	 2.7	 0.0	 5.84	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	11283	 1	 0.0	 -0.0	 0.13352	 0.05648	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	11284	 1	 -0.0	 -0.0	 0.0	 0.06	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	11285	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	11286	 1	 -0.0	 -0.0	 0.0	 19.62	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	11287	 1	 66.17	 27.4	 0.0	 14.12	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	11288	 1	 0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	11289	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	11290	 1	 11.91	 3.5	 0.0	 0.43	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	11291	 1	 -0.0	 -0.0	 0.0	 0.81	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	11292	 1	 51.96	 6.5	 0.0	 5.14	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	11293	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	11294	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	11295	 1	 48.65	 16.1	 0.0	 7.14	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	11296	 1	 0.0	 0.0	 0.0	 1.57	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	11297	 1	 131.3	 19.1	 0.039686	 14.000314	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	11298	 1	 0.2	 88.5	 0.0	 2.21	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	11299	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 9	    1.10000	    0.90000;
	11300	 1	 2.2	 0.5	 0.0	 0.58	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	11301	 1	 60.07	 36.0	 0.0	 0.06	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	11302	 1	 126.2	 -12.5	 0.0	 10.61	 0	    1.00000	    0.00000	 220.0	 3	    1.20000	    0.80000;
	11303	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	11304	 1	 27.93	 10.1	 0.0	 0.43	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	11305	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	11306	 1	 15.12	 4.9	 0.0	 0.68	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	11307	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	11308	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	11309	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	11310	 1	 0.0	 0.0	 0.0	 1.08	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	11311	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	11312	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	11313	 1	 0.0	 0.0	 0.0	 4.17	 0	    1.00000	    0.00000	 220.0	 8	    1.10000	    0.90000;
	11314	 1	 85.9	 93.8	 0.0	 3.93	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	11315	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	11316	 1	 -0.0	 0.0	 0.243444	 14.86713	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	11317	 1	 -0.0	 0.0	 0.0	 2.66	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	11318	 1	 70.78	 43.8	 0.0	 2.12	 0	    1.00000	    0.00000	 150.0	 9	    1.20000	    0.80000;
	11319	 1	 140.6	 20.1	 0.0	 13.81	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	11320	 1	 17.02	 5.5	 0.0	 1.02	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	11321	 1	 28.63	 5.6	 0.0	 1.28	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	11322	 1	 220.2	 83.2	 0.0	 0.61	 0	    1.00000	    0.00000	 220.0	 12	    1.10000	    0.90000;
	11323	 1	 39.64	 4.4	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 24	    1.10000	    0.90000;
	11324	 1	 65.98	 64.1	 0.0	 29.14	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	11325	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	11326	 1	 46.05	 22.0	 0.0	 2.95	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	11327	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	11328	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 7	    1.10000	    0.90000;
	11329	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 6.3	 1	    1.10000	    0.90000;
	11330	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	11331	 1	 20.82	 6.7	 0.0	 2.25	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	11332	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	11333	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	11334	 1	 0.0	 0.0	 0.0	 122.13	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	11335	 1	 137.0	 33.2	 0.0	 3.82	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	11336	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	11337	 1	 7.0	 1.0	 0.0	 1.51	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	11338	 1	 65.57	 44.6	 0.0	 5.95	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	11339	 1	 -0.0	 -0.0	 0.0	 0.36	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	11340	 1	 0.0	 -0.0	 0.0	 55.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	11341	 1	 35.74	 11.1	 0.038318	 0.271682	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	11342	 1	 31.84	 9.2	 0.0	 5.23	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	11343	 1	 -0.0	 0.0	 0.0	 0.97	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	11344	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	11345	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	11346	 1	 -0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	11347	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	11348	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	11349	 1	 0.0	 -0.0	 0.162749	 0.137938	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	11350	 1	 -0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	11351	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	11352	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	11353	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	11354	 1	 24.23	 4.7	 0.0	 0.75	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	11355	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	11356	 1	 58.5	 8.3	 0.0	 4.93	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	11357	 1	 0.0	 -0.0	 0.0	 5.53	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	11358	 1	 122.7	 -29.8	 0.0	 7.11	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	11359	 1	 10.9	 1.6	 0.0	 1.5	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	11360	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	11361	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	11362	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	11363	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	11364	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	11365	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	11366	 1	 15.9	 116.3	 0.0	 5.1	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	11367	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	11368	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	11369	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	11370	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	11371	 1	 524.5	 126.0	 0.0	 7.45	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	11372	 1	 0.0	 0.0	 0.0	 0.13	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	11373	 1	 76.6	 10.9	 0.0	 2.41	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	11374	 1	 2.2	 0.5	 0.0	 0.21	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	11375	 1	 8.03	 5.5	 0.0	 0.12	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	11376	 1	 17.52	 5.7	 0.0	 0.28	 0	    1.00000	    0.00000	 110.0	 18	    1.20000	    0.80000;
	11377	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	11378	 1	 -0.0	 0.0	 0.212593	 6.327407	 0	    1.00000	    0.00000	 380.0	 16	    1.10000	    0.90000;
	11379	 1	 -0.0	 -0.0	 0.818168	 126.193818	 0	    1.00000	    0.00000	 380.0	 9	    1.20000	    0.80000;
	11380	 1	 10.61	 1.0	 0.0	 1.7	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	11381	 1	 0.0	 -0.0	 0.059523	 1.960477	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	11382	 1	 0.0	 -0.0	 0.30117	 48.396871	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	11383	 1	 0.0	 0.0	 0.0	 0.15	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	11384	 1	 0.0	 -0.0	 0.0	 25.67	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	11385	 1	 11.01	 3.6	 0.0	 0.5	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	11386	 1	 78.89	 25.6	 0.0	 1.6	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	11387	 1	 0.0	 0.0	 0.0	 1.98	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	11388	 1	 11.91	 3.9	 0.0	 2.0	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	11389	 1	 3.4	 0.5	 0.0	 3.28	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	11390	 1	 47.15	 15.5	 0.0	 9.69	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	11391	 1	 0.0	 0.0	 0.0	 13.4	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	11392	 1	 0.0	 -0.6	 0.0	 0.5	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	11393	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	11394	 1	 48.15	 14.8	 0.0	 2.16	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	11395	 1	 223.6	 51.8	 0.0	 18.45	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	11396	 1	 12.6	 1.8	 0.0	 2.03	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	11397	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	11398	 1	 27.23	 10.1	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	11399	 1	 170.89	 50.38	 0.0	 6.44	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	11400	 1	 -0.0	 -0.0	 1.051502	 8.672363	 0	    1.00000	    0.00000	 380.0	 5	    1.20000	    0.80000;
	11401	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	11402	 1	 153.0	 21.5	 0.0	 28.85	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	11403	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	11404	 1	 7.61	 2.5	 0.0	 1.67	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	11405	 1	 124.5	 101.4	 0.0	 0.53	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	11406	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 8	    1.10000	    0.90000;
	11407	 1	 -0.0	 -0.0	 0.0	 13.33	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	11408	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 8	    1.10000	    0.90000;
	11409	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 8	    1.10000	    0.90000;
	11410	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 8	    1.10000	    0.90000;
	11411	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	11412	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	11413	 1	 0.0	 -0.0	 0.11	 2.57	 0	    1.00000	    0.00000	 220.0	 21	    1.10000	    0.90000;
	11414	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	11415	 1	 26.13	 8.5	 0.0	 0.37	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	11416	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	11417	 1	 0.0	 0.0	 0.115837	 3.304163	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	11418	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	11419	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	11420	 1	 30.03	 9.6	 0.0	 4.38	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	11421	 1	 -0.0	 -0.0	 0.0	 4.9	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	11422	 1	 0.0	 -0.0	 0.0	 55.79	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	11423	 1	 0.0	 -0.0	 0.1	 -0.29	 0	    1.00000	    0.00000	 220.0	 19	    1.10000	    0.90000;
	11424	 1	 -0.0	 0.0	 0.0	 1.33	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	11425	 1	 0.0	 0.0	 0.0	 0.46	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	11426	 1	 7.81	 2.8	 0.0	 0.4	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	11427	 1	 97.5	 13.9	 0.0	 2.42	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	11428	 1	 0.0	 -0.0	 0.0	 3.46	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	11429	 1	 12.91	 4.7	 0.0	 1.09	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	11430	 1	 139.9	 -26.2	 0.0	 5.42	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	11431	 1	 -0.0	 0.0	 0.039069	 0.260931	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	11432	 1	 0.0	 0.0	 0.0	 1.53	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	11433	 1	 9.61	 3.9	 0.058856	 0.431144	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	11434	 1	 -0.0	 0.0	 0.0	 0.14	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	11435	 1	 23.93	 5.8	 0.0	 0.64	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	11436	 1	 0.0	 0.0	 0.349217	 20.455616	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	11437	 1	 15.22	 3.9	 0.0	 0.89	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	11438	 1	 -0.0	 0.0	 0.0	 30.46	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	11439	 1	 -0.0	 0.0	 0.0	 0.22	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	11440	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 6.3	 1	    1.10000	    0.90000;
	11441	 1	 0.0	 -0.0	 0.0	 56.53	 0	    1.00000	    0.00000	 380.0	 9	    1.20000	    0.80000;
	11442	 1	 -0.0	 -0.0	 1.139672	 11.312126	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	11443	 1	 169.5	 27.7	 0.0	 3.04	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	11444	 1	 -9.31	 3.0	 0.0	 0.02	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	11445	 1	 -0.0	 0.0	 0.0	 43.0	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	11446	 1	 115.1	 16.4	 0.0	 7.67	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	11447	 1	 -0.0	 0.0	 0.0	 3.21	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	11448	 1	 209.1	 1.7	 0.0	 18.49	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	11449	 1	 22.83	 3.8	 0.0	 0.26	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	11450	 1	 1.8	 0.5	 0.0	 0.79	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	11451	 1	 34.9	 5.0	 0.0	 2.53	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	11452	 1	 -0.0	 0.0	 0.0	 10.33	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	11453	 1	 149.1	 -18.3	 0.0	 10.76	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	11454	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	11455	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	11456	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	11457	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	11458	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	11459	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	11460	 1	 584.3	 166.3	 0.0	 48.159681	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	11461	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 8	    1.10000	    0.90000;
	11462	 1	 0.0	 0.0	 0.0	 4.14	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	11463	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 8	    1.10000	    0.90000;
	11464	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 8	    1.10000	    0.90000;
	11465	 1	 77.7	 11.1	 0.0	 4.49	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	11466	 1	 0.0	 -0.0	 0.039875	 12.830062	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	11467	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	11468	 1	 12.11	 -4.0	 0.23333	 12.135003	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	11469	 1	 127.2	 -10.7	 0.0	 7.8	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	11470	 1	 179.0	 22.9	 0.0	 25.28	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	11471	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	11472	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	11473	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	11474	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	11475	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	11476	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.20000	    0.80000;
	11477	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	11478	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	11479	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	11480	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	11481	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	11482	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	11483	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 9	    1.10000	    0.90000;
	11484	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	11485	 1	 0.0	 -0.0	 0.0	 0.52	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	11486	 1	 -0.0	 0.0	 0.0	 1.77	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	11487	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	11488	 1	 37.04	 15.2	 0.174005	 27.214996	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	11489	 1	 32.44	 20.1	 0.0	 2.37	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	11490	 1	 137.2	 41.9	 0.101088	 13.207291	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	11491	 1	 0.0	 0.0	 0.090774	 13.090445	 0	    1.00000	    0.00000	 220.0	 18	    1.20000	    0.80000;
	11492	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 15.75	 1	    1.10000	    0.90000;
	11493	 1	 -3.2	 -7.9	 0.0	 1.95	 0	    1.00000	    0.00000	 220.0	 2	    1.10000	    0.90000;
	11494	 1	 -0.0	 -0.0	 0.135493	 30.26062	 0	    1.00000	    0.00000	 380.0	 21	    1.10000	    0.90000;
	11495	 1	 52.76	 17.2	 0.0	 38.38	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	11496	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	11497	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	11498	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	11499	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	11500	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	11501	 1	 193.3	 42.0	 0.119745	 3.480255	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	11502	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	11503	 1	 134.7	 17.5	 0.0	 4.53	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	11504	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	11505	 1	 110.3	 10.7	 0.117264	 16.622052	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	11506	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	11507	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	11508	 1	 0.0	 -0.0	 0.009953	 1.310047	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	11509	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	11510	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	11511	 1	 0.0	 0.0	 0.0	 1.01	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	11512	 1	 10.11	 4.3	 0.0	 0.63	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	11513	 1	 0.0	 0.0	 0.215164	 46.233143	 0	    1.00000	    0.00000	 380.0	 18	    1.20000	    0.80000;
	11514	 1	 -9.78	 -3.66	 0.0	 0.72	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	11515	 1	 0.0	 -0.0	 0.0	 2.06	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	11516	 1	 8.71	 2.5	 0.0	 0.66	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	11517	 1	 -0.0	 0.0	 0.101122	 0.748878	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	11518	 1	 0.0	 -0.0	 0.302291	 2.117657	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	11519	 1	 -0.0	 0.0	 0.0	 27.39	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	11520	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	11521	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	11522	 1	 185.8	 31.8	 0.0	 3.73	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	11523	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	11524	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	11525	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	11526	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	11527	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	11528	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	11529	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	11530	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	11531	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	11532	 1	 0.0	 -0.0	 0.0	 1.55	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	11533	 1	 0.0	 0.0	 0.0	 0.86	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	11534	 1	 0.0	 -0.0	 0.0	 15.21	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	11535	 1	 12.6	 1.8	 0.0	 4.19	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	11536	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	11537	 1	 -0.0	 0.0	 0.0	 3.98	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	11538	 1	 -3.53	 -4.62	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	11539	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 10.5	 1	    1.10000	    0.90000;
	11540	 1	 40.65	 16.0	 0.0	 0.36	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	11541	 1	 316.5	 100.8	 0.239735	 5.64021	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	11542	 1	 -0.0	 0.0	 0.0	 13.08	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	11543	 1	 -0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	11544	 1	 -0.0	 -0.0	 0.0	 2.36	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	11545	 1	 -0.0	 0.0	 0.0	 15.04	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	11546	 1	 0.0	 0.0	 0.0	 5.59	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	11547	 1	 -0.0	 -0.0	 0.463131	 37.913355	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	11548	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	11549	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	11550	 1	 258.3	 166.0	 0.0	 16.31	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	11551	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 20	    1.10000	    0.90000;
	11552	 1	 -0.0	 0.0	 0.0	 0.33	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	11553	 1	 11.41	 0.3	 0.0	 0.2	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	11554	 1	 39.14	 13.2	 0.0	 2.92	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	11555	 1	 229.3	 32.7	 0.0	 10.27	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	11556	 1	 88.5	 10.8	 0.0	 9.54	 0	    1.00000	    0.00000	 220.0	 20	    1.10000	    0.90000;
	11557	 1	 2.8	 0.5	 0.0	 1.26	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	11558	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 24	    1.10000	    0.90000;
	11559	 1	 -0.0	 -0.0	 0.0	 0.26	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	11560	 1	 -0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	11561	 1	 0.0	 0.0	 0.0	 77.597016	 0	    1.00000	    0.00000	 380.0	 24	    1.10000	    0.90000;
	11562	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	11563	 1	 17.02	 2.0	 0.0	 3.65	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	11564	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	11565	 1	 254.0	 74.3	 0.0	 54.48	 0	    1.00000	    0.00000	 380.0	 16	    1.10000	    0.90000;
	11566	 1	 -0.0	 0.0	 0.0	 6.51	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	11567	 1	 -0.0	 0.0	 0.0	 8.61	 0	    1.00000	    0.00000	 220.0	 8	    1.10000	    0.90000;
	11568	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	11569	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	11570	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	11571	 1	 0.3	 -97.2	 0.0	 0.07	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	11572	 1	 73.58	 48.6	 0.0	 2.87	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	11573	 1	 0.0	 0.0	 0.295058	 0.244119	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	11574	 1	 -0.0	 -0.0	 0.0	 7.99	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	11575	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	11576	 1	 47.55	 17.8	 0.0	 0.32	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	11577	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	11578	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	11579	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	11580	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	11581	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	11582	 1	 142.4	 20.0	 0.0	 2.42	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	11583	 1	 162.5	 42.7	 0.0	 12.79	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	11584	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	11585	 1	 41.88	 3.02	 0.0	 5.65	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	11586	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	11587	 1	 0.0	 -0.0	 0.0	 4.52	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	11588	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	11589	 1	 0.0	 0.0	 0.090774	 2.080444	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	11590	 1	 125.3	 7.7	 0.019458	 14.570542	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	11591	 1	 427.9	 145.8	 0.0	 40.72	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	11592	 1	 36.94	 11.0	 0.0	 0.52	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	11593	 1	 0.0	 0.0	 0.0	 8.77	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	11594	 1	 9.7	 1.4	 0.0	 11.34	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	11595	 1	 338.7	 52.5	 0.0	 11.36	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	11596	 1	 -0.0	 0.0	 0.15322	 5.97678	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	11597	 1	 3.2	 0.6	 0.0	 0.82	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	11598	 1	 -0.0	 -0.0	 0.0	 25.73	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	11599	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 23	    1.10000	    0.90000;
	11600	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	11601	 1	 52.46	 2.9	 0.0	 0.35	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	11602	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 23	    1.10000	    0.90000;
	11603	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	11604	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	11605	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	11606	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	11607	 1	 0.0	 -0.0	 0.0	 0.15	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	11608	 1	 0.0	 0.0	 0.0	 7.78	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	11609	 1	 9.21	 3.4	 0.0	 2.63	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	11610	 1	 30.35	 30.5	 0.0	 0.76	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	11611	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 23	    1.10000	    0.90000;
	11612	 1	 7.0	 1.0	 0.0	 4.05	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	11613	 1	 0.0	 0.0	 0.0	 1.55	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	11614	 1	 77.2	 11.0	 0.0	 9.22	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	11615	 1	 0.0	 -0.0	 0.0	 0.33	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	11616	 1	 0.0	 -0.0	 0.0	 7.73	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	11617	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	11618	 1	 -0.0	 8.3	 0.0	 10.19	 0	    1.00000	    0.00000	 150.0	 9	    1.20000	    0.80000;
	11619	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 22	    1.10000	    0.90000;
	11620	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	11621	 1	 -0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	11622	 1	 -0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	11623	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	11624	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	11625	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	11626	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	11627	 1	 -0.18	 -1.31	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	11628	 1	 35.14	 7.6	 0.0	 6.49	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	11629	 1	 0.0	 -0.0	 0.0	 2.74	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	11630	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	11631	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	11632	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	11633	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	11634	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	11635	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	11636	 1	 160.3	 89.7	 0.0	 47.28	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	11637	 1	 38.15	 23.6	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	11638	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	11639	 1	 -0.0	 0.0	 0.12	 20.1	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	11640	 1	 -0.0	 0.0	 0.0	 0.97	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	11641	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	11642	 1	 88.4	 25.2	 0.0	 12.9	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	11643	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	11644	 1	 0.3	 0.2	 0.0	 4.7	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	11645	 1	 36.84	 14.1	 0.0	 33.55	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	11646	 1	 60.07	 20.0	 0.0	 0.17	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	11647	 1	 -0.0	 -0.0	 0.0	 65.24	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	11648	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	11649	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	11650	 1	 0.0	 0.0	 0.232942	 35.845683	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	11651	 1	 17.52	 9.1	 0.0	 2.26	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	11652	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	11653	 1	 -0.67	 -2.78	 0.0	 11.64	 0	    1.00000	    0.00000	 220.0	 23	    1.10000	    0.90000;
	11654	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	11655	 1	 285.2	 65.3	 0.0	 11.28	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	11656	 1	 -0.0	 0.0	 0.0	 20.11	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	11657	 1	 1.5	 87.9	 0.529771	 7.297956	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	11658	 1	 -14.91	 -5.0	 0.0	 0.57	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	11659	 1	 0.0	 0.0	 0.733021	 192.153934	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	11660	 1	 0.0	 -0.0	 0.0	 42.81	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	11661	 1	 115.8	 29.3	 0.0	 4.31	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	11662	 1	 56.06	 17.0	 0.0	 2.4	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	11663	 1	 106.8	 22.2	 0.0	 0.97	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	11664	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	11665	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	11666	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	11667	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	11668	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	11669	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	11670	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	11671	 1	 0.0	 0.0	 0.361295	 2.568993	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	11672	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	11673	 1	 -35.74	 38.6	 0.0	 4.65	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	11674	 1	 100.9	 26.7	 0.0	 118.53	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	11675	 1	 38.44	 2.0	 0.0	 0.56	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	11676	 1	 -0.0	 -0.0	 0.0	 2.12	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	11677	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	11678	 1	 17.92	 5.8	 0.0	 0.84	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	11679	 1	 0.0	 0.0	 0.181549	 21.720889	 0	    1.00000	    0.00000	 220.0	 18	    1.20000	    0.80000;
	11680	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	11681	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	11682	 1	 -0.0	 0.0	 0.090774	 1.980444	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	11683	 1	 0.0	 0.0	 0.0	 3.86	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	11684	 1	 125.4	 17.8	 0.0	 4.02	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	11685	 1	 156.0	 60.7	 0.0	 1.52	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	11686	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 22	    1.10000	    0.90000;
	11687	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 22	    1.10000	    0.90000;
	11688	 1	 488.7	 184.7	 0.35476	 78.854076	 0	    1.00000	    0.00000	 380.0	 14	    1.10000	    0.90000;
	11689	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 22	    1.10000	    0.90000;
	11690	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 22	    1.10000	    0.90000;
	11691	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 22	    1.10000	    0.90000;
	11692	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 22	    1.10000	    0.90000;
	11693	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 22	    1.10000	    0.90000;
	11694	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 22	    1.10000	    0.90000;
	11695	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 22	    1.10000	    0.90000;
	11696	 1	 111.6	 8.9	 0.0	 16.19	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	11697	 1	 5.11	 1.3	 0.0	 0.8	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	11698	 1	 0.0	 -0.0	 0.0	 8.63	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	11699	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 7	    1.10000	    0.90000;
	11700	 1	 0.0	 0.0	 0.0	 0.22	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	11701	 1	 0.0	 0.0	 0.0	 59.88	 0	    1.00000	    0.00000	 380.0	 9	    1.20000	    0.80000;
	11702	 1	 0.0	 -0.0	 0.34087	 0.574879	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	11703	 1	 443.8	 172.1	 0.0	 52.54	 0	    1.00000	    0.00000	 380.0	 14	    1.10000	    0.90000;
	11704	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	11705	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	11706	 1	 3.3	 1.1	 0.0	 0.28	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	11707	 1	 0.0	 0.0	 0.0	 3.28	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	11708	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	11709	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	11710	 1	 -0.0	 -0.0	 0.0	 0.24	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	11711	 1	 0.0	 0.0	 0.0	 79.5	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	11712	 1	 21.72	 7.2	 0.0	 0.64	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	11713	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	11714	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	11715	 1	 0.0	 -0.0	 0.0	 48.74	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	11716	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	11717	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	11718	 1	 69.48	 19.7	 0.0	 22.1	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	11719	 1	 0.0	 0.0	 0.2527	 79.80215	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	11720	 1	 30.03	 10.0	 0.0	 1.11	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	11721	 1	 -0.0	 0.0	 0.0	 21.6	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	11722	 1	 237.9	 68.5	 0.0	 5.12	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	11723	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	11724	 1	 -0.2	 -0.96	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	11725	 1	 115.7	 10.7	 0.0	 19.1	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	11726	 1	 234.0	 13.1	 0.0	 51.03	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	11727	 1	 0.0	 0.0	 0.0	 0.59	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	11728	 1	 0.0	 -0.0	 0.0	 1.57	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	11729	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	11730	 1	 33.14	 20.5	 0.0	 0.54	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	11731	 1	 110.2	 15.7	 0.0	 1.11	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	11732	 1	 217.7	 164.6	 0.0	 11.88	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	11733	 1	 -0.0	 0.0	 0.12	 15.18	 0	    1.00000	    0.00000	 220.0	 21	    1.10000	    0.90000;
	11734	 1	 -1272.84	 -649.5	 0.0	 0.0	 0	    1.00000	    0.00000	 27.0	 3	    1.10000	    0.90000;
	11735	 1	 253.7	 85.0	 1.799271	 133.197518	 0	    1.00000	    0.00000	 380.0	 20	    1.20000	    0.80000;
	11736	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 23	    1.10000	    0.90000;
	11737	 1	 233.5	 151.0	 0.0	 35.31	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	11738	 1	 35.14	 1.8	 0.0	 6.12	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	11739	 1	 4.61	 1.7	 0.0	 0.47	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	11740	 1	 120.1	 17.1	 0.0	 0.08	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	11741	 1	 -0.0	 0.0	 0.0	 0.98	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	11742	 1	 -0.0	 -0.0	 0.0	 107.2	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	11743	 1	 62.7	 9.0	 0.0	 5.83	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	11744	 1	 0.0	 -8.1	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	11745	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	11746	 1	 -0.0	 0.0	 0.0	 0.27	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	11747	 1	 12.61	 7.8	 0.0	 2.42	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	11748	 1	 -0.0	 0.0	 0.0	 0.27	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	11749	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	11750	 1	 400.4	 23.6	 0.577149	 133.344695	 0	    1.00000	    0.00000	 380.0	 11	    1.10000	    0.90000;
	11751	 1	 18.22	 6.3	 0.0	 0.35	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	11752	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	11753	 1	 11.91	 3.3	 0.0	 6.84	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	11754	 1	 -0.0	 -0.0	 0.0	 1.91	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	11755	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 22	    1.10000	    0.90000;
	11756	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 22	    1.10000	    0.90000;
	11757	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 22	    1.10000	    0.90000;
	11758	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	11759	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	11760	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	11761	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	11762	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	11763	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	11764	 1	 0.0	 -0.0	 0.0	 9.68	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	11765	 1	 -0.0	 -0.0	 0.0	 0.35	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	11766	 1	 0.0	 0.0	 0.0	 0.52	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	11767	 1	 0.0	 -0.0	 0.458938	 18.186674	 0	    1.00000	    0.00000	 380.0	 13	    1.10000	    0.90000;
	11768	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	11769	 1	 -0.0	 -0.0	 0.0	 0.36	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	11770	 1	 0.0	 -0.0	 0.0	 0.76	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	11771	 1	 0.0	 -0.0	 0.0	 0.37	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	11772	 1	 135.7	 31.6	 0.0	 26.65	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	11773	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	11774	 1	 -0.0	 0.0	 0.0	 16.77	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	11775	 1	 14.92	 4.9	 0.0	 0.65	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	11776	 1	 81.99	 32.2	 0.0	 7.3	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	11777	 1	 13.9	 1.9	 0.0	 6.58	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	11778	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	11779	 1	 3.2	 1.5	 0.0	 0.95	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	11780	 1	 -0.0	 -0.0	 0.0	 0.35	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	11781	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	11782	 1	 36.84	 14.1	 0.0	 17.84	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	11783	 1	 -0.0	 -0.0	 0.0	 7.92	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	11784	 1	 40.04	 15.1	 0.0	 1.05	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	11785	 1	 149.63	 59.0	 0.0	 4.99	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	11786	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	11787	 1	 28.53	 11.5	 0.0	 0.72	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	11788	 1	 16.7	 2.4	 0.0	 2.64	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	11789	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	11790	 1	 -0.0	 -0.0	 0.0	 8.99	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	11791	 1	 9.41	 2.3	 0.0	 1.18	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	11792	 1	 0.0	 0.0	 0.0	 2.78	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	11793	 1	 0.0	 0.0	 0.0	 2.59	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	11794	 1	 1.8	 0.7	 0.0	 0.27	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	11795	 1	 14.22	 4.7	 0.0	 5.58	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	11796	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	11797	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	11798	 1	 -0.0	 0.0	 0.0	 4.32	 0	    1.00000	    0.00000	 150.0	 9	    1.20000	    0.80000;
	11799	 1	 0.0	 -0.0	 0.0	 0.11	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	11800	 1	 11.41	 4.4	 0.0	 0.12	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	11801	 1	 76.88	 16.4	 0.0	 6.61	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	11802	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	11803	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	11804	 1	 -0.0	 0.0	 0.0	 21.6	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	11805	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	11806	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	11807	 1	 0.0	 0.0	 0.0	 4.28	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	11808	 1	 8.31	 3.0	 0.0	 0.3	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	11809	 1	 156.6	 16.9	 0.0	 12.26	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	11810	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	11811	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	11812	 1	 254.9	 71.4	 0.0	 0.7	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	11813	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	11814	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	11815	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	11816	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	11817	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	11818	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	11819	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	11820	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	11821	 1	 12.91	 4.2	 0.0	 0.35	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	11822	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 7	    1.10000	    0.90000;
	11823	 1	 -0.0	 -0.0	 0.0	 215.65	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	11824	 1	 -0.0	 -0.0	 0.0	 24.17	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	11825	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	11826	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	11827	 1	 -0.17	 -1.82	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	11828	 1	 83.99	 6.0	 0.0	 65.12	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	11829	 1	 -0.0	 -0.0	 0.0	 4.22	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	11830	 1	 37.84	 12.3	 0.039146	 9.70064	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	11831	 1	 -0.0	 0.0	 0.0	 5.73	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	11832	 1	 12.11	 5.1	 0.0	 6.68	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	11833	 1	 27.9	 4.0	 0.0	 4.85	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	11834	 1	 70.38	 27.5	 0.0	 0.77	 0	    1.00000	    0.00000	 110.0	 3	    1.10000	    0.90000;
	11835	 1	 93.8	 15.9	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 24	    1.10000	    0.90000;
	11836	 1	 0.0	 -0.0	 0.0	 0.07	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	11837	 1	 123.8	 40.2	 0.078704	 3.951296	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	11838	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	11839	 1	 0.0	 -0.0	 0.348979	 0.528572	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	11840	 1	 -880.44	 -449.03	 0.0	 0.0	 0	    1.00000	    0.00000	 27.0	 3	    1.10000	    0.90000;
	11841	 1	 3.3	 1.1	 0.009871	 0.810129	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	11842	 1	 -0.0	 -0.0	 0.0	 61.795782	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	11843	 1	 25.0	 3.6	 0.0	 2.96	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	11844	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	11845	 1	 0.0	 0.0	 0.0	 66.29	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	11846	 1	 42.35	 13.5	 0.0	 0.32	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	11847	 1	 19.02	 6.0	 0.0	 1.45	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	11848	 1	 53.56	 18.8	 0.0	 1.45	 0	    1.00000	    0.00000	 220.0	 20	    1.10000	    0.90000;
	11849	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	11850	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 10.6	 1	    1.10000	    0.90000;
	11851	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	11852	 1	 0.0	 0.0	 0.0	 0.01	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	11853	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	11854	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	11855	 1	 28.63	 8.8	 0.0	 0.67	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	11856	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	11857	 1	 14.32	 2.2	 0.0	 1.26	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	11858	 1	 69.18	 9.5	 0.0	 3.67	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	11859	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 6.3	 1	    1.10000	    0.90000;
	11860	 1	 170.8	 70.4	 0.0	 7.23	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	11861	 1	 -0.0	 -0.0	 0.0	 9.54	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	11862	 1	 -19.32	 6.4	 0.0	 0.23	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	11863	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 23	    1.10000	    0.90000;
	11864	 1	 36.9	 5.3	 0.0	 3.7	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	11865	 1	 135.2	 70.6	 0.0	 9.37	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	11866	 1	 56.76	 13.4	 0.0	 1.18	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	11867	 1	 0.0	 0.0	 0.0	 3.22	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	11868	 1	 41.75	 7.4	 0.0	 18.54	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	11869	 1	 -0.0	 -0.0	 0.0	 44.66	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	11870	 1	 174.2	 54.3	 0.0	 23.93	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	11871	 1	 3.8	 1.3	 0.0	 1.11	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	11872	 1	 0.0	 -0.0	 0.0	 0.48	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	11873	 1	 0.0	 0.0	 0.0	 16.37	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	11874	 1	 68.48	 42.7	 0.0	 6.37	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	11875	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	11876	 1	 14.2	 2.0	 0.0	 1.34	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	11877	 1	 6.21	 1.5	 0.0	 1.42	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	11878	 1	 44.65	 -1.6	 0.019811	 15.410189	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	11879	 1	 130.0	 18.5	 0.0	 0.62	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	11880	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	11881	 1	 6.91	 -11.1	 0.0	 0.67	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	11882	 1	 35.94	 22.3	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	11883	 1	 -0.67	 -3.25	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.20000	    0.80000;
	11884	 1	 92.9	 13.2	 0.0	 4.15	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	11885	 1	 35.14	 11.0	 0.0	 0.48	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	11886	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	11887	 1	 -0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	11888	 1	 0.0	 0.0	 1.052336	 8.691699	 0	    1.00000	    0.00000	 380.0	 5	    1.20000	    0.80000;
	11889	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 8	    1.10000	    0.90000;
	11890	 1	 9.7	 1.4	 0.0	 5.11	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	11891	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 9	    1.10000	    0.90000;
	11892	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	11893	 1	 0.0	 -0.0	 0.0	 17.69	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	11894	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	11895	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	11896	 1	 316.1	 45.0	 0.0	 15.2	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	11897	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 8	    1.10000	    0.90000;
	11898	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 8	    1.10000	    0.90000;
	11899	 1	 0.0	 -0.0	 0.0	 0.32	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	11900	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	11901	 1	 0.0	 -0.0	 0.469372	 91.718414	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	11902	 1	 -0.0	 -0.0	 0.22542	 1.27215	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	11903	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 6.3	 1	    1.10000	    0.90000;
	11904	 1	 -0.0	 -0.0	 0.229027	 1.548687	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	11905	 1	 0.0	 0.0	 0.0	 5.56	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	11906	 1	 2.7	 -0.1	 0.038314	 0.201686	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	11907	 1	 13.21	 6.6	 0.0	 1.19	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	11908	 1	 -0.0	 -0.0	 0.096728	 2.243272	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	11909	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	11910	 1	 132.1	 13.2	 0.0	 6.9	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	11911	 1	 25.0	 3.6	 0.0	 1.31	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	11912	 1	 0.0	 0.0	 0.0	 2.71	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	11913	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	11914	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	11915	 1	 82.1	 29.1	 0.0	 0.4	 0	    1.00000	    0.00000	 110.0	 23	    1.10000	    0.90000;
	11916	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	11917	 1	 0.0	 0.0	 0.0	 16.11	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	11918	 1	 -0.0	 -0.0	 0.0	 1.74	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	11919	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	11920	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 9.0	 1	    1.10000	    0.90000;
	11921	 1	 59.9	 8.5	 0.0	 0.88	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	11922	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	11923	 1	 68.18	 16.1	 0.0	 3.35	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	11924	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	11925	 1	 71.98	 34.1	 0.0	 7.65	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	11926	 1	 35.84	 13.0	 0.0	 2.26	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	11927	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	11928	 1	 -0.0	 0.0	 0.0	 0.03	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	11929	 1	 0.0	 0.0	 0.0	 4.13	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	11930	 1	 87.9	 29.3	 0.0	 1.21	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	11931	 1	 59.27	 13.3	 0.039187	 3.630407	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	11932	 1	 56.7	 8.0	 0.0	 4.42	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	11933	 1	 0.0	 0.0	 0.0	 5.46	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	11934	 1	 -0.0	 -0.0	 0.0	 30.39	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	11935	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	11936	 1	 19.02	 6.3	 0.0	 0.2	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	11937	 1	 200.6	 28.6	 0.0	 0.29	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	11938	 1	 73.98	 -7.4	 0.705428	 109.0541	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	11939	 1	 29.23	 -49.9	 0.0	 5.49	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	11940	 1	 111.1	 35.6	 0.0	 0.53	 0	    1.00000	    0.00000	 110.0	 3	    1.10000	    0.90000;
	11941	 1	 -0.0	 0.0	 0.038239	 0.171761	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	11942	 1	 0.0	 -0.0	 0.0	 26.46	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	11943	 1	 -0.0	 -0.0	 0.0	 1.25	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	11944	 1	 164.4	 23.4	 0.0	 10.01	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	11945	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	11946	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	11947	 1	 -0.01	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 8	    1.10000	    0.90000;
	11948	 1	 80.49	 7.3	 0.0	 1.81	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	11949	 1	 -0.0	 -0.0	 0.0	 9.49	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	11950	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	11951	 1	 -0.0	 0.0	 0.170749	 0.347709	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	11952	 1	 -0.0	 0.0	 0.0	 23.91	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	11953	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	11954	 1	 8.91	 2.5	 0.0	 0.47	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	11955	 1	 -0.0	 0.0	 0.0	 8.1	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	11956	 1	 -0.0	 0.0	 0.0	 1.4	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	11957	 1	 34.44	 27.0	 0.0	 0.34	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	11958	 1	 0.0	 0.0	 0.0	 0.23	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	11959	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	11960	 1	 19.4	 2.8	 0.0	 3.46	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	11961	 1	 0.0	 -0.0	 0.039166	 8.300834	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	11962	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	11963	 1	 47.4	 6.7	 0.0	 3.82	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	11964	 1	 67.6	 9.6	 0.0	 2.95	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	11965	 1	 -0.0	 -0.0	 0.0	 2.67	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	11966	 1	 242.4	 46.7	 0.0	 75.67	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	11967	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 6.3	 1	    1.10000	    0.90000;
	11968	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	11969	 1	 -0.0	 0.0	 0.0	 50.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	11970	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 6.3	 1	    1.10000	    0.90000;
	11971	 1	 10.01	 2.0	 0.0	 0.73	 0	    1.00000	    0.00000	 150.0	 7	    1.10000	    0.90000;
	11972	 1	 16.7	 2.4	 0.0	 15.54	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	11973	 1	 56.26	 18.5	 0.0	 1.01	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	11974	 1	 11.01	 4.0	 0.0	 0.73	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	11975	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	11976	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	11977	 1	 169.93	 42.88	 0.0	 9.84	 0	    1.00000	    0.00000	 220.0	 17	    1.10000	    0.90000;
	11978	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	11979	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	11980	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	11981	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	11982	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	11983	 1	 303.5	 56.2	 0.0	 21.07	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	11984	 1	 3.8	 1.9	 0.0	 0.72	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	11985	 1	 27.53	 12.1	 0.0	 0.88	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	11986	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	11987	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 15.75	 1	    1.10000	    0.90000;
	11988	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	11989	 1	 111.36	 27.44	 0.0	 2.59	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	11990	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	11991	 1	 35.1	 5.0	 0.0	 1.57	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	11992	 1	 -0.0	 -0.0	 0.0	 4.47	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	11993	 1	 -0.0	 -0.0	 0.0	 1.28	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	11994	 1	 21.52	 5.1	 0.0	 0.25	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	11995	 1	 0.0	 0.0	 0.0	 0.15	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	11996	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 9	    1.10000	    0.90000;
	11997	 1	 125.3	 34.6	 0.0	 4.36	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	11998	 1	 -0.0	 0.0	 0.113823	 1.255147	 0	    1.00000	    0.00000	 380.0	 14	    1.10000	    0.90000;
	11999	 1	 0.0	 -0.0	 0.0	 0.12	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	12000	 1	 -0.0	 0.0	 0.0	 29.73	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	12001	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 15.75	 1	    1.10000	    0.90000;
	12002	 1	 0.0	 0.0	 0.233623	 -0.194686	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	12003	 1	 -0.0	 -0.0	 0.097109	 0.522891	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	12004	 1	 2.1	 396.2	 0.407504	 115.720413	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	12005	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	12006	 1	 -34.04	 -2.0	 0.0	 197.23	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	12007	 1	 -0.0	 -0.0	 0.0	 1.28	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	12008	 1	 76.59	 16.2	 0.0	 21.54	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	12009	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 23	    1.10000	    0.90000;
	12010	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 23	    1.10000	    0.90000;
	12011	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 23	    1.10000	    0.90000;
	12012	 1	 -0.0	 0.0	 0.099501	 82.133595	 0	    1.00000	    0.00000	 380.0	 18	    1.20000	    0.80000;
	12013	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	12014	 1	 -0.0	 0.0	 0.0	 1.2	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	12015	 1	 0.0	 -0.0	 0.090774	 5.709044	 0	    1.00000	    0.00000	 220.0	 18	    1.20000	    0.80000;
	12016	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	12017	 1	 0.0	 0.0	 0.0	 1.22	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	12018	 1	 0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	12019	 1	 31.63	 7.5	 0.0	 21.91	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	12020	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	12021	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	12022	 1	 -0.0	 0.0	 0.0	 0.39	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	12023	 1	 -12.15	 -0.84	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	12024	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	12025	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	12026	 1	 23.03	 14.3	 0.0	 16.88	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	12027	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	12028	 1	 2.8	 14.6	 0.0	 113.059828	 0	    1.00000	    0.00000	 380.0	 9	    1.20000	    0.80000;
	12029	 1	 -0.0	 0.0	 0.706809	 0.700443	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	12030	 1	 22.12	 8.0	 0.0	 0.53	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	12031	 1	 -0.0	 0.0	 0.0	 0.79	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	12032	 1	 13.11	 3.6	 0.0	 0.38	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	12033	 1	 10.81	 3.6	 0.0	 0.38	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	12034	 1	 26.93	 9.6	 0.0	 1.41	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	12035	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 7	    1.10000	    0.90000;
	12036	 1	 41.8	 5.9	 0.0	 10.67	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	12037	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	12038	 1	 0.0	 -0.0	 0.189785	 19.193314	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	12039	 1	 0.0	 -0.0	 0.0	 6.59	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	12040	 1	 72.38	 23.0	 0.0	 0.28	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	12041	 1	 -0.0	 0.0	 0.211407	 6.615121	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	12042	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	12043	 1	 73.58	 -13.1	 0.0	 7.58	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	12044	 1	 0.0	 -0.0	 0.0	 2.97	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	12045	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	12046	 1	 0.0	 -0.0	 0.0	 3.33	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	12047	 1	 0.0	 -0.0	 0.150629	 -0.150629	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	12048	 1	 99.6	 22.9	 0.0	 15.02	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	12049	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 20	    1.10000	    0.90000;
	12050	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 14.4	 1	    1.10000	    0.90000;
	12051	 1	 54.96	 62.6	 0.296391	 5.573008	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	12052	 1	 120.2	 30.7	 0.0	 9.98	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	12053	 1	 -0.2	 -1.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	12054	 1	 0.0	 0.0	 0.0	 0.32	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	12055	 1	 0.0	 -0.0	 0.0	 11.38	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	12056	 1	 2.0	 1.0	 0.0	 1.0	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	12057	 1	 0.0	 -0.0	 0.0	 0.84	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	12058	 1	 -0.0	 0.0	 0.563882	 82.938191	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	12059	 1	 -0.18	 -1.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	12060	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 6.3	 1	    1.10000	    0.90000;
	12061	 1	 20.2	 2.9	 0.0	 5.89	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	12062	 1	 -134.35	 -6.5	 0.0	 3.38	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	12063	 1	 165.9	 49.6	 0.0	 6.13	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	12064	 1	 169.6	 98.3	 0.0	 27.8	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	12065	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	12066	 1	 0.18	 87.5	 0.0	 3.94	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	12067	 1	 11.8	 1.7	 0.0	 6.98	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	12068	 1	 202.0	 28.7	 0.0	 0.36	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	12069	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	12070	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	12071	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	12072	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	12073	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	12074	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	12075	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	12076	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	12077	 1	 3.8	 3.8	 0.0	 0.95	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	12078	 1	 83.39	 16.5	 0.0	 16.43	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	12079	 1	 7.5	 173.3	 0.962911	 57.817695	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	12080	 1	 0.0	 0.0	 0.0	 65.93	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	12081	 1	 0.0	 -0.0	 0.038816	 1.131184	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	12082	 1	 207.9	 25.4	 0.0	 1.75	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	12083	 1	 2.5	 0.5	 0.0	 0.8	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	12084	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	12085	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	12086	 1	 -0.0	 -0.0	 0.0	 10.28	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	12087	 1	 63.77	 39.5	 0.0	 1.12	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	12088	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	12089	 1	 0.0	 -0.0	 0.0	 1.57	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	12090	 1	 5.31	 2.3	 0.0	 0.93	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	12091	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	12092	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	12093	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	12094	 1	 -0.0	 -0.0	 0.041633	 77.581311	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	12095	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	12096	 1	 -0.0	 0.0	 0.0	 24.67	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	12097	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	12098	 1	 135.7	 19.3	 0.0	 3.58	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	12099	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 9	    1.10000	    0.90000;
	12100	 1	 92.7	 -5.6	 0.2527	 35.620175	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	12101	 1	 0.0	 0.0	 0.019665	 0.420335	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	12102	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	12103	 1	 65.5	 9.3	 0.0	 7.21	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	12104	 1	 26.33	 7.6	 0.0	 0.32	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	12105	 1	 0.0	 0.0	 0.0	 0.55	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	12106	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	12107	 1	 12.11	 5.5	 0.0	 1.19	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	12108	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	12109	 1	 102.8	 30.8	 0.0	 2.66	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	12110	 1	 -0.0	 0.0	 0.0	 54.41	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	12111	 1	 0.0	 -0.0	 0.0	 0.32	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	12112	 1	 131.9	 50.6	 0.0	 79.02	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	12113	 1	 -0.0	 0.0	 0.0	 1.5	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	12114	 1	 0.0	 0.0	 0.0	 5.67	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	12115	 1	 1.9	 1.3	 0.0	 0.43	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	12116	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	12117	 1	 -0.0	 -0.0	 0.0	 0.31	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	12118	 1	 118.1	 20.2	 0.0	 1.47	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	12119	 1	 370.2	 107.7	 0.0	 81.59	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	12120	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	12121	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	12122	 1	 0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	12123	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	12124	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	12125	 1	 5.11	 2.5	 0.0	 0.19	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	12126	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	12127	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	12128	 1	 44.75	 27.7	 0.0	 1.14	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	12129	 1	 0.0	 -0.0	 0.0	 8.13	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	12130	 1	 69.28	 23.8	 0.0	 2.56	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	12131	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	12132	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	12133	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	12134	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	12135	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	12136	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	12137	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	12138	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	12139	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	12140	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	12141	 1	 216.8	 30.7	 0.0	 58.2	 0	    1.00000	    0.00000	 380.0	 16	    1.10000	    0.90000;
	12142	 1	 0.0	 0.0	 0.710082	 -0.042148	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	12143	 1	 0.4	 182.7	 0.233255	 122.325059	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	12144	 1	 0.0	 0.0	 0.0	 8.88	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	12145	 1	 24.12	 9.8	 0.0	 0.04	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	12146	 1	 196.1	 32.1	 0.0	 3.86	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	12147	 1	 9.61	 2.5	 0.0	 0.37	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	12148	 1	 3.0	 -0.0	 0.236576	 6.812853	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	12149	 1	 0.0	 -0.0	 0.0	 1.56	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	12150	 1	 39.04	 13.1	 0.0	 3.22	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	12151	 1	 -0.24	 -23.15	 0.0	 26.49	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	12152	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	12153	 1	 0.0	 -0.0	 0.0	 69.23	 0	    1.00000	    0.00000	 380.0	 23	    1.20000	    0.80000;
	12154	 1	 19.4	 2.8	 0.0	 6.62	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	12155	 1	 -0.0	 0.0	 0.0	 10.21	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	12156	 1	 69.38	 22.5	 0.0	 0.67	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	12157	 1	 7.0	 1.0	 0.0	 4.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	12158	 1	 255.9	 128.3	 0.0	 54.58	 0	    1.00000	    0.00000	 380.0	 17	    1.10000	    0.90000;
	12159	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	12160	 1	 -0.0	 -0.0	 0.0	 65.73	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	12161	 1	 0.0	 0.0	 1.147648	 -0.504228	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	12162	 1	 316.7	 46.1	 0.0	 46.23	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	12163	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	12164	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	12165	 1	 0.0	 -0.0	 0.0	 24.67	 0	    1.00000	    0.00000	 380.0	 1	    1.20000	    0.80000;
	12166	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	12167	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	12168	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	12169	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	12170	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	12171	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	12172	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	12173	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	12174	 1	 15.62	 2.8	 0.0	 0.71	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	12175	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	12176	 1	 120.6	 35.7	 0.0	 15.36	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	12177	 1	 21.82	 6.3	 0.0	 2.01	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	12178	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.5	 1	    1.10000	    0.90000;
	12179	 1	 15.62	 5.7	 0.0	 0.17	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	12180	 1	 107.9	 35.9	 0.0	 5.48	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	12181	 1	 40.05	 20.0	 0.0	 7.45	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	12182	 1	 0.0	 -0.0	 0.0	 25.28	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	12183	 1	 0.0	 0.0	 0.0	 1.6	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	12184	 1	 57.66	 6.1	 0.0	 1.77	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	12185	 1	 0.0	 0.0	 0.059718	 0.860282	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	12186	 1	 -0.0	 -0.0	 0.0	 0.62	 0	    1.00000	    0.00000	 380.0	 14	    1.10000	    0.90000;
	12187	 1	 114.42	 23.58	 0.0	 46.99	 0	    1.00000	    0.00000	 380.0	 13	    1.10000	    0.90000;
	12188	 1	 14.32	 5.5	 0.0	 3.15	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	12189	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	12190	 1	 9.41	 5.6	 0.0	 0.03	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	12191	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 22	    1.10000	    0.90000;
	12192	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 22	    1.10000	    0.90000;
	12193	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 22	    1.10000	    0.90000;
	12194	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 22	    1.10000	    0.90000;
	12195	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	12196	 1	 -0.0	 0.0	 0.0	 36.43	 0	    1.00000	    0.00000	 380.0	 1	    1.20000	    0.80000;
	12197	 1	 -0.0	 -0.0	 0.0	 17.3	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	12198	 1	 -0.12	 -1.31	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 8	    1.20000	    0.80000;
	12199	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 15.75	 1	    1.10000	    0.90000;
	12200	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	12201	 1	 -0.0	 -0.0	 0.0	 0.3	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	12202	 1	 0.0	 0.0	 0.0	 2.56	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	12203	 1	 16.02	 5.1	 0.0	 8.6	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	12204	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	12205	 1	 -29.84	 -2.96	 0.0	 0.28	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	12206	 1	 -0.0	 0.0	 0.0	 1.06	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	12207	 1	 0.0	 0.0	 0.0	 6.52	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	12208	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	12209	 1	 394.41	 96.3	 0.233064	 1.955491	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	12210	 1	 112.7	 14.5	 0.0	 1.24	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	12211	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	12212	 1	 82.99	 25.9	 0.0	 0.23	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	12213	 1	 5.01	 2.0	 0.0	 0.6	 0	    1.00000	    0.00000	 110.0	 23	    1.10000	    0.90000;
	12214	 1	 -0.0	 -0.0	 0.0	 5.81	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	12215	 1	 -0.0	 0.0	 0.0	 0.18	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	12216	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	12217	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	12218	 1	 0.0	 0.0	 0.0	 14.35	 0	    1.00000	    0.00000	 380.0	 8	    1.20000	    0.80000;
	12219	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	12220	 1	 31.03	 10.3	 0.0	 0.89	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	12221	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	12222	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	12223	 1	 -0.0	 0.0	 0.0	 15.0	 0	    1.00000	    0.00000	 220.0	 3	    1.20000	    0.80000;
	12224	 1	 -0.0	 0.0	 0.0	 0.05	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	12225	 1	 59.67	 9.2	 0.0	 18.03	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	12226	 1	 13.92	 3.8	 0.0	 1.26	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	12227	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	12228	 1	 0.0	 -0.0	 0.0	 0.93	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	12229	 1	 0.0	 -0.0	 0.361302	 2.888987	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	12230	 1	 0.0	 -0.0	 0.0	 8.18	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	12231	 1	 99.3	 23.6	 0.0	 1.77	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	12232	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	12233	 1	 -0.0	 0.0	 0.0	 0.15	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	12234	 1	 -0.0	 -0.0	 0.0	 0.14	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	12235	 1	 33.44	 11.0	 0.0	 4.0	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	12236	 1	 11.2	 1.6	 0.0	 2.09	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	12237	 1	 10.31	 2.3	 0.0	 1.11	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	12238	 1	 43.45	 15.9	 0.0196	 1.8004	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	12239	 1	 86.7	 41.5	 0.0	 18.57	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	12240	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	12241	 1	 -0.0	 0.0	 1.373975	 28.45227	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	12242	 1	 26.73	 10.8	 0.0	 0.43	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	12243	 1	 -0.0	 -0.0	 0.0	 0.36	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	12244	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	12245	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	12246	 1	 0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	12247	 1	 13.92	 8.9	 0.0	 2.65	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	12248	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 19.0	 1	    1.10000	    0.90000;
	12249	 1	 19.32	 7.0	 0.0	 0.44	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	12250	 1	 -0.0	 -0.0	 0.531454	 0.176647	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	12251	 1	 -0.0	 0.0	 0.0	 1.12	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	12252	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	12253	 1	 0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	12254	 1	 18.02	 6.5	 0.0	 2.19	 0	    1.00000	    0.00000	 110.0	 19	    1.20000	    0.80000;
	12255	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	12256	 1	 313.75	 96.8	 0.0	 5.67	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	12257	 1	 74.78	 26.4	 0.0	 2.42	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	12258	 1	 -0.0	 0.0	 0.278602	 31.723346	 0	    1.00000	    0.00000	 380.0	 19	    1.20000	    0.80000;
	12259	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	12260	 1	 0.0	 -0.0	 0.0	 3.03	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	12261	 1	 41.45	 56.2	 0.0	 6.55	 0	    1.00000	    0.00000	 220.0	 17	    1.10000	    0.90000;
	12262	 1	 -0.0	 0.0	 0.0	 0.29	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	12263	 1	 -0.0	 -8.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	12264	 1	 82.39	 14.4	 0.0	 13.37	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	12265	 1	 0.0	 -0.0	 0.057346	 7.362654	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	12266	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	12267	 1	 89.44	 63.66	 0.0	 2.6	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	12268	 1	 8.91	 5.1	 0.0	 0.42	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	12269	 1	 0.0	 0.0	 0.0	 9.41	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	12270	 1	 145.2	 21.4	 0.0	 1.09	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	12271	 1	 174.7	 31.0	 0.23738	 27.44968	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	12272	 1	 0.0	 -0.0	 0.0	 33.298535	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	12273	 1	 637.92	 139.57	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	12274	 1	 257.58	 -303.11	 0.290737	 64.242856	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	12275	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	12276	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	12277	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	12278	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	12279	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	12280	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	12281	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	12282	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	12283	 1	 -0.0	 0.0	 0.0	 0.3	 0	    1.00000	    0.00000	 110.0	 23	    1.10000	    0.90000;
	12284	 1	 29.75	 27.1	 0.077948	 5.312052	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	12285	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 6.3	 1	    1.10000	    0.90000;
	12286	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 10.6	 1	    1.10000	    0.90000;
	12287	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 15.0	 1	    1.10000	    0.90000;
	12288	 1	 133.7	 19.0	 0.0	 4.05	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	12289	 1	 74.18	 14.6	 0.0	 11.71	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	12290	 1	 44.05	 14.4	 0.0	 0.92	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	12291	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 15.75	 1	    1.10000	    0.90000;
	12292	 1	 12.6	 1.8	 0.0	 10.9	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	12293	 1	 19.2	 9.3	 0.0	 128.079082	 0	    1.00000	    0.00000	 380.0	 9	    1.20000	    0.80000;
	12294	 1	 80.29	 -4.1	 0.0	 0.43	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	12295	 1	 29.83	 14.4	 0.0	 8.89	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	12296	 1	 19.4	 2.8	 0.0	 1.61	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	12297	 1	 2.5	 1.3	 0.0	 0.62	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	12298	 1	 0.0	 0.0	 0.12	 8.51	 0	    1.00000	    0.00000	 220.0	 21	    1.10000	    0.90000;
	12299	 1	 192.1	 33.4	 0.039803	 6.200197	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	12300	 1	 191.2	 16.4	 0.0	 17.99	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	12301	 1	 14.86	 2.99	 0.0	 1.24	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	12302	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	12303	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	12304	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	12305	 1	 155.1	 39.9	 0.0	 6.37	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	12306	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	12307	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	12308	 1	 0.0	 0.0	 0.0	 3.77	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	12309	 1	 0.0	 -0.0	 0.0	 8.82	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	12310	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 20	    1.10000	    0.90000;
	12311	 1	 -0.0	 0.0	 0.0	 0.72	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	12312	 1	 50.96	 17.0	 0.0	 2.66	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	12313	 1	 -0.0	 0.0	 0.135493	 21.11062	 0	    1.00000	    0.00000	 380.0	 21	    1.20000	    0.80000;
	12314	 1	 2.9	 1.0	 0.0	 0.39	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	12315	 1	 27.9	 4.0	 0.0	 2.23	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	12316	 1	 2.8	 1.0	 0.0	 0.74	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	12317	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	12318	 1	 -0.0	 -0.0	 0.0	 3.97	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	12319	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	12320	 1	 126.54	 29.1	 0.0	 12.55	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	12321	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 7	    1.10000	    0.90000;
	12322	 1	 -0.0	 -0.0	 0.213044	 4.836956	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	12323	 1	 -0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	12324	 1	 6.31	 2.5	 0.0	 0.16	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	12325	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	12326	 1	 12.01	 4.0	 0.0	 0.72	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	12327	 1	 69.7	 9.9	 0.0	 6.07	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	12328	 1	 66.4	 9.4	 0.0	 4.35	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	12329	 1	 77.99	 19.3	 0.0	 3.04	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	12330	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	12331	 1	 0.0	 0.0	 0.0	 1.23	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	12332	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	12333	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	12334	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	12335	 1	 81.19	 23.4	 0.0	 52.6	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	12336	 1	 -0.0	 -0.0	 0.0	 42.32	 0	    1.00000	    0.00000	 380.0	 1	    1.20000	    0.80000;
	12337	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	12338	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	12339	 1	 0.0	 0.0	 0.223313	 34.22321	 0	    1.00000	    0.00000	 380.0	 12	    1.20000	    0.80000;
	12340	 1	 14.72	 5.3	 0.0	 0.91	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	12341	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	12342	 1	 0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	12343	 1	 216.3	 -6.9	 0.0	 2.44	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	12344	 1	 15.02	 7.0	 0.0	 0.67	 0	    1.00000	    0.00000	 110.0	 23	    1.10000	    0.90000;
	12345	 1	 0.0	 -0.0	 0.318467	 8.72115	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	12346	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	12347	 1	 -0.0	 -0.0	 0.0	 33.61	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	12348	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	12349	 1	 60.87	 5.0	 0.176606	 -0.077172	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	12350	 1	 0.0	 0.0	 0.019758	 4.380242	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	12351	 1	 0.0	 0.0	 0.0	 2.28	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	12352	 1	 -0.0	 -0.0	 0.0	 0.22	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	12353	 1	 0.0	 -0.0	 0.0	 17.92	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	12354	 1	 0.0	 -0.0	 0.0	 1.32	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	12355	 1	 0.0	 -0.0	 0.310722	 0.351065	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	12356	 1	 60.2	 8.6	 0.0	 1.79	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	12357	 1	 -0.0	 -0.0	 0.0	 61.61	 0	    1.00000	    0.00000	 154.0	 1	    1.20000	    0.80000;
	12358	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	12359	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	12360	 1	 231.2	 103.5	 0.0	 10.91	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	12361	 1	 115.03	 2.21	 0.0	 10.42	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	12362	 1	 96.8	 76.1	 0.245933	 14.261622	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	12363	 1	 213.6	 50.1	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	12364	 1	 286.3	 94.1	 0.468335	 42.319235	 0	    1.00000	    0.00000	 380.0	 13	    1.10000	    0.90000;
	12365	 1	 107.9	 15.3	 0.0	 99.52	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	12366	 1	 4.2	 0.6	 0.0	 2.04	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	12367	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 15.75	 1	    1.10000	    0.90000;
	12368	 1	 100.8	 32.3	 0.0	 7.16	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	12369	 1	 -0.0	 -0.0	 0.0	 37.57	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	12370	 1	 70.88	 43.9	 0.0	 3.65	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	12371	 1	 33.74	 7.4	 0.039535	 0.630465	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	12372	 1	 58.26	 16.9	 0.0	 0.95	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	12373	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	12374	 1	 8.21	 2.7	 0.0	 0.35	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	12375	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	12376	 1	 -0.0	 -0.0	 0.0	 4.05	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	12377	 1	 18.42	 7.0	 0.038628	 0.661372	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	12378	 1	 79.39	 24.7	 0.0	 198.67	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	12379	 1	 15.82	 9.5	 0.0	 0.02	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	12380	 1	 0.0	 0.0	 0.0	 0.54	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	12381	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	12382	 1	 0.0	 0.0	 0.0	 0.28	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	12383	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.5	 1	    1.10000	    0.90000;
	12384	 1	 101.9	 20.0	 0.0	 22.64	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	12385	 1	 40.75	 12.5	 0.0	 2.61	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	12386	 1	 0.0	 -0.0	 0.0	 14.38	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	12387	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	12388	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	12389	 1	 64.57	 23.1	 0.0	 1.88	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	12390	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	12391	 1	 -0.0	 -0.0	 0.0	 19.08	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	12392	 1	 2.8	 1.0	 0.0	 0.56	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	12393	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 10.5	 1	    1.20000	    0.80000;
	12394	 1	 33.84	 11.1	 0.0	 1.57	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	12395	 1	 -0.0	 0.0	 0.233802	 1.535165	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	12396	 1	 -0.24	 -25.61	 0.0	 11.32	 0	    1.00000	    0.00000	 220.0	 3	    1.20000	    0.80000;
	12397	 1	 169.9	 41.9	 0.039317	 0.820683	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	12398	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 10.5	 1	    1.10000	    0.90000;
	12399	 1	 41.05	 12.5	 0.019459	 0.140541	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	12400	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	12401	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	12402	 1	 18.52	 6.1	 0.0	 0.84	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	12403	 1	 29.13	 9.6	 0.0	 0.76	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	12404	 1	 11.01	 3.3	 0.0	 0.67	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	12405	 1	 -0.0	 -0.0	 0.168001	 0.399333	 0	    1.00000	    0.00000	 220.0	 21	    1.10000	    0.90000;
	12406	 1	 0.0	 -0.0	 0.056554	 12.862872	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	12407	 1	 188.2	 23.4	 0.0	 17.95	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	12408	 1	 68.6	 9.8	 0.0	 117.06	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	12409	 1	 19.72	 6.5	 0.0	 0.2	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	12410	 1	 0.0	 -0.0	 0.0	 1.15	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	12411	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	12412	 1	 -0.0	 0.0	 0.0	 2.11	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	12413	 1	 -0.0	 -0.0	 0.037576	 3.542424	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	12414	 1	 -0.0	 0.0	 0.0	 -0.17	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	12415	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	12416	 1	 0.0	 0.0	 0.0	 1.67	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	12417	 1	 0.0	 0.0	 0.0	 6.501239	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	12418	 1	 15.12	 5.0	 0.0	 0.53	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	12419	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	12420	 1	 50.2	 7.1	 0.0	 1.78	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	12421	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 6.3	 1	    1.10000	    0.90000;
	12422	 1	 -0.19	 -17.71	 0.0	 28.98	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	12423	 1	 374.4	 85.5	 0.458551	 99.79698	 0	    1.00000	    0.00000	 380.0	 11	    1.10000	    0.90000;
	12424	 1	 133.0	 18.9	 0.0	 18.79	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	12425	 1	 -0.0	 0.0	 0.0	 0.1	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	12426	 1	 8.81	 5.5	 0.0	 2.83	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	12427	 1	 35.04	 12.0	 0.0	 1.07	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	12428	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	12429	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	12430	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	12431	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	12432	 1	 -0.0	 -0.0	 0.343783	 27.652613	 0	    1.00000	    0.00000	 380.0	 20	    1.10000	    0.90000;
	12433	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	12434	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	12435	 1	 380.8	 62.8	 0.0	 7.11	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	12436	 1	 59.07	 23.4	 0.0	 21.88	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	12437	 1	 139.3	 19.9	 0.0	 0.56	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	12438	 1	 0.0	 0.0	 0.0	 0.01	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	12439	 1	 31.44	 12.4	 0.0	 2.89	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	12440	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	12441	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	12442	 1	 332.8	 92.2	 0.0	 29.46	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	12443	 1	 0.0	 -0.0	 0.0	 0.66	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	12444	 1	 -7.6	 28.6	 0.0	 0.19	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	12445	 1	 33.64	 4.5	 0.0	 0.4	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	12446	 1	 -0.0	 0.0	 0.0	 1.1	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	12447	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	12448	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	12449	 1	 286.1	 89.3	 0.0	 8.89	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	12450	 1	 111.08	 -44.35	 0.0	 7.94	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	12451	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	12452	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 8	    1.10000	    0.90000;
	12453	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 8	    1.10000	    0.90000;
	12454	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 8	    1.10000	    0.90000;
	12455	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	12456	 1	 -26.03	 -0.84	 0.0	 0.1	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	12457	 1	 0.0	 -0.0	 0.039626	 0.610374	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	12458	 1	 -0.0	 -0.0	 0.0	 0.85	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	12459	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	12460	 1	 35.84	 10.9	 0.0	 0.11	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	12461	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	12462	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	12463	 1	 13.91	 10.1	 0.0	 0.31	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	12464	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	12465	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	12466	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	12467	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	12468	 1	 24.22	 -1.06	 0.0	 2.92	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	12469	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	12470	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	12471	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	12472	 1	 -0.0	 -0.0	 0.582185	 0.836226	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	12473	 1	 55.56	 34.4	 0.0	 2.57	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	12474	 1	 277.9	 143.1	 0.0	 0.69	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	12475	 1	 0.0	 0.0	 0.332077	 31.17749	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	12476	 1	 -0.0	 0.0	 0.550522	 8.61491	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	12477	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	12478	 1	 51.06	 7.4	 0.0	 2.49	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	12479	 1	 0.0	 -0.0	 0.0	 2.02	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	12480	 1	 -0.59	 -0.86	 0.0	 0.14	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	12481	 1	 24.13	 10.8	 0.0	 15.2	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	12482	 1	 -0.0	 -0.0	 0.112964	 -0.054136	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	12483	 1	 38.84	 8.5	 0.0	 7.31	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	12484	 1	 0.0	 -0.0	 0.0	 1.97	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	12485	 1	 216.2	 75.3	 0.0	 2.74	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	12486	 1	 -0.0	 0.0	 0.0	 19.54	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	12487	 1	 0.0	 -0.0	 0.073728	 5.986272	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	12488	 1	 0.0	 0.0	 0.208917	 0.724607	 0	    1.00000	    0.00000	 380.0	 9	    1.20000	    0.80000;
	12489	 1	 0.0	 -0.0	 0.0	 2.78	 0	    1.00000	    0.00000	 220.0	 21	    1.10000	    0.90000;
	12490	 1	 -0.0	 -0.0	 0.0	 0.73	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	12491	 1	 19.4	 2.8	 0.0	 3.63	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	12492	 1	 299.5	 48.7	 0.098259	 18.211741	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	12493	 1	 55.96	 30.0	 0.438961	 55.322489	 0	    1.00000	    0.00000	 380.0	 21	    1.20000	    0.80000;
	12494	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 22	    1.10000	    0.90000;
	12495	 1	 0.0	 0.0	 0.0	 8.35	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	12496	 1	 10.5	 7.32	 0.0	 0.24	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	12497	 1	 0.0	 -0.0	 0.0	 2.46	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	12498	 1	 -0.0	 -0.0	 0.0	 3.01	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	12499	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	12500	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	12501	 1	 -0.0	 -0.0	 0.0	 1.15	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	12502	 1	 18.02	 5.9	 0.059068	 2.260932	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	12503	 1	 -0.0	 -0.0	 0.0	 0.42	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	12504	 1	 -0.17	 -1.82	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	12505	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	12506	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	12507	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 0.4	 1	    1.10000	    0.90000;
	12508	 1	 0.0	 -0.0	 0.0	 0.13	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	12509	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	12510	 1	 36.54	 22.6	 0.0	 0.04	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	12511	 1	 -0.0	 0.0	 0.040091	 29.754956	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	12512	 1	 44.45	 7.68	 0.0	 17.83	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	12513	 1	 -0.0	 -0.0	 0.047978	 5.881618	 0	    1.00000	    0.00000	 220.0	 8	    1.10000	    0.90000;
	12514	 1	 371.6	 100.4	 0.231295	 3.706891	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	12515	 1	 0.0	 0.0	 0.0	 21.62	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	12516	 1	 0.0	 0.0	 0.087808	 3.044992	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	12517	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	12518	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	12519	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	12520	 1	 -0.19	 -1.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	12521	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	12522	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	12523	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	12524	 1	 0.0	 0.0	 0.0	 1.35	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	12525	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	12526	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	12527	 1	 98.6	 27.1	 0.0	 42.45	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	12528	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	12529	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	12530	 1	 0.0	 0.0	 0.0	 13.01	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	12531	 1	 235.97	 34.52	 0.0	 7.15	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	12532	 1	 23.93	 7.9	 0.0	 0.88	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	12533	 1	 9.51	 3.4	 0.0	 0.73	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	12534	 1	 -0.0	 0.0	 0.123474	 4.29472	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	12535	 1	 38.84	 14.2	 0.0	 3.5	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	12536	 1	 236.44	 -98.55	 0.0	 1.31	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	12537	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	12538	 1	 -14.89	 -4.43	 0.0	 0.63	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	12539	 1	 0.0	 0.0	 0.0	 15.91	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	12540	 1	 10.11	 0.0	 0.0	 1.92	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	12541	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	12542	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	12543	 1	 97.6	 33.9	 0.0	 6.47	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	12544	 1	 6.41	 2.2	 0.0	 52.07	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	12545	 1	 -0.59	 -2.63	 0.0	 0.14	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	12546	 1	 -0.0	 0.0	 0.0	 0.67	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	12547	 1	 37.44	 9.1	 0.0	 7.87	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	12548	 1	 -8.02	 -15.14	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	12549	 1	 -0.0	 -0.0	 0.0	 3.76	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	12550	 1	 0.0	 -0.0	 0.0	 8.78	 0	    1.00000	    0.00000	 220.0	 8	    1.10000	    0.90000;
	12551	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	12552	 1	 93.6	 -43.5	 0.0	 33.51	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	12553	 1	 140.7	 10.4	 0.0	 2.51	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	12554	 1	 13.51	 5.6	 0.0	 0.86	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	12555	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	12556	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	12557	 1	 8.3	 1.2	 0.0	 2.86	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	12558	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	12559	 1	 101.7	 59.8	 0.098539	 36.661461	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	12560	 1	 104.3	 12.3	 0.0	 8.29	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	12561	 1	 89.08	 26.9	 0.0	 4.68	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	12562	 1	 0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	12563	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	12564	 1	 -0.0	 -0.0	 0.0	 1.82	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	12565	 1	 13.72	 8.5	 0.0	 0.06	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	12566	 1	 0.0	 0.0	 0.0	 4.5	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	12567	 1	 -0.0	 -0.0	 0.0	 5.98	 0	    1.00000	    0.00000	 220.0	 21	    1.10000	    0.90000;
	12568	 1	 84.0	 19.4	 0.010011	 4.66	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	12569	 1	 20.9	 3.0	 0.0	 7.77	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	12570	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	12571	 1	 0.0	 -3.7	 0.0	 0.25	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	12572	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	12573	 1	 0.0	 0.0	 0.0	 45.57454	 0	    1.00000	    0.00000	 380.0	 20	    1.10000	    0.90000;
	12574	 1	 0.0	 0.0	 0.0	 3.32	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	12575	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	12576	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	12577	 1	 76.99	 -0.7	 0.0	 1.06	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	12578	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	12579	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 21.0	 1	    1.10000	    0.90000;
	12580	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	12581	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	12582	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	12583	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	12584	 1	 0.0	 0.0	 0.117152	 0.132373	 0	    1.00000	    0.00000	 220.0	 20	    1.10000	    0.90000;
	12585	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	12586	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	12587	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	12588	 1	 12.31	 4.1	 0.0	 0.32	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	12589	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	12590	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	12591	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	12592	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	12593	 1	 0.0	 0.0	 0.0	 0.31	 0	    1.00000	    0.00000	 110.0	 1	    1.10000	    0.90000;
	12594	 1	 81.89	 19.9	 0.0	 5.1	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	12595	 1	 72.68	 24.3	 0.0	 3.12	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	12596	 1	 -0.0	 -0.0	 0.0	 0.85	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	12597	 1	 187.64	 31.94	 0.0	 4.75	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	12598	 1	 92.4	 6.3	 0.0	 4.32	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	12599	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 22	    1.10000	    0.90000;
	12600	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 22	    1.10000	    0.90000;
	12601	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 22	    1.10000	    0.90000;
	12602	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	12603	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	12604	 1	 0.0	 0.0	 0.0	 0.64	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	12605	 1	 111.4	 15.9	 0.0	 19.05	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	12606	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	12607	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	12608	 1	 10.0	 1.4	 0.0	 5.74	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	12609	 1	 20.9	 3.0	 0.0	 3.48	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	12610	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	12611	 1	 5.01	 1.8	 0.0	 0.77	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	12612	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 9	    1.10000	    0.90000;
	12613	 1	 21.22	 9.9	 0.0	 4.64	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	12614	 1	 -0.0	 0.0	 0.0	 15.0	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	12615	 1	 -0.0	 -0.0	 0.0	 0.63	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	12616	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	12617	 1	 -0.0	 -0.0	 0.0	 1.42	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	12618	 1	 0.0	 0.0	 0.176855	 3.419803	 0	    1.00000	    0.00000	 220.0	 19	    1.10000	    0.90000;
	12619	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	12620	 1	 60.9	 8.7	 0.0	 1.34	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	12621	 1	 562.3	 159.1	 0.245655	 7.565523	 0	    1.00000	    0.00000	 220.0	 14	    1.10000	    0.90000;
	12622	 1	 0.0	 0.0	 2.226096	 44.76755	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	12623	 1	 0.0	 -0.0	 0.0	 2.64	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	12624	 1	 22.02	 7.7	 0.0	 0.17	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	12625	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 14.0	 1	    1.10000	    0.90000;
	12626	 1	 214.8	 30.6	 0.0	 3.65	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	12627	 1	 221.9	 86.3	 0.0	 2.18	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	12628	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	12629	 1	 0.0	 0.0	 0.0	 18.22	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	12630	 1	 -0.0	 0.0	 0.0	 0.88	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	12631	 1	 0.0	 0.0	 0.0	 237.54	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	12632	 1	 0.0	 -0.0	 0.379262	 96.912184	 0	    1.00000	    0.00000	 380.0	 21	    1.10000	    0.90000;
	12633	 1	 -0.0	 -0.0	 0.0	 7.06	 0	    1.00000	    0.00000	 330.0	 24	    1.10000	    0.90000;
	12634	 1	 172.6	 24.6	 0.0	 11.39	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	12635	 1	 1.9	 1.3	 0.0	 0.92	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	12636	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	12637	 1	 15.32	 3.5	 0.0	 0.69	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	12638	 1	 38.04	 15.0	 0.0	 0.47	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	12639	 1	 15.42	 4.4	 0.0	 10.84	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	12640	 1	 0.0	 -0.0	 0.019788	 3.740212	 0	    1.00000	    0.00000	 220.0	 19	    1.10000	    0.90000;
	12641	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 9	    1.10000	    0.90000;
	12642	 1	 -18.27	 -12.99	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	12643	 1	 -0.0	 0.0	 0.235924	 0.173397	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	12644	 1	 0.0	 0.0	 0.0	 1.71	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	12645	 1	 40.54	 3.6	 0.0	 1.88	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	12646	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 23	    1.10000	    0.90000;
	12647	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	12648	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	12649	 1	 13.92	 6.9	 0.0	 0.79	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	12650	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	12651	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	12652	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	12653	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	12654	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	12655	 1	 0.0	 0.01	 0.0	 22.04	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	12656	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	12657	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 6.3	 1	    1.10000	    0.90000;
	12658	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	12659	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	12660	 1	 72.4	 10.3	 0.0	 2.54	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	12661	 1	 59.87	 19.9	 0.0	 0.32	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	12662	 1	 293.2	 87.4	 0.0	 26.36	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	12663	 1	 9.91	 3.3	 0.0	 0.82	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	12664	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	12665	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 7	    1.10000	    0.90000;
	12666	 1	 0.0	 0.0	 0.0	 72.57192	 0	    1.00000	    0.00000	 380.0	 20	    1.20000	    0.80000;
	12667	 1	 1.6	 0.8	 0.0	 0.79	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	12668	 1	 27.83	 -2.6	 0.0	 6.07	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	12669	 1	 0.0	 0.0	 0.0	 6.29	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	12670	 1	 9.7	 1.4	 0.0	 2.96	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	12671	 1	 -0.0	 -0.0	 0.0	 8.89	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	12672	 1	 13.62	 5.2	 0.03955	 0.19045	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	12673	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	12674	 1	 27.53	 17.0	 0.0	 0.03	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	12675	 1	 317.9	 55.4	 0.0	 37.61	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	12676	 1	 0.0	 0.0	 0.0	 0.51	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	12677	 1	 -33.74	 11.1	 0.0	 1.87	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	12678	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 10.5	 1	    1.20000	    0.80000;
	12679	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	12680	 1	 12.31	 7.4	 0.316013	 6.664212	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	12681	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	12682	 1	 0.0	 0.0	 0.0	 80.66	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	12683	 1	 0.0	 -0.0	 0.0	 0.43	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	12684	 1	 171.3	 13.9	 0.0	 59.09	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	12685	 1	 3.8	 3.8	 0.0	 0.08	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	12686	 1	 72.4	 10.3	 0.0	 6.82	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	12687	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	12688	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 15.75	 1	    1.10000	    0.90000;
	12689	 1	 65.2	 9.3	 0.0	 3.89	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	12690	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	12691	 1	 245.51	 9.17	 0.0	 24.25	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	12692	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	12693	 1	 26.93	 9.6	 0.0	 1.09	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	12694	 1	 0.0	 -0.0	 0.0	 4.82	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	12695	 1	 0.0	 0.0	 0.0	 1.96	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	12696	 1	 -0.0	 -0.0	 0.0	 6.62	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	12697	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	12698	 1	 -0.0	 0.0	 0.0	 2.05	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	12699	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	12700	 1	 -0.0	 -0.0	 0.117033	 -0.117033	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	12701	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	12702	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	12703	 1	 0.0	 0.0	 0.35622	 3.44315	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	12704	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	12705	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	12706	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	12707	 1	 0.0	 -0.0	 0.347111	 22.210024	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	12708	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 22	    1.10000	    0.90000;
	12709	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 23	    1.10000	    0.90000;
	12710	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	12711	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 22	    1.10000	    0.90000;
	12712	 1	 0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 22	    1.10000	    0.90000;
	12713	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 22	    1.10000	    0.90000;
	12714	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 22	    1.10000	    0.90000;
	12715	 1	 0.0	 -0.0	 0.297442	 67.102132	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	12716	 1	 347.1	 87.2	 0.0	 88.35	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	12717	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	12718	 1	 55.7	 7.9	 0.0	 0.76	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	12719	 1	 77.99	 18.5	 0.059094	 5.220755	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	12720	 1	 159.4	 -7.3	 0.0	 3.3	 0	    1.00000	    0.00000	 220.0	 3	    1.20000	    0.80000;
	12721	 1	 -0.0	 0.0	 0.0	 12.69	 0	    1.00000	    0.00000	 220.0	 12	    1.10000	    0.90000;
	12722	 1	 101.8	 20.2	 0.0	 0.91	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	12723	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	12724	 1	 0.0	 -0.0	 0.0	 10.83	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	12725	 1	 -0.0	 0.0	 0.0	 1.35	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	12726	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	12727	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	12728	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	12729	 1	 0.0	 -0.0	 0.0	 0.45	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	12730	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	12731	 1	 -0.0	 0.0	 0.0	 5.72	 0	    1.00000	    0.00000	 220.0	 21	    1.10000	    0.90000;
	12732	 1	 -0.0	 0.0	 0.0	 13.3	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	12733	 1	 76.69	 23.3	 0.0	 0.3	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	12734	 1	 -70.45	 -35.14	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	12735	 1	 -8.4	 -17.5	 0.058341	 1.591659	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	12736	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	12737	 1	 -26.03	 -2.9	 0.157541	 15.981844	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	12738	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	12739	 1	 0.0	 -0.0	 0.0	 12.68	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	12740	 1	 0.0	 0.0	 0.0	 13.49	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	12741	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	12742	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	12743	 1	 -0.0	 0.0	 0.049279	 37.690721	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	12744	 1	 253.4	 111.3	 0.415544	 10.153713	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	12745	 1	 136.0	 36.1	 0.0	 6.07	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	12746	 1	 57.56	 21.1	 0.0	 1.46	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	12747	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	12748	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 6.3	 1	    1.10000	    0.90000;
	12749	 1	 -0.0	 -0.0	 0.0	 4.26	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	12750	 1	 277.1	 37.0	 0.0	 21.03	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	12751	 1	 98.61	 50.3	 0.0	 0.17	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	12752	 1	 0.0	 -0.0	 0.172712	 3.166074	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	12753	 1	 -0.0	 0.0	 0.0	 0.54	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	12754	 1	 0.0	 -0.0	 0.0	 117.47	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	12755	 1	 -0.0	 0.0	 0.0	 2.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	12756	 1	 0.0	 0.0	 0.090774	 8.200444	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	12757	 1	 74.18	 27.3	 0.0	 25.25	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	12758	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	12759	 1	 0.0	 0.0	 0.0	 2.64	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	12760	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	12761	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	12762	 1	 282.0	 21.5	 0.0	 21.3	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	12763	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	12764	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	12765	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	12766	 1	 0.0	 -0.0	 0.0	 1.2	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	12767	 1	 -20.32	 6.7	 0.0	 0.2	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	12768	 1	 62.27	 23.8	 0.0	 0.13	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	12769	 1	 130.2	 88.8	 0.0	 0.08	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	12770	 1	 -0.0	 -0.0	 0.153185	 22.892346	 0	    1.00000	    0.00000	 380.0	 9	    1.20000	    0.80000;
	12771	 1	 -0.0	 0.0	 0.0	 15.67	 0	    1.00000	    0.00000	 380.0	 1	    1.20000	    0.80000;
	12772	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	12773	 1	 163.2	 31.9	 0.0	 4.9	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	12774	 1	 29.13	 9.5	 0.0	 0.98	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	12775	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	12776	 1	 25.18	 3.37	 0.0	 1.01	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	12777	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	12778	 1	 0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	12779	 1	 0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	12780	 1	 0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	12781	 1	 0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	12782	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	12783	 1	 62.7	 9.0	 0.0	 8.23	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	12784	 1	 42.25	 16.6	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	12785	 1	 0.0	 0.0	 0.0	 142.05	 0	    1.00000	    0.00000	 380.0	 14	    1.10000	    0.90000;
	12786	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	12787	 1	 20.9	 3.0	 0.0	 2.09	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	12788	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	12789	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	12790	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	12791	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	12792	 1	 10.31	 4.3	 0.0	 0.67	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	12793	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	12794	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	12795	 1	 163.5	 35.6	 0.0	 4.59	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	12796	 1	 4.4	 2.2	 0.0	 1.09	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	12797	 1	 162.49	 45.11	 0.0	 5.38	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	12798	 1	 0.0	 0.0	 0.0	 21.22	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	12799	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	12800	 1	 44.55	 7.5	 0.0	 0.6	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	12801	 1	 125.2	 17.8	 0.0	 2.5	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	12802	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	12803	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	12804	 1	 -16.42	 5.4	 0.0	 0.67	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	12805	 1	 5.51	 1.3	 0.0	 0.09	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	12806	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	12807	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	12808	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	12809	 1	 0.0	 0.0	 0.0	 61.44	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	12810	 1	 0.0	 -0.0	 0.0	 67.98	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	12811	 1	 62.7	 9.0	 0.0	 1.12	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	12812	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	12813	 1	 129.8	 67.2	 0.0	 2.57	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	12814	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	12815	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	12816	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 10.6	 1	    1.10000	    0.90000;
	12817	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	12818	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	12819	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	12820	 1	 226.7	 39.3	 0.0	 0.99	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	12821	 1	 -0.12	 -1.74	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 8	    1.20000	    0.80000;
	12822	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	12823	 1	 -0.0	 0.0	 0.297267	 36.522277	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	12824	 1	 34.54	 15.4	 0.0	 29.82	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	12825	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	12826	 1	 45.45	 14.9	 0.0	 1.12	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	12827	 1	 1.3	 0.5	 0.0	 0.39	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	12828	 1	 9.91	 3.3	 0.0	 0.98	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	12829	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 6.6	 1	    1.10000	    0.90000;
	12830	 1	 0.0	 0.0	 0.262086	 66.559018	 0	    1.00000	    0.00000	 380.0	 19	    1.10000	    0.90000;
	12831	 1	 69.88	 19.3	 0.0	 1.63	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	12832	 1	 37.94	 15.6	 0.435676	 1.98509	 0	    1.00000	    0.00000	 380.0	 21	    1.20000	    0.80000;
	12833	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	12834	 1	 62.77	 5.7	 0.0	 2.41	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	12835	 1	 0.0	 0.0	 0.0	 28.523869	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	12836	 1	 -0.0	 0.0	 0.0	 13.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	12837	 1	 -0.0	 0.0	 0.0	 1.31	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	12838	 1	 0.0	 0.0	 0.039248	 13.490752	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	12839	 1	 334.5	 135.2	 0.040246	 7.609754	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	12840	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	12841	 1	 0.0	 0.0	 0.0	 2.29	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	12842	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	12843	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	12844	 1	 -0.0	 0.0	 0.0	 29.01	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	12845	 1	 0.0	 0.0	 0.0	 90.93	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	12846	 1	 -0.0	 -0.0	 0.0	 4.26	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	12847	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	12848	 1	 34.9	 5.0	 0.0	 7.79	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	12849	 1	 131.78	 18.51	 0.059161	 58.650838	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	12850	 1	 188.6	 164.9	 0.0	 21.03	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	12851	 1	 -20.38	 -7.04	 0.0	 0.65	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	12852	 1	 168.13	 36.31	 0.0	 88.12	 0	    1.00000	    0.00000	 380.0	 13	    1.10000	    0.90000;
	12853	 1	 0.0	 -0.0	 0.0	 0.65	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	12854	 1	 -0.15	 -152.82	 0.394814	 24.589755	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	12855	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	12856	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	12857	 1	 42.65	 18.2	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	12858	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	12859	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	12860	 1	 0.0	 -0.0	 0.52227	 11.818844	 0	    1.00000	    0.00000	 220.0	 18	    1.20000	    0.80000;
	12861	 1	 0.0	 0.0	 0.0	 2.81	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	12862	 1	 155.05	 39.56	 0.0	 6.27	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	12863	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	12864	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	12865	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 15.75	 1	    1.10000	    0.90000;
	12866	 1	 0.0	 -0.0	 0.037734	 20.842266	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	12867	 1	 0.0	 -0.0	 0.0	 20.75	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	12868	 1	 5.5	 0.8	 0.0	 0.9	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	12869	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	12870	 1	 -0.0	 -0.0	 0.0	 6.52	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	12871	 1	 0.0	 0.0	 0.0	 5.01	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	12872	 1	 20.02	 15.0	 0.0	 0.14	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	12873	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 6.3	 1	    1.10000	    0.90000;
	12874	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 22	    1.10000	    0.90000;
	12875	 1	 89.3	 10.0	 0.0	 9.62	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	12876	 1	 0.0	 0.0	 0.0	 0.3	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	12877	 1	 82.59	 23.4	 0.0	 6.65	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	12878	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	12879	 1	 0.0	 0.0	 0.0	 2.67	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	12880	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	12881	 1	 0.0	 0.0	 0.0	 3.1	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	12882	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	12883	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	12884	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	12885	 1	 -0.0	 0.0	 0.0	 0.15	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	12886	 1	 0.0	 0.0	 0.0	 1.01	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	12887	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	12888	 1	 40.34	 15.9	 0.0	 6.02	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	12889	 1	 -8.21	 -2.4	 0.039039	 0.870721	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	12890	 1	 -0.0	 0.0	 0.0	 11.22	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	12891	 1	 3.7	 1.3	 0.0	 0.48	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	12892	 1	 124.5	 -6.0	 0.0	 1.91	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	12893	 1	 0.0	 -0.0	 0.0	 3.9	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	12894	 1	 0.0	 -0.0	 0.19108	 3.37892	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	12895	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	12896	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	12897	 1	 -0.0	 -0.0	 0.0	 89.82	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	12898	 1	 -20.12	 6.6	 0.0	 0.85	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	12899	 1	 29.43	 0.7	 0.056538	 0.952885	 0	    1.00000	    0.00000	 110.0	 3	    1.10000	    0.90000;
	12900	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	12901	 1	 0.0	 -0.0	 0.0	 0.02	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	12902	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	12903	 1	 23.53	 8.5	 0.0	 1.28	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	12904	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	12905	 1	 15.32	 5.0	 0.0	 0.49	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	12906	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	12907	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	12908	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	12909	 1	 3.5	 2.7	 0.0	 0.39	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	12910	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	12911	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	12912	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	12913	 1	 0.0	 -0.0	 0.0	 2.13	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	12914	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	12915	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	12916	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	12917	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	12918	 1	 126.3	 109.2	 0.0	 54.97	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	12919	 1	 100.4	 1.4	 0.0	 5.71	 0	    1.00000	    0.00000	 220.0	 20	    1.10000	    0.90000;
	12920	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	12921	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	12922	 1	 -0.0	 -0.0	 0.0	 0.04	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	12923	 1	 12.11	 -1.7	 0.059355	 18.920645	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	12924	 1	 -0.0	 0.0	 0.0	 3.79	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	12925	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	12926	 1	 66.27	 19.3	 0.0	 12.94	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	12927	 1	 25.0	 3.6	 0.0	 3.77	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	12928	 1	 35.04	 20.0	 0.0	 2.49	 0	    1.00000	    0.00000	 220.0	 21	    1.10000	    0.90000;
	12929	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	12930	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	12931	 1	 8.11	 1.4	 0.0	 1.47	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	12932	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	12933	 1	 61.97	 38.4	 0.505136	 4.390101	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	12934	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	12935	 1	 -0.0	 -0.0	 0.0	 0.93	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	12936	 1	 105.8	 53.6	 0.0	 6.27	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	12937	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	12938	 1	 0.0	 0.0	 0.0	 1.72	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	12939	 1	 0.0	 -0.0	 0.0	 31.05	 0	    1.00000	    0.00000	 380.0	 7	    1.10000	    0.90000;
	12940	 1	 57.46	 15.3	 0.0	 4.37	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	12941	 1	 -0.0	 0.0	 0.0	 25.67	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	12942	 1	 45.35	 28.1	 0.0	 1.9	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	12943	 1	 0.0	 -0.0	 0.0	 0.47	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	12944	 1	 -0.0	 0.0	 0.0	 0.12	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	12945	 1	 279.7	 4.6	 0.0	 3.77	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	12946	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 9.0	 1	    1.10000	    0.90000;
	12947	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	12948	 1	 21.02	 12.4	 0.0	 2.96	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	12949	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	12950	 1	 61.98	 39.2	 0.0	 5.1	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	12951	 1	 81.79	 10.8	 0.0	 10.84	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	12952	 1	 30.03	 15.0	 0.0	 2.49	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	12953	 1	 19.02	 3.8	 0.0	 4.55	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	12954	 1	 54.66	 18.6	 0.0	 3.04	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	12955	 1	 43.05	 25.0	 0.0	 0.02	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	12956	 1	 20.62	 10.7	 0.0	 0.14	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	12957	 1	 76.6	 10.9	 0.0	 6.82	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	12958	 1	 -0.21	 -1.04	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	12959	 1	 71.76	 11.37	 0.0	 0.0	 0	    1.00000	    0.00000	 110.0	 24	    1.10000	    0.90000;
	12960	 1	 18.62	 3.6	 0.0	 1.14	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	12961	 1	 58.77	 19.5	 0.234954	 12.084205	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	12962	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 9	    1.20000	    0.80000;
	12963	 1	 201.8	 71.2	 0.233209	 14.925376	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	12964	 1	 22.42	 29.5	 0.0	 0.08	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	12965	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 8	    1.10000	    0.90000;
	12966	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	12967	 1	 9.7	 1.4	 0.0	 4.91	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	12968	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	12969	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 8	    1.10000	    0.90000;
	12970	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 8	    1.10000	    0.90000;
	12971	 1	 25.73	 9.3	 0.0	 1.49	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	12972	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	12973	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	12974	 1	 120.0	 17.1	 0.0	 0.04	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	12975	 1	 0.0	 -0.0	 0.0	 63.59	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	12976	 1	 -0.0	 -0.0	 0.019913	 -0.019913	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	12977	 1	 -0.0	 0.0	 0.0	 30.31	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	12978	 1	 7.71	 2.4	 0.0	 6.93	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	12979	 1	 -0.0	 0.0	 0.0	 15.04	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	12980	 1	 45.25	 19.1	 0.0	 1.89	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	12981	 1	 0.0	 0.0	 0.0	 0.17	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	12982	 1	 7.61	 6.3	 0.0	 0.1	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	12983	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 15.0	 1	    1.10000	    0.90000;
	12984	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	12985	 1	 199.1	 23.3	 0.030559	 2.07	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	12986	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	12987	 1	 292.4	 -228.7	 0.0	 106.08	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	12988	 1	 1.8	 0.8	 0.0	 0.98	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	12989	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	12990	 1	 8.81	 2.2	 0.0	 4.78	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	12991	 1	 26.23	 9.5	 0.0	 0.65	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	12992	 1	 11.51	 3.8	 0.0	 0.53	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	12993	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	12994	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	12995	 1	 -0.0	 -0.0	 0.0	 15.18	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	12996	 1	 128.8	 54.5	 0.0	 24.74	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	12997	 1	 22.83	 8.0	 0.0	 3.71	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	12998	 1	 0.0	 0.0	 0.0	 17.77	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	12999	 1	 -29.73	 23.6	 0.0	 11.75	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	13000	 1	 126.21	 -7.73	 0.0	 6.2	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	13001	 1	 -0.0	 -0.0	 0.0	 0.36	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	13002	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 15.75	 1	    1.10000	    0.90000;
	13003	 1	 0.0	 -0.0	 0.2364	 -0.027	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	13004	 1	 23.53	 9.6	 0.020379	 3.689621	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	13005	 1	 179.6	 25.6	 0.0	 149.28	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	13006	 1	 3.8	 -12.7	 0.0	 1.42	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	13007	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	13008	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	13009	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	13010	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 10.5	 1	    1.20000	    0.80000;
	13011	 1	 -0.0	 0.0	 0.11625	 2.64375	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	13012	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	13013	 1	 -0.0	 0.0	 0.0	 6.59	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	13014	 1	 -0.0	 0.0	 0.041073	 2.799464	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	13015	 1	 14.72	 6.7	 0.0	 0.32	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	13016	 1	 80.59	 5.2	 0.0	 7.77	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	13017	 1	 151.56	 -314.2	 0.0	 60.91	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	13018	 1	 487.2	 116.7	 0.0	 56.29	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	13019	 1	 31.03	 8.9	 0.0	 0.14	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	13020	 1	 -0.0	 -0.0	 0.0	 23.68	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	13021	 1	 31.21	 -13.87	 0.0	 0.32	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	13022	 1	 22.02	 4.4	 0.0	 4.83	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	13023	 1	 47.95	 17.2	 0.0	 7.91	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	13024	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	13025	 1	 -0.0	 0.0	 0.0	 0.42	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	13026	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	13027	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	13028	 1	 373.0	 131.1	 0.038265	 4.041735	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	13029	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	13030	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	13031	 1	 203.6	 19.81	 0.0	 15.46	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	13032	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	13033	 1	 285.2	 61.4	 0.0	 26.04	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	13034	 1	 101.2	 -2.9	 0.0	 0.51	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	13035	 1	 0.3	 1.5	 0.0	 0.1	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	13036	 1	 0.0	 -0.0	 0.27075	 22.54135	 0	    1.00000	    0.00000	 380.0	 18	    1.20000	    0.80000;
	13037	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	13038	 1	 0.0	 0.0	 0.0	 1.55	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	13039	 1	 89.9	 29.3	 0.0	 6.77	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	13040	 1	 12.02	 3.6	 0.0	 0.47	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	13041	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	13042	 1	 82.19	 15.6	 0.0	 0.43	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	13043	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	13044	 1	 15.7	 2.2	 0.0	 2.88	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	13045	 1	 37.34	 12.1	 0.078064	 5.711936	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	13046	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	13047	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	13048	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	13049	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	13050	 1	 0.0	 -0.0	 0.0	 0.78	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	13051	 1	 0.0	 -0.0	 0.25741	 6.654316	 0	    1.00000	    0.00000	 220.0	 18	    1.20000	    0.80000;
	13052	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	13053	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	13054	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	13055	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	13056	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 8	    1.10000	    0.90000;
	13057	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	13058	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	13059	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	13060	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	13061	 1	 221.92	 101.15	 0.230538	 107.407491	 0	    1.00000	    0.00000	 380.0	 13	    1.10000	    0.90000;
	13062	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	13063	 1	 0.0	 0.0	 0.0	 0.39	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	13064	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	13065	 1	 21.9	 3.1	 0.0	 4.94	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	13066	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	13067	 1	 -0.0	 0.0	 0.0	 44.95	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	13068	 1	 75.3	 7.1	 0.0	 0.59	 0	    1.00000	    0.00000	 110.0	 23	    1.10000	    0.90000;
	13069	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	13070	 1	 -0.0	 -0.0	 0.0	 1.05	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	13071	 1	 91.6	 27.1	 0.0	 10.95	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	13072	 1	 21.32	 7.2	 0.0	 1.2	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	13073	 1	 26.33	 10.3	 0.0	 1.11	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	13074	 1	 0.0	 -0.0	 0.0	 2.24	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	13075	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 6.3	 1	    1.10000	    0.90000;
	13076	 1	 -0.0	 0.0	 0.0	 12.42	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	13077	 1	 0.0	 0.0	 0.0	 1.52	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	13078	 1	 113.7	 22.3	 0.0	 15.55	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	13079	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	13080	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	13081	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	13082	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	13083	 1	 0.0	 -0.0	 0.0	 1.91	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	13084	 1	 20.02	 12.4	 0.0	 0.03	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	13085	 1	 23.7	 3.4	 0.0	 4.27	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	13086	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	13087	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 10.6	 1	    1.10000	    0.90000;
	13088	 1	 -0.94	 -6.39	 0.0	 1.76	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	13089	 1	 1.5	 0.3	 0.0	 1.54	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	13090	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 15.75	 1	    1.10000	    0.90000;
	13091	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 22	    1.10000	    0.90000;
	13092	 1	 0.0	 -0.0	 0.0	 18.82	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	13093	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	13094	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	13095	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	13096	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 10.6	 1	    1.10000	    0.90000;
	13097	 1	 208.71	 62.99	 0.0	 3.45	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	13098	 1	 1.3	 -0.0	 0.0	 0.06	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	13099	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 8	    1.10000	    0.90000;
	13100	 1	 19.4	 2.8	 0.0	 11.38	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	13101	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	13102	 1	 -0.0	 0.0	 0.0	 0.2	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	13103	 1	 -0.0	 -0.0	 0.16572	 -0.637052	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	13104	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	13105	 1	 -0.68	 -2.44	 0.0	 0.02	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	13106	 1	 7.41	 2.4	 0.0	 2.23	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	13107	 1	 0.0	 0.0	 0.178531	 0.831142	 0	    1.00000	    0.00000	 220.0	 20	    1.10000	    0.90000;
	13108	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	13109	 1	 6.01	 2.2	 0.0	 0.82	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	13110	 1	 410.3	 91.6	 0.0	 13.25	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	13111	 1	 69.18	 35.1	 0.0	 12.59	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	13112	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	13113	 1	 20.22	 7.3	 0.0	 0.31	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	13114	 1	 -0.57	 -1.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	13115	 1	 -0.0	 0.0	 0.0	 2.29	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	13116	 1	 2.0	 0.3	 0.0	 1.02	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	13117	 1	 207.4	 44.3	 0.237333	 18.722	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	13118	 1	 0.0	 -0.0	 0.0	 4.6	 0	    1.00000	    0.00000	 220.0	 15	    1.10000	    0.90000;
	13119	 1	 0.0	 0.0	 0.0	 39.83	 0	    1.00000	    0.00000	 380.0	 1	    1.20000	    0.80000;
	13120	 1	 0.0	 -0.0	 0.0	 3.95	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	13121	 1	 50.96	 15.7	 0.0	 1.52	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	13122	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 7	    1.10000	    0.90000;
	13123	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	13124	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 8	    1.10000	    0.90000;
	13125	 1	 -0.0	 0.0	 0.0	 6.26	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	13126	 1	 50.96	 16.7	 0.0	 0.42	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	13127	 1	 0.0	 0.0	 0.0	 0.48	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	13128	 1	 27.7	 4.0	 0.0	 13.66	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	13129	 1	 131.5	 12.9	 0.0	 18.7	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	13130	 1	 -18.6	 -6.72	 0.0	 152.656532	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	13131	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	13132	 1	 -0.0	 0.0	 0.468803	 1.398864	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	13133	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 9	    1.10000	    0.90000;
	13134	 1	 95.61	 8.6	 0.0	 3.48	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	13135	 1	 426.6	 32.4	 0.157467	 3.3319	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	13136	 1	 -0.0	 -0.0	 1.152118	 -0.467789	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	13137	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	13138	 1	 -0.0	 -0.0	 0.0	 1.87	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	13139	 1	 0.0	 -0.0	 0.090774	 21.420444	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	13140	 1	 0.0	 0.0	 0.339749	 -0.264249	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	13141	 1	 8.11	 3.8	 0.0	 0.26	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	13142	 1	 -0.0	 0.0	 0.0	 1.03	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	13143	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 15.75	 1	    1.10000	    0.90000;
	13144	 1	 0.0	 -0.0	 0.0	 1.47	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	13145	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	13146	 1	 9.21	 3.4	 0.0	 1.48	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	13147	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	13148	 1	 -0.16	 -1.44	 0.0	 0.42	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	13149	 1	 0.0	 -0.0	 0.0	 49.35	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	13150	 1	 35.64	 10.7	 0.0	 5.94	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	13151	 1	 -0.0	 -0.0	 0.1444	 24.6772	 0	    1.00000	    0.00000	 380.0	 19	    1.20000	    0.80000;
	13152	 1	 0.0	 -0.0	 0.0	 -1.394261	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	13153	 1	 -0.0	 -0.0	 0.0	 28.22	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	13154	 1	 4.61	 1.5	 0.0	 1.23	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	13155	 1	 15.22	 2.5	 0.0	 0.69	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	13156	 1	 22.12	 8.0	 0.0	 1.51	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	13157	 1	 18.32	 6.6	 0.0	 0.45	 0	    1.00000	    0.00000	 110.0	 23	    1.10000	    0.90000;
	13158	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 7	    1.10000	    0.90000;
	13159	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 6.3	 1	    1.10000	    0.90000;
	13160	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 22	    1.10000	    0.90000;
	13161	 1	 -0.0	 -0.0	 0.0	 0.86	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	13162	 1	 278.3	 33.6	 0.0	 25.9	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	13163	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	13164	 1	 0.0	 -0.0	 0.224798	 32.902035	 0	    1.00000	    0.00000	 380.0	 12	    1.20000	    0.80000;
	13165	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	13166	 1	 -0.2	 -1.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	13167	 1	 87.7	 26.0	 0.0	 47.58	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	13168	 1	 0.0	 -0.0	 0.0	 1.25	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	13169	 1	 141.52	 50.48	 0.0	 66.28	 0	    1.00000	    0.00000	 380.0	 13	    1.10000	    0.90000;
	13170	 1	 0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	13171	 1	 -0.0	 0.0	 0.188566	 35.384296	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	13172	 1	 3.1	 1.6	 0.0	 0.09	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	13173	 1	 36.04	 22.3	 0.0	 2.37	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	13174	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	13175	 1	 -0.22	 -3.34	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	13176	 1	 5.51	 2.2	 0.0	 3.41	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	13177	 1	 0.0	 -0.0	 0.051721	 0.858279	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	13178	 1	 -0.0	 0.0	 0.0	 1.72	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	13179	 1	 -0.0	 -0.0	 0.0	 0.98	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	13180	 1	 0.0	 0.0	 0.11521	 58.265737	 0	    1.00000	    0.00000	 380.0	 7	    1.10000	    0.90000;
	13181	 1	 91.0	 21.0	 0.0	 11.23	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	13182	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	13183	 1	 -0.0	 -0.0	 0.0	 0.7	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	13184	 1	 98.7	 14.0	 0.0	 1.01	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	13185	 1	 33.54	 12.2	 0.0	 2.41	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	13186	 1	 32.1	 4.5	 0.0	 2.23	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	13187	 1	 -6.81	 2.2	 0.0	 0.57	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	13188	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	13189	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	13190	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	13191	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	13192	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 2	    1.10000	    0.90000;
	13193	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 6.3	 1	    1.10000	    0.90000;
	13194	 1	 -0.0	 -0.0	 0.038554	 0.011446	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	13195	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 10.6	 1	    1.10000	    0.90000;
	13196	 1	 -0.0	 0.0	 0.0	 4.8	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	13197	 1	 59.67	 13.1	 0.0	 2.26	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	13198	 1	 0.0	 -0.0	 1.04964	 7.653846	 0	    1.00000	    0.00000	 380.0	 5	    1.20000	    0.80000;
	13199	 1	 10.81	 1.3	 0.0	 2.23	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	13200	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	13201	 1	 93.1	 -15.12	 0.0	 1.04	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	13202	 1	 -0.0	 -0.0	 0.019887	 0.140113	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	13203	 1	 29.33	 5.6	 0.0	 6.56	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	13204	 1	 3.4	 1.1	 0.0	 2.14	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	13205	 1	 7.41	 2.7	 0.0	 3.34	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	13206	 1	 66.57	 0.56	 0.0	 7.63	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	13207	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 23	    1.10000	    0.90000;
	13208	 1	 50.96	 16.8	 0.0	 1.03	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	13209	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	13210	 1	 -0.0	 -0.0	 0.040026	 0.439974	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	13211	 1	 122.3	 17.5	 0.0	 1.51	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	13212	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	13213	 1	 93.9	 21.6	 0.0	 2.05	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	13214	 1	 113.4	 19.7	 0.215748	 8.474252	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	13215	 1	 -0.56	 -0.0	 0.0	 108.21	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	13216	 1	 0.0	 -7.5	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	13217	 1	 0.0	 -0.0	 0.0	 2.47	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	13218	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 14.4	 1	    1.10000	    0.90000;
	13219	 1	 88.0	 36.2	 0.0	 60.0	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	13220	 1	 0.0	 0.0	 0.0	 26.15	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	13221	 1	 -0.0	 -0.0	 0.04975	 68.521798	 0	    1.00000	    0.00000	 380.0	 18	    1.10000	    0.90000;
	13222	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	13223	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	13224	 1	 37.94	 3.4	 0.0	 11.17	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	13225	 1	 0.0	 -0.0	 0.0	 3.72	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	13226	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	13227	 1	 4.2	 1.4	 0.0	 0.98	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	13228	 1	 19.92	 6.6	 0.0	 0.18	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	13229	 1	 -0.0	 0.0	 0.0	 6.285833	 0	    1.00000	    0.00000	 220.0	 20	    1.10000	    0.90000;
	13230	 1	 0.0	 -0.0	 0.055698	 10.563585	 0	    1.00000	    0.00000	 220.0	 3	    1.20000	    0.80000;
	13231	 1	 0.0	 -0.0	 0.0	 43.7	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	13232	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	13233	 1	 1.6	 88.5	 0.467225	 47.990646	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	13234	 1	 3.7	 0.2	 0.0	 0.05	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	13235	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	13236	 1	 20.32	 6.3	 0.0	 0.05	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	13237	 1	 -0.0	 0.0	 0.0	 3.44	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	13238	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	13239	 1	 27.93	 8.9	 0.0	 0.47	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	13240	 1	 516.7	 144.3	 0.0	 2.32	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	13241	 1	 51.56	 18.7	 0.0	 0.18	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	13242	 1	 0.0	 0.0	 0.0	 7.89	 0	    1.00000	    0.00000	 220.0	 8	    1.10000	    0.90000;
	13243	 1	 -0.0	 -0.0	 0.0	 16.23	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	13244	 1	 0.0	 -0.0	 0.33861	 -0.263363	 0	    1.00000	    0.00000	 380.0	 8	    1.10000	    0.90000;
	13245	 1	 0.0	 0.0	 0.0	 4.39	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	13246	 1	 28.63	 17.7	 0.0	 0.1	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	13247	 1	 -0.0	 -0.0	 0.256503	 101.229042	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	13248	 1	 0.0	 0.0	 0.0	 0.4	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	13249	 1	 0.0	 0.0	 0.0	 9.64	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	13250	 1	 100.7	 20.5	 0.07943	 3.98057	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	13251	 1	 44.05	 21.0	 0.0	 0.03	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	13252	 1	 -0.0	 -0.0	 0.0	 0.25	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	13253	 1	 -0.0	 -0.0	 0.0	 2.78	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	13254	 1	 925.91	 147.97	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	13255	 1	 7.71	 2.2	 0.115287	 1.163535	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	13256	 1	 0.0	 0.0	 0.167278	 198.780601	 0	    1.00000	    0.00000	 380.0	 3	    1.20000	    0.80000;
	13257	 1	 23.43	 8.4	 0.0	 0.17	 0	    1.00000	    0.00000	 110.0	 15	    1.10000	    0.90000;
	13258	 1	 0.0	 0.0	 0.0	 35.28	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	13259	 1	 261.5	 95.0	 0.0	 49.05	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	13260	 1	 0.0	 0.0	 0.0	 1.29	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	13261	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	13262	 1	 0.0	 0.0	 0.0	 9.679984	 0	    1.00000	    0.00000	 220.0	 20	    1.10000	    0.90000;
	13263	 1	 298.4	 122.5	 0.233011	 3.125533	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	13264	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	13265	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	13266	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	13267	 1	 0.0	 0.0	 0.019352	 0.700648	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	13268	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	13269	 1	 0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	13270	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 6.3	 1	    1.10000	    0.90000;
	13271	 1	 274.3	 269.4	 1.130161	 137.739703	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	13272	 1	 -0.0	 0.0	 0.0	 44.96	 0	    1.00000	    0.00000	 380.0	 22	    1.10000	    0.90000;
	13273	 1	 82.29	 29.6	 0.0	 1.86	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	13274	 1	 0.0	 0.0	 0.097487	 3.732513	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	13275	 1	 81.29	 26.5	 0.0	 7.04	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	13276	 1	 60.57	 30.7	 0.461662	 2.094517	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	13277	 1	 -0.0	 -0.0	 0.0	 0.51	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	13278	 1	 -0.0	 -0.0	 0.040017	 0.899983	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	13279	 1	 -0.0	 0.0	 0.050138	 2.879862	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	13280	 1	 -0.0	 0.0	 0.0	 1.49	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	13281	 1	 4.1	 1.5	 0.0	 1.01	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	13282	 1	 53.36	 44.2	 0.0	 22.89	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	13283	 1	 18.52	 11.1	 0.0	 0.07	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	13284	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	13285	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	13286	 1	 92.9	 48.4	 0.0	 5.76	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	13287	 1	 44.95	 21.2	 0.040111	 39.389889	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	13288	 1	 0.0	 -0.0	 0.0	 0.87	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	13289	 1	 88.5	 24.5	 0.0	 2.23	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	13290	 1	 2.0	 1.0	 0.0	 0.8	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	13291	 1	 -8.49	 -17.09	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	13292	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	13293	 1	 4.2	 2.0	 0.0	 0.42	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	13294	 1	 -0.0	 0.0	 0.0	 14.64	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	13295	 1	 79.39	 16.8	 0.039541	 2.620459	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	13296	 1	 69.28	 31.3	 0.0	 32.76	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	13297	 1	 11.5	 1.7	 0.0	 3.08	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	13298	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	13299	 1	 8.7	 1.2	 0.0	 2.82	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	13300	 1	 0.0	 -0.0	 0.0	 50.210627	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	13301	 1	 -0.0	 -0.0	 0.0	 4.08	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	13302	 1	 41.15	 10.3	 0.0	 2.41	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	13303	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	13304	 1	 0.0	 -0.0	 0.233761	 -0.194801	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	13305	 1	 52.48	 6.43	 0.0	 1.47	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	13306	 1	 -0.0	 0.0	 0.0	 3.08	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	13307	 1	 79.29	 46.6	 0.293438	 5.195468	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	13308	 1	 119.02	 12.54	 0.0	 23.45	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	13309	 1	 0.0	 -0.0	 0.0	 31.57	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	13310	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	13311	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	13312	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 6.3	 1	    1.10000	    0.90000;
	13313	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	13314	 1	 102.6	 14.7	 0.0	 2.97	 0	    1.00000	    0.00000	 220.0	 20	    1.10000	    0.90000;
	13315	 1	 -0.0	 0.0	 0.048364	 5.54206	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	13316	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	13317	 1	 73.68	 24.0	 0.0	 0.46	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	13318	 1	 23.03	 14.2	 0.0	 1.24	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	13319	 1	 27.13	 16.8	 0.0	 1.34	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	13320	 1	 145.3	 3.8	 0.0	 41.054794	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	13321	 1	 0.0	 -0.0	 0.270022	 107.094537	 0	    1.00000	    0.00000	 380.0	 19	    1.10000	    0.90000;
	13322	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	13323	 1	 -0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	13324	 1	 0.0	 0.0	 0.0	 3.02	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	13325	 1	 0.0	 -0.0	 0.039122	 1.170659	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	13326	 1	 70.78	 19.6	 0.0	 8.1	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	13327	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 9	    1.20000	    0.80000;
	13328	 1	 15.63	 3.27	 0.0	 0.77	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	13329	 1	 -0.0	 0.0	 0.280385	 9.908955	 0	    1.00000	    0.00000	 380.0	 21	    1.10000	    0.90000;
	13330	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	13331	 1	 0.0	 -0.0	 0.0	 5.78	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	13332	 1	 110.0	 3.4	 0.0	 11.95	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	13333	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	13334	 1	 91.4	 18.1	 0.0	 4.89	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	13335	 1	 6.41	 4.3	 0.0	 0.23	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	13336	 1	 152.18	 21.63	 0.0	 1.91	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	13337	 1	 0.0	 0.0	 0.0	 249.03	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	13338	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	13339	 1	 80.49	 30.0	 0.0	 5.89	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	13340	 1	 -0.0	 0.0	 0.0	 0.49	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	13341	 1	 -0.0	 0.0	 0.218331	 2.960118	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	13342	 1	 0.2	 0.1	 0.0	 0.28	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	13343	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	13344	 1	 7.91	 2.7	 0.0	 0.01	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	13345	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	13346	 1	 132.2	 49.1	 0.0	 69.43	 0	    1.00000	    0.00000	 380.0	 16	    1.10000	    0.90000;
	13347	 1	 54.3	 7.8	 0.0	 4.44	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	13348	 1	 0.0	 0.0	 0.0	 2.42	 0	    1.00000	    0.00000	 380.0	 10	    1.10000	    0.90000;
	13349	 1	 -0.1	 68.5	 0.0	 17.24	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	13350	 1	 0.0	 -0.0	 0.243398	 -0.202832	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	13351	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	13352	 1	 12.61	 6.3	 0.0	 14.98	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	13353	 1	 -19.83	 -13.51	 0.0	 0.31	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	13354	 1	 -22.37	 -8.9	 0.151672	 11.87164	 0	    1.00000	    0.00000	 380.0	 3	    1.20000	    0.80000;
	13355	 1	 -0.0	 0.0	 0.0	 1.03	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	13356	 1	 8.31	 3.0	 0.0	 0.52	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	13357	 1	 78.01	 4.25	 0.0	 12.32	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	13358	 1	 -0.0	 0.0	 0.0	 0.57	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	13359	 1	 0.0	 0.0	 0.0	 6.27	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	13360	 1	 -0.0	 0.0	 0.0	 0.71	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	13361	 1	 0.0	 0.0	 0.0	 4.15	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	13362	 1	 -0.0	 -0.0	 0.0	 4.74	 0	    1.00000	    0.00000	 220.0	 22	    1.10000	    0.90000;
	13363	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	13364	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	13365	 1	 21.88	 4.73	 0.0	 -8.06	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	13366	 1	 206.4	 21.0	 0.0	 8.55	 0	    1.00000	    0.00000	 150.0	 10	    1.10000	    0.90000;
	13367	 1	 36.84	 14.1	 0.0	 3.8	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	13368	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.20000	    0.80000;
	13369	 1	 14.81	 0.6	 0.0	 0.68	 0	    1.00000	    0.00000	 110.0	 3	    1.10000	    0.90000;
	13370	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	13371	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	13372	 1	 0.0	 -0.0	 0.0	 2.15	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	13373	 1	 121.8	 17.4	 0.0	 1.01	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	13374	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	13375	 1	 0.0	 -0.0	 0.0	 0.44	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	13376	 1	 27.93	 11.1	 0.217305	 30.057967	 0	    1.00000	    0.00000	 380.0	 21	    1.20000	    0.80000;
	13377	 1	 0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	13378	 1	 11.35	 3.27	 0.0	 1.47	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	13379	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	13380	 1	 291.6	 47.0	 0.0	 2.38	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	13381	 1	 42.45	 -1.8	 0.058845	 0.360963	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	13382	 1	 0.0	 0.0	 0.0	 2.0	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	13383	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	13384	 1	 492.4	 162.0	 0.039293	 50.430707	 0	    1.00000	    0.00000	 380.0	 14	    1.10000	    0.90000;
	13385	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	13386	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	13387	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	13388	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	13389	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	13390	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	13391	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	13392	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	13393	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	13394	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	13395	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	13396	 1	 27.9	 4.0	 0.0	 4.34	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	13397	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	13398	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	13399	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	13400	 1	 16.52	 6.6	 0.0	 0.65	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	13401	 1	 -41.57	 -23.4	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	13402	 1	 -0.0	 -0.0	 0.0	 15.26	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	13403	 1	 -0.0	 0.0	 0.0	 0.59	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	13404	 1	 8.91	 2.5	 0.0	 0.31	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	13405	 1	 -0.0	 0.0	 0.211714	 1.318286	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	13406	 1	 -0.0	 0.0	 0.0	 11.35	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	13407	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	13408	 1	 -0.0	 0.0	 0.118317	 122.437372	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	13409	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 9	    1.10000	    0.90000;
	13410	 1	 133.5	 24.1	 0.0	 2.92	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	13411	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	13412	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	13413	 1	 8.3	 1.2	 0.0	 0.53	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	13414	 1	 0.0	 0.0	 0.0	 1.41	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	13415	 1	 -0.0	 -0.0	 0.0	 5.05	 0	    1.00000	    0.00000	 220.0	 22	    1.10000	    0.90000;
	13416	 1	 46.9	 6.7	 0.0	 3.45	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	13417	 1	 242.4	 5.1	 0.0	 4.93	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	13418	 1	 0.0	 -0.0	 0.0	 0.55	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	13419	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	13420	 1	 6.41	 2.3	 0.0	 1.51	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	13421	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	13422	 1	 24.33	 9.9	 0.0	 0.76	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	13423	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	13424	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	13425	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	13426	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	13427	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	13428	 1	 -0.0	 -0.0	 0.0	 20.53	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	13429	 1	 -0.0	 -0.0	 0.0	 0.59	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	13430	 1	 50.2	 7.1	 0.0	 3.52	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	13431	 1	 88.1	 36.0	 0.0	 27.89	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	13432	 1	 -0.0	 0.0	 0.0	 5.88	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	13433	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	13434	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	13435	 1	 -0.0	 0.0	 0.0	 0.52	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	13436	 1	 125.0	 9.6	 0.0	 0.25	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	13437	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	13438	 1	 33.5	 4.8	 0.0	 1.98	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	13439	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	13440	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	13441	 1	 55.9	 102.9	 0.0	 23.9	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	13442	 1	 0.0	 0.0	 0.0	 4.5	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	13443	 1	 0.0	 -0.0	 0.0	 0.58	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	13444	 1	 0.0	 -0.0	 0.0	 3.65	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	13445	 1	 -0.57	 -1.0	 0.0	 3.29	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	13446	 1	 3.8	 2.5	 0.0	 0.84	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	13447	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	13448	 1	 -0.0	 0.0	 0.0	 6.33	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	13449	 1	 119.0	 97.8	 0.0	 0.14	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	13450	 1	 7.0	 1.0	 0.0	 0.78	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	13451	 1	 2.2	 0.5	 0.0	 0.13	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	13452	 1	 -0.0	 -0.0	 0.0	 1.77	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	13453	 1	 181.1	 25.8	 0.0	 0.83	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	13454	 1	 223.3	 -7.6	 0.0	 19.97	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	13455	 1	 140.8	 44.9	 0.586408	 62.421067	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	13456	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	13457	 1	 0.0	 0.0	 0.0	 2.83	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	13458	 1	 112.4	 16.1	 0.0	 3.37	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	13459	 1	 11.31	 13.8	 0.0	 1.11	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	13460	 1	 -678.72	 -333.49	 0.0	 0.0	 0	    1.00000	    0.00000	 27.0	 3	    1.10000	    0.90000;
	13461	 1	 -0.0	 -0.3	 0.055108	 0.334077	 0	    1.00000	    0.00000	 110.0	 18	    1.20000	    0.80000;
	13462	 1	 -0.0	 -0.0	 0.0	 1.12	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	13463	 1	 87.4	 35.5	 0.0	 16.41	 0	    1.00000	    0.00000	 380.0	 16	    1.10000	    0.90000;
	13464	 1	 285.2	 83.5	 0.0	 5.6	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	13465	 1	 -0.0	 0.0	 0.0	 0.31	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	13466	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	13467	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	13468	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	13469	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	13470	 1	 35.14	 12.7	 0.0	 1.42	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	13471	 1	 0.0	 -0.0	 0.0	 19.71	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	13472	 1	 -0.0	 -0.0	 0.080832	 6.709376	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	13473	 1	 -0.0	 0.0	 0.0	 47.1	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	13474	 1	 -0.0	 -0.0	 0.0	 2.257591	 0	    1.00000	    0.00000	 220.0	 24	    1.10000	    0.90000;
	13475	 1	 25.03	 12.0	 0.0	 2.76	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	13476	 1	 152.7	 81.0	 0.0	 17.54	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	13477	 1	 124.0	 24.4	 2.308381	 123.32112	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	13478	 1	 36.74	 14.1	 0.0	 16.98	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	13479	 1	 -0.0	 0.0	 0.079602	 10.290299	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	13480	 1	 0.0	 0.0	 0.0	 37.112979	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	13481	 1	 -0.0	 -0.0	 0.0	 1.24	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	13482	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	13483	 1	 0.0	 0.0	 0.0	 4.13	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	13484	 1	 32.1	 4.5	 0.0	 4.34	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	13485	 1	 -0.0	 -0.0	 0.0	 15.15	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	13486	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	13487	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	13488	 1	 13.9	 1.9	 0.0	 5.87	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	13489	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	13490	 1	 -5.15	 -2.04	 0.0	 154.352274	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	13491	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	13492	 1	 175.7	 56.2	 0.0	 0.13	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	13493	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 1	    1.10000	    0.90000;
	13494	 1	 -0.0	 0.0	 0.0	 32.64	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	13495	 1	 38.84	 9.6	 0.0	 0.88	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	13496	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	13497	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	13498	 1	 50.56	 8.7	 0.0	 0.19	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	13499	 1	 39.5	 5.6	 0.0	 8.26	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	13500	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	13501	 1	 13.9	 1.9	 0.0	 2.11	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	13502	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	13503	 1	 0.0	 -0.0	 0.471538	 4.526699	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	13504	 1	 -0.0	 -0.0	 0.0	 7.12	 0	    1.00000	    0.00000	 380.0	 17	    1.10000	    0.90000;
	13505	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	13506	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	13507	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	13508	 1	 21.72	 13.4	 0.0	 2.38	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	13509	 1	 169.04	 33.9	 0.0	 5.48	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	13510	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	13511	 1	 0.0	 0.0	 0.0	 25.04	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	13512	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	13513	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 220.0	 10	    1.10000	    0.90000;
	13514	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	13515	 1	 16.7	 2.4	 0.0	 2.38	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	13516	 1	 431.5	 111.5	 0.0	 36.709841	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	13517	 1	 158.4	 31.0	 0.079228	 3.990772	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	13518	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	13519	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	13520	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	13521	 1	 89.59	 96.2	 0.0	 48.28	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	13522	 1	 -0.0	 0.0	 0.24842	 10.168602	 0	    1.00000	    0.00000	 220.0	 19	    1.10000	    0.90000;
	13523	 1	 66.57	 23.6	 0.0	 0.14	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	13524	 1	 35.44	 11.4	 0.0	 1.15	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	13525	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	13526	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	13527	 1	 15.22	 5.1	 0.0	 0.36	 0	    1.00000	    0.00000	 110.0	 18	    1.20000	    0.80000;
	13528	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	13529	 1	 0.0	 0.0	 0.574367	 0.152454	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	13530	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 22	    1.10000	    0.90000;
	13531	 1	 -0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	13532	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	13533	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	13534	 1	 5.5	 0.8	 0.0	 8.36	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	13535	 1	 -0.0	 -0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	13536	 1	 0.0	 -0.0	 0.0	 17.63	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	13537	 1	 2.2	 1.1	 0.0	 1.31	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	13538	 1	 -0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	13539	 1	 83.19	 37.3	 0.0	 28.16	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	13540	 1	 0.0	 0.0	 0.0	 0.55	 0	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	13541	 1	 99.5	 9.2	 0.0	 27.55	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	13542	 1	 60.07	 -0.0	 0.0	 0.04	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	13543	 1	 3.04	 -13.76	 0.0	 4.17	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	13544	 1	 54.96	 9.42	 0.0	 5.92	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	13545	 1	 0.0	 -0.0	 0.0	 81.15	 0	    1.00000	    0.00000	 380.0	 4	    1.10000	    0.90000;
	13546	 1	 -0.0	 0.0	 0.12	 1.55	 0	    1.00000	    0.00000	 220.0	 21	    1.10000	    0.90000;
	13547	 1	 311.4	 310.5	 0.18614	 104.074947	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	13548	 1	 1.6	 5.3	 0.196409	 7.603591	 0	    1.00000	    0.00000	 220.0	 7	    1.10000	    0.90000;
	13549	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 10.6	 1	    1.10000	    0.90000;
	13550	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	13551	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 6.3	 1	    1.10000	    0.90000;
	13552	 1	 94.9	 40.3	 0.0	 17.2	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	13553	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	13554	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	13555	 1	 244.6	 96.3	 0.0	 7.45	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	13556	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	13557	 1	 9.91	 2.0	 0.0	 0.23	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	13558	 1	 100.5	 19.3	 0.0	 13.51	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	13559	 1	 -0.0	 0.0	 0.168013	 0.409324	 0	    1.00000	    0.00000	 220.0	 21	    1.10000	    0.90000;
	13560	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	13561	 1	 43.15	 26.7	 0.0	 0.11	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	13562	 1	 6.01	 3.0	 0.0	 0.43	 0	    1.00000	    0.00000	 110.0	 23	    1.10000	    0.90000;
	13563	 1	 125.4	 7.6	 0.019458	 7.490542	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	13564	 1	 10.11	 2.8	 0.0	 1.01	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	13565	 1	 66.07	 15.6	 0.0	 5.57	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	13566	 1	 489.8	 162.0	 0.187289	 98.738033	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	13567	 1	 20.32	 6.7	 0.0	 1.27	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	13568	 1	 -0.0	 0.0	 0.0	 1.28	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	13569	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	13570	 1	 4.61	 0.8	 0.0	 2.46	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	13571	 1	 4.4	 2.2	 0.0	 0.28	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	13572	 1	 -0.0	 0.0	 0.077289	 3.152711	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	13573	 1	 2.43	 1.35	 0.0	 0.1	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	13574	 1	 29.7	 4.3	 0.0	 13.67	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	13575	 1	 156.3	 34.9	 0.0	 125.56	 0	    1.00000	    0.00000	 380.0	 20	    1.10000	    0.90000;
	13576	 1	 50.06	 44.0	 0.0	 52.57	 0	    1.00000	    0.00000	 220.0	 11	    1.10000	    0.90000;
	13577	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	13578	 1	 -28.33	 9.3	 0.0	 0.06	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	13579	 1	 -0.0	 -0.0	 0.0	 0.35	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	13580	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	13581	 1	 62.57	 -61.0	 0.0	 55.14	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
	13582	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	13583	 1	 0.0	 0.0	 0.484386	 7.703962	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	13584	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	13585	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	13586	 1	 17.92	 23.3	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 2	    1.10000	    0.90000;
	13587	 1	 -0.0	 0.0	 0.0	 2.72	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	13588	 1	 -0.0	 -0.0	 0.0	 1.15	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	13589	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	13590	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 15.75	 1	    1.10000	    0.90000;
	13591	 1	 15.82	 3.7	 0.0	 0.22	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	13592	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 14	    1.10000	    0.90000;
	13593	 1	 35.64	 6.4	 0.038822	 1.491178	 0	    1.00000	    0.00000	 110.0	 3	    1.10000	    0.90000;
	13594	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	13595	 1	 18.71	 0.64	 0.0	 1.58	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	13596	 1	 -0.0	 0.0	 0.059381	 2.260413	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	13597	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	13598	 1	 282.2	 268.3	 0.0	 0.28	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	13599	 1	 14.42	 3.8	 0.0	 1.24	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	13600	 1	 -0.0	 -0.0	 0.176054	 -0.106712	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	13601	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	13602	 1	 137.9	 25.6	 0.0	 8.24	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	13603	 1	 15.42	 6.6	 0.0	 2.46	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	13604	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	13605	 1	 -0.0	 -0.0	 0.162419	 14.137581	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	13606	 1	 11.71	 3.8	 0.0	 0.41	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	13607	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 4	    1.10000	    0.90000;
	13608	 1	 23.43	 7.3	 0.0	 0.89	 0	    1.00000	    0.00000	 110.0	 8	    1.10000	    0.90000;
	13609	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 5	    1.10000	    0.90000;
	13610	 1	 16.52	 5.5	 0.0	 0.75	 0	    1.00000	    0.00000	 110.0	 22	    1.10000	    0.90000;
	13611	 1	 226.1	 88.8	 0.0	 122.78	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	13612	 1	 0.0	 0.0	 0.0	 13.84	 0	    1.00000	    0.00000	 400.0	 1	    1.10000	    0.90000;
	13613	 1	 160.2	 22.8	 0.0	 14.42	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	13614	 1	 -0.0	 0.0	 0.0	 2.29	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	13615	 1	 11.44	 2.38	 0.0	 0.78	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	13616	 1	 12.11	 4.4	 0.0	 2.35	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	13617	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 6.3	 1	    1.10000	    0.90000;
	13618	 1	 11.5	 6.16	 0.0	 1.79	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	13619	 1	 0.0	 0.0	 0.457274	 6.947991	 0	    1.00000	    0.00000	 380.0	 14	    1.10000	    0.90000;
	13620	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	13621	 1	 -0.0	 -0.0	 0.0	 10.019046	 0	    1.00000	    0.00000	 380.0	 5	    1.10000	    0.90000;
	13622	 1	 64.57	 10.0	 0.0	 4.8	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	13623	 1	 1.3	 0.0	 0.0	 1.1	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	13624	 1	 41.6	 5.9	 0.0	 2.5	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	13625	 1	 103.6	 4.7	 0.0	 36.68	 0	    1.00000	    0.00000	 220.0	 4	    1.10000	    0.90000;
	13626	 1	 187.4	 72.8	 0.0	 34.95	 0	    1.00000	    0.00000	 150.0	 8	    1.10000	    0.90000;
	13627	 1	 0.0	 -0.0	 0.048364	 5.66206	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	13628	 1	 39.34	 13.3	 0.0	 0.67	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	13629	 1	 139.8	 -25.8	 0.0	 22.95	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	13630	 1	 26.4	 3.8	 0.0	 7.48	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	13631	 1	 0.0	 -0.0	 0.0	 6.58	 0	    1.00000	    0.00000	 380.0	 3	    1.10000	    0.90000;
	13632	 1	 22.02	 7.1	 0.0	 1.38	 0	    1.00000	    0.00000	 110.0	 21	    1.10000	    0.90000;
	13633	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	13634	 1	 0.0	 0.0	 0.0	 0.04	 0	    1.00000	    0.00000	 154.0	 1	    1.10000	    0.90000;
	13635	 1	 -0.0	 -0.0	 0.0	 5.98	 0	    1.00000	    0.00000	 220.0	 3	    1.10000	    0.90000;
	13636	 1	 10.11	 3.3	 0.0	 0.92	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	13637	 1	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	13638	 1	 0.0	 0.0	 0.090774	 11.940444	 0	    1.00000	    0.00000	 220.0	 18	    1.10000	    0.90000;
	13639	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 18	    1.10000	    0.90000;
	13640	 1	 -0.0	 0.0	 0.0	 6.95	 0	    1.00000	    0.00000	 380.0	 1	    1.10000	    0.90000;
	13641	 1	 38.34	 12.6	 0.0	 0.58	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	13642	 1	 83.5	 41.5	 0.0	 0.0	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	13643	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	13644	 1	 11.41	 3.7	 0.0	 0.63	 0	    1.00000	    0.00000	 110.0	 12	    1.10000	    0.90000;
	13645	 1	 -0.0	 0.0	 0.039946	 0.25004	 0	    1.00000	    0.00000	 220.0	 6	    1.10000	    0.90000;
	13646	 1	 0.0	 -0.0	 0.101868	 70.579862	 0	    1.00000	    0.00000	 380.0	 19	    1.20000	    0.80000;
	13647	 1	 157.0	 44.2	 0.0	 22.63	 0	    1.00000	    0.00000	 220.0	 1	    1.10000	    0.90000;
	13648	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 6	    1.10000	    0.90000;
	13649	 1	 2.1	 0.8	 0.0	 0.42	 0	    1.00000	    0.00000	 110.0	 18	    1.10000	    0.90000;
	13650	 1	 -121.89	 -52.61	 0.0	 0.48	 0	    1.00000	    0.00000	 220.0	 13	    1.10000	    0.90000;
	13651	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 9	    1.10000	    0.90000;
	13652	 1	 246.5	 -1.9	 0.0	 31.37	 0	    1.00000	    0.00000	 380.0	 6	    1.10000	    0.90000;
	13653	 1	 0.0	 0.0	 0.0	 1.27	 0	    1.00000	    0.00000	 110.0	 19	    1.10000	    0.90000;
	13654	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 380.0	 13	    1.20000	    0.80000;
	13655	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 3	    1.10000	    0.90000;
	13656	 1	 0.0	 -0.0	 0.340862	 0.564885	 0	    1.00000	    0.00000	 380.0	 2	    1.10000	    0.90000;
	13657	 1	 -0.0	 -0.0	 0.0	 3.66	 0	    1.00000	    0.00000	 150.0	 9	    1.10000	    0.90000;
	13658	 2	 0.0	 0.0	 0.0	 0.0	 0	    1.00000	    0.00000	 20.0	 10	    1.10000	    0.90000;
	13659	 1	 -0.0	 0.0	 0.0	 0.36	 0	    1.00000	    0.00000	 220.0	 5	    1.10000	    0.90000;
];

%% generator data
%	bus	Pg	Qg	Qmax	Qmin	Vg	mBase	status	Pmax	Pmin
mpc.gen = [
	1	 64.11	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 28.22; % NG
	12	 300.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 500.0	 100.0; % NG
	18	 62.675	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 25.35; % NG
	29	 61.595	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.19; % NG
	33	 58.45	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 16.9; % NG
	39	 300.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 500.0	 100.0; % COW
	42	 55.365	 0.0	 20.0	 -20.0	 1.0	 100.0	 1	 100.0	 10.73; % COW
	45	 250.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 400.0	 100.0; % NG
	51	 250.0	 0.0	 90.0	 -90.0	 1.0	 100.0	 1	 400.0	 100.0; % COW
	54	 62.36	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.72; % NG
	62	 850.0	 200.0	 520.0	 -120.0	 1.0	 100.0	 1	 1300.0	 400.0; % COW
	63	 850.0	 200.0	 520.0	 -120.0	 1.0	 100.0	 1	 1300.0	 400.0; % COW
	66	 250.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 400.0	 100.0; % NG
	68	 117.905	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 35.81; % NG
	69	 117.905	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 35.81; % NG
	77	 58.215	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 16.43; % NG
	78	 118.16	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 200.0	 36.32; % NG
	79	 56.045	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 12.09; % COW
	86	 250.0	 30.0	 80.0	 -20.0	 1.0	 100.0	 1	 400.0	 100.0; % NG
	94	 55.88	 5.0	 20.0	 -10.0	 1.0	 100.0	 1	 100.0	 11.76; % NG
	96	 66.475	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 32.95; % NG
	97	 66.475	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 32.95; % NG
	98	 66.475	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 32.95; % NG
	99	 57.95	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 15.9; % NG
	100	 57.95	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 15.9; % NG
	101	 66.475	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 32.95; % NG
	102	 66.475	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 32.95; % COW
	104	 129.315	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 58.63; % NG
	107	 122.755	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 45.51; % NG
	110	 130.49	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 60.98; % COW
	114	 64.115	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 28.23; % NG
	115	 57.45	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 14.9; % NG
	121	 62.01	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.02; % NG
	132	 52.175	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 4.35; % COW
	133	 62.255	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.51; % COW
	134	 65.18	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 30.36; % NG
	135	 64.115	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 28.23; % NG
	136	 116.945	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 33.89; % NG
	144	 55.935	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 11.87; % NG
	145	 850.0	 200.0	 520.0	 -120.0	 1.0	 100.0	 1	 1300.0	 400.0; % COW
	146	 850.0	 200.0	 520.0	 -120.0	 1.0	 100.0	 1	 1300.0	 400.0; % COW
	147	 850.0	 200.0	 520.0	 -120.0	 1.0	 100.0	 1	 1300.0	 400.0; % COW
	151	 300.0	 45.0	 150.0	 -60.0	 1.0	 100.0	 1	 500.0	 100.0; % NG
	153	 62.045	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.09; % NG
	154	 1050.0	 200.0	 520.0	 -120.0	 1.0	 100.0	 1	 1600.0	 500.0; % NUC
	156	 66.445	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 32.89; % NG
	161	 66.445	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 32.89; % NG
	162	 66.445	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 32.89; % COW
	165	 64.115	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 28.23; % NG
	179	 131.675	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 63.35; % NG
	182	 61.655	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.31; % NG
	196	 127.025	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 54.05; % NG
	197	 300.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 500.0	 100.0; % COW
	207	 59.315	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 18.63; % NG
	220	 132.575	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 65.15; % NG
	221	 132.575	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 65.15; % COW
	222	 132.555	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 65.11; % COW
	223	 132.575	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 65.15; % NG
	224	 132.555	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 65.11; % NG
	225	 132.555	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 65.11; % COW
	229	 57.01	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 14.02; % COW
	241	 850.0	 200.0	 520.0	 -120.0	 1.0	 100.0	 1	 1300.0	 400.0; % COW
	243	 60.81	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.62; % NG
	248	 58.795	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 17.59; % NG
	250	 250.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 400.0	 100.0; % COW
	258	 52.735	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 5.47; % NG
	259	 62.835	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 25.67; % NG
	266	 59.495	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 18.99; % NG
	270	 56.135	 0.0	 20.0	 -20.0	 1.0	 100.0	 1	 100.0	 12.27; % NG
	271	 850.0	 200.0	 520.0	 -120.0	 1.0	 100.0	 1	 1300.0	 400.0; % NG
	273	 850.0	 200.0	 520.0	 -120.0	 1.0	 100.0	 1	 1300.0	 400.0; % COW
	274	 850.0	 200.0	 520.0	 -120.0	 1.0	 100.0	 1	 1300.0	 400.0; % COW
	275	 850.0	 200.0	 520.0	 -120.0	 1.0	 100.0	 1	 1300.0	 400.0; % NG
	276	 850.0	 200.0	 520.0	 -120.0	 1.0	 100.0	 1	 1300.0	 400.0; % COW
	278	 850.0	 65.0	 320.0	 -190.0	 1.0	 100.0	 1	 1300.0	 400.0; % COW
	283	 52.665	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 5.33; % NG
	289	 62.3	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.6; % COW
	294	 130.935	 0.0	 50.0	 -50.0	 1.0	 100.0	 1	 200.0	 61.87; % NG
	296	 57.0	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 14.0; % COW
	299	 250.0	 35.0	 100.0	 -30.0	 1.0	 100.0	 1	 400.0	 100.0; % NG
	304	 63.325	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 26.65; % NG
	305	 59.245	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 18.49; % NG
	306	 59.245	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 18.49; % COW
	307	 55.885	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 11.77; % COW
	308	 55.885	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 11.77; % NG
	309	 60.695	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.39; % NG
	310	 60.695	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.39; % NG
	311	 60.695	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.39; % NG
	312	 60.695	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.39; % NG
	315	 50.685	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 1.37; % NG
	323	 550.0	 200.0	 520.0	 -120.0	 1.0	 100.0	 1	 900.0	 200.0; % COW
	324	 51.665	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 3.33; % NG
	325	 51.6	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 3.2; % COW
	328	 118.18	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 36.36; % NG
	331	 59.205	 5.0	 30.0	 -20.0	 1.0	 100.0	 1	 100.0	 18.41; % NG
	332	 50.665	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 1.33; % NG
	336	 55.36	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 10.72; % NG
	338	 55.36	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 10.72; % NG
	345	 450.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 700.0	 200.0; % COW
	346	 450.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 700.0	 200.0; % COW
	351	 250.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 400.0	 100.0; % NG
	354	 62.14	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.28; % COW
	358	 250.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 400.0	 100.0; % NG
	360	 128.04	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 56.08; % NG
	361	 128.04	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 56.08; % NG
	362	 128.04	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 56.08; % NG
	363	 128.04	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 56.08; % NG
	364	 51.75	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 3.5; % NG
	365	 131.735	 40.0	 110.0	 -30.0	 1.0	 100.0	 1	 200.0	 63.47; % NG
	368	 128.04	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 56.08; % NG
	369	 128.04	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 56.08; % NG
	382	 184.01	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 300.0	 68.02; % NG
	383	 184.08	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 300.0	 68.16; % NG
	392	 50.345	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 0.69; % NG
	394	 62.635	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 25.27; % NG
	395	 62.41	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.82; % COW
	396	 128.425	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 56.85; % NG
	400	 131.5	 5.0	 50.0	 -40.0	 1.0	 100.0	 1	 200.0	 63.0; % NG
	405	 61.215	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.43; % NG
	406	 61.215	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.43; % NG
	408	 61.64	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.28; % COW
	423	 50.33	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 0.66; % COW
	432	 51.5	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 3.0; % COW
	433	 60.015	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 20.03; % NG
	438	 56.045	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 12.09; % NG
	442	 60.45	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 20.9; % COW
	448	 58.405	 5.0	 20.0	 -10.0	 1.0	 100.0	 1	 100.0	 16.81; % NG
	454	 52.785	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 5.57; % NG
	458	 60.425	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 20.85; % NG
	463	 36.68	 0.0	 100000.0	 -100000.0	 1.0	 100.0	 1	 100.0	 -26.64; % NG
	470	 124.935	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 49.87; % NG
	476	 300.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 500.0	 100.0; % COW
	477	 62.675	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 25.35; % NG
	480	 129.735	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 59.47; % NG
	481	 129.735	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 59.47; % NG
	482	 129.735	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 59.47; % NG
	483	 129.735	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 59.47; % NG
	485	 450.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 700.0	 200.0; % COW
	492	 350.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 600.0	 100.0; % NG
	496	 121.425	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 42.85; % NG
	508	 1150.0	 200.0	 520.0	 -120.0	 1.0	 100.0	 1	 1800.0	 500.0; % NUC
	509	 1150.0	 200.0	 520.0	 -120.0	 1.0	 100.0	 1	 1800.0	 500.0; % COW
	510	 1150.0	 200.0	 520.0	 -120.0	 1.0	 100.0	 1	 1800.0	 500.0; % NUC
	514	 1150.0	 200.0	 520.0	 -120.0	 1.0	 100.0	 1	 1800.0	 500.0; % COW
	516	 60.855	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.71; % NG
	528	 57.885	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 15.77; % COW
	531	 62.93	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 25.86; % COW
	532	 350.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 600.0	 100.0; % NG
	533	 250.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 400.0	 100.0; % NG
	539	 250.0	 25.0	 90.0	 -40.0	 1.0	 100.0	 1	 400.0	 100.0; % NG
	552	 60.2	 0.0	 20.0	 -20.0	 1.0	 100.0	 1	 100.0	 20.4; % NG
	559	 117.165	 0.0	 30.0	 -30.0	 1.0	 100.0	 1	 200.0	 34.33; % NG
	564	 57.255	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 14.51; % NG
	572	 52.335	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 4.67; % NG
	575	 56.03	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 12.06; % NG
	576	 56.03	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 12.06; % NG
	577	 56.03	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 12.06; % NG
	581	 56.03	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 12.06; % NG
	585	 124.205	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 48.41; % NG
	589	 54.46	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 8.92; % NG
	610	 60.65	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.3; % COW
	614	 61.605	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.21; % NG
	615	 61.605	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.21; % NG
	619	 64.165	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 28.33; % NG
	621	 51.935	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 3.87; % COW
	623	 62.01	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.02; % COW
	626	 64.43	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 100.0	 28.86; % NG
	635	 50.045	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 0.09; % NG
	637	 58.405	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 16.81; % NG
	646	 450.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 700.0	 200.0; % COW
	648	 450.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 700.0	 200.0; % COW
	649	 450.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 700.0	 200.0; % COW
	651	 250.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 400.0	 100.0; % NG
	652	 250.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 400.0	 100.0; % COW
	654	 130.8	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 61.6; % NG
	660	 61.07	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.14; % COW
	666	 60.435	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 20.87; % NG
	671	 58.4	 5.0	 20.0	 -10.0	 1.0	 100.0	 1	 100.0	 16.8; % NG
	676	 350.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 600.0	 100.0; % NUC
	681	 128.225	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 56.45; % NG
	684	 122.965	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 45.93; % NG
	693	 300.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 500.0	 100.0; % COW
	695	 52.8	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 5.6; % NG
	698	 58.905	 5.0	 20.0	 -10.0	 1.0	 100.0	 1	 100.0	 17.81; % NG
	709	 850.0	 200.0	 520.0	 -120.0	 1.0	 100.0	 1	 1300.0	 400.0; % COW
	715	 57.965	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 15.93; % NG
	717	 57.705	 5.0	 10.0	 0.0	 1.0	 100.0	 1	 100.0	 15.41; % COW
	721	 124.785	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 49.57; % NG
	724	 61.835	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.67; % COW
	730	 132.82	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 65.64; % COW
	731	 132.82	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 65.64; % NG
	732	 132.82	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 65.64; % NG
	734	 132.82	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 65.64; % NG
	746	 55.335	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 10.67; % NG
	749	 57.525	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 15.05; % NG
	750	 57.525	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 15.05; % NG
	751	 57.525	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 15.05; % NG
	753	 56.88	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 13.76; % NG
	754	 121.55	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 43.1; % NG
	765	 126.125	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 52.25; % NG
	768	 65.58	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 31.16; % NG
	769	 65.58	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 31.16; % NG
	773	 60.045	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 20.09; % NG
	775	 58.78	 5.0	 20.0	 -10.0	 1.0	 100.0	 1	 100.0	 17.56; % NG
	778	 56.245	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 12.49; % NG
	779	 57.2	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 14.4; % NG
	783	 55.425	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 10.85; % NG
	786	 60.43	 0.0	 30.0	 -30.0	 1.0	 100.0	 1	 100.0	 20.86; % COW
	798	 60.3	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 20.6; % NG
	800	 850.0	 200.0	 520.0	 -120.0	 1.0	 100.0	 1	 1300.0	 400.0; % COW
	809	 60.435	 5.0	 20.0	 -10.0	 1.0	 100.0	 1	 100.0	 20.87; % COW
	811	 60.575	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.15; % COW
	814	 1300.0	 200.0	 520.0	 -120.0	 1.0	 100.0	 1	 2000.0	 600.0; % COW
	815	 130.895	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 61.79; % NG
	819	 300.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 500.0	 100.0; % COW
	824	 60.435	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 20.87; % NG
	828	 300.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 500.0	 100.0; % COW
	836	 56.385	 5.0	 20.0	 -10.0	 1.0	 100.0	 1	 100.0	 12.77; % NG
	839	 52.515	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 5.03; % COW
	841	 132.01	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 64.02; % NG
	844	 119.675	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 39.35; % NG
	845	 119.675	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 39.35; % NG
	846	 119.675	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 39.35; % NG
	849	 122.755	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 45.51; % NG
	855	 63.225	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 26.45; % NG
	858	 350.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 600.0	 100.0; % NUC
	859	 62.305	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.61; % COW
	861	 60.095	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 20.19; % NG
	862	 60.095	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 20.19; % NG
	864	 60.095	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 20.19; % NG
	865	 60.095	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 20.19; % NG
	869	 62.635	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 25.27; % NG
	873	 62.655	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 25.31; % NG
	874	 63.41	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 26.82; % NG
	888	 62.72	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 25.44; % COW
	898	 61.99	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.98; % NG
	901	 128.225	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 56.45; % NG
	904	 60.84	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.68; % NG
	907	 60.84	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.68; % COW
	910	 129.44	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 58.88; % NG
	912	 64.39	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 28.78; % NG
	916	 250.0	 30.0	 100.0	 -40.0	 1.0	 100.0	 1	 400.0	 100.0; % COW
	920	 64.39	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 28.78; % NG
	921	 350.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	925	 350.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	926	 300.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 500.0	 100.0; % COW
	927	 64.5	 0.0	 30.0	 -30.0	 1.0	 100.0	 1	 100.0	 29.0; % NG
	930	 64.39	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 28.78; % NG
	932	 56.525	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 13.05; % COW
	937	 58.21	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 16.42; % NG
	938	 59.61	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 19.22; % NG
	954	 120.1	 0.0	 30.0	 -30.0	 1.0	 100.0	 1	 200.0	 40.2; % COW
	956	 56.98	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 13.96; % NG
	958	 60.5	 5.0	 30.0	 -20.0	 1.0	 100.0	 1	 100.0	 21.0; % NG
	975	 55.58	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 11.16; % NG
	976	 55.54	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 11.08; % NG
	977	 55.54	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 11.08; % NG
	978	 55.54	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 11.08; % NG
	980	 60.29	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 20.58; % NG
	981	 62.775	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 25.55; % NG
	982	 62.775	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 25.55; % COW
	983	 62.775	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 25.55; % NG
	984	 56.335	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 12.67; % NG
	985	 56.335	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 12.67; % COW
	986	 56.335	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 12.67; % NG
	987	 56.335	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 12.67; % NG
	995	 62.41	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.82; % NG
	1002	 300.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 500.0	 100.0; % COW
	1004	 51.4	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 2.8; % NG
	1007	 55.0	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 10.0; % NG
	1010	 128.75	 -10.0	 60.0	 -80.0	 1.0	 100.0	 1	 200.0	 57.5; % NG
	1013	 61.99	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.98; % NG
	1031	 129.885	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 59.77; % NG
	1043	 116.975	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 33.95; % NG
	1044	 51.75	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 3.5; % NG
	1046	 52.845	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 5.69; % COW
	1048	 50.115	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 0.23; % NG
	1050	 450.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 700.0	 200.0; % COW
	1055	 61.64	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.28; % COW
	1057	 117.605	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 35.21; % NG
	1059	 62.265	 0.0	 30.0	 -30.0	 1.0	 100.0	 1	 100.0	 24.53; % NG
	1070	 57.67	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 15.34; % NG
	1071	 57.865	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 15.73; % NG
	1072	 129.97	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 59.94; % NG
	1073	 63.27	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 26.54; % NG
	1074	 126.915	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 53.83; % NG
	1077	 57.765	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 15.53; % NG
	1079	 62.235	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.47; % NG
	1083	 300.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 500.0	 100.0; % COW
	1085	 350.0	 35.0	 100.0	 -30.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	1088	 50.025	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 0.05; % NG
	1089	 58.745	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 17.49; % NG
	1090	 56.615	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 13.23; % NG
	1092	 58.745	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 17.49; % NG
	1093	 58.745	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 17.49; % COW
	1096	 62.43	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.86; % COW
	1104	 61.64	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.28; % NG
	1123	 183.47	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 300.0	 66.94; % COW
	1125	 60.435	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 20.87; % NG
	1138	 350.0	 0.0	 100.0	 -100.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	1148	 53.0	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 6.0; % NG
	1150	 300.0	 35.0	 100.0	 -30.0	 1.0	 100.0	 1	 500.0	 100.0; % NG
	1180	 58.4	 5.0	 20.0	 -10.0	 1.0	 100.0	 1	 100.0	 16.8; % COW
	1182	 57.79	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 15.58; % NG
	1183	 57.79	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 15.58; % NG
	1189	 59.32	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 18.64; % COW
	1192	 62.93	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 25.86; % NG
	1202	 61.835	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.67; % NG
	1208	 56.665	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 13.33; % NG
	1218	 250.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 400.0	 100.0; % COW
	1238	 52.185	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 4.37; % NG
	1245	 55.865	 0.0	 20.0	 -20.0	 1.0	 100.0	 1	 100.0	 11.73; % NG
	1257	 118.75	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 37.5; % NG
	1262	 300.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 500.0	 100.0; % COW
	1263	 300.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 500.0	 100.0; % NG
	1264	 350.0	 0.0	 100.0	 -100.0	 1.0	 100.0	 1	 600.0	 100.0; % NG
	1273	 55.985	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 11.97; % NG
	1274	 132.01	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 64.02; % NG
	1278	 62.72	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 25.44; % COW
	1287	 59.295	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 18.59; % NG
	1288	 59.065	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 18.13; % NG
	1290	 56.85	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 13.7; % NG
	1298	 59.295	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 18.59; % NG
	1304	 62.305	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.61; % COW
	1305	 58.28	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 16.56; % NG
	1306	 131.675	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 63.35; % COW
	1308	 350.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	1310	 127.105	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 54.21; % NG
	1323	 500.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 800.0	 200.0; % COW
	1324	 62.72	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 25.44; % NG
	1329	 51.665	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 3.33; % NG
	1330	 62.035	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.07; % COW
	1335	 131.835	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 63.67; % NG
	1338	 58.55	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 17.1; % COW
	1339	 58.55	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 17.1; % NG
	1342	 58.55	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 17.1; % NG
	1343	 58.55	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 17.1; % NG
	1344	 128.225	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 56.45; % NG
	1348	 58.55	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 17.1; % NG
	1349	 60.67	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.34; % NG
	1359	 60.525	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.05; % NG
	1367	 66.11	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 32.22; % NG
	1369	 350.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	1372	 350.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	1376	 58.215	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 16.43; % NG
	1381	 118.485	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 36.97; % NG
	1382	 57.15	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 14.3; % COW
	1389	 300.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 500.0	 100.0; % COW
	1390	 300.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 500.0	 100.0; % NG
	1391	 300.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 500.0	 100.0; % COW
	1394	 350.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	1401	 350.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	1407	 129.295	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 58.59; % NG
	1408	 129.295	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 58.59; % NG
	1410	 130.39	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 60.78; % COW
	1411	 130.39	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 60.78; % NG
	1412	 130.39	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 60.78; % NG
	1413	 130.39	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 60.78; % NG
	1414	 129.295	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 58.59; % COW
	1415	 129.295	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 58.59; % NG
	1416	 130.39	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 60.78; % COW
	1417	 129.295	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 58.59; % NG
	1419	 57.405	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 14.81; % NG
	1421	 50.665	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 1.33; % PEL
	1423	 127.925	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 55.85; % NG
	1427	 130.625	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 61.25; % NG
	1433	 56.255	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 12.51; % NG
	1434	 56.255	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 12.51; % NG
	1435	 60.785	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.57; % NG
	1436	 60.785	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.57; % NG
	1437	 56.255	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 12.51; % COW
	1438	 56.255	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 12.51; % NG
	1440	 64.88	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 29.76; % NG
	1441	 60.785	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.57; % NG
	1447	 118.485	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 36.97; % COW
	1448	 118.485	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 36.97; % NG
	1449	 118.485	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 36.97; % NG
	1450	 118.485	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 36.97; % NG
	1451	 66.1	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 32.2; % NG
	1453	 66.1	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 32.2; % NG
	1454	 66.1	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 32.2; % NG
	1455	 60.425	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 20.85; % NG
	1458	 130.625	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 61.25; % NG
	1462	 132.01	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 64.02; % NG
	1469	 52.335	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 4.67; % COW
	1470	 130.035	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 60.07; % NG
	1471	 130.035	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 60.07; % NG
	1473	 130.035	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 60.07; % NG
	1474	 130.035	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 60.07; % NG
	1475	 130.035	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 60.07; % COW
	1476	 130.035	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 60.07; % NG
	1477	 56.025	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 12.05; % COW
	1478	 56.025	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 12.05; % NG
	1479	 56.025	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 12.05; % NG
	1484	 60.265	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 20.53; % NG
	1485	 60.265	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 20.53; % NG
	1486	 60.265	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 20.53; % NG
	1488	 50.4	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 0.8; % NG
	1505	 57.115	 5.0	 20.0	 -10.0	 1.0	 100.0	 1	 100.0	 14.23; % NG
	1514	 62.14	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.28; % NG
	1516	 62.93	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 25.86; % NG
	1517	 117.135	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 34.27; % NG
	1518	 117.135	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 34.27; % NG
	1519	 116.715	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 33.43; % NG
	1520	 116.715	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 33.43; % NG
	1521	 124.5	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 49.0; % NG
	1526	 57.335	 10.0	 20.0	 0.0	 1.0	 100.0	 1	 100.0	 14.67; % NG
	1532	 56.735	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 13.47; % NG
	1534	 132.505	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 65.01; % COW
	1546	 250.0	 30.0	 80.0	 -20.0	 1.0	 100.0	 1	 400.0	 100.0; % NG
	1552	 500.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 800.0	 200.0; % COW
	1553	 62.045	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.09; % COW
	1556	 60.525	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.05; % COW
	1557	 60.525	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.05; % NG
	1558	 60.525	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.05; % COW
	1559	 550.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 900.0	 200.0; % COW
	1560	 60.855	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.71; % NG
	1561	 300.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 500.0	 100.0; % NG
	1562	 51.165	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 2.33; % NG
	1577	 62.485	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.97; % NG
	1586	 132.605	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 65.21; % NG
	1587	 132.605	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 65.21; % NG
	1594	 64.935	 5.0	 50.0	 -40.0	 1.0	 100.0	 1	 100.0	 29.87; % COW
	1599	 51.28	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 2.56; % NG
	1606	 127.485	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 54.97; % NG
	1627	 300.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 500.0	 100.0; % COW
	1629	 58.76	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 17.52; % NG
	1631	 350.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	1636	 56.93	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 13.86; % NG
	1640	 53.5	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 7.0; % NG
	1641	 58.775	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 17.55; % NG
	1642	 54.05	 5.0	 10.0	 0.0	 1.0	 100.0	 1	 100.0	 8.1; % NG
	1644	 54.65	 5.0	 10.0	 0.0	 1.0	 100.0	 1	 100.0	 9.3; % COW
	1656	 900.0	 200.0	 520.0	 -120.0	 1.0	 100.0	 1	 1400.0	 400.0; % COW
	1661	 850.0	 200.0	 520.0	 -120.0	 1.0	 100.0	 1	 1300.0	 400.0; % COW
	1662	 58.685	 5.0	 20.0	 -10.0	 1.0	 100.0	 1	 100.0	 17.37; % NG
	1675	 850.0	 200.0	 520.0	 -120.0	 1.0	 100.0	 1	 1300.0	 400.0; % COW
	1685	 56.665	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 13.33; % NG
	1689	 1050.0	 200.0	 520.0	 -120.0	 1.0	 100.0	 1	 1600.0	 500.0; % COW
	1701	 63.495	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 26.99; % NG
	1726	 850.0	 200.0	 520.0	 -120.0	 1.0	 100.0	 1	 1300.0	 400.0; % COW
	1731	 63.935	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 27.87; % NG
	1732	 118.75	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 37.5; % NG
	1734	 250.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 400.0	 100.0; % NG
	1735	 250.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 400.0	 100.0; % NG
	1749	 60.425	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 20.85; % NG
	1750	 450.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 700.0	 200.0; % COW
	1751	 450.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 700.0	 200.0; % COW
	1757	 59.065	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 18.13; % NG
	1763	 58.28	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 16.56; % NG
	1764	 56.225	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 12.45; % NG
	1770	 132.375	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 64.75; % NG
	1772	 132.375	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 64.75; % NG
	1774	 127.105	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 54.21; % NG
	1791	 60.045	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 20.09; % NG
	1794	 62.035	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.07; % NG
	1796	 300.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 500.0	 100.0; % NG
	1801	 132.685	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 65.37; % NG
	1803	 59.215	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 18.43; % NG
	1805	 60.005	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 20.01; % NG
	1807	 60.005	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 20.01; % NG
	1808	 59.215	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 18.43; % COW
	1812	 127.295	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 54.59; % COW
	1813	 62.41	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.82; % NG
	1815	 57.985	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 15.97; % NG
	1816	 58.315	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 16.63; % NG
	1821	 250.0	 0.0	 90.0	 -90.0	 1.0	 100.0	 1	 400.0	 100.0; % NG
	1822	 300.0	 45.0	 150.0	 -60.0	 1.0	 100.0	 1	 500.0	 100.0; % NG
	1831	 59.655	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 19.31; % NG
	1834	 54.995	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 9.99; % NG
	1836	 51.195	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 2.39; % NG
	1839	 124.155	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 48.31; % COW
	1840	 450.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 700.0	 200.0; % COW
	1845	 128.75	 -10.0	 60.0	 -80.0	 1.0	 100.0	 1	 200.0	 57.5; % NG
	1851	 450.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 700.0	 200.0; % NUC
	1853	 62.6	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 25.2; % NG
	1868	 188.0	 10.0	 70.0	 -50.0	 1.0	 100.0	 1	 300.0	 76.0; % NG
	1869	 119.04	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 38.08; % NG
	1876	 118.515	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 37.03; % NG
	1877	 118.515	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 37.03; % COW
	1878	 118.515	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 37.03; % NG
	1879	 118.515	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 37.03; % NG
	1880	 118.515	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 37.03; % COW
	1881	 118.515	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 37.03; % NG
	1882	 65.42	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 30.84; % NG
	1883	 65.42	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 30.84; % NG
	1884	 65.42	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 30.84; % NG
	1889	 61.325	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.65; % NG
	1895	 57.835	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 15.67; % NG
	1896	 63.31	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 26.62; % NG
	1903	 51.735	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 3.47; % COW
	1906	 58.335	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 16.67; % NG
	1907	 56.035	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 12.07; % NG
	1913	 127.205	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 54.41; % NG
	1914	 127.205	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 54.41; % NG
	1928	 55.515	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 11.03; % NG
	1932	 550.0	 200.0	 520.0	 -120.0	 1.0	 100.0	 1	 900.0	 200.0; % NUC
	1935	 55.985	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 11.97; % NG
	1936	 55.985	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 11.97; % COW
	1940	 300.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 500.0	 100.0; % COW
	1949	 29.86	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 -40.28; % NG
	1955	 121.735	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 43.47; % NG
	1957	 54.27	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 8.54; % NG
	1959	 53.585	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 7.17; % PEL
	1960	 57.45	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 14.9; % NG
	1961	 55.835	 0.0	 20.0	 -20.0	 1.0	 100.0	 1	 100.0	 11.67; % NG
	1963	 122.765	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 45.53; % NG
	1966	 116.78	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 33.56; % NG
	1967	 116.78	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 33.56; % NG
	1969	 122.215	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 44.43; % NG
	1972	 62.14	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.28; % NG
	1985	 120.1	 0.0	 30.0	 -30.0	 1.0	 100.0	 1	 200.0	 40.2; % NG
	1988	 58.575	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 17.15; % NG
	1995	 450.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 700.0	 200.0; % COW
	1997	 1150.0	 200.0	 520.0	 -120.0	 1.0	 100.0	 1	 1800.0	 500.0; % COW
	1999	 61.885	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.77; % NG
	2000	 61.885	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.77; % NG
	2001	 63.04	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 26.08; % NG
	2003	 60.235	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 20.47; % NG
	2004	 60.235	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 20.47; % NG
	2005	 60.235	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 20.47; % NG
	2006	 59.685	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 19.37; % NG
	2011	 61.885	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.77; % NG
	2012	 118.105	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 36.21; % COW
	2013	 118.105	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 36.21; % NG
	2014	 118.105	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 36.21; % NG
	2020	 118.105	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 36.21; % NG
	2042	 -45.385	 -10.0	 30.0	 -50.0	 1.0	 100.0	 1	 100.0	 -190.77; % NG
	2047	 350.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	2048	 57.335	 5.0	 20.0	 -10.0	 1.0	 100.0	 1	 100.0	 14.67; % COW
	2053	 350.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	2063	 58.63	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 17.26; % COW
	2066	 119.835	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 39.67; % COW
	2067	 -349.995	 0.0	 100000.0	 -100000.0	 1.0	 100.0	 1	 100.0	 -799.99; % COW
	2069	 250.0	 35.0	 100.0	 -30.0	 1.0	 100.0	 1	 400.0	 100.0; % NG
	2071	 130.935	 0.0	 50.0	 -50.0	 1.0	 100.0	 1	 200.0	 61.87; % NG
	2080	 130.16	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 60.32; % NG
	2082	 119.525	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 39.05; % NG
	2084	 450.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 700.0	 200.0; % NUC
	2085	 119.525	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 39.05; % NG
	2086	 119.525	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 39.05; % NG
	2090	 350.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	2091	 350.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 600.0	 100.0; % NG
	2093	 350.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	2097	 250.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 400.0	 100.0; % NG
	2102	 56.795	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 13.59; % NG
	2106	 250.0	 40.0	 100.0	 -20.0	 1.0	 100.0	 1	 400.0	 100.0; % COW
	2107	 56.365	 5.0	 20.0	 -10.0	 1.0	 100.0	 1	 100.0	 12.73; % NG
	2119	 850.0	 200.0	 520.0	 -120.0	 1.0	 100.0	 1	 1300.0	 400.0; % COW
	2122	 58.4	 0.0	 20.0	 -20.0	 1.0	 100.0	 1	 100.0	 16.8; % NG
	2131	 64.7	 15.0	 50.0	 -20.0	 1.0	 100.0	 1	 100.0	 29.4; % NG
	2135	 850.0	 200.0	 520.0	 -120.0	 1.0	 100.0	 1	 1300.0	 400.0; % NUC
	2136	 850.0	 200.0	 520.0	 -120.0	 1.0	 100.0	 1	 1300.0	 400.0; % COW
	2137	 850.0	 200.0	 520.0	 -120.0	 1.0	 100.0	 1	 1300.0	 400.0; % COW
	2138	 850.0	 200.0	 520.0	 -120.0	 1.0	 100.0	 1	 1300.0	 400.0; % COW
	2139	 119.0	 0.0	 30.0	 -30.0	 1.0	 100.0	 1	 200.0	 38.0; % NG
	2143	 300.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 500.0	 100.0; % NG
	2144	 300.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 500.0	 100.0; % NG
	2146	 300.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 500.0	 100.0; % COW
	2147	 350.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 600.0	 100.0; % NG
	2148	 61.315	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.63; % COW
	2149	 61.315	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.63; % NG
	2153	 59.74	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 19.48; % NG
	2154	 57.425	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 14.85; % NG
	2155	 58.16	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 16.32; % NG
	2156	 60.435	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 20.87; % NG
	2157	 57.335	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 14.67; % NG
	2158	 58.16	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 16.32; % NG
	2166	 57.15	 5.0	 20.0	 -10.0	 1.0	 100.0	 1	 100.0	 14.3; % COW
	2167	 60.575	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.15; % COW
	2172	 124.925	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 49.85; % COW
	2176	 127.485	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 54.97; % NG
	2177	 127.485	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 54.97; % NG
	2178	 127.485	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 54.97; % COW
	2179	 127.485	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 54.97; % NG
	2180	 194.1	 0.0	 80.0	 -80.0	 1.0	 100.0	 1	 300.0	 88.2; % COW
	2183	 61.985	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.97; % NG
	2186	 250.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 400.0	 100.0; % NG
	2190	 64.515	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 29.03; % NG
	2192	 50.33	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 0.66; % PEL
	2197	 300.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 500.0	 100.0; % NG
	2198	 132.3	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 64.6; % NG
	2205	 52.645	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 5.29; % COW
	2210	 59.065	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 18.13; % NG
	2215	 59.125	 5.0	 30.0	 -20.0	 1.0	 100.0	 1	 100.0	 18.25; % NG
	2222	 58.47	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 16.94; % NG
	2223	 57.68	 0.0	 20.0	 -20.0	 1.0	 100.0	 1	 100.0	 15.36; % NG
	2236	 117.995	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 35.99; % NG
	2237	 64.935	 10.0	 40.0	 -20.0	 1.0	 100.0	 1	 100.0	 29.87; % COW
	2242	 62.035	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.07; % COW
	2246	 58.01	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 16.02; % COW
	2247	 60.65	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.3; % NG
	2248	 60.65	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.3; % COW
	2249	 60.65	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.3; % NG
	2252	 60.65	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.3; % COW
	2253	 60.005	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 20.01; % NG
	2260	 195.335	 40.0	 110.0	 -30.0	 1.0	 100.0	 1	 300.0	 90.67; % NG
	2266	 28.975	 -5.0	 10.0	 -20.0	 1.0	 100.0	 1	 100.0	 -42.05; % NG
	2268	 55.0	 5.0	 10.0	 0.0	 1.0	 100.0	 1	 100.0	 10.0; % NG
	2270	 54.665	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 9.33; % NG
	2278	 51.735	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 3.47; % NG
	2282	 60.575	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.15; % NG
	2283	 60.575	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.15; % COW
	2284	 60.575	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.15; % NG
	2285	 60.575	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.15; % COW
	2286	 250.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 400.0	 100.0; % COW
	2287	 250.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 400.0	 100.0; % NG
	2292	 57.575	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 15.15; % NG
	2301	 300.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 500.0	 100.0; % NG
	2302	 450.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 700.0	 200.0; % NUC
	2303	 193.835	 25.0	 70.0	 -20.0	 1.0	 100.0	 1	 300.0	 87.67; % NG
	2307	 58.15	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 16.3; % NG
	2308	 350.0	 0.0	 100.0	 -100.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	2318	 118.945	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 37.89; % COW
	2321	 118.945	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 37.89; % NG
	2322	 118.945	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 37.89; % NG
	2324	 57.765	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 15.53; % NG
	2325	 57.765	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 15.53; % COW
	2328	 61.435	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.87; % NG
	2329	 61.435	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.87; % NG
	2330	 61.435	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.87; % NG
	2331	 61.435	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.87; % NG
	2332	 61.325	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.65; % NG
	2333	 57.765	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 15.53; % NG
	2341	 50.835	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 1.67; % NG
	2345	 450.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 700.0	 200.0; % COW
	2347	 127.105	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 54.21; % COW
	2351	 53.325	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 6.65; % NG
	2357	 52.125	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 4.25; % NG
	2368	 124.935	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 49.87; % NG
	2369	 60.855	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.71; % NG
	2370	 60.855	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.71; % NG
	2371	 60.855	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.71; % NG
	2372	 128.1	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 56.2; % NG
	2373	 128.1	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 56.2; % NG
	2377	 128.1	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 56.2; % NG
	2389	 61.215	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.43; % NG
	2397	 52.335	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 4.67; % NG
	2408	 132.01	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 64.02; % NG
	2410	 55.355	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 10.71; % COW
	2411	 55.735	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 11.47; % NG
	2422	 51.125	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 2.25; % NG
	2428	 118.415	 0.0	 40.0	 -40.0	 1.0	 100.0	 1	 200.0	 36.83; % NG
	2429	 58.875	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 17.75; % NG
	2430	 250.0	 30.0	 100.0	 -40.0	 1.0	 100.0	 1	 400.0	 100.0; % NG
	2434	 300.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 500.0	 100.0; % NG
	2435	 128.405	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 56.81; % COW
	2436	 128.405	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 56.81; % COW
	2437	 128.405	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 56.81; % NG
	2438	 128.405	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 56.81; % NG
	2439	 128.405	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 56.81; % COW
	2440	 58.44	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 16.88; % NG
	2446	 127.295	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 54.59; % NG
	2447	 127.295	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 54.59; % NG
	2448	 127.295	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 54.59; % NG
	2458	 56.205	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 12.41; % NG
	2459	 62.305	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.61; % NG
	2460	 57.035	 5.0	 20.0	 -10.0	 1.0	 100.0	 1	 100.0	 14.07; % COW
	2462	 450.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 700.0	 200.0; % COW
	2464	 51.755	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 3.51; % NG
	2473	 62.93	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 25.86; % NG
	2480	 1150.0	 200.0	 520.0	 -120.0	 1.0	 100.0	 1	 1800.0	 500.0; % COW
	2481	 1150.0	 200.0	 520.0	 -120.0	 1.0	 100.0	 1	 1800.0	 500.0; % NG
	2482	 125.565	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 51.13; % NG
	2485	 61.435	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.87; % NG
	2486	 60.375	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 20.75; % NG
	2487	 60.375	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 20.75; % COW
	2488	 56.99	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 13.98; % COW
	2489	 56.99	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 13.98; % NG
	2490	 60.375	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 20.75; % NG
	2506	 65.75	 0.0	 20.0	 -20.0	 1.0	 100.0	 1	 100.0	 31.5; % NG
	2510	 130.895	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 61.79; % NG
	2513	 64.515	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 29.03; % NG
	2514	 64.515	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 29.03; % NG
	2515	 64.515	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 29.03; % NG
	2516	 64.515	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 29.03; % NG
	2518	 117.67	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 35.34; % COW
	2526	 50.3	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 0.6; % COW
	2533	 131.58	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 63.16; % NG
	2534	 130.15	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 60.3; % COW
	2539	 750.0	 0.0	 100000.0	 -100000.0	 1.0	 100.0	 1	 1200.0	 300.0; % NUC
	2540	 130.15	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 60.3; % NG
	2543	 130.15	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 60.3; % NG
	2559	 57.87	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 15.74; % NG
	2561	 57.935	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 15.87; % COW
	2566	 66.165	 0.0	 30.0	 -30.0	 1.0	 100.0	 1	 100.0	 32.33; % NG
	2569	 250.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 400.0	 100.0; % NG
	2571	 130.15	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 60.3; % NG
	2572	 131.58	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 63.16; % NG
	2573	 131.58	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 63.16; % NG
	2577	 130.15	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 60.3; % NG
	2584	 250.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 400.0	 100.0; % COW
	2592	 300.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 500.0	 100.0; % COW
	2603	 64.935	 5.0	 50.0	 -40.0	 1.0	 100.0	 1	 100.0	 29.87; % COW
	2606	 450.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 700.0	 200.0; % NG
	2607	 450.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 700.0	 200.0; % NG
	2610	 118.405	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 36.81; % COW
	2624	 350.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 600.0	 100.0; % NG
	2625	 300.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 500.0	 100.0; % COW
	2627	 350.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 600.0	 100.0; % NG
	2635	 63.935	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 27.87; % COW
	2642	 118.605	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 37.21; % NG
	2645	 62.24	 5.0	 30.0	 -20.0	 1.0	 100.0	 1	 100.0	 24.48; % NG
	2646	 116.775	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 33.55; % NG
	2647	 116.98	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 33.96; % NG
	2650	 131.835	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 63.67; % NG
	2651	 131.835	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 63.67; % COW
	2652	 132.635	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 65.27; % NG
	2653	 132.635	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 65.27; % COW
	2654	 132.635	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 65.27; % COW
	2655	 132.635	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 65.27; % NG
	2656	 132.635	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 65.27; % NG
	2657	 132.635	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 65.27; % NG
	2662	 62.72	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 25.44; % NG
	2666	 58.575	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 17.15; % NG
	2667	 58.575	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 17.15; % COW
	2669	 58.575	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 17.15; % NG
	2670	 126.595	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 53.19; % NG
	2676	 61.38	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.76; % NG
	2681	 130.16	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 60.32; % NG
	2687	 62.44	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.88; % NG
	2688	 63.385	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 26.77; % NG
	2690	 62.44	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.88; % NG
	2691	 51.755	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 3.51; % NG
	2693	 56.635	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 13.27; % NG
	2694	 56.635	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 13.27; % NG
	2695	 65.4	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 30.8; % NG
	2698	 62.265	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.53; % COW
	2700	 59.065	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 18.13; % COW
	2702	 55.555	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 11.11; % NG
	2703	 60.36	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 20.72; % NG
	2705	 60.36	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 20.72; % NG
	2708	 58.995	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 17.99; % NG
	2711	 59.17	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 18.34; % NG
	2712	 66.365	 5.0	 30.0	 -20.0	 1.0	 100.0	 1	 100.0	 32.73; % NG
	2717	 185.67	 0.0	 50.0	 -50.0	 1.0	 100.0	 1	 300.0	 71.34; % NG
	2721	 54.2	 5.0	 10.0	 0.0	 1.0	 100.0	 1	 100.0	 8.4; % NG
	2734	 126.07	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 52.14; % NG
	2756	 57.5	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 15.0; % COW
	2759	 300.0	 35.0	 100.0	 -30.0	 1.0	 100.0	 1	 500.0	 100.0; % COW
	2760	 450.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 700.0	 200.0; % NUC
	2767	 62.075	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.15; % NG
	2777	 60.425	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 20.85; % NG
	2783	 118.105	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 36.21; % NG
	2784	 51.4	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 2.8; % NG
	2785	 62.075	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.15; % NG
	2786	 62.93	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 25.86; % COW
	2787	 119.09	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 38.18; % NG
	2789	 124.955	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 49.91; % NG
	2790	 58.325	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 16.65; % COW
	2796	 61.325	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.65; % COW
	2799	 118.105	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 36.21; % NG
	2803	 59.125	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 18.25; % NG
	2810	 118.105	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 36.21; % NG
	2811	 350.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	2816	 55.0	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 10.0; % COW
	2819	 58.73	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 17.46; % NG
	2828	 131.015	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 62.03; % NG
	2831	 57.665	 0.0	 20.0	 -20.0	 1.0	 100.0	 1	 100.0	 15.33; % NG
	2836	 56.195	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 12.39; % NG
	2838	 57.24	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 14.48; % NG
	2840	 60.99	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.98; % NG
	2841	 60.99	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.98; % NG
	2842	 56.195	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 12.39; % NG
	2844	 57.015	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 14.03; % PEL
	2845	 57.24	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 14.48; % NG
	2852	 60.0	 0.0	 30.0	 -30.0	 1.0	 100.0	 1	 100.0	 20.0; % NG
	2858	 60.88	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.76; % NG
	2870	 64.115	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 28.23; % NG
	2871	 60.88	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.76; % NG
	2877	 62.14	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.28; % NG
	2880	 350.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 600.0	 100.0; % NG
	2881	 350.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	2894	 500.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 800.0	 200.0; % PEL
	2895	 300.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 500.0	 100.0; % COW
	2901	 450.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 700.0	 200.0; % COW
	2902	 450.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 700.0	 200.0; % COW
	2906	 53.035	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 6.07; % COW
	2912	 56.515	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 13.03; % NG
	2933	 51.26	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 2.52; % NG
	2934	 300.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 500.0	 100.0; % NG
	2950	 -44.975	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 -189.95; % NG
	2955	 60.685	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.37; % COW
	2963	 61.455	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.91; % NG
	2964	 61.855	 5.0	 20.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.71; % NG
	2968	 62.0	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.0; % COW
	2969	 62.0	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.0; % NG
	2970	 55.57	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 11.14; % NG
	2973	 62.0	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.0; % COW
	2974	 62.0	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.0; % NG
	2976	 128.225	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 56.45; % COW
	2978	 61.945	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.89; % COW
	2979	 61.945	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.89; % NG
	2980	 61.945	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.89; % COW
	2981	 64.905	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 29.81; % NG
	2982	 64.905	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 29.81; % NG
	2984	 60.415	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 20.83; % COW
	2990	 250.0	 25.0	 100.0	 -50.0	 1.0	 100.0	 1	 400.0	 100.0; % COW
	2991	 124.785	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 49.57; % NG
	2994	 116.665	 5.0	 30.0	 -20.0	 1.0	 100.0	 1	 200.0	 33.33; % COW
	3012	 300.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 500.0	 100.0; % COW
	3013	 350.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	3015	 250.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 400.0	 100.0; % NG
	3017	 131.58	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 63.16; % NG
	3021	 131.58	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 63.16; % NG
	3022	 131.58	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 63.16; % NG
	3029	 130.16	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 60.32; % NG
	3031	 62.405	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.81; % COW
	3050	 129.115	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 58.23; % NG
	3058	 65.52	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 31.04; % PEL
	3061	 59.295	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 18.59; % NG
	3062	 59.295	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 18.59; % NG
	3063	 59.785	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 19.57; % NG
	3065	 350.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	3068	 1150.0	 200.0	 520.0	 -120.0	 1.0	 100.0	 1	 1800.0	 500.0; % NG
	3072	 450.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 700.0	 200.0; % NUC
	3074	 450.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 700.0	 200.0; % COW
	3082	 118.415	 0.0	 30.0	 -30.0	 1.0	 100.0	 1	 200.0	 36.83; % NG
	3093	 300.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 500.0	 100.0; % NG
	3094	 250.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 400.0	 100.0; % COW
	3095	 500.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 800.0	 200.0; % COW
	3096	 250.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 400.0	 100.0; % COW
	3097	 500.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 800.0	 200.0; % COW
	3098	 500.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 800.0	 200.0; % COW
	3100	 300.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 500.0	 100.0; % NG
	3101	 300.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 500.0	 100.0; % NG
	3103	 128.065	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 56.13; % NG
	3104	 128.065	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 56.13; % NG
	3107	 61.125	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.25; % COW
	3108	 61.125	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.25; % NG
	3109	 61.125	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.25; % COW
	3111	 61.125	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.25; % NG
	3112	 58.345	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 16.69; % NG
	3113	 60.025	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 20.05; % NG
	3114	 58.125	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 16.25; % NG
	3121	 131.875	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 63.75; % NG
	3122	 131.875	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 63.75; % NG
	3123	 500.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 800.0	 200.0; % COW
	3124	 500.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 800.0	 200.0; % COW
	3127	 250.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 400.0	 100.0; % COW
	3128	 500.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 800.0	 200.0; % COW
	3130	 500.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 800.0	 200.0; % COW
	3134	 127.435	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 54.87; % NG
	3135	 127.435	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 54.87; % NG
	3136	 127.435	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 54.87; % NG
	3137	 127.435	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 54.87; % NG
	3139	 129.115	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 58.23; % NG
	3141	 56.855	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 13.71; % NG
	3142	 56.855	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 13.71; % NG
	3143	 60.95	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.9; % NG
	3145	 130.105	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 60.21; % NG
	3146	 63.935	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 27.87; % NG
	3148	 52.455	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 4.91; % NG
	3152	 450.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 700.0	 200.0; % COW
	3154	 129.91	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 59.82; % NG
	3164	 51.755	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 3.51; % NG
	3165	 300.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 500.0	 100.0; % COW
	3166	 56.97	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 13.94; % NG
	3167	 300.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 500.0	 100.0; % NG
	3168	 300.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 500.0	 100.0; % NG
	3169	 300.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 500.0	 100.0; % NG
	3176	 62.265	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.53; % NG
	3178	 250.0	 40.0	 100.0	 -20.0	 1.0	 100.0	 1	 400.0	 100.0; % NG
	3179	 350.0	 35.0	 100.0	 -30.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	3184	 58.4	 0.0	 20.0	 -20.0	 1.0	 100.0	 1	 100.0	 16.8; % COW
	3186	 131.425	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 62.85; % NG
	3201	 250.0	 15.0	 100.0	 -70.0	 1.0	 100.0	 1	 400.0	 100.0; % COW
	3206	 58.45	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 16.9; % NG
	3210	 120.025	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 40.05; % NG
	3213	 120.025	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 40.05; % NG
	3214	 120.025	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 40.05; % NG
	3215	 120.025	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 40.05; % NG
	3216	 120.025	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 40.05; % COW
	3217	 127.835	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 55.67; % NG
	3219	 120.025	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 40.05; % NG
	3220	 120.025	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 40.05; % NG
	3224	 300.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 500.0	 100.0; % COW
	3225	 62.44	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.88; % NG
	3228	 55.425	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 10.85; % NG
	3233	 62.44	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.88; % COW
	3234	 57.455	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 14.91; % NG
	3236	 60.335	 0.0	 20.0	 -20.0	 1.0	 100.0	 1	 100.0	 20.67; % NG
	3248	 62.305	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.61; % NG
	3255	 450.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 700.0	 200.0; % NUC
	3265	 1300.0	 200.0	 520.0	 -120.0	 1.0	 100.0	 1	 2000.0	 600.0; % NG
	3270	 53.315	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 6.63; % NG
	3280	 300.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 500.0	 100.0; % COW
	3282	 128.87	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 57.74; % COW
	3283	 128.87	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 57.74; % COW
	3284	 128.87	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 57.74; % NG
	3292	 64.43	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 100.0	 28.86; % NG
	3294	 300.0	 45.0	 190.0	 -100.0	 1.0	 100.0	 1	 500.0	 100.0; % NG
	3296	 124.205	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 48.41; % COW
	3297	 65.46	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 30.92; % NG
	3298	 65.46	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 30.92; % NG
	3299	 65.46	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 30.92; % NG
	3306	 65.46	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 30.92; % NG
	3307	 65.46	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 30.92; % NG
	3308	 62.805	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 25.61; % COW
	3309	 62.805	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 25.61; % NG
	3323	 59.61	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 19.22; % COW
	3325	 58.24	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 16.48; % NG
	3326	 58.24	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 16.48; % NG
	3327	 58.905	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 17.81; % NG
	3328	 58.905	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 17.81; % COW
	3329	 131.015	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 62.03; % NG
	3330	 57.04	 5.0	 20.0	 -10.0	 1.0	 100.0	 1	 100.0	 14.08; % NG
	3334	 57.375	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 14.75; % NG
	3335	 57.375	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 14.75; % NG
	3336	 57.375	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 14.75; % NG
	3337	 57.375	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 14.75; % NG
	3338	 58.285	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 16.57; % NG
	3339	 57.375	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 14.75; % NG
	3343	 65.18	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 30.36; % NG
	3344	 250.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 400.0	 100.0; % NG
	3348	 51.735	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 3.47; % NG
	3351	 56.42	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 12.84; % NG
	3352	 127.005	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 54.01; % NG
	3360	 50.145	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 0.29; % NG
	3361	 58.585	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 17.17; % NG
	3365	 131.815	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 63.63; % COW
	3366	 131.815	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 63.63; % NG
	3367	 131.815	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 63.63; % NG
	3368	 131.815	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 63.63; % COW
	3369	 250.0	 35.0	 100.0	 -30.0	 1.0	 100.0	 1	 400.0	 100.0; % COW
	3371	 56.585	 0.0	 20.0	 -20.0	 1.0	 100.0	 1	 100.0	 13.17; % NG
	3384	 61.985	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.97; % NG
	3385	 52.915	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 5.83; % NG
	3396	 61.895	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.79; % NG
	3403	 122.56	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 45.12; % NG
	3404	 62.035	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.07; % NG
	3409	 55.175	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 10.35; % NG
	3410	 59.975	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 19.95; % NG
	3412	 128.805	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 57.61; % NG
	3414	 128.805	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 57.61; % COW
	3415	 128.805	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 57.61; % NG
	3416	 128.805	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 57.61; % NG
	3418	 129.065	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 58.13; % COW
	3419	 129.065	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 58.13; % NG
	3432	 59.8	 5.0	 40.0	 -30.0	 1.0	 100.0	 1	 100.0	 19.6; % NG
	3451	 850.0	 200.0	 520.0	 -120.0	 1.0	 100.0	 1	 1300.0	 400.0; % COW
	3456	 60.895	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.79; % NG
	3463	 300.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 500.0	 100.0; % COW
	3468	 62.41	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.82; % NG
	3469	 124.64	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 200.0	 49.28; % NG
	3471	 62.555	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 25.11; % NG
	3481	 61.915	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.83; % NG
	3482	 128.225	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 56.45; % NG
	3485	 65.98	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 31.96; % COW
	3487	 65.98	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 31.96; % COW
	3488	 55.245	 -5.0	 10.0	 -20.0	 1.0	 100.0	 1	 100.0	 10.49; % NG
	3489	 65.98	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 31.96; % COW
	3490	 65.98	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 31.96; % NG
	3491	 62.685	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 25.37; % NG
	3494	 500.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 800.0	 200.0; % COW
	3495	 500.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 800.0	 200.0; % COW
	3496	 500.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 800.0	 200.0; % COW
	3499	 60.435	 0.0	 20.0	 -20.0	 1.0	 100.0	 1	 100.0	 20.87; % NG
	3508	 58.285	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 16.57; % NG
	3515	 126.8	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 53.6; % NG
	3517	 60.595	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.19; % NG
	3520	 61.225	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.45; % COW
	3521	 61.225	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.45; % COW
	3523	 61.225	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.45; % NG
	3524	 61.225	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.45; % NG
	3525	 61.225	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.45; % COW
	3526	 61.225	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.45; % NG
	3528	 127.32	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 54.64; % NG
	3529	 127.32	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 54.64; % NG
	3530	 127.32	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 54.64; % NG
	3535	 130.16	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 60.32; % COW
	3543	 59.885	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 19.77; % NG
	3551	 300.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 500.0	 100.0; % COW
	3553	 300.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 500.0	 100.0; % COW
	3557	 1150.0	 200.0	 520.0	 -120.0	 1.0	 100.0	 1	 1800.0	 500.0; % COW
	3558	 1150.0	 200.0	 520.0	 -120.0	 1.0	 100.0	 1	 1800.0	 500.0; % NUC
	3567	 116.665	 5.0	 30.0	 -20.0	 1.0	 100.0	 1	 200.0	 33.33; % NG
	3569	 62.74	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 25.48; % NG
	3571	 60.485	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 20.97; % NG
	3577	 62.93	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 25.86; % COW
	3580	 57.845	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 15.69; % NG
	3582	 57.845	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 15.69; % NG
	3585	 350.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	3586	 350.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 600.0	 100.0; % NG
	3587	 300.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 500.0	 100.0; % NG
	3588	 300.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 500.0	 100.0; % COW
	3593	 64.395	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 28.79; % NG
	3607	 300.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 500.0	 100.0; % COW
	3608	 56.66	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 13.32; % NG
	3610	 450.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 700.0	 200.0; % PEL
	3611	 450.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 700.0	 200.0; % COW
	3617	 57.255	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 14.51; % NG
	3619	 60.015	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 20.03; % NG
	3620	 60.015	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 20.03; % NG
	3621	 59.92	 5.0	 20.0	 -10.0	 1.0	 100.0	 1	 100.0	 19.84; % NG
	3625	 59.945	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 19.89; % NG
	3631	 126.665	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 53.33; % NG
	3633	 58.915	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 17.83; % NG
	3641	 55.755	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 11.51; % NG
	3642	 55.755	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 11.51; % NG
	3644	 129.115	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 58.23; % NG
	3646	 57.67	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 15.34; % NG
	3647	 127.115	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 54.23; % NG
	3651	 132.095	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 64.19; % NG
	3655	 131.425	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 62.85; % NG
	3656	 132.095	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 64.19; % NG
	3663	 133.235	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 66.47; % NG
	3671	 131.035	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 62.07; % NG
	3672	 131.035	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 62.07; % NG
	3674	 51.425	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 2.85; % COW
	3675	 51.755	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 3.51; % COW
	3680	 56.97	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 13.94; % COW
	3682	 55.665	 5.0	 20.0	 -10.0	 1.0	 100.0	 1	 100.0	 11.33; % COW
	3683	 62.265	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.53; % NG
	3686	 117.71	 0.0	 40.0	 -40.0	 1.0	 100.0	 1	 200.0	 35.42; % NG
	3695	 118.275	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 36.55; % COW
	3696	 118.275	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 36.55; % NG
	3697	 118.275	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 36.55; % NG
	3698	 118.275	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 36.55; % NG
	3699	 118.275	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 36.55; % NG
	3700	 118.275	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 36.55; % NG
	3701	 118.275	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 36.55; % COW
	3710	 131.675	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 63.35; % NG
	3712	 62.2	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.4; % NG
	3714	 62.2	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.4; % COW
	3717	 130.47	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 60.94; % NG
	3718	 130.47	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 60.94; % NG
	3720	 130.47	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 60.94; % NG
	3724	 750.0	 200.0	 520.0	 -120.0	 1.0	 100.0	 1	 1200.0	 300.0; % COW
	3728	 124.93	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 49.86; % NG
	3729	 124.93	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 49.86; % NG
	3738	 58.335	 5.0	 10.0	 0.0	 1.0	 100.0	 1	 100.0	 16.67; % COW
	3754	 350.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	3757	 350.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	3763	 65.46	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 30.92; % NG
	3771	 58.855	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 17.71; % NG
	3781	 126.8	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 53.6; % NG
	3782	 126.8	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 53.6; % NG
	3787	 126.8	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 53.6; % COW
	3792	 124.205	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 48.41; % NG
	3797	 450.0	 20.0	 180.0	 -140.0	 1.0	 100.0	 1	 700.0	 200.0; % COW
	3800	 123.14	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 46.28; % NG
	3810	 57.425	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 14.85; % NG
	3811	 62.685	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 25.37; % COW
	3812	 62.685	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 25.37; % NG
	3814	 52.425	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 4.85; % NG
	3815	 58.77	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 17.54; % NG
	3816	 58.77	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 17.54; % COW
	3820	 57.425	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 14.85; % NG
	3823	 124.935	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 49.87; % NG
	3838	 58.765	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 17.53; % NG
	3842	 51.065	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 2.13; % NG
	3845	 62.36	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.72; % PEL
	3848	 53.0	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 6.0; % NG
	3853	 61.25	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.5; % NG
	3854	 60.3	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 20.6; % NG
	3857	 65.42	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 30.84; % COW
	3866	 300.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 500.0	 100.0; % COW
	3867	 300.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 500.0	 100.0; % COW
	3872	 52.0	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 4.0; % NG
	3877	 61.985	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.97; % NG
	3878	 59.225	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 18.45; % NG
	3880	 56.035	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 12.07; % NG
	3893	 55.36	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 10.72; % NG
	3894	 51.28	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 2.56; % NG
	3899	 62.14	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.28; % NG
	3903	 66.36	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 100.0	 32.72; % NG
	3904	 131.255	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 62.51; % COW
	3906	 59.64	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 19.28; % NG
	3907	 59.64	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 19.28; % COW
	3908	 59.64	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 19.28; % NG
	3909	 59.64	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 19.28; % NG
	3910	 59.64	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 19.28; % COW
	3911	 59.64	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 19.28; % NG
	3912	 66.445	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 32.89; % NG
	3913	 117.565	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 35.13; % NG
	3914	 131.255	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 62.51; % NG
	3915	 62.255	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.51; % NG
	3916	 59.375	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 18.75; % NG
	3922	 183.43	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 300.0	 66.86; % NG
	3926	 300.0	 45.0	 140.0	 -50.0	 1.0	 100.0	 1	 500.0	 100.0; % NG
	3929	 56.105	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 12.21; % NG
	3934	 60.155	 5.0	 20.0	 -10.0	 1.0	 100.0	 1	 100.0	 20.31; % NG
	3939	 300.0	 35.0	 130.0	 -60.0	 1.0	 100.0	 1	 500.0	 100.0; % COW
	3943	 250.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 400.0	 100.0; % COW
	3947	 60.025	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 20.05; % NG
	3948	 119.6	 0.0	 30.0	 -30.0	 1.0	 100.0	 1	 200.0	 39.2; % NG
	3962	 129.44	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 58.88; % NG
	3968	 64.7	 15.0	 50.0	 -20.0	 1.0	 100.0	 1	 100.0	 29.4; % NG
	3971	 124.155	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 48.31; % NG
	3984	 300.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 500.0	 100.0; % NG
	3990	 59.065	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 18.13; % NG
	3997	 132.3	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 64.6; % NG
	4000	 183.47	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 300.0	 66.94; % NG
	4004	 130.16	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 60.32; % NG
	4009	 50.025	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 0.05; % NG
	4011	 58.415	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 16.83; % COW
	4013	 300.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 500.0	 100.0; % COW
	4020	 59.35	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 18.7; % NG
	4021	 59.35	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 18.7; % NG
	4022	 62.99	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 25.98; % NG
	4024	 59.14	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 18.28; % COW
	4025	 59.14	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 18.28; % COW
	4026	 57.995	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 15.99; % NG
	4027	 57.995	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 15.99; % COW
	4039	 60.305	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 20.61; % NG
	4040	 60.305	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 20.61; % NG
	4041	 55.94	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 11.88; % NG
	4042	 60.305	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 20.61; % NG
	4043	 59.54	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 19.08; % NG
	4044	 59.54	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 19.08; % NG
	4045	 63.195	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 26.39; % NG
	4047	 62.145	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.29; % NG
	4048	 58.99	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 17.98; % NG
	4049	 59.855	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 19.71; % NG
	4052	 64.21	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 28.42; % NG
	4053	 130.105	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 60.21; % NG
	4054	 130.105	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 60.21; % NG
	4056	 130.105	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 60.21; % NG
	4057	 128.95	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 57.9; % COW
	4058	 128.95	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 57.9; % NG
	4059	 128.95	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 57.9; % NG
	4060	 128.95	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 57.9; % NG
	4061	 128.95	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 57.9; % NG
	4062	 128.95	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 57.9; % NG
	4063	 64.43	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 100.0	 28.86; % COW
	4066	 66.625	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 33.25; % NG
	4067	 66.625	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 33.25; % PEL
	4068	 66.625	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 33.25; % COW
	4069	 66.625	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 33.25; % COW
	4074	 60.64	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.28; % NG
	4083	 350.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	4084	 350.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 600.0	 100.0; % NG
	4085	 51.665	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 3.33; % NG
	4087	 350.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 600.0	 100.0; % PEL
	4102	 450.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 700.0	 200.0; % COW
	4116	 -45.915	 0.0	 20.0	 -20.0	 1.0	 100.0	 1	 100.0	 -191.83; % COW
	4120	 124.925	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 49.85; % COW
	4126	 61.475	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.95; % NG
	4130	 300.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 500.0	 100.0; % COW
	4133	 62.265	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.53; % NG
	4135	 63.495	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 26.99; % COW
	4136	 119.905	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 39.81; % NG
	4137	 126.065	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 52.13; % NG
	4138	 126.065	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 52.13; % NG
	4139	 126.065	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 52.13; % NG
	4140	 126.07	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 52.14; % NG
	4141	 126.07	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 52.14; % NG
	4143	 126.07	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 52.14; % NG
	4144	 125.445	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 50.89; % NG
	4145	 131.875	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 63.75; % NG
	4151	 59.75	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 19.5; % NG
	4152	 60.765	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.53; % NG
	4154	 60.905	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.81; % COW
	4155	 125.565	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 51.13; % NG
	4156	 125.565	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 51.13; % NG
	4157	 132.385	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 64.77; % NG
	4158	 132.385	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 64.77; % NG
	4159	 123.155	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 46.31; % NG
	4160	 132.385	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 64.77; % NG
	4161	 123.155	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 46.31; % NG
	4162	 60.545	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.09; % NG
	4163	 124.645	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 49.29; % NG
	4164	 124.645	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 49.29; % NG
	4166	 56.195	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 12.39; % NG
	4167	 60.525	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.05; % COW
	4171	 59.315	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 18.63; % NG
	4181	 63.145	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 26.29; % NG
	4182	 126.915	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 53.83; % NG
	4183	 126.915	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 53.83; % NG
	4185	 126.915	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 53.83; % NG
	4187	 126.915	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 53.83; % NG
	4190	 116.665	 5.0	 30.0	 -20.0	 1.0	 100.0	 1	 200.0	 33.33; % NG
	4191	 62.265	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.53; % NG
	4193	 62.835	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 25.67; % COW
	4195	 450.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 700.0	 200.0; % COW
	4196	 51.665	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 3.33; % NG
	4197	 500.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 800.0	 200.0; % COW
	4200	 57.015	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 14.03; % NG
	4202	 450.0	 0.0	 100.0	 -100.0	 1.0	 100.0	 1	 700.0	 200.0; % NUC
	4203	 124.935	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 49.87; % NG
	4206	 116.765	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 33.53; % NG
	4207	 130.445	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 60.89; % NG
	4208	 250.0	 25.0	 100.0	 -50.0	 1.0	 100.0	 1	 400.0	 100.0; % NG
	4209	 131.675	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 63.35; % NG
	4214	 130.445	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 60.89; % NG
	4217	 58.45	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 16.9; % NG
	4226	 350.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	4234	 65.125	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 100.0	 30.25; % NG
	4235	 54.1	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 8.2; % NG
	4237	 52.175	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 4.35; % NG
	4240	 122.335	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 44.67; % NG
	4242	 124.055	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 48.11; % NG
	4245	 300.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 500.0	 100.0; % NG
	4252	 61.62	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.24; % COW
	4253	 250.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 400.0	 100.0; % NG
	4254	 250.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 400.0	 100.0; % COW
	4256	 57.46	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 14.92; % COW
	4259	 52.8	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 5.6; % NG
	4261	 250.0	 35.0	 100.0	 -30.0	 1.0	 100.0	 1	 400.0	 100.0; % NG
	4264	 62.14	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.28; % NG
	4267	 62.265	 0.0	 30.0	 -30.0	 1.0	 100.0	 1	 100.0	 24.53; % NG
	4274	 300.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 500.0	 100.0; % COW
	4282	 62.075	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.15; % NG
	4284	 131.75	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 63.5; % NG
	4285	 131.75	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 63.5; % COW
	4286	 131.75	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 63.5; % NG
	4287	 131.75	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 63.5; % NG
	4288	 131.75	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 63.5; % NG
	4290	 131.75	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 63.5; % NG
	4298	 62.93	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 25.86; % NG
	4301	 131.015	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 62.03; % NG
	4309	 124.205	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 48.41; % NG
	4310	 500.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 800.0	 200.0; % COW
	4314	 66.27	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 32.54; % NG
	4324	 59.27	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 18.54; % NG
	4326	 59.81	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 19.62; % NG
	4331	 116.665	 5.0	 30.0	 -20.0	 1.0	 100.0	 1	 200.0	 33.33; % NG
	4337	 56.72	 5.0	 20.0	 -10.0	 1.0	 100.0	 1	 100.0	 13.44; % COW
	4339	 62.56	 5.0	 20.0	 -10.0	 1.0	 100.0	 1	 100.0	 25.12; % COW
	4343	 66.27	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 32.54; % NG
	4344	 56.245	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 12.49; % NG
	4345	 66.27	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 32.54; % NG
	4347	 127.925	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 55.85; % NG
	4353	 116.865	 5.0	 30.0	 -20.0	 1.0	 100.0	 1	 200.0	 33.73; % NG
	4354	 62.36	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.72; % NG
	4366	 58.335	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 16.67; % PEL
	4367	 500.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 800.0	 200.0; % COW
	4371	 450.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 700.0	 200.0; % COW
	4376	 450.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 700.0	 200.0; % COW
	4378	 450.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 700.0	 200.0; % COW
	4379	 450.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 700.0	 200.0; % COW
	4380	 450.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 700.0	 200.0; % COW
	4384	 62.675	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 25.35; % NG
	4385	 56.305	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 12.61; % COW
	4386	 56.305	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 12.61; % NG
	4387	 56.305	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 12.61; % NG
	4392	 59.8	 10.0	 40.0	 -20.0	 1.0	 100.0	 1	 100.0	 19.6; % NG
	4393	 120.87	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 41.74; % NG
	4400	 350.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	4403	 119.17	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 38.34; % NG
	4405	 58.215	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 16.43; % NG
	4411	 63.145	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 26.29; % NG
	4422	 117.995	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 35.99; % NG
	4423	 50.835	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 1.67; % NG
	4424	 117.995	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 35.99; % COW
	4425	 117.995	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 35.99; % NG
	4426	 59.32	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 18.64; % NG
	4427	 59.32	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 18.64; % NG
	4430	 55.695	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 11.39; % PEL
	4432	 59.245	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 18.49; % COW
	4433	 59.245	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 18.49; % NG
	4434	 59.245	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 18.49; % COW
	4440	 62.255	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.51; % NG
	4443	 500.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 800.0	 200.0; % COW
	4448	 350.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	4449	 61.455	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.91; % NG
	4451	 65.785	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 31.57; % NG
	4452	 300.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 500.0	 100.0; % NG
	4453	 65.785	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 31.57; % COW
	4454	 63.275	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 26.55; % NG
	4455	 119.505	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 39.01; % NG
	4456	 63.275	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 26.55; % NG
	4457	 63.275	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 26.55; % COW
	4458	 64.11	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 28.22; % NG
	4460	 117.51	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 35.02; % NG
	4461	 65.785	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 31.57; % NG
	4470	 131.875	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 63.75; % NG
	4473	 250.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 400.0	 100.0; % NG
	4480	 55.88	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 11.76; % NG
	4481	 61.09	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.18; % COW
	4483	 60.995	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.99; % NG
	4484	 61.095	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.19; % NG
	4488	 51.215	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 2.43; % NG
	4495	 183.47	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 300.0	 66.94; % NG
	4499	 124.155	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 48.31; % NG
	4501	 60.84	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.68; % NG
	4505	 300.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 500.0	 100.0; % COW
	4509	 750.0	 200.0	 520.0	 -120.0	 1.0	 100.0	 1	 1200.0	 300.0; % COW
	4512	 60.84	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.68; % COW
	4513	 56.775	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 13.55; % NG
	4517	 350.0	 0.0	 100.0	 -100.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	4526	 128.335	 0.0	 60.0	 -60.0	 1.0	 100.0	 1	 200.0	 56.67; % NG
	4534	 60.015	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 20.03; % NG
	4535	 60.015	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 20.03; % NG
	4537	 60.015	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 20.03; % NG
	4539	 60.45	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 20.9; % COW
	4540	 57.34	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 14.68; % NG
	4547	 61.03	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.06; % COW
	4548	 61.03	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.06; % NG
	4549	 61.03	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.06; % NG
	4550	 61.03	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.06; % NG
	4551	 61.03	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.06; % COW
	4552	 61.03	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.06; % NG
	4553	 59.65	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 19.3; % NG
	4554	 61.03	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.06; % NG
	4563	 59.61	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 19.22; % NG
	4572	 60.82	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.64; % NG
	4573	 130.16	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 60.32; % NG
	4576	 127.535	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 55.07; % NG
	4577	 127.535	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 55.07; % COW
	4578	 127.535	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 55.07; % NG
	4580	 127.535	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 55.07; % NG
	4585	 130.8	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 61.6; % NG
	4590	 59.6	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 19.2; % NG
	4594	 60.64	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.28; % NG
	4598	 126.125	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 52.25; % NG
	4602	 126.125	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 52.25; % NG
	4603	 126.125	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 52.25; % NG
	4604	 126.125	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 52.25; % NG
	4607	 57.69	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 15.38; % NG
	4611	 50.33	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 0.66; % NG
	4612	 350.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	4614	 57.5	 5.0	 10.0	 0.0	 1.0	 100.0	 1	 100.0	 15.0; % COW
	4616	 450.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 700.0	 200.0; % COW
	4617	 63.26	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 26.52; % COW
	4618	 56.665	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 13.33; % NG
	4619	 56.665	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 13.33; % NG
	4622	 250.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 400.0	 100.0; % NG
	4626	 64.39	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 28.78; % NG
	4627	 64.39	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 28.78; % COW
	4630	 64.39	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 28.78; % NG
	4631	 64.39	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 28.78; % COW
	4633	 64.39	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 28.78; % NG
	4634	 64.39	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 28.78; % NG
	4635	 64.39	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 28.78; % NG
	4643	 53.455	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 6.91; % COW
	4644	 54.92	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 9.84; % NG
	4648	 57.1	 5.0	 20.0	 -10.0	 1.0	 100.0	 1	 100.0	 14.2; % COW
	4652	 127.895	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 55.79; % NG
	4655	 300.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 500.0	 100.0; % COW
	4656	 300.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 500.0	 100.0; % COW
	4657	 300.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 500.0	 100.0; % NG
	4658	 300.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 500.0	 100.0; % COW
	4662	 65.695	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 100.0	 31.39; % COW
	4663	 65.695	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 100.0	 31.39; % COW
	4664	 128.445	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 56.89; % NG
	4665	 128.445	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 56.89; % COW
	4666	 117.605	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 35.21; % COW
	4668	 60.435	 0.0	 20.0	 -20.0	 1.0	 100.0	 1	 100.0	 20.87; % NG
	4670	 450.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 700.0	 200.0; % COW
	4671	 62.93	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 25.86; % NG
	4675	 63.495	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 26.99; % NG
	4676	 122.61	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 45.22; % NG
	4677	 122.61	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 45.22; % NG
	4678	 122.61	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 45.22; % NG
	4679	 128.965	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 57.93; % NG
	4680	 128.965	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 57.93; % NG
	4683	 126.59	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 53.18; % COW
	4686	 116.985	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 33.97; % NG
	4690	 60.855	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.71; % NG
	4691	 129.975	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 59.95; % NG
	4692	 300.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 500.0	 100.0; % COW
	4694	 60.855	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.71; % NG
	4695	 350.0	 50.0	 140.0	 -40.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	4697	 120.27	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 40.54; % NG
	4698	 129.975	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 59.95; % NG
	4699	 129.975	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 59.95; % NG
	4702	 60.855	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.71; % NG
	4703	 118.405	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 36.81; % NG
	4704	 65.0	 0.0	 30.0	 -30.0	 1.0	 100.0	 1	 100.0	 30.0; % NG
	4707	 60.855	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.71; % NG
	4709	 56.255	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 12.51; % COW
	4710	 500.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 800.0	 200.0; % COW
	4715	 58.45	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 16.9; % NG
	4718	 350.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	4722	 130.645	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 61.29; % NG
	4723	 130.645	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 61.29; % NG
	4724	 130.645	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 61.29; % NG
	4725	 130.645	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 61.29; % NG
	4726	 130.645	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 61.29; % NG
	4727	 130.645	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 61.29; % NG
	4728	 130.645	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 61.29; % NG
	4729	 130.645	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 61.29; % NG
	4733	 58.865	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 17.73; % NG
	4738	 58.865	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 17.73; % NG
	4745	 118.69	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 37.38; % NG
	4746	 50.49	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 0.98; % COW
	4751	 130.625	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 61.25; % NG
	4752	 129.615	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 59.23; % NG
	4753	 130.625	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 61.25; % NG
	4757	 350.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	4763	 62.035	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.07; % NG
	4764	 64.115	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 28.23; % NG
	4770	 119.505	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 39.01; % NG
	4771	 62.48	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.96; % NG
	4772	 119.505	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 39.01; % NG
	4773	 119.505	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 39.01; % NG
	4774	 62.485	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.97; % NG
	4775	 66.665	 0.0	 20.0	 -20.0	 1.0	 100.0	 1	 100.0	 33.33; % COW
	4777	 61.62	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.24; % NG
	4786	 120.835	 10.0	 20.0	 0.0	 1.0	 100.0	 1	 200.0	 41.67; % NG
	4791	 64.165	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 28.33; % COW
	4792	 64.165	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 28.33; % NG
	4793	 60.835	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.67; % NG
	4796	 55.0	 5.0	 10.0	 0.0	 1.0	 100.0	 1	 100.0	 10.0; % COW
	4809	 132.375	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 64.75; % NG
	4810	 132.375	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 64.75; % COW
	4811	 132.375	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 64.75; % NG
	4814	 130.055	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 60.11; % NG
	4823	 57.335	 10.0	 20.0	 0.0	 1.0	 100.0	 1	 100.0	 14.67; % NG
	4837	 121.735	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 43.47; % NG
	4843	 121.735	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 43.47; % NG
	4844	 121.735	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 43.47; % COW
	4845	 121.735	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 43.47; % NG
	4846	 121.735	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 43.47; % NG
	4847	 121.735	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 43.47; % NG
	4855	 350.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 600.0	 100.0; % NUC
	4856	 350.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	4857	 350.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	4858	 350.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 600.0	 100.0; % NG
	4859	 300.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 500.0	 100.0; % NG
	4861	 350.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	4862	 350.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	4864	 300.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 500.0	 100.0; % NG
	4870	 56.245	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 12.49; % COW
	4887	 450.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 700.0	 200.0; % COW
	4888	 450.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 700.0	 200.0; % COW
	4892	 350.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	4893	 350.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 600.0	 100.0; % PEL
	4896	 350.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	4897	 350.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	4902	 57.6	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 15.2; % COW
	4903	 57.6	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 15.2; % NG
	4904	 59.215	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 18.43; % COW
	4905	 59.215	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 18.43; % NG
	4910	 61.915	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.83; % NG
	4917	 57.0	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 14.0; % NG
	4918	 63.035	 0.0	 20.0	 -20.0	 1.0	 100.0	 1	 100.0	 26.07; % NG
	4922	 65.765	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 31.53; % NG
	4924	 118.945	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 37.89; % NG
	4925	 61.895	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.79; % NG
	4926	 56.655	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 13.31; % NG
	4928	 350.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	4931	 62.235	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.47; % NG
	4932	 62.235	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.47; % NG
	4934	 62.305	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.61; % NG
	4938	 62.56	 5.0	 20.0	 -10.0	 1.0	 100.0	 1	 100.0	 25.12; % NG
	4939	 62.845	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 25.69; % NG
	4942	 57.875	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 15.75; % COW
	4943	 57.875	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 15.75; % NG
	4945	 58.255	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 16.51; % NG
	4946	 58.255	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 16.51; % COW
	4949	 66.14	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 32.28; % NG
	4952	 300.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 500.0	 100.0; % NG
	4958	 116.94	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 33.88; % NG
	4959	 900.0	 200.0	 520.0	 -120.0	 1.0	 100.0	 1	 1400.0	 400.0; % COW
	4963	 119.195	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 38.39; % NG
	4964	 119.195	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 38.39; % NG
	4967	 55.555	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 11.11; % COW
	4982	 132.82	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 65.64; % NG
	4983	 52.335	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 4.67; % NG
	4985	 62.655	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 25.31; % NG
	4987	 62.68	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 25.36; % COW
	4988	 58.28	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 16.56; % NG
	4998	 124.155	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 48.31; % NG
	5000	 50.98	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 1.96; % NG
	5007	 61.455	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.91; % NG
	5008	 61.455	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.91; % NG
	5009	 61.455	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.91; % NG
	5012	 124.785	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 49.57; % COW
	5013	 124.785	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 49.57; % NG
	5017	 123.115	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 46.23; % NG
	5018	 123.115	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 46.23; % NG
	5023	 300.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 500.0	 100.0; % NG
	5025	 57.23	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 14.46; % NG
	5029	 60.595	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.19; % NG
	5034	 350.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	5036	 58.805	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 17.61; % NG
	5037	 55.57	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 11.14; % NG
	5038	 59.655	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 19.31; % NG
	5050	 55.665	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 11.33; % COW
	5051	 62.615	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 25.23; % NG
	5052	 62.615	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 25.23; % NG
	5053	 62.615	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 25.23; % NG
	5054	 55.865	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 11.73; % NG
	5055	 55.865	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 11.73; % COW
	5056	 55.865	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 11.73; % NG
	5057	 55.865	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 11.73; % NG
	5058	 450.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 700.0	 200.0; % COW
	5059	 300.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 500.0	 100.0; % NG
	5060	 300.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 500.0	 100.0; % COW
	5061	 53.5	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 7.0; % NG
	5062	 350.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	5063	 350.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	5064	 350.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	5065	 450.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 700.0	 200.0; % COW
	5069	 56.265	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 12.53; % NG
	5070	 55.315	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 10.63; % NG
	5071	 56.265	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 12.53; % NG
	5072	 56.265	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 12.53; % PEL
	5073	 56.265	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 12.53; % NG
	5074	 56.265	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 12.53; % NG
	5076	 56.42	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 12.84; % COW
	5077	 56.42	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 12.84; % COW
	5078	 56.42	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 12.84; % NG
	5082	 128.495	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 56.99; % NG
	5084	 300.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 500.0	 100.0; % COW
	5085	 127.825	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 55.65; % NG
	5086	 127.825	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 55.65; % NG
	5089	 127.825	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 55.65; % NG
	5090	 127.825	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 55.65; % COW
	5091	 127.825	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 55.65; % NG
	5092	 127.825	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 55.65; % NG
	5099	 59.945	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 19.89; % NG
	5109	 57.055	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 14.11; % NG
	5111	 52.175	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 4.35; % NG
	5116	 60.78	 5.0	 30.0	 -20.0	 1.0	 100.0	 1	 100.0	 21.56; % NG
	5122	 56.375	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 12.75; % NG
	5123	 61.23	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.46; % NG
	5126	 62.855	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 25.71; % NG
	5127	 62.855	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 25.71; % NG
	5128	 56.375	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 12.75; % NG
	5129	 56.375	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 12.75; % NG
	5130	 56.375	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 12.75; % NG
	5131	 56.375	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 12.75; % NG
	5133	 56.375	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 12.75; % NG
	5134	 60.31	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 20.62; % NG
	5135	 450.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 700.0	 200.0; % COW
	5138	 58.915	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 17.83; % NG
	5143	 132.3	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 64.6; % NG
	5144	 61.995	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.99; % NG
	5145	 56.225	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 12.45; % COW
	5146	 56.225	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 12.45; % COW
	5147	 56.225	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 12.45; % NG
	5148	 60.085	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 20.17; % NG
	5151	 56.225	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 12.45; % NG
	5155	 199.31	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 300.0	 98.62; % COW
	5158	 197.25	 0.0	 80.0	 -80.0	 1.0	 100.0	 1	 300.0	 94.5; % NG
	5159	 132.3	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 64.6; % NG
	5162	 53.335	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 6.67; % COW
	5163	 132.3	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 64.6; % NG
	5166	 64.965	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 100.0	 29.93; % COW
	5169	 56.635	 5.0	 20.0	 -10.0	 1.0	 100.0	 1	 100.0	 13.27; % NG
	5177	 58.485	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 16.97; % COW
	5178	 58.485	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 16.97; % NG
	5187	 62.36	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.72; % NG
	5188	 63.495	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 26.99; % NG
	5192	 250.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 400.0	 100.0; % COW
	5196	 60.785	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.57; % NG
	5202	 60.2	 0.0	 20.0	 -20.0	 1.0	 100.0	 1	 100.0	 20.4; % COW
	5207	 450.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 700.0	 200.0; % COW
	5208	 450.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 700.0	 200.0; % NUC
	5210	 50.17	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 0.34; % NG
	5212	 122.5	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 45.0; % NG
	5223	 500.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 800.0	 200.0; % COW
	5225	 116.775	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 33.55; % NG
	5226	 116.775	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 33.55; % COW
	5228	 116.775	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 33.55; % COW
	5229	 116.775	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 33.55; % NG
	5242	 124.055	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 48.11; % NG
	5243	 118.725	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 37.45; % NG
	5245	 65.6	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 100.0	 31.2; % COW
	5246	 124.055	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 48.11; % NG
	5252	 66.27	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 32.54; % COW
	5254	 50.085	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 0.17; % NG
	5260	 350.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	5261	 66.27	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 32.54; % NG
	5262	 66.27	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 32.54; % NG
	5270	 119.17	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 38.34; % NG
	5271	 119.17	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 38.34; % NG
	5274	 118.345	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 36.69; % NG
	5275	 118.345	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 36.69; % NG
	5276	 118.345	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 36.69; % NG
	5277	 118.345	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 36.69; % NG
	5278	 119.17	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 38.34; % NG
	5279	 119.17	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 38.34; % NG
	5281	 250.0	 0.0	 90.0	 -90.0	 1.0	 100.0	 1	 400.0	 100.0; % COW
	5286	 123.375	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 46.75; % NG
	5287	 123.375	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 46.75; % NG
	5289	 52.735	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 5.47; % NG
	5292	 61.62	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.24; % NG
	5301	 116.905	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 33.81; % NG
	5302	 117.6	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 35.2; % COW
	5303	 64.425	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 28.85; % NG
	5304	 64.425	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 28.85; % NG
	5305	 63.295	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 26.59; % NG
	5306	 63.295	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 26.59; % NG
	5307	 63.295	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 26.59; % NG
	5308	 63.295	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 26.59; % NG
	5309	 119.355	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 38.71; % NG
	5310	 119.355	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 38.71; % NG
	5311	 300.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 500.0	 100.0; % NG
	5314	 131.15	 15.0	 90.0	 -60.0	 1.0	 100.0	 1	 200.0	 62.3; % COW
	5316	 51.06	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 2.12; % NG
	5317	 125.75	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 51.5; % NG
	5319	 500.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 800.0	 200.0; % COW
	5322	 58.27	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 16.54; % NG
	5323	 129.25	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 58.5; % NG
	5324	 129.25	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 58.5; % NG
	5325	 129.25	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 58.5; % NG
	5326	 129.25	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 58.5; % NG
	5327	 129.25	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 58.5; % NG
	5328	 129.25	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 58.5; % NG
	5330	 59.32	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 18.64; % NG
	5332	 60.785	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.57; % NG
	5333	 50.375	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 0.75; % NG
	5335	 129.115	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 58.23; % NG
	5341	 129.97	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 59.94; % NG
	5342	 119.195	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 38.39; % COW
	5343	 250.0	 35.0	 100.0	 -30.0	 1.0	 100.0	 1	 400.0	 100.0; % NG
	5347	 130.16	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 60.32; % NG
	5350	 56.425	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 12.85; % PEL
	5352	 60.105	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 20.21; % NG
	5354	 300.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 500.0	 100.0; % NG
	5356	 129.91	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 59.82; % NG
	5359	 54.84	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 9.68; % NG
	5365	 62.845	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 25.69; % NG
	5366	 62.845	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 25.69; % NG
	5368	 127.965	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 55.93; % NG
	5369	 127.965	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 55.93; % COW
	5370	 127.965	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 55.93; % NG
	5371	 127.965	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 55.93; % NG
	5382	 119.195	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 38.39; % NG
	5384	 52.125	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 4.25; % NG
	5385	 60.095	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 20.19; % NG
	5388	 63.01	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 26.02; % NG
	5391	 61.64	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.28; % NG
	5397	 59.8	 5.0	 40.0	 -30.0	 1.0	 100.0	 1	 100.0	 19.6; % NG
	5401	 62.95	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 25.9; % NG
	5403	 -35.69	 -5.0	 40.0	 -50.0	 1.0	 100.0	 1	 100.0	 -171.38; % NG
	5406	 63.975	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 27.95; % NG
	5408	 52.175	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 4.35; % NG
	5411	 61.61	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.22; % NG
	5416	 61.05	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.1; % NG
	5418	 52.775	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 5.55; % NG
	5420	 61.435	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.87; % COW
	5439	 62.305	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.61; % NG
	5444	 132.56	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 65.12; % NG
	5455	 187.335	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 300.0	 74.67; % COW
	5456	 121.55	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 43.1; % NG
	5463	 62.805	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 25.61; % NG
	5464	 128.0	 5.0	 60.0	 -50.0	 1.0	 100.0	 1	 200.0	 56.0; % COW
	5466	 63.145	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 26.29; % PEL
	5467	 63.145	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 26.29; % NG
	5468	 63.145	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 26.29; % NG
	5473	 125.75	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 51.5; % NG
	5476	 64.135	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 100.0	 28.27; % NG
	5484	 63.335	 0.0	 20.0	 -20.0	 1.0	 100.0	 1	 100.0	 26.67; % COW
	5490	 57.115	 5.0	 20.0	 -10.0	 1.0	 100.0	 1	 100.0	 14.23; % NG
	5494	 58.535	 0.0	 20.0	 -20.0	 1.0	 100.0	 1	 100.0	 17.07; % NG
	5498	 60.98	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.96; % NG
	5503	 250.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 400.0	 100.0; % NG
	5510	 129.755	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 59.51; % COW
	5512	 59.255	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 18.51; % COW
	5514	 129.755	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 59.51; % NG
	5517	 300.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 500.0	 100.0; % NG
	5523	 129.975	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 59.95; % NG
	5528	 62.985	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 25.97; % NG
	5530	 129.975	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 59.95; % NG
	5534	 300.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 500.0	 100.0; % NG
	5540	 60.53	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.06; % NG
	5542	 63.335	 0.0	 30.0	 -30.0	 1.0	 100.0	 1	 100.0	 26.67; % NG
	5546	 130.895	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 61.79; % NG
	5548	 55.57	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 11.14; % NG
	5575	 58.73	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 17.46; % COW
	5576	 250.0	 5.0	 140.0	 -130.0	 1.0	 100.0	 1	 400.0	 100.0; % NG
	5581	 500.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 800.0	 200.0; % COW
	5587	 550.0	 100.0	 260.0	 -60.0	 1.0	 100.0	 1	 900.0	 200.0; % COW
	5592	 121.425	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 42.85; % NG
	5593	 57.625	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 15.25; % NG
	5594	 60.785	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.57; % NG
	5607	 61.44	 5.0	 20.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.88; % COW
	5608	 57.59	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 15.18; % NG
	5610	 61.44	 5.0	 20.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.88; % NG
	5611	 58.445	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 16.89; % COW
	5612	 58.445	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 16.89; % NG
	5613	 57.59	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 15.18; % COW
	5614	 60.56	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.12; % NG
	5619	 57.175	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 14.35; % NG
	5622	 61.425	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.85; % NG
	5627	 300.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 500.0	 100.0; % NG
	5628	 57.965	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 15.93; % NG
	5629	 57.965	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 15.93; % COW
	5630	 53.585	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 7.17; % NG
	5631	 60.31	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 20.62; % NG
	5632	 55.425	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 10.85; % NG
	5634	 60.31	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 20.62; % NG
	5637	 300.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 500.0	 100.0; % PEL
	5640	 300.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 500.0	 100.0; % NG
	5641	 62.675	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 25.35; % NG
	5645	 117.71	 0.0	 40.0	 -40.0	 1.0	 100.0	 1	 200.0	 35.42; % NG
	5653	 58.285	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 16.57; % NG
	5654	 300.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 500.0	 100.0; % NG
	5657	 350.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 600.0	 100.0; % NUC
	5658	 50.33	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 0.66; % NG
	5660	 59.785	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 19.57; % NG
	5668	 60.84	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.68; % NG
	5670	 60.84	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.68; % NG
	5672	 62.265	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.53; % PEL
	5674	 500.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 800.0	 200.0; % COW
	5676	 116.94	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 33.88; % COW
	5679	 51.6	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 3.2; % COW
	5681	 120.835	 10.0	 20.0	 0.0	 1.0	 100.0	 1	 200.0	 41.67; % NG
	5695	 120.87	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 41.74; % NG
	5697	 52.685	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 5.37; % NG
	5702	 52.105	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 4.21; % NG
	5704	 500.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 800.0	 200.0; % NUC
	5705	 500.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 800.0	 200.0; % COW
	5706	 300.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 500.0	 100.0; % NG
	5707	 300.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 500.0	 100.0; % COW
	5708	 300.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 500.0	 100.0; % COW
	5714	 500.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 800.0	 200.0; % COW
	5715	 62.725	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 25.45; % NG
	5716	 59.205	 5.0	 30.0	 -20.0	 1.0	 100.0	 1	 100.0	 18.41; % NG
	5718	 300.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 500.0	 100.0; % NG
	5723	 62.255	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.51; % NG
	5728	 132.63	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 65.26; % NG
	5729	 132.63	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 65.26; % NG
	5730	 132.63	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 65.26; % NG
	5731	 132.63	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 65.26; % NG
	5732	 129.3	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 58.6; % NG
	5739	 61.675	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.35; % NG
	5741	 62.01	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.02; % NG
	5742	 300.0	 55.0	 130.0	 -20.0	 1.0	 100.0	 1	 500.0	 100.0; % NG
	5746	 60.79	 5.0	 20.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.58; % NG
	5750	 117.355	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 34.71; % NG
	5751	 65.855	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 31.71; % NG
	5761	 61.655	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.31; % NG
	5764	 61.62	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.24; % NG
	5765	 62.43	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.86; % NG
	5769	 117.69	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 35.38; % NG
	5770	 63.48	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 26.96; % COW
	5771	 63.48	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 26.96; % COW
	5772	 117.69	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 35.38; % NG
	5776	 500.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 800.0	 200.0; % COW
	5777	 500.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 800.0	 200.0; % COW
	5781	 500.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 800.0	 200.0; % COW
	5782	 500.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 800.0	 200.0; % COW
	5797	 300.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 500.0	 100.0; % COW
	5804	 61.915	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.83; % NG
	5805	 60.43	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 20.86; % NG
	5816	 450.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 700.0	 200.0; % PEL
	5825	 56.425	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 12.85; % NG
	5826	 55.25	 5.0	 20.0	 -10.0	 1.0	 100.0	 1	 100.0	 10.5; % NG
	5830	 120.79	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 41.58; % NG
	5831	 55.735	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 11.47; % NG
	5832	 55.735	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 11.47; % NG
	5838	 700.0	 200.0	 520.0	 -120.0	 1.0	 100.0	 1	 1100.0	 300.0; % COW
	5842	 59.965	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 19.93; % PEL
	5847	 62.295	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.59; % NG
	5849	 62.6	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 25.2; % NG
	5850	 133.225	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 66.45; % NG
	5856	 250.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 400.0	 100.0; % NG
	5858	 250.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 400.0	 100.0; % COW
	5864	 65.095	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 30.19; % NG
	5868	 130.055	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 60.11; % NG
	5880	 127.025	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 54.05; % NG
	5881	 350.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	5882	 350.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	5883	 350.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 600.0	 100.0; % NG
	5884	 350.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 600.0	 100.0; % NG
	5885	 127.025	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 54.05; % NG
	5886	 127.025	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 54.05; % NG
	5887	 350.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	5889	 350.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 600.0	 100.0; % NG
	5896	 118.785	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 37.57; % NG
	5897	 129.13	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 58.26; % NG
	5898	 129.13	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 58.26; % NG
	5900	 129.13	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 58.26; % NG
	5901	 129.13	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 58.26; % NG
	5902	 129.13	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 58.26; % COW
	5905	 193.5	 0.0	 50.0	 -50.0	 1.0	 100.0	 1	 300.0	 87.0; % NG
	5911	 58.58	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 17.16; % NG
	5924	 60.425	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 20.85; % PEL
	5928	 60.88	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.76; % NG
	5929	 61.685	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.37; % COW
	5930	 61.685	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.37; % NG
	5931	 61.125	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.25; % NG
	5932	 61.685	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.37; % NG
	5933	 61.685	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.37; % NG
	5934	 61.685	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.37; % COW
	5935	 58.535	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 17.07; % COW
	5936	 58.535	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 17.07; % COW
	5961	 61.07	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.14; % NG
	5963	 58.875	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 17.75; % NG
	5964	 195.0	 25.0	 70.0	 -20.0	 1.0	 100.0	 1	 300.0	 90.0; % NG
	5965	 250.0	 15.0	 110.0	 -80.0	 1.0	 100.0	 1	 400.0	 100.0; % NG
	5973	 55.94	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 11.88; % NG
	5977	 59.81	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 19.62; % NG
	5978	 126.6	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 53.2; % COW
	5979	 62.41	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.82; % NG
	5982	 51.735	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 3.47; % NG
	5984	 60.905	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.81; % NG
	5987	 850.0	 200.0	 520.0	 -120.0	 1.0	 100.0	 1	 1300.0	 400.0; % COW
	5988	 850.0	 200.0	 520.0	 -120.0	 1.0	 100.0	 1	 1300.0	 400.0; % COW
	5989	 850.0	 200.0	 520.0	 -120.0	 1.0	 100.0	 1	 1300.0	 400.0; % COW
	5990	 850.0	 200.0	 520.0	 -120.0	 1.0	 100.0	 1	 1300.0	 400.0; % NUC
	5992	 61.985	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.97; % COW
	5999	 116.78	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 33.56; % COW
	6002	 121.2	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 42.4; % NG
	6003	 121.2	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 42.4; % NG
	6005	 121.2	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 42.4; % NG
	6006	 121.2	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 42.4; % NG
	6007	 121.2	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 42.4; % NG
	6008	 121.2	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 42.4; % NG
	6009	 51.5	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 3.0; % COW
	6014	 116.78	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 33.56; % NG
	6016	 61.065	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.13; % COW
	6017	 250.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 400.0	 100.0; % COW
	6023	 500.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 800.0	 200.0; % COW
	6025	 130.895	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 61.79; % COW
	6034	 60.425	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 20.85; % NG
	6038	 300.0	 35.0	 130.0	 -60.0	 1.0	 100.0	 1	 500.0	 100.0; % COW
	6039	 129.75	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 59.5; % NG
	6040	 129.75	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 59.5; % NG
	6048	 127.435	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 54.87; % NG
	6049	 62.93	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 25.86; % NG
	6055	 121.24	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 42.48; % NG
	6058	 550.0	 100.0	 260.0	 -60.0	 1.0	 100.0	 1	 900.0	 200.0; % NUC
	6066	 500.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 800.0	 200.0; % COW
	6068	 62.305	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.61; % NG
	6072	 53.035	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 6.07; % NG
	6076	 59.6	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 19.2; % NG
	6085	 750.0	 200.0	 520.0	 -120.0	 1.0	 100.0	 1	 1200.0	 300.0; % NUC
	6087	 58.935	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 17.87; % NG
	6088	 60.905	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.81; % NG
	6089	 55.58	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 11.16; % NG
	6090	 60.025	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 20.05; % NG
	6091	 60.025	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 20.05; % NG
	6092	 62.895	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 25.79; % NG
	6093	 58.935	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 17.87; % NG
	6096	 62.645	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 25.29; % NG
	6097	 55.58	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 11.16; % NG
	6098	 55.58	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 11.16; % NG
	6103	 500.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 800.0	 200.0; % COW
	6107	 62.675	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 25.35; % NG
	6121	 128.425	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 56.85; % NG
	6123	 62.36	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.72; % COW
	6130	 51.665	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 3.33; % NG
	6132	 55.0	 5.0	 10.0	 0.0	 1.0	 100.0	 1	 100.0	 10.0; % NG
	6135	 55.88	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 11.76; % NG
	6138	 900.0	 200.0	 520.0	 -120.0	 1.0	 100.0	 1	 1400.0	 400.0; % NG
	6139	 900.0	 200.0	 520.0	 -120.0	 1.0	 100.0	 1	 1400.0	 400.0; % COW
	6140	 900.0	 200.0	 520.0	 -120.0	 1.0	 100.0	 1	 1400.0	 400.0; % NUC
	6141	 1250.0	 200.0	 520.0	 -120.0	 1.0	 100.0	 1	 1900.0	 600.0; % COW
	6155	 60.435	 5.0	 20.0	 -10.0	 1.0	 100.0	 1	 100.0	 20.87; % COW
	6156	 60.49	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 20.98; % NG
	6161	 121.615	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 43.23; % NG
	6162	 121.615	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 43.23; % NG
	6163	 51.455	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 2.91; % NG
	6167	 56.915	 5.0	 20.0	 -10.0	 1.0	 100.0	 1	 100.0	 13.83; % NG
	6171	 54.1	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 8.2; % NG
	6192	 55.85	 5.0	 10.0	 0.0	 1.0	 100.0	 1	 100.0	 11.7; % NG
	6193	 350.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	6194	 350.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	6195	 58.47	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 16.94; % COW
	6199	 59.3	 5.0	 10.0	 0.0	 1.0	 100.0	 1	 100.0	 18.6; % NG
	6200	 52.565	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 5.13; % NG
	6201	 900.0	 200.0	 520.0	 -120.0	 1.0	 100.0	 1	 1400.0	 400.0; % COW
	6202	 900.0	 200.0	 520.0	 -120.0	 1.0	 100.0	 1	 1400.0	 400.0; % COW
	6203	 900.0	 200.0	 520.0	 -120.0	 1.0	 100.0	 1	 1400.0	 400.0; % COW
	6204	 900.0	 200.0	 520.0	 -120.0	 1.0	 100.0	 1	 1400.0	 400.0; % COW
	6208	 900.0	 200.0	 520.0	 -120.0	 1.0	 100.0	 1	 1400.0	 400.0; % COW
	6210	 62.01	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.02; % NG
	6212	 250.0	 0.0	 100000.0	 -100000.0	 1.0	 100.0	 1	 400.0	 100.0; % NG
	6213	 63.73	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 27.46; % NG
	6215	 122.41	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 44.82; % NG
	6218	 63.73	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 27.46; % NG
	6219	 61.13	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.26; % COW
	6220	 122.41	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 44.82; % NG
	6225	 62.93	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 25.86; % NG
	6226	 500.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 800.0	 200.0; % COW
	6227	 500.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 800.0	 200.0; % COW
	6254	 850.0	 200.0	 520.0	 -120.0	 1.0	 100.0	 1	 1300.0	 400.0; % NG
	6262	 300.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 500.0	 100.0; % NG
	6272	 49.9	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 -0.2; % COW
	6276	 350.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	6277	 350.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	6278	 60.43	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 20.86; % NG
	6279	 350.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	6280	 350.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 600.0	 100.0; % NG
	6291	 61.915	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.83; % NG
	6296	 66.61	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 100.0	 33.22; % NG
	6298	 59.895	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 19.79; % NG
	6299	 59.895	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 19.79; % NG
	6305	 183.335	 20.0	 90.0	 -50.0	 1.0	 100.0	 1	 300.0	 66.67; % NG
	6314	 50.835	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 1.67; % NG
	6317	 450.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 700.0	 200.0; % COW
	6325	 57.365	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 14.73; % NG
	6326	 57.365	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 14.73; % COW
	6327	 57.365	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 14.73; % COW
	6328	 57.365	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 14.73; % NG
	6329	 57.365	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 14.73; % NG
	6331	 133.225	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 66.45; % NG
	6335	 61.345	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.69; % NG
	6336	 61.345	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.69; % COW
	6337	 61.345	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.69; % COW
	6341	 61.835	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.67; % COW
	6346	 59.965	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 19.93; % NG
	6347	 50.005	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 0.01; % COW
	6351	 350.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	6352	 350.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 600.0	 100.0; % NG
	6353	 300.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 500.0	 100.0; % NG
	6354	 300.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 500.0	 100.0; % NG
	6357	 300.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 500.0	 100.0; % NG
	6358	 300.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 500.0	 100.0; % COW
	6359	 56.105	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 12.21; % COW
	6360	 300.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 500.0	 100.0; % COW
	6361	 300.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 500.0	 100.0; % NG
	6363	 118.785	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 37.57; % NG
	6368	 850.0	 200.0	 520.0	 -120.0	 1.0	 100.0	 1	 1300.0	 400.0; % COW
	6369	 350.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	6370	 350.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 600.0	 100.0; % NG
	6371	 350.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	6372	 350.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	6383	 62.335	 0.0	 30.0	 -30.0	 1.0	 100.0	 1	 100.0	 24.67; % COW
	6391	 127.535	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 55.07; % NG
	6398	 60.88	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.76; % NG
	6401	 61.405	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.81; % NG
	6402	 61.405	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.81; % NG
	6404	 61.405	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.81; % NG
	6405	 61.85	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.7; % COW
	6406	 300.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 500.0	 100.0; % NG
	6407	 61.405	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.81; % NG
	6408	 61.85	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.7; % COW
	6409	 500.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 800.0	 200.0; % COW
	6417	 450.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 700.0	 200.0; % COW
	6418	 450.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 700.0	 200.0; % COW
	6420	 65.43	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 100.0	 30.86; % NG
	6421	 64.675	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 100.0	 29.35; % NG
	6422	 450.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 700.0	 200.0; % COW
	6429	 54.43	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 8.86; % COW
	6431	 57.0	 5.0	 20.0	 -10.0	 1.0	 100.0	 1	 100.0	 14.0; % NG
	6436	 500.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 800.0	 200.0; % NUC
	6440	 55.28	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 10.56; % COW
	6451	 58.485	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 16.97; % NG
	6452	 58.465	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 16.93; % NG
	6454	 65.565	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 31.13; % NG
	6455	 63.385	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 26.77; % NG
	6456	 63.385	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 26.77; % NG
	6465	 61.62	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.24; % NG
	6471	 119.225	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 38.45; % NG
	6476	 350.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	6477	 56.875	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 13.75; % NG
	6487	 62.41	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.82; % NG
	6491	 196.265	 40.0	 110.0	 -30.0	 1.0	 100.0	 1	 300.0	 92.53; % NG
	6498	 120.025	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 40.05; % NG
	6500	 350.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	6507	 60.425	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 20.85; % NG
	6527	 300.0	 45.0	 150.0	 -60.0	 1.0	 100.0	 1	 500.0	 100.0; % NG
	6539	 55.595	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 11.19; % NG
	6541	 63.295	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 26.59; % NG
	6542	 63.295	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 26.59; % NG
	6543	 63.295	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 26.59; % COW
	6544	 131.215	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 62.43; % NG
	6545	 58.33	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 16.66; % COW
	6547	 131.215	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 62.43; % NG
	6548	 131.215	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 62.43; % NG
	6557	 65.98	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 31.96; % NG
	6563	 60.435	 0.0	 20.0	 -20.0	 1.0	 100.0	 1	 100.0	 20.87; % COW
	6566	 61.55	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.1; % NG
	6567	 61.55	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.1; % NG
	6584	 250.0	 5.0	 80.0	 -70.0	 1.0	 100.0	 1	 400.0	 100.0; % COW
	6585	 188.0	 10.0	 70.0	 -50.0	 1.0	 100.0	 1	 300.0	 76.0; % COW
	6593	 62.755	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 25.51; % NG
	6601	 250.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 400.0	 100.0; % NG
	6602	 62.36	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.72; % NG
	6606	 129.355	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 58.71; % COW
	6607	 129.355	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 58.71; % NG
	6608	 129.355	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 58.71; % NG
	6609	 129.355	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 58.71; % NG
	6610	 129.355	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 58.71; % NG
	6611	 129.355	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 58.71; % NG
	6612	 129.355	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 58.71; % COW
	6616	 196.265	 40.0	 110.0	 -30.0	 1.0	 100.0	 1	 300.0	 92.53; % NG
	6620	 450.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 700.0	 200.0; % NG
	6621	 57.885	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 15.77; % COW
	6622	 117.545	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 200.0	 35.09; % NG
	6623	 60.225	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 20.45; % NG
	6624	 60.225	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 20.45; % COW
	6628	 450.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 700.0	 200.0; % COW
	6630	 60.225	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 20.45; % NG
	6631	 62.84	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 25.68; % NG
	6639	 57.95	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 15.9; % COW
	6640	 57.95	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 15.9; % NG
	6641	 57.95	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 15.9; % NG
	6642	 57.95	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 15.9; % COW
	6649	 52.735	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 5.47; % NG
	6650	 132.01	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 64.02; % COW
	6651	 124.925	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 49.85; % NG
	6654	 65.095	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 30.19; % NG
	6663	 130.39	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 60.78; % NG
	6667	 300.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 500.0	 100.0; % COW
	6670	 62.255	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.51; % NG
	6680	 118.415	 0.0	 40.0	 -40.0	 1.0	 100.0	 1	 200.0	 36.83; % NG
	6686	 58.48	 0.0	 20.0	 -20.0	 1.0	 100.0	 1	 100.0	 16.96; % NG
	6689	 66.445	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 32.89; % NG
	6690	 66.445	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 32.89; % COW
	6691	 66.445	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 32.89; % COW
	6693	 116.78	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 33.56; % NG
	6697	 116.78	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 33.56; % NG
	6709	 55.375	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 10.75; % NG
	6713	 119.18	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 38.36; % NG
	6717	 50.665	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 1.33; % NG
	6719	 122.965	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 45.93; % NG
	6721	 122.965	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 45.93; % COW
	6726	 60.685	 5.0	 20.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.37; % NG
	6729	 450.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 700.0	 200.0; % COW
	6731	 57.485	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 14.97; % COW
	6734	 300.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 500.0	 100.0; % COW
	6747	 250.0	 25.0	 130.0	 -80.0	 1.0	 100.0	 1	 400.0	 100.0; % NG
	6749	 61.225	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.45; % COW
	6754	 300.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 500.0	 100.0; % COW
	6757	 61.28	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.56; % NG
	6758	 61.28	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.56; % COW
	6759	 61.28	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.56; % COW
	6760	 61.28	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.56; % NG
	6761	 61.28	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.56; % NG
	6762	 61.28	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.56; % COW
	6763	 61.28	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.56; % NG
	6764	 128.865	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 57.73; % NG
	6765	 131.785	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 63.57; % NG
	6769	 57.01	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 14.02; % COW
	6773	 65.46	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 30.92; % NG
	6774	 61.205	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.41; % NG
	6780	 62.93	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 25.86; % NG
	6784	 52.8	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 5.6; % NG
	6785	 61.205	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.41; % NG
	6789	 61.205	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.41; % NG
	6792	 57.71	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 15.42; % NG
	6793	 57.71	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 15.42; % NG
	6794	 57.065	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 14.13; % NG
	6795	 57.065	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 14.13; % NG
	6797	 61.62	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.24; % NG
	6798	 61.62	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.24; % NG
	6799	 61.67	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.34; % COW
	6801	 56.925	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 13.85; % NG
	6802	 56.925	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 13.85; % NG
	6806	 63.93	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 27.86; % COW
	6807	 63.93	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 27.86; % NG
	6808	 63.93	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 27.86; % NG
	6814	 63.93	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 27.86; % NG
	6815	 63.93	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 27.86; % COW
	6820	 61.835	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.67; % NG
	6822	 300.0	 60.0	 140.0	 -20.0	 1.0	 100.0	 1	 500.0	 100.0; % NG
	6836	 300.0	 35.0	 100.0	 -30.0	 1.0	 100.0	 1	 500.0	 100.0; % NG
	6842	 57.01	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 14.02; % NG
	6846	 57.835	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 15.67; % NG
	6847	 58.36	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 16.72; % NG
	6861	 55.425	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 10.85; % COW
	6862	 128.87	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 57.74; % NG
	6864	 50.835	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 1.67; % NG
	6865	 58.28	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 16.56; % NG
	6870	 131.675	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 63.35; % NG
	6871	 250.0	 0.0	 80.0	 -80.0	 1.0	 100.0	 1	 400.0	 100.0; % COW
	6875	 131.67	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 63.34; % NG
	6876	 131.67	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 63.34; % COW
	6877	 131.67	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 63.34; % NG
	6879	 1150.0	 200.0	 520.0	 -120.0	 1.0	 100.0	 1	 1800.0	 500.0; % COW
	6880	 1150.0	 200.0	 520.0	 -120.0	 1.0	 100.0	 1	 1800.0	 500.0; % NUC
	6885	 127.485	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 54.97; % NG
	6886	 118.645	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 37.29; % NG
	6903	 300.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 500.0	 100.0; % COW
	6909	 450.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 700.0	 200.0; % COW
	6910	 450.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 700.0	 200.0; % COW
	6912	 183.47	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 300.0	 66.94; % NG
	6918	 300.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 500.0	 100.0; % COW
	6930	 128.04	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 56.08; % NG
	6931	 128.04	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 56.08; % NG
	6939	 53.5	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 7.0; % COW
	6942	 51.735	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 3.47; % COW
	6944	 62.805	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 25.61; % NG
	6948	 57.865	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 15.73; % NG
	6952	 52.735	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 5.47; % NG
	6963	 62.515	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 25.03; % COW
	6967	 62.805	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 25.61; % COW
	6969	 62.805	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 25.61; % COW
	6976	 60.4	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 20.8; % NG
	6985	 125.935	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 51.87; % NG
	6987	 125.935	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 51.87; % COW
	6990	 58.215	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 16.43; % NG
	6992	 60.735	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.47; % NG
	6994	 51.935	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 3.87; % NG
	6996	 300.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 500.0	 100.0; % COW
	6998	 127.925	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 55.85; % NG
	7005	 500.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 800.0	 200.0; % NG
	7009	 55.065	 5.0	 20.0	 -10.0	 1.0	 100.0	 1	 100.0	 10.13; % NG
	7020	 126.235	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 52.47; % NG
	7028	 62.675	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 25.35; % COW
	7031	 58.095	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 16.19; % NG
	7045	 350.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	7052	 57.735	 0.0	 20.0	 -20.0	 1.0	 100.0	 1	 100.0	 15.47; % NG
	7055	 129.485	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 58.97; % NG
	7056	 60.655	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.31; % COW
	7057	 61.915	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.83; % NG
	7063	 850.0	 200.0	 520.0	 -120.0	 1.0	 100.0	 1	 1300.0	 400.0; % COW
	7064	 61.435	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.87; % NG
	7066	 52.175	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 4.35; % NG
	7068	 55.365	 5.0	 20.0	 -10.0	 1.0	 100.0	 1	 100.0	 10.73; % NG
	7070	 51.52	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 3.04; % NG
	7071	 450.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 700.0	 200.0; % COW
	7072	 350.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	7073	 250.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 400.0	 100.0; % NG
	7075	 58.295	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 16.59; % COW
	7079	 118.015	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 36.03; % NG
	7080	 57.885	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 15.77; % NG
	7081	 57.885	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 15.77; % COW
	7082	 57.885	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 15.77; % NG
	7083	 57.885	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 15.77; % NG
	7084	 57.985	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 15.97; % NG
	7085	 57.885	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 15.77; % NG
	7087	 57.985	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 15.97; % NG
	7105	 62.93	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 25.86; % NG
	7110	 130.47	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 60.94; % NG
	7111	 250.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 400.0	 100.0; % NG
	7113	 300.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 500.0	 100.0; % NG
	7114	 66.035	 5.0	 30.0	 -20.0	 1.0	 100.0	 1	 100.0	 32.07; % COW
	7115	 61.915	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.83; % COW
	7116	 62.255	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.51; % PEL
	7122	 118.75	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 37.5; % NG
	7133	 65.18	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 30.36; % NG
	7137	 250.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 400.0	 100.0; % NG
	7139	 55.935	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 11.87; % COW
	7142	 129.115	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 58.23; % NG
	7143	 52.915	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 5.83; % NG
	7146	 64.965	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 100.0	 29.93; % COW
	7148	 128.75	 -10.0	 60.0	 -80.0	 1.0	 100.0	 1	 200.0	 57.5; % NG
	7149	 128.335	 0.0	 60.0	 -60.0	 1.0	 100.0	 1	 200.0	 56.67; % COW
	7156	 62.725	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 25.45; % NG
	7159	 54.335	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 8.67; % NG
	7163	 60.75	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.5; % NG
	7164	 61.655	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.31; % NG
	7168	 62.01	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.02; % NG
	7170	 187.335	 10.0	 80.0	 -60.0	 1.0	 100.0	 1	 300.0	 74.67; % COW
	7173	 129.44	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 58.88; % NG
	7178	 60.08	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 20.16; % NG
	7179	 131.76	 15.0	 50.0	 -20.0	 1.0	 100.0	 1	 200.0	 63.52; % NG
	7183	 65.785	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 31.57; % COW
	7186	 52.125	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 4.25; % NG
	7200	 65.785	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 31.57; % NG
	7213	 54.2	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 8.4; % NG
	7228	 60.81	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.62; % NG
	7233	 300.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 500.0	 100.0; % COW
	7236	 57.97	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 15.94; % NG
	7240	 61.765	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.53; % NG
	7242	 60.64	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.28; % NG
	7243	 52.125	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 4.25; % NG
	7249	 59.495	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 18.99; % NG
	7250	 56.605	 5.0	 20.0	 -10.0	 1.0	 100.0	 1	 100.0	 13.21; % NG
	7252	 850.0	 200.0	 520.0	 -120.0	 1.0	 100.0	 1	 1300.0	 400.0; % NUC
	7257	 58.335	 5.0	 20.0	 -10.0	 1.0	 100.0	 1	 100.0	 16.67; % NG
	7261	 50.835	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 1.67; % NG
	7262	 183.63	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 300.0	 67.26; % NG
	7267	 52.175	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 4.35; % NG
	7282	 52.32	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 4.64; % NG
	7289	 129.115	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 58.23; % NG
	7291	 58.125	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 16.25; % NG
	7297	 125.75	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 51.5; % NG
	7304	 118.75	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 37.5; % NG
	7317	 62.14	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.28; % COW
	7327	 250.0	 35.0	 100.0	 -30.0	 1.0	 100.0	 1	 400.0	 100.0; % NG
	7329	 62.665	 0.0	 20.0	 -20.0	 1.0	 100.0	 1	 100.0	 25.33; % COW
	7333	 129.295	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 58.59; % NG
	7334	 300.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 500.0	 100.0; % COW
	7338	 450.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 700.0	 200.0; % COW
	7340	 250.0	 25.0	 100.0	 -50.0	 1.0	 100.0	 1	 400.0	 100.0; % NG
	7342	 56.98	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 13.96; % NG
	7345	 51.235	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 2.47; % COW
	7346	 62.2	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.4; % COW
	7349	 61.74	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.48; % NG
	7350	 61.74	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.48; % NG
	7351	 132.01	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 64.02; % NG
	7352	 62.515	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 25.03; % COW
	7354	 900.0	 200.0	 520.0	 -120.0	 1.0	 100.0	 1	 1400.0	 400.0; % COW
	7356	 61.675	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.35; % PEL
	7365	 62.305	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.61; % COW
	7369	 60.915	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.83; % NG
	7370	 61.215	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.43; % COW
	7371	 61.64	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.28; % NG
	7372	 61.215	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.43; % NG
	7374	 60.915	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.83; % NG
	7375	 60.915	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.83; % COW
	7376	 60.915	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.83; % NG
	7377	 59.975	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 19.95; % NG
	7378	 60.095	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 20.19; % NG
	7379	 60.095	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 20.19; % NG
	7381	 250.0	 5.0	 140.0	 -130.0	 1.0	 100.0	 1	 400.0	 100.0; % NG
	7386	 64.135	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 100.0	 28.27; % NG
	7388	 650.0	 200.0	 520.0	 -120.0	 1.0	 100.0	 1	 1000.0	 300.0; % COW
	7391	 63.48	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 26.96; % NG
	7392	 62.72	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 25.44; % NG
	7416	 56.135	 0.0	 20.0	 -20.0	 1.0	 100.0	 1	 100.0	 12.27; % NG
	7426	 350.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 600.0	 100.0; % NG
	7428	 62.855	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 25.71; % COW
	7430	 58.535	 0.0	 20.0	 -20.0	 1.0	 100.0	 1	 100.0	 17.07; % NG
	7447	 62.93	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 25.86; % NG
	7449	 300.0	 35.0	 100.0	 -30.0	 1.0	 100.0	 1	 500.0	 100.0; % COW
	7452	 117.905	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 35.81; % COW
	7470	 1100.0	 200.0	 520.0	 -120.0	 1.0	 100.0	 1	 1700.0	 500.0; % COW
	7473	 57.835	 5.0	 20.0	 -10.0	 1.0	 100.0	 1	 100.0	 15.67; % COW
	7474	 61.39	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.78; % NG
	7475	 61.765	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.53; % NG
	7476	 350.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 600.0	 100.0; % NG
	7477	 350.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	7487	 65.0	 10.0	 20.0	 0.0	 1.0	 100.0	 1	 100.0	 30.0; % COW
	7489	 350.0	 35.0	 100.0	 -30.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	7490	 60.63	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.26; % NG
	7498	 126.205	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 52.41; % NG
	7499	 132.525	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 65.05; % NG
	7501	 58.515	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 17.03; % COW
	7502	 56.175	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 12.35; % NG
	7504	 56.175	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 12.35; % NG
	7505	 56.255	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 12.51; % NG
	7507	 58.515	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 17.03; % NG
	7508	 59.185	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 18.37; % COW
	7511	 250.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 400.0	 100.0; % NG
	7512	 60.855	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.71; % NG
	7513	 56.975	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 13.95; % NG
	7523	 129.485	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 58.97; % NG
	7524	 129.485	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 58.97; % NG
	7526	 129.485	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 58.97; % COW
	7528	 129.485	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 58.97; % COW
	7531	 350.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	7535	 196.265	 40.0	 110.0	 -30.0	 1.0	 100.0	 1	 300.0	 92.53; % COW
	7539	 130.895	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 61.79; % NG
	7540	 62.345	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.69; % NG
	7544	 128.805	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 57.61; % NG
	7547	 56.79	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 13.58; % NG
	7551	 132.875	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 65.75; % NG
	7556	 131.5	 5.0	 50.0	 -40.0	 1.0	 100.0	 1	 200.0	 63.0; % NG
	7557	 63.505	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 27.01; % NG
	7558	 63.505	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 27.01; % NG
	7559	 63.505	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 27.01; % NG
	7560	 63.505	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 27.01; % NG
	7561	 129.885	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 59.77; % NG
	7562	 57.375	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 14.75; % NG
	7563	 57.375	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 14.75; % NG
	7564	 55.985	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 11.97; % COW
	7568	 60.335	 0.0	 20.0	 -20.0	 1.0	 100.0	 1	 100.0	 20.67; % NG
	7577	 55.865	 0.0	 20.0	 -20.0	 1.0	 100.0	 1	 100.0	 11.73; % COW
	7585	 60.435	 0.0	 20.0	 -20.0	 1.0	 100.0	 1	 100.0	 20.87; % NG
	7593	 250.0	 35.0	 100.0	 -30.0	 1.0	 100.0	 1	 400.0	 100.0; % NG
	7598	 125.675	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 51.35; % COW
	7599	 130.7	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 61.4; % NG
	7600	 116.78	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 33.56; % COW
	7613	 56.735	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 13.47; % NG
	7625	 61.915	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.83; % NG
	7628	 129.315	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 58.63; % NG
	7634	 58.405	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 16.81; % NG
	7636	 60.855	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.71; % NG
	7637	 60.855	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.71; % NG
	7639	 52.44	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 4.88; % COW
	7640	 -846.265	 0.0	 100000.0	 -100000.0	 1.0	 100.0	 1	 100.0	 -1792.53; % NG
	7641	 62.265	 0.0	 30.0	 -30.0	 1.0	 100.0	 1	 100.0	 24.53; % COW
	7643	 196.265	 40.0	 110.0	 -30.0	 1.0	 100.0	 1	 300.0	 92.53; % NG
	7645	 350.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 600.0	 100.0; % NG
	7648	 350.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	7649	 350.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	7654	 300.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 500.0	 100.0; % COW
	7662	 300.0	 35.0	 100.0	 -30.0	 1.0	 100.0	 1	 500.0	 100.0; % COW
	7667	 183.47	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 300.0	 66.94; % NG
	7668	 60.435	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 20.87; % NG
	7670	 127.015	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 54.03; % NG
	7671	 127.015	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 54.03; % NG
	7672	 127.015	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 54.03; % NG
	7674	 350.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	7675	 124.245	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 48.49; % NG
	7676	 124.245	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 48.49; % NG
	7677	 57.165	 5.0	 10.0	 0.0	 1.0	 100.0	 1	 100.0	 14.33; % COW
	7681	 250.0	 10.0	 90.0	 -70.0	 1.0	 100.0	 1	 400.0	 100.0; % NG
	7689	 62.43	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.86; % NG
	7700	 57.965	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 15.93; % NG
	7705	 59.125	 5.0	 30.0	 -20.0	 1.0	 100.0	 1	 100.0	 18.25; % NG
	7707	 117.165	 0.0	 30.0	 -30.0	 1.0	 100.0	 1	 200.0	 34.33; % NG
	7712	 56.93	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 13.86; % NG
	7716	 126.6	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 53.2; % NG
	7717	 126.6	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 53.2; % NG
	7719	 126.6	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 53.2; % NG
	7721	 126.6	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 53.2; % NG
	7722	 126.6	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 53.2; % NG
	7731	 50.275	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 0.55; % NG
	7732	 56.645	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 13.29; % NG
	7734	 60.535	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.07; % NG
	7736	 500.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 800.0	 200.0; % COW
	7740	 61.835	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.67; % NG
	7742	 60.0	 5.0	 10.0	 0.0	 1.0	 100.0	 1	 100.0	 20.0; % NG
	7743	 250.0	 25.0	 90.0	 -40.0	 1.0	 100.0	 1	 400.0	 100.0; % COW
	7750	 250.0	 30.0	 100.0	 -40.0	 1.0	 100.0	 1	 400.0	 100.0; % COW
	7751	 195.0	 25.0	 70.0	 -20.0	 1.0	 100.0	 1	 300.0	 90.0; % NG
	7754	 129.615	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 59.23; % COW
	7768	 53.0	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 6.0; % COW
	7776	 850.0	 200.0	 520.0	 -120.0	 1.0	 100.0	 1	 1300.0	 400.0; % COW
	7777	 55.835	 5.0	 20.0	 -10.0	 1.0	 100.0	 1	 100.0	 11.67; % NG
	7784	 131.675	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 63.35; % NG
	7808	 300.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 500.0	 100.0; % NG
	7812	 58.585	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 17.17; % NG
	7814	 300.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 500.0	 100.0; % NG
	7825	 56.75	 5.0	 20.0	 -10.0	 1.0	 100.0	 1	 100.0	 13.5; % NG
	7833	 350.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	7841	 58.425	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 16.85; % NG
	7842	 61.205	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.41; % NG
	7844	 65.46	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 30.92; % NG
	7846	 65.46	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 30.92; % NG
	7847	 63.41	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 26.82; % NG
	7848	 61.205	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.41; % COW
	7849	 350.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	7851	 61.205	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.41; % COW
	7857	 52.8	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 5.6; % NG
	7858	 62.305	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.61; % NG
	7859	 58.28	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 16.56; % NG
	7875	 62.72	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 25.44; % NG
	7877	 52.175	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 4.35; % NG
	7890	 62.035	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.07; % NG
	7899	 60.66	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.32; % COW
	7901	 63.275	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 26.55; % NG
	7902	 63.275	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 26.55; % COW
	7903	 58.865	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 17.73; % COW
	7904	 58.865	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 17.73; % COW
	7905	 58.295	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 16.59; % NG
	7908	 58.865	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 17.73; % NG
	7918	 52.175	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 4.35; % NG
	7921	 54.665	 5.0	 20.0	 -10.0	 1.0	 100.0	 1	 100.0	 9.33; % NG
	7925	 350.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 600.0	 100.0; % NG
	7929	 450.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 700.0	 200.0; % COW
	7930	 500.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 800.0	 200.0; % NG
	7931	 59.27	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 18.54; % NG
	7932	 60.63	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.26; % COW
	7933	 61.065	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.13; % NG
	7939	 59.61	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 19.22; % NG
	7943	 60.63	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.26; % COW
	7946	 59.225	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 18.45; % NG
	7949	 60.0	 5.0	 30.0	 -20.0	 1.0	 100.0	 1	 100.0	 20.0; % NG
	7951	 63.32	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 26.64; % NG
	7962	 51.01	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 2.02; % NG
	7965	 129.295	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 58.59; % NG
	7966	 129.295	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 58.59; % NG
	7967	 65.095	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 30.19; % NG
	7970	 126.8	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 53.6; % COW
	7976	 60.08	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 20.16; % NG
	7979	 117.905	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 35.81; % NG
	7981	 117.905	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 35.81; % NG
	7988	 117.905	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 35.81; % NG
	7989	 117.905	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 35.81; % NG
	7992	 61.535	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.07; % PEL
	7993	 61.535	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.07; % COW
	7995	 58.075	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 16.15; % NG
	7998	 51.135	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 2.27; % COW
	8000	 58.075	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 16.15; % NG
	8001	 58.075	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 16.15; % COW
	8010	 56.165	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 12.33; % NG
	8017	 129.315	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 58.63; % COW
	8021	 129.315	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 58.63; % NG
	8022	 129.315	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 58.63; % COW
	8023	 64.535	 0.0	 30.0	 -30.0	 1.0	 100.0	 1	 100.0	 29.07; % PEL
	8033	 125.2	 5.0	 50.0	 -40.0	 1.0	 100.0	 1	 200.0	 50.4; % NG
	8039	 56.045	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 12.09; % COW
	8053	 60.63	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.26; % NG
	8055	 60.63	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.26; % NG
	8056	 60.63	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.26; % NG
	8060	 65.0	 0.0	 30.0	 -30.0	 1.0	 100.0	 1	 100.0	 30.0; % NG
	8063	 62.14	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.28; % NG
	8067	 62.36	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.72; % NG
	8088	 300.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 500.0	 100.0; % COW
	8089	 59.345	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 18.69; % NG
	8090	 300.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 500.0	 100.0; % COW
	8091	 121.395	 0.0	 40.0	 -40.0	 1.0	 100.0	 1	 200.0	 42.79; % COW
	8092	 62.045	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.09; % NG
	8096	 60.3	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 20.6; % NG
	8097	 500.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 800.0	 200.0; % NUC
	8099	 63.935	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 27.87; % NG
	8109	 58.33	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 16.66; % NG
	8110	 61.565	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.13; % COW
	8111	 62.295	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.59; % COW
	8112	 61.565	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.13; % PEL
	8113	 62.495	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.99; % COW
	8114	 62.295	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.59; % NG
	8116	 62.495	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.99; % NG
	8121	 57.665	 0.0	 20.0	 -20.0	 1.0	 100.0	 1	 100.0	 15.33; % NG
	8122	 50.835	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 1.67; % NG
	8123	 127.32	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 54.64; % NG
	8125	 129.62	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 59.24; % NG
	8126	 127.32	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 54.64; % NG
	8127	 129.62	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 59.24; % NG
	8128	 129.62	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 59.24; % NG
	8130	 61.225	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.45; % NG
	8141	 55.365	 5.0	 20.0	 -10.0	 1.0	 100.0	 1	 100.0	 10.73; % NG
	8143	 128.425	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 56.85; % NG
	8145	 132.605	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 65.21; % COW
	8146	 132.505	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 65.01; % NG
	8147	 132.58	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 65.16; % NG
	8148	 132.58	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 65.16; % NG
	8149	 132.505	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 65.01; % NG
	8151	 132.59	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 65.18; % NG
	8153	 132.58	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 65.16; % NG
	8154	 132.59	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 65.18; % NG
	8157	 57.68	 0.0	 20.0	 -20.0	 1.0	 100.0	 1	 100.0	 15.36; % NG
	8159	 61.915	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.83; % NG
	8162	 129.13	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 58.26; % NG
	8163	 55.0	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 10.0; % NG
	8167	 350.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 600.0	 100.0; % NUC
	8173	 129.13	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 58.26; % NG
	8179	 132.32	 0.0	 50.0	 -50.0	 1.0	 100.0	 1	 200.0	 64.64; % NG
	8191	 61.62	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.24; % NG
	8193	 52.17	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 4.34; % COW
	8202	 120.0	 0.0	 30.0	 -30.0	 1.0	 100.0	 1	 200.0	 40.0; % NG
	8205	 59.45	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 18.9; % COW
	8206	 58.775	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 17.55; % NG
	8218	 61.035	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.07; % NG
	8219	 61.035	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.07; % NG
	8220	 61.035	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.07; % NG
	8221	 61.035	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.07; % NG
	8222	 61.035	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.07; % NG
	8223	 61.035	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.07; % NG
	8224	 61.035	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.07; % COW
	8246	 50.085	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 0.17; % NG
	8253	 56.665	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 13.33; % NG
	8274	 120.455	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 40.91; % COW
	8275	 120.455	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 40.91; % NG
	8276	 120.455	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 40.91; % NG
	8290	 183.335	 20.0	 90.0	 -50.0	 1.0	 100.0	 1	 300.0	 66.67; % NG
	8299	 53.5	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 7.0; % COW
	8301	 121.86	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 43.72; % NG
	8308	 129.62	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 59.24; % NG
	8317	 65.21	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 30.42; % NG
	8319	 65.21	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 30.42; % NG
	8320	 65.21	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 30.42; % NG
	8321	 21.955	 -15.0	 40.0	 -70.0	 1.0	 100.0	 1	 100.0	 -56.09; % NG
	8323	 58.535	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 17.07; % NG
	8326	 59.065	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 18.13; % PEL
	8342	 127.105	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 54.21; % NG
	8343	 119.395	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 38.79; % NG
	8352	 58.335	 5.0	 20.0	 -10.0	 1.0	 100.0	 1	 100.0	 16.67; % NG
	8354	 119.395	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 38.79; % NG
	8357	 119.395	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 38.79; % NG
	8359	 52.325	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 4.65; % COW
	8367	 62.035	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.07; % NG
	8369	 61.105	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.21; % COW
	8370	 61.915	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.83; % COW
	8373	 62.0	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.0; % NG
	8378	 62.0	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.0; % NG
	8380	 61.105	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.21; % NG
	8385	 60.0	 5.0	 10.0	 0.0	 1.0	 100.0	 1	 100.0	 20.0; % NG
	8386	 58.075	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 16.15; % COW
	8387	 128.225	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 56.45; % COW
	8388	 350.0	 35.0	 100.0	 -30.0	 1.0	 100.0	 1	 600.0	 100.0; % NG
	8389	 130.895	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 61.79; % NG
	8393	 55.135	 5.0	 20.0	 -10.0	 1.0	 100.0	 1	 100.0	 10.27; % COW
	8394	 128.75	 -10.0	 60.0	 -80.0	 1.0	 100.0	 1	 200.0	 57.5; % NG
	8396	 51.425	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 2.85; % NG
	8397	 61.175	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.35; % COW
	8402	 61.175	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.35; % COW
	8409	 58.21	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 16.42; % NG
	8413	 63.335	 0.0	 20.0	 -20.0	 1.0	 100.0	 1	 100.0	 26.67; % NG
	8415	 57.15	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 14.3; % NG
	8421	 58.47	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 16.94; % NG
	8423	 350.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 600.0	 100.0; % NG
	8424	 350.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	8425	 53.455	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 6.91; % COW
	8433	 118.6	 5.0	 40.0	 -30.0	 1.0	 100.0	 1	 200.0	 37.2; % NG
	8436	 64.5	 0.0	 30.0	 -30.0	 1.0	 100.0	 1	 100.0	 29.0; % COW
	8439	 130.39	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 60.78; % NG
	8441	 55.215	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 10.43; % NG
	8444	 132.59	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 65.18; % COW
	8445	 58.24	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 16.48; % NG
	8447	 57.405	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 14.81; % NG
	8451	 63.585	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 100.0	 27.17; % COW
	8453	 450.0	 -5.0	 120.0	 -130.0	 1.0	 100.0	 1	 700.0	 200.0; % COW
	8456	 118.515	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 37.03; % NG
	8457	 58.55	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 17.1; % NG
	8459	 58.55	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 17.1; % NG
	8470	 122.105	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 44.21; % NG
	8471	 122.105	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 44.21; % NG
	8473	 122.105	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 44.21; % NG
	8474	 122.105	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 44.21; % NG
	8476	 52.665	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 5.33; % COW
	8479	 56.66	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 13.32; % NG
	8483	 450.0	 0.0	 100.0	 -100.0	 1.0	 100.0	 1	 700.0	 200.0; % COW
	8488	 53.75	 5.0	 10.0	 0.0	 1.0	 100.0	 1	 100.0	 7.5; % NG
	8490	 61.435	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.87; % NG
	8493	 51.335	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 2.67; % NG
	8499	 250.0	 40.0	 100.0	 -20.0	 1.0	 100.0	 1	 400.0	 100.0; % COW
	8519	 130.895	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 61.79; % NG
	8524	 62.93	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 25.86; % COW
	8530	 56.465	 5.0	 20.0	 -10.0	 1.0	 100.0	 1	 100.0	 12.93; % NG
	8537	 124.785	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 49.57; % NG
	8538	 122.765	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 45.53; % NG
	8544	 121.31	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 42.62; % NG
	8545	 123.155	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 46.31; % NG
	8546	 123.155	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 46.31; % NG
	8547	 122.86	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 45.72; % NG
	8548	 122.86	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 45.72; % COW
	8549	 122.675	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 45.35; % NG
	8550	 122.675	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 45.35; % NG
	8552	 127.285	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 54.57; % NG
	8555	 60.335	 0.0	 20.0	 -20.0	 1.0	 100.0	 1	 100.0	 20.67; % NG
	8559	 119.165	 0.0	 30.0	 -30.0	 1.0	 100.0	 1	 200.0	 38.33; % NG
	8561	 250.0	 35.0	 100.0	 -30.0	 1.0	 100.0	 1	 400.0	 100.0; % NG
	8563	 56.205	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 12.41; % COW
	8569	 1150.0	 200.0	 520.0	 -120.0	 1.0	 100.0	 1	 1800.0	 500.0; % COW
	8570	 1150.0	 200.0	 520.0	 -120.0	 1.0	 100.0	 1	 1800.0	 500.0; % COW
	8571	 1150.0	 200.0	 520.0	 -120.0	 1.0	 100.0	 1	 1800.0	 500.0; % COW
	8573	 58.875	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 17.75; % NG
	8576	 60.375	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 20.75; % COW
	8577	 57.295	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 14.59; % COW
	8578	 57.295	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 14.59; % NG
	8581	 59.685	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 19.37; % NG
	8582	 59.685	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 19.37; % NG
	8595	 51.935	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 3.87; % COW
	8598	 128.805	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 57.61; % NG
	8604	 132.555	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 65.11; % COW
	8609	 132.555	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 65.11; % NG
	8610	 132.555	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 65.11; % NG
	8632	 500.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 800.0	 200.0; % COW
	8635	 250.0	 35.0	 100.0	 -30.0	 1.0	 100.0	 1	 400.0	 100.0; % COW
	8637	 130.16	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 60.32; % NG
	8639	 117.67	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 35.34; % NG
	8644	 131.5	 5.0	 50.0	 -40.0	 1.0	 100.0	 1	 200.0	 63.0; % NG
	8647	 350.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	8648	 350.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	8651	 57.935	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 15.87; % NG
	8654	 50.835	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 1.67; % NG
	8655	 124.155	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 48.31; % NG
	8656	 54.0	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 8.0; % NG
	8658	 131.795	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 63.59; % COW
	8665	 131.795	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 63.59; % NG
	8668	 59.435	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 18.87; % COW
	8671	 59.435	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 18.87; % NG
	8675	 60.515	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.03; % NG
	8679	 60.515	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.03; % NG
	8680	 60.515	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.03; % NG
	8686	 60.64	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.28; % NG
	8687	 124.785	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 49.57; % NG
	8701	 126.235	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 52.47; % NG
	8702	 126.235	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 52.47; % NG
	8704	 61.675	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.35; % NG
	8706	 126.235	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 52.47; % NG
	8707	 126.235	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 52.47; % NG
	8709	 57.935	 0.0	 20.0	 -20.0	 1.0	 100.0	 1	 100.0	 15.87; % NG
	8711	 850.0	 200.0	 520.0	 -120.0	 1.0	 100.0	 1	 1300.0	 400.0; % COW
	8712	 850.0	 200.0	 520.0	 -120.0	 1.0	 100.0	 1	 1300.0	 400.0; % COW
	8713	 850.0	 200.0	 520.0	 -120.0	 1.0	 100.0	 1	 1300.0	 400.0; % COW
	8714	 850.0	 200.0	 520.0	 -120.0	 1.0	 100.0	 1	 1300.0	 400.0; % COW
	8716	 350.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	8717	 350.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	8719	 59.945	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 19.89; % NG
	8725	 57.695	 5.0	 20.0	 -10.0	 1.0	 100.0	 1	 100.0	 15.39; % NG
	8726	 55.28	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 10.56; % NG
	8731	 131.405	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 62.81; % NG
	8732	 131.405	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 62.81; % COW
	8733	 131.405	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 62.81; % NG
	8734	 131.405	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 62.81; % NG
	8735	 131.405	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 62.81; % NG
	8740	 350.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	8741	 350.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	8744	 116.765	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 33.53; % NG
	8745	 116.765	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 33.53; % COW
	8746	 116.765	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 33.53; % NG
	8747	 116.765	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 33.53; % NG
	8753	 124.925	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 49.85; % NG
	8755	 116.765	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 33.53; % COW
	8759	 300.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 500.0	 100.0; % COW
	8763	 60.425	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 20.85; % NG
	8764	 51.14	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 2.28; % NG
	8770	 300.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 500.0	 100.0; % COW
	8772	 118.38	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 36.76; % COW
	8773	 350.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 600.0	 100.0; % NG
	8774	 118.75	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 37.5; % NG
	8776	 63.335	 0.0	 20.0	 -20.0	 1.0	 100.0	 1	 100.0	 26.67; % NG
	8791	 50.0	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 -0.0; % SYNC
	8793	 61.67	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.34; % NG
	8797	 59.065	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 18.13; % NG
	8803	 500.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 800.0	 200.0; % COW
	8806	 132.25	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 64.5; % NG
	8807	 132.25	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 64.5; % NG
	8809	 132.25	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 64.5; % NG
	8810	 61.985	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.97; % COW
	8816	 250.0	 20.0	 120.0	 -80.0	 1.0	 100.0	 1	 400.0	 100.0; % NG
	8820	 61.64	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.28; % NG
	8824	 121.2	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 42.4; % NG
	8830	 250.0	 25.0	 90.0	 -40.0	 1.0	 100.0	 1	 400.0	 100.0; % NG
	8837	 52.915	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 5.83; % NG
	8838	 121.2	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 42.4; % COW
	8839	 127.115	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 54.23; % NG
	8841	 500.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 800.0	 200.0; % COW
	8842	 500.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 800.0	 200.0; % COW
	8843	 500.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 800.0	 200.0; % COW
	8844	 500.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 800.0	 200.0; % COW
	8846	 250.0	 30.0	 100.0	 -40.0	 1.0	 100.0	 1	 400.0	 100.0; % COW
	8851	 61.835	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.67; % COW
	8852	 62.035	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.07; % NG
	8857	 52.335	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 4.67; % NG
	8860	 58.355	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 16.71; % NG
	8861	 58.355	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 16.71; % NG
	8864	 60.005	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 20.01; % NG
	8866	 60.005	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 20.01; % NG
	8867	 60.005	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 20.01; % PEL
	8873	 117.355	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 34.71; % COW
	8881	 53.5	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 7.0; % NG
	8884	 128.225	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 56.45; % NG
	8885	 132.095	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 64.19; % NG
	8887	 63.335	 0.0	 30.0	 -30.0	 1.0	 100.0	 1	 100.0	 26.67; % COW
	8893	 52.175	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 4.35; % NG
	8894	 350.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	8896	 57.735	 0.0	 20.0	 -20.0	 1.0	 100.0	 1	 100.0	 15.47; % NG
	8897	 126.71	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 53.42; % NG
	8898	 126.69	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 53.38; % NG
	8900	 59.9	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 19.8; % COW
	8901	 58.1	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 16.2; % NG
	8902	 58.1	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 16.2; % NG
	8903	 58.1	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 16.2; % NG
	8904	 126.665	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 53.33; % NG
	8905	 126.665	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 53.33; % NG
	8906	 58.1	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 16.2; % NG
	8907	 126.665	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 53.33; % COW
	8908	 126.71	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 53.42; % COW
	8909	 126.71	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 53.42; % NG
	8910	 126.71	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 53.42; % NG
	8911	 450.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 700.0	 200.0; % COW
	8912	 124.155	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 48.31; % COW
	8914	 57.575	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 15.15; % NG
	8916	 50.835	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 1.67; % NG
	8921	 300.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 500.0	 100.0; % COW
	8933	 55.0	 0.0	 20.0	 -20.0	 1.0	 100.0	 1	 100.0	 10.0; % NG
	8937	 118.945	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 37.89; % NG
	8938	 118.945	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 37.89; % NG
	8939	 118.945	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 37.89; % NG
	8941	 117.25	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 34.5; % COW
	8942	 59.895	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 19.79; % NG
	8943	 117.25	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 34.5; % NG
	8944	 117.25	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 34.5; % COW
	8945	 119.09	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 38.18; % NG
	8952	 61.435	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.87; % NG
	8953	 61.435	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.87; % NG
	8954	 61.435	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.87; % COW
	8955	 61.435	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.87; % NG
	8956	 58.67	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 17.34; % NG
	8958	 1050.0	 200.0	 520.0	 -120.0	 1.0	 100.0	 1	 1600.0	 500.0; % COW
	8961	 59.125	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 18.25; % NG
	8962	 61.435	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.87; % NG
	8963	 61.435	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.87; % NG
	8964	 125.795	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 51.59; % NG
	8965	 125.795	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 51.59; % NG
	8966	 125.795	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 51.59; % NG
	8967	 125.795	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 51.59; % NG
	8969	 55.57	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 11.14; % COW
	8976	 124.955	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 49.91; % NG
	8980	 57.2	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 14.4; % NG
	8994	 126.32	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 52.64; % NG
	8999	 57.56	 5.0	 20.0	 -10.0	 1.0	 100.0	 1	 100.0	 15.12; % COW
	9016	 63.335	 0.0	 20.0	 -20.0	 1.0	 100.0	 1	 100.0	 26.67; % COW
	9024	 300.0	 45.0	 150.0	 -60.0	 1.0	 100.0	 1	 500.0	 100.0; % COW
	9028	 56.175	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 12.35; % COW
	9033	 450.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 700.0	 200.0; % COW
	9034	 450.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 700.0	 200.0; % COW
	9035	 122.215	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 44.43; % COW
	9041	 62.01	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.02; % NG
	9045	 350.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	9047	 66.1	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 32.2; % NG
	9049	 250.0	 35.0	 100.0	 -30.0	 1.0	 100.0	 1	 400.0	 100.0; % NG
	9051	 350.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	9054	 250.0	 30.0	 100.0	 -40.0	 1.0	 100.0	 1	 400.0	 100.0; % COW
	9056	 50.385	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 0.77; % NG
	9060	 350.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	9061	 58.875	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 17.75; % NG
	9074	 64.615	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 100.0	 29.23; % COW
	9075	 61.4	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.8; % NG
	9081	 59.45	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 18.9; % NG
	9084	 132.56	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 65.12; % NG
	9088	 61.55	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.1; % NG
	9102	 58.97	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 17.94; % COW
	9106	 58.97	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 17.94; % NG
	9107	 58.97	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 17.94; % NG
	9110	 57.86	 0.0	 20.0	 -20.0	 1.0	 100.0	 1	 100.0	 15.72; % NG
	9120	 58.63	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 17.26; % NG
	9123	 119.835	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 39.67; % NG
	9137	 64.515	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 29.03; % NG
	9138	 61.99	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.98; % NG
	9141	 119.495	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 38.99; % NG
	9142	 119.495	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 38.99; % NG
	9144	 127.925	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 55.85; % NG
	9148	 850.0	 200.0	 520.0	 -120.0	 1.0	 100.0	 1	 1300.0	 400.0; % COW
	9149	 62.36	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.72; % NG
	9151	 53.0	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 6.0; % NG
	9152	 1150.0	 200.0	 520.0	 -120.0	 1.0	 100.0	 1	 1800.0	 500.0; % COW
	9166	 55.835	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 11.67; % COW
	9168	 51.6	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 3.2; % COW
	9169	 57.455	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 14.91; % COW
	9179	 129.115	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 58.23; % COW
	9182	 50.0	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 -0.0; % SYNC
	9184	 55.735	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 11.47; % PEL
	9188	 129.635	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 59.27; % NG
	9189	 129.635	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 59.27; % NG
	9190	 129.635	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 59.27; % NG
	9191	 129.635	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 59.27; % NG
	9195	 300.0	 35.0	 130.0	 -60.0	 1.0	 100.0	 1	 500.0	 100.0; % NG
	9204	 187.165	 15.0	 90.0	 -60.0	 1.0	 100.0	 1	 300.0	 74.33; % NG
	9206	 300.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 500.0	 100.0; % NG
	9213	 55.985	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 11.97; % NG
	9214	 63.0	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 26.0; % NG
	9215	 63.355	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 26.71; % NG
	9216	 56.85	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 13.7; % NG
	9218	 59.295	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 18.59; % NG
	9219	 61.765	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.53; % NG
	9220	 61.765	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.53; % NG
	9222	 55.985	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 11.97; % NG
	9223	 51.125	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 2.25; % COW
	9224	 55.985	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 11.97; % COW
	9225	 60.36	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 20.72; % NG
	9227	 57.665	 0.0	 20.0	 -20.0	 1.0	 100.0	 1	 100.0	 15.33; % NG
	9228	 131.805	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 63.61; % COW
	9229	 131.805	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 63.61; % NG
	9230	 131.805	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 63.61; % NG
	9231	 131.805	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 63.61; % NG
	9232	 131.805	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 63.61; % NG
	9233	 131.805	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 63.61; % NG
	9236	 61.67	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.34; % NG
	9237	 131.835	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 63.67; % COW
	9244	 61.54	 5.0	 20.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.08; % NG
	9246	 118.485	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 36.97; % NG
	9247	 118.485	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 36.97; % NG
	9250	 300.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 500.0	 100.0; % NG
	9256	 350.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	9257	 350.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	9258	 350.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	9260	 350.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 600.0	 100.0; % NG
	9261	 350.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	9265	 350.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 600.0	 100.0; % PEL
	9273	 61.985	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.97; % COW
	9279	 128.24	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 56.48; % NG
	9280	 61.4	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.8; % NG
	9281	 300.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 500.0	 100.0; % COW
	9282	 116.98	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 33.96; % NG
	9283	 350.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	9288	 58.095	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 16.19; % NG
	9292	 60.0	 5.0	 20.0	 -10.0	 1.0	 100.0	 1	 100.0	 20.0; % NG
	9294	 450.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 700.0	 200.0; % COW
	9297	 62.045	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.09; % NG
	9301	 126.595	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 53.19; % NG
	9312	 53.005	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 6.01; % COW
	9314	 60.08	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 20.16; % COW
	9317	 62.41	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.82; % COW
	9321	 59.9	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 19.8; % NG
	9322	 56.635	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 13.27; % COW
	9323	 56.635	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 13.27; % COW
	9327	 51.755	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 3.51; % COW
	9342	 58.915	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 17.83; % NG
	9343	 119.17	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 38.34; % NG
	9345	 62.08	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.16; % NG
	9346	 62.08	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.16; % NG
	9347	 62.08	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.16; % COW
	9348	 62.08	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.16; % NG
	9349	 62.08	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.16; % NG
	9350	 62.08	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.16; % NG
	9351	 62.08	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.16; % NG
	9352	 62.08	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.16; % COW
	9354	 62.41	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.82; % NG
	9357	 118.75	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 37.5; % NG
	9359	 128.225	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 56.45; % NG
	9364	 300.0	 35.0	 100.0	 -30.0	 1.0	 100.0	 1	 500.0	 100.0; % COW
	9370	 300.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 500.0	 100.0; % COW
	9374	 62.255	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.51; % NG
	9376	 60.575	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.15; % NG
	9377	 60.575	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.15; % NG
	9378	 60.575	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.15; % NG
	9379	 60.575	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.15; % NG
	9383	 60.575	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.15; % NG
	9384	 60.575	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.15; % NG
	9387	 56.525	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 13.05; % NG
	9389	 53.315	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 6.63; % COW
	9392	 450.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 700.0	 200.0; % NUC
	9393	 121.31	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 42.62; % NG
	9395	 120.0	 5.0	 30.0	 -20.0	 1.0	 100.0	 1	 200.0	 40.0; % NG
	9408	 132.525	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 65.05; % NG
	9413	 50.835	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 1.67; % NG
	9417	 119.09	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 38.18; % NG
	9421	 50.305	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 0.61; % NG
	9422	 124.955	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 49.91; % COW
	9427	 61.325	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.65; % NG
	9438	 122.755	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 45.51; % NG
	9439	 450.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 700.0	 200.0; % COW
	9440	 122.755	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 45.51; % NG
	9441	 122.755	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 45.51; % NG
	9442	 122.755	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 45.51; % NG
	9443	 122.755	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 45.51; % NG
	9457	 250.0	 0.0	 80.0	 -80.0	 1.0	 100.0	 1	 400.0	 100.0; % NG
	9461	 116.665	 5.0	 30.0	 -20.0	 1.0	 100.0	 1	 200.0	 33.33; % NG
	9464	 131.015	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 62.03; % NG
	9466	 58.615	 5.0	 20.0	 -10.0	 1.0	 100.0	 1	 100.0	 17.23; % COW
	9467	 128.1	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 56.2; % NG
	9471	 60.99	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.98; % NG
	9472	 60.99	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.98; % NG
	9473	 60.855	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.71; % COW
	9474	 60.855	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.71; % NG
	9475	 58.995	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 17.99; % NG
	9476	 58.995	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 17.99; % COW
	9477	 59.17	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 18.34; % NG
	9478	 58.955	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 17.91; % COW
	9479	 58.955	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 17.91; % NG
	9480	 58.955	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 17.91; % NG
	9481	 58.955	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 17.91; % NG
	9482	 58.955	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 17.91; % PEL
	9486	 128.1	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 56.2; % NG
	9504	 64.935	 10.0	 40.0	 -20.0	 1.0	 100.0	 1	 100.0	 29.87; % NG
	9508	 122.56	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 45.12; % NG
	9512	 132.01	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 64.02; % NG
	9513	 300.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 500.0	 100.0; % NG
	9515	 300.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 500.0	 100.0; % NG
	9520	 58.585	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 17.17; % NG
	9521	 61.945	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.89; % NG
	9522	 300.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 500.0	 100.0; % NG
	9523	 300.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 500.0	 100.0; % NG
	9525	 300.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 500.0	 100.0; % NG
	9527	 500.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 800.0	 200.0; % COW
	9540	 350.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	9542	 57.46	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 14.92; % NG
	9547	 130.105	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 60.21; % NG
	9549	 130.105	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 60.21; % NG
	9550	 130.105	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 60.21; % NG
	9551	 130.105	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 60.21; % NG
	9552	 58.235	 0.0	 20.0	 -20.0	 1.0	 100.0	 1	 100.0	 16.47; % NG
	9553	 250.0	 10.0	 90.0	 -70.0	 1.0	 100.0	 1	 400.0	 100.0; % NG
	9554	 50.705	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 1.41; % NG
	9556	 131.945	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 63.89; % NG
	9573	 183.665	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 300.0	 67.33; % NG
	9574	 183.665	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 300.0	 67.33; % COW
	9579	 1050.0	 200.0	 520.0	 -120.0	 1.0	 100.0	 1	 1600.0	 500.0; % COW
	9584	 700.0	 200.0	 520.0	 -120.0	 1.0	 100.0	 1	 1100.0	 300.0; % COW
	9585	 700.0	 200.0	 520.0	 -120.0	 1.0	 100.0	 1	 1100.0	 300.0; % PEL
	9586	 117.51	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 35.02; % NG
	9587	 117.51	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 35.02; % NG
	9588	 63.39	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 26.78; % NG
	9589	 63.39	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 26.78; % NG
	9590	 63.39	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 26.78; % NG
	9591	 63.39	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 26.78; % NG
	9597	 250.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 400.0	 100.0; % COW
	9602	 125.5	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 51.0; % NG
	9613	 128.225	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 56.45; % NG
	9614	 58.28	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 16.56; % NG
	9616	 65.725	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 31.45; % NG
	9617	 117.475	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 34.95; % NG
	9618	 117.475	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 34.95; % COW
	9619	 118.355	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 36.71; % NG
	9622	 118.355	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 36.71; % NG
	9623	 64.905	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 29.81; % NG
	9627	 1150.0	 200.0	 520.0	 -120.0	 1.0	 100.0	 1	 1800.0	 500.0; % COW
	9628	 116.865	 5.0	 30.0	 -20.0	 1.0	 100.0	 1	 200.0	 33.73; % NG
	9638	 56.165	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 12.33; % COW
	9655	 1250.0	 200.0	 520.0	 -120.0	 1.0	 100.0	 1	 1900.0	 600.0; % NG
	9656	 1250.0	 200.0	 520.0	 -120.0	 1.0	 100.0	 1	 1900.0	 600.0; % NUC
	9659	 61.28	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.56; % NG
	9662	 130.16	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 60.32; % NG
	9679	 1150.0	 200.0	 520.0	 -120.0	 1.0	 100.0	 1	 1800.0	 500.0; % COW
	9681	 1150.0	 200.0	 520.0	 -120.0	 1.0	 100.0	 1	 1800.0	 500.0; % PEL
	9682	 1150.0	 200.0	 520.0	 -120.0	 1.0	 100.0	 1	 1800.0	 500.0; % COW
	9687	 500.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 800.0	 200.0; % COW
	9690	 250.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 400.0	 100.0; % NG
	9693	 52.975	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 5.95; % NG
	9695	 61.315	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.63; % NG
	9696	 61.315	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.63; % NG
	9697	 61.315	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.63; % NG
	9698	 61.315	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.63; % NG
	9699	 63.075	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 26.15; % NG
	9700	 60.26	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 20.52; % NG
	9702	 63.075	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 26.15; % COW
	9706	 57.985	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 15.97; % NG
	9713	 118.405	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 36.81; % NG
	9722	 250.0	 0.0	 90.0	 -90.0	 1.0	 100.0	 1	 400.0	 100.0; % COW
	9728	 50.02	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 0.04; % NG
	9738	 300.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 500.0	 100.0; % COW
	9742	 63.935	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 27.87; % COW
	9748	 51.215	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 2.43; % COW
	9751	 62.615	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 25.23; % NG
	9753	 62.62	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 25.24; % NG
	9754	 131.875	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 63.75; % NG
	9756	 116.98	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 33.96; % NG
	9757	 131.885	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 63.77; % COW
	9758	 131.885	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 63.77; % NG
	9759	 131.875	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 63.75; % NG
	9761	 131.885	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 63.77; % NG
	9762	 131.885	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 63.77; % NG
	9763	 131.885	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 63.77; % NG
	9764	 131.885	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 63.77; % NG
	9766	 65.0	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 30.0; % NG
	9775	 129.115	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 58.23; % NG
	9778	 53.59	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 7.18; % COW
	9781	 57.69	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 15.38; % NG
	9785	 127.895	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 55.79; % NG
	9793	 133.235	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 66.47; % COW
	9797	 50.06	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 0.12; % NG
	9804	 56.165	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 12.33; % NG
	9808	 62.265	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.53; % COW
	9809	 59.065	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 18.13; % COW
	9815	 62.095	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.19; % COW
	9818	 63.98	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 27.96; % NG
	9830	 51.28	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 2.56; % COW
	9836	 54.265	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 8.53; % NG
	9852	 300.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 500.0	 100.0; % NG
	9853	 54.65	 5.0	 10.0	 0.0	 1.0	 100.0	 1	 100.0	 9.3; % NG
	9855	 52.935	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 5.87; % NG
	9856	 131.72	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 63.44; % NG
	9860	 57.5	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 15.0; % NG
	9862	 132.3	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 64.6; % NG
	9870	 132.3	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 64.6; % NG
	9871	 300.0	 40.0	 150.0	 -70.0	 1.0	 100.0	 1	 500.0	 100.0; % NG
	9873	 58.875	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 17.75; % NG
	9875	 450.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 700.0	 200.0; % COW
	9880	 62.0	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.0; % NG
	9881	 51.595	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 3.19; % NG
	9884	 61.435	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.87; % NG
	9885	 62.0	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.0; % NG
	9887	 62.0	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.0; % COW
	9889	 350.0	 0.0	 100.0	 -100.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	9890	 124.74	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 49.48; % NG
	9896	 63.245	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 26.49; % NG
	9897	 56.205	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 12.41; % NG
	9900	 56.205	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 12.41; % COW
	9901	 61.325	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.65; % NG
	9902	 121.395	 0.0	 40.0	 -40.0	 1.0	 100.0	 1	 200.0	 42.79; % NG
	9906	 196.665	 0.0	 70.0	 -70.0	 1.0	 100.0	 1	 300.0	 93.33; % COW
	9909	 127.005	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 54.01; % NG
	9911	 127.005	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 54.01; % NG
	9912	 127.005	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 54.01; % NG
	9914	 60.005	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 20.01; % COW
	9922	 60.975	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.95; % NG
	9923	 59.74	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 19.48; % NG
	9926	 62.985	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 25.97; % NG
	9932	 59.63	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 19.26; % NG
	9933	 60.975	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.95; % NG
	9937	 183.335	 20.0	 90.0	 -50.0	 1.0	 100.0	 1	 300.0	 66.67; % NG
	9946	 58.77	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 17.54; % NG
	9953	 131.015	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 62.03; % NG
	9957	 56.855	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 13.71; % NG
	9958	 56.855	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 13.71; % NG
	9959	 56.855	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 13.71; % COW
	9960	 127.485	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 54.97; % NG
	9961	 57.805	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 15.61; % NG
	9963	 59.315	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 18.63; % PEL
	9964	 57.805	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 15.61; % NG
	9972	 250.0	 30.0	 100.0	 -40.0	 1.0	 100.0	 1	 400.0	 100.0; % NG
	9974	 60.88	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.76; % NG
	9975	 63.335	 0.0	 20.0	 -20.0	 1.0	 100.0	 1	 100.0	 26.67; % NG
	9976	 57.835	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 15.67; % NG
	9984	 121.735	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 43.47; % NG
	9995	 66.665	 0.0	 20.0	 -20.0	 1.0	 100.0	 1	 100.0	 33.33; % NG
	9997	 50.025	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 0.05; % COW
	10001	 62.035	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.07; % NG
	10004	 61.985	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.97; % COW
	10006	 60.5	 5.0	 30.0	 -20.0	 1.0	 100.0	 1	 100.0	 21.0; % NG
	10007	 61.765	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.53; % PEL
	10010	 53.455	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 6.91; % NG
	10012	 53.335	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 6.67; % NG
	10017	 122.56	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 45.12; % NG
	10023	 59.64	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 19.28; % NG
	10034	 58.425	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 16.85; % COW
	10037	 119.04	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 38.08; % NG
	10050	 61.955	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.91; % COW
	10052	 51.735	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 3.47; % NG
	10057	 117.71	 0.0	 40.0	 -40.0	 1.0	 100.0	 1	 200.0	 35.42; % NG
	10060	 850.0	 200.0	 520.0	 -120.0	 1.0	 100.0	 1	 1300.0	 400.0; % COW
	10064	 1150.0	 200.0	 520.0	 -120.0	 1.0	 100.0	 1	 1800.0	 500.0; % NUC
	10065	 1150.0	 200.0	 520.0	 -120.0	 1.0	 100.0	 1	 1800.0	 500.0; % COW
	10068	 55.985	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 11.97; % NG
	10073	 64.695	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 29.39; % NG
	10074	 64.695	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 29.39; % NG
	10075	 65.565	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 31.13; % NG
	10076	 65.565	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 31.13; % COW
	10077	 65.565	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 31.13; % NG
	10078	 65.565	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 31.13; % COW
	10080	 65.565	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 31.13; % NG
	10084	 119.225	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 38.45; % NG
	10092	 62.555	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 25.11; % NG
	10094	 300.0	 35.0	 100.0	 -30.0	 1.0	 100.0	 1	 500.0	 100.0; % NG
	10096	 61.105	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.21; % NG
	10100	 61.855	 5.0	 20.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.71; % NG
	10101	 124.155	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 48.31; % NG
	10102	 450.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 700.0	 200.0; % COW
	10110	 60.08	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 20.16; % NG
	10114	 50.755	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 1.51; % PEL
	10115	 450.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 700.0	 200.0; % COW
	10116	 450.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 700.0	 200.0; % COW
	10117	 450.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 700.0	 200.0; % NG
	10120	 127.925	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 55.85; % NG
	10132	 61.225	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.45; % PEL
	10134	 61.225	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.45; % COW
	10135	 61.225	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.45; % NG
	10141	 130.8	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 61.6; % NG
	10142	 130.8	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 61.6; % NG
	10143	 130.8	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 61.6; % COW
	10151	 61.02	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.04; % NG
	10156	 250.0	 30.0	 100.0	 -40.0	 1.0	 100.0	 1	 400.0	 100.0; % COW
	10158	 59.885	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 19.77; % NG
	10164	 61.02	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.04; % NG
	10165	 500.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 800.0	 200.0; % NG
	10171	 130.15	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 60.3; % NG
	10172	 130.15	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 60.3; % NG
	10173	 130.15	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 60.3; % NG
	10174	 130.15	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 60.3; % NG
	10177	 250.0	 0.0	 90.0	 -90.0	 1.0	 100.0	 1	 400.0	 100.0; % NG
	10178	 61.55	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.1; % NG
	10186	 51.735	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 3.47; % NG
	10192	 58.44	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 16.88; % COW
	10194	 58.355	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 16.71; % NG
	10195	 58.355	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 16.71; % NG
	10197	 57.665	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 15.33; % NG
	10198	 57.665	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 15.33; % NG
	10201	 58.925	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 17.85; % NG
	10202	 58.925	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 17.85; % COW
	10210	 62.84	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 25.68; % NG
	10211	 300.0	 45.0	 190.0	 -100.0	 1.0	 100.0	 1	 500.0	 100.0; % COW
	10218	 59.45	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 18.9; % COW
	10222	 61.04	 5.0	 20.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.08; % NG
	10223	 60.835	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.67; % NG
	10232	 57.885	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 15.77; % NG
	10236	 58.125	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 16.25; % NG
	10237	 50.98	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 1.96; % COW
	10238	 58.27	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 16.54; % NG
	10239	 187.88	 10.0	 70.0	 -50.0	 1.0	 100.0	 1	 300.0	 75.76; % NG
	10241	 56.5	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 13.0; % NG
	10242	 56.5	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 13.0; % COW
	10246	 58.915	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 17.83; % NG
	10249	 61.62	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.24; % NG
	10250	 250.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 400.0	 100.0; % COW
	10253	 127.115	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 54.23; % NG
	10254	 127.115	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 54.23; % COW
	10264	 63.935	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 27.87; % NG
	10267	 132.825	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 65.65; % NG
	10268	 132.825	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 65.65; % NG
	10269	 119.1	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 38.2; % NG
	10270	 119.1	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 38.2; % NG
	10276	 53.0	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 6.0; % COW
	10281	 61.335	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.67; % NG
	10283	 56.97	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 13.94; % COW
	10285	 52.035	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 4.07; % NG
	10287	 59.67	 5.0	 20.0	 -10.0	 1.0	 100.0	 1	 100.0	 19.34; % NG
	10295	 59.125	 5.0	 30.0	 -20.0	 1.0	 100.0	 1	 100.0	 18.25; % NG
	10298	 61.655	 0.0	 30.0	 -30.0	 1.0	 100.0	 1	 100.0	 23.31; % NG
	10302	 62.035	 5.0	 30.0	 -20.0	 1.0	 100.0	 1	 100.0	 24.07; % NG
	10311	 58.56	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 17.12; % NG
	10315	 58.45	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 16.9; % NG
	10324	 132.685	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 65.37; % NG
	10328	 128.445	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 56.89; % NG
	10329	 132.685	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 65.37; % COW
	10330	 750.0	 200.0	 520.0	 -120.0	 1.0	 100.0	 1	 1200.0	 300.0; % COW
	10337	 124.33	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 48.66; % COW
	10339	 60.855	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.71; % NG
	10343	 119.135	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 38.27; % NG
	10348	 63.41	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 26.82; % COW
	10352	 62.93	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 25.86; % NG
	10355	 130.515	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 61.03; % COW
	10357	 450.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 700.0	 200.0; % COW
	10361	 52.26	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 4.52; % NG
	10362	 118.63	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 37.26; % NG
	10363	 63.41	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 26.82; % NG
	10365	 55.835	 0.0	 20.0	 -20.0	 1.0	 100.0	 1	 100.0	 11.67; % NG
	10368	 127.65	 5.0	 60.0	 -50.0	 1.0	 100.0	 1	 200.0	 55.3; % NG
	10373	 133.265	 40.0	 110.0	 -30.0	 1.0	 100.0	 1	 200.0	 66.53; % NG
	10374	 450.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 700.0	 200.0; % COW
	10375	 450.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 700.0	 200.0; % COW
	10376	 118.7	 0.0	 40.0	 -40.0	 1.0	 100.0	 1	 200.0	 37.4; % NG
	10377	 300.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 500.0	 100.0; % COW
	10378	 300.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 500.0	 100.0; % COW
	10384	 62.01	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.02; % NG
	10386	 61.05	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.1; % NG
	10388	 57.01	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 14.02; % COW
	10390	 121.21	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 42.42; % NG
	10401	 121.86	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 43.72; % NG
	10402	 121.86	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 43.72; % NG
	10404	 121.86	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 43.72; % NG
	10405	 121.86	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 43.72; % COW
	10406	 61.405	 5.0	 20.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.81; % COW
	10408	 55.595	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 11.19; % NG
	10409	 52.1	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 4.2; % NG
	10410	 62.0	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.0; % NG
	10417	 58.855	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 17.71; % NG
	10418	 62.635	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 25.27; % PEL
	10422	 58.24	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 16.48; % NG
	10423	 122.105	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 44.21; % NG
	10426	 62.72	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 25.44; % COW
	10427	 62.72	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 25.44; % NG
	10428	 60.0	 5.0	 20.0	 -10.0	 1.0	 100.0	 1	 100.0	 20.0; % NG
	10432	 54.22	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 8.44; % NG
	10433	 52.485	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 4.97; % NG
	10434	 56.66	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 13.32; % NG
	10435	 56.66	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 13.32; % NG
	10436	 58.285	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 16.57; % NG
	10437	 55.325	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 10.65; % NG
	10438	 55.325	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 10.65; % NG
	10439	 54.22	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 8.44; % COW
	10442	 123.155	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 46.31; % NG
	10443	 58.77	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 17.54; % NG
	10447	 58.935	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 17.87; % NG
	10448	 65.18	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 30.36; % NG
	10452	 49.64	 0.0	 20.0	 -20.0	 1.0	 100.0	 1	 100.0	 -0.72; % NG
	10453	 62.97	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 25.94; % NG
	10456	 63.08	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 26.16; % NG
	10461	 350.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	10462	 350.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 600.0	 100.0; % NG
	10466	 53.335	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 6.67; % NG
	10469	 62.36	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.72; % NG
	10470	 58.935	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 17.87; % NG
	10472	 131.795	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 63.59; % COW
	10473	 250.0	 40.0	 100.0	 -20.0	 1.0	 100.0	 1	 400.0	 100.0; % COW
	10474	 131.795	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 63.59; % NG
	10475	 131.795	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 63.59; % NG
	10476	 131.795	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 63.59; % NG
	10479	 131.815	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 63.63; % NG
	10480	 131.815	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 63.63; % NG
	10488	 61.345	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.69; % NG
	10489	 61.345	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.69; % NG
	10501	 58.4	 0.0	 20.0	 -20.0	 1.0	 100.0	 1	 100.0	 16.8; % COW
	10505	 450.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 700.0	 200.0; % COW
	10507	 51.755	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 3.51; % NG
	10508	 53.63	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 7.26; % NG
	10521	 128.805	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 57.61; % NG
	10522	 128.805	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 57.61; % NG
	10527	 62.14	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.28; % NG
	10530	 1050.0	 200.0	 520.0	 -120.0	 1.0	 100.0	 1	 1600.0	 500.0; % NG
	10534	 66.14	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 32.28; % COW
	10535	 300.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 500.0	 100.0; % COW
	10537	 59.64	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 19.28; % NG
	10538	 59.64	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 19.28; % NG
	10554	 450.0	 0.0	 100.0	 -100.0	 1.0	 100.0	 1	 700.0	 200.0; % COW
	10555	 1150.0	 200.0	 520.0	 -120.0	 1.0	 100.0	 1	 1800.0	 500.0; % NUC
	10556	 1150.0	 200.0	 520.0	 -120.0	 1.0	 100.0	 1	 1800.0	 500.0; % COW
	10557	 52.125	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 4.25; % COW
	10558	 1150.0	 200.0	 520.0	 -120.0	 1.0	 100.0	 1	 1800.0	 500.0; % COW
	10567	 300.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 500.0	 100.0; % NG
	10575	 60.025	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 20.05; % COW
	10580	 50.4	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 0.8; % COW
	10588	 120.835	 10.0	 20.0	 0.0	 1.0	 100.0	 1	 200.0	 41.67; % NG
	10589	 124.155	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 48.31; % NG
	10598	 53.265	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 6.53; % NG
	10605	 62.93	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 25.86; % NG
	10612	 59.065	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 18.13; % NG
	10613	 50.155	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 0.31; % NG
	10617	 128.225	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 56.45; % NG
	10619	 127.32	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 54.64; % NG
	10621	 59.895	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 19.79; % NG
	10622	 61.685	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.37; % NG
	10625	 59.895	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 19.79; % NG
	10627	 128.065	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 56.13; % NG
	10629	 183.47	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 300.0	 66.94; % NG
	10633	 130.16	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 60.32; % NG
	10635	 118.275	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 36.55; % NG
	10640	 250.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 400.0	 100.0; % NG
	10643	 130.695	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 61.39; % NG
	10647	 300.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 500.0	 100.0; % COW
	10648	 58.68	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 17.36; % NG
	10649	 58.68	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 17.36; % NG
	10650	 52.125	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 4.25; % NG
	10652	 63.335	 0.0	 20.0	 -20.0	 1.0	 100.0	 1	 100.0	 26.67; % NG
	10653	 59.35	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 18.7; % NG
	10656	 61.46	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.92; % NG
	10657	 64.9	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 29.8; % NG
	10658	 64.9	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 29.8; % NG
	10660	 58.68	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 17.36; % NG
	10668	 60.485	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 20.97; % COW
	10669	 60.485	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 20.97; % NG
	10670	 63.08	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 26.16; % NG
	10671	 61.99	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.98; % NG
	10672	 61.99	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.98; % COW
	10674	 61.99	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.98; % COW
	10675	 61.99	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.98; % NG
	10676	 61.99	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.98; % COW
	10678	 53.895	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 7.79; % COW
	10693	 51.665	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 3.33; % NG
	10696	 60.64	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.28; % NG
	10712	 61.125	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.25; % COW
	10713	 58.345	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 16.69; % NG
	10715	 450.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 700.0	 200.0; % COW
	10719	 57.5	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 15.0; % NG
	10720	 57.5	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 15.0; % NG
	10721	 58.345	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 16.69; % NG
	10722	 58.345	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 16.69; % NG
	10738	 124.925	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 49.85; % NG
	10742	 58.56	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 17.12; % NG
	10743	 57.67	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 15.34; % NG
	10747	 128.445	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 56.89; % NG
	10748	 127.115	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 54.23; % COW
	10750	 124.33	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 48.66; % NG
	10752	 119.135	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 38.27; % NG
	10753	 119.905	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 39.81; % NG
	10754	 119.905	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 39.81; % NG
	10755	 124.33	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 48.66; % NG
	10756	 124.33	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 48.66; % NG
	10757	 53.5	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 7.0; % NG
	10762	 450.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 700.0	 200.0; % COW
	10763	 450.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 700.0	 200.0; % COW
	10764	 450.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 700.0	 200.0; % COW
	10765	 450.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 700.0	 200.0; % COW
	10775	 123.14	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 46.28; % COW
	10783	 122.5	 10.0	 20.0	 0.0	 1.0	 100.0	 1	 200.0	 45.0; % NG
	10784	 63.335	 0.0	 30.0	 -30.0	 1.0	 100.0	 1	 100.0	 26.67; % NG
	10785	 61.915	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.83; % NG
	10788	 62.265	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.53; % NG
	10803	 118.275	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 36.55; % NG
	10804	 118.275	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 36.55; % NG
	10808	 131.675	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 63.35; % NG
	10809	 130.445	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 60.89; % NG
	10811	 130.645	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 61.29; % NG
	10814	 250.0	 5.0	 140.0	 -130.0	 1.0	 100.0	 1	 400.0	 100.0; % NG
	10825	 250.0	 0.0	 90.0	 -90.0	 1.0	 100.0	 1	 400.0	 100.0; % NG
	10829	 50.31	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 0.62; % COW
	10835	 65.75	 0.0	 20.0	 -20.0	 1.0	 100.0	 1	 100.0	 31.5; % NG
	10841	 131.945	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 63.89; % NG
	10845	 61.62	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.24; % NG
	10847	 127.485	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 54.97; % NG
	10862	 63.145	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 26.29; % NG
	10865	 62.43	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.86; % COW
	10881	 58.855	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 17.71; % PEL
	10891	 55.2	 5.0	 30.0	 -20.0	 1.0	 100.0	 1	 100.0	 10.4; % NG
	10898	 58.415	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 16.83; % NG
	10901	 124.205	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 48.41; % NG
	10907	 131.015	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 62.03; % NG
	10908	 350.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 600.0	 100.0; % NG
	10913	 126.32	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 52.64; % COW
	10918	 124.935	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 49.87; % NG
	10927	 350.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	10928	 350.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	10930	 350.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 600.0	 100.0; % NG
	10932	 200.0	 25.0	 120.0	 -70.0	 1.0	 100.0	 1	 300.0	 100.0; % COW
	10935	 58.585	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 17.17; % NG
	10938	 57.255	 5.0	 20.0	 -10.0	 1.0	 100.0	 1	 100.0	 14.51; % NG
	10940	 63.5	 0.0	 20.0	 -20.0	 1.0	 100.0	 1	 100.0	 27.0; % NG
	10945	 52.335	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 4.67; % PEL
	10946	 300.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 500.0	 100.0; % NG
	10951	 116.935	 5.0	 40.0	 -30.0	 1.0	 100.0	 1	 200.0	 33.87; % NG
	10954	 250.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 400.0	 100.0; % NG
	10963	 187.165	 15.0	 90.0	 -60.0	 1.0	 100.0	 1	 300.0	 74.33; % NG
	10971	 55.0	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 10.0; % NG
	10973	 129.68	 10.0	 60.0	 -40.0	 1.0	 100.0	 1	 200.0	 59.36; % NG
	10978	 63.145	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 26.29; % COW
	10983	 57.255	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 14.51; % NG
	10985	 129.065	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 58.13; % NG
	10987	 56.88	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 13.76; % COW
	10994	 57.86	 0.0	 20.0	 -20.0	 1.0	 100.0	 1	 100.0	 15.72; % COW
	10998	 1300.0	 200.0	 520.0	 -120.0	 1.0	 100.0	 1	 2000.0	 600.0; % COW
	11005	 62.255	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.51; % COW
	11010	 183.43	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 300.0	 66.86; % NG
	11020	 50.755	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 1.51; % NG
	11023	 64.11	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 28.22; % NG
	11025	 64.11	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 28.22; % NG
	11028	 119.505	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 39.01; % NG
	11030	 133.24	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 66.48; % NG
	11032	 1100.0	 200.0	 520.0	 -120.0	 1.0	 100.0	 1	 1700.0	 500.0; % COW
	11037	 250.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 400.0	 100.0; % NG
	11039	 60.025	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 20.05; % COW
	11047	 250.0	 5.0	 80.0	 -70.0	 1.0	 100.0	 1	 400.0	 100.0; % NG
	11049	 183.47	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 300.0	 66.94; % NG
	11051	 124.155	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 48.31; % NG
	11059	 66.665	 0.0	 20.0	 -20.0	 1.0	 100.0	 1	 100.0	 33.33; % NG
	11065	 59.065	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 18.13; % NG
	11076	 56.655	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 13.31; % NG
	11085	 60.815	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.63; % NG
	11086	 60.815	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.63; % NG
	11087	 60.815	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.63; % NG
	11088	 60.815	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.63; % COW
	11090	 57.98	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 15.96; % NG
	11095	 57.34	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 14.68; % COW
	11096	 300.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 500.0	 100.0; % NG
	11099	 61.865	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.73; % NG
	11102	 61.245	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.49; % NG
	11104	 61.245	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.49; % COW
	11106	 60.115	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 20.23; % NG
	11107	 61.245	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.49; % NG
	11108	 60.115	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 20.23; % COW
	11109	 60.115	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 20.23; % NG
	11110	 59.65	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 19.3; % NG
	11111	 60.115	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 20.23; % NG
	11115	 59.61	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 19.22; % NG
	11118	 57.865	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 15.73; % COW
	11119	 57.865	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 15.73; % NG
	11120	 58.515	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 17.03; % NG
	11121	 58.515	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 17.03; % NG
	11122	 63.18	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 26.36; % NG
	11124	 57.865	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 15.73; % COW
	11125	 57.865	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 15.73; % NG
	11128	 130.16	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 60.32; % NG
	11129	 59.225	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 18.45; % NG
	11130	 58.515	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 17.03; % COW
	11131	 64.43	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 100.0	 28.86; % NG
	11132	 130.075	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 60.15; % COW
	11133	 130.075	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 60.15; % NG
	11137	 130.075	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 60.15; % COW
	11138	 60.5	 5.0	 30.0	 -20.0	 1.0	 100.0	 1	 100.0	 21.0; % NG
	11145	 59.6	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 19.2; % NG
	11154	 250.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 400.0	 100.0; % COW
	11155	 60.64	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.28; % NG
	11158	 51.065	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 2.13; % COW
	11167	 128.065	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 56.13; % NG
	11170	 128.75	 -10.0	 60.0	 -80.0	 1.0	 100.0	 1	 200.0	 57.5; % NG
	11172	 128.065	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 56.13; % COW
	11174	 128.065	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 56.13; % NG
	11175	 128.065	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 56.13; % NG
	11177	 53.335	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 6.67; % NG
	11191	 64.39	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 28.78; % NG
	11193	 64.39	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 28.78; % NG
	11194	 64.39	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 28.78; % COW
	11195	 64.39	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 28.78; % NG
	11196	 64.39	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 28.78; % NG
	11197	 64.39	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 28.78; % NG
	11198	 64.39	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 28.78; % NG
	11201	 450.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 700.0	 200.0; % COW
	11203	 55.865	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 11.73; % NG
	11204	 450.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 700.0	 200.0; % NUC
	11211	 61.265	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.53; % NG
	11212	 61.195	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.39; % NG
	11214	 58.945	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 17.89; % COW
	11219	 126.195	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 52.39; % NG
	11220	 128.235	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 56.47; % NG
	11221	 62.265	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.53; % NG
	11225	 61.55	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.1; % NG
	11226	 133.235	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 66.47; % NG
	11227	 60.88	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.76; % NG
	11229	 61.6	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.2; % NG
	11230	 50.615	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 1.23; % NG
	11231	 60.88	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.76; % NG
	11233	 120.525	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 41.05; % NG
	11235	 119.245	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 38.49; % COW
	11236	 120.525	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 41.05; % NG
	11237	 59.24	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 18.48; % PEL
	11238	 119.245	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 38.49; % NG
	11239	 51.725	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 3.45; % NG
	11240	 127.835	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 55.67; % COW
	11241	 127.835	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 55.67; % NG
	11242	 127.835	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 55.67; % NG
	11244	 59.24	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 18.48; % NG
	11250	 60.525	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.05; % NG
	11251	 116.985	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 33.97; % NG
	11256	 450.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 700.0	 200.0; % COW
	11257	 65.315	 10.0	 20.0	 0.0	 1.0	 100.0	 1	 100.0	 30.63; % NG
	11259	 450.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 700.0	 200.0; % COW
	11264	 62.265	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.53; % NG
	11265	 59.065	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 18.13; % NG
	11273	 63.335	 0.0	 20.0	 -20.0	 1.0	 100.0	 1	 100.0	 26.67; % NG
	11281	 55.0	 5.0	 10.0	 0.0	 1.0	 100.0	 1	 100.0	 10.0; % NG
	11285	 129.615	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 59.23; % NG
	11289	 61.46	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.92; % NG
	11294	 1300.0	 200.0	 520.0	 -120.0	 1.0	 100.0	 1	 2000.0	 600.0; % NUC
	11299	 129.97	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 59.94; % NG
	11305	 122.755	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 45.51; % NG
	11307	 118.69	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 37.38; % NG
	11308	 129.535	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 59.07; % NG
	11309	 61.46	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.92; % NG
	11311	 51.215	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 2.43; % NG
	11312	 116.945	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 33.89; % NG
	11315	 62.035	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.07; % NG
	11325	 59.855	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 19.71; % COW
	11327	 63.295	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 26.59; % COW
	11328	 61.62	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.24; % NG
	11329	 52.8	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 5.6; % NG
	11330	 58.99	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 17.98; % NG
	11332	 250.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 400.0	 100.0; % NG
	11333	 250.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 400.0	 100.0; % NG
	11336	 60.005	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 20.01; % COW
	11344	 59.295	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 18.59; % NG
	11345	 130.105	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 60.21; % NG
	11347	 64.495	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 28.99; % NG
	11348	 63.215	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 26.43; % NG
	11351	 63.48	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 26.96; % NG
	11352	 63.48	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 26.96; % NG
	11353	 63.215	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 26.43; % NG
	11355	 61.305	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.61; % NG
	11360	 350.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	11361	 500.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 800.0	 200.0; % COW
	11362	 500.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 800.0	 200.0; % COW
	11363	 350.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	11364	 130.055	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 60.11; % NG
	11367	 130.055	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 60.11; % NG
	11368	 130.055	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 60.11; % NG
	11369	 130.055	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 60.11; % NG
	11370	 130.055	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 60.11; % NG
	11377	 350.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	11393	 50.025	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 0.05; % NG
	11401	 56.645	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 13.29; % COW
	11403	 350.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	11406	 500.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 800.0	 200.0; % COW
	11408	 250.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 400.0	 100.0; % NG
	11409	 250.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 400.0	 100.0; % NG
	11410	 128.235	 15.0	 50.0	 -20.0	 1.0	 100.0	 1	 200.0	 56.47; % COW
	11411	 122.965	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 45.93; % NG
	11412	 122.965	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 45.93; % COW
	11414	 122.965	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 45.93; % NG
	11416	 122.965	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 45.93; % COW
	11418	 850.0	 200.0	 520.0	 -120.0	 1.0	 100.0	 1	 1300.0	 400.0; % COW
	11419	 850.0	 200.0	 520.0	 -120.0	 1.0	 100.0	 1	 1300.0	 400.0; % COW
	11440	 50.835	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 1.67; % NG
	11454	 59.505	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 19.01; % COW
	11455	 59.505	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 19.01; % NG
	11456	 60.08	 5.0	 20.0	 -10.0	 1.0	 100.0	 1	 100.0	 20.16; % NG
	11467	 58.875	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 17.75; % NG
	11471	 56.615	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 13.23; % COW
	11472	 300.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 500.0	 100.0; % COW
	11473	 61.895	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.79; % COW
	11474	 58.28	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 16.56; % NG
	11475	 300.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 500.0	 100.0; % COW
	11477	 300.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 500.0	 100.0; % NG
	11478	 300.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 500.0	 100.0; % NG
	11479	 300.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 500.0	 100.0; % COW
	11480	 300.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 500.0	 100.0; % COW
	11481	 59.345	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 18.69; % NG
	11482	 59.945	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 19.89; % COW
	11483	 500.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 800.0	 200.0; % NUC
	11484	 56.81	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 13.62; % COW
	11487	 62.255	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.51; % NG
	11492	 300.0	 35.0	 100.0	 -30.0	 1.0	 100.0	 1	 500.0	 100.0; % COW
	11496	 117.995	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 35.99; % NG
	11497	 59.32	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 18.64; % NG
	11498	 59.32	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 18.64; % NG
	11499	 59.32	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 18.64; % COW
	11500	 59.32	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 18.64; % COW
	11502	 53.685	 5.0	 20.0	 -10.0	 1.0	 100.0	 1	 100.0	 7.37; % NG
	11504	 118.595	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 37.19; % NG
	11506	 117.995	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 35.99; % NG
	11507	 117.995	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 35.99; % NG
	11509	 123.335	 10.0	 60.0	 -40.0	 1.0	 100.0	 1	 200.0	 46.67; % NG
	11510	 350.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 600.0	 100.0; % NG
	11520	 350.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	11521	 900.0	 200.0	 520.0	 -120.0	 1.0	 100.0	 1	 1400.0	 400.0; % COW
	11523	 66.11	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 32.22; % NG
	11524	 66.11	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 32.22; % PEL
	11525	 66.11	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 32.22; % COW
	11526	 66.11	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 32.22; % NG
	11527	 118.565	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 37.13; % COW
	11528	 118.565	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 37.13; % COW
	11529	 61.215	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.43; % NG
	11530	 118.565	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 37.13; % COW
	11536	 350.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 600.0	 100.0; % PEL
	11539	 187.165	 15.0	 90.0	 -60.0	 1.0	 100.0	 1	 300.0	 74.33; % NG
	11549	 129.4	 0.0	 50.0	 -50.0	 1.0	 100.0	 1	 200.0	 58.8; % NG
	11551	 60.995	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.99; % NG
	11558	 124.155	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 48.31; % NG
	11564	 450.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 700.0	 200.0; % COW
	11568	 123.115	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 46.23; % NG
	11569	 123.115	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 46.23; % NG
	11570	 117.67	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 35.34; % NG
	11577	 56.775	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 13.55; % NG
	11578	 59.47	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 18.94; % NG
	11579	 57.23	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 14.46; % NG
	11580	 118.02	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 36.04; % NG
	11581	 58.48	 0.0	 20.0	 -20.0	 1.0	 100.0	 1	 100.0	 16.96; % NG
	11584	 53.035	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 6.07; % NG
	11586	 300.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 500.0	 100.0; % NG
	11588	 57.87	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 15.74; % NG
	11599	 60.53	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.06; % COW
	11600	 63.285	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 26.57; % NG
	11602	 60.53	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.06; % NG
	11603	 59.485	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 18.97; % COW
	11604	 59.485	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 18.97; % COW
	11605	 63.285	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 26.57; % NG
	11606	 63.285	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 26.57; % NG
	11611	 59.655	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 19.31; % NG
	11617	 61.02	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.04; % NG
	11619	 300.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 500.0	 100.0; % COW
	11623	 61.02	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.04; % NG
	11624	 61.02	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.04; % NG
	11625	 61.55	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.1; % COW
	11626	 61.55	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.1; % NG
	11630	 64.935	 10.0	 40.0	 -20.0	 1.0	 100.0	 1	 100.0	 29.87; % NG
	11631	 59.58	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 19.16; % NG
	11632	 59.495	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 18.99; % NG
	11633	 60.82	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.64; % COW
	11634	 59.58	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 19.16; % COW
	11635	 59.495	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 18.99; % NG
	11638	 56.795	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 13.59; % NG
	11641	 52.735	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 5.47; % NG
	11643	 64.43	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 100.0	 28.86; % NG
	11648	 62.14	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.28; % NG
	11649	 350.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	11652	 59.945	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 19.89; % NG
	11654	 60.64	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.28; % NG
	11665	 250.0	 10.0	 80.0	 -60.0	 1.0	 100.0	 1	 400.0	 100.0; % NG
	11666	 119.035	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 38.07; % NG
	11667	 119.035	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 38.07; % COW
	11668	 119.035	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 38.07; % NG
	11669	 119.035	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 38.07; % NG
	11670	 119.035	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 38.07; % NG
	11672	 50.005	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 0.01; % NG
	11677	 121.21	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 42.42; % NG
	11680	 450.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 700.0	 200.0; % COW
	11686	 56.225	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 12.45; % NG
	11687	 62.97	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 25.94; % NG
	11689	 58.01	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 16.02; % COW
	11690	 58.01	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 16.02; % NG
	11691	 58.01	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 16.02; % NG
	11692	 58.01	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 16.02; % NG
	11693	 58.01	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 16.02; % NG
	11694	 64.39	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 28.78; % NG
	11695	 64.39	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 28.78; % COW
	11699	 62.93	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 25.86; % NG
	11704	 350.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	11705	 54.42	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 8.84; % NG
	11713	 300.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 500.0	 100.0; % NG
	11714	 300.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 500.0	 100.0; % COW
	11716	 60.49	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 20.98; % NG
	11717	 300.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 500.0	 100.0; % COW
	11723	 58.515	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 17.03; % NG
	11729	 63.495	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 26.99; % COW
	11736	 133.255	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 66.51; % NG
	11745	 120.27	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 40.54; % NG
	11749	 118.405	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 36.81; % NG
	11752	 63.505	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 27.01; % NG
	11755	 63.655	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 27.31; % NG
	11756	 63.655	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 27.31; % NG
	11757	 63.655	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 27.31; % NG
	11758	 116.775	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 33.55; % COW
	11759	 116.775	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 33.55; % NG
	11760	 116.775	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 33.55; % NG
	11761	 58.45	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 16.9; % NG
	11762	 116.775	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 33.55; % NG
	11763	 116.775	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 33.55; % NG
	11768	 116.8	 0.0	 30.0	 -30.0	 1.0	 100.0	 1	 200.0	 33.6; % NG
	11773	 60.525	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.05; % COW
	11781	 50.32	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 0.64; % NG
	11786	 450.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 700.0	 200.0; % COW
	11789	 52.175	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 4.35; % NG
	11796	 65.42	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 30.84; % NG
	11797	 350.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	11803	 119.905	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 39.81; % NG
	11805	 64.115	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 28.23; % NG
	11806	 65.125	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 100.0	 30.25; % NG
	11810	 119.505	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 39.01; % COW
	11811	 119.005	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 38.01; % NG
	11813	 57.485	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 14.97; % NG
	11814	 57.485	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 14.97; % NG
	11815	 119.005	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 38.01; % NG
	11816	 119.005	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 38.01; % NG
	11817	 119.17	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 38.34; % NG
	11818	 119.17	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 38.34; % NG
	11819	 57.485	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 14.97; % NG
	11820	 57.485	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 14.97; % NG
	11822	 61.62	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.24; % NG
	11825	 -65.065	 0.0	 20.0	 -20.0	 1.0	 100.0	 1	 100.0	 -230.13; % NG
	11849	 132.375	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 64.75; % NG
	11850	 52.735	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 5.47; % PEL
	11851	 450.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 700.0	 200.0; % COW
	11853	 300.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 500.0	 100.0; % COW
	11854	 450.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 700.0	 200.0; % COW
	11856	 300.0	 40.0	 150.0	 -70.0	 1.0	 100.0	 1	 500.0	 100.0; % COW
	11859	 51.665	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 3.33; % COW
	11875	 60.905	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.81; % NG
	11880	 58.33	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 16.66; % NG
	11886	 59.465	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 18.93; % NG
	11889	 300.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 500.0	 100.0; % NG
	11891	 61.675	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.35; % NG
	11892	 63.505	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 27.01; % NG
	11894	 129.065	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 58.13; % NG
	11895	 116.975	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 33.95; % NG
	11897	 300.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 500.0	 100.0; % NG
	11898	 350.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	11900	 57.86	 0.0	 20.0	 -20.0	 1.0	 100.0	 1	 100.0	 15.72; % NG
	11903	 51.01	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 2.02; % COW
	11909	 1250.0	 200.0	 520.0	 -120.0	 1.0	 100.0	 1	 1900.0	 600.0; % COW
	11913	 63.01	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 26.02; % NG
	11914	 63.01	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 26.02; % COW
	11916	 61.865	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.73; % NG
	11919	 61.865	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.73; % PEL
	11920	 60.435	 0.0	 20.0	 -20.0	 1.0	 100.0	 1	 100.0	 20.87; % NG
	11922	 59.63	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 19.26; % NG
	11924	 131.835	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 63.67; % NG
	11927	 1300.0	 0.0	 100000.0	 -100000.0	 1.0	 100.0	 1	 2000.0	 600.0; % COW
	11935	 118.415	 0.0	 40.0	 -40.0	 1.0	 100.0	 1	 200.0	 36.83; % NG
	11945	 53.455	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 6.91; % NG
	11946	 126.235	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 52.47; % NG
	11950	 350.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 600.0	 100.0; % NG
	11953	 121.395	 0.0	 40.0	 -40.0	 1.0	 100.0	 1	 200.0	 42.79; % NG
	11959	 126.235	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 52.47; % NG
	11962	 126.235	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 52.47; % NG
	11967	 51.735	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 3.47; % NG
	11968	 131.675	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 63.35; % NG
	11970	 52.8	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 5.6; % NG
	11975	 122.765	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 45.53; % COW
	11976	 65.765	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 31.53; % COW
	11978	 131.255	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 62.51; % NG
	11979	 131.255	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 62.51; % COW
	11980	 131.255	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 62.51; % NG
	11982	 350.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	11986	 66.14	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 32.28; % COW
	11987	 350.0	 0.0	 100.0	 -100.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	11988	 62.305	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.61; % COW
	11990	 56.585	 0.0	 20.0	 -20.0	 1.0	 100.0	 1	 100.0	 13.17; % COW
	11996	 61.67	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.34; % NG
	12001	 250.0	 25.0	 130.0	 -80.0	 1.0	 100.0	 1	 400.0	 100.0; % COW
	12013	 250.0	 35.0	 90.0	 -20.0	 1.0	 100.0	 1	 400.0	 100.0; % COW
	12016	 300.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 500.0	 100.0; % COW
	12020	 58.74	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 17.48; % NG
	12021	 64.5	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 29.0; % COW
	12024	 125.75	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 51.5; % NG
	12025	 117.815	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 35.63; % NG
	12027	 56.8	 5.0	 20.0	 -10.0	 1.0	 100.0	 1	 100.0	 13.6; % NG
	12035	 62.93	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 25.86; % COW
	12042	 57.24	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 14.48; % COW
	12045	 63.385	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 26.77; % COW
	12049	 62.655	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 25.31; % NG
	12050	 195.0	 25.0	 70.0	 -20.0	 1.0	 100.0	 1	 300.0	 90.0; % NG
	12060	 51.6	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 3.2; % COW
	12065	 300.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 500.0	 100.0; % NG
	12069	 61.455	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.91; % COW
	12070	 61.455	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.91; % NG
	12071	 61.455	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.91; % COW
	12072	 132.19	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 64.38; % COW
	12073	 61.455	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.91; % NG
	12074	 61.455	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.91; % NG
	12075	 61.455	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.91; % NG
	12076	 61.455	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.91; % NG
	12084	 120.025	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 40.05; % COW
	12085	 120.025	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 40.05; % NG
	12088	 59.555	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 19.11; % NG
	12091	 60.595	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.19; % COW
	12093	 130.515	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 61.03; % NG
	12095	 131.67	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 63.34; % NG
	12097	 130.895	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 61.79; % NG
	12099	 55.57	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 11.14; % NG
	12102	 131.215	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 62.43; % NG
	12106	 63.295	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 26.59; % NG
	12116	 64.11	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 28.22; % NG
	12121	 56.42	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 12.84; % COW
	12123	 51.5	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 3.0; % NG
	12124	 56.245	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 12.49; % NG
	12126	 59.715	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 19.43; % NG
	12127	 59.715	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 19.43; % COW
	12131	 127.825	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 55.65; % COW
	12132	 127.825	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 55.65; % NG
	12133	 130.325	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 60.65; % NG
	12134	 130.325	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 60.65; % NG
	12135	 130.325	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 60.65; % NG
	12136	 130.325	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 60.65; % NG
	12137	 130.315	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 60.63; % NG
	12138	 130.315	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 60.63; % NG
	12139	 130.315	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 60.63; % NG
	12140	 130.315	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 60.63; % NG
	12152	 130.445	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 60.89; % NG
	12163	 55.865	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 11.73; % NG
	12164	 55.865	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 11.73; % NG
	12166	 60.215	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 20.43; % NG
	12167	 60.215	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 20.43; % COW
	12168	 60.215	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 20.43; % NG
	12169	 60.215	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 20.43; % NG
	12170	 55.865	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 11.73; % COW
	12171	 55.865	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 11.73; % NG
	12172	 60.215	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 20.43; % NG
	12173	 1100.0	 200.0	 520.0	 -120.0	 1.0	 100.0	 1	 1700.0	 500.0; % NUC
	12175	 60.31	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 20.62; % NG
	12178	 66.365	 5.0	 40.0	 -30.0	 1.0	 100.0	 1	 100.0	 32.73; % COW
	12189	 56.035	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 12.07; % NG
	12191	 57.9	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 15.8; % NG
	12192	 57.9	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 15.8; % NG
	12193	 56.305	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 12.61; % NG
	12194	 56.305	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 12.61; % COW
	12195	 57.055	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 14.11; % NG
	12199	 300.0	 60.0	 140.0	 -20.0	 1.0	 100.0	 1	 500.0	 100.0; % NG
	12200	 59.975	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 19.95; % COW
	12204	 350.0	 35.0	 190.0	 -120.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	12208	 500.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 800.0	 200.0; % COW
	12211	 450.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 700.0	 200.0; % COW
	12216	 62.36	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.72; % NG
	12217	 63.495	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 26.99; % NG
	12219	 57.485	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 14.97; % COW
	12221	 51.045	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 2.09; % COW
	12222	 61.955	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.91; % COW
	12227	 62.675	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 25.35; % COW
	12232	 129.975	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 59.95; % NG
	12240	 117.015	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 200.0	 34.03; % COW
	12245	 60.08	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 20.16; % NG
	12248	 350.0	 35.0	 100.0	 -30.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	12252	 300.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 500.0	 100.0; % COW
	12255	 450.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 700.0	 200.0; % COW
	12259	 300.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 500.0	 100.0; % COW
	12266	 250.0	 15.0	 100.0	 -70.0	 1.0	 100.0	 1	 400.0	 100.0; % COW
	12275	 127.765	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 55.53; % NG
	12276	 127.765	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 55.53; % NG
	12277	 52.035	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 4.07; % NG
	12278	 126.59	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 53.18; % NG
	12279	 126.59	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 53.18; % COW
	12280	 127.765	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 55.53; % COW
	12281	 126.59	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 53.18; % NG
	12282	 62.41	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.82; % COW
	12285	 51.065	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 2.13; % NG
	12286	 118.415	 0.0	 30.0	 -30.0	 1.0	 100.0	 1	 200.0	 36.83; % NG
	12287	 250.0	 25.0	 90.0	 -40.0	 1.0	 100.0	 1	 400.0	 100.0; % NG
	12291	 300.0	 35.0	 100.0	 -30.0	 1.0	 100.0	 1	 500.0	 100.0; % NG
	12302	 63.57	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 27.14; % NG
	12303	 63.57	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 27.14; % COW
	12304	 63.57	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 27.14; % COW
	12306	 62.45	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.9; % NG
	12307	 63.57	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 27.14; % COW
	12310	 61.655	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.31; % NG
	12319	 117.43	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 34.86; % COW
	12321	 61.62	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.24; % COW
	12325	 117.43	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 34.86; % COW
	12330	 121.24	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 42.48; % NG
	12332	 121.24	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 42.48; % NG
	12333	 121.24	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 42.48; % NG
	12334	 121.24	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 42.48; % NG
	12337	 63.295	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 26.59; % NG
	12338	 63.295	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 26.59; % NG
	12341	 125.75	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 51.5; % NG
	12346	 450.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 700.0	 200.0; % NUC
	12348	 350.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	12358	 53.335	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 6.67; % NG
	12359	 52.035	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 4.07; % COW
	12367	 300.0	 35.0	 130.0	 -60.0	 1.0	 100.0	 1	 500.0	 100.0; % COW
	12373	 450.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 700.0	 200.0; % COW
	12375	 192.0	 15.0	 90.0	 -60.0	 1.0	 100.0	 1	 300.0	 84.0; % NG
	12381	 56.425	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 12.85; % NG
	12383	 117.625	 5.0	 30.0	 -20.0	 1.0	 100.0	 1	 200.0	 35.25; % NG
	12387	 58.325	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 16.65; % COW
	12388	 119.04	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 38.08; % NG
	12390	 300.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 500.0	 100.0; % COW
	12393	 183.335	 20.0	 90.0	 -50.0	 1.0	 100.0	 1	 300.0	 66.67; % NG
	12398	 64.7	 15.0	 50.0	 -20.0	 1.0	 100.0	 1	 100.0	 29.4; % NG
	12400	 59.965	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 19.93; % NG
	12401	 133.0	 5.0	 50.0	 -40.0	 1.0	 100.0	 1	 200.0	 66.0; % COW
	12411	 133.225	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 66.45; % COW
	12415	 300.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 500.0	 100.0; % COW
	12419	 58.63	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 17.26; % NG
	12421	 51.665	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 3.33; % NG
	12428	 119.885	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 39.77; % COW
	12429	 119.885	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 39.77; % NG
	12430	 119.885	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 39.77; % COW
	12431	 119.885	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 39.77; % NG
	12433	 119.885	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 39.77; % COW
	12434	 66.625	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 33.25; % PEL
	12440	 65.095	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 30.19; % NG
	12441	 52.44	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 4.88; % NG
	12447	 122.965	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 45.93; % NG
	12448	 63.495	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 26.99; % NG
	12451	 61.05	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.1; % NG
	12452	 300.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 500.0	 100.0; % NG
	12453	 300.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 500.0	 100.0; % NG
	12454	 300.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 500.0	 100.0; % COW
	12455	 122.965	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 45.93; % NG
	12459	 65.765	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 31.53; % NG
	12461	 129.34	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 58.68; % NG
	12462	 129.34	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 58.68; % NG
	12464	 129.34	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 58.68; % NG
	12465	 129.13	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 58.26; % COW
	12466	 129.34	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 58.68; % COW
	12467	 129.34	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 58.68; % NG
	12469	 129.13	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 58.26; % NG
	12470	 129.13	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 58.26; % NG
	12477	 58.58	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 17.16; % COW
	12494	 122.215	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 44.43; % NG
	12499	 54.05	 5.0	 10.0	 0.0	 1.0	 100.0	 1	 100.0	 8.1; % NG
	12500	 60.4	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 20.8; % NG
	12505	 125.935	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 51.87; % NG
	12506	 125.935	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 51.87; % NG
	12507	 50.275	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 0.55; % NG
	12509	 350.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	12517	 118.015	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 36.03; % NG
	12518	 350.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	12519	 132.25	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 64.5; % NG
	12521	 61.07	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.14; % COW
	12522	 61.07	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.14; % NG
	12523	 61.07	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.14; % NG
	12525	 300.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 500.0	 100.0; % NG
	12526	 300.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 500.0	 100.0; % COW
	12528	 58.875	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 17.75; % NG
	12529	 129.355	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 58.71; % NG
	12537	 850.0	 200.0	 520.0	 -120.0	 1.0	 100.0	 1	 1300.0	 400.0; % COW
	12541	 50.255	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 0.51; % NG
	12542	 59.81	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 19.62; % NG
	12551	 55.935	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 11.87; % COW
	12555	 52.975	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 5.95; % COW
	12556	 250.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 400.0	 100.0; % NG
	12558	 52.01	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 4.02; % COW
	12563	 500.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 800.0	 200.0; % NUC
	12570	 56.875	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 13.75; % NG
	12572	 187.335	 10.0	 80.0	 -60.0	 1.0	 100.0	 1	 300.0	 74.67; % NG
	12579	 850.0	 65.0	 320.0	 -190.0	 1.0	 100.0	 1	 1300.0	 400.0; % PEL
	12582	 62.855	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 25.71; % NG
	12583	 62.855	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 25.71; % NG
	12586	 64.135	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 100.0	 28.27; % COW
	12587	 -156.91	 0.0	 100000.0	 -100000.0	 1.0	 100.0	 1	 100.0	 -413.82; % NG
	12589	 64.135	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 100.0	 28.27; % NG
	12590	 64.135	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 100.0	 28.27; % NG
	12591	 64.135	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 100.0	 28.27; % NG
	12592	 64.135	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 100.0	 28.27; % COW
	12599	 117.485	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 34.97; % NG
	12600	 117.485	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 34.97; % NG
	12601	 117.485	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 34.97; % NG
	12603	 250.0	 10.0	 80.0	 -60.0	 1.0	 100.0	 1	 400.0	 100.0; % COW
	12606	 300.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 500.0	 100.0; % NG
	12607	 120.63	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 41.26; % NG
	12610	 120.63	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 41.26; % NG
	12612	 55.57	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 11.14; % NG
	12616	 52.175	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 4.35; % NG
	12625	 250.0	 10.0	 90.0	 -70.0	 1.0	 100.0	 1	 400.0	 100.0; % NG
	12636	 57.97	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 15.94; % PEL
	12641	 250.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 400.0	 100.0; % COW
	12646	 57.98	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 15.96; % COW
	12647	 128.495	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 56.99; % NG
	12648	 128.495	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 56.99; % NG
	12650	 128.495	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 56.99; % COW
	12651	 128.495	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 56.99; % NG
	12652	 128.495	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 56.99; % NG
	12653	 128.495	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 56.99; % NG
	12654	 128.495	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 56.99; % NG
	12656	 62.84	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 25.68; % NG
	12657	 51.665	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 3.33; % COW
	12658	 63.335	 0.0	 20.0	 -20.0	 1.0	 100.0	 1	 100.0	 26.67; % NG
	12659	 118.105	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 36.21; % NG
	12664	 56.81	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 13.62; % NG
	12665	 550.0	 100.0	 260.0	 -60.0	 1.0	 100.0	 1	 900.0	 200.0; % COW
	12673	 118.105	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 36.21; % NG
	12678	 183.335	 20.0	 90.0	 -50.0	 1.0	 100.0	 1	 300.0	 66.67; % COW
	12681	 57.625	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 15.25; % NG
	12687	 60.15	 5.0	 40.0	 -30.0	 1.0	 100.0	 1	 100.0	 20.3; % COW
	12688	 450.0	 0.0	 100.0	 -100.0	 1.0	 100.0	 1	 700.0	 200.0; % COW
	12690	 118.105	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 36.21; % NG
	12692	 56.3	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 12.6; % NG
	12697	 59.225	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 18.45; % COW
	12699	 59.225	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 18.45; % NG
	12701	 61.36	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.72; % NG
	12702	 59.225	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 18.45; % NG
	12704	 61.36	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.72; % NG
	12705	 61.425	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.85; % NG
	12706	 61.425	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.85; % NG
	12708	 55.285	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 10.57; % NG
	12709	 60.015	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 20.03; % COW
	12711	 60.585	 5.0	 20.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.17; % NG
	12713	 60.725	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.45; % NG
	12714	 55.285	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 10.57; % COW
	12717	 62.675	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 25.35; % NG
	12723	 59.24	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 18.48; % NG
	12726	 350.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	12727	 128.425	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 56.85; % NG
	12728	 62.265	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.53; % COW
	12730	 123.335	 5.0	 40.0	 -30.0	 1.0	 100.0	 1	 200.0	 46.67; % NG
	12736	 63.335	 0.0	 20.0	 -20.0	 1.0	 100.0	 1	 100.0	 26.67; % NG
	12738	 60.99	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.98; % COW
	12742	 61.245	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.49; % NG
	12747	 61.245	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.49; % NG
	12748	 50.835	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 1.67; % NG
	12758	 131.835	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 63.67; % COW
	12760	 119.395	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 38.79; % NG
	12761	 119.395	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 38.79; % COW
	12763	 119.395	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 38.79; % NG
	12764	 123.305	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 46.61; % COW
	12765	 123.305	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 46.61; % NG
	12772	 500.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 800.0	 200.0; % COW
	12775	 250.0	 35.0	 100.0	 -30.0	 1.0	 100.0	 1	 400.0	 100.0; % NG
	12777	 58.545	 5.0	 20.0	 -10.0	 1.0	 100.0	 1	 100.0	 17.09; % NG
	12782	 57.115	 5.0	 20.0	 -10.0	 1.0	 100.0	 1	 100.0	 14.23; % NG
	12786	 118.75	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 37.5; % NG
	12788	 124.89	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 49.78; % NG
	12789	 124.89	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 49.78; % NG
	12790	 124.89	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 49.78; % NG
	12791	 124.89	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 49.78; % NG
	12794	 450.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 700.0	 200.0; % COW
	12799	 116.985	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 33.97; % NG
	12802	 125.745	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 51.49; % NG
	12803	 126.205	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 52.41; % NG
	12806	 132.565	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 65.13; % NG
	12807	 132.565	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 65.13; % NG
	12808	 132.565	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 65.13; % NG
	12814	 132.19	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 64.38; % COW
	12815	 60.335	 5.0	 10.0	 0.0	 1.0	 100.0	 1	 100.0	 20.67; % NG
	12816	 56.135	 0.0	 20.0	 -20.0	 1.0	 100.0	 1	 100.0	 12.27; % NG
	12817	 900.0	 200.0	 520.0	 -120.0	 1.0	 100.0	 1	 1400.0	 400.0; % COW
	12818	 900.0	 200.0	 520.0	 -120.0	 1.0	 100.0	 1	 1400.0	 400.0; % COW
	12819	 61.325	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.65; % NG
	12822	 62.01	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.02; % NG
	12825	 63.18	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 26.36; % COW
	12829	 61.655	 0.0	 30.0	 -30.0	 1.0	 100.0	 1	 100.0	 23.31; % COW
	12833	 300.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 500.0	 100.0; % COW
	12840	 60.005	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 20.01; % NG
	12843	 60.005	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 20.01; % NG
	12847	 53.63	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 7.26; % NG
	12855	 850.0	 200.0	 520.0	 -120.0	 1.0	 100.0	 1	 1300.0	 400.0; % NUC
	12856	 60.005	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 20.01; % NG
	12859	 300.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 500.0	 100.0; % COW
	12863	 51.755	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 3.51; % NG
	12864	 56.2	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 12.4; % NG
	12865	 250.0	 25.0	 130.0	 -80.0	 1.0	 100.0	 1	 400.0	 100.0; % NG
	12869	 130.075	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 60.15; % NG
	12873	 54.2	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 8.4; % COW
	12874	 300.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 500.0	 100.0; % COW
	12878	 350.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	12880	 350.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	12882	 350.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	12883	 350.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	12884	 350.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	12887	 51.755	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 3.51; % NG
	12896	 56.105	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 12.21; % COW
	12900	 66.61	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 100.0	 33.22; % NG
	12902	 59.845	 5.0	 20.0	 -10.0	 1.0	 100.0	 1	 100.0	 19.69; % COW
	12904	 58.33	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 16.66; % COW
	12906	 55.735	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 11.47; % NG
	12907	 55.735	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 11.47; % NG
	12908	 55.735	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 11.47; % NG
	12910	 55.735	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 11.47; % NG
	12911	 62.01	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.02; % NG
	12912	 55.735	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 11.47; % NG
	12914	 56.425	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 12.85; % NG
	12915	 132.3	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 64.6; % NG
	12916	 55.735	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 11.47; % PEL
	12917	 55.735	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 11.47; % NG
	12920	 850.0	 200.0	 520.0	 -120.0	 1.0	 100.0	 1	 1300.0	 400.0; % COW
	12921	 850.0	 200.0	 520.0	 -120.0	 1.0	 100.0	 1	 1300.0	 400.0; % NUC
	12925	 850.0	 200.0	 520.0	 -120.0	 1.0	 100.0	 1	 1300.0	 400.0; % COW
	12929	 62.295	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.59; % COW
	12930	 60.98	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.96; % NG
	12934	 133.225	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 66.45; % NG
	12937	 850.0	 200.0	 520.0	 -120.0	 1.0	 100.0	 1	 1300.0	 400.0; % PEL
	12946	 60.435	 0.0	 20.0	 -20.0	 1.0	 100.0	 1	 100.0	 20.87; % NG
	12949	 60.905	 5.0	 30.0	 -20.0	 1.0	 100.0	 1	 100.0	 21.81; % NG
	12962	 500.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 800.0	 200.0; % NUC
	12965	 300.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 500.0	 100.0; % COW
	12966	 55.865	 0.0	 20.0	 -20.0	 1.0	 100.0	 1	 100.0	 11.73; % COW
	12968	 850.0	 200.0	 520.0	 -120.0	 1.0	 100.0	 1	 1300.0	 400.0; % NG
	12969	 300.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 500.0	 100.0; % NG
	12970	 300.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 500.0	 100.0; % NG
	12973	 58.36	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 16.72; % NG
	12983	 200.0	 25.0	 120.0	 -70.0	 1.0	 100.0	 1	 300.0	 100.0; % NG
	12984	 59.925	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 19.85; % NG
	12986	 59.925	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 19.85; % COW
	12989	 61.115	 5.0	 10.0	 0.0	 1.0	 100.0	 1	 100.0	 22.23; % NG
	12993	 56.655	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 13.31; % NG
	12994	 56.655	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 13.31; % COW
	13002	 250.0	 25.0	 130.0	 -80.0	 1.0	 100.0	 1	 400.0	 100.0; % NG
	13007	 60.995	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.99; % COW
	13008	 60.995	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.99; % NG
	13009	 60.995	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.99; % NG
	13010	 183.335	 20.0	 90.0	 -50.0	 1.0	 100.0	 1	 300.0	 66.67; % NG
	13012	 300.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 500.0	 100.0; % COW
	13027	 56.435	 5.0	 20.0	 -10.0	 1.0	 100.0	 1	 100.0	 12.87; % NG
	13029	 53.62	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 7.24; % NG
	13032	 55.48	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 10.96; % NG
	13037	 54.315	 5.0	 20.0	 -10.0	 1.0	 100.0	 1	 100.0	 8.63; % NG
	13041	 58.875	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 17.75; % NG
	13043	 58.1	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 16.2; % NG
	13046	 58.1	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 16.2; % NG
	13047	 57.205	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 14.41; % COW
	13048	 57.205	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 14.41; % COW
	13049	 57.205	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 14.41; % NG
	13052	 57.205	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 14.41; % COW
	13053	 57.205	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 14.41; % COW
	13054	 57.205	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 14.41; % COW
	13055	 58.1	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 16.2; % NG
	13057	 60.105	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 20.21; % COW
	13058	 60.105	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 20.21; % COW
	13059	 58.1	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 16.2; % NG
	13060	 58.1	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 16.2; % NG
	13062	 128.065	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 56.13; % COW
	13064	 58.1	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 16.2; % NG
	13066	 128.065	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 56.13; % NG
	13069	 131.215	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 62.43; % NG
	13075	 50.685	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 1.37; % PEL
	13079	 300.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 500.0	 100.0; % NG
	13080	 66.445	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 32.89; % COW
	13081	 61.85	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.7; % NG
	13082	 52.185	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 4.37; % NG
	13086	 61.065	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.13; % NG
	13087	 55.245	 -5.0	 10.0	 -20.0	 1.0	 100.0	 1	 100.0	 10.49; % COW
	13090	 300.0	 35.0	 100.0	 -30.0	 1.0	 100.0	 1	 500.0	 100.0; % NG
	13091	 183.665	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 300.0	 67.33; % NG
	13093	 65.98	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 31.96; % NG
	13095	 119.525	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 39.05; % NG
	13096	 64.535	 0.0	 30.0	 -30.0	 1.0	 100.0	 1	 100.0	 29.07; % COW
	13101	 66.445	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 32.89; % NG
	13108	 116.78	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 33.56; % NG
	13112	 54.665	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 9.33; % NG
	13122	 62.93	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 25.86; % NG
	13123	 350.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	13131	 57.835	 5.0	 20.0	 -10.0	 1.0	 100.0	 1	 100.0	 15.67; % NG
	13133	 61.435	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.87; % COW
	13137	 450.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 700.0	 200.0; % COW
	13143	 250.0	 25.0	 130.0	 -80.0	 1.0	 100.0	 1	 400.0	 100.0; % NG
	13145	 350.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	13147	 60.735	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.47; % NG
	13158	 550.0	 100.0	 260.0	 -60.0	 1.0	 100.0	 1	 900.0	 200.0; % COW
	13159	 51.4	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 2.8; % NG
	13160	 64.39	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 28.78; % NG
	13163	 61.865	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.73; % NG
	13165	 51.735	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 3.47; % NG
	13174	 62.675	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 25.35; % NG
	13182	 41.66	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 -16.68; % NG
	13188	 350.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	13189	 350.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	13190	 350.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	13191	 250.0	 35.0	 100.0	 -30.0	 1.0	 100.0	 1	 400.0	 100.0; % NG
	13192	 1300.0	 200.0	 520.0	 -120.0	 1.0	 100.0	 1	 2000.0	 600.0; % NG
	13193	 50.4	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 0.8; % COW
	13195	 62.265	 0.0	 30.0	 -30.0	 1.0	 100.0	 1	 100.0	 24.53; % COW
	13200	 119.165	 0.0	 30.0	 -30.0	 1.0	 100.0	 1	 200.0	 38.33; % NG
	13209	 250.0	 60.0	 160.0	 -40.0	 1.0	 100.0	 1	 400.0	 100.0; % NG
	13212	 52.035	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 4.07; % COW
	13218	 195.0	 25.0	 70.0	 -20.0	 1.0	 100.0	 1	 300.0	 90.0; % NG
	13222	 63.035	 0.0	 20.0	 -20.0	 1.0	 100.0	 1	 100.0	 26.07; % NG
	13223	 62.36	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.72; % NG
	13226	 52.735	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 5.47; % NG
	13232	 116.975	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 33.95; % NG
	13235	 450.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 700.0	 200.0; % COW
	13238	 119.6	 0.0	 30.0	 -30.0	 1.0	 100.0	 1	 200.0	 39.2; % NG
	13265	 53.42	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 6.84; % NG
	13268	 55.535	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 11.07; % NG
	13270	 51.665	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 3.33; % NG
	13285	 117.25	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 34.5; % NG
	13292	 62.255	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.51; % NG
	13298	 58.47	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 16.94; % NG
	13303	 62.01	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 24.02; % NG
	13310	 61.13	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.26; % NG
	13311	 61.15	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.3; % NG
	13312	 51.165	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 2.33; % NG
	13313	 118.02	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 36.04; % NG
	13316	 116.78	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 33.56; % NG
	13322	 450.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 700.0	 200.0; % COW
	13327	 500.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 800.0	 200.0; % COW
	13330	 60.835	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.67; % NG
	13333	 300.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 500.0	 100.0; % COW
	13338	 120.835	 10.0	 20.0	 0.0	 1.0	 100.0	 1	 200.0	 41.67; % NG
	13345	 63.48	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 26.96; % NG
	13363	 58.67	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 17.34; % NG
	13370	 60.43	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 20.86; % NG
	13371	 56.8	 5.0	 20.0	 -10.0	 1.0	 100.0	 1	 100.0	 13.6; % NG
	13379	 550.0	 85.0	 230.0	 -60.0	 1.0	 100.0	 1	 900.0	 200.0; % COW
	13383	 127.835	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 55.67; % NG
	13385	 120.79	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 41.58; % NG
	13386	 120.79	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 41.58; % NG
	13387	 120.79	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 41.58; % NG
	13388	 127.63	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 55.26; % COW
	13389	 127.63	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 55.26; % NG
	13390	 59.895	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 19.79; % COW
	13391	 59.895	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 19.79; % NG
	13392	 61.28	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.56; % NG
	13393	 59.895	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 19.79; % NG
	13394	 59.895	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 19.79; % NG
	13395	 59.895	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 19.79; % COW
	13397	 127.63	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 55.26; % NG
	13398	 127.63	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 55.26; % NG
	13399	 127.63	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 55.26; % COW
	13407	 58.4	 0.0	 20.0	 -20.0	 1.0	 100.0	 1	 100.0	 16.8; % PEL
	13409	 60.3	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 20.6; % NG
	13411	 127.105	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 54.21; % COW
	13412	 60.64	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.28; % NG
	13419	 57.485	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 14.97; % COW
	13421	 61.955	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.91; % COW
	13423	 61.955	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.91; % NG
	13424	 61.955	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 23.91; % NG
	13425	 59.145	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 18.29; % NG
	13426	 121.14	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 42.28; % COW
	13433	 117.43	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 34.86; % NG
	13437	 117.43	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 34.86; % NG
	13439	 117.43	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 34.86; % COW
	13440	 61.32	 5.0	 20.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.64; % COW
	13447	 54.1	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 8.2; % COW
	13456	 59.495	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 18.99; % NG
	13466	 117.995	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 35.99; % NG
	13467	 54.975	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 9.95; % NG
	13468	 118.785	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 37.57; % NG
	13482	 117.995	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 35.99; % COW
	13486	 117.995	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 35.99; % NG
	13487	 116.78	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 33.56; % COW
	13489	 126.915	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 53.83; % NG
	13491	 56.855	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 13.71; % NG
	13493	 450.0	 20.0	 180.0	 -140.0	 1.0	 100.0	 1	 700.0	 200.0; % PEL
	13496	 60.88	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.76; % COW
	13497	 60.88	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.76; % COW
	13500	 60.88	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.76; % COW
	13502	 60.88	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.76; % NG
	13505	 60.88	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.76; % NG
	13506	 60.88	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.76; % PEL
	13507	 60.88	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 21.76; % NG
	13510	 50.07	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 0.14; % NG
	13512	 59.245	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 18.49; % COW
	13514	 60.335	 0.0	 20.0	 -20.0	 1.0	 100.0	 1	 100.0	 20.67; % NG
	13520	 126.915	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 53.83; % NG
	13525	 117.69	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 35.38; % NG
	13526	 300.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 500.0	 100.0; % NG
	13530	 300.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 500.0	 100.0; % COW
	13549	 57.68	 0.0	 20.0	 -20.0	 1.0	 100.0	 1	 100.0	 15.36; % NG
	13550	 60.5	 5.0	 30.0	 -20.0	 1.0	 100.0	 1	 100.0	 21.0; % NG
	13551	 50.835	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 1.67; % NG
	13556	 52.175	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 4.35; % COW
	13560	 300.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 500.0	 100.0; % COW
	13569	 132.01	 20.0	 60.0	 -20.0	 1.0	 100.0	 1	 200.0	 64.02; % NG
	13577	 66.445	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 100.0	 32.89; % NG
	13580	 61.28	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.56; % COW
	13582	 61.28	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 22.56; % NG
	13584	 56.375	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 12.75; % NG
	13585	 57.425	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 14.85; % COW
	13589	 57.425	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 14.85; % NG
	13590	 128.75	 -10.0	 60.0	 -80.0	 1.0	 100.0	 1	 200.0	 57.5; % NG
	13592	 450.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 700.0	 200.0; % COW
	13594	 56.79	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 13.58; % COW
	13597	 56.79	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 13.58; % NG
	13601	 57.245	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 14.49; % NG
	13604	 57.425	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 14.85; % NG
	13607	 62.68	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 25.36; % COW
	13609	 57.335	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 14.67; % NG
	13617	 50.755	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 1.51; % NG
	13620	 350.0	 80.0	 210.0	 -50.0	 1.0	 100.0	 1	 600.0	 100.0; % COW
	13633	 116.78	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 33.56; % COW
	13639	 59.975	 5.0	 20.0	 -10.0	 1.0	 100.0	 1	 100.0	 19.95; % COW
	13643	 56.105	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 100.0	 12.21; % NG
	13648	 116.78	 15.0	 40.0	 -10.0	 1.0	 100.0	 1	 200.0	 33.56; % NG
	13651	 55.595	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 11.19; % COW
	13654	 50.0	 185.0	 560.0	 -190.0	 1.0	 100.0	 1	 100.0	 -0.0; % SYNC
	13655	 56.82	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 13.64; % NG
	13658	 58.805	 10.0	 30.0	 -10.0	 1.0	 100.0	 1	 100.0	 17.61; % COW
];

%% generator cost data
%	2	startup	shutdown	n	c(n-1)	...	c0
mpc.gencost = [
	2	 0.0	 0.0	 3	   0.000000	  27.954228	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.143713	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.023300	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  51.463262	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.508304	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.808540	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.015714	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  40.567642	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.120316	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.661962	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  10.481931	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  19.669638	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.400897	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.031117	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.242378	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  50.339155	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  52.825019	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.377178	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.832187	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.128379	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.316094	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.162551	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.080374	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.336521	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  50.130798	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.676174	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.196636	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.860664	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.210300	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.695448	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  35.014750	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.955337	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.737375	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.886235	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.057666	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.641399	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.069068	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.720301	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.940127	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.200856	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.879743	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.567664	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  50.488486	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.505449	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   6.756078	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  39.927862	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.641926	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  13.552185	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  37.917450	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.221093	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.129152	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.349309	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.946972	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  41.060699	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.294041	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.316737	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.022137	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  40.725019	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.652507	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.102393	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  17.361215	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  21.185940	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  56.255608	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.118419	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.942449	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  54.916011	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.841073	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.268096	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.360233	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.482304	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.612526	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.673979	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  44.346833	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   9.850911	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  17.961633	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  47.879405	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.682295	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.955846	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.815055	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.395029	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.648114	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.687958	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.088330	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.520964	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.244256	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  55.006030	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  56.557792	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.802205	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.115886	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  13.523820	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   9.541324	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  42.895105	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.531307	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  21.243375	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.132596	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.469462	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.188084	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.797374	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   2.807034	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  38.330795	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  15.797323	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.691261	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  37.092772	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.022659	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.206209	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.679004	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.085532	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.229155	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.233444	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.780348	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.266202	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.698023	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.002466	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.961595	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.257100	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.566299	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.960736	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.781055	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.191530	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.822356	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.962398	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.802543	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  17.037271	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  10.803317	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.884582	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.591668	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.389730	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.024243	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.776801	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.706552	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.255239	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.330803	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  42.334739	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.165927	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.607600	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  52.280667	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.346690	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.509925	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  38.709892	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.001340	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   7.817212	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  28.307705	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   7.727480	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  31.844451	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  37.050856	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.201224	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.167792	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  55.853240	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.074043	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.702483	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.829440	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.232632	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.893354	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.159760	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  52.733756	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  12.561403	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.657106	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.494973	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   5.844693	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.208792	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  13.388423	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  50.799253	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  61.398490	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.218817	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.364734	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.791247	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  37.236281	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.262407	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.093584	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.026018	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  17.210590	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  17.497695	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.809831	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.131772	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   8.724450	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.033813	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.904989	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.783500	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   7.212610	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  24.133309	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.831396	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.026804	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.298717	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.611810	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  14.350541	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  37.706440	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.677674	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  38.305847	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.627595	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  40.028120	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  42.239015	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  51.867892	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  14.573395	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.444624	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.224722	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.487608	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.282317	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.198563	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.156531	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.043926	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.015648	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  14.372772	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.047633	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  51.920078	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   6.103463	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  57.543224	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.473367	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  14.761557	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  35.175819	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.009603	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.791906	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.068129	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  14.929146	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  46.249004	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.450751	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.884487	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.548541	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.090355	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.407180	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  52.061496	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.189833	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.778452	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.786651	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.875173	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.936952	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   6.432538	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  19.264526	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  38.083473	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.870670	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  56.702788	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.154464	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.130760	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.663769	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.634182	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.417682	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.742634	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.265854	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.019294	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.576387	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  42.776503	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.346986	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.311118	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  45.168969	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.641691	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.240162	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  35.042468	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  35.284687	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  13.838482	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.509595	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.592518	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.736733	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.401701	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.012889	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.787371	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.052197	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.877911	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.755559	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.429555	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.138437	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.619981	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.497065	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  41.594487	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.656458	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.049105	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  45.962622	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.347612	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  57.272901	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.161473	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  42.765384	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.781502	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.258006	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.578132	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.955493	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  13.291487	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.692644	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  14.153577	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.685326	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.925091	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.595292	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  38.299698	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.304823	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.155531	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.100222	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  57.135306	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.431375	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.894420	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.162690	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.940171	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.290319	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.818124	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   9.360355	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.654652	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.713538	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.699446	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.056504	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  21.248346	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  63.266048	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  12.351011	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  14.768507	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.808561	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.763435	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.304960	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.293273	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  19.066652	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.984890	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.663387	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  45.206884	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.345857	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.431802	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  13.887828	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  41.302672	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.287609	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.894374	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.656480	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  48.858118	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.366358	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.722001	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.098849	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.513447	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  17.667394	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.093751	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.342384	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.127115	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.512461	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  42.131979	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  13.577178	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.775363	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.109801	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.669703	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.675143	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.191951	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  13.648760	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.773613	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   9.478100	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.690928	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.974969	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.005213	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  62.173517	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.762591	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  59.606230	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.129390	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.478362	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.443469	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.122872	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.278872	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  13.278661	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.182736	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.833364	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  44.579236	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.969605	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.713033	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   4.156797	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.724355	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.239567	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.716446	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.918262	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.644317	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.703923	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.599871	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  51.996275	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  13.008532	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  39.002651	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  12.437454	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 110.853208	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  39.413334	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.753167	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.867625	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.034606	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.327599	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.881475	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.796943	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.152348	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  53.414383	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.228482	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.267633	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.913209	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.295990	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.773715	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  12.398101	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.221526	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  14.128223	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.138964	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.069291	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  55.874011	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  10.809757	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  49.637071	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.444591	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.986228	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.422436	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.918054	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.142124	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.122423	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  44.727774	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.055259	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.331966	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.203853	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.924416	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.522004	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.087358	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.769190	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.254902	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.263040	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.458771	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.553735	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.447915	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.097177	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.582932	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.121989	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.110009	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.926503	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.769341	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  17.428360	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  16.553332	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  44.947711	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.598383	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.840244	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.114930	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.020320	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.061730	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.206920	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.614182	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.244001	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.024508	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.053953	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  51.874294	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.219486	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.566753	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.761193	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  39.761775	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  12.992569	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.917473	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.598833	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.733448	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  14.560040	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.524740	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  39.276810	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.960207	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  53.987608	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.223595	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.171708	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.487887	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  17.472143	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.441420	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.800005	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.163695	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.764413	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.191385	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  16.957400	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  50.329225	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.208953	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.293710	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.458203	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.580800	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  11.281860	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.543395	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.075935	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  68.466193	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.526900	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.340161	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  54.155567	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.171010	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.195158	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.621338	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.482936	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.913875	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  57.976661	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.500298	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.626824	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.221115	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.506974	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.866452	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.191963	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.361907	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.107403	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   8.069051	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  33.502667	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.621741	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.047902	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.686046	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.564693	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  40.041237	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.525293	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.109580	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.593607	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.861109	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  11.330907	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.801899	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.693730	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.483348	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.515818	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  12.065032	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.706419	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  50.824225	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.462597	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.665876	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.775546	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   7.709152	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  35.370033	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.978671	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  19.588138	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.103434	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.427471	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.778364	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 119.109749	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  51.268191	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.200604	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  50.510686	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.017024	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   6.671666	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.847251	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.895737	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.431492	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.106750	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.397224	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  37.628031	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.993720	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.813918	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.785059	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.441447	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.669942	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.967662	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.007033	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  50.305782	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.014855	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  16.227964	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.499756	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.960220	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.396352	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.708776	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  46.647077	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  16.470796	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  19.732638	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.735314	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  17.675845	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  52.480965	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.318273	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.855563	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.649426	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   6.315765	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  48.016734	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.215049	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.687335	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.728149	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.758144	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  18.949512	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.183616	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.539990	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  47.762304	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.550224	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  52.113365	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.515193	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   7.103293	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  23.257181	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.396874	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  16.253478	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.996485	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  57.708031	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.982498	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.711854	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  16.515157	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.636930	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  38.722753	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.782684	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  14.687077	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.919114	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.611068	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.542710	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.864977	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.545725	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.375121	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  19.979043	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.782950	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.671505	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.158221	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  35.699636	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.986153	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  46.652363	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.335319	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.289435	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 108.599819	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  32.134538	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.773575	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.193183	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  40.242271	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.631695	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.268404	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.223343	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.653791	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.556252	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  13.425903	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.993923	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.146360	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.569307	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.485211	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.173176	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  49.871440	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.510327	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.733338	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.967095	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  50.922043	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  50.687387	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.343743	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.272373	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  41.686647	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.277798	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  21.082257	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  42.100033	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.616565	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.975278	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   7.361294	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  36.087072	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.660819	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.235827	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  10.864692	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  35.342754	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.637625	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.042474	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.195162	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.547368	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  57.365557	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.060734	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.830539	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.769206	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.297907	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  61.474850	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.611318	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.088774	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  35.282545	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.118720	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.491373	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.543447	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.777056	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.350766	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  52.130754	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.236316	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.447921	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  13.614413	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.036383	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.813709	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.787810	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  16.759238	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.117904	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  13.111421	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.056258	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.840645	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.801580	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.010167	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  19.160879	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  40.941855	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.085333	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.028574	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.011512	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.035432	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.849865	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.010847	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.485071	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.557805	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.736408	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.591799	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  42.590342	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.459707	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.198638	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.451368	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.112759	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.194366	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.339091	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.083055	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.728153	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.627623	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  50.434785	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  51.431062	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.249342	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.443399	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.789564	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.094399	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.181396	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.240033	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   0.971474	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  38.227653	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.346947	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   5.931597	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  36.450422	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.134446	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.072686	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.867789	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.419031	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.610393	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  59.217170	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.482733	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.571284	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.247714	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.015426	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.861960	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.040127	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  66.792524	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.271825	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.425556	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  11.767991	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.161860	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.757484	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.913130	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.373449	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  53.740669	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.599561	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  14.511496	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.637374	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.004677	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.366393	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.004497	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.878305	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.780701	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.518917	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.642181	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.140173	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.918622	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.896619	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  49.083694	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.675259	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.698576	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.809595	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.111865	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.725769	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  51.067509	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.528244	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.781509	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.002652	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.074248	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.415067	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.800335	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  39.334226	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.337404	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.982403	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.497253	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.563223	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.518740	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  10.119016	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.225371	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.798208	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.945096	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  18.099097	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   6.653006	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  32.645107	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.172776	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.505398	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.270059	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.849770	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.944602	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  14.652810	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.466524	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.105229	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  19.010522	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.221671	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.282128	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.718105	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  14.143686	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.049370	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.773172	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.040249	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.422762	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.952353	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  55.920901	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.064140	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.103067	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  58.275849	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  99.699596	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  37.730674	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.739718	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.313896	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.375249	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  58.484246	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.552068	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.279958	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.131875	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 109.263141	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  17.535290	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  46.946185	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  18.529065	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  14.031910	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  42.866837	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.734955	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.831656	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.780440	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   2.547774	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  45.841016	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.644873	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.571992	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  15.524775	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.629502	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.247471	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   8.254146	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.137236	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   7.189258	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  35.608229	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  14.365611	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.783297	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.088057	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.639520	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  19.479811	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.503922	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.415233	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.666860	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.305501	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.528912	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.848095	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.550345	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.870215	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.483632	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.121114	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.481862	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 116.393961	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  33.929438	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.751088	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.456134	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.805633	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  45.523744	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   6.382767	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  25.366212	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.230690	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.957016	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.939111	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  42.939313	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  35.263732	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.755180	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  35.274923	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  14.141261	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.223993	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.285543	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.264256	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.745397	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  45.243925	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.036405	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.921120	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.142725	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.296503	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.804733	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.801401	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.229146	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.127248	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.641300	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.882151	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.466026	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.042057	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  51.363616	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.644582	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.562840	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.284190	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.204035	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  50.302972	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  51.396577	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.852265	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.790651	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.843848	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  54.865461	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.435832	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  35.096991	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.991845	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.628371	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  37.747903	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.149850	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.791353	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.451673	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.303581	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.325860	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.855140	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.753349	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.176585	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.107036	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.758111	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.698999	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.760115	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  50.900297	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.722254	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.285100	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.145631	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.712154	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  52.497976	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.943246	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  38.204092	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.258627	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.171958	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  45.437781	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.854916	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.927453	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   7.723546	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  42.336012	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.966811	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.504036	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.045068	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.425279	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.031292	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.251069	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.151570	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.474793	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  15.718234	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.986777	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.851834	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.793817	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.866356	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  12.403323	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  21.549332	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.763462	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  37.966566	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.746613	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  51.641236	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.194550	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  19.837328	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.888723	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.949660	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.840708	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.389108	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.616960	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.536045	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.491033	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.424689	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.170087	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.653066	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  10.108981	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  11.310722	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.951058	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.862617	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.233297	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  14.531416	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.968104	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.472979	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  12.387968	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  56.800352	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.132408	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.837755	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.683689	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.960574	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  50.966902	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   0.641499	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.555353	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.449884	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.784257	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.388647	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.419423	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.245068	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  39.713572	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.461009	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.905004	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  42.427246	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.448377	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.171670	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.588011	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.019570	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.708206	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.715044	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.304284	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  35.940761	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  38.993980	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.189665	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.960172	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.977274	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.031710	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.748419	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.958311	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  38.655435	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.968528	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.365563	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.752947	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.814119	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  46.597134	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.834376	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.963319	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.924171	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  41.438636	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.673945	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.929988	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.508035	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.413132	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  46.124708	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.042054	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.125151	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  17.340868	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   6.443106	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  34.573198	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.997626	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.201939	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.367213	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  41.343277	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.192348	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.952004	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.747119	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.594178	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.915667	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  37.384339	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.915070	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.465949	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 127.322258	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  23.462597	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.112738	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.654213	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.395427	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.156225	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.512581	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  53.773989	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.131977	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.996640	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.382160	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.212148	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.024211	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.190152	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.933739	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.103449	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.444354	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.316155	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.355123	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.220718	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.935614	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.509837	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.106171	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.102195	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  52.583213	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.146837	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.459707	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  43.959889	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.069935	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.849941	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.576660	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.850308	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.114610	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  48.537675	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.394386	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.264700	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  38.472125	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.132279	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.996653	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  11.018071	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  35.794226	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.949236	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.129782	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.511384	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  20.328857	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  39.157332	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.681811	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  50.452214	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.724813	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.895267	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.799580	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.868500	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  50.745152	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.539797	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.854779	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  39.037447	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.453137	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.980669	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.042919	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  19.851675	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.085128	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.539747	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.587847	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 112.485421	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  39.767310	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.710200	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.304264	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   9.422919	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.797431	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  16.266406	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.401015	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.767993	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.613536	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.194884	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.698094	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.765000	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.531217	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.890964	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.157887	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  21.928903	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.373976	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  11.472840	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.687541	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.128175	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.073074	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.881039	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.812689	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.238044	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   8.039785	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.501107	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.206206	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.959517	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.571575	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  58.013086	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.274254	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.434551	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.945789	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.088735	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  65.663418	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.988923	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.903423	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.200001	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.794240	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.462684	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  51.592096	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.079729	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.588976	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.340452	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.682756	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  43.147186	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.308015	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.066111	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.710762	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  38.994153	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  38.144155	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.936247	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  35.311405	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  14.776887	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.301675	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.652159	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  60.424287	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.178988	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.330211	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.858764	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.146101	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.684083	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.013784	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.654026	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.034722	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.396458	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.125826	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.381799	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.321688	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.355387	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.914913	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.831186	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.693619	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  14.272758	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 130.268893	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  16.636628	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.433202	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  21.419629	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.349336	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.437018	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.231216	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 110.864273	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  17.966132	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.546384	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.901878	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.667042	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.692629	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.918107	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  10.044041	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.662305	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.718994	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.991910	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.056516	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  50.459530	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.393701	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.985349	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.061480	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.264170	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.443285	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.566708	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.525701	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.805360	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.612639	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.541499	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.173911	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  10.370296	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.802772	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.044340	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.685591	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.209424	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.943872	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.436051	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.025673	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.166056	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.877952	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.882489	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.708592	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.773300	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.441266	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.899099	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.083103	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  10.331629	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  11.722328	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.155192	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.501134	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.895567	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   8.301786	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  35.383745	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.791211	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.656638	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.321304	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.998865	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.408846	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.414632	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.061706	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.970776	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.053165	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   6.670545	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.408553	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.507771	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.349860	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.185102	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.203846	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.560584	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.130560	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  38.074066	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  54.825042	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.031595	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.887323	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.823364	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.876007	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.489074	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.494960	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.590874	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.798383	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.907264	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.876884	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.389806	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.498679	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.171321	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.492614	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.106813	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.626958	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.050068	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  51.845871	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.148839	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.315459	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   4.115197	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.679454	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.060929	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.627867	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  12.373525	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.866282	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 116.322400	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  25.122358	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  18.919517	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.050116	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  16.114912	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.526198	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  20.230952	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  43.151916	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.514166	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.076704	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.689585	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.633556	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.501537	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.841433	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  56.261476	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.367160	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.637434	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  60.452697	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.359111	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.583887	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.995748	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.698899	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.854846	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 123.640236	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  27.860702	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  53.489446	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.476065	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  38.391017	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.412401	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.555631	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  43.639035	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.076744	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.921755	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.228811	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.438530	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  62.167475	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  71.994712	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.813460	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  38.276626	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.498979	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.196458	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.584717	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.101840	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.510475	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.051989	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  12.863829	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.782101	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.936444	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.835887	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  53.830891	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  52.076188	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.171523	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  14.643660	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  16.176547	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.884216	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.261777	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.483181	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.672173	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.479397	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.116543	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.709430	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  38.418348	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.167098	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.236803	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.249074	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.703857	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.097935	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  59.313146	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.587844	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.155728	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.444427	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.635301	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.212533	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.733039	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.897353	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.604320	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.673817	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.525900	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.351207	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.549516	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.429724	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.327843	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.554480	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  61.818525	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.842660	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.175087	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.124049	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.725259	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.069636	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.698055	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  19.482905	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.449092	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.061551	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.878929	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.056731	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  19.334390	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.053381	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  41.412936	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.194227	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.705657	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.622656	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.842068	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.076071	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  50.670951	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.471838	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.102668	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.061796	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.658141	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.173696	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.496353	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.415168	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.799730	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  21.048393	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  38.047582	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.859753	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.399552	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  58.799634	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.843322	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.800865	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.110880	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.889307	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.555551	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.316337	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  42.097053	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.695032	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.930459	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.861095	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.871548	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.222211	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.151466	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.223021	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  50.387113	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.082857	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  54.545163	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.993716	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.235272	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.517317	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.076980	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.417348	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.070675	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  42.252514	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.964424	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  57.817499	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.840717	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.125570	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.753877	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.759882	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.165831	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.516078	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.464136	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.537297	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.895549	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.268089	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.371358	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.727831	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.164730	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   0.854904	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.384235	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.957967	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.604815	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.440851	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.283990	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.845405	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.884337	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  66.183975	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.780652	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.112093	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  51.512027	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.741063	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.094115	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.234993	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.397923	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.186315	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.295755	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.998903	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.068894	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.315098	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.977989	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.496603	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.777474	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.468112	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   6.966222	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  26.205296	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  19.964118	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  41.512423	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.893489	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  14.210468	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.339802	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.300486	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.367223	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.919089	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.326848	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.893785	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 124.928127	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  26.701062	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  18.002348	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  15.081130	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  45.191494	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.788795	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  12.676094	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.056165	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.006608	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.012712	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.695104	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.185840	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.186461	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.600359	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.776296	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.829502	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.372703	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.499606	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.268591	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  51.121491	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.623829	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  50.568239	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.981421	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.159528	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.647420	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  54.063464	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  62.459124	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.853425	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  21.655317	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.683913	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.716430	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  11.414403	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  56.340413	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.901109	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.060615	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.389939	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.417689	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.768885	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.010611	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.069095	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.677975	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.697928	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.422685	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.159666	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.256828	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.879380	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.454066	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.236999	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.572197	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  46.635634	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  14.970807	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.001220	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.244794	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.973228	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.857708	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.571494	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.830796	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.555858	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  40.094793	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  52.565737	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.215695	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.146973	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.541902	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.270563	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  11.957250	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  21.950987	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  17.454152	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.453802	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.320441	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.046941	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.681365	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 101.952095	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  33.096448	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.647893	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.175800	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  19.785238	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  45.071269	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.664754	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.461566	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  46.075211	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.029167	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.132398	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.233140	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.673747	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  13.844665	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.299404	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.185665	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.175560	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.256747	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.661552	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.152329	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.028632	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.224841	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.345205	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.197630	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.116049	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  50.729788	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.755283	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.609971	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.443541	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  20.021937	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.071518	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  52.322928	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  11.800726	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.294946	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.581374	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.774749	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  53.209318	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.290909	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.350241	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.732477	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   1.104365	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.319414	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.681029	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  37.555053	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.689756	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  37.293050	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.879133	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.862676	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.999070	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  46.949581	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.523042	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.338078	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   6.988321	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  52.077436	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.516178	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.040639	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  38.941486	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.147128	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.614264	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  41.098120	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.049164	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.626894	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.274839	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  43.933231	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.961064	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.692949	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.798915	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.672490	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.740803	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.583845	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.069445	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.190943	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.981690	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.427895	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.991816	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.453094	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.972206	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.021362	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  41.554469	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.134036	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.222060	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.651775	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.327585	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.283072	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.085285	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.293724	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.413773	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.161605	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.513939	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.618263	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  50.828897	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.512769	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.680253	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.180004	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.513997	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.799423	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.585329	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  50.284545	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.385776	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.786207	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.912550	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.756719	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.343454	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.018208	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.486628	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.926863	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.165457	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  58.781538	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.110477	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.856364	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.279319	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  12.867451	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 109.084090	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  37.301585	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.318072	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.488207	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.738971	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.081080	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.981149	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.396013	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   7.724462	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.493377	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.489253	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  51.000761	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.939070	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.407536	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.061066	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.028563	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.543089	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.863766	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.272993	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  53.958525	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.762813	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.334913	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.746653	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.710357	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.824979	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  49.771107	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.249645	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.244469	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  35.379997	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.570476	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.827161	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 120.473344	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  22.569277	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.013310	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.612254	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.943572	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.555997	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.906831	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  50.904670	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.053580	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.729299	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.357594	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  20.719389	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.111967	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.146962	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.101516	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.773618	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.120949	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.729507	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.434158	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.367510	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.671725	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.983563	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.435817	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  16.800651	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.182650	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  12.259156	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  49.413768	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.666720	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.002344	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.155754	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  38.618602	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.644038	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.506898	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   4.784592	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.890678	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  38.177806	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.073547	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.411346	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.889661	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.190733	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.402544	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  57.870672	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.655608	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.943637	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  56.144910	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 113.509838	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  47.146590	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.001185	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.909731	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.091728	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.440945	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   7.373998	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  50.567137	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  53.646892	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  10.077511	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.905936	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 112.567749	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  26.532456	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.433297	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  43.563601	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.054991	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.340298	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.476352	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.046012	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   6.908622	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  18.804617	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  45.607792	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.072797	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.937619	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  38.120323	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  44.233791	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.144382	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.351099	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.529298	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.977504	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.059162	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.709757	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  56.605464	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.727105	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.787994	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.949093	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.677671	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.507724	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.172362	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.486276	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.688646	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.145210	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.917963	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.395695	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.926045	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.670419	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  20.251081	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.362785	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.176227	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  19.359443	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.235026	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.670376	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.778756	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  54.792025	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 122.094380	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  38.014266	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.657334	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.657272	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.479480	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.280047	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.340856	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 105.315054	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  46.747941	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.597762	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.279825	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.254939	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   8.838418	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.763269	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.372269	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.536857	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   3.659695	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  18.701062	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  41.432212	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.685228	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.997491	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.978647	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.416013	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  11.197947	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  10.773484	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.002689	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.405479	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  57.838843	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.630292	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.200175	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.093530	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  54.381614	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 107.830204	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  20.835244	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.736212	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.096156	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.509584	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.244914	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.677603	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.113605	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  19.283278	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  13.117979	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  47.137220	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.047819	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.234156	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.286226	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.578762	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.430696	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.318066	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  44.631846	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.713009	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.350511	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.902619	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.097911	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  19.888159	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   7.517139	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  38.305592	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.660475	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  38.460914	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  55.135559	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  50.768326	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.615326	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.681957	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.893659	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.832060	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  37.854388	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  14.106055	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.178997	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  20.461432	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  12.833556	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  43.795349	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  13.719154	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.706774	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.783711	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.617921	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.922511	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.695752	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   8.161182	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  12.842228	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.957018	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  52.887685	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.922251	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   6.667863	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  37.159556	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.000954	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.498310	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.618681	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.907674	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.288938	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.433137	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  52.064394	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  13.533636	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.297008	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.133105	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.269354	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.338232	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.747221	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  52.540220	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.488186	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.512839	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  50.048260	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.950280	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   6.990434	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  32.348586	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  15.870741	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  35.820297	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.635160	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.874689	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.233397	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.611044	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.928333	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.138856	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.578308	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  16.470986	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.137369	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  40.141056	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.170573	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.118501	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.025889	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.133920	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.852627	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  14.466617	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  59.176575	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.863363	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.838297	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.330943	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.567502	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.247283	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.079847	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.336195	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.343477	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.183981	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  54.187728	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.516901	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.149364	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.628065	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.775219	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  37.893804	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.246715	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  55.416540	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.448856	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.703212	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  51.342992	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.250275	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.718979	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.770676	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.361260	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.739624	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  14.246534	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.069686	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.216295	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.951254	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  55.087653	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.793470	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.975068	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.988479	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  40.051008	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.876389	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.323467	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  14.490853	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.265649	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.010379	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.160488	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  53.660213	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.795206	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   9.772023	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  19.322977	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  53.955683	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.210477	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.652293	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.805588	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.955716	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.610133	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  11.654237	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.162855	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.766910	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.353313	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  14.620169	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.470043	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.383169	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.766260	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  38.851583	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.738943	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.209632	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.344452	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.704645	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  40.649820	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  18.683869	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.760715	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.062390	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   2.309517	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  46.148067	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   6.926321	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  34.188476	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  17.927259	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  57.453360	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.736360	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.313650	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.915252	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.122024	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.776501	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.159131	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.786710	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.106756	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.088882	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.691536	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.637510	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.621421	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   4.616461	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.131792	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.529104	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.035756	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.008300	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.104716	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.461718	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.611420	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.926742	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.181189	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.466837	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.517234	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.201323	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.286297	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.630294	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.687148	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.802201	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.983816	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.719058	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.574217	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.311958	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.259828	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.515752	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.866070	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   1.318143	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  18.364714	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.976875	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.926518	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  40.688727	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.038372	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.881511	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.244219	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  38.234841	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.136632	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.915983	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.012278	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.380350	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.498574	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  44.994619	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.678324	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  53.513244	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.455794	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.006599	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.326692	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.075105	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.564624	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  13.877242	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.139262	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.881851	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  16.957551	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  56.749824	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.786043	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  53.314930	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.899814	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.402915	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   9.191220	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.344468	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.390037	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  13.386326	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  16.208017	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  19.797706	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  44.076769	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.613390	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.594379	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.833075	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.827327	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.607204	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.812392	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.857083	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.400376	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  40.979634	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.503606	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.152968	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.012464	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  48.318333	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.290115	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.289234	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.074676	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.242725	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.553687	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.352665	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.240206	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.922804	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.543600	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.595806	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.283550	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.476075	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   4.185108	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.944348	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.731975	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  44.926948	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  59.625724	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.391066	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.234143	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.521132	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.998974	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.838468	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.959055	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.322230	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.235243	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.722978	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  54.820773	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.713272	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.196951	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.935331	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.119786	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  41.849817	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.512670	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  35.770737	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.346247	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   7.623160	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  46.704728	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.551223	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.391970	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  16.798653	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.145130	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  48.502605	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.432338	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.091352	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.469552	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.234490	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.979507	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  35.615584	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.072353	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.376512	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  14.817446	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.001767	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.345265	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.073910	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.669639	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.570924	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  49.704745	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.931987	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.707114	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.845940	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  47.005773	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.322018	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.423132	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.392058	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.378808	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  44.954830	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.513156	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  12.432227	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.483143	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.772612	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  19.852807	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.352498	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.824670	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.227542	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.791875	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.710928	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.793386	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.377161	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  38.787487	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.818698	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  12.442638	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.071583	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  13.609703	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  18.501870	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.901969	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.522850	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  50.266489	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.286946	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.084813	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.491453	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.073463	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.999888	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  12.643388	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  19.862886	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 120.370967	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  15.669937	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.318034	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.800629	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.057891	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  50.897502	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.173457	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.258447	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.451360	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  14.787591	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  53.601042	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.982639	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.628219	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.717026	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.822232	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.533272	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.483506	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  56.021178	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.988482	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.289043	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  50.521853	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.701723	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.625843	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.227776	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.755501	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.265920	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.181573	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.462021	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.435586	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.104953	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.481930	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   8.109076	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  27.843292	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.598775	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.003346	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.040148	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.467240	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.158084	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.017756	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  51.291340	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.372457	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.609319	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.452942	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.379232	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  35.626507	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.717380	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  19.819243	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.879120	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.198109	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.256580	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  16.190504	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.295454	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.406491	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.882672	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.276919	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  20.288300	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 108.853565	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  27.120690	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.467891	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.231515	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.530085	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.437287	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.650418	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.631201	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  13.113451	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.097949	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.573356	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.772338	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.993961	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.608451	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.817454	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  40.922188	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.589135	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.223720	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.444044	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.054840	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  14.980957	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  57.844586	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.188731	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  19.313713	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  21.399991	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.067776	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  15.407380	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.081068	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.482366	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.513608	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   7.552531	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  10.705362	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  46.777923	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.104689	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.331223	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.961978	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  50.957351	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  55.100996	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  66.874597	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.996276	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.990999	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  17.485791	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.333475	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.233175	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.868148	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.590771	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.496133	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  17.462564	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  20.490096	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  15.043010	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.180718	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.541532	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.445190	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.763720	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.168616	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.183772	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  13.152599	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.266962	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.422748	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.681609	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.605164	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.071664	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.543588	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.121230	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.070264	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.411853	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  41.855471	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.968245	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.631097	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  40.166312	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.485510	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  39.461253	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.484404	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.720104	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.879625	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  13.395563	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.026699	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.355810	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  47.298909	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.918883	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.762909	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  52.191791	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.388904	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.807512	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  19.505620	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  15.443795	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.393505	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  65.154727	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.488502	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.462974	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  60.818283	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.431927	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  42.251693	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.924063	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.321363	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  42.767814	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.595664	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  13.689330	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.094998	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.990259	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  54.010398	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  14.971371	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.811936	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.854727	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.286984	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  13.026222	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.206701	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.323942	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.971434	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.852040	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  46.868792	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.501603	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.213807	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  35.630762	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.646863	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.189090	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.563407	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  19.864408	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.390827	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.638942	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  57.103303	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.616531	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.787768	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.588197	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.985560	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  38.743636	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.706589	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  14.920919	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.979287	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.982995	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.555324	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  15.811280	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.358667	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  45.220237	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.851702	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.625176	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.597341	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.052786	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.636903	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.709862	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  40.154464	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.917116	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  16.111269	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.682427	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  42.156435	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.278487	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.748628	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.702440	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.343340	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.692103	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  39.682470	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.051018	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.670367	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.123256	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.327500	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.592275	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  40.623835	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.348038	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.948178	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.947649	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.371556	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.214194	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.339985	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.163913	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  18.514901	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.774380	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.273818	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.432082	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.976215	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  92.334111	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  37.666898	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  37.079386	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.973057	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  13.108069	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.818466	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  54.595648	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.337478	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  49.605160	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.752005	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 107.894826	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  44.981311	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.458021	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.332069	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.474035	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  53.470778	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.265142	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.916192	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.855324	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.843730	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  35.308534	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.481148	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  19.502990	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  46.357262	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.185314	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   8.803703	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  18.101175	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.870223	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.096978	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.193380	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 114.565377	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  30.655066	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  14.319507	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   3.550952	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.096580	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.297170	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.767875	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.045469	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.210459	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.412323	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.654340	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.791182	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.584765	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.838646	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.682280	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  18.971434	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  13.392690	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.631522	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.119019	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.670795	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.615203	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.773839	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  51.560349	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.512592	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.992462	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.735991	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   7.725833	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  41.562045	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.115694	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.607585	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.472928	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  39.594929	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.497609	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.058649	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.417580	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.501130	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.705042	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.704487	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.012298	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  10.275734	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.891150	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.870333	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.559934	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.494526	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  19.129722	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.884700	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.942610	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.560076	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.005174	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.314896	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.440477	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  51.723560	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.200588	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.559212	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.806150	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  97.438395	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  42.908669	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.609299	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.861458	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.735117	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.021362	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.647243	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  40.340056	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.712122	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  20.142036	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.632340	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   9.365368	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.387848	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.236445	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.663054	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.946745	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  35.039921	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.488035	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.658418	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.653504	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.184507	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.452313	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  18.404728	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.583455	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.897809	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.909596	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.571907	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.081881	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.956920	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  21.852241	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.318946	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.710202	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  35.346558	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.468335	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.316208	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  41.229733	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.092842	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.082186	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  17.033753	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  56.858561	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.708506	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  55.177565	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.925198	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.376953	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.344468	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.913803	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.379966	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  40.484442	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.873541	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  37.290351	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.612132	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.912773	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.386421	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.619573	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.616557	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.385900	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.810865	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.664682	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.614809	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.285924	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.918674	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.020210	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.538353	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.475592	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.631360	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.064395	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  55.500138	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.483139	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.604204	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.514895	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.700924	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.986181	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  20.401343	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  35.325175	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.009047	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.812214	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  35.697269	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.204315	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.552366	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.189621	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.579336	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.229563	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.532968	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.885091	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.817150	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  18.221911	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.895013	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  53.694698	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.526625	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.854918	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  17.592126	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.900808	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.223329	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.687440	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  58.825389	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.515595	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  40.298704	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.369149	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.783588	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.503231	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  11.955273	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.135269	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.540260	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.777366	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.289170	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.450069	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.126670	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.992541	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.024737	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.300258	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.714667	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  19.706635	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.318443	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.643546	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  15.087845	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  15.668091	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  54.559515	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.055194	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.158655	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.427915	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.726469	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.898838	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.182779	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.222753	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.253419	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.406070	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  43.793510	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.375790	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  42.003000	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.059654	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.399787	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.556359	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.656425	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  39.949264	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.336257	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.476792	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  17.075475	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  35.176346	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.028525	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.636104	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000; % SYNC
	2	 0.0	 0.0	 3	   0.000000	  28.399496	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.565571	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.322830	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.870489	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.338033	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  50.582743	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.666353	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  40.301183	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.749603	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.089694	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.936655	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.797947	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.433112	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.929580	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   8.959003	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  21.386314	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.008287	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.257056	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  13.650112	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.249375	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  40.772802	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.846620	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.580751	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.318881	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.343798	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.467445	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 108.159046	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  25.608170	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  35.118139	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  11.986628	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.188803	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.470226	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  39.880561	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.458584	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.829764	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  59.390928	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.652384	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   2.896679	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  39.905605	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  52.305083	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.562703	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.644486	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.929966	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.107495	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.745293	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.011771	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.598583	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.036504	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.390266	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  11.650094	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  43.612039	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.818163	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  14.389845	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.518245	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.553628	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.012894	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.370652	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.151758	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  49.997327	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.711227	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.863737	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  10.896369	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.765663	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.321563	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.604159	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.064732	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.655679	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.592661	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.129614	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.753003	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.701929	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.495610	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.766981	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.015053	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.125872	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.748418	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.390468	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.960577	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.593530	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.714901	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.229266	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.246474	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.164007	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.174694	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.504917	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.382304	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  21.526459	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.345655	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.820543	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  53.135946	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.681135	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  12.538743	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  45.770014	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.471452	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  38.871596	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.700952	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  18.484174	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.139835	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.270529	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.273296	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.288733	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  39.677112	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.237429	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.589238	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.084372	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.185917	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.332074	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.789690	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.453916	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.463824	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  54.719255	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.017981	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.342314	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.151141	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.069259	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.376946	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  35.232680	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  16.214261	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  43.260909	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000; % SYNC
	2	 0.0	 0.0	 3	   0.000000	 111.808694	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  29.811658	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.415891	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.790747	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  11.915051	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.724235	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.370300	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.222253	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.177012	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.031666	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.016056	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.045721	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.320961	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.320229	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.539070	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.315072	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.768921	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.212771	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   3.617083	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.640309	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   9.377871	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  13.837771	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  53.717031	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.821808	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.526508	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.952229	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.895626	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.801147	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  37.674947	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  11.163072	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.903478	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.100332	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.930536	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.885178	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.377121	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  48.203602	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.584099	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 112.437699	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  15.187199	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.864302	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  57.795950	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  12.091962	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  45.623825	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.398082	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  46.336245	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.718116	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.049054	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.421210	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.821291	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.793120	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  18.929489	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.315550	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  11.010639	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.624943	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  19.789139	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.912326	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  18.274208	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  61.861436	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.654737	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.016088	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.152104	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.739332	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.355442	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.810770	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.987168	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.404788	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.832625	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.638968	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.234642	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.958347	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.775718	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.879601	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  13.964691	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  55.966676	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.055431	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.436309	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.023053	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.825886	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.308288	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.252920	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   6.784181	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  41.217889	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.168891	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.556912	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.092323	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  52.638962	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.999361	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.896105	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.949003	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.777930	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.946106	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.084559	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.328453	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.027270	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.656928	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.198947	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.705407	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.152553	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.400686	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  40.518441	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  52.786404	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.047264	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.779772	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  19.752543	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.698156	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.713782	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.835438	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.840611	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  10.518499	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.031478	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.482813	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 109.252242	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  20.052978	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.980566	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.089369	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.056067	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.558497	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   7.530273	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.371693	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.795409	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.604880	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.806467	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.146349	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.748187	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.527328	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.320519	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.090193	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  50.367049	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.785453	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  60.195098	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.322597	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.783729	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.231913	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.818550	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.201488	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.091768	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.101682	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  19.441454	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 113.165155	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  23.019669	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.426603	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.896497	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.910500	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.764978	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.151117	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.016202	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  41.541935	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.714394	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.816909	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.042032	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.623662	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.535378	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.767959	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  65.986654	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  13.554225	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.521603	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  39.864094	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.843955	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  50.236968	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   7.028344	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  37.273376	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.350979	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.141709	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 110.653032	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	   2.800981	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.807788	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  40.058303	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.802076	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.577424	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.144915	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.850546	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.592541	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.612372	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.840014	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.176909	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.620989	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.099285	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.029639	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.982012	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.712784	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.244735	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  12.925759	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  41.824956	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.209938	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.667400	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.503742	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.798316	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.794473	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.372160	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.164568	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.993448	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  10.172102	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.682473	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.466723	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.523920	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.202945	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  50.099351	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.153409	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   8.949799	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.576667	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.351442	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  11.158322	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.534798	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.104558	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.748363	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.888925	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  39.059068	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.977012	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.360881	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  55.959079	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.227669	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.360838	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.856407	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.439331	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.720162	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.113766	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.752779	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  41.478951	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.864228	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.448099	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.013306	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   9.698666	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.367327	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.643004	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.792371	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.010001	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.687598	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.620077	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.827601	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.904378	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  46.083909	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.449694	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  52.601620	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.213155	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.732238	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.194030	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  53.719523	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.560216	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.044892	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.181665	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.026699	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.202304	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.615889	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.900451	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.827510	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  16.965342	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.341749	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 117.717966	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  37.515452	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.693189	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.247286	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.859854	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.846625	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.619196	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  50.612394	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.082996	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  41.264108	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   9.746633	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   7.958753	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 123.517408	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  18.705656	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.785381	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.236946	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.862645	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.814392	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  42.412790	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.731039	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.711863	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.818716	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.262351	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   8.377728	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  21.268629	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.662218	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.863354	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  52.018747	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   5.399807	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   1.856339	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  42.912648	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.832604	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   3.629905	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.015752	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  55.936499	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  52.353512	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.336618	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.941274	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.810157	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.417527	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  56.344109	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 123.442991	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  33.480276	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  39.476059	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.857170	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.734600	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 108.644421	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  27.078245	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.963558	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.867512	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.518552	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.075500	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  37.600005	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.318868	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.717658	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   9.733132	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.779812	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.478009	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.650254	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.179626	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.622219	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.175771	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.274251	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   4.499561	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.127914	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.222691	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   8.972897	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  55.855612	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.339681	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.965081	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.040567	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.855682	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.239197	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  21.863070	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  19.918297	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.698327	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.159584	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.748987	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.655664	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.634242	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.012696	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.282330	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.494156	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  50.174356	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  55.913982	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.424200	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  41.298081	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.591534	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.454544	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.019495	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.354263	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.638370	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.868798	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.686181	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  21.051759	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.406232	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.147562	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.679804	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.608303	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.421258	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.521467	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  58.315941	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.486949	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.189678	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.968115	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.751435	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.390267	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  19.625534	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.129565	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.410296	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  12.684779	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  40.197518	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.964668	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  13.573974	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.207686	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.124924	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.055022	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.689294	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.867669	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.253267	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.056298	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  12.625325	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  58.014944	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.667140	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.201113	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.482273	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  64.787314	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   6.483008	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  35.047619	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.548759	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.653086	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.542556	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.153076	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.029387	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.400180	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  53.172101	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  54.292750	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.290598	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 110.208230	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  24.806627	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.243543	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  11.773532	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  47.619379	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  13.544493	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.020861	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.392309	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.537884	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.044455	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.800539	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.478558	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.347675	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.319661	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.764329	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.162596	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.684646	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.099337	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.703547	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.294307	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.801708	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.883307	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  51.368088	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.565363	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.693957	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.512659	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.743014	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  21.879518	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  45.020812	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.349845	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.565675	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.577534	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.876661	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.957452	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  53.478991	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.751047	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.102786	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.515939	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.621278	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.456401	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.337558	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.554576	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.970684	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.021422	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  21.053247	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.815000	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.006366	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.400019	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   7.649434	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  17.108939	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.042616	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  21.657258	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  18.767551	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.015953	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.174941	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  44.534653	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  58.863466	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.218947	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.173315	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.230158	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.166263	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  58.590306	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.242529	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.786520	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.934633	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.402587	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.802768	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.481758	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.495595	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.382701	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.615680	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.327446	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.188194	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  50.449505	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.647839	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.658746	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.108137	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.296609	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.343976	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.192335	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.209450	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   6.457982	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.464236	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  15.392995	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.842315	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.658756	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.591848	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.972709	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.974317	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.099137	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.735014	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  53.037780	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  14.281688	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.923224	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.920467	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.000128	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  11.002675	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.771008	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.407885	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.681951	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.027839	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.423637	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  56.802280	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.165063	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.971725	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.425665	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.403812	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.618963	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.483788	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.673288	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  59.191330	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.599480	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.601034	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  21.854936	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.770985	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  40.882995	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  21.093087	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.052817	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.072878	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.947312	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.196924	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.376986	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.284764	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.233794	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.304249	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.216403	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.039548	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.125923	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.889269	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.468914	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.136955	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  13.579622	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.327909	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.442889	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.879125	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 112.664058	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  54.028173	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.691099	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  13.372629	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.984055	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.101682	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.685829	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.166420	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.593929	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.301914	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  50.175006	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.235997	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  14.874128	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.558986	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.318974	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  94.855768	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  33.321907	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  73.586977	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.991545	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.835671	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.598202	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.864017	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.410619	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.767613	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.076473	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.253969	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.659348	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  11.343014	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.291016	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  37.516437	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.818787	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.112265	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.863430	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.511490	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.784301	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.480591	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.239975	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.324389	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  40.559768	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.225974	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.825701	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.536648	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.141290	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.227798	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.115368	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.846734	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.167415	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.048262	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.241466	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.353707	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  15.021662	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.213406	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.807523	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   9.619659	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.951346	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.727080	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.749179	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  49.707727	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.575298	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.576061	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.715311	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.333480	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.590825	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.155114	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.197974	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.204897	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   7.486218	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.994513	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.829535	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.996816	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.636490	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  43.307638	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.768126	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  20.191125	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.135289	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.686657	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.748475	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.299846	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  41.366747	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.300139	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.284168	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.222085	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.731925	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.143809	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.732740	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.389021	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.415813	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.208196	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.264550	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  35.354680	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.427320	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.655030	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.067461	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.982574	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.596962	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   7.225298	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  47.712473	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.918527	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.830771	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.591595	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.848417	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.783439	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.134463	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.817907	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.477613	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.794101	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.678289	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.831600	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.594502	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  12.534621	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.921509	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 105.993980	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  14.246959	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.851507	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.938745	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  37.008943	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.089898	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   9.112313	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.807380	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   0.042964	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.709995	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.453215	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.407501	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  35.855425	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.532692	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.852855	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.742450	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.163232	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.211043	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   6.401665	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  10.626848	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.836297	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.320966	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.160916	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.316451	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.311153	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.142117	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.193939	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.162454	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  17.223785	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  42.225835	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.680563	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.234456	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.800355	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.579356	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.924282	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  51.912963	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.698653	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.588345	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.963828	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  52.326018	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.645278	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.650540	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.037682	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.056447	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.193961	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.905607	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.125173	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.649607	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.131462	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.075839	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.545461	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.637917	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   6.051367	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  49.278478	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  10.623828	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  15.010421	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.719624	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.985657	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.117550	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   8.464422	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  21.329922	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.548950	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  43.874921	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.425957	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  15.025950	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.653832	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.872034	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  11.972640	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  38.811845	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.003011	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.652716	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.711247	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  15.154564	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.857614	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  41.678099	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.717924	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  35.003065	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.778328	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  12.810373	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.444798	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  35.573685	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   5.374232	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   5.972855	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  23.346495	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  63.313322	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.755340	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  40.813381	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.148072	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.775883	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  13.910144	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.991308	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   8.473442	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.079895	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.369632	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.275354	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.127238	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.778043	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.347249	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.034822	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  42.411354	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 111.805480	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  19.708191	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  43.045993	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.696150	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  16.149569	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  37.153063	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.140637	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 114.742346	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  37.052305	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.115231	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.235639	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.499900	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.087578	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.577992	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.121799	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.859123	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.346648	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.897149	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  64.675301	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.597971	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   3.130614	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.986687	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.390246	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  61.742459	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.918446	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  43.059682	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.358617	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.005822	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.451626	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.885941	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.735972	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.045305	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.934259	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  11.674580	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  39.116680	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.412193	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.255654	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.777046	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.933738	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.327893	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.192182	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   5.872448	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   9.585337	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  37.419419	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.424338	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.473272	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.603589	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.004705	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.830404	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.010403	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.625496	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.634266	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   8.037571	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.801741	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.801101	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.566077	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.491163	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.688838	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.144991	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.212207	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.023451	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.271599	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.052827	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.080062	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.287330	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  14.290893	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.709081	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.531924	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.652186	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  41.874285	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.554278	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  51.053896	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.435906	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.501697	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  38.974234	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.257699	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.011124	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.070841	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.552360	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.665283	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.890289	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.373907	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.071647	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.947700	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.876034	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.544442	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  18.620881	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.993686	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.754016	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.280790	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.763070	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.642497	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.733859	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  40.235641	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  14.354407	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  39.970452	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.526454	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.158746	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.819041	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.516454	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.805056	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.346873	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  49.276133	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.982876	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.213063	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.047821	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.093911	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.937804	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.956500	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.370570	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.987604	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.651136	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.134830	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.657550	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 101.618429	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	   9.616141	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.929572	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.649002	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.007623	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.869217	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  44.961541	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  52.086325	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.404834	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  52.703929	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.781152	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.485980	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.241805	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.234661	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.048862	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.527387	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  21.585855	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.201097	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  19.131640	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  18.292537	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.747345	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.454817	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 121.874424	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  36.173186	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   8.615648	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.986587	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.135448	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  46.185942	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.632247	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.729561	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  57.821855	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.613368	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.169316	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.938892	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.693117	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.541670	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.350766	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.622917	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.152707	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  45.081575	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.726771	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.454460	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   9.341965	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  16.982265	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.658040	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  18.296824	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   5.375499	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  43.080894	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.789088	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  14.901540	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.968586	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  41.516248	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.991198	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  42.425561	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.528468	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.221635	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.590134	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  21.007449	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  12.582199	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.395523	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.828070	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.286868	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.118264	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  13.536496	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.380674	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.419516	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  21.365925	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  37.294728	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.613178	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  51.059030	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.207535	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.579076	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.985280	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.613845	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.490967	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.849856	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.506552	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  52.940366	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.027384	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.239319	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.619910	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.841345	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.130419	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.357038	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.073281	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.948761	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.413676	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  21.081500	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  35.389550	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.638191	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.680592	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.237226	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  50.880574	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.380310	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.584563	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.390194	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.355612	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.455551	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  66.258024	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  52.165174	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.359858	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  10.505028	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  57.612453	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.112195	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.554039	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.159474	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.607040	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   6.537739	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  35.381215	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.329476	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  12.016246	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.530050	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  50.373587	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.004959	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.977113	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  60.374890	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.148348	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.394953	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  12.249774	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  21.753175	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  20.086930	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.706513	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.859811	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.036935	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  20.353745	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  44.570664	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.194515	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.930323	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.849326	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.788597	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.314220	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  42.339915	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  12.682084	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.097310	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.303084	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  42.697989	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  50.319987	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.036354	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.635396	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.154807	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  18.713884	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  41.218750	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.570517	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.575283	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.722301	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.302886	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.502778	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.889044	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.092774	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.930499	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.130786	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.424830	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  46.011234	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.621185	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  17.579795	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  20.929653	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  40.117451	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.988057	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.374275	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.264100	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  54.832108	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.758865	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.006457	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   6.920132	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  39.871813	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.794131	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.311209	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  12.271658	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.209632	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.963530	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.592816	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.674176	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  13.743091	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  14.055014	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.025053	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  62.140109	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.098581	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.826293	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.435591	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.556005	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  19.337863	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  55.199511	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.576656	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.371347	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.958881	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.286880	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  41.077595	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.815069	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 124.566459	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  29.634228	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.898125	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.444297	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.706658	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  60.501778	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  61.504224	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.865065	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.510266	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  40.237792	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.793698	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.770655	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.479578	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  57.857729	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.954978	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.348913	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  44.779658	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.421412	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.342555	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.166941	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  39.268844	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.633874	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.266138	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.822738	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.078261	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  60.031513	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.666756	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  35.737939	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.514610	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  41.512928	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.602919	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.327457	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.727869	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.643422	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.046984	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  63.210240	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.160149	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.347411	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  43.769205	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.760665	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.405992	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.324923	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.390796	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.214629	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   7.698775	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  52.440157	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  50.075725	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 121.899606	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  31.208380	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.857998	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.655636	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.279425	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.378198	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.096225	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.577991	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.628826	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  20.242598	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.771778	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.310290	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.914849	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  40.120780	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.453833	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.807690	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.752539	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.937013	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.117880	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 107.694614	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  33.180359	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.596483	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.255674	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.910473	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.527577	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  42.649314	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.081333	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.963179	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  50.044808	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   6.523302	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.965731	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  21.843839	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.667286	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.495818	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.708765	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.580583	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.851718	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.861997	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.377053	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  40.101607	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  46.469443	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.579083	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.047583	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  40.822103	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.625957	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.861515	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  47.204495	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.344140	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.539589	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.454862	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.564263	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  51.227732	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.136081	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.605366	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.544450	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.696686	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.289038	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  51.838550	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.077139	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  44.458298	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.342638	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.213287	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.263981	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.689950	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.057100	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.576714	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.281078	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.195101	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   9.431282	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.596053	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  44.017047	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.371702	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  35.669954	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.819088	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.245153	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.122348	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  11.150066	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  57.407991	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.136836	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.929669	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.277271	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.305340	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.152142	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.138891	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.783790	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.873438	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.937370	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.177383	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.995196	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.901229	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.065748	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.001761	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  44.643449	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.917107	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.313884	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.772959	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  18.202763	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.768639	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.617405	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.112379	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   8.318515	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	   8.521743	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.893916	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.104325	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.473879	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   5.791489	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.800013	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.269314	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  11.759078	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  37.393676	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  44.727074	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  11.139814	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  14.832613	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.292033	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  39.207039	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.833713	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.316795	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.538281	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.882543	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  41.159624	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.846041	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.767821	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.390568	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.009984	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  13.578616	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.051136	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.158760	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 106.896165	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  30.522020	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.911415	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   6.785856	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  22.290868	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  18.953218	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  18.537482	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.152798	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 114.431968	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  46.274130	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.032023	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   6.808234	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	   1.211178	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  18.968655	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.513429	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.339584	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.973781	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.105246	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.405444	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.110746	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.297489	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  45.205056	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.281900	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.648734	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  46.638797	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.910873	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.922472	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.684687	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   5.478324	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.939927	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.783366	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.656567	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.357141	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.980715	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.419035	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.480402	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.995987	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.368972	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  40.539310	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.131102	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.121863	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.112800	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.468721	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  13.202019	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.762206	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  21.371539	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  41.699036	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.609301	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   5.918307	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.502827	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.902327	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  50.274166	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  89.639648	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  52.581173	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.893203	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  41.098407	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.245581	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.128022	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.939153	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  51.137704	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.742373	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.053508	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.438286	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.621531	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.805256	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.912678	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.092103	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.907725	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.285811	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.038118	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.386811	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  18.767687	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  11.690974	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.195310	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.597023	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.769006	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  19.980506	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.116531	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.594590	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.541336	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.166838	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.569426	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  12.878745	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.642392	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  18.184314	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.943942	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.204539	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  14.929084	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  15.688475	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.592630	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.165528	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.020351	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  50.148885	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  51.804557	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.825123	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.323336	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.838461	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.913045	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  49.464344	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.849726	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.319434	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.212305	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.894088	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  57.027158	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.277871	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.668068	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.683630	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.153451	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.460648	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.463427	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.882410	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.345428	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.780035	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.693457	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   5.038586	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.276274	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.852292	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.408736	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.122826	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.600836	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.031715	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  40.347123	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.823445	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.792467	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.529586	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.604127	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.755524	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  12.181229	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   4.572608	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.783984	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.471054	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.937701	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.072940	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  45.206806	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.834128	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.109543	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 110.060071	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  37.136590	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.621099	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  58.113457	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.965615	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.377178	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  53.097427	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.885078	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  52.566941	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.290019	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.198856	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.168362	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.099568	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.662883	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.866736	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  43.863034	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  10.938866	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.118917	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.703421	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.650702	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  52.399296	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.770355	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  17.540528	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.853438	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  99.804816	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  34.004505	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.339493	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.380261	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.120535	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.324247	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 100.487877	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  42.343858	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  13.959409	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.058259	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.779595	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.342267	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.624150	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  50.832073	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.992621	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  43.488806	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.861397	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.232110	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.127829	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.138210	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.767030	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.607594	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.924350	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  39.304166	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.722907	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.969545	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  45.627643	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.893993	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.137833	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.482191	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  16.229450	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.405352	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  68.468255	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  16.053952	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  21.364384	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.093130	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.678605	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.619392	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  18.426625	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  36.904475	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.334848	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  13.328056	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000; % SYNC
	2	 0.0	 0.0	 3	   0.000000	  24.449601	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   9.955637	   0.000000; % COW
];

%% branch data
%	fbus	tbus	r	x	b	rateA	rateB	rateC	ratio	angle	status	angmin	angmax
mpc.branch = [
	7519	 4482	 0.0006	 0.00616	 0.0	 5104	 5104	 5104	 0.0	 0.0	 1	 -30.0	 30.0;
	7519	 11823	 0.0005	 0.0074	 0.0	 4259	 4259	 4259	 0.0	 0.0	 1	 -30.0	 30.0;
	3073	 4516	 0.00107	 0.00626	 0.0	 4974	 4974	 4974	 0.0	 0.0	 1	 -30.0	 30.0;
	3073	 4706	 0.000841	 0.0055	 0.0	 5678	 5678	 5678	 0.0	 0.0	 1	 -30.0	 30.0;
	5157	 1032	 0.00143	 0.01563	 0.0	 2013	 2013	 2013	 0.0	 0.0	 1	 -30.0	 30.0;
	5157	 6653	 0.00146	 0.01692	 0.0	 1860	 1860	 1860	 0.0	 0.0	 1	 -30.0	 30.0;
	628	 7896	 7e-05	 0.00057	 0.0	 55004	 55004	 55004	 0.0	 0.0	 1	 -30.0	 30.0;
	628	 6592	 6e-05	 0.00056	 0.0	 56085	 56085	 56085	 0.0	 0.0	 1	 -30.0	 30.0;
	11792	 10888	 0.003349	 0.01656	 0.0	 1870	 1870	 1870	 0.0	 0.0	 1	 -30.0	 30.0;
	11792	 4609	 0.003409	 0.016211	 0.0	 1907	 1907	 1907	 0.0	 0.0	 1	 -30.0	 30.0;
	6573	 10888	 0.003479	 0.01586	 0.0	 1946	 1946	 1946	 0.0	 0.0	 1	 -30.0	 30.0;
	6573	 4609	 0.003099	 0.017969	 0.0	 1733	 1733	 1733	 0.0	 0.0	 1	 -30.0	 30.0;
	782	 13300	 0.00127	 0.01842	 0.0	 1711	 1711	 1711	 0.0	 0.0	 1	 -30.0	 30.0;
	782	 1186	 0.00126	 0.01847	 0.0	 1707	 1707	 1707	 0.0	 0.0	 1	 -30.0	 30.0;
	11715	 924	 0.0013	 0.01808	 0.0	 1743	 1743	 1743	 0.0	 0.0	 1	 -30.0	 30.0;
	11715	 12182	 0.00131	 0.01765	 0.0	 1785	 1785	 1785	 0.0	 0.0	 1	 -30.0	 30.0;
	10257	 2582	 0.00065	 0.01311	 0.0	 2891	 2891	 2891	 0.0	 0.0	 1	 -30.0	 30.0;
	10257	 9363	 0.00067	 0.00974	 0.0	 3851	 3851	 3851	 0.0	 0.0	 1	 -30.0	 30.0;
	7595	 11501	 0.00236	 0.01418	 0.0	 2198	 2198	 2198	 0.0	 0.0	 1	 -30.0	 30.0;
	7595	 11390	 0.002169	 0.015909	 0.0	 1968	 1968	 1968	 0.0	 0.0	 1	 -30.0	 30.0;
	6873	 1806	 0.00027	 0.00254	 0.0	 12367	 12367	 12367	 0.0	 0.0	 1	 -30.0	 30.0;
	6873	 11151	 0.00027	 0.00259	 0.0	 12131	 12131	 12131	 0.0	 0.0	 1	 -30.0	 30.0;
	11949	 1806	 0.00033	 0.00302	 0.0	 10398	 10398	 10398	 0.0	 0.0	 1	 -30.0	 30.0;
	11949	 1269	 0.00029	 0.00312	 0.0	 10081	 10081	 10081	 0.0	 0.0	 1	 -30.0	 30.0;
	2623	 3359	 0.000289	 0.00137	 0.0	 22560	 22560	 22560	 0.0	 0.0	 1	 -30.0	 30.0;
	2623	 11159	 0.000219	 0.00263	 0.0	 11969	 11969	 11969	 0.0	 0.0	 1	 -30.0	 30.0;
	3020	 3359	 0.000289	 0.001341	 0.0	 23027	 23027	 23027	 0.0	 0.0	 1	 -30.0	 30.0;
	3020	 12995	 0.000229	 0.00257	 0.0	 12243	 12243	 12243	 0.0	 0.0	 1	 -30.0	 30.0;
	9670	 3359	 0.000841	 0.00689	 0.0	 4551	 4551	 4551	 0.0	 0.0	 1	 -30.0	 30.0;
	9670	 2360	 0.000979	 0.00586	 0.0	 5317	 5317	 5317	 0.0	 0.0	 1	 -30.0	 30.0;
	8390	 3359	 0.00014	 0.0012	 0.0	 26146	 26146	 26146	 0.0	 0.0	 1	 -30.0	 30.0;
	8390	 11515	 0.000211	 0.001539	 0.0	 20335	 20335	 20335	 0.0	 0.0	 1	 -30.0	 30.0;
	12630	 3359	 0.000401	 0.004901	 0.0	 6424	 6424	 6424	 0.0	 0.0	 1	 -30.0	 30.0;
	12630	 11515	 0.000219	 0.00151	 0.0	 20703	 20703	 20703	 0.0	 0.0	 1	 -30.0	 30.0;
	3340	 3359	 0.000729	 0.004539	 0.0	 6872	 6872	 6872	 0.0	 0.0	 1	 -30.0	 30.0;
	3340	 3953	 0.00062	 0.00482	 0.0	 6500	 6500	 6500	 0.0	 0.0	 1	 -30.0	 30.0;
	7444	 8848	 0.00052	 0.00407	 0.0	 7699	 7699	 7699	 0.0	 0.0	 1	 -30.0	 30.0;
	7444	 5026	 0.00034	 0.00502	 0.0	 6278	 6278	 6278	 0.0	 0.0	 1	 -30.0	 30.0;
	11055	 8848	 0.00065	 0.00698	 0.0	 4506	 4506	 4506	 0.0	 0.0	 1	 -30.0	 30.0;
	11055	 13067	 0.00059	 0.00806	 0.0	 3909	 3909	 3909	 0.0	 0.0	 1	 -30.0	 30.0;
	9857	 13125	 0.00063	 0.00464	 0.0	 6746	 6746	 6746	 0.0	 0.0	 1	 -30.0	 30.0;
	9857	 12598	 0.000599	 0.005099	 0.0	 6153	 6153	 6153	 0.0	 0.0	 1	 -30.0	 30.0;
	7256	 7011	 0.00064	 0.00307	 0.0	 10073	 10073	 10073	 0.0	 0.0	 1	 -30.0	 30.0;
	7256	 11232	 0.000659	 0.003	 0.0	 10284	 10284	 10284	 0.0	 0.0	 1	 -30.0	 30.0;
	12732	 9895	 0.00053	 0.00528	 0.0	 5953	 5953	 5953	 0.0	 0.0	 1	 -30.0	 30.0;
	12732	 4416	 0.00056	 0.0053	 0.0	 5927	 5927	 5927	 0.0	 0.0	 1	 -30.0	 30.0;
	4494	 7011	 0.0018	 0.007919	 0.0	 3890	 3890	 3890	 0.0	 0.0	 1	 -30.0	 30.0;
	4494	 10481	 0.001651	 0.00862	 0.0	 3600	 3600	 3600	 0.0	 0.0	 1	 -30.0	 30.0;
	7913	 9895	 0.00045	 0.00545	 0.0	 5777	 5777	 5777	 0.0	 0.0	 1	 -30.0	 30.0;
	7913	 1269	 0.00052	 0.00476	 0.0	 6597	 6597	 6597	 0.0	 0.0	 1	 -30.0	 30.0;
	3258	 10043	 0.01286	 0.037421	 0.0	 799	 799	 799	 0.0	 0.0	 1	 -30.0	 30.0;
	3258	 8238	 0.032397	 0.123	 0.0	 249	 249	 249	 0.0	 0.0	 1	 -30.0	 30.0;
	697	 10043	 0.032851	 0.069727	 0.0	 410	 410	 410	 0.0	 0.0	 1	 -30.0	 30.0;
	697	 11841	 0.059942	 0.112802	 0.0	 248	 248	 248	 0.0	 0.0	 1	 -30.0	 30.0;
	11629	 10942	 0.00011	 0.00109	 0.0	 28833	 28833	 28833	 0.0	 0.0	 1	 -30.0	 30.0;
	11629	 13171	 0.00011	 0.00107	 0.0	 29367	 29367	 29367	 0.0	 0.0	 1	 -30.0	 30.0;
	9089	 11260	 0.000461	 0.00395	 0.0	 7943	 7943	 7943	 0.0	 0.0	 1	 -30.0	 30.0;
	9089	 7609	 0.000599	 0.003789	 0.0	 8235	 8235	 8235	 0.0	 0.0	 1	 -30.0	 30.0;
	13119	 3581	 0.00173	 0.01542	 0.0	 2423	 2423	 2423	 0.0	 0.0	 1	 -30.0	 30.0;
	13119	 6381	 0.00166	 0.02083	 0.0	 1799	 1799	 1799	 0.0	 0.0	 1	 -30.0	 30.0;
	5075	 13106	 0.006314	 0.018488	 0.0	 1617	 1617	 1617	 0.0	 0.0	 1	 -30.0	 30.0;
	5075	 9503	 0.015727	 0.037669	 0.0	 774	 774	 774	 0.0	 0.0	 1	 -30.0	 30.0;
	11048	 10312	 0.00374	 0.02095	 0.0	 1485	 1485	 1485	 0.0	 0.0	 1	 -30.0	 30.0;
	11048	 3185	 0.00511	 0.019461	 0.0	 1570	 1570	 1570	 0.0	 0.0	 1	 -30.0	 30.0;
	1538	 4109	 0.011281	 0.050771	 0.0	 608	 608	 608	 0.0	 0.0	 1	 -30.0	 30.0;
	1538	 3721	 0.0115	 0.049719	 0.0	 619	 619	 619	 0.0	 0.0	 1	 -30.0	 30.0;
	5803	 4109	 0.011719	 0.048659	 0.0	 632	 632	 632	 0.0	 0.0	 1	 -30.0	 30.0;
	5803	 3721	 0.01193	 0.047599	 0.0	 644	 644	 644	 0.0	 0.0	 1	 -30.0	 30.0;
	189	 4268	 0.00064	 0.00715	 0.0	 4401	 4401	 4401	 0.0	 0.0	 1	 -30.0	 30.0;
	189	 11488	 0.00089	 0.00712	 0.0	 4403	 4403	 4403	 0.0	 0.0	 1	 -30.0	 30.0;
	7384	 1009	 0.00048	 0.00555	 0.0	 5671	 5671	 5671	 0.0	 0.0	 1	 -30.0	 30.0;
	7384	 11547	 0.00047	 0.00566	 0.0	 5562	 5562	 5562	 0.0	 0.0	 1	 -30.0	 30.0;
	11070	 1009	 0.00046	 0.00524	 0.0	 6006	 6006	 6006	 0.0	 0.0	 1	 -30.0	 30.0;
	11070	 11547	 0.00052	 0.00514	 0.0	 6115	 6115	 6115	 0.0	 0.0	 1	 -30.0	 30.0;
	2061	 6603	 0.00438	 0.010686	 0.0	 2736	 2736	 2736	 0.0	 0.0	 1	 -30.0	 30.0;
	2061	 9733	 0.031347	 0.062653	 0.0	 451	 451	 451	 0.0	 0.0	 1	 -30.0	 30.0;
	9502	 7241	 0.00029	 0.00298	 0.0	 10550	 10550	 10550	 0.0	 0.0	 1	 -30.0	 30.0;
	9502	 8865	 0.0003	 0.00291	 0.0	 10798	 10798	 10798	 0.0	 0.0	 1	 -30.0	 30.0;
	12336	 13321	 0.00155	 0.01529	 0.0	 2469	 2469	 2469	 0.0	 0.0	 1	 -30.0	 30.0;
	12336	 494	 0.00148	 0.0152	 0.0	 2462	 2462	 2462	 0.0	 0.0	 1	 -30.0	 30.0;
	13540	 11971	 0.000169	 0.00096	 0.0	 32406	 32406	 32406	 0.0	 0.0	 1	 -30.0	 30.0;
	13540	 330	 0.000182	 0.000942	 0.0	 32924	 32924	 32924	 0.0	 0.0	 1	 -30.0	 30.0;
	8250	 622	 0.00016	 0.00184	 0.0	 17103	 17103	 17103	 0.0	 0.0	 1	 -30.0	 30.0;
	8250	 8646	 0.00022	 0.00287	 0.0	 10974	 10974	 10974	 0.0	 0.0	 1	 -30.0	 30.0;
	5656	 9506	 0.00015	 0.00187	 0.0	 16838	 16838	 16838	 0.0	 0.0	 1	 -30.0	 30.0;
	5656	 7003	 0.00022	 0.00266	 0.0	 11835	 11835	 11835	 0.0	 0.0	 1	 -30.0	 30.0;
	8767	 13151	 0.00138	 0.0174	 0.0	 2154	 2154	 2154	 0.0	 0.0	 1	 -30.0	 30.0;
	8767	 256	 0.00272	 0.0288	 0.0	 1300	 1300	 1300	 0.0	 0.0	 1	 -30.0	 30.0;
	11952	 7565	 0.00065	 0.01024	 0.0	 3079	 3079	 3079	 0.0	 0.0	 1	 -30.0	 30.0;
	11952	 8750	 0.00073	 0.01004	 0.0	 3138	 3138	 3138	 0.0	 0.0	 1	 -30.0	 30.0;
	13220	 7565	 0.00075	 0.00983	 0.0	 3205	 3205	 3205	 0.0	 0.0	 1	 -30.0	 30.0;
	13220	 8750	 0.00076	 0.00963	 0.0	 3270	 3270	 3270	 0.0	 0.0	 1	 -30.0	 30.0;
	10465	 10831	 0.00042	 0.02666	 0.0	 1410	 1410	 1410	 0.0	 0.0	 1	 -30.0	 30.0;
	8079	 10358	 0.00029	 0.0026	 0.0	 12075	 12075	 12075	 0.0	 0.0	 1	 -30.0	 30.0;
	8079	 8404	 0.00022	 0.00303	 0.0	 10398	 10398	 10398	 0.0	 0.0	 1	 -30.0	 30.0;
	7197	 5524	 0.001	 0.006159	 0.0	 5063	 5063	 5063	 0.0	 0.0	 1	 -30.0	 30.0;
	7197	 11931	 0.00113	 0.00657	 0.0	 4739	 4739	 4739	 0.0	 0.0	 1	 -30.0	 30.0;
	1721	 12153	 0.0013	 0.01277	 0.0	 2929	 2929	 2929	 0.0	 0.0	 1	 -30.0	 30.0;
	1721	 10744	 0.00163	 0.01808	 0.0	 2071	 2071	 2071	 0.0	 0.0	 1	 -30.0	 30.0;
	8400	 850	 0.00047	 0.00406	 0.0	 9198	 9198	 9198	 0.0	 0.0	 1	 -30.0	 30.0;
	8400	 8575	 0.00235	 0.02343	 0.0	 1597	 1597	 1597	 0.0	 0.0	 1	 -30.0	 30.0;
	9020	 2201	 0.00036	 0.00445	 0.0	 7076	 7076	 7076	 0.0	 0.0	 1	 -30.0	 30.0;
	9020	 2350	 0.00017	 0.0025	 0.0	 12606	 12606	 12606	 0.0	 0.0	 1	 -30.0	 30.0;
	6435	 2201	 0.00036	 0.00436	 0.0	 7221	 7221	 7221	 0.0	 0.0	 1	 -30.0	 30.0;
	6435	 3448	 0.00017	 0.00255	 0.0	 12360	 12360	 12360	 0.0	 0.0	 1	 -30.0	 30.0;
	3223	 4642	 0.00096	 0.00995	 0.0	 3761	 3761	 3761	 0.0	 0.0	 1	 -30.0	 30.0;
	3223	 9919	 0.00152	 0.01949	 0.0	 1923	 1923	 1923	 0.0	 0.0	 1	 -30.0	 30.0;
	7755	 4642	 0.00094	 0.01014	 0.0	 3692	 3692	 3692	 0.0	 0.0	 1	 -30.0	 30.0;
	7755	 9919	 0.00149	 0.01986	 0.0	 1888	 1888	 1888	 0.0	 0.0	 1	 -30.0	 30.0;
	4129	 4642	 0.00107	 0.01243	 0.0	 3014	 3014	 3014	 0.0	 0.0	 1	 -30.0	 30.0;
	4129	 3715	 0.00102	 0.01034	 0.0	 3618	 3618	 3618	 0.0	 0.0	 1	 -30.0	 30.0;
	5471	 7106	 0.0047	 0.02061	 0.0	 1495	 1495	 1495	 0.0	 0.0	 1	 -30.0	 30.0;
	5471	 5434	 0.00739	 0.040531	 0.0	 767	 767	 767	 0.0	 0.0	 1	 -30.0	 30.0;
	8834	 12770	 0.00049	 0.00611	 0.0	 6133	 6133	 6133	 0.0	 0.0	 1	 -30.0	 30.0;
	8834	 10744	 0.00035	 0.00431	 0.0	 8694	 8694	 8694	 0.0	 0.0	 1	 -30.0	 30.0;
	7831	 1467	 0.00261	 0.01344	 0.0	 2308	 2308	 2308	 0.0	 0.0	 1	 -30.0	 30.0;
	7831	 5173	 0.003521	 0.019591	 0.0	 1587	 1587	 1587	 0.0	 0.0	 1	 -30.0	 30.0;
	10033	 5005	 0.0025	 0.01419	 0.0	 2193	 2193	 2193	 0.0	 0.0	 1	 -30.0	 30.0;
	10033	 7387	 0.00287	 0.0237	 0.0	 1324	 1324	 1324	 0.0	 0.0	 1	 -30.0	 30.0;
	9789	 9848	 0.00088	 0.00956	 0.0	 3952	 3952	 3952	 0.0	 0.0	 1	 -30.0	 30.0;
	9789	 430	 0.00095	 0.00877	 0.0	 3581	 3581	 3581	 0.0	 0.0	 1	 -30.0	 30.0;
	2916	 1094	 0.00332	 0.020651	 0.0	 1511	 1511	 1511	 0.0	 0.0	 1	 -30.0	 30.0;
	2916	 2869	 0.003969	 0.018781	 0.0	 1646	 1646	 1646	 0.0	 0.0	 1	 -30.0	 30.0;
	4142	 3925	 0.002849	 0.014909	 0.0	 2082	 2082	 2082	 0.0	 0.0	 1	 -30.0	 30.0;
	4142	 2245	 0.00439	 0.02451	 0.0	 1269	 1269	 1269	 0.0	 0.0	 1	 -30.0	 30.0;
	123	 12854	 0.0002	 0.0018	 0.0	 17442	 17442	 17442	 0.0	 0.0	 1	 -30.0	 30.0;
	123	 12369	 0.00025	 0.00261	 0.0	 12048	 12048	 12048	 0.0	 0.0	 1	 -30.0	 30.0;
	10806	 12854	 0.0002	 0.00176	 0.0	 17833	 17833	 17833	 0.0	 0.0	 1	 -30.0	 30.0;
	10806	 1112	 0.00025	 0.00255	 0.0	 12329	 12329	 12329	 0.0	 0.0	 1	 -30.0	 30.0;
	12593	 9027	 0.012488	 0.047413	 0.0	 645	 645	 645	 0.0	 0.0	 1	 -30.0	 30.0;
	12593	 455	 0.010479	 0.027711	 0.0	 1067	 1067	 1067	 0.0	 0.0	 1	 -30.0	 30.0;
	3745	 10922	 0.00044	 0.00428	 0.0	 7342	 7342	 7342	 0.0	 0.0	 1	 -30.0	 30.0;
	3745	 1898	 0.00036	 0.00475	 0.0	 6631	 6631	 6631	 0.0	 0.0	 1	 -30.0	 30.0;
	6938	 7640	 0.00058	 0.00534	 0.0	 5881	 5881	 5881	 0.0	 0.0	 1	 -30.0	 30.0;
	6938	 4543	 0.00054	 0.00589	 0.0	 5341	 5341	 5341	 0.0	 0.0	 1	 -30.0	 30.0;
	4229	 2024	 0.00206	 0.02057	 0.0	 1528	 1528	 1528	 0.0	 0.0	 1	 -30.0	 30.0;
	4229	 9388	 0.00077	 0.00872	 0.0	 3609	 3609	 3609	 0.0	 0.0	 1	 -30.0	 30.0;
	5543	 13575	 0.00161	 0.01963	 0.0	 1604	 1604	 1604	 0.0	 0.0	 1	 -30.0	 30.0;
	5543	 9388	 0.00075	 0.00888	 0.0	 3545	 3545	 3545	 0.0	 0.0	 1	 -30.0	 30.0;
	2764	 10638	 0.00016	 0.00152	 0.0	 20667	 20667	 20667	 0.0	 0.0	 1	 -30.0	 30.0;
	2764	 10338	 0.00019	 0.00163	 0.0	 19249	 19249	 19249	 0.0	 0.0	 1	 -30.0	 30.0;
	7963	 10638	 0.00015	 0.0016	 0.0	 19656	 19656	 19656	 0.0	 0.0	 1	 -30.0	 30.0;
	7963	 10338	 0.00015	 0.00183	 0.0	 17204	 17204	 17204	 0.0	 0.0	 1	 -30.0	 30.0;
	5383	 4802	 0.00121	 0.01426	 0.0	 2208	 2208	 2208	 0.0	 0.0	 1	 -30.0	 30.0;
	5383	 8035	 0.00116	 0.01456	 0.0	 2163	 2163	 2163	 0.0	 0.0	 1	 -30.0	 30.0;
	663	 204	 0.00068	 0.00727	 0.0	 4327	 4327	 4327	 0.0	 0.0	 1	 -30.0	 30.0;
	663	 6973	 0.0007	 0.00734	 0.0	 4285	 4285	 4285	 0.0	 0.0	 1	 -30.0	 30.0;
	11598	 204	 0.00076	 0.00712	 0.0	 4412	 4412	 4412	 0.0	 0.0	 1	 -30.0	 30.0;
	11598	 6973	 0.0008	 0.00719	 0.0	 4367	 4367	 4367	 0.0	 0.0	 1	 -30.0	 30.0;
	2983	 2257	 0.0002	 0.0022	 0.0	 14299	 14299	 14299	 0.0	 0.0	 1	 -30.0	 30.0;
	2983	 10869	 0.0002	 0.0022	 0.0	 14299	 14299	 14299	 0.0	 0.0	 1	 -30.0	 30.0;
	411	 4997	 0.000205	 0.00215	 0.0	 14626	 14626	 14626	 0.0	 0.0	 1	 -30.0	 30.0;
	411	 10869	 0.000205	 0.00215	 0.0	 14626	 14626	 14626	 0.0	 0.0	 1	 -30.0	 30.0;
	8649	 12423	 0.00053	 0.00589	 0.0	 5342	 5342	 5342	 0.0	 0.0	 1	 -30.0	 30.0;
	8649	 1165	 0.00046	 0.00675	 0.0	 4669	 4669	 4669	 0.0	 0.0	 1	 -30.0	 30.0;
	13485	 12423	 0.00054	 0.00577	 0.0	 5451	 5451	 5451	 0.0	 0.0	 1	 -30.0	 30.0;
	13485	 1165	 0.00045	 0.00625	 0.0	 5041	 5041	 5041	 0.0	 0.0	 1	 -30.0	 30.0;
	2363	 2209	 0.00275	 0.02752	 0.0	 1360	 1360	 1360	 0.0	 0.0	 1	 -30.0	 30.0;
	2363	 11249	 0.00184	 0.01515	 0.0	 2464	 2464	 2464	 0.0	 0.0	 1	 -30.0	 30.0;
	3314	 10019	 0.00438	 0.02432	 0.0	 1279	 1279	 1279	 0.0	 0.0	 1	 -30.0	 30.0;
	3314	 879	 0.0043	 0.01949	 0.0	 1583	 1583	 1583	 0.0	 0.0	 1	 -30.0	 30.0;
	12347	 10227	 0.00033	 0.00269	 0.0	 11656	 11656	 11656	 0.0	 0.0	 1	 -30.0	 30.0;
	12347	 2517	 0.00243	 0.01904	 0.0	 1977	 1977	 1977	 0.0	 0.0	 1	 -30.0	 30.0;
	1326	 10227	 0.00034	 0.00263	 0.0	 11912	 11912	 11912	 0.0	 0.0	 1	 -30.0	 30.0;
	1326	 2517	 0.00248	 0.01864	 0.0	 2018	 2018	 2018	 0.0	 0.0	 1	 -30.0	 30.0;
	9864	 13169	 0.00122	 0.01249	 0.0	 2518	 2518	 2518	 0.0	 0.0	 1	 -30.0	 30.0;
	9864	 5959	 0.00106	 0.01031	 0.0	 3048	 3048	 3048	 0.0	 0.0	 1	 -30.0	 30.0;
	4830	 13169	 0.00119	 0.01273	 0.0	 2471	 2471	 2471	 0.0	 0.0	 1	 -30.0	 30.0;
	4830	 5959	 0.00108	 0.01009	 0.0	 3113	 3113	 3113	 0.0	 0.0	 1	 -30.0	 30.0;
	12318	 6464	 0.001039	 0.013711	 0.0	 2298	 2298	 2298	 0.0	 0.0	 1	 -30.0	 30.0;
	12318	 7516	 0.00114	 0.011409	 0.0	 2755	 2755	 2755	 0.0	 0.0	 1	 -30.0	 30.0;
	11537	 8566	 0.001021	 0.013969	 0.0	 2256	 2256	 2256	 0.0	 0.0	 1	 -30.0	 30.0;
	11537	 7516	 0.001169	 0.011159	 0.0	 2816	 2816	 2816	 0.0	 0.0	 1	 -30.0	 30.0;
	13343	 12066	 0.0	 0.000271	 0.0	 116559	 116559	 116559	 0.0	 0.0	 1	 -30.0	 30.0;
	3313	 12066	 0.0	 0.000271	 0.0	 116559	 116559	 116559	 0.0	 0.0	 1	 -30.0	 30.0;
	1196	 218	 0.009372	 0.035702	 0.0	 856	 856	 856	 0.0	 0.0	 1	 -30.0	 30.0;
	1196	 3002	 0.029157	 0.103686	 0.0	 294	 294	 294	 0.0	 0.0	 1	 -30.0	 30.0;
	780	 8041	 0.00065	 0.00673	 0.0	 4672	 4672	 4672	 0.0	 0.0	 1	 -30.0	 30.0;
	780	 6114	 0.00066	 0.00658	 0.0	 4777	 4777	 4777	 0.0	 0.0	 1	 -30.0	 30.0;
	5179	 3568	 0.000969	 0.006021	 0.0	 5180	 5180	 5180	 0.0	 0.0	 1	 -30.0	 30.0;
	5179	 3085	 0.00099	 0.005901	 0.0	 5280	 5280	 5280	 0.0	 0.0	 1	 -30.0	 30.0;
	1666	 7897	 0.00088	 0.006599	 0.0	 4745	 4745	 4745	 0.0	 0.0	 1	 -30.0	 30.0;
	1666	 6301	 0.00086	 0.006729	 0.0	 4657	 4657	 4657	 0.0	 0.0	 1	 -30.0	 30.0;
	12861	 4782	 9e-05	 0.00077	 0.0	 40746	 40746	 40746	 0.0	 0.0	 1	 -30.0	 30.0;
	12861	 6207	 9e-05	 0.00078	 0.0	 40230	 40230	 40230	 0.0	 0.0	 1	 -30.0	 30.0;
	7212	 4782	 8e-05	 0.00082	 0.0	 38340	 38340	 38340	 0.0	 0.0	 1	 -30.0	 30.0;
	7212	 11151	 8e-05	 0.00076	 0.0	 41334	 41334	 41334	 0.0	 0.0	 1	 -30.0	 30.0;
	9869	 8041	 9e-05	 0.00074	 0.0	 42374	 42374	 42374	 0.0	 0.0	 1	 -30.0	 30.0;
	9869	 6207	 9e-05	 0.00073	 0.0	 42946	 42946	 42946	 0.0	 0.0	 1	 -30.0	 30.0;
	6015	 3568	 0.00062	 0.003781	 0.0	 8245	 8245	 8245	 0.0	 0.0	 1	 -30.0	 30.0;
	6015	 1131	 0.000599	 0.0035	 0.0	 8896	 8896	 8896	 0.0	 0.0	 1	 -30.0	 30.0;
	10035	 7897	 0.00064	 0.00274	 0.0	 11227	 11227	 11227	 0.0	 0.0	 1	 -30.0	 30.0;
	10035	 1910	 0.000651	 0.00268	 0.0	 11454	 11454	 11454	 0.0	 0.0	 1	 -30.0	 30.0;
	9951	 1939	 0.00055	 0.00685	 0.0	 4597	 4597	 4597	 0.0	 0.0	 1	 -30.0	 30.0;
	9951	 557	 0.00061	 0.00639	 0.0	 4921	 4921	 4921	 0.0	 0.0	 1	 -30.0	 30.0;
	8771	 8041	 0.00042	 0.00523	 0.0	 6021	 6021	 6021	 0.0	 0.0	 1	 -30.0	 30.0;
	8771	 12272	 0.00045	 0.00605	 0.0	 5207	 5207	 5207	 0.0	 0.0	 1	 -30.0	 30.0;
	8284	 4782	 0.0003	 0.00228	 0.0	 13736	 13736	 13736	 0.0	 0.0	 1	 -30.0	 30.0;
	8284	 13171	 0.00026	 0.00264	 0.0	 11908	 11908	 11908	 0.0	 0.0	 1	 -30.0	 30.0;
	4891	 7738	 0.00536	 0.03568	 0.0	 876	 876	 876	 0.0	 0.0	 1	 -30.0	 30.0;
	4891	 9177	 0.006091	 0.03549	 0.0	 878	 878	 878	 0.0	 0.0	 1	 -30.0	 30.0;
	7982	 7738	 0.006419	 0.033271	 0.0	 933	 933	 933	 0.0	 0.0	 1	 -30.0	 30.0;
	7982	 2109	 0.005789	 0.035901	 0.0	 869	 869	 869	 0.0	 0.0	 1	 -30.0	 30.0;
	10181	 2611	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	10181	 11398	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	13331	 7738	 0.008401	 0.04011	 0.0	 771	 771	 771	 0.0	 0.0	 1	 -30.0	 30.0;
	13331	 4629	 0.007831	 0.041531	 0.0	 748	 748	 748	 0.0	 0.0	 1	 -30.0	 30.0;
	11042	 971	 0.00575	 0.046461	 0.0	 675	 675	 675	 0.0	 0.0	 1	 -30.0	 30.0;
	11042	 9307	 0.006711	 0.04426	 0.0	 706	 706	 706	 0.0	 0.0	 1	 -30.0	 30.0;
	5320	 12300	 0.00036	 0.00485	 0.0	 6495	 6495	 6495	 0.0	 0.0	 1	 -30.0	 30.0;
	5320	 9117	 0.00042	 0.00415	 0.0	 7573	 7573	 7573	 0.0	 0.0	 1	 -30.0	 30.0;
	10275	 2399	 9e-05	 0.00069	 0.0	 45395	 45395	 45395	 0.0	 0.0	 1	 -30.0	 30.0;
	10275	 10873	 4e-05	 0.00036	 0.0	 87206	 87206	 87206	 0.0	 0.0	 1	 -30.0	 30.0;
	11545	 3592	 0.00055	 0.00569	 0.0	 5526	 5526	 5526	 0.0	 0.0	 1	 -30.0	 30.0;
	11545	 10322	 0.0007	 0.00767	 0.0	 4102	 4102	 4102	 0.0	 0.0	 1	 -30.0	 30.0;
	8859	 13646	 0.0013	 0.01299	 0.0	 2880	 2880	 2880	 0.0	 0.0	 1	 -30.0	 30.0;
	4222	 12258	 0.00092	 0.01031	 0.0	 3632	 3632	 3632	 0.0	 0.0	 1	 -30.0	 30.0;
	1576	 13646	 0.00158	 0.01496	 0.0	 2499	 2499	 2499	 0.0	 0.0	 1	 -30.0	 30.0;
	1576	 1624	 0.00123	 0.01309	 0.0	 2860	 2860	 2860	 0.0	 0.0	 1	 -30.0	 30.0;
	5947	 9710	 0.000599	 0.00274	 0.0	 11263	 11263	 11263	 0.0	 0.0	 1	 -30.0	 30.0;
	5947	 10727	 0.0005	 0.00405	 0.0	 7741	 7741	 7741	 0.0	 0.0	 1	 -30.0	 30.0;
	3661	 11493	 0.003349	 0.02445	 0.0	 1280	 1280	 1280	 0.0	 0.0	 1	 -30.0	 30.0;
	3661	 11925	 0.003281	 0.02493	 0.0	 1257	 1257	 1257	 0.0	 0.0	 1	 -30.0	 30.0;
	5848	 5338	 0.00087	 0.01097	 0.0	 3417	 3417	 3417	 0.0	 0.0	 1	 -30.0	 30.0;
	5848	 13272	 0.00161	 0.01464	 0.0	 2576	 2576	 2576	 0.0	 0.0	 1	 -30.0	 30.0;
	8440	 4914	 0.0	 0.00046	 0.0	 68669	 68669	 68669	 0.0	 0.0	 1	 -30.0	 30.0;
	6339	 5430	 0.00118	 0.01223	 0.0	 3060	 3060	 3060	 0.0	 0.0	 1	 -30.0	 30.0;
	6339	 9813	 0.00045	 0.00364	 0.0	 10250	 10250	 10250	 0.0	 0.0	 1	 -30.0	 30.0;
	3407	 2782	 0.00714	 0.03393	 0.0	 912	 912	 912	 0.0	 0.0	 1	 -30.0	 30.0;
	3407	 13262	 0.00655	 0.036849	 0.0	 844	 844	 844	 0.0	 0.0	 1	 -30.0	 30.0;
	11656	 11688	 0.00088	 0.00722	 0.0	 4343	 4343	 4343	 0.0	 0.0	 1	 -30.0	 30.0;
	11656	 9434	 0.00071	 0.00835	 0.0	 3770	 3770	 3770	 0.0	 0.0	 1	 -30.0	 30.0;
	9621	 11688	 0.00084	 0.00705	 0.0	 4450	 4450	 4450	 0.0	 0.0	 1	 -30.0	 30.0;
	9621	 9162	 0.00102	 0.00799	 0.0	 3922	 3922	 3922	 0.0	 0.0	 1	 -30.0	 30.0;
	9337	 8152	 0.003781	 0.029969	 0.0	 1046	 1046	 1046	 0.0	 0.0	 1	 -30.0	 30.0;
	9337	 11977	 0.00386	 0.02969	 0.0	 1056	 1056	 1056	 0.0	 0.0	 1	 -30.0	 30.0;
	9790	 640	 0.00076	 0.00463	 0.0	 6733	 6733	 6733	 0.0	 0.0	 1	 -30.0	 30.0;
	9790	 4131	 0.000711	 0.004841	 0.0	 6456	 6456	 6456	 0.0	 0.0	 1	 -30.0	 30.0;
	7596	 13576	 0.00631	 0.034469	 0.0	 902	 902	 902	 0.0	 0.0	 1	 -30.0	 30.0;
	7596	 11009	 0.006169	 0.03512	 0.0	 886	 886	 886	 0.0	 0.0	 1	 -30.0	 30.0;
	4467	 8002	 0.002961	 0.017651	 0.0	 1765	 1765	 1765	 0.0	 0.0	 1	 -30.0	 30.0;
	4467	 4131	 0.00299	 0.02462	 0.0	 1274	 1274	 1274	 0.0	 0.0	 1	 -30.0	 30.0;
	386	 13576	 0.002789	 0.011659	 0.0	 2635	 2635	 2635	 0.0	 0.0	 1	 -30.0	 30.0;
	386	 9823	 0.00249	 0.013211	 0.0	 2350	 2350	 2350	 0.0	 0.0	 1	 -30.0	 30.0;
	10827	 13576	 0.002669	 0.016031	 0.0	 1944	 1944	 1944	 0.0	 0.0	 1	 -30.0	 30.0;
	10827	 6896	 0.00261	 0.014841	 0.0	 2097	 2097	 2097	 0.0	 0.0	 1	 -30.0	 30.0;
	8613	 13576	 0.00074	 0.004599	 0.0	 6782	 6782	 6782	 0.0	 0.0	 1	 -30.0	 30.0;
	8613	 4717	 0.000719	 0.00468	 0.0	 6672	 6672	 6672	 0.0	 0.0	 1	 -30.0	 30.0;
	2868	 6889	 3.5e-05	 0.000355	 0.0	 105381	 105381	 105381	 0.0	 0.0	 1	 -30.0	 30.0;
	2868	 7065	 3.5e-05	 0.000355	 0.0	 105381	 105381	 105381	 0.0	 0.0	 1	 -30.0	 30.0;
	2031	 372	 0.00511	 0.02949	 0.0	 1056	 1056	 1056	 0.0	 0.0	 1	 -30.0	 30.0;
	2031	 8334	 0.007719	 0.044271	 0.0	 703	 703	 703	 0.0	 0.0	 1	 -30.0	 30.0;
	4223	 372	 0.004281	 0.022469	 0.0	 1381	 1381	 1381	 0.0	 0.0	 1	 -30.0	 30.0;
	4223	 4491	 0.005961	 0.03382	 0.0	 920	 920	 920	 0.0	 0.0	 1	 -30.0	 30.0;
	7174	 6169	 0.00073	 0.01034	 0.0	 3048	 3048	 3048	 0.0	 0.0	 1	 -30.0	 30.0;
	7174	 10838	 0.00076	 0.00889	 0.0	 3541	 3541	 3541	 0.0	 0.0	 1	 -30.0	 30.0;
	3739	 3750	 0.005159	 0.025789	 0.0	 1202	 1202	 1202	 0.0	 0.0	 1	 -30.0	 30.0;
	3739	 13415	 0.00549	 0.027711	 0.0	 1119	 1119	 1119	 0.0	 0.0	 1	 -30.0	 30.0;
	2999	 3750	 0.00614	 0.01764	 0.0	 1692	 1692	 1692	 0.0	 0.0	 1	 -30.0	 30.0;
	2999	 2132	 0.003229	 0.01788	 0.0	 1739	 1739	 1739	 0.0	 0.0	 1	 -30.0	 30.0;
	12353	 7021	 0.00053	 0.00587	 0.0	 5360	 5360	 5360	 0.0	 0.0	 1	 -30.0	 30.0;
	12353	 8085	 0.00055	 0.00666	 0.0	 4727	 4727	 4727	 0.0	 0.0	 1	 -30.0	 30.0;
	8372	 9726	 0.00326	 0.01388	 0.0	 2216	 2216	 2216	 0.0	 0.0	 1	 -30.0	 30.0;
	8372	 5972	 0.003081	 0.01488	 0.0	 2079	 2079	 2079	 0.0	 0.0	 1	 -30.0	 30.0;
	4977	 2449	 0.00051	 0.00614	 0.0	 5127	 5127	 5127	 0.0	 0.0	 1	 -30.0	 30.0;
	4977	 9117	 0.00043	 0.00406	 0.0	 7737	 7737	 7737	 0.0	 0.0	 1	 -30.0	 30.0;
	11807	 9193	 0.00761	 0.046031	 0.0	 678	 678	 678	 0.0	 0.0	 1	 -30.0	 30.0;
	11807	 13362	 0.00351	 0.01632	 0.0	 1893	 1893	 1893	 0.0	 0.0	 1	 -30.0	 30.0;
	7367	 2297	 0.00031	 0.00495	 0.0	 6369	 6369	 6369	 0.0	 0.0	 1	 -30.0	 30.0;
	7367	 13504	 0.00043	 0.00485	 0.0	 6488	 6488	 6488	 0.0	 0.0	 1	 -30.0	 30.0;
	13361	 210	 0.00426	 0.027099	 0.0	 1152	 1152	 1152	 0.0	 0.0	 1	 -30.0	 30.0;
	13361	 8579	 0.00437	 0.024969	 0.0	 1247	 1247	 1247	 0.0	 0.0	 1	 -30.0	 30.0;
	8856	 11596	 0.005	 0.03932	 0.0	 797	 797	 797	 0.0	 0.0	 1	 -30.0	 30.0;
	8856	 10943	 0.006039	 0.036789	 0.0	 848	 848	 848	 0.0	 0.0	 1	 -30.0	 30.0;
	12165	 8452	 0.0009	 0.00893	 0.0	 4189	 4189	 4189	 0.0	 0.0	 1	 -30.0	 30.0;
	12165	 10718	 0.00286	 0.02156	 0.0	 1729	 1729	 1729	 0.0	 0.0	 1	 -30.0	 30.0;
	991	 210	 0.00418	 0.022729	 0.0	 1367	 1367	 1367	 0.0	 0.0	 1	 -30.0	 30.0;
	991	 8264	 0.00405	 0.02231	 0.0	 1394	 1394	 1394	 0.0	 0.0	 1	 -30.0	 30.0;
	10687	 7078	 0.00013	 0.00675	 0.0	 4679	 4679	 4679	 0.0	 0.0	 1	 -30.0	 30.0;
	10687	 1766	 0.00013	 0.00688	 0.0	 4591	 4591	 4591	 0.0	 0.0	 1	 -30.0	 30.0;
	13494	 6000	 0.00078	 0.01201	 0.0	 2625	 2625	 2625	 0.0	 0.0	 1	 -30.0	 30.0;
	13494	 9558	 0.00075	 0.01254	 0.0	 2515	 2515	 2515	 0.0	 0.0	 1	 -30.0	 30.0;
	3322	 4944	 0.00071	 0.00722	 0.0	 4354	 4354	 4354	 0.0	 0.0	 1	 -30.0	 30.0;
	3322	 6366	 0.00084	 0.0074	 0.0	 4242	 4242	 4242	 0.0	 0.0	 1	 -30.0	 30.0;
	6082	 13221	 0.00105	 0.0081	 0.0	 3868	 3868	 3868	 0.0	 0.0	 1	 -30.0	 30.0;
	6082	 11561	 0.00203	 0.01565	 0.0	 2002	 2002	 2002	 0.0	 0.0	 1	 -30.0	 30.0;
	12539	 2263	 0.00035	 0.00581	 0.0	 5427	 5427	 5427	 0.0	 0.0	 1	 -30.0	 30.0;
	12539	 3777	 0.00045	 0.00534	 0.0	 5895	 5895	 5895	 0.0	 0.0	 1	 -30.0	 30.0;
	12308	 11016	 8.1e-05	 0.001331	 0.0	 23689	 23689	 23689	 0.0	 0.0	 1	 -30.0	 30.0;
	12308	 9194	 0.00025	 0.001591	 0.0	 19614	 19614	 19614	 0.0	 0.0	 1	 -30.0	 30.0;
	10168	 3267	 0.00401	 0.026219	 0.0	 1191	 1191	 1191	 0.0	 0.0	 1	 -30.0	 30.0;
	10168	 10943	 0.004669	 0.027521	 0.0	 1132	 1132	 1132	 0.0	 0.0	 1	 -30.0	 30.0;
	460	 12666	 0.00115	 0.01265	 0.0	 2960	 2960	 2960	 0.0	 0.0	 1	 -30.0	 30.0;
	460	 1925	 0.00112	 0.0129	 0.0	 2904	 2904	 2904	 0.0	 0.0	 1	 -30.0	 30.0;
	11384	 10686	 0.00123	 0.01589	 0.0	 1982	 1982	 1982	 0.0	 0.0	 1	 -30.0	 30.0;
	11384	 11561	 0.00054	 0.00484	 0.0	 6487	 6487	 6487	 0.0	 0.0	 1	 -30.0	 30.0;
	5551	 2914	 0.00401	 0.03961	 0.0	 794	 794	 794	 0.0	 0.0	 1	 -30.0	 30.0;
	5551	 12265	 0.002909	 0.01981	 0.0	 1578	 1578	 1578	 0.0	 0.0	 1	 -30.0	 30.0;
	1418	 8986	 0.002211	 0.014419	 0.0	 2166	 2166	 2166	 0.0	 0.0	 1	 -30.0	 30.0;
	1418	 4609	 0.002169	 0.013349	 0.0	 2336	 2336	 2336	 0.0	 0.0	 1	 -30.0	 30.0;
	5389	 12666	 0.00055	 0.00508	 0.0	 7357	 7357	 7357	 0.0	 0.0	 1	 -30.0	 30.0;
	5389	 1255	 0.00046	 0.00595	 0.0	 6358	 6358	 6358	 0.0	 0.0	 1	 -30.0	 30.0;
	4132	 10934	 0.00201	 0.00988	 0.0	 3133	 3133	 3133	 0.0	 0.0	 1	 -30.0	 30.0;
	4132	 3129	 0.003401	 0.019099	 0.0	 1629	 1629	 1629	 0.0	 0.0	 1	 -30.0	 30.0;
	2817	 992	 0.00028	 0.00308	 0.0	 10214	 10214	 10214	 0.0	 0.0	 1	 -30.0	 30.0;
	2817	 8261	 0.00038	 0.00307	 0.0	 10212	 10212	 10212	 0.0	 0.0	 1	 -30.0	 30.0;
	7950	 6182	 0.00044	 0.00577	 0.0	 6497	 6497	 6497	 0.0	 0.0	 1	 -30.0	 30.0;
	7950	 9582	 0.00102	 0.01295	 0.0	 2894	 2894	 2894	 0.0	 0.0	 1	 -30.0	 30.0;
	8170	 2362	 0.00085	 0.01005	 0.0	 3132	 3132	 3132	 0.0	 0.0	 1	 -30.0	 30.0;
	8170	 8003	 0.00073	 0.0097	 0.0	 3248	 3248	 3248	 0.0	 0.0	 1	 -30.0	 30.0;
	11189	 10774	 0.00139	 0.0126	 0.0	 2492	 2492	 2492	 0.0	 0.0	 1	 -30.0	 30.0;
	11189	 8008	 0.00117	 0.01389	 0.0	 2267	 2267	 2267	 0.0	 0.0	 1	 -30.0	 30.0;
	9620	 2145	 0.00076	 0.00908	 0.0	 3467	 3467	 3467	 0.0	 0.0	 1	 -30.0	 30.0;
	9620	 12632	 0.00137	 0.01338	 0.0	 2349	 2349	 2349	 0.0	 0.0	 1	 -30.0	 30.0;
	12114	 3721	 0.006	 0.0402	 0.0	 778	 778	 778	 0.0	 0.0	 1	 -30.0	 30.0;
	12114	 6284	 0.005719	 0.03906	 0.0	 801	 801	 801	 0.0	 0.0	 1	 -30.0	 30.0;
	3244	 10774	 0.0007	 0.01065	 0.0	 2960	 2960	 2960	 0.0	 0.0	 1	 -30.0	 30.0;
	3244	 3272	 0.00066	 0.01062	 0.0	 2969	 2969	 2969	 0.0	 0.0	 1	 -30.0	 30.0;
	6020	 494	 0.00153	 0.01695	 0.0	 2209	 2209	 2209	 0.0	 0.0	 1	 -30.0	 30.0;
	6020	 8891	 0.00083	 0.00925	 0.0	 4048	 4048	 4048	 0.0	 0.0	 1	 -30.0	 30.0;
	12682	 7713	 0.00033	 0.00101	 0.0	 29729	 29729	 29729	 0.0	 0.0	 1	 -30.0	 30.0;
	11711	 7713	 0.00028	 0.00104	 0.0	 29329	 29329	 29329	 0.0	 0.0	 1	 -30.0	 30.0;
	1504	 884	 0.00139	 0.0125	 0.0	 2989	 2989	 2989	 0.0	 0.0	 1	 -30.0	 30.0;
	1504	 5821	 0.00119	 0.01236	 0.0	 3028	 3028	 3028	 0.0	 0.0	 1	 -30.0	 30.0;
	3381	 12919	 0.010099	 0.05513	 0.0	 564	 564	 564	 0.0	 0.0	 1	 -30.0	 30.0;
	3381	 879	 0.00464	 0.027021	 0.0	 1153	 1153	 1153	 0.0	 0.0	 1	 -30.0	 30.0;
	7853	 6824	 0.002211	 0.012031	 0.0	 2583	 2583	 2583	 0.0	 0.0	 1	 -30.0	 30.0;
	7853	 5972	 0.002479	 0.0115	 0.0	 2686	 2686	 2686	 0.0	 0.0	 1	 -30.0	 30.0;
	8048	 4231	 0.030281	 0.058314	 0.0	 481	 481	 481	 0.0	 0.0	 1	 -30.0	 30.0;
	8048	 174	 0.028174	 0.054256	 0.0	 517	 517	 517	 0.0	 0.0	 1	 -30.0	 30.0;
	1392	 4231	 0.01114	 0.026231	 0.0	 1109	 1109	 1109	 0.0	 0.0	 1	 -30.0	 30.0;
	1392	 3084	 0.018157	 0.045248	 0.0	 648	 648	 648	 0.0	 0.0	 1	 -30.0	 30.0;
	9306	 524	 0.00369	 0.017159	 0.0	 1800	 1800	 1800	 0.0	 0.0	 1	 -30.0	 30.0;
	9306	 11008	 0.004909	 0.03018	 0.0	 1034	 1034	 1034	 0.0	 0.0	 1	 -30.0	 30.0;
	12771	 10677	 0.00408	 0.0056	 0.0	 5426	 5426	 5426	 0.0	 0.0	 1	 -30.0	 30.0;
	12771	 11249	 0.00301	 0.00925	 0.0	 3865	 3865	 3865	 0.0	 0.0	 1	 -30.0	 30.0;
	6857	 524	 0.001599	 0.00489	 0.0	 6140	 6140	 6140	 0.0	 0.0	 1	 -30.0	 30.0;
	6857	 9037	 0.00031	 0.00175	 0.0	 17774	 17774	 17774	 0.0	 0.0	 1	 -30.0	 30.0;
	8995	 524	 0.00163	 0.004789	 0.0	 6245	 6245	 6245	 0.0	 0.0	 1	 -30.0	 30.0;
	8995	 9037	 0.00031	 0.001789	 0.0	 17398	 17398	 17398	 0.0	 0.0	 1	 -30.0	 30.0;
	4390	 4711	 0.00988	 0.063229	 0.0	 494	 494	 494	 0.0	 0.0	 1	 -30.0	 30.0;
	4390	 2245	 0.00114	 0.00638	 0.0	 4874	 4874	 4874	 0.0	 0.0	 1	 -30.0	 30.0;
	993	 10347	 0.00065	 0.00755	 0.0	 4169	 4169	 4169	 0.0	 0.0	 1	 -30.0	 30.0;
	993	 10709	 0.00052	 0.00503	 0.0	 6247	 6247	 6247	 0.0	 0.0	 1	 -30.0	 30.0;
	826	 10347	 0.00063	 0.0077	 0.0	 4089	 4089	 4089	 0.0	 0.0	 1	 -30.0	 30.0;
	826	 10709	 0.00053	 0.00493	 0.0	 6371	 6371	 6371	 0.0	 0.0	 1	 -30.0	 30.0;
	3394	 4877	 0.00055	 0.00683	 0.0	 4610	 4610	 4610	 0.0	 0.0	 1	 -30.0	 30.0;
	3394	 12158	 0.00118	 0.01134	 0.0	 2771	 2771	 2771	 0.0	 0.0	 1	 -30.0	 30.0;
	9489	 4877	 0.00056	 0.00668	 0.0	 4713	 4713	 4713	 0.0	 0.0	 1	 -30.0	 30.0;
	9489	 12158	 0.0012	 0.0111	 0.0	 2830	 2830	 2830	 0.0	 0.0	 1	 -30.0	 30.0;
	9708	 13164	 0.0098	 0.01047	 0.0	 2622	 2622	 2622	 0.0	 0.0	 1	 -30.0	 30.0;
	9708	 4642	 0.00134	 0.01215	 0.0	 3076	 3076	 3076	 0.0	 0.0	 1	 -30.0	 30.0;
	9498	 13164	 0.00092	 0.01198	 0.0	 3129	 3129	 3129	 0.0	 0.0	 1	 -30.0	 30.0;
	9498	 3715	 0.00057	 0.00616	 0.0	 6077	 6077	 6077	 0.0	 0.0	 1	 -30.0	 30.0;
	12196	 10919	 0.00108	 0.01773	 0.0	 2117	 2117	 2117	 0.0	 0.0	 1	 -30.0	 30.0;
	12196	 5789	 0.00064	 0.01047	 0.0	 3584	 3584	 3584	 0.0	 0.0	 1	 -30.0	 30.0;
	535	 11908	 0.002211	 0.013341	 0.0	 2336	 2336	 2336	 0.0	 0.0	 1	 -30.0	 30.0;
	535	 140	 0.001901	 0.014229	 0.0	 2201	 2201	 2201	 0.0	 0.0	 1	 -30.0	 30.0;
	7945	 1076	 0.00193	 0.011771	 0.0	 2649	 2649	 2649	 0.0	 0.0	 1	 -30.0	 30.0;
	7945	 12534	 0.00251	 0.014909	 0.0	 2090	 2090	 2090	 0.0	 0.0	 1	 -30.0	 30.0;
	9005	 892	 6e-05	 0.00084	 0.0	 37509	 37509	 37509	 0.0	 0.0	 1	 -30.0	 30.0;
	9005	 1766	 6e-05	 0.00092	 0.0	 34262	 34262	 34262	 0.0	 0.0	 1	 -30.0	 30.0;
	12416	 8601	 0.00138	 0.010349	 0.0	 3026	 3026	 3026	 0.0	 0.0	 1	 -30.0	 30.0;
	12416	 10021	 0.00156	 0.009151	 0.0	 3403	 3403	 3403	 0.0	 0.0	 1	 -30.0	 30.0;
	9221	 8601	 0.001349	 0.010539	 0.0	 2973	 2973	 2973	 0.0	 0.0	 1	 -30.0	 30.0;
	9221	 10021	 0.001591	 0.00895	 0.0	 3475	 3475	 3475	 0.0	 0.0	 1	 -30.0	 30.0;
	8515	 2315	 0.0	 0.000271	 0.0	 116559	 116559	 116559	 0.0	 0.0	 1	 -30.0	 30.0;
	6403	 6614	 0.00057	 0.0071	 0.0	 4435	 4435	 4435	 0.0	 0.0	 1	 -30.0	 30.0;
	6403	 9117	 0.00057	 0.00697	 0.0	 4517	 4517	 4517	 0.0	 0.0	 1	 -30.0	 30.0;
	9514	 6056	 0.000969	 0.00743	 0.0	 4216	 4216	 4216	 0.0	 0.0	 1	 -30.0	 30.0;
	9514	 7101	 0.00099	 0.007271	 0.0	 4305	 4305	 4305	 0.0	 0.0	 1	 -30.0	 30.0;
	1452	 6056	 0.00088	 0.00824	 0.0	 3812	 3812	 3812	 0.0	 0.0	 1	 -30.0	 30.0;
	1452	 7101	 0.00086	 0.008401	 0.0	 3741	 3741	 3741	 0.0	 0.0	 1	 -30.0	 30.0;
	5682	 5452	 0.00293	 0.01664	 0.0	 1870	 1870	 1870	 0.0	 0.0	 1	 -30.0	 30.0;
	5682	 11733	 0.008719	 0.05249	 0.0	 594	 594	 594	 0.0	 0.0	 1	 -30.0	 30.0;
	4825	 2456	 0.00057	 0.00627	 0.0	 5018	 5018	 5018	 0.0	 0.0	 1	 -30.0	 30.0;
	4825	 11561	 0.00088	 0.00878	 0.0	 3580	 3580	 3580	 0.0	 0.0	 1	 -30.0	 30.0;
	13359	 326	 0.00033	 0.00421	 0.0	 7480	 7480	 7480	 0.0	 0.0	 1	 -30.0	 30.0;
	13359	 12737	 0.00084	 0.00353	 0.0	 8706	 8706	 8706	 0.0	 0.0	 1	 -30.0	 30.0;
	624	 11012	 0.0001	 0.00119	 0.0	 26451	 26451	 26451	 0.0	 0.0	 1	 -30.0	 30.0;
	624	 8261	 0.0001	 0.0013	 0.0	 24227	 24227	 24227	 0.0	 0.0	 1	 -30.0	 30.0;
	7026	 7780	 9e-05	 0.00121	 0.0	 26034	 26034	 26034	 0.0	 0.0	 1	 -30.0	 30.0;
	7026	 6366	 0.0001	 0.00134	 0.0	 23508	 23508	 23508	 0.0	 0.0	 1	 -30.0	 30.0;
	4755	 4357	 0.00063	 0.01067	 0.0	 2956	 2956	 2956	 0.0	 0.0	 1	 -30.0	 30.0;
	4755	 3462	 0.00073	 0.00959	 0.0	 3285	 3285	 3285	 0.0	 0.0	 1	 -30.0	 30.0;
	10662	 5711	 0.002021	 0.030271	 0.0	 1042	 1042	 1042	 0.0	 0.0	 1	 -30.0	 30.0;
	10662	 7437	 0.00218	 0.02786	 0.0	 1131	 1131	 1131	 0.0	 0.0	 1	 -30.0	 30.0;
	7214	 4357	 0.00086	 0.00781	 0.0	 4021	 4021	 4021	 0.0	 0.0	 1	 -30.0	 30.0;
	7214	 6268	 0.00092	 0.00666	 0.0	 4699	 4699	 4699	 0.0	 0.0	 1	 -30.0	 30.0;
	8164	 5711	 0.003969	 0.0272	 0.0	 1150	 1150	 1150	 0.0	 0.0	 1	 -30.0	 30.0;
	8164	 8677	 0.00311	 0.029729	 0.0	 1057	 1057	 1057	 0.0	 0.0	 1	 -30.0	 30.0;
	12629	 4357	 0.00055	 0.00837	 0.0	 3766	 3766	 3766	 0.0	 0.0	 1	 -30.0	 30.0;
	12629	 4831	 0.00053	 0.0084	 0.0	 3753	 3753	 3753	 0.0	 0.0	 1	 -30.0	 30.0;
	7840	 4357	 0.00053	 0.00853	 0.0	 3696	 3696	 3696	 0.0	 0.0	 1	 -30.0	 30.0;
	7840	 4831	 0.00052	 0.00778	 0.0	 4052	 4052	 4052	 0.0	 0.0	 1	 -30.0	 30.0;
	11317	 5711	 0.0017	 0.008159	 0.0	 3791	 3791	 3791	 0.0	 0.0	 1	 -30.0	 30.0;
	11317	 11518	 0.001729	 0.00799	 0.0	 3864	 3864	 3864	 0.0	 0.0	 1	 -30.0	 30.0;
	3240	 5711	 0.00176	 0.00781	 0.0	 3946	 3946	 3946	 0.0	 0.0	 1	 -30.0	 30.0;
	3240	 11518	 0.00157	 0.008849	 0.0	 3515	 3515	 3515	 0.0	 0.0	 1	 -30.0	 30.0;
	1135	 5711	 0.000219	 0.002229	 0.0	 14104	 14104	 14104	 0.0	 0.0	 1	 -30.0	 30.0;
	1135	 7516	 0.000229	 0.00218	 0.0	 14411	 14411	 14411	 0.0	 0.0	 1	 -30.0	 30.0;
	2781	 5711	 0.000229	 0.00213	 0.0	 14745	 14745	 14745	 0.0	 0.0	 1	 -30.0	 30.0;
	2781	 7516	 0.000211	 0.002419	 0.0	 13009	 13009	 13009	 0.0	 0.0	 1	 -30.0	 30.0;
	6505	 5711	 0.00019	 0.00255	 0.0	 12353	 12353	 12353	 0.0	 0.0	 1	 -30.0	 30.0;
	6505	 7516	 0.000211	 0.0025	 0.0	 12591	 12591	 12591	 0.0	 0.0	 1	 -30.0	 30.0;
	12092	 5711	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	12092	 5740	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	2757	 11750	 0.00067	 0.01058	 0.0	 2980	 2980	 2980	 0.0	 0.0	 1	 -30.0	 30.0;
	2757	 10922	 0.00065	 0.01078	 0.0	 2925	 2925	 2925	 0.0	 0.0	 1	 -30.0	 30.0;
	5460	 404	 0.009281	 0.05299	 0.0	 588	 588	 588	 0.0	 0.0	 1	 -30.0	 30.0;
	5460	 13262	 0.009419	 0.057219	 0.0	 545	 545	 545	 0.0	 0.0	 1	 -30.0	 30.0;
	7572	 3427	 0.00055	 0.00505	 0.0	 6219	 6219	 6219	 0.0	 0.0	 1	 -30.0	 30.0;
	7572	 9194	 9.9e-05	 0.00164	 0.0	 19226	 19226	 19226	 0.0	 0.0	 1	 -30.0	 30.0;
	11268	 11750	 0.00064	 0.00998	 0.0	 3159	 3159	 3159	 0.0	 0.0	 1	 -30.0	 30.0;
	11268	 3389	 0.00216	 0.02943	 0.0	 1071	 1071	 1071	 0.0	 0.0	 1	 -30.0	 30.0;
	7272	 3049	 0.00039	 0.00474	 0.0	 6642	 6642	 6642	 0.0	 0.0	 1	 -30.0	 30.0;
	7272	 2493	 0.00045	 0.00467	 0.0	 6733	 6733	 6733	 0.0	 0.0	 1	 -30.0	 30.0;
	11286	 3049	 0.00052	 0.00567	 0.0	 5548	 5548	 5548	 0.0	 0.0	 1	 -30.0	 30.0;
	11286	 2409	 0.00054	 0.00667	 0.0	 4721	 4721	 4721	 0.0	 0.0	 1	 -30.0	 30.0;
	6560	 6485	 0.008909	 0.042349	 0.0	 730	 730	 730	 0.0	 0.0	 1	 -30.0	 30.0;
	6560	 12261	 0.00713	 0.03293	 0.0	 938	 938	 938	 0.0	 0.0	 1	 -30.0	 30.0;
	13149	 2024	 0.0021	 0.02015	 0.0	 1560	 1560	 1560	 0.0	 0.0	 1	 -30.0	 30.0;
	13149	 13575	 0.00177	 0.02084	 0.0	 1511	 1511	 1511	 0.0	 0.0	 1	 -30.0	 30.0;
	9609	 249	 0.001461	 0.00781	 0.0	 3976	 3976	 3976	 0.0	 0.0	 1	 -30.0	 30.0;
	9609	 8612	 0.001651	 0.007651	 0.0	 4036	 4036	 4036	 0.0	 0.0	 1	 -30.0	 30.0;
	12837	 249	 0.00168	 0.0075	 0.0	 4110	 4110	 4110	 0.0	 0.0	 1	 -30.0	 30.0;
	12837	 8612	 0.001719	 0.007341	 0.0	 4190	 4190	 4190	 0.0	 0.0	 1	 -30.0	 30.0;
	11653	 10180	 0.00626	 0.020771	 0.0	 1457	 1457	 1457	 0.0	 0.0	 1	 -30.0	 30.0;
	11653	 10180	 0.00638	 0.02032	 0.0	 1484	 1484	 1484	 0.0	 0.0	 1	 -30.0	 30.0;
	111	 1302	 0.047983	 0.076364	 0.0	 351	 351	 351	 0.0	 0.0	 1	 -30.0	 30.0;
	111	 2235	 0.010868	 0.039083	 0.0	 779	 779	 779	 0.0	 0.0	 1	 -30.0	 30.0;
	6531	 5081	 0.021851	 0.032364	 0.0	 809	 809	 809	 0.0	 0.0	 1	 -30.0	 30.0;
	10859	 5081	 0.075008	 0.121636	 0.0	 222	 222	 222	 0.0	 0.0	 1	 -30.0	 30.0;
	5081	 7553	 0.049273	 0.084942	 0.0	 322	 322	 322	 0.0	 0.0	 1	 -30.0	 30.0;
	8666	 8494	 0.058521	 0.110017	 0.0	 254	 254	 254	 0.0	 0.0	 1	 -30.0	 30.0;
	11001	 9689	 0.012992	 0.052719	 0.0	 582	 582	 582	 0.0	 0.0	 1	 -30.0	 30.0;
	9689	 11001	 0.012727	 0.053752	 0.0	 572	 572	 572	 0.0	 0.0	 1	 -30.0	 30.0;
	6310	 3549	 0.013341	 0.054169	 0.0	 567	 567	 567	 0.0	 0.0	 1	 -30.0	 30.0;
	7106	 6310	 0.014961	 0.083521	 0.0	 373	 373	 373	 0.0	 0.0	 1	 -30.0	 30.0;
	10458	 2358	 0.023653	 0.033603	 0.0	 769	 769	 769	 0.0	 0.0	 1	 -30.0	 30.0;
	10458	 2358	 0.024099	 0.032876	 0.0	 775	 775	 775	 0.0	 0.0	 1	 -30.0	 30.0;
	2358	 11001	 0.024934	 0.109579	 0.0	 282	 282	 282	 0.0	 0.0	 1	 -30.0	 30.0;
	2358	 11001	 0.024397	 0.111653	 0.0	 277	 277	 277	 0.0	 0.0	 1	 -30.0	 30.0;
	2358	 8780	 0.03414	 0.051058	 0.0	 515	 515	 515	 0.0	 0.0	 1	 -30.0	 30.0;
	1302	 6531	 0.018893	 0.029083	 0.0	 911	 911	 911	 0.0	 0.0	 1	 -30.0	 30.0;
	3549	 8241	 0.000581	 0.003081	 0.0	 10075	 10075	 10075	 0.0	 0.0	 1	 -30.0	 30.0;
	3549	 8241	 0.0005	 0.002789	 0.0	 11148	 11148	 11148	 0.0	 0.0	 1	 -30.0	 30.0;
	3549	 2972	 0.009281	 0.03489	 0.0	 875	 875	 875	 0.0	 0.0	 1	 -30.0	 30.0;
	8720	 3549	 0.006081	 0.034	 0.0	 915	 915	 915	 0.0	 0.0	 1	 -30.0	 30.0;
	8720	 3549	 0.00595	 0.034651	 0.0	 899	 899	 899	 0.0	 0.0	 1	 -30.0	 30.0;
	2421	 10458	 0.05019	 0.076339	 0.0	 346	 346	 346	 0.0	 0.0	 1	 -30.0	 30.0;
	10458	 5586	 0.05724	 0.101868	 0.0	 271	 271	 271	 0.0	 0.0	 1	 -30.0	 30.0;
	12153	 10717	 0.0013	 0.01496	 0.0	 2504	 2504	 2504	 0.0	 0.0	 1	 -30.0	 30.0;
	2209	 12153	 0.00108	 0.01115	 0.0	 3356	 3356	 3356	 0.0	 0.0	 1	 -30.0	 30.0;
	12153	 850	 0.00223	 0.02267	 0.0	 1651	 1651	 1651	 0.0	 0.0	 1	 -30.0	 30.0;
	11653	 2972	 0.008229	 0.03325	 0.0	 923	 923	 923	 0.0	 0.0	 1	 -30.0	 30.0;
	11653	 8698	 0.018159	 0.06526	 0.0	 467	 467	 467	 0.0	 0.0	 1	 -30.0	 30.0;
	10859	 13562	 0.02257	 0.034777	 0.0	 762	 762	 762	 0.0	 0.0	 1	 -30.0	 30.0;
	10859	 3783	 0.032339	 0.103017	 0.0	 293	 293	 293	 0.0	 0.0	 1	 -30.0	 30.0;
	10859	 3783	 0.031678	 0.105041	 0.0	 288	 288	 288	 0.0	 0.0	 1	 -30.0	 30.0;
	10859	 1184	 0.028331	 0.050182	 0.0	 549	 549	 549	 0.0	 0.0	 1	 -30.0	 30.0;
	10859	 1302	 0.047314	 0.063678	 0.0	 399	 399	 399	 0.0	 0.0	 1	 -30.0	 30.0;
	7106	 10559	 0.0045	 0.02618	 0.0	 1190	 1190	 1190	 0.0	 0.0	 1	 -30.0	 30.0;
	7106	 8720	 0.01913	 0.10681	 0.0	 292	 292	 292	 0.0	 0.0	 1	 -30.0	 30.0;
	12213	 8666	 0.059273	 0.08086	 0.0	 316	 316	 316	 0.0	 0.0	 1	 -30.0	 30.0;
	2530	 12344	 0.008041	 0.014298	 0.0	 1926	 1926	 1926	 0.0	 0.0	 1	 -30.0	 30.0;
	6827	 2530	 0.047802	 0.073562	 0.0	 361	 361	 361	 0.0	 0.0	 1	 -30.0	 30.0;
	5477	 2421	 0.049636	 0.058818	 0.0	 411	 411	 411	 0.0	 0.0	 1	 -30.0	 30.0;
	13562	 2235	 0.04738	 0.075992	 0.0	 353	 353	 353	 0.0	 0.0	 1	 -30.0	 30.0;
	8780	 13068	 0.035603	 0.045331	 0.0	 549	 549	 549	 0.0	 0.0	 1	 -30.0	 30.0;
	4150	 7553	 0.024529	 0.031678	 0.0	 789	 789	 789	 0.0	 0.0	 1	 -30.0	 30.0;
	13157	 4150	 0.036851	 0.047521	 0.0	 526	 526	 526	 0.0	 0.0	 1	 -30.0	 30.0;
	9286	 12283	 0.004058	 0.011041	 0.0	 2686	 2686	 2686	 0.0	 0.0	 1	 -30.0	 30.0;
	6779	 9286	 0.012818	 0.022554	 0.0	 1218	 1218	 1218	 0.0	 0.0	 1	 -30.0	 30.0;
	6672	 2361	 0.079256	 0.118479	 0.0	 222	 222	 222	 0.0	 0.0	 1	 -30.0	 30.0;
	6779	 6672	 0.012554	 0.022967	 0.0	 1207	 1207	 1207	 0.0	 0.0	 1	 -30.0	 30.0;
	12283	 11915	 0.007917	 0.029628	 0.0	 1030	 1030	 1030	 0.0	 0.0	 1	 -30.0	 30.0;
	12283	 11915	 0.007744	 0.027438	 0.0	 1108	 1108	 1108	 0.0	 0.0	 1	 -30.0	 30.0;
	2209	 5117	 0.00039	 0.00461	 0.0	 8126	 8126	 8126	 0.0	 0.0	 1	 -30.0	 30.0;
	10559	 414	 0.014039	 0.071669	 0.0	 433	 433	 433	 0.0	 0.0	 1	 -30.0	 30.0;
	10559	 414	 0.01251	 0.081219	 0.0	 385	 385	 385	 0.0	 0.0	 1	 -30.0	 30.0;
	414	 8698	 0.0045	 0.016831	 0.0	 1814	 1814	 1814	 0.0	 0.0	 1	 -30.0	 30.0;
	8720	 414	 0.00261	 0.009401	 0.0	 3238	 3238	 3238	 0.0	 0.0	 1	 -30.0	 30.0;
	10560	 3783	 0.08024	 0.135628	 0.0	 201	 201	 201	 0.0	 0.0	 1	 -30.0	 30.0;
	6348	 10560	 0.043587	 0.057314	 0.0	 439	 439	 439	 0.0	 0.0	 1	 -30.0	 30.0;
	10559	 119	 0.00326	 0.01895	 0.0	 1643	 1643	 1643	 0.0	 0.0	 1	 -30.0	 30.0;
	1076	 119	 0.005409	 0.02675	 0.0	 1158	 1158	 1158	 0.0	 0.0	 1	 -30.0	 30.0;
	12344	 4935	 0.083537	 0.116554	 0.0	 221	 221	 221	 0.0	 0.0	 1	 -30.0	 30.0;
	3658	 4935	 0.012463	 0.054793	 0.0	 563	 563	 563	 0.0	 0.0	 1	 -30.0	 30.0;
	1184	 13068	 0.044992	 0.07586	 0.0	 359	 359	 359	 0.0	 0.0	 1	 -30.0	 30.0;
	10482	 2361	 0.032777	 0.050628	 0.0	 524	 524	 524	 0.0	 0.0	 1	 -30.0	 30.0;
	5586	 6827	 0.060314	 0.092818	 0.0	 286	 286	 286	 0.0	 0.0	 1	 -30.0	 30.0;
	13157	 12213	 0.02462	 0.034967	 0.0	 739	 739	 739	 0.0	 0.0	 1	 -30.0	 30.0;
	11915	 5477	 0.026603	 0.03038	 0.0	 783	 783	 783	 0.0	 0.0	 1	 -30.0	 30.0;
	50	 7481	 0.01595	 0.022281	 0.0	 1153	 1153	 1153	 0.0	 0.0	 1	 -30.0	 30.0;
	10482	 7481	 0.018083	 0.021843	 0.0	 1114	 1114	 1114	 0.0	 0.0	 1	 -30.0	 30.0;
	119	 8720	 0.0132	 0.06293	 0.0	 492	 492	 492	 0.0	 0.0	 1	 -30.0	 30.0;
	119	 8720	 0.01345	 0.06162	 0.0	 501	 501	 501	 0.0	 0.0	 1	 -30.0	 30.0;
	6779	 5477	 0.010612	 0.023017	 0.0	 1247	 1247	 1247	 0.0	 0.0	 1	 -30.0	 30.0;
	1409	 11040	 0.01601	 0.06706	 0.0	 459	 459	 459	 0.0	 0.0	 1	 -30.0	 30.0;
	1409	 8152	 0.00362	 0.01457	 0.0	 2105	 2105	 2105	 0.0	 0.0	 1	 -30.0	 30.0;
	2043	 6999	 0.010281	 0.04007	 0.0	 764	 764	 764	 0.0	 0.0	 1	 -30.0	 30.0;
	2043	 13576	 0.01549	 0.06756	 0.0	 456	 456	 456	 0.0	 0.0	 1	 -30.0	 30.0;
	2594	 7565	 0.00073	 0.01141	 0.0	 2763	 2763	 2763	 0.0	 0.0	 1	 -30.0	 30.0;
	2594	 11750	 0.00108	 0.01698	 0.0	 1857	 1857	 1857	 0.0	 0.0	 1	 -30.0	 30.0;
	4109	 756	 0.0022	 0.027409	 0.0	 1149	 1149	 1149	 0.0	 0.0	 1	 -30.0	 30.0;
	4109	 756	 0.002151	 0.02794	 0.0	 1128	 1128	 1128	 0.0	 0.0	 1	 -30.0	 30.0;
	4109	 11112	 0.00445	 0.02582	 0.0	 1206	 1206	 1206	 0.0	 0.0	 1	 -30.0	 30.0;
	4109	 404	 0.005099	 0.02426	 0.0	 1275	 1275	 1275	 0.0	 0.0	 1	 -30.0	 30.0;
	4109	 2461	 0.019539	 0.100021	 0.0	 310	 310	 310	 0.0	 0.0	 1	 -30.0	 30.0;
	4109	 2461	 0.01914	 0.101979	 0.0	 305	 305	 305	 0.0	 0.0	 1	 -30.0	 30.0;
	7565	 3133	 0.00158	 0.02551	 0.0	 1236	 1236	 1236	 0.0	 0.0	 1	 -30.0	 30.0;
	7565	 6866	 0.00021	 0.00296	 0.0	 10645	 10645	 10645	 0.0	 0.0	 1	 -30.0	 30.0;
	7565	 8236	 0.00157	 0.02091	 0.0	 1507	 1507	 1507	 0.0	 0.0	 1	 -30.0	 30.0;
	1929	 6866	 0.00162	 0.02163	 0.0	 1457	 1457	 1457	 0.0	 0.0	 1	 -30.0	 30.0;
	11180	 6999	 0.008521	 0.03463	 0.0	 886	 886	 886	 0.0	 0.0	 1	 -30.0	 30.0;
	11180	 13576	 0.00463	 0.078531	 0.0	 402	 402	 402	 0.0	 0.0	 1	 -30.0	 30.0;
	11180	 13576	 0.004531	 0.072711	 0.0	 434	 434	 434	 0.0	 0.0	 1	 -30.0	 30.0;
	11180	 164	 0.00575	 0.02876	 0.0	 1077	 1077	 1077	 0.0	 0.0	 1	 -30.0	 30.0;
	11180	 4559	 0.00411	 0.01826	 0.0	 1688	 1688	 1688	 0.0	 0.0	 1	 -30.0	 30.0;
	11180	 2461	 0.008091	 0.03594	 0.0	 858	 858	 858	 0.0	 0.0	 1	 -30.0	 30.0;
	5617	 2883	 0.011031	 0.060581	 0.0	 513	 513	 513	 0.0	 0.0	 1	 -30.0	 30.0;
	5617	 8736	 0.01326	 0.07163	 0.0	 434	 434	 434	 0.0	 0.0	 1	 -30.0	 30.0;
	7417	 2611	 0.007031	 0.069341	 0.0	 454	 454	 454	 0.0	 0.0	 1	 -30.0	 30.0;
	7417	 8152	 0.00238	 0.031081	 0.0	 1014	 1014	 1014	 0.0	 0.0	 1	 -30.0	 30.0;
	6999	 13576	 0.010831	 0.057479	 0.0	 541	 541	 541	 0.0	 0.0	 1	 -30.0	 30.0;
	6999	 164	 0.001849	 0.01024	 0.0	 3036	 3036	 3036	 0.0	 0.0	 1	 -30.0	 30.0;
	11040	 9874	 0.017581	 0.07664	 0.0	 402	 402	 402	 0.0	 0.0	 1	 -30.0	 30.0;
	11040	 9874	 0.017909	 0.07501	 0.0	 410	 410	 410	 0.0	 0.0	 1	 -30.0	 30.0;
	11040	 8736	 0.01312	 0.05724	 0.0	 538	 538	 538	 0.0	 0.0	 1	 -30.0	 30.0;
	11040	 8736	 0.01337	 0.056021	 0.0	 549	 549	 549	 0.0	 0.0	 1	 -30.0	 30.0;
	11040	 813	 0.007961	 0.0347	 0.0	 888	 888	 888	 0.0	 0.0	 1	 -30.0	 30.0;
	7425	 13576	 0.01181	 0.044729	 0.0	 683	 683	 683	 0.0	 0.0	 1	 -30.0	 30.0;
	7425	 177	 0.00457	 0.018729	 0.0	 1639	 1639	 1639	 0.0	 0.0	 1	 -30.0	 30.0;
	12423	 4778	 0.0012	 0.0141	 0.0	 2233	 2233	 2233	 0.0	 0.0	 1	 -30.0	 30.0;
	12423	 4778	 0.00107	 0.01598	 0.0	 1973	 1973	 1973	 0.0	 0.0	 1	 -30.0	 30.0;
	12423	 4219	 0.00046	 0.00666	 0.0	 4732	 4732	 4732	 0.0	 0.0	 1	 -30.0	 30.0;
	12423	 3969	 0.001	 0.0181	 0.0	 1743	 1743	 1743	 0.0	 0.0	 1	 -30.0	 30.0;
	1646	 5450	 9.1e-05	 0.00139	 0.0	 22677	 22677	 22677	 0.0	 0.0	 1	 -30.0	 30.0;
	1646	 5450	 0.00013	 0.00089	 0.0	 35119	 35119	 35119	 0.0	 0.0	 1	 -30.0	 30.0;
	11112	 404	 0.000281	 0.001289	 0.0	 23943	 23943	 23943	 0.0	 0.0	 1	 -30.0	 30.0;
	8760	 5140	 0.00119	 0.01964	 0.0	 1606	 1606	 1606	 0.0	 0.0	 1	 -30.0	 30.0;
	8760	 5140	 0.00117	 0.02001	 0.0	 1576	 1576	 1576	 0.0	 0.0	 1	 -30.0	 30.0;
	2611	 6181	 0.00238	 0.032341	 0.0	 975	 975	 975	 0.0	 0.0	 1	 -30.0	 30.0;
	2611	 6181	 0.002331	 0.02994	 0.0	 1052	 1052	 1052	 0.0	 0.0	 1	 -30.0	 30.0;
	2611	 5376	 0.005479	 0.07155	 0.0	 441	 441	 441	 0.0	 0.0	 1	 -30.0	 30.0;
	2782	 404	 0.008091	 0.036841	 0.0	 838	 838	 838	 0.0	 0.0	 1	 -30.0	 30.0;
	8152	 5376	 0.003081	 0.03707	 0.0	 850	 850	 850	 0.0	 0.0	 1	 -30.0	 30.0;
	8152	 813	 0.01086	 0.05936	 0.0	 524	 524	 524	 0.0	 0.0	 1	 -30.0	 30.0;
	4219	 1353	 0.00063	 0.00975	 0.0	 3233	 3233	 3233	 0.0	 0.0	 1	 -30.0	 30.0;
	13576	 479	 0.00143	 0.025771	 0.0	 1224	 1224	 1224	 0.0	 0.0	 1	 -30.0	 30.0;
	13576	 479	 0.001401	 0.026271	 0.0	 1201	 1201	 1201	 0.0	 0.0	 1	 -30.0	 30.0;
	13576	 177	 0.00631	 0.03037	 0.0	 1019	 1019	 1019	 0.0	 0.0	 1	 -30.0	 30.0;
	2883	 8736	 0.00325	 0.01388	 0.0	 2216	 2216	 2216	 0.0	 0.0	 1	 -30.0	 30.0;
	479	 5450	 0.015461	 0.0828	 0.0	 376	 376	 376	 0.0	 0.0	 1	 -30.0	 30.0;
	479	 5450	 0.017521	 0.08114	 0.0	 381	 381	 381	 0.0	 0.0	 1	 -30.0	 30.0;
	8236	 11750	 0.00036	 0.00554	 0.0	 5690	 5690	 5690	 0.0	 0.0	 1	 -30.0	 30.0;
	3969	 11750	 0.0018	 0.02089	 0.0	 1507	 1507	 1507	 0.0	 0.0	 1	 -30.0	 30.0;
	1353	 11750	 0.00183	 0.02045	 0.0	 1539	 1539	 1539	 0.0	 0.0	 1	 -30.0	 30.0;
	5140	 672	 0.00052	 0.01489	 0.0	 2121	 2121	 2121	 0.0	 0.0	 1	 -30.0	 30.0;
	5140	 672	 0.00051	 0.01518	 0.0	 2080	 2080	 2080	 0.0	 0.0	 1	 -30.0	 30.0;
	8509	 8736	 0.020669	 0.110081	 0.0	 283	 283	 283	 0.0	 0.0	 1	 -30.0	 30.0;
	8509	 8736	 0.02024	 0.1122	 0.0	 278	 278	 278	 0.0	 0.0	 1	 -30.0	 30.0;
	446	 404	 0.01089	 0.05145	 0.0	 601	 601	 601	 0.0	 0.0	 1	 -30.0	 30.0;
	446	 404	 0.01111	 0.050401	 0.0	 613	 613	 613	 0.0	 0.0	 1	 -30.0	 30.0;
	4559	 2461	 0.00493	 0.026719	 0.0	 1163	 1163	 1163	 0.0	 0.0	 1	 -30.0	 30.0;
	5711	 249	 0.005169	 0.067461	 0.0	 467	 467	 467	 0.0	 0.0	 1	 -30.0	 30.0;
	5711	 249	 0.00506	 0.068729	 0.0	 459	 459	 459	 0.0	 0.0	 1	 -30.0	 30.0;
	2723	 10043	 0.011397	 0.04438	 0.0	 690	 690	 690	 0.0	 0.0	 1	 -30.0	 30.0;
	11775	 12394	 0.022504	 0.082851	 0.0	 368	 368	 368	 0.0	 0.0	 1	 -30.0	 30.0;
	11775	 5793	 0.015793	 0.061587	 0.0	 497	 497	 497	 0.0	 0.0	 1	 -30.0	 30.0;
	8315	 3750	 0.012659	 0.05405	 0.0	 570	 570	 570	 0.0	 0.0	 1	 -30.0	 30.0;
	1058	 8142	 0.016149	 0.057248	 0.0	 532	 532	 532	 0.0	 0.0	 1	 -30.0	 30.0;
	218	 8142	 0.038612	 0.122471	 0.0	 246	 246	 246	 0.0	 0.0	 1	 -30.0	 30.0;
	8142	 10533	 0.044273	 0.108959	 0.0	 269	 269	 269	 0.0	 0.0	 1	 -30.0	 30.0;
	13106	 8657	 0.038876	 0.139587	 0.0	 218	 218	 218	 0.0	 0.0	 1	 -30.0	 30.0;
	13106	 9368	 0.10805	 0.191992	 0.0	 144	 144	 144	 0.0	 0.0	 1	 -30.0	 30.0;
	4476	 13106	 0.035802	 0.084231	 0.0	 346	 346	 346	 0.0	 0.0	 1	 -30.0	 30.0;
	4940	 7549	 0.00614	 0.02205	 0.0	 1381	 1381	 1381	 0.0	 0.0	 1	 -30.0	 30.0;
	4940	 3440	 0.003587	 0.01395	 0.0	 2193	 2193	 2193	 0.0	 0.0	 1	 -30.0	 30.0;
	7549	 11388	 0.019554	 0.05981	 0.0	 502	 502	 502	 0.0	 0.0	 1	 -30.0	 30.0;
	3440	 4836	 0.038066	 0.142281	 0.0	 215	 215	 215	 0.0	 0.0	 1	 -30.0	 30.0;
	11973	 6342	 0.007421	 0.02181	 0.0	 1372	 1372	 1372	 0.0	 0.0	 1	 -30.0	 30.0;
	6342	 12033	 0.007562	 0.021339	 0.0	 1396	 1396	 1396	 0.0	 0.0	 1	 -30.0	 30.0;
	11973	 7034	 0.007388	 0.026537	 0.0	 1147	 1147	 1147	 0.0	 0.0	 1	 -30.0	 30.0;
	7034	 7169	 0.00724	 0.02705	 0.0	 1129	 1129	 1129	 0.0	 0.0	 1	 -30.0	 30.0;
	109	 10356	 0.004893	 0.018273	 0.0	 1670	 1670	 1670	 0.0	 0.0	 1	 -30.0	 30.0;
	10356	 8071	 0.004777	 0.018612	 0.0	 1644	 1644	 1644	 0.0	 0.0	 1	 -30.0	 30.0;
	11973	 9284	 0.015289	 0.041463	 0.0	 715	 715	 715	 0.0	 0.0	 1	 -30.0	 30.0;
	11973	 9284	 0.01143	 0.042091	 0.0	 725	 725	 725	 0.0	 0.0	 1	 -30.0	 30.0;
	109	 11973	 0.006793	 0.014182	 0.0	 2009	 2009	 2009	 0.0	 0.0	 1	 -30.0	 30.0;
	8071	 11973	 0.012967	 0.048471	 0.0	 630	 630	 630	 0.0	 0.0	 1	 -30.0	 30.0;
	8981	 9284	 0.009281	 0.029554	 0.0	 1020	 1020	 1020	 0.0	 0.0	 1	 -30.0	 30.0;
	8594	 9284	 0.041248	 0.116479	 0.0	 256	 256	 256	 0.0	 0.0	 1	 -30.0	 30.0;
	5578	 9284	 0.071479	 0.137678	 0.0	 204	 204	 204	 0.0	 0.0	 1	 -30.0	 30.0;
	3312	 9284	 0.020612	 0.075893	 0.0	 402	 402	 402	 0.0	 0.0	 1	 -30.0	 30.0;
	9284	 755	 0.05214	 0.100421	 0.0	 280	 280	 280	 0.0	 0.0	 1	 -30.0	 30.0;
	6982	 9284	 0.047942	 0.179157	 0.0	 171	 171	 171	 0.0	 0.0	 1	 -30.0	 30.0;
	10639	 3604	 0.0016	 0.01402	 0.0	 2239	 2239	 2239	 0.0	 0.0	 1	 -30.0	 30.0;
	8611	 8981	 0.009149	 0.027992	 0.0	 1073	 1073	 1073	 0.0	 0.0	 1	 -30.0	 30.0;
	12735	 8611	 0.031107	 0.116281	 0.0	 263	 263	 263	 0.0	 0.0	 1	 -30.0	 30.0;
	12735	 8071	 0.026463	 0.091273	 0.0	 333	 333	 333	 0.0	 0.0	 1	 -30.0	 30.0;
	3659	 12735	 0.023562	 0.075017	 0.0	 402	 402	 402	 0.0	 0.0	 1	 -30.0	 30.0;
	8311	 12735	 0.015702	 0.050017	 0.0	 603	 603	 603	 0.0	 0.0	 1	 -30.0	 30.0;
	6443	 4836	 0.004802	 0.017231	 0.0	 1766	 1766	 1766	 0.0	 0.0	 1	 -30.0	 30.0;
	6443	 1728	 0.065579	 0.208826	 0.0	 145	 145	 145	 0.0	 0.0	 1	 -30.0	 30.0;
	6443	 5108	 0.049917	 0.112843	 0.0	 256	 256	 256	 0.0	 0.0	 1	 -30.0	 30.0;
	6443	 193	 0.047793	 0.095603	 0.0	 296	 296	 296	 0.0	 0.0	 1	 -30.0	 30.0;
	10834	 4836	 0.043421	 0.168942	 0.0	 182	 182	 182	 0.0	 0.0	 1	 -30.0	 30.0;
	11388	 4836	 0.029364	 0.093017	 0.0	 324	 324	 324	 0.0	 0.0	 1	 -30.0	 30.0;
	4179	 5603	 0.023521	 0.086562	 0.0	 353	 353	 353	 0.0	 0.0	 1	 -30.0	 30.0;
	1375	 5603	 0.017909	 0.058463	 0.0	 517	 517	 517	 0.0	 0.0	 1	 -30.0	 30.0;
	5519	 788	 0.008198	 0.030248	 0.0	 1008	 1008	 1008	 0.0	 0.0	 1	 -30.0	 30.0;
	788	 4492	 0.015579	 0.053744	 0.0	 565	 565	 565	 0.0	 0.0	 1	 -30.0	 30.0;
	788	 8742	 0.030471	 0.09738	 0.0	 310	 310	 310	 0.0	 0.0	 1	 -30.0	 30.0;
	4018	 788	 0.017157	 0.066	 0.0	 464	 464	 464	 0.0	 0.0	 1	 -30.0	 30.0;
	1797	 6603	 0.017628	 0.065868	 0.0	 464	 464	 464	 0.0	 0.0	 1	 -30.0	 30.0;
	1797	 6100	 0.022686	 0.072273	 0.0	 417	 417	 417	 0.0	 0.0	 1	 -30.0	 30.0;
	3163	 12374	 0.010322	 0.03719	 0.0	 819	 819	 819	 0.0	 0.0	 1	 -30.0	 30.0;
	12374	 11018	 0.010802	 0.038281	 0.0	 795	 795	 795	 0.0	 0.0	 1	 -30.0	 30.0;
	7290	 10533	 0.019298	 0.073041	 0.0	 419	 419	 419	 0.0	 0.0	 1	 -30.0	 30.0;
	4645	 7290	 0.011678	 0.035273	 0.0	 851	 851	 851	 0.0	 0.0	 1	 -30.0	 30.0;
	7411	 6603	 0.019719	 0.057256	 0.0	 522	 522	 522	 0.0	 0.0	 1	 -30.0	 30.0;
	251	 1058	 0.026421	 0.086471	 0.0	 350	 350	 350	 0.0	 0.0	 1	 -30.0	 30.0;
	12033	 2738	 0.014281	 0.045471	 0.0	 663	 663	 663	 0.0	 0.0	 1	 -30.0	 30.0;
	1375	 10286	 0.004529	 0.013686	 0.0	 2192	 2192	 2192	 0.0	 0.0	 1	 -30.0	 30.0;
	10286	 11018	 0.014603	 0.058463	 0.0	 525	 525	 525	 0.0	 0.0	 1	 -30.0	 30.0;
	9827	 8117	 0.007702	 0.020876	 0.0	 1420	 1420	 1420	 0.0	 0.0	 1	 -30.0	 30.0;
	9827	 5067	 0.010281	 0.03957	 0.0	 773	 773	 773	 0.0	 0.0	 1	 -30.0	 30.0;
	8117	 7411	 0.00686	 0.023661	 0.0	 1283	 1283	 1283	 0.0	 0.0	 1	 -30.0	 30.0;
	5519	 7418	 0.02457	 0.09557	 0.0	 321	 321	 321	 0.0	 0.0	 1	 -30.0	 30.0;
	24	 1728	 0.03024	 0.085372	 0.0	 349	 349	 349	 0.0	 0.0	 1	 -30.0	 30.0;
	24	 10834	 0.04157	 0.14924	 0.0	 204	 204	 204	 0.0	 0.0	 1	 -30.0	 30.0;
	8786	 24	 0.028132	 0.097008	 0.0	 313	 313	 313	 0.0	 0.0	 1	 -30.0	 30.0;
	24	 12828	 0.038661	 0.123091	 0.0	 245	 245	 245	 0.0	 0.0	 1	 -30.0	 30.0;
	2498	 12905	 0.019364	 0.077413	 0.0	 396	 396	 396	 0.0	 0.0	 1	 -30.0	 30.0;
	12905	 5793	 0.009562	 0.036182	 0.0	 845	 845	 845	 0.0	 0.0	 1	 -30.0	 30.0;
	10639	 8195	 0.00147	 0.01643	 0.0	 1915	 1915	 1915	 0.0	 0.0	 1	 -30.0	 30.0;
	1021	 9078	 0.005719	 0.016826	 0.0	 1778	 1778	 1778	 0.0	 0.0	 1	 -30.0	 30.0;
	9078	 13644	 0.007843	 0.027041	 0.0	 1122	 1122	 1122	 0.0	 0.0	 1	 -30.0	 30.0;
	9078	 1827	 0.016826	 0.045628	 0.0	 650	 650	 650	 0.0	 0.0	 1	 -30.0	 30.0;
	9078	 3138	 0.02238	 0.062777	 0.0	 474	 474	 474	 0.0	 0.0	 1	 -30.0	 30.0;
	1728	 1021	 0.012959	 0.041248	 0.0	 731	 731	 731	 0.0	 0.0	 1	 -30.0	 30.0;
	13644	 6445	 0.004702	 0.017562	 0.0	 1738	 1738	 1738	 0.0	 0.0	 1	 -30.0	 30.0;
	11306	 13644	 0.023331	 0.080446	 0.0	 378	 378	 378	 0.0	 0.0	 1	 -30.0	 30.0;
	2127	 1375	 0.00505	 0.018653	 0.0	 1635	 1635	 1635	 0.0	 0.0	 1	 -30.0	 30.0;
	6393	 2127	 0.008562	 0.025686	 0.0	 1167	 1167	 1167	 0.0	 0.0	 1	 -30.0	 30.0;
	5110	 4258	 0.026124	 0.083149	 0.0	 363	 363	 363	 0.0	 0.0	 1	 -30.0	 30.0;
	4258	 6982	 0.02038	 0.04605	 0.0	 628	 628	 628	 0.0	 0.0	 1	 -30.0	 30.0;
	11322	 9657	 0.000169	 0.00106	 0.0	 29428	 29428	 29428	 0.0	 0.0	 1	 -30.0	 30.0;
	1360	 11322	 0.00043	 0.003901	 0.0	 8049	 8049	 8049	 0.0	 0.0	 1	 -30.0	 30.0;
	11217	 6803	 0.005298	 0.021	 0.0	 1459	 1459	 1459	 0.0	 0.0	 1	 -30.0	 30.0;
	6803	 10688	 0.001322	 0.004289	 0.0	 7038	 7038	 7038	 0.0	 0.0	 1	 -30.0	 30.0;
	9414	 1600	 0.005471	 0.016554	 0.0	 1812	 1812	 1812	 0.0	 0.0	 1	 -30.0	 30.0;
	9414	 7154	 0.022198	 0.064653	 0.0	 463	 463	 463	 0.0	 0.0	 1	 -30.0	 30.0;
	7016	 3955	 0.027653	 0.099256	 0.0	 307	 307	 307	 0.0	 0.0	 1	 -30.0	 30.0;
	3766	 7016	 0.044099	 0.152107	 0.0	 200	 200	 200	 0.0	 0.0	 1	 -30.0	 30.0;
	4313	 4582	 0.017603	 0.047711	 0.0	 622	 622	 622	 0.0	 0.0	 1	 -30.0	 30.0;
	4313	 6393	 0.024198	 0.06562	 0.0	 452	 452	 452	 0.0	 0.0	 1	 -30.0	 30.0;
	12339	 5338	 0.00165	 0.01428	 0.0	 2616	 2616	 2616	 0.0	 0.0	 1	 -30.0	 30.0;
	10677	 12339	 0.00131	 0.01467	 0.0	 2553	 2553	 2553	 0.0	 0.0	 1	 -30.0	 30.0;
	8657	 13227	 0.040802	 0.129909	 0.0	 232	 232	 232	 0.0	 0.0	 1	 -30.0	 30.0;
	1331	 3955	 0.005058	 0.019686	 0.0	 1555	 1555	 1555	 0.0	 0.0	 1	 -30.0	 30.0;
	3955	 1970	 0.075521	 0.145463	 0.0	 193	 193	 193	 0.0	 0.0	 1	 -30.0	 30.0;
	1331	 5161	 0.024033	 0.088488	 0.0	 345	 345	 345	 0.0	 0.0	 1	 -30.0	 30.0;
	11063	 7227	 0.001599	 0.007401	 0.0	 4172	 4172	 4172	 0.0	 0.0	 1	 -30.0	 30.0;
	1827	 12394	 0.025289	 0.082934	 0.0	 365	 365	 365	 0.0	 0.0	 1	 -30.0	 30.0;
	10213	 10834	 0.012421	 0.035058	 0.0	 850	 850	 850	 0.0	 0.0	 1	 -30.0	 30.0;
	4711	 3925	 0.00855	 0.03774	 0.0	 817	 817	 817	 0.0	 0.0	 1	 -30.0	 30.0;
	8594	 7597	 0.010686	 0.03019	 0.0	 987	 987	 987	 0.0	 0.0	 1	 -30.0	 30.0;
	6124	 9027	 0.010331	 0.03438	 0.0	 880	 880	 880	 0.0	 0.0	 1	 -30.0	 30.0;
	9027	 9578	 0.01581	 0.050339	 0.0	 599	 599	 599	 0.0	 0.0	 1	 -30.0	 30.0;
	11217	 7154	 0.005661	 0.022744	 0.0	 1348	 1348	 1348	 0.0	 0.0	 1	 -30.0	 30.0;
	10440	 12377	 0.000636	 0.002512	 0.0	 12190	 12190	 12190	 0.0	 0.0	 1	 -30.0	 30.0;
	5793	 10440	 0.005281	 0.017521	 0.0	 1727	 1727	 1727	 0.0	 0.0	 1	 -30.0	 30.0;
	10440	 2822	 0.002826	 0.00781	 0.0	 3804	 3804	 3804	 0.0	 0.0	 1	 -30.0	 30.0;
	1600	 7310	 0.018066	 0.056876	 0.0	 530	 530	 530	 0.0	 0.0	 1	 -30.0	 30.0;
	7310	 6100	 0.038537	 0.144033	 0.0	 212	 212	 212	 0.0	 0.0	 1	 -30.0	 30.0;
	7310	 1769	 0.049669	 0.141083	 0.0	 212	 212	 212	 0.0	 0.0	 1	 -30.0	 30.0;
	7310	 10688	 0.058628	 0.17286	 0.0	 174	 174	 174	 0.0	 0.0	 1	 -30.0	 30.0;
	7310	 8822	 0.00043	 0.001273	 0.0	 23509	 23509	 23509	 0.0	 0.0	 1	 -30.0	 30.0;
	7310	 10070	 0.025917	 0.093058	 0.0	 327	 327	 327	 0.0	 0.0	 1	 -30.0	 30.0;
	2470	 6124	 0.02295	 0.065	 0.0	 459	 459	 459	 0.0	 0.0	 1	 -30.0	 30.0;
	8697	 6100	 0.001504	 0.00486	 0.0	 6209	 6209	 6209	 0.0	 0.0	 1	 -30.0	 30.0;
	8697	 6100	 0.002182	 0.006678	 0.0	 4497	 4497	 4497	 0.0	 0.0	 1	 -30.0	 30.0;
	4973	 1360	 0.002979	 0.02218	 0.0	 1412	 1412	 1412	 0.0	 0.0	 1	 -30.0	 30.0;
	4973	 1360	 0.003021	 0.022531	 0.0	 1390	 1390	 1390	 0.0	 0.0	 1	 -30.0	 30.0;
	3659	 8311	 0.020843	 0.058843	 0.0	 507	 507	 507	 0.0	 0.0	 1	 -30.0	 30.0;
	7418	 3659	 0.009331	 0.027413	 0.0	 1091	 1091	 1091	 0.0	 0.0	 1	 -30.0	 30.0;
	3659	 10098	 0.009182	 0.024769	 0.0	 1196	 1196	 1196	 0.0	 0.0	 1	 -30.0	 30.0;
	7708	 524	 0.00275	 0.01488	 0.0	 2088	 2088	 2088	 0.0	 0.0	 1	 -30.0	 30.0;
	9783	 4311	 0.0001	 0.00082	 0.0	 45507	 45507	 45507	 0.0	 0.0	 1	 -30.0	 30.0;
	9193	 1360	 0.01476	 0.08713	 0.0	 358	 358	 358	 0.0	 0.0	 1	 -30.0	 30.0;
	9193	 7227	 0.00212	 0.011469	 0.0	 2709	 2709	 2709	 0.0	 0.0	 1	 -30.0	 30.0;
	10688	 9647	 0.013521	 0.049959	 0.0	 611	 611	 611	 0.0	 0.0	 1	 -30.0	 30.0;
	9647	 1375	 0.017793	 0.07124	 0.0	 431	 431	 431	 0.0	 0.0	 1	 -30.0	 30.0;
	12721	 3750	 0.01481	 0.086021	 0.0	 362	 362	 362	 0.0	 0.0	 1	 -30.0	 30.0;
	7227	 12721	 0.01686	 0.07207	 0.0	 427	 427	 427	 0.0	 0.0	 1	 -30.0	 30.0;
	11018	 8245	 0.012331	 0.034413	 0.0	 865	 865	 865	 0.0	 0.0	 1	 -30.0	 30.0;
	8347	 8245	 0.000777	 0.00276	 0.0	 11017	 11017	 11017	 0.0	 0.0	 1	 -30.0	 30.0;
	4674	 218	 0.028421	 0.08657	 0.0	 347	 347	 347	 0.0	 0.0	 1	 -30.0	 30.0;
	2738	 6770	 0.023521	 0.081132	 0.0	 374	 374	 374	 0.0	 0.0	 1	 -30.0	 30.0;
	4255	 3759	 0.000901	 0.005	 0.0	 6218	 6218	 6218	 0.0	 0.0	 1	 -30.0	 30.0;
	3759	 4485	 0.00263	 0.01551	 0.0	 2008	 2008	 2008	 0.0	 0.0	 1	 -30.0	 30.0;
	10517	 4597	 0.017463	 0.071669	 0.0	 429	 429	 429	 0.0	 0.0	 1	 -30.0	 30.0;
	10517	 2070	 0.016826	 0.065512	 0.0	 468	 468	 468	 0.0	 0.0	 1	 -30.0	 30.0;
	4582	 5663	 0.019587	 0.076612	 0.0	 400	 400	 400	 0.0	 0.0	 1	 -30.0	 30.0;
	1958	 2498	 0.022537	 0.071769	 0.0	 420	 420	 420	 0.0	 0.0	 1	 -30.0	 30.0;
	4645	 251	 0.013256	 0.04005	 0.0	 749	 749	 749	 0.0	 0.0	 1	 -30.0	 30.0;
	13154	 4674	 0.046397	 0.13586	 0.0	 221	 221	 221	 0.0	 0.0	 1	 -30.0	 30.0;
	13154	 833	 0.026471	 0.105893	 0.0	 290	 290	 290	 0.0	 0.0	 1	 -30.0	 30.0;
	8069	 10604	 0.025504	 0.08119	 0.0	 372	 372	 372	 0.0	 0.0	 1	 -30.0	 30.0;
	7226	 8069	 0.027603	 0.10738	 0.0	 285	 285	 285	 0.0	 0.0	 1	 -30.0	 30.0;
	10533	 5578	 0.084843	 0.156942	 0.0	 178	 178	 178	 0.0	 0.0	 1	 -30.0	 30.0;
	7633	 4492	 0.030521	 0.115653	 0.0	 265	 265	 265	 0.0	 0.0	 1	 -30.0	 30.0;
	7169	 11821	 0.004	 0.010851	 0.0	 2732	 2732	 2732	 0.0	 0.0	 1	 -30.0	 30.0;
	11821	 7597	 0.016017	 0.043421	 0.0	 683	 683	 683	 0.0	 0.0	 1	 -30.0	 30.0;
	7633	 2723	 0.027091	 0.087488	 0.0	 345	 345	 345	 0.0	 0.0	 1	 -30.0	 30.0;
	10875	 10136	 0.02243	 0.047793	 0.0	 599	 599	 599	 0.0	 0.0	 1	 -30.0	 30.0;
	11388	 10136	 0.016851	 0.051537	 0.0	 583	 583	 583	 0.0	 0.0	 1	 -30.0	 30.0;
	12377	 12394	 0.01638	 0.053901	 0.0	 561	 561	 561	 0.0	 0.0	 1	 -30.0	 30.0;
	12377	 12394	 0.012298	 0.045521	 0.0	 670	 670	 670	 0.0	 0.0	 1	 -30.0	 30.0;
	12394	 10028	 0.025017	 0.048653	 0.0	 578	 578	 578	 0.0	 0.0	 1	 -30.0	 30.0;
	5067	 13194	 0.00186	 0.007174	 0.0	 4263	 4263	 4263	 0.0	 0.0	 1	 -30.0	 30.0;
	4276	 13194	 0.001397	 0.005372	 0.0	 5691	 5691	 5691	 0.0	 0.0	 1	 -30.0	 30.0;
	3138	 6445	 0.010777	 0.043479	 0.0	 706	 706	 706	 0.0	 0.0	 1	 -30.0	 30.0;
	9326	 3138	 0.016413	 0.047628	 0.0	 628	 628	 628	 0.0	 0.0	 1	 -30.0	 30.0;
	2054	 8025	 0.004	 0.011281	 0.0	 2640	 2640	 2640	 0.0	 0.0	 1	 -30.0	 30.0;
	6100	 8025	 0.004041	 0.015099	 0.0	 2021	 2021	 2021	 0.0	 0.0	 1	 -30.0	 30.0;
	5067	 6685	 0.004636	 0.017579	 0.0	 1738	 1738	 1738	 0.0	 0.0	 1	 -30.0	 30.0;
	6685	 6100	 0.006529	 0.025091	 0.0	 1219	 1219	 1219	 0.0	 0.0	 1	 -30.0	 30.0;
	9578	 5067	 0.01781	 0.052339	 0.0	 572	 572	 572	 0.0	 0.0	 1	 -30.0	 30.0;
	2054	 4276	 0.003744	 0.010149	 0.0	 2921	 2921	 2921	 0.0	 0.0	 1	 -30.0	 30.0;
	9724	 6100	 0.006248	 0.023702	 0.0	 1289	 1289	 1289	 0.0	 0.0	 1	 -30.0	 30.0;
	9724	 9368	 0.035107	 0.106207	 0.0	 283	 283	 283	 0.0	 0.0	 1	 -30.0	 30.0;
	9724	 13267	 0.014769	 0.045182	 0.0	 665	 665	 665	 0.0	 0.0	 1	 -30.0	 30.0;
	9724	 2692	 0.004322	 0.012198	 0.0	 2441	 2441	 2441	 0.0	 0.0	 1	 -30.0	 30.0;
	9724	 10070	 0.015678	 0.054083	 0.0	 561	 561	 561	 0.0	 0.0	 1	 -30.0	 30.0;
	44	 10213	 0.011331	 0.023636	 0.0	 1206	 1206	 1206	 0.0	 0.0	 1	 -30.0	 30.0;
	1360	 9657	 0.000591	 0.002969	 0.0	 10435	 10435	 10435	 0.0	 0.0	 1	 -30.0	 30.0;
	1360	 9657	 0.000281	 0.0025	 0.0	 12556	 12556	 12556	 0.0	 0.0	 1	 -30.0	 30.0;
	7227	 9657	 0.00781	 0.039159	 0.0	 792	 792	 792	 0.0	 0.0	 1	 -30.0	 30.0;
	9657	 1616	 0.00419	 0.02431	 0.0	 1281	 1281	 1281	 0.0	 0.0	 1	 -30.0	 30.0;
	524	 9657	 0.014479	 0.06989	 0.0	 443	 443	 443	 0.0	 0.0	 1	 -30.0	 30.0;
	524	 9657	 0.013419	 0.07594	 0.0	 410	 410	 410	 0.0	 0.0	 1	 -30.0	 30.0;
	5338	 7701	 0.00208	 0.02183	 0.0	 1715	 1715	 1715	 0.0	 0.0	 1	 -30.0	 30.0;
	10604	 5578	 0.028083	 0.103397	 0.0	 295	 295	 295	 0.0	 0.0	 1	 -30.0	 30.0;
	8742	 3163	 0.005793	 0.017802	 0.0	 1688	 1688	 1688	 0.0	 0.0	 1	 -30.0	 30.0;
	13227	 13267	 0.016124	 0.049322	 0.0	 609	 609	 609	 0.0	 0.0	 1	 -30.0	 30.0;
	44	 5108	 0.018471	 0.041802	 0.0	 692	 692	 692	 0.0	 0.0	 1	 -30.0	 30.0;
	1970	 1536	 0.031719	 0.066198	 0.0	 431	 431	 431	 0.0	 0.0	 1	 -30.0	 30.0;
	303	 2470	 0.017554	 0.056124	 0.0	 538	 538	 538	 0.0	 0.0	 1	 -30.0	 30.0;
	8879	 1769	 0.011207	 0.037917	 0.0	 799	 799	 799	 0.0	 0.0	 1	 -30.0	 30.0;
	3750	 4255	 0.02261	 0.105521	 0.0	 293	 293	 293	 0.0	 0.0	 1	 -30.0	 30.0;
	5578	 7226	 0.002397	 0.013603	 0.0	 2287	 2287	 2287	 0.0	 0.0	 1	 -30.0	 30.0;
	7226	 755	 0.021901	 0.055818	 0.0	 527	 527	 527	 0.0	 0.0	 1	 -30.0	 30.0;
	5110	 5578	 0.007719	 0.030066	 0.0	 1018	 1018	 1018	 0.0	 0.0	 1	 -30.0	 30.0;
	5578	 3312	 0.017711	 0.05	 0.0	 596	 596	 596	 0.0	 0.0	 1	 -30.0	 30.0;
	833	 5578	 0.035322	 0.070802	 0.0	 400	 400	 400	 0.0	 0.0	 1	 -30.0	 30.0;
	6770	 8786	 0.017281	 0.050777	 0.0	 589	 589	 589	 0.0	 0.0	 1	 -30.0	 30.0;
	3264	 7633	 0.04324	 0.168223	 0.0	 182	 182	 182	 0.0	 0.0	 1	 -30.0	 30.0;
	8822	 3264	 0.022678	 0.082017	 0.0	 372	 372	 372	 0.0	 0.0	 1	 -30.0	 30.0;
	3264	 4018	 0.026	 0.079537	 0.0	 378	 378	 378	 0.0	 0.0	 1	 -30.0	 30.0;
	7870	 10079	 0.027347	 0.080372	 0.0	 373	 373	 373	 0.0	 0.0	 1	 -30.0	 30.0;
	5161	 7870	 0.023364	 0.074372	 0.0	 406	 406	 406	 0.0	 0.0	 1	 -30.0	 30.0;
	4231	 4476	 0.011421	 0.02757	 0.0	 1059	 1059	 1059	 0.0	 0.0	 1	 -30.0	 30.0;
	7227	 4255	 0.011039	 0.047169	 0.0	 653	 653	 653	 0.0	 0.0	 1	 -30.0	 30.0;
	1616	 4255	 0.015159	 0.0732	 0.0	 423	 423	 423	 0.0	 0.0	 1	 -30.0	 30.0;
	3840	 4255	 0.00119	 0.005729	 0.0	 5399	 5399	 5399	 0.0	 0.0	 1	 -30.0	 30.0;
	11279	 4255	 0.00182	 0.060349	 0.0	 524	 524	 524	 0.0	 0.0	 1	 -30.0	 30.0;
	10688	 5663	 0.00795	 0.032132	 0.0	 955	 955	 955	 0.0	 0.0	 1	 -30.0	 30.0;
	1211	 10688	 0.006372	 0.021934	 0.0	 1383	 1383	 1383	 0.0	 0.0	 1	 -30.0	 30.0;
	3766	 10688	 0.015992	 0.036041	 0.0	 802	 802	 802	 0.0	 0.0	 1	 -30.0	 30.0;
	10688	 6393	 0.022843	 0.087157	 0.0	 351	 351	 351	 0.0	 0.0	 1	 -30.0	 30.0;
	11097	 4179	 0.00495	 0.014942	 0.0	 2007	 2007	 2007	 0.0	 0.0	 1	 -30.0	 30.0;
	1536	 11097	 0.000901	 0.00238	 0.0	 12413	 12413	 12413	 0.0	 0.0	 1	 -30.0	 30.0;
	5663	 11097	 0.008942	 0.027339	 0.0	 1099	 1099	 1099	 0.0	 0.0	 1	 -30.0	 30.0;
	5663	 4179	 0.00476	 0.017587	 0.0	 1734	 1734	 1734	 0.0	 0.0	 1	 -30.0	 30.0;
	10079	 4179	 0.037339	 0.128802	 0.0	 236	 236	 236	 0.0	 0.0	 1	 -30.0	 30.0;
	1536	 7191	 0.00081	 0.00219	 0.0	 13528	 13528	 13528	 0.0	 0.0	 1	 -30.0	 30.0;
	1536	 6516	 0.005132	 0.018438	 0.0	 1651	 1651	 1651	 0.0	 0.0	 1	 -30.0	 30.0;
	6413	 5663	 0.005934	 0.023107	 0.0	 1325	 1325	 1325	 0.0	 0.0	 1	 -30.0	 30.0;
	6413	 5663	 0.005802	 0.021397	 0.0	 1425	 1425	 1425	 0.0	 0.0	 1	 -30.0	 30.0;
	6413	 335	 0.000463	 0.001421	 0.0	 21136	 21136	 21136	 0.0	 0.0	 1	 -30.0	 30.0;
	6413	 8879	 0.000909	 0.002521	 0.0	 11787	 11787	 11787	 0.0	 0.0	 1	 -30.0	 30.0;
	5663	 6516	 0.009347	 0.025364	 0.0	 1169	 1169	 1169	 0.0	 0.0	 1	 -30.0	 30.0;
	13567	 7191	 0.00062	 0.002017	 0.0	 14970	 14970	 14970	 0.0	 0.0	 1	 -30.0	 30.0;
	335	 13567	 0.000917	 0.002364	 0.0	 12458	 12458	 12458	 0.0	 0.0	 1	 -30.0	 30.0;
	13567	 3766	 0.009248	 0.016446	 0.0	 1675	 1675	 1675	 0.0	 0.0	 1	 -30.0	 30.0;
	8879	 3826	 0.00295	 0.008	 0.0	 3705	 3705	 3705	 0.0	 0.0	 1	 -30.0	 30.0;
	3766	 8879	 0.003339	 0.012612	 0.0	 2422	 2422	 2422	 0.0	 0.0	 1	 -30.0	 30.0;
	3766	 3826	 0.00319	 0.012504	 0.0	 2448	 2448	 2448	 0.0	 0.0	 1	 -30.0	 30.0;
	1211	 3766	 0.007826	 0.030521	 0.0	 1003	 1003	 1003	 0.0	 0.0	 1	 -30.0	 30.0;
	10387	 7701	 0.00063	 0.00702	 0.0	 5334	 5334	 5334	 0.0	 0.0	 1	 -30.0	 30.0;
	7701	 8195	 0.00184	 0.02018	 0.0	 1873	 1873	 1873	 0.0	 0.0	 1	 -30.0	 30.0;
	2057	 8855	 0.003818	 0.010661	 0.0	 2790	 2790	 2790	 0.0	 0.0	 1	 -30.0	 30.0;
	11018	 2057	 0.008678	 0.025198	 0.0	 1186	 1186	 1186	 0.0	 0.0	 1	 -30.0	 30.0;
	8347	 2057	 0.008843	 0.024661	 0.0	 1206	 1206	 1206	 0.0	 0.0	 1	 -30.0	 30.0;
	193	 10028	 0.023347	 0.041909	 0.0	 659	 659	 659	 0.0	 0.0	 1	 -30.0	 30.0;
	12828	 7597	 0.018091	 0.055347	 0.0	 543	 543	 543	 0.0	 0.0	 1	 -30.0	 30.0;
	9651	 1958	 0.03443	 0.093347	 0.0	 318	 318	 318	 0.0	 0.0	 1	 -30.0	 30.0;
	9651	 2070	 0.041033	 0.111248	 0.0	 267	 267	 267	 0.0	 0.0	 1	 -30.0	 30.0;
	4444	 11306	 0.015843	 0.05686	 0.0	 536	 536	 536	 0.0	 0.0	 1	 -30.0	 30.0;
	6770	 4444	 0.020397	 0.064959	 0.0	 464	 464	 464	 0.0	 0.0	 1	 -30.0	 30.0;
	303	 7633	 0.017893	 0.054959	 0.0	 547	 547	 547	 0.0	 0.0	 1	 -30.0	 30.0;
	1375	 8855	 0.029496	 0.09295	 0.0	 324	 324	 324	 0.0	 0.0	 1	 -30.0	 30.0;
	13641	 12377	 0.011579	 0.046397	 0.0	 661	 661	 661	 0.0	 0.0	 1	 -30.0	 30.0;
	11279	 4711	 0.00099	 0.0042	 0.0	 7321	 7321	 7321	 0.0	 0.0	 1	 -30.0	 30.0;
	11279	 4711	 0.00076	 0.00449	 0.0	 6937	 6937	 6937	 0.0	 0.0	 1	 -30.0	 30.0;
	10255	 2023	 0.006587	 0.016868	 0.0	 1745	 1745	 1745	 0.0	 0.0	 1	 -30.0	 30.0;
	2023	 8855	 0.016876	 0.064909	 0.0	 471	 471	 471	 0.0	 0.0	 1	 -30.0	 30.0;
	10255	 7418	 0.036612	 0.115372	 0.0	 261	 261	 261	 0.0	 0.0	 1	 -30.0	 30.0;
	4597	 5793	 0.009421	 0.030826	 0.0	 980	 980	 980	 0.0	 0.0	 1	 -30.0	 30.0;
	13641	 5793	 0.008041	 0.030438	 0.0	 1004	 1004	 1004	 0.0	 0.0	 1	 -30.0	 30.0;
	7418	 10098	 0.000744	 0.002182	 0.0	 13702	 13702	 13702	 0.0	 0.0	 1	 -30.0	 30.0;
	11279	 6390	 0.000901	 0.003979	 0.0	 7743	 7743	 7743	 0.0	 0.0	 1	 -30.0	 30.0;
	11279	 4485	 0.01212	 0.05176	 0.0	 595	 595	 595	 0.0	 0.0	 1	 -30.0	 30.0;
	9783	 8195	 0.00256	 0.02765	 0.0	 1367	 1367	 1367	 0.0	 0.0	 1	 -30.0	 30.0;
	2822	 10875	 0.00224	 0.007256	 0.0	 4160	 4160	 4160	 0.0	 0.0	 1	 -30.0	 30.0;
	13164	 8195	 0.0009	 0.00943	 0.0	 4006	 4006	 4006	 0.0	 0.0	 1	 -30.0	 30.0;
	4597	 13641	 0.007744	 0.024273	 0.0	 1240	 1240	 1240	 0.0	 0.0	 1	 -30.0	 30.0;
	10875	 13641	 0.006372	 0.017992	 0.0	 1655	 1655	 1655	 0.0	 0.0	 1	 -30.0	 30.0;
	2070	 11388	 0.048554	 0.142669	 0.0	 210	 210	 210	 0.0	 0.0	 1	 -30.0	 30.0;
	2692	 13267	 0.010802	 0.030488	 0.0	 977	 977	 977	 0.0	 0.0	 1	 -30.0	 30.0;
	9326	 6708	 0.015496	 0.047397	 0.0	 634	 634	 634	 0.0	 0.0	 1	 -30.0	 30.0;
	11018	 8855	 0.010207	 0.030826	 0.0	 973	 973	 973	 0.0	 0.0	 1	 -30.0	 30.0;
	8855	 6708	 0.026504	 0.077876	 0.0	 384	 384	 384	 0.0	 0.0	 1	 -30.0	 30.0;
	4482	 962	 0.00073	 0.00905	 0.0	 3480	 3480	 3480	 0.0	 0.0	 1	 -30.0	 30.0;
	3183	 7221	 0.00192	 0.02296	 0.0	 1371	 1371	 1371	 0.0	 0.0	 1	 -30.0	 30.0;
	2593	 3359	 0.01431	 0.05899	 0.0	 521	 521	 521	 0.0	 0.0	 1	 -30.0	 30.0;
	3359	 2044	 0.02607	 0.07168	 0.0	 415	 415	 415	 0.0	 0.0	 1	 -30.0	 30.0;
	8848	 9981	 0.00054	 0.00465	 0.0	 6748	 6748	 6748	 0.0	 0.0	 1	 -30.0	 30.0;
	8848	 3239	 0.00126	 0.01124	 0.0	 2793	 2793	 2793	 0.0	 0.0	 1	 -30.0	 30.0;
	8848	 10523	 0.00048	 0.00527	 0.0	 5970	 5970	 5970	 0.0	 0.0	 1	 -30.0	 30.0;
	8848	 9186	 0.00082	 0.00938	 0.0	 3355	 3355	 3355	 0.0	 0.0	 1	 -30.0	 30.0;
	4381	 13586	 0.00028	 0.003502	 0.0	 8992	 8992	 8992	 0.0	 0.0	 1	 -30.0	 30.0;
	4381	 5114	 0.691467	 4.414711	 0.0	 8	 8	 8	 0.0	 0.0	 1	 -30.0	 30.0;
	4381	 1350	 0.02004	 0.0916	 0.0	 337	 337	 337	 0.0	 0.0	 1	 -30.0	 30.0;
	4381	 342	 0.841911	 4.768444	 0.0	 7	 7	 7	 0.0	 0.0	 1	 -30.0	 30.0;
	4381	 9970	 0.026	 0.08948	 0.0	 339	 339	 339	 0.0	 0.0	 1	 -30.0	 30.0;
	4381	 13254	 0.002631	 0.011889	 0.0	 2595	 2595	 2595	 0.0	 0.0	 1	 -30.0	 30.0;
	4381	 8395	 0.7232	 1.944	 0.0	 16	 16	 16	 0.0	 0.0	 1	 -30.0	 30.0;
	13586	 1350	 0.156169	 0.546756	 0.0	 56	 56	 56	 0.0	 0.0	 1	 -30.0	 30.0;
	13586	 9970	 0.168809	 0.580622	 0.0	 53	 53	 53	 0.0	 0.0	 1	 -30.0	 30.0;
	13586	 13254	 0.019222	 0.068209	 0.0	 446	 446	 446	 0.0	 0.0	 1	 -30.0	 30.0;
	7727	 2304	 0.00039	 0.00386	 0.0	 8142	 8142	 8142	 0.0	 0.0	 1	 -30.0	 30.0;
	7727	 1668	 0.00096	 0.01138	 0.0	 2766	 2766	 2766	 0.0	 0.0	 1	 -30.0	 30.0;
	7727	 13402	 0.00037	 0.00325	 0.0	 9657	 9657	 9657	 0.0	 0.0	 1	 -30.0	 30.0;
	7727	 11873	 0.00029	 0.00339	 0.0	 9284	 9284	 9284	 0.0	 0.0	 1	 -30.0	 30.0;
	5114	 3277	 0.009458	 0.158871	 0.0	 199	 199	 199	 0.0	 0.0	 1	 -30.0	 30.0;
	3277	 6494	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	9970	 3277	 0.312951	 7.130667	 0.0	 5	 5	 5	 0.0	 0.0	 1	 -30.0	 30.0;
	11058	 3277	 0.247649	 1.075911	 0.0	 29	 29	 29	 0.0	 0.0	 1	 -30.0	 30.0;
	6499	 3277	 0.06056	 0.18612	 0.0	 162	 162	 162	 0.0	 0.0	 1	 -30.0	 30.0;
	12273	 3277	 2.142489	 4.347733	 0.0	 7	 7	 7	 0.0	 0.0	 1	 -30.0	 30.0;
	10883	 3277	 0.07132	 1.068889	 0.0	 30	 30	 30	 0.0	 0.0	 1	 -30.0	 30.0;
	412	 3277	 0.02268	 0.08652	 0.0	 354	 354	 354	 0.0	 0.0	 1	 -30.0	 30.0;
	3510	 3277	 2.007778	 4.494222	 0.0	 8	 8	 8	 0.0	 0.0	 1	 -30.0	 30.0;
	6844	 3277	 0.006178	 0.028938	 0.0	 1068	 1068	 1068	 0.0	 0.0	 1	 -30.0	 30.0;
	6590	 3277	 0.027711	 0.260951	 0.0	 121	 121	 121	 0.0	 0.0	 1	 -30.0	 30.0;
	5114	 8135	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	6724	 5114	 0.00692	 0.337378	 0.0	 94	 94	 94	 0.0	 0.0	 1	 -30.0	 30.0;
	342	 5114	 0.025991	 0.10048	 0.0	 305	 305	 305	 0.0	 0.0	 1	 -30.0	 30.0;
	9970	 5114	 0.083711	 0.8648	 0.0	 37	 37	 37	 0.0	 0.0	 1	 -30.0	 30.0;
	11058	 5114	 0.447378	 1.862089	 0.0	 17	 17	 17	 0.0	 0.0	 1	 -30.0	 30.0;
	6499	 5114	 0.062169	 0.153191	 0.0	 192	 192	 192	 0.0	 0.0	 1	 -30.0	 30.0;
	12273	 5114	 2.492533	 4.725778	 0.0	 6	 6	 6	 0.0	 0.0	 1	 -30.0	 30.0;
	10883	 5114	 0.020271	 0.08244	 0.0	 373	 373	 373	 0.0	 0.0	 1	 -30.0	 30.0;
	412	 5114	 0.11416	 1.777556	 0.0	 18	 18	 18	 0.0	 0.0	 1	 -30.0	 30.0;
	8395	 5114	 0.574978	 2.992578	 0.0	 11	 11	 11	 0.0	 0.0	 1	 -30.0	 30.0;
	3510	 5114	 1.887067	 4.964444	 0.0	 8	 8	 8	 0.0	 0.0	 1	 -30.0	 30.0;
	6844	 5114	 0.250778	 0.817422	 0.0	 37	 37	 37	 0.0	 0.0	 1	 -30.0	 30.0;
	6590	 5114	 0.007049	 0.029609	 0.0	 1038	 1038	 1038	 0.0	 0.0	 1	 -30.0	 30.0;
	8135	 6724	 0.003049	 0.020218	 0.0	 1545	 1545	 1545	 0.0	 0.0	 1	 -30.0	 30.0;
	6494	 6724	 0.002911	 0.020262	 0.0	 1544	 1544	 1544	 0.0	 0.0	 1	 -30.0	 30.0;
	7221	 4112	 4e-05	 0.00041	 0.0	 76679	 76679	 76679	 0.0	 0.0	 1	 -30.0	 30.0;
	7221	 962	 0.00087	 0.01087	 0.0	 2897	 2897	 2897	 0.0	 0.0	 1	 -30.0	 30.0;
	7221	 1491	 4e-05	 0.00046	 0.0	 68410	 68410	 68410	 0.0	 0.0	 1	 -30.0	 30.0;
	7221	 962	 0.00095	 0.00924	 0.0	 3401	 3401	 3401	 0.0	 0.0	 1	 -30.0	 30.0;
	2593	 7602	 0.528017	 2.636157	 0.0	 12	 12	 12	 0.0	 0.0	 1	 -30.0	 30.0;
	2593	 2044	 0.032031	 0.128659	 0.0	 239	 239	 239	 0.0	 0.0	 1	 -30.0	 30.0;
	2304	 11382	 0.00044	 0.0032	 0.0	 9780	 9780	 9780	 0.0	 0.0	 1	 -30.0	 30.0;
	2304	 3618	 0.00046	 0.00489	 0.0	 6432	 6432	 6432	 0.0	 0.0	 1	 -30.0	 30.0;
	13402	 11382	 0.0003	 0.00352	 0.0	 8942	 8942	 8942	 0.0	 0.0	 1	 -30.0	 30.0;
	13402	 129	 0.00051	 0.00454	 0.0	 6915	 6915	 6915	 0.0	 0.0	 1	 -30.0	 30.0;
	4826	 962	 0.00068	 0.00746	 0.0	 4217	 4217	 4217	 0.0	 0.0	 1	 -30.0	 30.0;
	4826	 12707	 0.00093	 0.01022	 0.0	 3079	 3079	 3079	 0.0	 0.0	 1	 -30.0	 30.0;
	12707	 1937	 4e-05	 0.0004	 0.0	 78577	 78577	 78577	 0.0	 0.0	 1	 -30.0	 30.0;
	12707	 11873	 0.00078	 0.00698	 0.0	 4498	 4498	 4498	 0.0	 0.0	 1	 -30.0	 30.0;
	1668	 2394	 4e-05	 0.00043	 0.0	 73144	 73144	 73144	 0.0	 0.0	 1	 -30.0	 30.0;
	1668	 10304	 0.00025	 0.00309	 0.0	 10190	 10190	 10190	 0.0	 0.0	 1	 -30.0	 30.0;
	1282	 11382	 0.00047	 0.00538	 0.0	 5849	 5849	 5849	 0.0	 0.0	 1	 -30.0	 30.0;
	2985	 11382	 0.00046	 0.00548	 0.0	 5744	 5744	 5744	 0.0	 0.0	 1	 -30.0	 30.0;
	2985	 8729	 0.00016	 0.00173	 0.0	 18181	 18181	 18181	 0.0	 0.0	 1	 -30.0	 30.0;
	2985	 9186	 0.00166	 0.01471	 0.0	 2134	 2134	 2134	 0.0	 0.0	 1	 -30.0	 30.0;
	1282	 11382	 0.00051	 0.00512	 0.0	 6140	 6140	 6140	 0.0	 0.0	 1	 -30.0	 30.0;
	9805	 11873	 0.00021	 0.00248	 0.0	 12692	 12692	 12692	 0.0	 0.0	 1	 -30.0	 30.0;
	342	 6724	 0.004391	 0.021689	 0.0	 1428	 1428	 1428	 0.0	 0.0	 1	 -30.0	 30.0;
	3500	 9186	 0.00024	 0.00289	 0.0	 10893	 10893	 10893	 0.0	 0.0	 1	 -30.0	 30.0;
	1350	 5137	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	1350	 13254	 0.01788	 0.100471	 0.0	 310	 310	 310	 0.0	 0.0	 1	 -30.0	 30.0;
	5137	 4174	 0.006458	 0.039982	 0.0	 780	 780	 780	 0.0	 0.0	 1	 -30.0	 30.0;
	342	 9970	 0.106151	 0.993333	 0.0	 32	 32	 32	 0.0	 0.0	 1	 -30.0	 30.0;
	342	 8395	 0.699778	 3.232311	 0.0	 10	 10	 10	 0.0	 0.0	 1	 -30.0	 30.0;
	13254	 9970	 0.257058	 0.43592	 0.0	 63	 63	 63	 0.0	 0.0	 1	 -30.0	 30.0;
	8395	 9970	 0.002769	 0.011449	 0.0	 2682	 2682	 2682	 0.0	 0.0	 1	 -30.0	 30.0;
	962	 5712	 0.00034	 0.00305	 0.0	 10293	 10293	 10293	 0.0	 0.0	 1	 -30.0	 30.0;
	962	 10304	 0.00123	 0.01255	 0.0	 2505	 2505	 2505	 0.0	 0.0	 1	 -30.0	 30.0;
	962	 13656	 6e-05	 0.00065	 0.0	 48391	 48391	 48391	 0.0	 0.0	 1	 -30.0	 30.0;
	962	 11702	 6e-05	 0.00063	 0.0	 49913	 49913	 49913	 0.0	 0.0	 1	 -30.0	 30.0;
	962	 9098	 6e-05	 0.00055	 0.0	 57093	 57093	 57093	 0.0	 0.0	 1	 -30.0	 30.0;
	962	 7884	 0.00079	 0.00968	 0.0	 3253	 3253	 3253	 0.0	 0.0	 1	 -30.0	 30.0;
	962	 61	 7e-05	 0.00079	 0.0	 39828	 39828	 39828	 0.0	 0.0	 1	 -30.0	 30.0;
	1142	 4784	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	11058	 1142	 2.064178	 7.545333	 0.0	 5	 5	 5	 0.0	 0.0	 1	 -30.0	 30.0;
	9831	 1142	 0.153711	 0.482489	 0.0	 63	 63	 63	 0.0	 0.0	 1	 -30.0	 30.0;
	12273	 1142	 0.015809	 0.12368	 0.0	 254	 254	 254	 0.0	 0.0	 1	 -30.0	 30.0;
	3510	 1142	 0.057978	 0.363422	 0.0	 104	 104	 104	 0.0	 0.0	 1	 -30.0	 30.0;
	6844	 1142	 0.6932	 2.196889	 0.0	 14	 14	 14	 0.0	 0.0	 1	 -30.0	 30.0;
	6590	 1142	 0.560356	 2.395867	 0.0	 13	 13	 13	 0.0	 0.0	 1	 -30.0	 30.0;
	7884	 3238	 0.00024	 0.00213	 0.0	 14737	 14737	 14737	 0.0	 0.0	 1	 -30.0	 30.0;
	7884	 11179	 0.00093	 0.00884	 0.0	 3554	 3554	 3554	 0.0	 0.0	 1	 -30.0	 30.0;
	13254	 3070	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	5402	 8729	 0.00018	 0.00204	 0.0	 15425	 15425	 15425	 0.0	 0.0	 1	 -30.0	 30.0;
	8371	 8729	 0.00018	 0.00208	 0.0	 15130	 15130	 15130	 0.0	 0.0	 1	 -30.0	 30.0;
	10366	 10981	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	11058	 10366	 0.02068	 0.093391	 0.0	 331	 331	 331	 0.0	 0.0	 1	 -30.0	 30.0;
	6499	 10366	 0.777778	 7.408	 0.0	 5	 5	 5	 0.0	 0.0	 1	 -30.0	 30.0;
	10366	 9831	 0.00884	 0.07292	 0.0	 431	 431	 431	 0.0	 0.0	 1	 -30.0	 30.0;
	412	 10366	 0.131671	 8.295556	 0.0	 4	 4	 4	 0.0	 0.0	 1	 -30.0	 30.0;
	10366	 2298	 0.082462	 0.568222	 0.0	 56	 56	 56	 0.0	 0.0	 1	 -30.0	 30.0;
	10981	 2298	 0.0042	 0.02624	 0.0	 1189	 1189	 1189	 0.0	 0.0	 1	 -30.0	 30.0;
	12041	 12038	 0.00031	 0.00317	 0.0	 9918	 9918	 9918	 0.0	 0.0	 1	 -30.0	 30.0;
	12041	 11382	 0.00043	 0.00498	 0.0	 6320	 6320	 6320	 0.0	 0.0	 1	 -30.0	 30.0;
	13341	 11382	 0.00042	 0.00508	 0.0	 6197	 6197	 6197	 0.0	 0.0	 1	 -30.0	 30.0;
	11058	 6499	 0.110671	 0.773067	 0.0	 41	 41	 41	 0.0	 0.0	 1	 -30.0	 30.0;
	11058	 9831	 0.00912	 0.037609	 0.0	 817	 817	 817	 0.0	 0.0	 1	 -30.0	 30.0;
	11058	 12273	 0.098049	 0.598711	 0.0	 53	 53	 53	 0.0	 0.0	 1	 -30.0	 30.0;
	11058	 10883	 0.019031	 1.160356	 0.0	 28	 28	 28	 0.0	 0.0	 1	 -30.0	 30.0;
	11058	 412	 0.024071	 0.915733	 0.0	 35	 35	 35	 0.0	 0.0	 1	 -30.0	 30.0;
	3510	 11058	 1.484267	 4.479111	 0.0	 9	 9	 9	 0.0	 0.0	 1	 -30.0	 30.0;
	6844	 11058	 0.011578	 0.063271	 0.0	 492	 492	 492	 0.0	 0.0	 1	 -30.0	 30.0;
	6590	 11058	 0.654889	 1.839111	 0.0	 17	 17	 17	 0.0	 0.0	 1	 -30.0	 30.0;
	11058	 2298	 0.022049	 0.10076	 0.0	 307	 307	 307	 0.0	 0.0	 1	 -30.0	 30.0;
	6499	 9831	 0.459867	 2.604711	 0.0	 12	 12	 12	 0.0	 0.0	 1	 -30.0	 30.0;
	6499	 12273	 2.320222	 6.088	 0.0	 5	 5	 5	 0.0	 0.0	 1	 -30.0	 30.0;
	6499	 10883	 0.006369	 0.048089	 0.0	 652	 652	 652	 0.0	 0.0	 1	 -30.0	 30.0;
	6499	 412	 0.006631	 0.0432	 0.0	 723	 723	 723	 0.0	 0.0	 1	 -30.0	 30.0;
	3510	 6499	 2.567244	 6.767111	 0.0	 6	 6	 6	 0.0	 0.0	 1	 -30.0	 30.0;
	6844	 6499	 0.309889	 1.214178	 0.0	 26	 26	 26	 0.0	 0.0	 1	 -30.0	 30.0;
	6590	 6499	 0.009191	 0.043289	 0.0	 714	 714	 714	 0.0	 0.0	 1	 -30.0	 30.0;
	6499	 2298	 0.691022	 5.239556	 0.0	 6	 6	 6	 0.0	 0.0	 1	 -30.0	 30.0;
	7602	 2044	 0.002669	 0.01718	 0.0	 1817	 1817	 1817	 0.0	 0.0	 1	 -30.0	 30.0;
	12038	 7626	 0.00074	 0.00694	 0.0	 4526	 4526	 4526	 0.0	 0.0	 1	 -30.0	 30.0;
	12038	 11382	 0.00068	 0.008	 0.0	 3935	 3935	 3935	 0.0	 0.0	 1	 -30.0	 30.0;
	9831	 1354	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	12273	 9831	 0.00524	 0.030631	 0.0	 1017	 1017	 1017	 0.0	 0.0	 1	 -30.0	 30.0;
	10883	 9831	 0.33932	 3.814667	 0.0	 9	 9	 9	 0.0	 0.0	 1	 -30.0	 30.0;
	412	 9831	 0.22696	 2.614933	 0.0	 13	 13	 13	 0.0	 0.0	 1	 -30.0	 30.0;
	3510	 9831	 0.190671	 0.719378	 0.0	 51	 51	 51	 0.0	 0.0	 1	 -30.0	 30.0;
	6844	 9831	 1.050222	 2.105556	 0.0	 14	 14	 14	 0.0	 0.0	 1	 -30.0	 30.0;
	6590	 9831	 1.431644	 4.294578	 0.0	 7	 7	 7	 0.0	 0.0	 1	 -30.0	 30.0;
	2298	 9831	 0.022618	 0.161089	 0.0	 195	 195	 195	 0.0	 0.0	 1	 -30.0	 30.0;
	7626	 2254	 0.00088	 0.00895	 0.0	 3513	 3513	 3513	 0.0	 0.0	 1	 -30.0	 30.0;
	12273	 2191	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	10883	 12273	 1.827778	 7.768	 0.0	 4	 4	 4	 0.0	 0.0	 1	 -30.0	 30.0;
	3510	 12273	 0.020849	 0.153382	 0.0	 246	 246	 246	 0.0	 0.0	 1	 -30.0	 30.0;
	6844	 12273	 0.156231	 0.656267	 0.0	 47	 47	 47	 0.0	 0.0	 1	 -30.0	 30.0;
	6590	 12273	 0.176498	 0.891556	 0.0	 35	 35	 35	 0.0	 0.0	 1	 -30.0	 30.0;
	11382	 3239	 0.00067	 0.00777	 0.0	 4051	 4051	 4051	 0.0	 0.0	 1	 -30.0	 30.0;
	10883	 412	 0.004578	 0.061889	 0.0	 509	 509	 509	 0.0	 0.0	 1	 -30.0	 30.0;
	10883	 4174	 0.01348	 0.05932	 0.0	 520	 520	 520	 0.0	 0.0	 1	 -30.0	 30.0;
	6844	 10883	 0.066391	 2.802622	 0.0	 12	 12	 12	 0.0	 0.0	 1	 -30.0	 30.0;
	6590	 10883	 0.194258	 2.220444	 0.0	 15	 15	 15	 0.0	 0.0	 1	 -30.0	 30.0;
	10883	 2298	 0.008151	 0.072822	 0.0	 432	 432	 432	 0.0	 0.0	 1	 -30.0	 30.0;
	412	 4174	 0.016502	 0.055382	 0.0	 547	 547	 547	 0.0	 0.0	 1	 -30.0	 30.0;
	6844	 412	 0.0806	 4.633778	 0.0	 7	 7	 7	 0.0	 0.0	 1	 -30.0	 30.0;
	6590	 412	 0.831556	 3.729644	 0.0	 9	 9	 9	 0.0	 0.0	 1	 -30.0	 30.0;
	412	 2298	 0.007951	 0.074151	 0.0	 424	 424	 424	 0.0	 0.0	 1	 -30.0	 30.0;
	2254	 8510	 0.0004	 0.00362	 0.0	 8673	 8673	 8673	 0.0	 0.0	 1	 -30.0	 30.0;
	10304	 13103	 0.00015	 0.00177	 0.0	 17783	 17783	 17783	 0.0	 0.0	 1	 -30.0	 30.0;
	8395	 12108	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	471	 9098	 2e-05	 0.00022	 0.0	 142990	 142990	 142990	 0.0	 0.0	 1	 -30.0	 30.0;
	6844	 3510	 0.02864	 0.172902	 0.0	 217	 217	 217	 0.0	 0.0	 1	 -30.0	 30.0;
	3510	 6590	 0.017591	 0.1404	 0.0	 269	 269	 269	 0.0	 0.0	 1	 -30.0	 30.0;
	6844	 6590	 0.00752	 0.031711	 0.0	 970	 970	 970	 0.0	 0.0	 1	 -30.0	 30.0;
	2298	 6473	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	12971	 3259	 0.032587	 0.058388	 0.0	 473	 473	 473	 0.0	 0.0	 1	 -30.0	 30.0;
	929	 3259	 0.029752	 0.070686	 0.0	 412	 412	 412	 0.0	 0.0	 1	 -30.0	 30.0;
	6446	 5892	 0.00699	 0.04244	 0.0	 874	 874	 874	 0.0	 0.0	 1	 -30.0	 30.0;
	5892	 11019	 0.0008	 0.006081	 0.0	 6129	 6129	 6129	 0.0	 0.0	 1	 -30.0	 30.0;
	5892	 8749	 0.004669	 0.041919	 0.0	 892	 892	 892	 0.0	 0.0	 1	 -30.0	 30.0;
	5892	 8749	 0.00476	 0.04106	 0.0	 910	 910	 910	 0.0	 0.0	 1	 -30.0	 30.0;
	10227	 2900	 0.00146	 0.0163	 0.0	 1931	 1931	 1931	 0.0	 0.0	 1	 -30.0	 30.0;
	10227	 2900	 0.00098	 0.01485	 0.0	 2123	 2123	 2123	 0.0	 0.0	 1	 -30.0	 30.0;
	10227	 2900	 0.00143	 0.01661	 0.0	 1895	 1895	 1895	 0.0	 0.0	 1	 -30.0	 30.0;
	2145	 10227	 0.00209	 0.0241	 0.0	 1306	 1306	 1306	 0.0	 0.0	 1	 -30.0	 30.0;
	2145	 10227	 0.00273	 0.02677	 0.0	 1174	 1174	 1174	 0.0	 0.0	 1	 -30.0	 30.0;
	2145	 10227	 0.00279	 0.02623	 0.0	 1198	 1198	 1198	 0.0	 0.0	 1	 -30.0	 30.0;
	8032	 1164	 0.007479	 0.032207	 0.0	 1148	 1148	 1148	 0.0	 0.0	 1	 -30.0	 30.0;
	8032	 3008	 0.04319	 0.16186	 0.0	 227	 227	 227	 0.0	 0.0	 1	 -30.0	 30.0;
	2305	 4806	 0.007256	 0.029702	 0.0	 1034	 1034	 1034	 0.0	 0.0	 1	 -30.0	 30.0;
	4806	 8823	 0.006488	 0.036041	 0.0	 863	 863	 863	 0.0	 0.0	 1	 -30.0	 30.0;
	5561	 6684	 0.028653	 0.066364	 0.0	 437	 437	 437	 0.0	 0.0	 1	 -30.0	 30.0;
	10396	 5561	 0.010463	 0.027446	 0.0	 1076	 1076	 1076	 0.0	 0.0	 1	 -30.0	 30.0;
	2035	 4589	 0.012409	 0.071919	 0.0	 433	 433	 433	 0.0	 0.0	 1	 -30.0	 30.0;
	2035	 4589	 0.012659	 0.07045	 0.0	 442	 442	 442	 0.0	 0.0	 1	 -30.0	 30.0;
	4589	 12640	 0.003419	 0.02344	 0.0	 1334	 1334	 1334	 0.0	 0.0	 1	 -30.0	 30.0;
	4589	 10889	 0.002469	 0.01486	 0.0	 2097	 2097	 2097	 0.0	 0.0	 1	 -30.0	 30.0;
	4589	 7538	 0.00682	 0.03368	 0.0	 920	 920	 920	 0.0	 0.0	 1	 -30.0	 30.0;
	4589	 1292	 0.02036	 0.09743	 0.0	 318	 318	 318	 0.0	 0.0	 1	 -30.0	 30.0;
	12971	 5532	 0.048	 0.080331	 0.0	 338	 338	 338	 0.0	 0.0	 1	 -30.0	 30.0;
	12971	 4992	 0.00262	 0.008083	 0.0	 3718	 3718	 3718	 0.0	 0.0	 1	 -30.0	 30.0;
	12971	 9566	 0.004107	 0.023083	 0.0	 1348	 1348	 1348	 0.0	 0.0	 1	 -30.0	 30.0;
	12971	 11748	 0.003207	 0.015719	 0.0	 1969	 1969	 1969	 0.0	 0.0	 1	 -30.0	 30.0;
	12971	 1037	 0.004727	 0.02143	 0.0	 1440	 1440	 1440	 0.0	 0.0	 1	 -30.0	 30.0;
	12971	 6848	 0.004041	 0.012702	 0.0	 2370	 2370	 2370	 0.0	 0.0	 1	 -30.0	 30.0;
	12971	 3676	 0.017802	 0.037777	 0.0	 757	 757	 757	 0.0	 0.0	 1	 -30.0	 30.0;
	4201	 7895	 0.002934	 0.014273	 0.0	 2168	 2168	 2168	 0.0	 0.0	 1	 -30.0	 30.0;
	5373	 4201	 0.006231	 0.032174	 0.0	 964	 964	 964	 0.0	 0.0	 1	 -30.0	 30.0;
	8818	 4224	 0.026876	 0.085248	 0.0	 354	 354	 354	 0.0	 0.0	 1	 -30.0	 30.0;
	8818	 1740	 0.050636	 0.099223	 0.0	 284	 284	 284	 0.0	 0.0	 1	 -30.0	 30.0;
	1384	 4853	 0.045347	 0.092	 0.0	 308	 308	 308	 0.0	 0.0	 1	 -30.0	 30.0;
	10215	 4853	 0.005231	 0.013504	 0.0	 2182	 2182	 2182	 0.0	 0.0	 1	 -30.0	 30.0;
	13420	 8567	 0.024752	 0.057446	 0.0	 505	 505	 505	 0.0	 0.0	 1	 -30.0	 30.0;
	13420	 2099	 0.015083	 0.065182	 0.0	 473	 473	 473	 0.0	 0.0	 1	 -30.0	 30.0;
	13420	 10947	 0.03986	 0.070686	 0.0	 390	 390	 390	 0.0	 0.0	 1	 -30.0	 30.0;
	7589	 13420	 0.036231	 0.064248	 0.0	 429	 429	 429	 0.0	 0.0	 1	 -30.0	 30.0;
	13420	 503	 0.004537	 0.022041	 0.0	 1404	 1404	 1404	 0.0	 0.0	 1	 -30.0	 30.0;
	13470	 11054	 0.052603	 0.157802	 0.0	 190	 190	 190	 0.0	 0.0	 1	 -30.0	 30.0;
	10947	 11054	 0.005562	 0.024083	 0.0	 1278	 1278	 1278	 0.0	 0.0	 1	 -30.0	 30.0;
	10947	 11054	 0.005446	 0.024554	 0.0	 1256	 1256	 1256	 0.0	 0.0	 1	 -30.0	 30.0;
	5318	 11054	 0.009107	 0.051661	 0.0	 603	 603	 603	 0.0	 0.0	 1	 -30.0	 30.0;
	11054	 6936	 0.00419	 0.009868	 0.0	 2947	 2947	 2947	 0.0	 0.0	 1	 -30.0	 30.0;
	6629	 11054	 0.024281	 0.13338	 0.0	 233	 233	 233	 0.0	 0.0	 1	 -30.0	 30.0;
	6629	 11054	 0.02376	 0.123496	 0.0	 252	 252	 252	 0.0	 0.0	 1	 -30.0	 30.0;
	7337	 11054	 0.005331	 0.020752	 0.0	 1475	 1475	 1475	 0.0	 0.0	 1	 -30.0	 30.0;
	6703	 7885	 0.001107	 0.004603	 0.0	 6673	 6673	 6673	 0.0	 0.0	 1	 -30.0	 30.0;
	7885	 3706	 0.005628	 0.030702	 0.0	 1012	 1012	 1012	 0.0	 0.0	 1	 -30.0	 30.0;
	1037	 11926	 0.024628	 0.130893	 0.0	 238	 238	 238	 0.0	 0.0	 1	 -30.0	 30.0;
	1037	 11926	 0.024132	 0.133463	 0.0	 233	 233	 233	 0.0	 0.0	 1	 -30.0	 30.0;
	8682	 11926	 0.01419	 0.07062	 0.0	 439	 439	 439	 0.0	 0.0	 1	 -30.0	 30.0;
	8682	 11926	 0.014471	 0.069182	 0.0	 447	 447	 447	 0.0	 0.0	 1	 -30.0	 30.0;
	9872	 12389	 0.008372	 0.045231	 0.0	 687	 687	 687	 0.0	 0.0	 1	 -30.0	 30.0;
	6788	 9872	 0.024628	 0.097983	 0.0	 313	 313	 313	 0.0	 0.0	 1	 -30.0	 30.0;
	9872	 13113	 0.002471	 0.009331	 0.0	 3273	 3273	 3273	 0.0	 0.0	 1	 -30.0	 30.0;
	500	 2673	 0.025702	 0.144587	 0.0	 216	 216	 216	 0.0	 0.0	 1	 -30.0	 30.0;
	6143	 500	 0.003421	 0.019752	 0.0	 1576	 1576	 1576	 0.0	 0.0	 1	 -30.0	 30.0;
	5184	 56	 0.004562	 0.017174	 0.0	 1778	 1778	 1778	 0.0	 0.0	 1	 -30.0	 30.0;
	56	 1284	 0.018868	 0.083661	 0.0	 369	 369	 369	 0.0	 0.0	 1	 -30.0	 30.0;
	56	 2267	 0.01019	 0.027917	 0.0	 1063	 1063	 1063	 0.0	 0.0	 1	 -30.0	 30.0;
	13072	 5184	 0.019471	 0.064058	 0.0	 472	 472	 472	 0.0	 0.0	 1	 -30.0	 30.0;
	9130	 2400	 0.053446	 0.118207	 0.0	 244	 244	 244	 0.0	 0.0	 1	 -30.0	 30.0;
	2400	 8054	 0.049521	 0.123438	 0.0	 238	 238	 238	 0.0	 0.0	 1	 -30.0	 30.0;
	3834	 7401	 0.00914	 0.042039	 0.0	 735	 735	 735	 0.0	 0.0	 1	 -30.0	 30.0;
	7401	 1292	 0.004711	 0.021591	 0.0	 1430	 1430	 1430	 0.0	 0.0	 1	 -30.0	 30.0;
	2028	 13653	 0.0	 0.000893	 0.0	 35373	 35373	 35373	 0.0	 0.0	 1	 -30.0	 30.0;
	6883	 2028	 0.00405	 0.021132	 0.0	 1469	 1469	 1469	 0.0	 0.0	 1	 -30.0	 30.0;
	6883	 2028	 0.004587	 0.020711	 0.0	 1490	 1490	 1490	 0.0	 0.0	 1	 -30.0	 30.0;
	13653	 5429	 0.044182	 0.091041	 0.0	 313	 313	 313	 0.0	 0.0	 1	 -30.0	 30.0;
	13653	 11192	 0.022653	 0.047421	 0.0	 602	 602	 602	 0.0	 0.0	 1	 -30.0	 30.0;
	13653	 10958	 0.058876	 0.108463	 0.0	 256	 256	 256	 0.0	 0.0	 1	 -30.0	 30.0;
	670	 5241	 0.013174	 0.026992	 0.0	 1052	 1052	 1052	 0.0	 0.0	 1	 -30.0	 30.0;
	10751	 670	 0.001273	 0.002818	 0.0	 10216	 10216	 10216	 0.0	 0.0	 1	 -30.0	 30.0;
	2419	 2305	 0.009471	 0.048769	 0.0	 636	 636	 636	 0.0	 0.0	 1	 -30.0	 30.0;
	8688	 5087	 0.017388	 0.04138	 0.0	 704	 704	 704	 0.0	 0.0	 1	 -30.0	 30.0;
	5087	 10725	 0.017339	 0.054661	 0.0	 551	 551	 551	 0.0	 0.0	 1	 -30.0	 30.0;
	7895	 6750	 0.025033	 0.137942	 0.0	 226	 226	 226	 0.0	 0.0	 1	 -30.0	 30.0;
	7895	 6750	 0.024521	 0.140653	 0.0	 222	 222	 222	 0.0	 0.0	 1	 -30.0	 30.0;
	6750	 10524	 0.021198	 0.056041	 0.0	 528	 528	 528	 0.0	 0.0	 1	 -30.0	 30.0;
	6750	 12031	 0.007174	 0.035	 0.0	 885	 885	 885	 0.0	 0.0	 1	 -30.0	 30.0;
	3835	 6750	 0.010826	 0.029992	 0.0	 991	 991	 991	 0.0	 0.0	 1	 -30.0	 30.0;
	3835	 6750	 0.012876	 0.028058	 0.0	 1024	 1024	 1024	 0.0	 0.0	 1	 -30.0	 30.0;
	3454	 7619	 0.034248	 0.143124	 0.0	 215	 215	 215	 0.0	 0.0	 1	 -30.0	 30.0;
	8790	 7619	 0.015421	 0.066364	 0.0	 464	 464	 464	 0.0	 0.0	 1	 -30.0	 30.0;
	7589	 8567	 0.014512	 0.035901	 0.0	 816	 816	 816	 0.0	 0.0	 1	 -30.0	 30.0;
	9285	 2035	 0.00863	 0.054419	 0.0	 574	 574	 574	 0.0	 0.0	 1	 -30.0	 30.0;
	9285	 2035	 0.008461	 0.055479	 0.0	 563	 563	 563	 0.0	 0.0	 1	 -30.0	 30.0;
	704	 6273	 0.013256	 0.073248	 0.0	 425	 425	 425	 0.0	 0.0	 1	 -30.0	 30.0;
	13276	 6273	 0.004033	 0.018174	 0.0	 1697	 1697	 1697	 0.0	 0.0	 1	 -30.0	 30.0;
	929	 5532	 0.016008	 0.027066	 0.0	 1005	 1005	 1005	 0.0	 0.0	 1	 -30.0	 30.0;
	7618	 5318	 0.013537	 0.070083	 0.0	 443	 443	 443	 0.0	 0.0	 1	 -30.0	 30.0;
	11426	 7618	 0.004744	 0.024876	 0.0	 1248	 1248	 1248	 0.0	 0.0	 1	 -30.0	 30.0;
	4992	 3974	 0.014364	 0.037438	 0.0	 788	 788	 788	 0.0	 0.0	 1	 -30.0	 30.0;
	12254	 3207	 0.010364	 0.020314	 0.0	 1649	 1649	 1649	 0.0	 0.0	 1	 -30.0	 30.0;
	3207	 5414	 0.007289	 0.018207	 0.0	 1917	 1917	 1917	 0.0	 0.0	 1	 -30.0	 30.0;
	12316	 2133	 0.011744	 0.052446	 0.0	 588	 588	 588	 0.0	 0.0	 1	 -30.0	 30.0;
	10920	 12316	 0.015438	 0.062876	 0.0	 488	 488	 488	 0.0	 0.0	 1	 -30.0	 30.0;
	13321	 3581	 0.00157	 0.01612	 0.0	 2343	 2343	 2343	 0.0	 0.0	 1	 -30.0	 30.0;
	13321	 3581	 0.00154	 0.01643	 0.0	 2300	 2300	 2300	 0.0	 0.0	 1	 -30.0	 30.0;
	5373	 7895	 0.001967	 0.008438	 0.0	 3646	 3646	 3646	 0.0	 0.0	 1	 -30.0	 30.0;
	7895	 2339	 0.01162	 0.033653	 0.0	 888	 888	 888	 0.0	 0.0	 1	 -30.0	 30.0;
	1643	 1248	 0.006901	 0.04661	 0.0	 671	 671	 671	 0.0	 0.0	 1	 -30.0	 30.0;
	1643	 1248	 0.00782	 0.04568	 0.0	 682	 682	 682	 0.0	 0.0	 1	 -30.0	 30.0;
	4107	 1248	 0.005401	 0.0343	 0.0	 910	 910	 910	 0.0	 0.0	 1	 -30.0	 30.0;
	969	 1248	 0.011419	 0.07275	 0.0	 429	 429	 429	 0.0	 0.0	 1	 -30.0	 30.0;
	6446	 8749	 0.01044	 0.05919	 0.0	 626	 626	 626	 0.0	 0.0	 1	 -30.0	 30.0;
	13205	 1542	 0.050314	 0.112132	 0.0	 258	 258	 258	 0.0	 0.0	 1	 -30.0	 30.0;
	13205	 1542	 0.057017	 0.109893	 0.0	 256	 256	 256	 0.0	 0.0	 1	 -30.0	 30.0;
	1542	 6267	 0.007	 0.028231	 0.0	 1087	 1087	 1087	 0.0	 0.0	 1	 -30.0	 30.0;
	1542	 12445	 0.010719	 0.040868	 0.0	 748	 748	 748	 0.0	 0.0	 1	 -30.0	 30.0;
	1542	 5669	 0.04443	 0.10976	 0.0	 267	 267	 267	 0.0	 0.0	 1	 -30.0	 30.0;
	1542	 827	 0.021372	 0.121033	 0.0	 258	 258	 258	 0.0	 0.0	 1	 -30.0	 30.0;
	1542	 1243	 0.020579	 0.095331	 0.0	 324	 324	 324	 0.0	 0.0	 1	 -30.0	 30.0;
	4186	 13205	 0.02386	 0.06986	 0.0	 428	 428	 428	 0.0	 0.0	 1	 -30.0	 30.0;
	13109	 4186	 0.062901	 0.105628	 0.0	 257	 257	 257	 0.0	 0.0	 1	 -30.0	 30.0;
	4186	 3008	 0.035686	 0.149314	 0.0	 206	 206	 206	 0.0	 0.0	 1	 -30.0	 30.0;
	9516	 4186	 0.00181	 0.006876	 0.0	 4443	 4443	 4443	 0.0	 0.0	 1	 -30.0	 30.0;
	2888	 4186	 0.002628	 0.01462	 0.0	 2127	 2127	 2127	 0.0	 0.0	 1	 -30.0	 30.0;
	2888	 4186	 0.002983	 0.014331	 0.0	 2158	 2158	 2158	 0.0	 0.0	 1	 -30.0	 30.0;
	620	 4186	 0.006157	 0.03114	 0.0	 996	 996	 996	 0.0	 0.0	 1	 -30.0	 30.0;
	2879	 10925	 0.022	 0.043066	 0.0	 654	 654	 654	 0.0	 0.0	 1	 -30.0	 30.0;
	2009	 2879	 0.013438	 0.033479	 0.0	 876	 876	 876	 0.0	 0.0	 1	 -30.0	 30.0;
	2879	 12615	 0.013488	 0.028893	 0.0	 991	 991	 991	 0.0	 0.0	 1	 -30.0	 30.0;
	4993	 13570	 0.114058	 0.230033	 0.0	 124	 124	 124	 0.0	 0.0	 1	 -30.0	 30.0;
	13570	 1328	 0.062901	 0.133777	 0.0	 214	 214	 214	 0.0	 0.0	 1	 -30.0	 30.0;
	13570	 2823	 0.041868	 0.106554	 0.0	 276	 276	 276	 0.0	 0.0	 1	 -30.0	 30.0;
	4986	 12249	 0.052347	 0.07786	 0.0	 337	 337	 337	 0.0	 0.0	 1	 -30.0	 30.0;
	12249	 8102	 0.003099	 0.006174	 0.0	 4573	 4573	 4573	 0.0	 0.0	 1	 -30.0	 30.0;
	1249	 10766	 0.04357	 0.108678	 0.0	 270	 270	 270	 0.0	 0.0	 1	 -30.0	 30.0;
	1249	 12030	 0.020893	 0.043289	 0.0	 658	 658	 658	 0.0	 0.0	 1	 -30.0	 30.0;
	6684	 10725	 0.035289	 0.072058	 0.0	 394	 394	 394	 0.0	 0.0	 1	 -30.0	 30.0;
	3008	 13205	 0.050579	 0.074298	 0.0	 352	 352	 352	 0.0	 0.0	 1	 -30.0	 30.0;
	3120	 13205	 0.042934	 0.087917	 0.0	 323	 323	 323	 0.0	 0.0	 1	 -30.0	 30.0;
	1164	 10414	 0.036711	 0.086397	 0.0	 337	 337	 337	 0.0	 0.0	 1	 -30.0	 30.0;
	10414	 12254	 0.053124	 0.100066	 0.0	 335	 335	 335	 0.0	 0.0	 1	 -30.0	 30.0;
	10414	 5974	 0.022959	 0.041727	 0.0	 664	 664	 664	 0.0	 0.0	 1	 -30.0	 30.0;
	5834	 2346	 0.00476	 0.023868	 0.0	 1298	 1298	 1298	 0.0	 0.0	 1	 -30.0	 30.0;
	11341	 5834	 0.005529	 0.011182	 0.0	 2533	 2533	 2533	 0.0	 0.0	 1	 -30.0	 30.0;
	11068	 1054	 0.00183	 0.02821	 0.0	 1330	 1330	 1330	 0.0	 0.0	 1	 -30.0	 30.0;
	10919	 11068	 0.00198	 0.02074	 0.0	 1805	 1805	 1805	 0.0	 0.0	 1	 -30.0	 30.0;
	13146	 8672	 0.022917	 0.094893	 0.0	 324	 324	 324	 0.0	 0.0	 1	 -30.0	 30.0;
	13146	 8672	 0.023347	 0.092868	 0.0	 330	 330	 330	 0.0	 0.0	 1	 -30.0	 30.0;
	8672	 4319	 0.030364	 0.073256	 0.0	 399	 399	 399	 0.0	 0.0	 1	 -30.0	 30.0;
	8672	 9445	 0.004562	 0.020132	 0.0	 1531	 1531	 1531	 0.0	 0.0	 1	 -30.0	 30.0;
	8672	 9445	 0.010562	 0.020686	 0.0	 1360	 1360	 1360	 0.0	 0.0	 1	 -30.0	 30.0;
	1328	 8672	 0.01838	 0.07314	 0.0	 419	 419	 419	 0.0	 0.0	 1	 -30.0	 30.0;
	8672	 7355	 0.005628	 0.029702	 0.0	 1045	 1045	 1045	 0.0	 0.0	 1	 -30.0	 30.0;
	8672	 7355	 0.005777	 0.029273	 0.0	 1059	 1059	 1059	 0.0	 0.0	 1	 -30.0	 30.0;
	4023	 8672	 0.014529	 0.236802	 0.0	 134	 134	 134	 0.0	 0.0	 1	 -30.0	 30.0;
	3711	 2475	 0.005818	 0.032182	 0.0	 966	 966	 966	 0.0	 0.0	 1	 -30.0	 30.0;
	3711	 6883	 0.003636	 0.021843	 0.0	 1427	 1427	 1427	 0.0	 0.0	 1	 -30.0	 30.0;
	5019	 2900	 0.00318	 0.02624	 0.0	 1196	 1196	 1196	 0.0	 0.0	 1	 -30.0	 30.0;
	5019	 10919	 0.00442	 0.03649	 0.0	 1033	 1033	 1033	 0.0	 0.0	 1	 -30.0	 30.0;
	6742	 2355	 0.005099	 0.027868	 0.0	 1115	 1115	 1115	 0.0	 0.0	 1	 -30.0	 30.0;
	6742	 2475	 0.00995	 0.049397	 0.0	 627	 627	 627	 0.0	 0.0	 1	 -30.0	 30.0;
	6742	 2475	 0.01014	 0.048397	 0.0	 639	 639	 639	 0.0	 0.0	 1	 -30.0	 30.0;
	6742	 2401	 0.007917	 0.04757	 0.0	 656	 656	 656	 0.0	 0.0	 1	 -30.0	 30.0;
	6742	 137	 0.004008	 0.022182	 0.0	 1402	 1402	 1402	 0.0	 0.0	 1	 -30.0	 30.0;
	6742	 298	 0.006603	 0.039124	 0.0	 797	 797	 797	 0.0	 0.0	 1	 -30.0	 30.0;
	12254	 8213	 0.00657	 0.028281	 0.0	 1295	 1295	 1295	 0.0	 0.0	 1	 -30.0	 30.0;
	10766	 12254	 0.071471	 0.124661	 0.0	 265	 265	 265	 0.0	 0.0	 1	 -30.0	 30.0;
	10766	 12254	 0.069983	 0.127058	 0.0	 262	 262	 262	 0.0	 0.0	 1	 -30.0	 30.0;
	12254	 5414	 0.00743	 0.018182	 0.0	 1914	 1914	 1914	 0.0	 0.0	 1	 -30.0	 30.0;
	13072	 11429	 0.004653	 0.024339	 0.0	 1275	 1275	 1275	 0.0	 0.0	 1	 -30.0	 30.0;
	10725	 13072	 0.007157	 0.03462	 0.0	 894	 894	 894	 0.0	 0.0	 1	 -30.0	 30.0;
	10725	 13072	 0.007298	 0.033909	 0.0	 911	 911	 911	 0.0	 0.0	 1	 -30.0	 30.0;
	9904	 6075	 0.00024	 0.00281	 0.0	 11201	 11201	 11201	 0.0	 0.0	 1	 -30.0	 30.0;
	7874	 10614	 0.010711	 0.056603	 0.0	 549	 549	 549	 0.0	 0.0	 1	 -30.0	 30.0;
	5506	 7874	 0.064273	 0.068058	 0.0	 338	 338	 338	 0.0	 0.0	 1	 -30.0	 30.0;
	11200	 8129	 0.013917	 0.06676	 0.0	 464	 464	 464	 0.0	 0.0	 1	 -30.0	 30.0;
	11200	 12693	 0.034298	 0.076091	 0.0	 379	 379	 379	 0.0	 0.0	 1	 -30.0	 30.0;
	6703	 4558	 0.00676	 0.044942	 0.0	 696	 696	 696	 0.0	 0.0	 1	 -30.0	 30.0;
	6703	 6143	 0.025579	 0.109438	 0.0	 282	 282	 282	 0.0	 0.0	 1	 -30.0	 30.0;
	6703	 6143	 0.026091	 0.107198	 0.0	 287	 287	 287	 0.0	 0.0	 1	 -30.0	 30.0;
	1864	 4947	 0.00319	 0.01543	 0.0	 2005	 2005	 2005	 0.0	 0.0	 1	 -30.0	 30.0;
	4947	 3957	 0.003669	 0.014628	 0.0	 2095	 2095	 2095	 0.0	 0.0	 1	 -30.0	 30.0;
	4122	 2261	 0.001653	 0.007331	 0.0	 4204	 4204	 4204	 0.0	 0.0	 1	 -30.0	 30.0;
	704	 4122	 0.009661	 0.04095	 0.0	 751	 751	 751	 0.0	 0.0	 1	 -30.0	 30.0;
	2145	 13321	 0.00089	 0.00981	 0.0	 3207	 3207	 3207	 0.0	 0.0	 1	 -30.0	 30.0;
	2145	 13321	 0.00087	 0.01	 0.0	 3147	 3147	 3147	 0.0	 0.0	 1	 -30.0	 30.0;
	13321	 6075	 0.00114	 0.01867	 0.0	 1689	 1689	 1689	 0.0	 0.0	 1	 -30.0	 30.0;
	7175	 4001	 0.034661	 0.089231	 0.0	 330	 330	 330	 0.0	 0.0	 1	 -30.0	 30.0;
	1580	 7175	 0.009463	 0.018603	 0.0	 1514	 1514	 1514	 0.0	 0.0	 1	 -30.0	 30.0;
	4065	 10381	 0.032777	 0.061248	 0.0	 455	 455	 455	 0.0	 0.0	 1	 -30.0	 30.0;
	10029	 4065	 0.029182	 0.043207	 0.0	 728	 728	 728	 0.0	 0.0	 1	 -30.0	 30.0;
	9868	 8688	 0.012826	 0.022587	 0.0	 1217	 1217	 1217	 0.0	 0.0	 1	 -30.0	 30.0;
	2806	 13470	 0.01519	 0.065017	 0.0	 474	 474	 474	 0.0	 0.0	 1	 -30.0	 30.0;
	11304	 13470	 0.002107	 0.009	 0.0	 3418	 3418	 3418	 0.0	 0.0	 1	 -30.0	 30.0;
	13470	 6629	 0.010099	 0.046587	 0.0	 663	 663	 663	 0.0	 0.0	 1	 -30.0	 30.0;
	298	 2355	 0.001934	 0.009008	 0.0	 3429	 3429	 3429	 0.0	 0.0	 1	 -30.0	 30.0;
	9130	 10925	 0.041537	 0.116843	 0.0	 255	 255	 255	 0.0	 0.0	 1	 -30.0	 30.0;
	6788	 2099	 0.013091	 0.050041	 0.0	 611	 611	 611	 0.0	 0.0	 1	 -30.0	 30.0;
	1565	 10381	 0.003058	 0.005579	 0.0	 4965	 4965	 4965	 0.0	 0.0	 1	 -30.0	 30.0;
	2396	 13146	 0.008554	 0.035397	 0.0	 868	 868	 868	 0.0	 0.0	 1	 -30.0	 30.0;
	13616	 7940	 0.020314	 0.102727	 0.0	 302	 302	 302	 0.0	 0.0	 1	 -30.0	 30.0;
	7429	 7940	 0.005008	 0.025364	 0.0	 1222	 1222	 1222	 0.0	 0.0	 1	 -30.0	 30.0;
	8054	 7940	 0.042182	 0.161132	 0.0	 190	 190	 190	 0.0	 0.0	 1	 -30.0	 30.0;
	11423	 1862	 0.00014	 0.000581	 0.0	 52855	 52855	 52855	 0.0	 0.0	 1	 -30.0	 30.0;
	5014	 3060	 0.001339	 0.007438	 0.0	 4180	 4180	 4180	 0.0	 0.0	 1	 -30.0	 30.0;
	3533	 2261	 0.004223	 0.009347	 0.0	 3080	 3080	 3080	 0.0	 0.0	 1	 -30.0	 30.0;
	2261	 8093	 0.016314	 0.034562	 0.0	 827	 827	 827	 0.0	 0.0	 1	 -30.0	 30.0;
	13276	 2261	 0.009331	 0.045339	 0.0	 683	 683	 683	 0.0	 0.0	 1	 -30.0	 30.0;
	3533	 5893	 0.00038	 0.002769	 0.0	 11302	 11302	 11302	 0.0	 0.0	 1	 -30.0	 30.0;
	13276	 3533	 0.007066	 0.043107	 0.0	 724	 724	 724	 0.0	 0.0	 1	 -30.0	 30.0;
	2626	 2806	 0.003124	 0.017231	 0.0	 1804	 1804	 1804	 0.0	 0.0	 1	 -30.0	 30.0;
	3678	 7956	 0.020512	 0.048562	 0.0	 600	 600	 600	 0.0	 0.0	 1	 -30.0	 30.0;
	3120	 7956	 0.016934	 0.03314	 0.0	 849	 849	 849	 0.0	 0.0	 1	 -30.0	 30.0;
	13342	 5373	 0.011083	 0.030769	 0.0	 966	 966	 966	 0.0	 0.0	 1	 -30.0	 30.0;
	704	 9652	 0.024314	 0.099174	 0.0	 310	 310	 310	 0.0	 0.0	 1	 -30.0	 30.0;
	704	 9652	 0.024769	 0.097058	 0.0	 316	 316	 316	 0.0	 0.0	 1	 -30.0	 30.0;
	704	 9652	 0.025231	 0.09495	 0.0	 322	 322	 322	 0.0	 0.0	 1	 -30.0	 30.0;
	704	 7536	 0.012917	 0.049612	 0.0	 617	 617	 617	 0.0	 0.0	 1	 -30.0	 30.0;
	704	 4787	 0.048058	 0.135157	 0.0	 221	 221	 221	 0.0	 0.0	 1	 -30.0	 30.0;
	704	 5893	 0.009372	 0.048876	 0.0	 635	 635	 635	 0.0	 0.0	 1	 -30.0	 30.0;
	704	 7941	 0.00538	 0.031752	 0.0	 981	 981	 981	 0.0	 0.0	 1	 -30.0	 30.0;
	704	 7941	 0.005273	 0.029397	 0.0	 1058	 1058	 1058	 0.0	 0.0	 1	 -30.0	 30.0;
	704	 13185	 0.044562	 0.09762	 0.0	 295	 295	 295	 0.0	 0.0	 1	 -30.0	 30.0;
	9652	 5647	 0.017876	 0.097091	 0.0	 320	 320	 320	 0.0	 0.0	 1	 -30.0	 30.0;
	9652	 5203	 0.037207	 0.166008	 0.0	 186	 186	 186	 0.0	 0.0	 1	 -30.0	 30.0;
	10919	 13151	 0.00018	 0.00154	 0.0	 24246	 24246	 24246	 0.0	 0.0	 1	 -30.0	 30.0;
	10919	 13151	 0.00023	 0.00194	 0.0	 19243	 19243	 19243	 0.0	 0.0	 1	 -30.0	 30.0;
	1784	 573	 0.005669	 0.040521	 0.0	 773	 773	 773	 0.0	 0.0	 1	 -30.0	 30.0;
	1784	 349	 0.001581	 0.012159	 0.0	 2577	 2577	 2577	 0.0	 0.0	 1	 -30.0	 30.0;
	1784	 349	 0.001409	 0.013781	 0.0	 2281	 2281	 2281	 0.0	 0.0	 1	 -30.0	 30.0;
	1784	 5136	 0.00111	 0.0075	 0.0	 4167	 4167	 4167	 0.0	 0.0	 1	 -30.0	 30.0;
	1784	 817	 0.0115	 0.07662	 0.0	 408	 408	 408	 0.0	 0.0	 1	 -30.0	 30.0;
	3151	 4224	 0.002661	 0.01286	 0.0	 2406	 2406	 2406	 0.0	 0.0	 1	 -30.0	 30.0;
	2475	 6883	 0.010793	 0.046942	 0.0	 656	 656	 656	 0.0	 0.0	 1	 -30.0	 30.0;
	1384	 13616	 0.023826	 0.100992	 0.0	 305	 305	 305	 0.0	 0.0	 1	 -30.0	 30.0;
	13616	 11135	 0.014603	 0.07986	 0.0	 390	 390	 390	 0.0	 0.0	 1	 -30.0	 30.0;
	13616	 7429	 0.026132	 0.099818	 0.0	 307	 307	 307	 0.0	 0.0	 1	 -30.0	 30.0;
	11794	 7030	 0.002289	 0.012554	 0.0	 2476	 2476	 2476	 0.0	 0.0	 1	 -30.0	 30.0;
	11794	 9130	 0.00743	 0.030719	 0.0	 1000	 1000	 1000	 0.0	 0.0	 1	 -30.0	 30.0;
	12314	 4986	 0.014653	 0.029174	 0.0	 968	 968	 968	 0.0	 0.0	 1	 -30.0	 30.0;
	8682	 12314	 0.016388	 0.04286	 0.0	 689	 689	 689	 0.0	 0.0	 1	 -30.0	 30.0;
	11192	 13281	 0.056248	 0.122041	 0.0	 236	 236	 236	 0.0	 0.0	 1	 -30.0	 30.0;
	506	 13281	 0.024901	 0.049099	 0.0	 574	 574	 574	 0.0	 0.0	 1	 -30.0	 30.0;
	6819	 10524	 0.026554	 0.061851	 0.0	 470	 470	 470	 0.0	 0.0	 1	 -30.0	 30.0;
	4993	 9845	 0.073678	 0.305793	 0.0	 101	 101	 101	 0.0	 0.0	 1	 -30.0	 30.0;
	4477	 4993	 0.029083	 0.060017	 0.0	 474	 474	 474	 0.0	 0.0	 1	 -30.0	 30.0;
	4993	 95	 0.021893	 0.134521	 0.0	 232	 232	 232	 0.0	 0.0	 1	 -30.0	 30.0;
	1873	 8072	 0.018983	 0.03914	 0.0	 727	 727	 727	 0.0	 0.0	 1	 -30.0	 30.0;
	8072	 8263	 0.024529	 0.041612	 0.0	 654	 654	 654	 0.0	 0.0	 1	 -30.0	 30.0;
	10342	 7920	 0.039421	 0.085686	 0.0	 335	 335	 335	 0.0	 0.0	 1	 -30.0	 30.0;
	10766	 7920	 0.039421	 0.085769	 0.0	 335	 335	 335	 0.0	 0.0	 1	 -30.0	 30.0;
	10607	 10342	 0.00876	 0.016901	 0.0	 1660	 1660	 1660	 0.0	 0.0	 1	 -30.0	 30.0;
	5917	 10607	 0.006967	 0.018248	 0.0	 1618	 1618	 1618	 0.0	 0.0	 1	 -30.0	 30.0;
	12340	 3957	 0.025099	 0.107901	 0.0	 286	 286	 286	 0.0	 0.0	 1	 -30.0	 30.0;
	5429	 12340	 0.02605	 0.103438	 0.0	 297	 297	 297	 0.0	 0.0	 1	 -30.0	 30.0;
	7589	 3232	 0.012719	 0.033719	 0.0	 877	 877	 877	 0.0	 0.0	 1	 -30.0	 30.0;
	3232	 11426	 0.022273	 0.043661	 0.0	 645	 645	 645	 0.0	 0.0	 1	 -30.0	 30.0;
	3079	 7612	 0.00124	 0.006653	 0.0	 4668	 4668	 4668	 0.0	 0.0	 1	 -30.0	 30.0;
	3069	 7612	 0.001587	 0.007636	 0.0	 4051	 4051	 4051	 0.0	 0.0	 1	 -30.0	 30.0;
	8971	 5554	 0.006207	 0.032331	 0.0	 960	 960	 960	 0.0	 0.0	 1	 -30.0	 30.0;
	8971	 5554	 0.006083	 0.032942	 0.0	 943	 943	 943	 0.0	 0.0	 1	 -30.0	 30.0;
	5554	 5506	 0.001314	 0.005446	 0.0	 5639	 5639	 5639	 0.0	 0.0	 1	 -30.0	 30.0;
	6267	 641	 0.003851	 0.01662	 0.0	 1852	 1852	 1852	 0.0	 0.0	 1	 -30.0	 30.0;
	4329	 11808	 0.005124	 0.031934	 0.0	 977	 977	 977	 0.0	 0.0	 1	 -30.0	 30.0;
	13276	 11808	 0.005008	 0.029562	 0.0	 1054	 1054	 1054	 0.0	 0.0	 1	 -30.0	 30.0;
	863	 12031	 0.048331	 0.094372	 0.0	 298	 298	 298	 0.0	 0.0	 1	 -30.0	 30.0;
	863	 3740	 0.015678	 0.073826	 0.0	 419	 419	 419	 0.0	 0.0	 1	 -30.0	 30.0;
	3836	 1226	 0.005579	 0.019174	 0.0	 1582	 1582	 1582	 0.0	 0.0	 1	 -30.0	 30.0;
	506	 3836	 0.029397	 0.077132	 0.0	 383	 383	 383	 0.0	 0.0	 1	 -30.0	 30.0;
	2401	 1226	 0.002901	 0.006802	 0.0	 4272	 4272	 4272	 0.0	 0.0	 1	 -30.0	 30.0;
	2401	 137	 0.004769	 0.020826	 0.0	 1479	 1479	 1479	 0.0	 0.0	 1	 -30.0	 30.0;
	2401	 12891	 0.031388	 0.06305	 0.0	 449	 449	 449	 0.0	 0.0	 1	 -30.0	 30.0;
	2401	 5717	 0.032587	 0.068752	 0.0	 416	 416	 416	 0.0	 0.0	 1	 -30.0	 30.0;
	2401	 1918	 0.042802	 0.083983	 0.0	 336	 336	 336	 0.0	 0.0	 1	 -30.0	 30.0;
	5647	 5203	 0.01214	 0.069124	 0.0	 451	 451	 451	 0.0	 0.0	 1	 -30.0	 30.0;
	4001	 2673	 0.008388	 0.017033	 0.0	 1664	 1664	 1664	 0.0	 0.0	 1	 -30.0	 30.0;
	10947	 12943	 0.008521	 0.046653	 0.0	 667	 667	 667	 0.0	 0.0	 1	 -30.0	 30.0;
	10947	 12545	 0.003331	 0.013818	 0.0	 2223	 2223	 2223	 0.0	 0.0	 1	 -30.0	 30.0;
	3834	 573	 0.016729	 0.090401	 0.0	 344	 344	 344	 0.0	 0.0	 1	 -30.0	 30.0;
	3834	 8812	 0.01526	 0.081479	 0.0	 382	 382	 382	 0.0	 0.0	 1	 -30.0	 30.0;
	3834	 12618	 0.00905	 0.068219	 0.0	 460	 460	 460	 0.0	 0.0	 1	 -30.0	 30.0;
	3834	 2745	 0.01205	 0.08575	 0.0	 439	 439	 439	 0.0	 0.0	 1	 -30.0	 30.0;
	3834	 10184	 0.007841	 0.04113	 0.0	 755	 755	 755	 0.0	 0.0	 1	 -30.0	 30.0;
	124	 355	 0.002413	 0.010686	 0.0	 2884	 2884	 2884	 0.0	 0.0	 1	 -30.0	 30.0;
	1243	 124	 0.005041	 0.022769	 0.0	 1355	 1355	 1355	 0.0	 0.0	 1	 -30.0	 30.0;
	3420	 46	 0.00126	 0.007531	 0.0	 4137	 4137	 4137	 0.0	 0.0	 1	 -30.0	 30.0;
	11341	 2931	 0.00176	 0.007603	 0.0	 4048	 4048	 4048	 0.0	 0.0	 1	 -30.0	 30.0;
	11341	 2931	 0.00157	 0.00862	 0.0	 3606	 3606	 3606	 0.0	 0.0	 1	 -30.0	 30.0;
	13109	 3678	 0.02743	 0.059157	 0.0	 485	 485	 485	 0.0	 0.0	 1	 -30.0	 30.0;
	2396	 11739	 0.028992	 0.060893	 0.0	 469	 469	 469	 0.0	 0.0	 1	 -30.0	 30.0;
	5181	 3454	 0.012942	 0.051851	 0.0	 592	 592	 592	 0.0	 0.0	 1	 -30.0	 30.0;
	1565	 5181	 0.071157	 0.104149	 0.0	 251	 251	 251	 0.0	 0.0	 1	 -30.0	 30.0;
	1677	 9791	 0.002017	 0.010686	 0.0	 2905	 2905	 2905	 0.0	 0.0	 1	 -30.0	 30.0;
	4536	 9791	 0.00195	 0.009364	 0.0	 3303	 3303	 3303	 0.0	 0.0	 1	 -30.0	 30.0;
	4536	 9791	 0.001992	 0.009174	 0.0	 3365	 3365	 3365	 0.0	 0.0	 1	 -30.0	 30.0;
	1873	 834	 0.027017	 0.074521	 0.0	 399	 399	 399	 0.0	 0.0	 1	 -30.0	 30.0;
	834	 10342	 0.025107	 0.072339	 0.0	 413	 413	 413	 0.0	 0.0	 1	 -30.0	 30.0;
	6374	 5485	 0.002942	 0.006248	 0.0	 4574	 4574	 4574	 0.0	 0.0	 1	 -30.0	 30.0;
	5485	 5620	 0.006983	 0.028678	 0.0	 1071	 1071	 1071	 0.0	 0.0	 1	 -30.0	 30.0;
	2673	 8086	 0.049636	 0.077364	 0.0	 344	 344	 344	 0.0	 0.0	 1	 -30.0	 30.0;
	13014	 8086	 0.071752	 0.121198	 0.0	 225	 225	 225	 0.0	 0.0	 1	 -30.0	 30.0;
	11304	 8024	 0.00219	 0.009174	 0.0	 3350	 3350	 3350	 0.0	 0.0	 1	 -30.0	 30.0;
	8858	 11304	 0.018719	 0.067983	 0.0	 448	 448	 448	 0.0	 0.0	 1	 -30.0	 30.0;
	13276	 7536	 0.006339	 0.025397	 0.0	 1207	 1207	 1207	 0.0	 0.0	 1	 -30.0	 30.0;
	10614	 28	 0.011876	 0.064967	 0.0	 479	 479	 479	 0.0	 0.0	 1	 -30.0	 30.0;
	9845	 12392	 0.004603	 0.024603	 0.0	 1262	 1262	 1262	 0.0	 0.0	 1	 -30.0	 30.0;
	2547	 9845	 0.037934	 0.102868	 0.0	 289	 289	 289	 0.0	 0.0	 1	 -30.0	 30.0;
	4319	 10695	 0.020818	 0.067711	 0.0	 446	 446	 446	 0.0	 0.0	 1	 -30.0	 30.0;
	3974	 1677	 0.020223	 0.048471	 0.0	 602	 602	 602	 0.0	 0.0	 1	 -30.0	 30.0;
	1677	 5506	 0.00705	 0.034314	 0.0	 902	 902	 902	 0.0	 0.0	 1	 -30.0	 30.0;
	1677	 3032	 0.015388	 0.074008	 0.0	 418	 418	 418	 0.0	 0.0	 1	 -30.0	 30.0;
	1677	 3032	 0.015066	 0.075463	 0.0	 411	 411	 411	 0.0	 0.0	 1	 -30.0	 30.0;
	1873	 43	 0.060331	 0.128752	 0.0	 223	 223	 223	 0.0	 0.0	 1	 -30.0	 30.0;
	43	 10261	 0.037752	 0.085843	 0.0	 337	 337	 337	 0.0	 0.0	 1	 -30.0	 30.0;
	43	 929	 0.060471	 0.109992	 0.0	 252	 252	 252	 0.0	 0.0	 1	 -30.0	 30.0;
	8263	 43	 0.021959	 0.050058	 0.0	 578	 578	 578	 0.0	 0.0	 1	 -30.0	 30.0;
	10342	 5346	 0.005347	 0.026198	 0.0	 1182	 1182	 1182	 0.0	 0.0	 1	 -30.0	 30.0;
	5917	 5346	 0.005058	 0.015769	 0.0	 1908	 1908	 1908	 0.0	 0.0	 1	 -30.0	 30.0;
	1384	 1590	 0.010256	 0.053223	 0.0	 583	 583	 583	 0.0	 0.0	 1	 -30.0	 30.0;
	5248	 12392	 0.01476	 0.082157	 0.0	 379	 379	 379	 0.0	 0.0	 1	 -30.0	 30.0;
	6819	 11057	 0.047843	 0.112033	 0.0	 260	 260	 260	 0.0	 0.0	 1	 -30.0	 30.0;
	1832	 6111	 0.013909	 0.036793	 0.0	 804	 804	 804	 0.0	 0.0	 1	 -30.0	 30.0;
	6111	 4477	 0.030289	 0.064818	 0.0	 442	 442	 442	 0.0	 0.0	 1	 -30.0	 30.0;
	6111	 1580	 0.026132	 0.123132	 0.0	 251	 251	 251	 0.0	 0.0	 1	 -30.0	 30.0;
	6111	 1580	 0.026628	 0.120562	 0.0	 256	 256	 256	 0.0	 0.0	 1	 -30.0	 30.0;
	5113	 6111	 0.016727	 0.063959	 0.0	 478	 478	 478	 0.0	 0.0	 1	 -30.0	 30.0;
	9725	 7694	 0.002413	 0.010248	 0.0	 3001	 3001	 3001	 0.0	 0.0	 1	 -30.0	 30.0;
	9725	 6143	 0.009	 0.040843	 0.0	 756	 756	 756	 0.0	 0.0	 1	 -30.0	 30.0;
	641	 12445	 0.008421	 0.018488	 0.0	 1555	 1555	 1555	 0.0	 0.0	 1	 -30.0	 30.0;
	4277	 6863	 0.014917	 0.034322	 0.0	 845	 845	 845	 0.0	 0.0	 1	 -30.0	 30.0;
	4277	 3989	 0.00743	 0.035942	 0.0	 861	 861	 861	 0.0	 0.0	 1	 -30.0	 30.0;
	7694	 4277	 0.003851	 0.016	 0.0	 1920	 1920	 1920	 0.0	 0.0	 1	 -30.0	 30.0;
	7153	 4277	 0.00162	 0.008008	 0.0	 3867	 3867	 3867	 0.0	 0.0	 1	 -30.0	 30.0;
	5093	 1832	 0.014372	 0.045793	 0.0	 659	 659	 659	 0.0	 0.0	 1	 -30.0	 30.0;
	7435	 5093	 0.038678	 0.089967	 0.0	 323	 323	 323	 0.0	 0.0	 1	 -30.0	 30.0;
	11429	 6833	 0.009504	 0.021727	 0.0	 1332	 1332	 1332	 0.0	 0.0	 1	 -30.0	 30.0;
	6833	 2267	 0.018364	 0.096521	 0.0	 322	 322	 322	 0.0	 0.0	 1	 -30.0	 30.0;
	7355	 9445	 0.00195	 0.010669	 0.0	 2913	 2913	 2913	 0.0	 0.0	 1	 -30.0	 30.0;
	9445	 9055	 0.021182	 0.046826	 0.0	 615	 615	 615	 0.0	 0.0	 1	 -30.0	 30.0;
	10751	 11135	 0.031752	 0.131826	 0.0	 233	 233	 233	 0.0	 0.0	 1	 -30.0	 30.0;
	8024	 6629	 0.002917	 0.01238	 0.0	 2484	 2484	 2484	 0.0	 0.0	 1	 -30.0	 30.0;
	28	 2544	 0.016157	 0.035826	 0.0	 804	 804	 804	 0.0	 0.0	 1	 -30.0	 30.0;
	28	 4542	 0.003727	 0.020529	 0.0	 1514	 1514	 1514	 0.0	 0.0	 1	 -30.0	 30.0;
	28	 8739	 0.019992	 0.079231	 0.0	 387	 387	 387	 0.0	 0.0	 1	 -30.0	 30.0;
	4558	 2544	 0.023653	 0.094587	 0.0	 324	 324	 324	 0.0	 0.0	 1	 -30.0	 30.0;
	4542	 2168	 0.009322	 0.049058	 0.0	 633	 633	 633	 0.0	 0.0	 1	 -30.0	 30.0;
	8682	 2168	 0.026727	 0.146752	 0.0	 212	 212	 212	 0.0	 0.0	 1	 -30.0	 30.0;
	7537	 817	 0.000531	 0.002919	 0.0	 10647	 10647	 10647	 0.0	 0.0	 1	 -30.0	 30.0;
	832	 9055	 0.021992	 0.059397	 0.0	 499	 499	 499	 0.0	 0.0	 1	 -30.0	 30.0;
	832	 7435	 0.044413	 0.10176	 0.0	 285	 285	 285	 0.0	 0.0	 1	 -30.0	 30.0;
	5943	 832	 0.043223	 0.088562	 0.0	 321	 321	 321	 0.0	 0.0	 1	 -30.0	 30.0;
	5241	 4787	 0.006992	 0.014066	 0.0	 2011	 2011	 2011	 0.0	 0.0	 1	 -30.0	 30.0;
	2419	 7816	 0.007256	 0.028802	 0.0	 1064	 1064	 1064	 0.0	 0.0	 1	 -30.0	 30.0;
	2419	 7816	 0.006471	 0.032636	 0.0	 950	 950	 950	 0.0	 0.0	 1	 -30.0	 30.0;
	2419	 13185	 0.043198	 0.156397	 0.0	 195	 195	 195	 0.0	 0.0	 1	 -30.0	 30.0;
	3706	 3707	 0.016248	 0.04014	 0.0	 730	 730	 730	 0.0	 0.0	 1	 -30.0	 30.0;
	2035	 1643	 0.00206	 0.01393	 0.0	 2244	 2244	 2244	 0.0	 0.0	 1	 -30.0	 30.0;
	2035	 1643	 0.002021	 0.01419	 0.0	 2204	 2204	 2204	 0.0	 0.0	 1	 -30.0	 30.0;
	2035	 46	 0.00324	 0.02076	 0.0	 1504	 1504	 1504	 0.0	 0.0	 1	 -30.0	 30.0;
	2035	 46	 0.00318	 0.021159	 0.0	 1477	 1477	 1477	 0.0	 0.0	 1	 -30.0	 30.0;
	1873	 10342	 0.031603	 0.070331	 0.0	 410	 410	 410	 0.0	 0.0	 1	 -30.0	 30.0;
	3069	 1873	 0.003132	 0.014554	 0.0	 2122	 2122	 2122	 0.0	 0.0	 1	 -30.0	 30.0;
	9375	 1873	 0.006669	 0.032091	 0.0	 964	 964	 964	 0.0	 0.0	 1	 -30.0	 30.0;
	503	 12943	 0.008934	 0.046298	 0.0	 670	 670	 670	 0.0	 0.0	 1	 -30.0	 30.0;
	1284	 7760	 0.002942	 0.012008	 0.0	 2555	 2555	 2555	 0.0	 0.0	 1	 -30.0	 30.0;
	8213	 5974	 0.010942	 0.062207	 0.0	 601	 601	 601	 0.0	 0.0	 1	 -30.0	 30.0;
	8258	 8619	 0.002529	 0.011777	 0.0	 2623	 2623	 2623	 0.0	 0.0	 1	 -30.0	 30.0;
	8258	 743	 0.015107	 0.042769	 0.0	 697	 697	 697	 0.0	 0.0	 1	 -30.0	 30.0;
	10980	 13342	 0.00705	 0.022099	 0.0	 1362	 1362	 1362	 0.0	 0.0	 1	 -30.0	 30.0;
	8835	 5644	 0.038231	 0.105893	 0.0	 281	 281	 281	 0.0	 0.0	 1	 -30.0	 30.0;
	5774	 8835	 0.005901	 0.021289	 0.0	 1430	 1430	 1430	 0.0	 0.0	 1	 -30.0	 30.0;
	170	 7589	 0.013636	 0.022686	 0.0	 1194	 1194	 1194	 0.0	 0.0	 1	 -30.0	 30.0;
	10261	 929	 0.023826	 0.059364	 0.0	 494	 494	 494	 0.0	 0.0	 1	 -30.0	 30.0;
	10342	 5172	 0.016091	 0.045967	 0.0	 649	 649	 649	 0.0	 0.0	 1	 -30.0	 30.0;
	5172	 6309	 0.017033	 0.053008	 0.0	 568	 568	 568	 0.0	 0.0	 1	 -30.0	 30.0;
	1005	 5644	 0.017744	 0.09686	 0.0	 321	 321	 321	 0.0	 0.0	 1	 -30.0	 30.0;
	8619	 4221	 0.003636	 0.018818	 0.0	 1649	 1649	 1649	 0.0	 0.0	 1	 -30.0	 30.0;
	8619	 4221	 0.003562	 0.019174	 0.0	 1620	 1620	 1620	 0.0	 0.0	 1	 -30.0	 30.0;
	9594	 8172	 0.008256	 0.021909	 0.0	 1350	 1350	 1350	 0.0	 0.0	 1	 -30.0	 30.0;
	8172	 11429	 0.026917	 0.061636	 0.0	 470	 470	 470	 0.0	 0.0	 1	 -30.0	 30.0;
	8331	 6515	 0.022702	 0.057149	 0.0	 514	 514	 514	 0.0	 0.0	 1	 -30.0	 30.0;
	6515	 2339	 0.023983	 0.070124	 0.0	 427	 427	 427	 0.0	 0.0	 1	 -30.0	 30.0;
	5318	 3767	 0.035231	 0.078314	 0.0	 368	 368	 368	 0.0	 0.0	 1	 -30.0	 30.0;
	3767	 13014	 0.02462	 0.053603	 0.0	 536	 536	 536	 0.0	 0.0	 1	 -30.0	 30.0;
	7030	 7239	 0.008091	 0.03214	 0.0	 954	 954	 954	 0.0	 0.0	 1	 -30.0	 30.0;
	6894	 4936	 0.016793	 0.081388	 0.0	 381	 381	 381	 0.0	 0.0	 1	 -30.0	 30.0;
	4936	 1590	 0.008636	 0.047388	 0.0	 656	 656	 656	 0.0	 0.0	 1	 -30.0	 30.0;
	4991	 10342	 0.009364	 0.018207	 0.0	 1543	 1543	 1543	 0.0	 0.0	 1	 -30.0	 30.0;
	10342	 12030	 0.023331	 0.063727	 0.0	 466	 466	 466	 0.0	 0.0	 1	 -30.0	 30.0;
	10342	 4833	 0.014983	 0.033579	 0.0	 860	 860	 860	 0.0	 0.0	 1	 -30.0	 30.0;
	4536	 8971	 0.004636	 0.019678	 0.0	 1563	 1563	 1563	 0.0	 0.0	 1	 -30.0	 30.0;
	4536	 8971	 0.004727	 0.019273	 0.0	 1592	 1592	 1592	 0.0	 0.0	 1	 -30.0	 30.0;
	4329	 226	 0.018446	 0.089686	 0.0	 345	 345	 345	 0.0	 0.0	 1	 -30.0	 30.0;
	13276	 4329	 0.011529	 0.056587	 0.0	 547	 547	 547	 0.0	 0.0	 1	 -30.0	 30.0;
	3478	 9130	 0.00862	 0.021587	 0.0	 1359	 1359	 1359	 0.0	 0.0	 1	 -30.0	 30.0;
	3478	 4587	 0.005702	 0.013017	 0.0	 2223	 2223	 2223	 0.0	 0.0	 1	 -30.0	 30.0;
	9052	 942	 0.048256	 0.078099	 0.0	 345	 345	 345	 0.0	 0.0	 1	 -30.0	 30.0;
	942	 6300	 0.065529	 0.159802	 0.0	 183	 183	 183	 0.0	 0.0	 1	 -30.0	 30.0;
	8790	 942	 0.02681	 0.110702	 0.0	 278	 278	 278	 0.0	 0.0	 1	 -30.0	 30.0;
	95	 2547	 0.04538	 0.142983	 0.0	 211	 211	 211	 0.0	 0.0	 1	 -30.0	 30.0;
	1565	 1864	 0.024992	 0.097777	 0.0	 313	 313	 313	 0.0	 0.0	 1	 -30.0	 30.0;
	12991	 1864	 0.020256	 0.109372	 0.0	 284	 284	 284	 0.0	 0.0	 1	 -30.0	 30.0;
	1864	 762	 0.024636	 0.095653	 0.0	 320	 320	 320	 0.0	 0.0	 1	 -30.0	 30.0;
	3151	 7429	 0.003364	 0.017669	 0.0	 1757	 1757	 1757	 0.0	 0.0	 1	 -30.0	 30.0;
	5414	 13356	 0.018463	 0.039124	 0.0	 877	 877	 877	 0.0	 0.0	 1	 -30.0	 30.0;
	13356	 9309	 0.021636	 0.060793	 0.0	 490	 490	 490	 0.0	 0.0	 1	 -30.0	 30.0;
	10666	 170	 0.01786	 0.039711	 0.0	 726	 726	 726	 0.0	 0.0	 1	 -30.0	 30.0;
	573	 5136	 0.00588	 0.03186	 0.0	 975	 975	 975	 0.0	 0.0	 1	 -30.0	 30.0;
	10215	 10751	 0.045058	 0.177512	 0.0	 173	 173	 173	 0.0	 0.0	 1	 -30.0	 30.0;
	10751	 3918	 0.003686	 0.017711	 0.0	 1747	 1747	 1747	 0.0	 0.0	 1	 -30.0	 30.0;
	10751	 3918	 0.003612	 0.018058	 0.0	 1716	 1716	 1716	 0.0	 0.0	 1	 -30.0	 30.0;
	10751	 3918	 0.007876	 0.021066	 0.0	 1405	 1405	 1405	 0.0	 0.0	 1	 -30.0	 30.0;
	3221	 10751	 0.03186	 0.159347	 0.0	 195	 195	 195	 0.0	 0.0	 1	 -30.0	 30.0;
	13014	 5248	 0.034901	 0.071347	 0.0	 398	 398	 398	 0.0	 0.0	 1	 -30.0	 30.0;
	2640	 7816	 0.006339	 0.033281	 0.0	 933	 933	 933	 0.0	 0.0	 1	 -30.0	 30.0;
	2640	 7816	 0.006207	 0.033917	 0.0	 917	 917	 917	 0.0	 0.0	 1	 -30.0	 30.0;
	5203	 7816	 0.006207	 0.034983	 0.0	 890	 890	 890	 0.0	 0.0	 1	 -30.0	 30.0;
	9546	 13276	 0.006289	 0.024661	 0.0	 1242	 1242	 1242	 0.0	 0.0	 1	 -30.0	 30.0;
	9546	 11101	 0.002554	 0.01376	 0.0	 2258	 2258	 2258	 0.0	 0.0	 1	 -30.0	 30.0;
	1328	 11739	 0.003579	 0.01486	 0.0	 2067	 2067	 2067	 0.0	 0.0	 1	 -30.0	 30.0;
	8129	 2626	 0.01495	 0.02843	 0.0	 984	 984	 984	 0.0	 0.0	 1	 -30.0	 30.0;
	2267	 10816	 0.011727	 0.028934	 0.0	 1012	 1012	 1012	 0.0	 0.0	 1	 -30.0	 30.0;
	10816	 10980	 0.013843	 0.048909	 0.0	 622	 622	 622	 0.0	 0.0	 1	 -30.0	 30.0;
	2673	 2626	 0.032388	 0.080711	 0.0	 364	 364	 364	 0.0	 0.0	 1	 -30.0	 30.0;
	2673	 2626	 0.011719	 0.074793	 0.0	 418	 418	 418	 0.0	 0.0	 1	 -30.0	 30.0;
	2626	 8858	 0.00057	 0.002612	 0.0	 11816	 11816	 11816	 0.0	 0.0	 1	 -30.0	 30.0;
	3405	 1792	 0.012554	 0.026314	 0.0	 1084	 1084	 1084	 0.0	 0.0	 1	 -30.0	 30.0;
	8682	 3405	 0.022554	 0.049397	 0.0	 582	 582	 582	 0.0	 0.0	 1	 -30.0	 30.0;
	1328	 4023	 0.005438	 0.021669	 0.0	 1414	 1414	 1414	 0.0	 0.0	 1	 -30.0	 30.0;
	2384	 2145	 0.00079	 0.00721	 0.0	 4355	 4355	 4355	 0.0	 0.0	 1	 -30.0	 30.0;
	2384	 5852	 0.00023	 0.00228	 0.0	 13785	 13785	 13785	 0.0	 0.0	 1	 -30.0	 30.0;
	11341	 13523	 0.002248	 0.012083	 0.0	 2571	 2571	 2571	 0.0	 0.0	 1	 -30.0	 30.0;
	11341	 13523	 0.002198	 0.012314	 0.0	 2526	 2526	 2526	 0.0	 0.0	 1	 -30.0	 30.0;
	10766	 2709	 0.014727	 0.064099	 0.0	 481	 481	 481	 0.0	 0.0	 1	 -30.0	 30.0;
	355	 10766	 0.016364	 0.040901	 0.0	 718	 718	 718	 0.0	 0.0	 1	 -30.0	 30.0;
	5669	 10766	 0.024471	 0.063686	 0.0	 463	 463	 463	 0.0	 0.0	 1	 -30.0	 30.0;
	12258	 13646	 0.00037	 0.00429	 0.0	 8731	 8731	 8731	 0.0	 0.0	 1	 -30.0	 30.0;
	12830	 13646	 0.00201	 0.02375	 0.0	 1592	 1592	 1592	 0.0	 0.0	 1	 -30.0	 30.0;
	13646	 4230	 9e-05	 0.00093	 0.0	 40234	 40234	 40234	 0.0	 0.0	 1	 -30.0	 30.0;
	13646	 2724	 9e-05	 0.00095	 0.0	 39394	 39394	 39394	 0.0	 0.0	 1	 -30.0	 30.0;
	8812	 13522	 0.004969	 0.034979	 0.0	 895	 895	 895	 0.0	 0.0	 1	 -30.0	 30.0;
	8812	 13522	 0.00468	 0.033031	 0.0	 947	 947	 947	 0.0	 0.0	 1	 -30.0	 30.0;
	13522	 9419	 0.00076	 0.007909	 0.0	 3976	 3976	 3976	 0.0	 0.0	 1	 -30.0	 30.0;
	13522	 7538	 0.020539	 0.080461	 0.0	 381	 381	 381	 0.0	 0.0	 1	 -30.0	 30.0;
	2673	 3989	 0.024562	 0.099231	 0.0	 309	 309	 309	 0.0	 0.0	 1	 -30.0	 30.0;
	2673	 13014	 0.103397	 0.231174	 0.0	 125	 125	 125	 0.0	 0.0	 1	 -30.0	 30.0;
	2673	 95	 0.063843	 0.141661	 0.0	 204	 204	 204	 0.0	 0.0	 1	 -30.0	 30.0;
	12258	 1054	 0.00059	 0.00906	 0.0	 4141	 4141	 4141	 0.0	 0.0	 1	 -30.0	 30.0;
	8812	 9419	 0.001979	 0.02175	 0.0	 1447	 1447	 1447	 0.0	 0.0	 1	 -30.0	 30.0;
	8812	 5205	 0.005281	 0.040039	 0.0	 783	 783	 783	 0.0	 0.0	 1	 -30.0	 30.0;
	8812	 817	 0.012281	 0.069219	 0.0	 450	 450	 450	 0.0	 0.0	 1	 -30.0	 30.0;
	8812	 10184	 0.00668	 0.04144	 0.0	 753	 753	 753	 0.0	 0.0	 1	 -30.0	 30.0;
	9419	 9002	 0.00725	 0.03801	 0.0	 817	 817	 817	 0.0	 0.0	 1	 -30.0	 30.0;
	5852	 2900	 0.00225	 0.02188	 0.0	 1437	 1437	 1437	 0.0	 0.0	 1	 -30.0	 30.0;
	8749	 2745	 0.00525	 0.03749	 0.0	 994	 994	 994	 0.0	 0.0	 1	 -30.0	 30.0;
	8749	 2745	 0.00605	 0.03069	 0.0	 1202	 1202	 1202	 0.0	 0.0	 1	 -30.0	 30.0;
	5414	 4754	 0.054793	 0.13405	 0.0	 262	 262	 262	 0.0	 0.0	 1	 -30.0	 30.0;
	2709	 5414	 0.019099	 0.076488	 0.0	 482	 482	 482	 0.0	 0.0	 1	 -30.0	 30.0;
	5414	 10029	 0.035686	 0.057678	 0.0	 555	 555	 555	 0.0	 0.0	 1	 -30.0	 30.0;
	9868	 10307	 0.00481	 0.020579	 0.0	 1495	 1495	 1495	 0.0	 0.0	 1	 -30.0	 30.0;
	9868	 10307	 0.004909	 0.020149	 0.0	 1524	 1524	 1524	 0.0	 0.0	 1	 -30.0	 30.0;
	9868	 6309	 0.010843	 0.055512	 0.0	 559	 559	 559	 0.0	 0.0	 1	 -30.0	 30.0;
	9868	 6309	 0.012289	 0.054397	 0.0	 567	 567	 567	 0.0	 0.0	 1	 -30.0	 30.0;
	4833	 9868	 0.003562	 0.018124	 0.0	 1711	 1711	 1711	 0.0	 0.0	 1	 -30.0	 30.0;
	12903	 6863	 0.038017	 0.081934	 0.0	 350	 350	 350	 0.0	 0.0	 1	 -30.0	 30.0;
	12903	 1580	 0.020149	 0.083124	 0.0	 370	 370	 370	 0.0	 0.0	 1	 -30.0	 30.0;
	12903	 9837	 0.009554	 0.040959	 0.0	 752	 752	 752	 0.0	 0.0	 1	 -30.0	 30.0;
	4023	 4788	 0.008331	 0.043322	 0.0	 717	 717	 717	 0.0	 0.0	 1	 -30.0	 30.0;
	4788	 2823	 0.02114	 0.114479	 0.0	 272	 272	 272	 0.0	 0.0	 1	 -30.0	 30.0;
	1565	 4754	 0.017488	 0.03838	 0.0	 749	 749	 749	 0.0	 0.0	 1	 -30.0	 30.0;
	10307	 6214	 0.00381	 0.019256	 0.0	 1610	 1610	 1610	 0.0	 0.0	 1	 -30.0	 30.0;
	5917	 6214	 0.001397	 0.005802	 0.0	 5293	 5293	 5293	 0.0	 0.0	 1	 -30.0	 30.0;
	3254	 9130	 0.004719	 0.024603	 0.0	 1261	 1261	 1261	 0.0	 0.0	 1	 -30.0	 30.0;
	3254	 9130	 0.00462	 0.025058	 0.0	 1240	 1240	 1240	 0.0	 0.0	 1	 -30.0	 30.0;
	4587	 9130	 0.005413	 0.027876	 0.0	 1113	 1113	 1113	 0.0	 0.0	 1	 -30.0	 30.0;
	9130	 10215	 0.032041	 0.196413	 0.0	 159	 159	 159	 0.0	 0.0	 1	 -30.0	 30.0;
	3950	 9130	 0.002198	 0.022248	 0.0	 1413	 1413	 1413	 0.0	 0.0	 1	 -30.0	 30.0;
	9130	 269	 0.00262	 0.018463	 0.0	 1694	 1694	 1694	 0.0	 0.0	 1	 -30.0	 30.0;
	9130	 6894	 0.030347	 0.112149	 0.0	 272	 272	 272	 0.0	 0.0	 1	 -30.0	 30.0;
	5620	 1005	 0.014512	 0.05981	 0.0	 514	 514	 514	 0.0	 0.0	 1	 -30.0	 30.0;
	1792	 12179	 0.005438	 0.009124	 0.0	 2974	 2974	 2974	 0.0	 0.0	 1	 -30.0	 30.0;
	12640	 1862	 0.005169	 0.022219	 0.0	 1385	 1385	 1385	 0.0	 0.0	 1	 -30.0	 30.0;
	1037	 9566	 0.007793	 0.029769	 0.0	 1027	 1027	 1027	 0.0	 0.0	 1	 -30.0	 30.0;
	1037	 11748	 0.006091	 0.028653	 0.0	 1079	 1079	 1079	 0.0	 0.0	 1	 -30.0	 30.0;
	6143	 3707	 0.02876	 0.060388	 0.0	 473	 473	 473	 0.0	 0.0	 1	 -30.0	 30.0;
	2346	 2730	 0.02443	 0.09576	 0.0	 320	 320	 320	 0.0	 0.0	 1	 -30.0	 30.0;
	8682	 2730	 0.009083	 0.03857	 0.0	 798	 798	 798	 0.0	 0.0	 1	 -30.0	 30.0;
	13014	 6936	 0.048157	 0.08462	 0.0	 325	 325	 325	 0.0	 0.0	 1	 -30.0	 30.0;
	7239	 3254	 0.002512	 0.013826	 0.0	 2248	 2248	 2248	 0.0	 0.0	 1	 -30.0	 30.0;
	12179	 9205	 0.012298	 0.026826	 0.0	 1071	 1071	 1071	 0.0	 0.0	 1	 -30.0	 30.0;
	12389	 12693	 0.022744	 0.133521	 0.0	 234	 234	 234	 0.0	 0.0	 1	 -30.0	 30.0;
	7760	 2267	 0.022554	 0.088876	 0.0	 345	 345	 345	 0.0	 0.0	 1	 -30.0	 30.0;
	9052	 12891	 0.019231	 0.033802	 0.0	 813	 813	 813	 0.0	 0.0	 1	 -30.0	 30.0;
	10725	 9594	 0.010017	 0.022711	 0.0	 1273	 1273	 1273	 0.0	 0.0	 1	 -30.0	 30.0;
	10725	 743	 0.00219	 0.011843	 0.0	 2623	 2623	 2623	 0.0	 0.0	 1	 -30.0	 30.0;
	8331	 8300	 0.019281	 0.064488	 0.0	 470	 470	 470	 0.0	 0.0	 1	 -30.0	 30.0;
	3740	 8300	 0.02119	 0.091727	 0.0	 336	 336	 336	 0.0	 0.0	 1	 -30.0	 30.0;
	6300	 13021	 0.003099	 0.013893	 0.0	 2220	 2220	 2220	 0.0	 0.0	 1	 -30.0	 30.0;
	1565	 13021	 0.004132	 0.021959	 0.0	 1414	 1414	 1414	 0.0	 0.0	 1	 -30.0	 30.0;
	1565	 13021	 0.004041	 0.02238	 0.0	 1389	 1389	 1389	 0.0	 0.0	 1	 -30.0	 30.0;
	1565	 12991	 0.002471	 0.010901	 0.0	 2826	 2826	 2826	 0.0	 0.0	 1	 -30.0	 30.0;
	6075	 12830	 0.002	 0.017	 0.0	 1846	 1846	 1846	 0.0	 0.0	 1	 -30.0	 30.0;
	1708	 12830	 0.0016	 0.01758	 0.0	 1790	 1790	 1790	 0.0	 0.0	 1	 -30.0	 30.0;
	12389	 493	 0.027397	 0.111917	 0.0	 275	 275	 275	 0.0	 0.0	 1	 -30.0	 30.0;
	12389	 13113	 0.008752	 0.044802	 0.0	 692	 692	 692	 0.0	 0.0	 1	 -30.0	 30.0;
	1037	 9205	 0.045727	 0.07386	 0.0	 364	 364	 364	 0.0	 0.0	 1	 -30.0	 30.0;
	10215	 6526	 0.044281	 0.119579	 0.0	 248	 248	 248	 0.0	 0.0	 1	 -30.0	 30.0;
	1918	 6526	 0.057612	 0.11224	 0.0	 251	 251	 251	 0.0	 0.0	 1	 -30.0	 30.0;
	6374	 6526	 0.063314	 0.107273	 0.0	 254	 254	 254	 0.0	 0.0	 1	 -30.0	 30.0;
	5917	 4991	 0.006769	 0.017909	 0.0	 1650	 1650	 1650	 0.0	 0.0	 1	 -30.0	 30.0;
	10228	 6143	 0.003273	 0.01157	 0.0	 2628	 2628	 2628	 0.0	 0.0	 1	 -30.0	 30.0;
	10228	 796	 0.000248	 0.001331	 0.0	 23331	 23331	 23331	 0.0	 0.0	 1	 -30.0	 30.0;
	3918	 11974	 0.010603	 0.045727	 0.0	 673	 673	 673	 0.0	 0.0	 1	 -30.0	 30.0;
	11974	 6374	 0.016273	 0.089678	 0.0	 347	 347	 347	 0.0	 0.0	 1	 -30.0	 30.0;
	5717	 10972	 0.008397	 0.022777	 0.0	 1302	 1302	 1302	 0.0	 0.0	 1	 -30.0	 30.0;
	10972	 2009	 0.013421	 0.036314	 0.0	 816	 816	 816	 0.0	 0.0	 1	 -30.0	 30.0;
	13276	 5893	 0.009628	 0.050752	 0.0	 612	 612	 612	 0.0	 0.0	 1	 -30.0	 30.0;
	8739	 493	 0.011777	 0.046843	 0.0	 654	 654	 654	 0.0	 0.0	 1	 -30.0	 30.0;
	5506	 493	 0.014446	 0.059967	 0.0	 513	 513	 513	 0.0	 0.0	 1	 -30.0	 30.0;
	10215	 3221	 0.005174	 0.029562	 0.0	 1053	 1053	 1053	 0.0	 0.0	 1	 -30.0	 30.0;
	2339	 3835	 0.069256	 0.110017	 0.0	 243	 243	 243	 0.0	 0.0	 1	 -30.0	 30.0;
	2133	 4979	 0.00524	 0.022124	 0.0	 1390	 1390	 1390	 0.0	 0.0	 1	 -30.0	 30.0;
	4221	 13241	 0.005083	 0.019421	 0.0	 1574	 1574	 1574	 0.0	 0.0	 1	 -30.0	 30.0;
	13241	 1874	 0.004099	 0.013868	 0.0	 2185	 2185	 2185	 0.0	 0.0	 1	 -30.0	 30.0;
	13156	 10666	 0.04181	 0.081397	 0.0	 346	 346	 346	 0.0	 0.0	 1	 -30.0	 30.0;
	13156	 6788	 0.041446	 0.067174	 0.0	 401	 401	 401	 0.0	 0.0	 1	 -30.0	 30.0;
	46	 3390	 0.008841	 0.0587	 0.0	 533	 533	 533	 0.0	 0.0	 1	 -30.0	 30.0;
	2640	 5203	 0.011876	 0.064	 0.0	 486	 486	 486	 0.0	 0.0	 1	 -30.0	 30.0;
	8054	 3151	 0.037579	 0.182612	 0.0	 170	 170	 170	 0.0	 0.0	 1	 -30.0	 30.0;
	226	 10695	 0.025752	 0.129421	 0.0	 240	 240	 240	 0.0	 0.0	 1	 -30.0	 30.0;
	4979	 5113	 0.00543	 0.011421	 0.0	 2498	 2498	 2498	 0.0	 0.0	 1	 -30.0	 30.0;
	5113	 5774	 0.003727	 0.010066	 0.0	 2943	 2943	 2943	 0.0	 0.0	 1	 -30.0	 30.0;
	6309	 10396	 0.015868	 0.053702	 0.0	 565	 565	 565	 0.0	 0.0	 1	 -30.0	 30.0;
	3060	 13156	 0.026388	 0.120603	 0.0	 256	 256	 256	 0.0	 0.0	 1	 -30.0	 30.0;
	3079	 3069	 0.002372	 0.010669	 0.0	 2891	 2891	 2891	 0.0	 0.0	 1	 -30.0	 30.0;
	4221	 1874	 0.001289	 0.005041	 0.0	 6071	 6071	 6071	 0.0	 0.0	 1	 -30.0	 30.0;
	4221	 5379	 0.001438	 0.006421	 0.0	 4801	 4801	 4801	 0.0	 0.0	 1	 -30.0	 30.0;
	4221	 1678	 0.001471	 0.006289	 0.0	 4891	 4891	 4891	 0.0	 0.0	 1	 -30.0	 30.0;
	5852	 1708	 0.00105	 0.01056	 0.0	 2977	 2977	 2977	 0.0	 0.0	 1	 -30.0	 30.0;
	4107	 46	 0.01137	 0.056789	 0.0	 546	 546	 546	 0.0	 0.0	 1	 -30.0	 30.0;
	969	 46	 0.00519	 0.028151	 0.0	 1104	 1104	 1104	 0.0	 0.0	 1	 -30.0	 30.0;
	2346	 8682	 0.030091	 0.150033	 0.0	 207	 207	 207	 0.0	 0.0	 1	 -30.0	 30.0;
	8790	 138	 0.011207	 0.023851	 0.0	 1199	 1199	 1199	 0.0	 0.0	 1	 -30.0	 30.0;
	138	 12615	 0.073347	 0.103488	 0.0	 250	 250	 250	 0.0	 0.0	 1	 -30.0	 30.0;
	7941	 1740	 0.064149	 0.131041	 0.0	 217	 217	 217	 0.0	 0.0	 1	 -30.0	 30.0;
	2228	 1862	 0.002341	 0.009719	 0.0	 3160	 3160	 3160	 0.0	 0.0	 1	 -30.0	 30.0;
	8102	 421	 0.051231	 0.126554	 0.0	 232	 232	 232	 0.0	 0.0	 1	 -30.0	 30.0;
	9309	 421	 0.031967	 0.079413	 0.0	 369	 369	 369	 0.0	 0.0	 1	 -30.0	 30.0;
	7153	 796	 0.00024	 0.001	 0.0	 30716	 30716	 30716	 0.0	 0.0	 1	 -30.0	 30.0;
	8093	 4413	 0.034008	 0.069388	 0.0	 409	 409	 409	 0.0	 0.0	 1	 -30.0	 30.0;
	762	 1466	 0.003	 0.01243	 0.0	 2471	 2471	 2471	 0.0	 0.0	 1	 -30.0	 30.0;
	1466	 10958	 0.036281	 0.073678	 0.0	 385	 385	 385	 0.0	 0.0	 1	 -30.0	 30.0;
	3069	 4712	 0.003587	 0.017231	 0.0	 1795	 1795	 1795	 0.0	 0.0	 1	 -30.0	 30.0;
	2598	 10184	 0.00012	 0.00062	 0.0	 50020	 50020	 50020	 0.0	 0.0	 1	 -30.0	 30.0;
	10920	 9837	 0.006909	 0.039231	 0.0	 793	 793	 793	 0.0	 0.0	 1	 -30.0	 30.0;
	2888	 9516	 0.003314	 0.007017	 0.0	 4071	 4071	 4071	 0.0	 0.0	 1	 -30.0	 30.0;
	13185	 13276	 0.011289	 0.063661	 0.0	 489	 489	 489	 0.0	 0.0	 1	 -30.0	 30.0;
	13185	 13276	 0.01105	 0.058942	 0.0	 527	 527	 527	 0.0	 0.0	 1	 -30.0	 30.0;
	11101	 13276	 0.007711	 0.039413	 0.0	 787	 787	 787	 0.0	 0.0	 1	 -30.0	 30.0;
	827	 355	 0.004017	 0.013669	 0.0	 2218	 2218	 2218	 0.0	 0.0	 1	 -30.0	 30.0;
	6848	 11057	 0.040521	 0.08386	 0.0	 340	 340	 340	 0.0	 0.0	 1	 -30.0	 30.0;
	3676	 1333	 0.024579	 0.061231	 0.0	 479	 479	 479	 0.0	 0.0	 1	 -30.0	 30.0;
	4413	 5943	 0.067992	 0.151463	 0.0	 191	 191	 191	 0.0	 0.0	 1	 -30.0	 30.0;
	7337	 12545	 0.003579	 0.011942	 0.0	 2534	 2534	 2534	 0.0	 0.0	 1	 -30.0	 30.0;
	2888	 620	 0.00776	 0.021587	 0.0	 1377	 1377	 1377	 0.0	 0.0	 1	 -30.0	 30.0;
	13185	 10692	 0.003298	 0.009463	 0.0	 3153	 3153	 3153	 0.0	 0.0	 1	 -30.0	 30.0;
	3882	 10692	 0.005157	 0.01376	 0.0	 2150	 2150	 2150	 0.0	 0.0	 1	 -30.0	 30.0;
	8823	 3882	 0.009934	 0.034479	 0.0	 881	 881	 881	 0.0	 0.0	 1	 -30.0	 30.0;
	5379	 9375	 0.002008	 0.010802	 0.0	 2875	 2875	 2875	 0.0	 0.0	 1	 -30.0	 30.0;
	1678	 4712	 0.001967	 0.011008	 0.0	 2825	 2825	 2825	 0.0	 0.0	 1	 -30.0	 30.0;
	950	 3596	 0.003219	 0.01439	 0.0	 2143	 2143	 2143	 0.0	 0.0	 1	 -30.0	 30.0;
	950	 2747	 0.00239	 0.01426	 0.0	 2185	 2185	 2185	 0.0	 0.0	 1	 -30.0	 30.0;
	12838	 9543	 0.00143	 0.013591	 0.0	 2312	 2312	 2312	 0.0	 0.0	 1	 -30.0	 30.0;
	12838	 10574	 0.004669	 0.05795	 0.0	 544	 544	 544	 0.0	 0.0	 1	 -30.0	 30.0;
	12838	 2219	 0.00412	 0.043151	 0.0	 729	 729	 729	 0.0	 0.0	 1	 -30.0	 30.0;
	12838	 4516	 0.000521	 0.00612	 0.0	 5143	 5143	 5143	 0.0	 0.0	 1	 -30.0	 30.0;
	7928	 1603	 0.005849	 0.02768	 0.0	 1117	 1117	 1117	 0.0	 0.0	 1	 -30.0	 30.0;
	1140	 7928	 0.012742	 0.049311	 0.0	 621	 621	 621	 0.0	 0.0	 1	 -30.0	 30.0;
	2181	 10574	 0.00206	 0.01061	 0.0	 2923	 2923	 2923	 0.0	 0.0	 1	 -30.0	 30.0;
	2181	 2857	 0.001591	 0.01	 0.0	 3120	 3120	 3120	 0.0	 0.0	 1	 -30.0	 30.0;
	1806	 2225	 0.00098	 0.00874	 0.0	 3592	 3592	 3592	 0.0	 0.0	 1	 -30.0	 30.0;
	1806	 8041	 0.00045	 0.00548	 0.0	 5745	 5745	 5745	 0.0	 0.0	 1	 -30.0	 30.0;
	6975	 8723	 0.000719	 0.003349	 0.0	 9222	 9222	 9222	 0.0	 0.0	 1	 -30.0	 30.0;
	6975	 3222	 0.000919	 0.00687	 0.0	 4558	 4558	 4558	 0.0	 0.0	 1	 -30.0	 30.0;
	6975	 9267	 0.000219	 0.0015	 0.0	 20838	 20838	 20838	 0.0	 0.0	 1	 -30.0	 30.0;
	4783	 3764	 0.00355	 0.019669	 0.0	 1581	 1581	 1581	 0.0	 0.0	 1	 -30.0	 30.0;
	4783	 1094	 0.00389	 0.02201	 0.0	 1414	 1414	 1414	 0.0	 0.0	 1	 -30.0	 30.0;
	4783	 9469	 0.00251	 0.01455	 0.0	 2140	 2140	 2140	 0.0	 0.0	 1	 -30.0	 30.0;
	6484	 6678	 0.00825	 0.036781	 0.0	 838	 838	 838	 0.0	 0.0	 1	 -30.0	 30.0;
	6484	 6129	 0.000581	 0.00412	 0.0	 7592	 7592	 7592	 0.0	 0.0	 1	 -30.0	 30.0;
	9895	 13180	 0.00103	 0.01236	 0.0	 2547	 2547	 2547	 0.0	 0.0	 1	 -30.0	 30.0;
	9895	 8041	 0.0014	 0.01768	 0.0	 1782	 1782	 1782	 0.0	 0.0	 1	 -30.0	 30.0;
	7914	 527	 0.00088	 0.01169	 0.0	 2695	 2695	 2695	 0.0	 0.0	 1	 -30.0	 30.0;
	5808	 210	 0.001711	 0.01164	 0.0	 2685	 2685	 2685	 0.0	 0.0	 1	 -30.0	 30.0;
	5808	 6533	 0.00268	 0.015031	 0.0	 2069	 2069	 2069	 0.0	 0.0	 1	 -30.0	 30.0;
	5808	 11908	 0.0018	 0.01132	 0.0	 2756	 2756	 2756	 0.0	 0.0	 1	 -30.0	 30.0;
	1613	 6185	 0.00051	 0.00268	 0.0	 11579	 11579	 11579	 0.0	 0.0	 1	 -30.0	 30.0;
	1613	 3591	 0.000651	 0.003289	 0.0	 9422	 9422	 9422	 0.0	 0.0	 1	 -30.0	 30.0;
	2956	 6173	 0.0012	 0.01137	 0.0	 2763	 2763	 2763	 0.0	 0.0	 1	 -30.0	 30.0;
	2956	 4399	 0.00168	 0.02275	 0.0	 1385	 1385	 1385	 0.0	 0.0	 1	 -30.0	 30.0;
	6660	 8723	 0.002331	 0.0225	 0.0	 1397	 1397	 1397	 0.0	 0.0	 1	 -30.0	 30.0;
	6660	 8723	 0.002081	 0.0255	 0.0	 1235	 1235	 1235	 0.0	 0.0	 1	 -30.0	 30.0;
	6660	 1001	 0.000781	 0.004979	 0.0	 6268	 6268	 6268	 0.0	 0.0	 1	 -30.0	 30.0;
	6660	 3110	 0.00514	 0.06699	 0.0	 471	 471	 471	 0.0	 0.0	 1	 -30.0	 30.0;
	10942	 5115	 0.00088	 0.00804	 0.0	 3906	 3906	 3906	 0.0	 0.0	 1	 -30.0	 30.0;
	10942	 4782	 0.00032	 0.00311	 0.0	 10104	 10104	 10104	 0.0	 0.0	 1	 -30.0	 30.0;
	10942	 322	 0.00015	 0.00197	 0.0	 15988	 15988	 15988	 0.0	 0.0	 1	 -30.0	 30.0;
	11260	 3596	 0.004719	 0.023831	 0.0	 1301	 1301	 1301	 0.0	 0.0	 1	 -30.0	 30.0;
	11260	 3222	 0.00669	 0.029979	 0.0	 1029	 1029	 1029	 0.0	 0.0	 1	 -30.0	 30.0;
	13548	 2098	 0.001031	 0.01225	 0.0	 2570	 2570	 2570	 0.0	 0.0	 1	 -30.0	 30.0;
	13548	 7897	 0.00105	 0.00937	 0.0	 3351	 3351	 3351	 0.0	 0.0	 1	 -30.0	 30.0;
	13548	 1327	 0.00201	 0.01293	 0.0	 2414	 2414	 2414	 0.0	 0.0	 1	 -30.0	 30.0;
	2873	 1094	 0.002	 0.012229	 0.0	 2550	 2550	 2550	 0.0	 0.0	 1	 -30.0	 30.0;
	2873	 2736	 8.1e-05	 0.000521	 0.0	 59909	 59909	 59909	 0.0	 0.0	 1	 -30.0	 30.0;
	2873	 9543	 0.00113	 0.010969	 0.0	 2865	 2865	 2865	 0.0	 0.0	 1	 -30.0	 30.0;
	13180	 12939	 0.00195	 0.02538	 0.0	 1241	 1241	 1241	 0.0	 0.0	 1	 -30.0	 30.0;
	13180	 4782	 0.00164	 0.01684	 0.0	 1867	 1867	 1867	 0.0	 0.0	 1	 -30.0	 30.0;
	10140	 9424	 0.006289	 0.06895	 0.0	 457	 457	 457	 0.0	 0.0	 1	 -30.0	 30.0;
	10140	 13286	 0.001169	 0.010229	 0.0	 3069	 3069	 3069	 0.0	 0.0	 1	 -30.0	 30.0;
	10140	 8505	 0.00805	 0.060409	 0.0	 519	 519	 519	 0.0	 0.0	 1	 -30.0	 30.0;
	10140	 8505	 0.00789	 0.061581	 0.0	 509	 509	 509	 0.0	 0.0	 1	 -30.0	 30.0;
	10140	 10574	 0.007159	 0.04164	 0.0	 748	 748	 748	 0.0	 0.0	 1	 -30.0	 30.0;
	10140	 10574	 0.007289	 0.040729	 0.0	 764	 764	 764	 0.0	 0.0	 1	 -30.0	 30.0;
	10140	 4525	 0.004531	 0.02731	 0.0	 1142	 1142	 1142	 0.0	 0.0	 1	 -30.0	 30.0;
	10140	 1527	 0.004521	 0.033581	 0.0	 933	 933	 933	 0.0	 0.0	 1	 -30.0	 30.0;
	2098	 4975	 0.0005	 0.005081	 0.0	 6187	 6187	 6187	 0.0	 0.0	 1	 -30.0	 30.0;
	2098	 1160	 0.00132	 0.006521	 0.0	 4748	 4748	 4748	 0.0	 0.0	 1	 -30.0	 30.0;
	7748	 9424	 0.004401	 0.030531	 0.0	 1025	 1025	 1025	 0.0	 0.0	 1	 -30.0	 30.0;
	7748	 2219	 0.000469	 0.003409	 0.0	 9180	 9180	 9180	 0.0	 0.0	 1	 -30.0	 30.0;
	4382	 5115	 0.00239	 0.02364	 0.0	 1330	 1330	 1330	 0.0	 0.0	 1	 -30.0	 30.0;
	4382	 10861	 0.00034	 0.0041	 0.0	 7678	 7678	 7678	 0.0	 0.0	 1	 -30.0	 30.0;
	4382	 4399	 0.00027	 0.00327	 0.0	 9627	 9627	 9627	 0.0	 0.0	 1	 -30.0	 30.0;
	4382	 4399	 0.00026	 0.00333	 0.0	 9457	 9457	 9457	 0.0	 0.0	 1	 -30.0	 30.0;
	4382	 1194	 0.00059	 0.00574	 0.0	 5475	 5475	 5475	 0.0	 0.0	 1	 -30.0	 30.0;
	8506	 11417	 0.000789	 0.003711	 0.0	 8326	 8326	 8326	 0.0	 0.0	 1	 -30.0	 30.0;
	8506	 11016	 0.00419	 0.04988	 0.0	 632	 632	 632	 0.0	 0.0	 1	 -30.0	 30.0;
	8506	 7646	 0.001651	 0.010919	 0.0	 2861	 2861	 2861	 0.0	 0.0	 1	 -30.0	 30.0;
	8482	 4525	 0.007281	 0.03162	 0.0	 974	 974	 974	 0.0	 0.0	 1	 -30.0	 30.0;
	8482	 3267	 0.006831	 0.03505	 0.0	 885	 885	 885	 0.0	 0.0	 1	 -30.0	 30.0;
	5115	 8041	 0.00108	 0.01258	 0.0	 2502	 2502	 2502	 0.0	 0.0	 1	 -30.0	 30.0;
	5115	 10861	 0.00174	 0.0229	 0.0	 1376	 1376	 1376	 0.0	 0.0	 1	 -30.0	 30.0;
	5115	 1194	 0.00223	 0.02125	 0.0	 1479	 1479	 1479	 0.0	 0.0	 1	 -30.0	 30.0;
	3596	 8723	 0.0023	 0.014081	 0.0	 2214	 2214	 2214	 0.0	 0.0	 1	 -30.0	 30.0;
	3596	 2747	 0.00213	 0.026831	 0.0	 1174	 1174	 1174	 0.0	 0.0	 1	 -30.0	 30.0;
	3596	 8422	 0.001039	 0.00549	 0.0	 5654	 5654	 5654	 0.0	 0.0	 1	 -30.0	 30.0;
	3596	 3243	 0.00301	 0.016711	 0.0	 1861	 1861	 1861	 0.0	 0.0	 1	 -30.0	 30.0;
	3596	 1992	 0.000849	 0.005229	 0.0	 5963	 5963	 5963	 0.0	 0.0	 1	 -30.0	 30.0;
	3596	 2290	 0.002781	 0.020281	 0.0	 1544	 1544	 1544	 0.0	 0.0	 1	 -30.0	 30.0;
	3596	 1327	 0.002159	 0.01389	 0.0	 2248	 2248	 2248	 0.0	 0.0	 1	 -30.0	 30.0;
	217	 11971	 0.003502	 0.031631	 0.0	 993	 993	 993	 0.0	 0.0	 1	 -30.0	 30.0;
	1603	 10234	 0.003929	 0.024729	 0.0	 1262	 1262	 1262	 0.0	 0.0	 1	 -30.0	 30.0;
	10234	 217	 0.00076	 0.005609	 0.0	 5581	 5581	 5581	 0.0	 0.0	 1	 -30.0	 30.0;
	3764	 6185	 0.002039	 0.01249	 0.0	 2496	 2496	 2496	 0.0	 0.0	 1	 -30.0	 30.0;
	7231	 12939	 0.00036	 0.00572	 0.0	 5512	 5512	 5512	 0.0	 0.0	 1	 -30.0	 30.0;
	7231	 1638	 0.00028	 0.00448	 0.0	 7038	 7038	 7038	 0.0	 0.0	 1	 -30.0	 30.0;
	4303	 9424	 0.001091	 0.01663	 0.0	 1896	 1896	 1896	 0.0	 0.0	 1	 -30.0	 30.0;
	4303	 4525	 0.011909	 0.080909	 0.0	 387	 387	 387	 0.0	 0.0	 1	 -30.0	 30.0;
	4303	 210	 0.000401	 0.00232	 0.0	 13417	 13417	 13417	 0.0	 0.0	 1	 -30.0	 30.0;
	4303	 210	 0.000349	 0.00263	 0.0	 11907	 11907	 11907	 0.0	 0.0	 1	 -30.0	 30.0;
	2116	 8695	 0.000531	 0.0063	 0.0	 4997	 4997	 4997	 0.0	 0.0	 1	 -30.0	 30.0;
	2116	 683	 0.005531	 0.02938	 0.0	 1057	 1057	 1057	 0.0	 0.0	 1	 -30.0	 30.0;
	2116	 11596	 0.00019	 0.002521	 0.0	 12495	 12495	 12495	 0.0	 0.0	 1	 -30.0	 30.0;
	8695	 9424	 0.00075	 0.010909	 0.0	 2889	 2889	 2889	 0.0	 0.0	 1	 -30.0	 30.0;
	12322	 6129	 0.007	 0.03088	 0.0	 998	 998	 998	 0.0	 0.0	 1	 -30.0	 30.0;
	12322	 6533	 0.002349	 0.009281	 0.0	 3300	 3300	 3300	 0.0	 0.0	 1	 -30.0	 30.0;
	9424	 7621	 0.003219	 0.02125	 0.0	 1470	 1470	 1470	 0.0	 0.0	 1	 -30.0	 30.0;
	9424	 7621	 0.004461	 0.027961	 0.0	 1116	 1116	 1116	 0.0	 0.0	 1	 -30.0	 30.0;
	1378	 6283	 0.00105	 0.007901	 0.0	 3964	 3964	 3964	 0.0	 0.0	 1	 -30.0	 30.0;
	9824	 6678	 0.002461	 0.01019	 0.0	 3014	 3014	 3014	 0.0	 0.0	 1	 -30.0	 30.0;
	9824	 6129	 0.00605	 0.028409	 0.0	 1088	 1088	 1088	 0.0	 0.0	 1	 -30.0	 30.0;
	2966	 1327	 7e-05	 0.00039	 0.0	 79720	 79720	 79720	 0.0	 0.0	 1	 -30.0	 30.0;
	8723	 2747	 0.0047	 0.02175	 0.0	 1420	 1420	 1420	 0.0	 0.0	 1	 -30.0	 30.0;
	10923	 6375	 0.00118	 0.00719	 0.0	 4336	 4336	 4336	 0.0	 0.0	 1	 -30.0	 30.0;
	10923	 341	 0.002349	 0.01887	 0.0	 1662	 1662	 1662	 0.0	 0.0	 1	 -30.0	 30.0;
	2971	 2263	 0.00104	 0.01314	 0.0	 2397	 2397	 2397	 0.0	 0.0	 1	 -30.0	 30.0;
	2971	 4399	 0.0004	 0.004	 0.0	 7858	 7858	 7858	 0.0	 0.0	 1	 -30.0	 30.0;
	13286	 9776	 0.001289	 0.006229	 0.0	 4966	 4966	 4966	 0.0	 0.0	 1	 -30.0	 30.0;
	13286	 5238	 0.00555	 0.035419	 0.0	 882	 882	 882	 0.0	 0.0	 1	 -30.0	 30.0;
	13286	 5238	 0.00381	 0.0328	 0.0	 957	 957	 957	 0.0	 0.0	 1	 -30.0	 30.0;
	6678	 8601	 0.00093	 0.006841	 0.0	 4576	 4576	 4576	 0.0	 0.0	 1	 -30.0	 30.0;
	6678	 8601	 0.000909	 0.006979	 0.0	 4489	 4489	 4489	 0.0	 0.0	 1	 -30.0	 30.0;
	4441	 8108	 0.001091	 0.0082	 0.0	 3819	 3819	 3819	 0.0	 0.0	 1	 -30.0	 30.0;
	4441	 5688	 0.002081	 0.020419	 0.0	 1539	 1539	 1539	 0.0	 0.0	 1	 -30.0	 30.0;
	6283	 5006	 0.00082	 0.00276	 0.0	 10971	 10971	 10971	 0.0	 0.0	 1	 -30.0	 30.0;
	6283	 4525	 0.00162	 0.007021	 0.0	 4384	 4384	 4384	 0.0	 0.0	 1	 -30.0	 30.0;
	11563	 8505	 0.002831	 0.015021	 0.0	 2067	 2067	 2067	 0.0	 0.0	 1	 -30.0	 30.0;
	11563	 192	 0.006781	 0.03026	 0.0	 1019	 1019	 1019	 0.0	 0.0	 1	 -30.0	 30.0;
	2225	 4782	 0.00041	 0.00523	 0.0	 6022	 6022	 6022	 0.0	 0.0	 1	 -30.0	 30.0;
	2225	 6173	 0.00062	 0.0098	 0.0	 3217	 3217	 3217	 0.0	 0.0	 1	 -30.0	 30.0;
	2225	 6173	 0.00083	 0.00975	 0.0	 3229	 3229	 3229	 0.0	 0.0	 1	 -30.0	 30.0;
	5238	 7897	 0.00131	 0.01564	 0.0	 2013	 2013	 2013	 0.0	 0.0	 1	 -30.0	 30.0;
	5238	 10574	 0.002039	 0.026831	 0.0	 1174	 1174	 1174	 0.0	 0.0	 1	 -30.0	 30.0;
	5238	 5688	 0.001031	 0.00945	 0.0	 3323	 3323	 3323	 0.0	 0.0	 1	 -30.0	 30.0;
	5238	 5501	 0.001789	 0.015211	 0.0	 2063	 2063	 2063	 0.0	 0.0	 1	 -30.0	 30.0;
	2747	 10574	 0.003021	 0.03739	 0.0	 843	 843	 843	 0.0	 0.0	 1	 -30.0	 30.0;
	2747	 566	 0.004211	 0.04031	 0.0	 780	 780	 780	 0.0	 0.0	 1	 -30.0	 30.0;
	2747	 5209	 0.004979	 0.029409	 0.0	 1060	 1060	 1060	 0.0	 0.0	 1	 -30.0	 30.0;
	2747	 5209	 0.00488	 0.029979	 0.0	 1040	 1040	 1040	 0.0	 0.0	 1	 -30.0	 30.0;
	2747	 3427	 0.002211	 0.02399	 0.0	 1312	 1312	 1312	 0.0	 0.0	 1	 -30.0	 30.0;
	2747	 3427	 0.00231	 0.023021	 0.0	 1366	 1366	 1366	 0.0	 0.0	 1	 -30.0	 30.0;
	683	 4525	 0.00719	 0.046841	 0.0	 667	 667	 667	 0.0	 0.0	 1	 -30.0	 30.0;
	1736	 8505	 0.00155	 0.00968	 0.0	 3223	 3223	 3223	 0.0	 0.0	 1	 -30.0	 30.0;
	1736	 8505	 0.0015	 0.01051	 0.0	 2976	 2976	 2976	 0.0	 0.0	 1	 -30.0	 30.0;
	1736	 4375	 0.00169	 0.013401	 0.0	 2339	 2339	 2339	 0.0	 0.0	 1	 -30.0	 30.0;
	1736	 3670	 0.001659	 0.012409	 0.0	 2524	 2524	 2524	 0.0	 0.0	 1	 -30.0	 30.0;
	3884	 4525	 0.005091	 0.0167	 0.0	 1810	 1810	 1810	 0.0	 0.0	 1	 -30.0	 30.0;
	3884	 3267	 0.009919	 0.04649	 0.0	 665	 665	 665	 0.0	 0.0	 1	 -30.0	 30.0;
	2917	 7646	 9.1e-05	 0.000531	 0.0	 58632	 58632	 58632	 0.0	 0.0	 1	 -30.0	 30.0;
	8505	 10574	 0.00982	 0.045331	 0.0	 682	 682	 682	 0.0	 0.0	 1	 -30.0	 30.0;
	8505	 13000	 0.003039	 0.02964	 0.0	 1061	 1061	 1061	 0.0	 0.0	 1	 -30.0	 30.0;
	2736	 5841	 0.004159	 0.02051	 0.0	 1510	 1510	 1510	 0.0	 0.0	 1	 -30.0	 30.0;
	5006	 4525	 0.00087	 0.00469	 0.0	 6623	 6623	 6623	 0.0	 0.0	 1	 -30.0	 30.0;
	8108	 852	 0.0017	 0.021039	 0.0	 1497	 1497	 1497	 0.0	 0.0	 1	 -30.0	 30.0;
	4782	 322	 0.00019	 0.0032	 0.0	 9854	 9854	 9854	 0.0	 0.0	 1	 -30.0	 30.0;
	3568	 4210	 0.006979	 0.03975	 0.0	 783	 783	 783	 0.0	 0.0	 1	 -30.0	 30.0;
	3568	 852	 0.000521	 0.004081	 0.0	 7678	 7678	 7678	 0.0	 0.0	 1	 -30.0	 30.0;
	3568	 1527	 0.00382	 0.02214	 0.0	 1406	 1406	 1406	 0.0	 0.0	 1	 -30.0	 30.0;
	1939	 6173	 0.00204	 0.02487	 0.0	 1266	 1266	 1266	 0.0	 0.0	 1	 -30.0	 30.0;
	9543	 6185	 0.00312	 0.018469	 0.0	 1687	 1687	 1687	 0.0	 0.0	 1	 -30.0	 30.0;
	4210	 4525	 0.005479	 0.038841	 0.0	 806	 806	 806	 0.0	 0.0	 1	 -30.0	 30.0;
	192	 10574	 0.000789	 0.007729	 0.0	 4066	 4066	 4066	 0.0	 0.0	 1	 -30.0	 30.0;
	8399	 9469	 0.001789	 0.01618	 0.0	 1941	 1941	 1941	 0.0	 0.0	 1	 -30.0	 30.0;
	8399	 9469	 0.00175	 0.016479	 0.0	 1907	 1907	 1907	 0.0	 0.0	 1	 -30.0	 30.0;
	9469	 5841	 0.00375	 0.025099	 0.0	 1245	 1245	 1245	 0.0	 0.0	 1	 -30.0	 30.0;
	6503	 9418	 0.010778	 0.035609	 0.0	 850	 850	 850	 0.0	 0.0	 1	 -30.0	 30.0;
	9418	 6503	 0.0096	 0.04036	 0.0	 762	 762	 762	 0.0	 0.0	 1	 -30.0	 30.0;
	11661	 6129	 0.001031	 0.016919	 0.0	 1864	 1864	 1864	 0.0	 0.0	 1	 -30.0	 30.0;
	11661	 6129	 0.00101	 0.01725	 0.0	 1829	 1829	 1829	 0.0	 0.0	 1	 -30.0	 30.0;
	10574	 7152	 0.00124	 0.013169	 0.0	 2389	 2389	 2389	 0.0	 0.0	 1	 -30.0	 30.0;
	10574	 7152	 0.00119	 0.01356	 0.0	 2321	 2321	 2321	 0.0	 0.0	 1	 -30.0	 30.0;
	10574	 5501	 0.00119	 0.013281	 0.0	 2369	 2369	 2369	 0.0	 0.0	 1	 -30.0	 30.0;
	6375	 10934	 0.00306	 0.02405	 0.0	 1303	 1303	 1303	 0.0	 0.0	 1	 -30.0	 30.0;
	6375	 7621	 0.002469	 0.018081	 0.0	 1731	 1731	 1731	 0.0	 0.0	 1	 -30.0	 30.0;
	11335	 2030	 0.0018	 0.014651	 0.0	 2140	 2140	 2140	 0.0	 0.0	 1	 -30.0	 30.0;
	11335	 3427	 0.001081	 0.010219	 0.0	 3074	 3074	 3074	 0.0	 0.0	 1	 -30.0	 30.0;
	2030	 11016	 0.000669	 0.003521	 0.0	 8814	 8814	 8814	 0.0	 0.0	 1	 -30.0	 30.0;
	4525	 527	 0.001039	 0.0142	 0.0	 2219	 2219	 2219	 0.0	 0.0	 1	 -30.0	 30.0;
	4525	 9022	 0.002771	 0.019919	 0.0	 1571	 1571	 1571	 0.0	 0.0	 1	 -30.0	 30.0;
	4975	 7152	 0.00295	 0.013401	 0.0	 2302	 2302	 2302	 0.0	 0.0	 1	 -30.0	 30.0;
	7152	 3222	 0.00411	 0.02488	 0.0	 1253	 1253	 1253	 0.0	 0.0	 1	 -30.0	 30.0;
	7152	 7036	 0.00061	 0.007211	 0.0	 4365	 4365	 4365	 0.0	 0.0	 1	 -30.0	 30.0;
	1527	 1160	 0.002219	 0.011081	 0.0	 2796	 2796	 2796	 0.0	 0.0	 1	 -30.0	 30.0;
	8693	 4269	 6e-05	 0.00066	 0.0	 47664	 47664	 47664	 0.0	 0.0	 1	 -30.0	 30.0;
	6185	 3670	 0.00411	 0.026081	 0.0	 1197	 1197	 1197	 0.0	 0.0	 1	 -30.0	 30.0;
	4831	 4399	 0.00168	 0.02222	 0.0	 1418	 1418	 1418	 0.0	 0.0	 1	 -30.0	 30.0;
	4831	 4269	 0.00049	 0.0061	 0.0	 5162	 5162	 5162	 0.0	 0.0	 1	 -30.0	 30.0;
	3222	 9267	 0.00082	 0.00575	 0.0	 5439	 5439	 5439	 0.0	 0.0	 1	 -30.0	 30.0;
	11596	 3267	 0.001409	 0.01918	 0.0	 1643	 1643	 1643	 0.0	 0.0	 1	 -30.0	 30.0;
	8422	 3243	 0.001841	 0.011159	 0.0	 2793	 2793	 2793	 0.0	 0.0	 1	 -30.0	 30.0;
	6000	 4269	 0.00109	 0.01044	 0.0	 3010	 3010	 3010	 0.0	 0.0	 1	 -30.0	 30.0;
	7078	 1638	 0.00088	 0.01608	 0.0	 1962	 1962	 1962	 0.0	 0.0	 1	 -30.0	 30.0;
	6129	 10127	 0.000591	 0.007781	 0.0	 4048	 4048	 4048	 0.0	 0.0	 1	 -30.0	 30.0;
	6129	 4468	 0.001901	 0.0247	 0.0	 1276	 1276	 1276	 0.0	 0.0	 1	 -30.0	 30.0;
	11417	 9956	 0.00382	 0.018401	 0.0	 1681	 1681	 1681	 0.0	 0.0	 1	 -30.0	 30.0;
	11016	 9956	 0.004169	 0.02775	 0.0	 1126	 1126	 1126	 0.0	 0.0	 1	 -30.0	 30.0;
	11016	 3427	 0.001849	 0.01889	 0.0	 1665	 1665	 1665	 0.0	 0.0	 1	 -30.0	 30.0;
	3267	 4468	 0.00076	 0.01036	 0.0	 3041	 3041	 3041	 0.0	 0.0	 1	 -30.0	 30.0;
	2857	 1001	 0.00207	 0.009849	 0.0	 3139	 3139	 3139	 0.0	 0.0	 1	 -30.0	 30.0;
	966	 566	 0.001849	 0.013841	 0.0	 2263	 2263	 2263	 0.0	 0.0	 1	 -30.0	 30.0;
	966	 566	 0.00243	 0.015771	 0.0	 1980	 1980	 1980	 0.0	 0.0	 1	 -30.0	 30.0;
	4399	 2362	 0.00128	 0.01149	 0.0	 2733	 2733	 2733	 0.0	 0.0	 1	 -30.0	 30.0;
	3110	 1042	 0.00057	 0.005961	 0.0	 5275	 5275	 5275	 0.0	 0.0	 1	 -30.0	 30.0;
	3110	 1788	 0.00218	 0.015099	 0.0	 2071	 2071	 2071	 0.0	 0.0	 1	 -30.0	 30.0;
	566	 7646	 0.00131	 0.008771	 0.0	 3562	 3562	 3562	 0.0	 0.0	 1	 -30.0	 30.0;
	1042	 1788	 0.00163	 0.008729	 0.0	 3558	 3558	 3558	 0.0	 0.0	 1	 -30.0	 30.0;
	1992	 2073	 0.004831	 0.02588	 0.0	 1200	 1200	 1200	 0.0	 0.0	 1	 -30.0	 30.0;
	341	 4516	 0.00062	 0.00857	 0.0	 3677	 3677	 3677	 0.0	 0.0	 1	 -30.0	 30.0;
	10127	 8601	 0.002281	 0.0362	 0.0	 871	 871	 871	 0.0	 0.0	 1	 -30.0	 30.0;
	9022	 13000	 0.00132	 0.01036	 0.0	 3025	 3025	 3025	 0.0	 0.0	 1	 -30.0	 30.0;
	2073	 3427	 0.00281	 0.017099	 0.0	 1823	 1823	 1823	 0.0	 0.0	 1	 -30.0	 30.0;
	3427	 2290	 0.00424	 0.0258	 0.0	 1209	 1209	 1209	 0.0	 0.0	 1	 -30.0	 30.0;
	1032	 11688	 0.00036	 0.00313	 0.0	 10026	 10026	 10026	 0.0	 0.0	 1	 -30.0	 30.0;
	8878	 13384	 0.00112	 0.0114	 0.0	 2758	 2758	 2758	 0.0	 0.0	 1	 -30.0	 30.0;
	8878	 13619	 0.00046	 0.007	 0.0	 4503	 4503	 4503	 0.0	 0.0	 1	 -30.0	 30.0;
	8878	 553	 0.00113	 0.01516	 0.0	 2078	 2078	 2078	 0.0	 0.0	 1	 -30.0	 30.0;
	13384	 10332	 0.00138	 0.01478	 0.0	 2128	 2128	 2128	 0.0	 0.0	 1	 -30.0	 30.0;
	13384	 759	 0.00107	 0.01447	 0.0	 2178	 2178	 2178	 0.0	 0.0	 1	 -30.0	 30.0;
	8895	 12621	 0.012651	 0.08939	 0.0	 350	 350	 350	 0.0	 0.0	 1	 -30.0	 30.0;
	8895	 8762	 0.00957	 0.05424	 0.0	 574	 574	 574	 0.0	 0.0	 1	 -30.0	 30.0;
	1854	 5027	 0.0017	 0.01823	 0.0	 1726	 1726	 1726	 0.0	 0.0	 1	 -30.0	 30.0;
	1854	 8750	 0.00092	 0.00892	 0.0	 3523	 3523	 3523	 0.0	 0.0	 1	 -30.0	 30.0;
	1854	 10774	 0.00063	 0.00829	 0.0	 3800	 3800	 3800	 0.0	 0.0	 1	 -30.0	 30.0;
	10332	 11703	 0.00052	 0.00757	 0.0	 4163	 4163	 4163	 0.0	 0.0	 1	 -30.0	 30.0;
	11703	 4797	 0.00189	 0.02546	 0.0	 1487	 1487	 1487	 0.0	 0.0	 1	 -30.0	 30.0;
	11703	 6154	 0.00044	 0.00602	 0.0	 5234	 5234	 5234	 0.0	 0.0	 1	 -30.0	 30.0;
	204	 8187	 0.00138	 0.01477	 0.0	 2130	 2130	 2130	 0.0	 0.0	 1	 -30.0	 30.0;
	8187	 6169	 0.00055	 0.00597	 0.0	 5269	 5269	 5269	 0.0	 0.0	 1	 -30.0	 30.0;
	553	 5588	 0.00047	 0.00684	 0.0	 5534	 5534	 5534	 0.0	 0.0	 1	 -30.0	 30.0;
	12621	 4921	 0.0038	 0.026331	 0.0	 1188	 1188	 1188	 0.0	 0.0	 1	 -30.0	 30.0;
	10332	 3538	 0.001	 0.00937	 0.0	 3353	 3353	 3353	 0.0	 0.0	 1	 -30.0	 30.0;
	10332	 553	 0.00203	 0.01819	 0.0	 1726	 1726	 1726	 0.0	 0.0	 1	 -30.0	 30.0;
	8762	 9318	 0.002419	 0.015021	 0.0	 2077	 2077	 2077	 0.0	 0.0	 1	 -30.0	 30.0;
	8762	 9318	 0.00274	 0.014719	 0.0	 2110	 2110	 2110	 0.0	 0.0	 1	 -30.0	 30.0;
	8762	 5288	 0.014599	 0.077461	 0.0	 401	 401	 401	 0.0	 0.0	 1	 -30.0	 30.0;
	8762	 10391	 0.012461	 0.05613	 0.0	 550	 550	 550	 0.0	 0.0	 1	 -30.0	 30.0;
	8762	 4921	 0.014581	 0.083849	 0.0	 372	 372	 372	 0.0	 0.0	 1	 -30.0	 30.0;
	10398	 4797	 0.0006	 0.00665	 0.0	 5683	 5683	 5683	 0.0	 0.0	 1	 -30.0	 30.0;
	10398	 4797	 0.00057	 0.00856	 0.0	 4423	 4423	 4423	 0.0	 0.0	 1	 -30.0	 30.0;
	10398	 8750	 0.00234	 0.02648	 0.0	 1189	 1189	 1189	 0.0	 0.0	 1	 -30.0	 30.0;
	3538	 5767	 0.00019	 0.00167	 0.0	 18794	 18794	 18794	 0.0	 0.0	 1	 -30.0	 30.0;
	3538	 2967	 0.00019	 0.00164	 0.0	 19133	 19133	 19133	 0.0	 0.0	 1	 -30.0	 30.0;
	8750	 12186	 3e-05	 0.00047	 0.0	 67071	 67071	 67071	 0.0	 0.0	 1	 -30.0	 30.0;
	8750	 1197	 3e-05	 0.00048	 0.0	 65679	 65679	 65679	 0.0	 0.0	 1	 -30.0	 30.0;
	9122	 5945	 0.00097	 0.01084	 0.0	 2903	 2903	 2903	 0.0	 0.0	 1	 -30.0	 30.0;
	8750	 8520	 8e-05	 0.00073	 0.0	 43013	 43013	 43013	 0.0	 0.0	 1	 -30.0	 30.0;
	8750	 7273	 8e-05	 0.0006	 0.0	 52184	 52184	 52184	 0.0	 0.0	 1	 -30.0	 30.0;
	8750	 2221	 7e-05	 0.00067	 0.0	 46891	 46891	 46891	 0.0	 0.0	 1	 -30.0	 30.0;
	8750	 1035	 7e-05	 0.00066	 0.0	 47593	 47593	 47593	 0.0	 0.0	 1	 -30.0	 30.0;
	5288	 821	 0.00145	 0.00707	 0.0	 4377	 4377	 4377	 0.0	 0.0	 1	 -30.0	 30.0;
	5288	 4951	 0.00164	 0.00693	 0.0	 4436	 4436	 4436	 0.0	 0.0	 1	 -30.0	 30.0;
	553	 10569	 8e-05	 0.00084	 0.0	 37435	 37435	 37435	 0.0	 0.0	 1	 -30.0	 30.0;
	553	 7880	 0.0001	 0.00083	 0.0	 37784	 37784	 37784	 0.0	 0.0	 1	 -30.0	 30.0;
	553	 11998	 0.0001	 0.00081	 0.0	 38703	 38703	 38703	 0.0	 0.0	 1	 -30.0	 30.0;
	4802	 1729	 0.00019	 0.00215	 0.0	 14635	 14635	 14635	 0.0	 0.0	 1	 -30.0	 30.0;
	204	 5749	 0.00037	 0.00292	 0.0	 10732	 10732	 10732	 0.0	 0.0	 1	 -30.0	 30.0;
	204	 2952	 0.00033	 0.00332	 0.0	 9468	 9468	 9468	 0.0	 0.0	 1	 -30.0	 30.0;
	5211	 5997	 0.002031	 0.01382	 0.0	 2262	 2262	 2262	 0.0	 0.0	 1	 -30.0	 30.0;
	5211	 3723	 0.001979	 0.014091	 0.0	 2220	 2220	 2220	 0.0	 0.0	 1	 -30.0	 30.0;
	4797	 4280	 4e-05	 0.00052	 0.0	 72079	 72079	 72079	 0.0	 0.0	 1	 -30.0	 30.0;
	4797	 1634	 4e-05	 0.00054	 0.0	 69424	 69424	 69424	 0.0	 0.0	 1	 -30.0	 30.0;
	5211	 2938	 0.00136	 0.0067	 0.0	 4621	 4621	 4621	 0.0	 0.0	 1	 -30.0	 30.0;
	4802	 6463	 0.0001	 0.00078	 0.0	 40168	 40168	 40168	 0.0	 0.0	 1	 -30.0	 30.0;
	4802	 2293	 0.00011	 0.00076	 0.0	 41134	 41134	 41134	 0.0	 0.0	 1	 -30.0	 30.0;
	5027	 4802	 0.00376	 0.04872	 0.0	 647	 647	 647	 0.0	 0.0	 1	 -30.0	 30.0;
	4802	 8574	 0.0002	 0.00258	 0.0	 12207	 12207	 12207	 0.0	 0.0	 1	 -30.0	 30.0;
	4802	 553	 0.00089	 0.0087	 0.0	 3612	 3612	 3612	 0.0	 0.0	 1	 -30.0	 30.0;
	436	 5211	 0.01282	 0.053159	 0.0	 578	 578	 578	 0.0	 0.0	 1	 -30.0	 30.0;
	436	 10221	 0.002219	 0.01038	 0.0	 2976	 2976	 2976	 0.0	 0.0	 1	 -30.0	 30.0;
	436	 5211	 0.01307	 0.05205	 0.0	 589	 589	 589	 0.0	 0.0	 1	 -30.0	 30.0;
	436	 4921	 0.00449	 0.01863	 0.0	 1649	 1649	 1649	 0.0	 0.0	 1	 -30.0	 30.0;
	204	 6154	 0.00215	 0.0248	 0.0	 1269	 1269	 1269	 0.0	 0.0	 1	 -30.0	 30.0;
	3374	 9122	 0.00192	 0.02113	 0.0	 1489	 1489	 1489	 0.0	 0.0	 1	 -30.0	 30.0;
	3374	 11688	 0.00165	 0.01704	 0.0	 1846	 1846	 1846	 0.0	 0.0	 1	 -30.0	 30.0;
	4797	 6169	 0.00168	 0.02469	 0.0	 1534	 1534	 1534	 0.0	 0.0	 1	 -30.0	 30.0;
	4797	 6154	 0.00222	 0.02324	 0.0	 1626	 1626	 1626	 0.0	 0.0	 1	 -30.0	 30.0;
	9122	 759	 0.00173	 0.01682	 0.0	 1869	 1869	 1869	 0.0	 0.0	 1	 -30.0	 30.0;
	9122	 12785	 0.00174	 0.01872	 0.0	 1681	 1681	 1681	 0.0	 0.0	 1	 -30.0	 30.0;
	9122	 3538	 0.00194	 0.02194	 0.0	 1435	 1435	 1435	 0.0	 0.0	 1	 -30.0	 30.0;
	7738	 4872	 0.013831	 0.056841	 0.0	 540	 540	 540	 0.0	 0.0	 1	 -30.0	 30.0;
	7738	 4872	 0.014091	 0.055599	 0.0	 551	 551	 551	 0.0	 0.0	 1	 -30.0	 30.0;
	5288	 291	 0.009081	 0.05263	 0.0	 592	 592	 592	 0.0	 0.0	 1	 -30.0	 30.0;
	5288	 7312	 0.007401	 0.05661	 0.0	 554	 554	 554	 0.0	 0.0	 1	 -30.0	 30.0;
	11688	 12785	 0.00164	 0.01627	 0.0	 1932	 1932	 1932	 0.0	 0.0	 1	 -30.0	 30.0;
	10391	 3721	 0.022909	 0.124591	 0.0	 250	 250	 250	 0.0	 0.0	 1	 -30.0	 30.0;
	4306	 12785	 0.00074	 0.00791	 0.0	 3976	 3976	 3976	 0.0	 0.0	 1	 -30.0	 30.0;
	4306	 10774	 0.00136	 0.01726	 0.0	 1825	 1825	 1825	 0.0	 0.0	 1	 -30.0	 30.0;
	291	 5211	 0.011211	 0.07026	 0.0	 444	 444	 444	 0.0	 0.0	 1	 -30.0	 30.0;
	291	 5211	 0.01143	 0.06882	 0.0	 453	 453	 453	 0.0	 0.0	 1	 -30.0	 30.0;
	12785	 6154	 0.00544	 0.06455	 0.0	 488	 488	 488	 0.0	 0.0	 1	 -30.0	 30.0;
	4872	 3721	 0.016289	 0.066719	 0.0	 460	 460	 460	 0.0	 0.0	 1	 -30.0	 30.0;
	4872	 3721	 0.016591	 0.065271	 0.0	 470	 470	 470	 0.0	 0.0	 1	 -30.0	 30.0;
	8750	 10774	 0.00077	 0.0096	 0.0	 3280	 3280	 3280	 0.0	 0.0	 1	 -30.0	 30.0;
	8750	 10774	 0.00093	 0.00905	 0.0	 3473	 3473	 3473	 0.0	 0.0	 1	 -30.0	 30.0;
	3721	 7312	 0.021729	 0.15268	 0.0	 205	 205	 205	 0.0	 0.0	 1	 -30.0	 30.0;
	718	 10221	 0.00064	 0.002919	 0.0	 10571	 10571	 10571	 0.0	 0.0	 1	 -30.0	 30.0;
	10221	 4921	 0.002211	 0.009169	 0.0	 3350	 3350	 3350	 0.0	 0.0	 1	 -30.0	 30.0;
	5531	 13443	 0.00014	 0.001729	 0.0	 18210	 18210	 18210	 0.0	 0.0	 1	 -30.0	 30.0;
	439	 13443	 0.0002	 0.00281	 0.0	 11213	 11213	 11213	 0.0	 0.0	 1	 -30.0	 30.0;
	3806	 7655	 0.000711	 0.004289	 0.0	 7266	 7266	 7266	 0.0	 0.0	 1	 -30.0	 30.0;
	3806	 10208	 0.0007	 0.00438	 0.0	 7122	 7122	 7122	 0.0	 0.0	 1	 -30.0	 30.0;
	5531	 3806	 0.00032	 0.00437	 0.0	 7209	 7209	 7209	 0.0	 0.0	 1	 -30.0	 30.0;
	7655	 8407	 7e-05	 0.000401	 0.0	 77598	 77598	 77598	 0.0	 0.0	 1	 -30.0	 30.0;
	10208	 12057	 7e-05	 0.000401	 0.0	 77598	 77598	 77598	 0.0	 0.0	 1	 -30.0	 30.0;
	1167	 8407	 0.00189	 0.0083	 0.0	 3711	 3711	 3711	 0.0	 0.0	 1	 -30.0	 30.0;
	1167	 12057	 0.00168	 0.009401	 0.0	 3308	 3308	 3308	 0.0	 0.0	 1	 -30.0	 30.0;
	5531	 10545	 0.000151	 0.00169	 0.0	 18617	 18617	 18617	 0.0	 0.0	 1	 -30.0	 30.0;
	9099	 11009	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	9099	 11009	 0.001	 0.120531	 0.0	 263	 263	 263	 0.0	 0.0	 1	 -30.0	 30.0;
	13629	 9099	 4.583678	 10.16446	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	9099	 8267	 8.430371	 11.9126	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	9099	 4147	 8.911157	 11.64008	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	11448	 9099	 7.455785	 17.24773	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	2359	 9099	 9.746074	 17.22748	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	8608	 9099	 0.796777	 2.654959	 0.0	 12	 12	 12	 0.0	 0.0	 1	 -30.0	 30.0;
	4055	 9099	 0.960248	 2.559091	 0.0	 12	 12	 12	 0.0	 0.0	 1	 -30.0	 30.0;
	8156	 9099	 5.215909	 9.009917	 0.0	 4	 4	 4	 0.0	 0.0	 1	 -30.0	 30.0;
	6030	 9099	 5.097107	 9.164256	 0.0	 4	 4	 4	 0.0	 0.0	 1	 -30.0	 30.0;
	917	 9099	 19.22748	 20.93388	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	4995	 9099	 17.18905	 24.75	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	9099	 12407	 17.2064	 22.05785	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	12043	 9099	 0.227459	 1.377252	 0.0	 23	 23	 23	 0.0	 0.0	 1	 -30.0	 30.0;
	9823	 9099	 0.13382	 0.643926	 0.0	 49	 49	 49	 0.0	 0.0	 1	 -30.0	 30.0;
	6896	 9099	 0.211219	 1.206674	 0.0	 26	 26	 26	 0.0	 0.0	 1	 -30.0	 30.0;
	10979	 9099	 0.230165	 1.120413	 0.0	 28	 28	 28	 0.0	 0.0	 1	 -30.0	 30.0;
	1535	 9099	 29.19835	 48.54959	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	5183	 9099	 0.13231	 0.939504	 0.0	 34	 34	 34	 0.0	 0.0	 1	 -30.0	 30.0;
	7916	 9099	 0.842851	 2.338843	 0.0	 16	 16	 16	 0.0	 0.0	 1	 -30.0	 30.0;
	3743	 9099	 0.820764	 2.471488	 0.0	 15	 15	 15	 0.0	 0.0	 1	 -30.0	 30.0;
	4717	 9099	 0.553244	 1.973719	 0.0	 16	 16	 16	 0.0	 0.0	 1	 -30.0	 30.0;
	4717	 9099	 0.01405	 0.0548	 0.0	 559	 559	 559	 0.0	 0.0	 1	 -30.0	 30.0;
	9099	 2256	 1.071157	 2.739256	 0.0	 11	 11	 11	 0.0	 0.0	 1	 -30.0	 30.0;
	9099	 2256	 0.00774	 0.04075	 0.0	 762	 762	 762	 0.0	 0.0	 1	 -30.0	 30.0;
	7691	 9099	 16.64566	 21.19835	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	6065	 9099	 16.22913	 16.64318	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	13629	 11009	 10.87128	 19.07149	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	11009	 8267	 15.62583	 25.67355	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	11009	 4147	 16.95331	 27.19835	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	11448	 11009	 16.6593	 34.37603	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	2359	 11009	 19.6814	 37.93595	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	8608	 11009	 1.881012	 4.967975	 0.0	 6	 6	 6	 0.0	 0.0	 1	 -30.0	 30.0;
	4055	 11009	 1.902851	 5.765909	 0.0	 6	 6	 6	 0.0	 0.0	 1	 -30.0	 30.0;
	8156	 11009	 10.14587	 20.68595	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	6030	 11009	 10.93058	 18.98595	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	917	 11009	 36.07851	 50.20248	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	4995	 11009	 40.72727	 46.32438	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	11009	 12407	 36.24587	 46.68595	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	12043	 11009	 0.444855	 2.8	 0.0	 12	 12	 12	 0.0	 0.0	 1	 -30.0	 30.0;
	9823	 11009	 0.273946	 1.391054	 0.0	 23	 23	 23	 0.0	 0.0	 1	 -30.0	 30.0;
	6896	 11009	 0.514545	 2.160744	 0.0	 15	 15	 15	 0.0	 0.0	 1	 -30.0	 30.0;
	10979	 11009	 0.450992	 2.507851	 0.0	 13	 13	 13	 0.0	 0.0	 1	 -30.0	 30.0;
	5183	 11009	 0.292665	 1.871012	 0.0	 17	 17	 17	 0.0	 0.0	 1	 -30.0	 30.0;
	7916	 11009	 1.795062	 4.826033	 0.0	 8	 8	 8	 0.0	 0.0	 1	 -30.0	 30.0;
	3743	 11009	 1.551219	 5.755991	 0.0	 7	 7	 7	 0.0	 0.0	 1	 -30.0	 30.0;
	4717	 11009	 1.089959	 4.426653	 0.0	 7	 7	 7	 0.0	 0.0	 1	 -30.0	 30.0;
	11009	 2256	 0.00757	 0.037729	 0.0	 821	 821	 821	 0.0	 0.0	 1	 -30.0	 30.0;
	11009	 2256	 2.158264	 6.029752	 0.0	 5	 5	 5	 0.0	 0.0	 1	 -30.0	 30.0;
	7691	 11009	 35.04132	 44.83471	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	6065	 11009	 30.36983	 39.79132	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	7867	 6362	 0.00058	 0.00554	 0.0	 5671	 5671	 5671	 0.0	 0.0	 1	 -30.0	 30.0;
	7867	 8653	 0.00116	 0.01169	 0.0	 2689	 2689	 2689	 0.0	 0.0	 1	 -30.0	 30.0;
	9172	 6362	 0.00052	 0.00627	 0.0	 5021	 5021	 5021	 0.0	 0.0	 1	 -30.0	 30.0;
	9172	 8653	 0.00118	 0.01144	 0.0	 2747	 2747	 2747	 0.0	 0.0	 1	 -30.0	 30.0;
	7867	 9172	 0.001	 0.223012	 0.0	 142	 142	 142	 0.0	 0.0	 1	 -30.0	 30.0;
	7867	 6362	 0.05072	 0.617493	 0.0	 51	 51	 51	 0.0	 0.0	 1	 -30.0	 30.0;
	7867	 8653	 0.05373	 0.600208	 0.0	 53	 53	 53	 0.0	 0.0	 1	 -30.0	 30.0;
	478	 7867	 0.381143	 1.437258	 0.0	 22	 22	 22	 0.0	 0.0	 1	 -30.0	 30.0;
	9172	 6362	 0.04991	 0.630229	 0.0	 50	 50	 50	 0.0	 0.0	 1	 -30.0	 30.0;
	9172	 8653	 0.05131	 0.624993	 0.0	 51	 51	 51	 0.0	 0.0	 1	 -30.0	 30.0;
	478	 9172	 0.389938	 1.410526	 0.0	 22	 22	 22	 0.0	 0.0	 1	 -30.0	 30.0;
	6587	 5003	 0.00059	 0.00463	 0.0	 6768	 6768	 6768	 0.0	 0.0	 1	 -30.0	 30.0;
	6587	 2275	 0.00047	 0.0038	 0.0	 8250	 8250	 8250	 0.0	 0.0	 1	 -30.0	 30.0;
	9153	 11186	 0.0006	 0.00453	 0.0	 6913	 6913	 6913	 0.0	 0.0	 1	 -30.0	 30.0;
	9153	 5003	 0.03442	 0.298892	 0.0	 105	 105	 105	 0.0	 0.0	 1	 -30.0	 30.0;
	9153	 11186	 0.03377	 0.305229	 0.0	 103	 103	 103	 0.0	 0.0	 1	 -30.0	 30.0;
	9153	 9673	 0.00047	 0.00372	 0.0	 8425	 8425	 8425	 0.0	 0.0	 1	 -30.0	 30.0;
	6562	 880	 0.00036	 0.00341	 0.0	 9212	 9212	 9212	 0.0	 0.0	 1	 -30.0	 30.0;
	5912	 6562	 0.00164	 0.01639	 0.0	 1918	 1918	 1918	 0.0	 0.0	 1	 -30.0	 30.0;
	707	 9072	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	707	 9072	 0.001	 0.13669	 0.0	 232	 232	 232	 0.0	 0.0	 1	 -30.0	 30.0;
	707	 11302	 2.103099	 5.086777	 0.0	 7	 7	 7	 0.0	 0.0	 1	 -30.0	 30.0;
	707	 9140	 0.004781	 0.02089	 0.0	 1474	 1474	 1474	 0.0	 0.0	 1	 -30.0	 30.0;
	707	 7014	 46.67975	 63.95455	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	707	 12720	 45.98967	 55.45455	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	707	 9401	 1.337128	 3.255992	 0.0	 11	 11	 11	 0.0	 0.0	 1	 -30.0	 30.0;
	707	 1566	 0.09056	 0.365041	 0.0	 84	 84	 84	 0.0	 0.0	 1	 -30.0	 30.0;
	707	 5754	 0.085081	 0.477665	 0.0	 66	 66	 66	 0.0	 0.0	 1	 -30.0	 30.0;
	707	 5754	 0.008	 0.040669	 0.0	 763	 763	 763	 0.0	 0.0	 1	 -30.0	 30.0;
	9072	 11302	 2.446281	 4.115289	 0.0	 8	 8	 8	 0.0	 0.0	 1	 -30.0	 30.0;
	9072	 141	 0.00488	 0.020469	 0.0	 1803	 1803	 1803	 0.0	 0.0	 1	 -30.0	 30.0;
	9072	 7014	 44.43595	 63.26653	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	9072	 12720	 47.34298	 50.52893	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	9072	 9401	 1.382355	 2.978719	 0.0	 12	 12	 12	 0.0	 0.0	 1	 -30.0	 30.0;
	9072	 1566	 0.07226	 0.393864	 0.0	 79	 79	 79	 0.0	 0.0	 1	 -30.0	 30.0;
	9072	 1566	 0.007831	 0.04144	 0.0	 749	 749	 749	 0.0	 0.0	 1	 -30.0	 30.0;
	9072	 5754	 0.08989	 0.428161	 0.0	 73	 73	 73	 0.0	 0.0	 1	 -30.0	 30.0;
	5482	 11721	 0.00055	 0.00435	 0.0	 7205	 7205	 7205	 0.0	 0.0	 1	 -30.0	 30.0;
	3229	 11721	 0.00128	 0.00706	 0.0	 4403	 4403	 4403	 0.0	 0.0	 1	 -30.0	 30.0;
	4798	 8075	 0.00053	 0.00407	 0.0	 7697	 7697	 7697	 0.0	 0.0	 1	 -30.0	 30.0;
	5993	 8075	 0.00056	 0.00478	 0.0	 6564	 6564	 6564	 0.0	 0.0	 1	 -30.0	 30.0;
	6510	 5482	 0.208393	 1.089612	 0.0	 29	 29	 29	 0.0	 0.0	 1	 -30.0	 30.0;
	3603	 5482	 0.199571	 1.1759	 0.0	 27	 27	 27	 0.0	 0.0	 1	 -30.0	 30.0;
	1665	 5482	 0.02232	 0.346918	 0.0	 91	 91	 91	 0.0	 0.0	 1	 -30.0	 30.0;
	4490	 5482	 0.858172	 1.866898	 0.0	 16	 16	 16	 0.0	 0.0	 1	 -30.0	 30.0;
	2872	 5482	 0.00031	 0.00216	 0.0	 14476	 14476	 14476	 0.0	 0.0	 1	 -30.0	 30.0;
	7278	 5482	 0.001	 0.274529	 0.0	 116	 116	 116	 0.0	 0.0	 1	 -30.0	 30.0;
	13017	 5482	 4.431302	 8.136427	 0.0	 4	 4	 4	 0.0	 0.0	 1	 -30.0	 30.0;
	10335	 12622	 0.36115	 2.404917	 0.0	 13	 13	 13	 0.0	 0.0	 1	 -30.0	 30.0;
	10335	 272	 0.319377	 2.230125	 0.0	 15	 15	 15	 0.0	 0.0	 1	 -30.0	 30.0;
	10335	 4883	 0.325519	 2.183657	 0.0	 15	 15	 15	 0.0	 0.0	 1	 -30.0	 30.0;
	7997	 10335	 1.726316	 5.458795	 0.0	 7	 7	 7	 0.0	 0.0	 1	 -30.0	 30.0;
	10335	 6414	 2.428047	 7.275623	 0.0	 5	 5	 5	 0.0	 0.0	 1	 -30.0	 30.0;
	10335	 12406	 0.00056	 0.00716	 0.0	 4399	 4399	 4399	 0.0	 0.0	 1	 -30.0	 30.0;
	10335	 12406	 0.527043	 3.451801	 0.0	 10	 10	 10	 0.0	 0.0	 1	 -30.0	 30.0;
	10335	 8314	 0.515582	 3.196122	 0.0	 10	 10	 10	 0.0	 0.0	 1	 -30.0	 30.0;
	10335	 9085	 1.334072	 5.856163	 0.0	 7	 7	 7	 0.0	 0.0	 1	 -30.0	 30.0;
	10335	 6868	 0.0011	 0.01318	 0.0	 2389	 2389	 2389	 0.0	 0.0	 1	 -30.0	 30.0;
	10335	 13020	 0.00108	 0.01344	 0.0	 2343	 2343	 2343	 0.0	 0.0	 1	 -30.0	 30.0;
	10335	 8314	 0.00063	 0.00702	 0.0	 4482	 4482	 4482	 0.0	 0.0	 1	 -30.0	 30.0;
	5899	 1467	 0.246612	 1.335723	 0.0	 24	 24	 24	 0.0	 0.0	 1	 -30.0	 30.0;
	5899	 1467	 0.008229	 0.04962	 0.0	 629	 629	 629	 0.0	 0.0	 1	 -30.0	 30.0;
	5899	 5005	 0.219628	 1.572521	 0.0	 20	 20	 20	 0.0	 0.0	 1	 -30.0	 30.0;
	5899	 5923	 4.089256	 11.14855	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	5899	 1752	 0.00943	 0.04726	 0.0	 656	 656	 656	 0.0	 0.0	 1	 -30.0	 30.0;
	5899	 1752	 3.689876	 10.15083	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	5899	 644	 0.202581	 1.497417	 0.0	 21	 21	 21	 0.0	 0.0	 1	 -30.0	 30.0;
	5899	 2726	 0.1973	 1.490124	 0.0	 22	 22	 22	 0.0	 0.0	 1	 -30.0	 30.0;
	5899	 418	 0.0028	 0.013271	 0.0	 2329	 2329	 2329	 0.0	 0.0	 1	 -30.0	 30.0;
	5899	 5344	 0.12369	 1.125744	 0.0	 28	 28	 28	 0.0	 0.0	 1	 -30.0	 30.0;
	5899	 2264	 1.335496	 4.761364	 0.0	 7	 7	 7	 0.0	 0.0	 1	 -30.0	 30.0;
	5899	 4342	 1.15	 4.888636	 0.0	 7	 7	 7	 0.0	 0.0	 1	 -30.0	 30.0;
	5899	 1684	 1.052913	 5.261983	 0.0	 6	 6	 6	 0.0	 0.0	 1	 -30.0	 30.0;
	5899	 5005	 0.00932	 0.04863	 0.0	 638	 638	 638	 0.0	 0.0	 1	 -30.0	 30.0;
	5899	 5923	 0.00961	 0.046281	 0.0	 669	 669	 669	 0.0	 0.0	 1	 -30.0	 30.0;
	5899	 8634	 0.0025	 0.015031	 0.0	 2074	 2074	 2074	 0.0	 0.0	 1	 -30.0	 30.0;
	7074	 11117	 0.0008	 0.00519	 0.0	 6016	 6016	 6016	 0.0	 0.0	 1	 -30.0	 30.0;
	7074	 1752	 0.00612	 0.03036	 0.0	 1020	 1020	 1020	 0.0	 0.0	 1	 -30.0	 30.0;
	11117	 2637	 0.00038	 0.00243	 0.0	 12843	 12843	 12843	 0.0	 0.0	 1	 -30.0	 30.0;
	6964	 549	 0.000909	 0.005091	 0.0	 6108	 6108	 6108	 0.0	 0.0	 1	 -30.0	 30.0;
	6964	 644	 0.00187	 0.00944	 0.0	 3283	 3283	 3283	 0.0	 0.0	 1	 -30.0	 30.0;
	549	 2637	 0.00043	 0.00238	 0.0	 13061	 13061	 13061	 0.0	 0.0	 1	 -30.0	 30.0;
	12866	 6188	 0.00013	 0.00176	 0.0	 17899	 17899	 17899	 0.0	 0.0	 1	 -30.0	 30.0;
	12866	 6188	 0.00013	 0.00179	 0.0	 17601	 17601	 17601	 0.0	 0.0	 1	 -30.0	 30.0;
	10280	 1533	 0.00018	 0.00189	 0.0	 16638	 16638	 16638	 0.0	 0.0	 1	 -30.0	 30.0;
	10280	 10514	 0.0002	 0.00185	 0.0	 16976	 16976	 16976	 0.0	 0.0	 1	 -30.0	 30.0;
	1533	 2174	 0.00039	 0.00344	 0.0	 9124	 9124	 9124	 0.0	 0.0	 1	 -30.0	 30.0;
	10514	 8313	 0.0004	 0.00337	 0.0	 9308	 9308	 9308	 0.0	 0.0	 1	 -30.0	 30.0;
	10280	 13454	 0.00027	 0.00274	 0.0	 11473	 11473	 11473	 0.0	 0.0	 1	 -30.0	 30.0;
	10280	 1771	 0.00056	 0.00437	 0.0	 7170	 7170	 7170	 0.0	 0.0	 1	 -30.0	 30.0;
	10280	 9732	 0.00026	 0.00279	 0.0	 11273	 11273	 11273	 0.0	 0.0	 1	 -30.0	 30.0;
	7699	 3986	 0.001349	 0.00763	 0.0	 4077	 4077	 4077	 0.0	 0.0	 1	 -30.0	 30.0;
	7699	 3746	 0.00374	 0.02218	 0.0	 1405	 1405	 1405	 0.0	 0.0	 1	 -30.0	 30.0;
	7699	 5547	 0.000349	 0.00186	 0.0	 16692	 16692	 16692	 0.0	 0.0	 1	 -30.0	 30.0;
	7699	 3746	 0.004651	 0.02025	 0.0	 1521	 1521	 1521	 0.0	 0.0	 1	 -30.0	 30.0;
	7699	 5547	 0.00037	 0.00182	 0.0	 17008	 17008	 17008	 0.0	 0.0	 1	 -30.0	 30.0;
	376	 6032	 0.001	 0.209093	 0.0	 152	 152	 152	 0.0	 0.0	 1	 -30.0	 30.0;
	376	 6510	 0.00062	 0.00513	 0.0	 6113	 6113	 6113	 0.0	 0.0	 1	 -30.0	 30.0;
	376	 3603	 0.04427	 0.493158	 0.0	 64	 64	 64	 0.0	 0.0	 1	 -30.0	 30.0;
	376	 2174	 2.319321	 5.378532	 0.0	 6	 6	 6	 0.0	 0.0	 1	 -30.0	 30.0;
	7131	 376	 2.762188	 4.809072	 0.0	 6	 6	 6	 0.0	 0.0	 1	 -30.0	 30.0;
	13017	 376	 24.69598	 23.43698	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	376	 6550	 1.383864	 4.675693	 0.0	 7	 7	 7	 0.0	 0.0	 1	 -30.0	 30.0;
	964	 376	 0.470817	 2.500277	 0.0	 13	 13	 13	 0.0	 0.0	 1	 -30.0	 30.0;
	1651	 376	 0.00099	 0.00946	 0.0	 3321	 3321	 3321	 0.0	 0.0	 1	 -30.0	 30.0;
	13282	 376	 0.05862	 0.781925	 0.0	 41	 41	 41	 0.0	 0.0	 1	 -30.0	 30.0;
	6032	 3603	 0.04335	 0.502652	 0.0	 63	 63	 63	 0.0	 0.0	 1	 -30.0	 30.0;
	6032	 3603	 0.00063	 0.00502	 0.0	 6244	 6244	 6244	 0.0	 0.0	 1	 -30.0	 30.0;
	6032	 2174	 2.364751	 5.268767	 0.0	 6	 6	 6	 0.0	 0.0	 1	 -30.0	 30.0;
	7131	 6032	 2.814266	 4.706787	 0.0	 6	 6	 6	 0.0	 0.0	 1	 -30.0	 30.0;
	13017	 6032	 25.15305	 22.92729	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	6032	 13432	 0.00032	 0.00223	 0.0	 14022	 14022	 14022	 0.0	 0.0	 1	 -30.0	 30.0;
	6032	 6550	 1.353809	 4.329363	 0.0	 7	 7	 7	 0.0	 0.0	 1	 -30.0	 30.0;
	964	 6032	 0.460582	 2.315097	 0.0	 14	 14	 14	 0.0	 0.0	 1	 -30.0	 30.0;
	13282	 6032	 0.0574	 0.796953	 0.0	 40	 40	 40	 0.0	 0.0	 1	 -30.0	 30.0;
	11793	 2977	 0.00439	 0.016341	 0.0	 1867	 1867	 1867	 0.0	 0.0	 1	 -30.0	 30.0;
	385	 8316	 0.004039	 0.019031	 0.0	 1624	 1624	 1624	 0.0	 0.0	 1	 -30.0	 30.0;
	385	 12536	 0.001331	 0.007669	 0.0	 4059	 4059	 4059	 0.0	 0.0	 1	 -30.0	 30.0;
	8316	 10603	 0.001091	 0.005159	 0.0	 5991	 5991	 5991	 0.0	 0.0	 1	 -30.0	 30.0;
	12536	 2935	 0.00131	 0.00782	 0.0	 3984	 3984	 3984	 0.0	 0.0	 1	 -30.0	 30.0;
	2935	 3932	 0.00449	 0.022021	 0.0	 1406	 1406	 1406	 0.0	 0.0	 1	 -30.0	 30.0;
	6510	 3603	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	6510	 3603	 0.001	 0.229342	 0.0	 138	 138	 138	 0.0	 0.0	 1	 -30.0	 30.0;
	1665	 6510	 0.159093	 0.880956	 0.0	 36	 36	 36	 0.0	 0.0	 1	 -30.0	 30.0;
	4490	 6510	 0.11009	 0.785942	 0.0	 40	 40	 40	 0.0	 0.0	 1	 -30.0	 30.0;
	2872	 6510	 0.00133	 0.01275	 0.0	 2465	 2465	 2465	 0.0	 0.0	 1	 -30.0	 30.0;
	7278	 6510	 0.08106	 0.897645	 0.0	 36	 36	 36	 0.0	 0.0	 1	 -30.0	 30.0;
	13017	 6510	 0.0009	 0.00658	 0.0	 4757	 4757	 4757	 0.0	 0.0	 1	 -30.0	 30.0;
	13017	 6510	 1.066967	 3.005956	 0.0	 10	 10	 10	 0.0	 0.0	 1	 -30.0	 30.0;
	2897	 6510	 0.00037	 0.00335	 0.0	 9373	 9373	 9373	 0.0	 0.0	 1	 -30.0	 30.0;
	1665	 3603	 0.14919	 0.968975	 0.0	 33	 33	 33	 0.0	 0.0	 1	 -30.0	 30.0;
	4490	 3603	 0.107472	 0.83054	 0.0	 38	 38	 38	 0.0	 0.0	 1	 -30.0	 30.0;
	3603	 2174	 6.591066	 12.31994	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	7278	 3603	 0.089861	 0.931163	 0.0	 34	 34	 34	 0.0	 0.0	 1	 -30.0	 30.0;
	7278	 3603	 0.00151	 0.0125	 0.0	 2509	 2509	 2509	 0.0	 0.0	 1	 -30.0	 30.0;
	7131	 3603	 7.50831	 11.99515	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	13017	 3603	 57.05332	 52.93698	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	13017	 3603	 1.218213	 2.697091	 0.0	 11	 11	 11	 0.0	 0.0	 1	 -30.0	 30.0;
	13017	 3603	 0.00091	 0.00644	 0.0	 4857	 4857	 4857	 0.0	 0.0	 1	 -30.0	 30.0;
	6550	 3603	 5.391066	 9.229224	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	964	 3603	 1.899723	 5.672438	 0.0	 6	 6	 6	 0.0	 0.0	 1	 -30.0	 30.0;
	1670	 3603	 0.00034	 0.00341	 0.0	 9218	 9218	 9218	 0.0	 0.0	 1	 -30.0	 30.0;
	13282	 3603	 0.372853	 1.916066	 0.0	 17	 17	 17	 0.0	 0.0	 1	 -30.0	 30.0;
	260	 4180	 0.001	 0.398657	 0.0	 80	 80	 80	 0.0	 0.0	 1	 -30.0	 30.0;
	260	 3119	 0.00157	 0.00875	 0.0	 3554	 3554	 3554	 0.0	 0.0	 1	 -30.0	 30.0;
	2774	 4180	 0.013419	 0.18632	 0.0	 170	 170	 170	 0.0	 0.0	 1	 -30.0	 30.0;
	2774	 3119	 0.001771	 0.00857	 0.0	 3610	 3610	 3610	 0.0	 0.0	 1	 -30.0	 30.0;
	5912	 10382	 3e-05	 0.00035	 0.0	 89920	 89920	 89920	 0.0	 0.0	 1	 -30.0	 30.0;
	5912	 6823	 4e-05	 0.00047	 0.0	 66966	 66966	 66966	 0.0	 0.0	 1	 -30.0	 30.0;
	11448	 11302	 6.406818	 19.24731	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	2359	 11302	 5.408471	 18.64401	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	366	 11302	 4.777893	 12.85021	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	11302	 1535	 7.316529	 22.04545	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	11302	 1535	 0.00518	 0.053229	 0.0	 710	 710	 710	 0.0	 0.0	 1	 -30.0	 30.0;
	7014	 11302	 1.28	 5.819421	 0.0	 7	 7	 7	 0.0	 0.0	 1	 -30.0	 30.0;
	12720	 11302	 1.306178	 5.47314	 0.0	 7	 7	 7	 0.0	 0.0	 1	 -30.0	 30.0;
	11302	 9401	 0.001	 0.244421	 0.0	 154	 154	 154	 0.0	 0.0	 1	 -30.0	 30.0;
	1566	 11302	 0.326384	 2.031736	 0.0	 19	 19	 19	 0.0	 0.0	 1	 -30.0	 30.0;
	5754	 11302	 0.34876	 2.295661	 0.0	 17	 17	 17	 0.0	 0.0	 1	 -30.0	 30.0;
	11302	 9401	 0.000401	 0.00324	 0.0	 11515	 11515	 11515	 0.0	 0.0	 1	 -30.0	 30.0;
	272	 12622	 1.103116	 4.165166	 0.0	 8	 8	 8	 0.0	 0.0	 1	 -30.0	 30.0;
	4883	 12622	 0.982756	 4.720568	 0.0	 7	 7	 7	 0.0	 0.0	 1	 -30.0	 30.0;
	7997	 12622	 17.77701	 32.87327	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	12622	 6414	 11.94321	 24.78324	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	12406	 12622	 0.13187	 1.326939	 0.0	 24	 24	 24	 0.0	 0.0	 1	 -30.0	 30.0;
	8314	 12622	 0.129169	 1.352909	 0.0	 24	 24	 24	 0.0	 0.0	 1	 -30.0	 30.0;
	9085	 12622	 15.47438	 32.5367	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	12866	 12622	 0.00019	 0.00211	 0.0	 14910	 14910	 14910	 0.0	 0.0	 1	 -30.0	 30.0;
	12866	 12622	 0.0002	 0.00206	 0.0	 15262	 15262	 15262	 0.0	 0.0	 1	 -30.0	 30.0;
	11263	 5667	 0.00013	 0.001771	 0.0	 17789	 17789	 17789	 0.0	 0.0	 1	 -30.0	 30.0;
	9820	 7765	 0.008081	 0.041651	 0.0	 745	 745	 745	 0.0	 0.0	 1	 -30.0	 30.0;
	9820	 7765	 0.168091	 0.83657	 0.0	 38	 38	 38	 0.0	 0.0	 1	 -30.0	 30.0;
	9820	 7765	 0.008229	 0.040771	 0.0	 760	 760	 760	 0.0	 0.0	 1	 -30.0	 30.0;
	7733	 7765	 2.293802	 5.98719	 0.0	 5	 5	 5	 0.0	 0.0	 1	 -30.0	 30.0;
	3193	 7765	 2.825	 5.516736	 0.0	 6	 6	 6	 0.0	 0.0	 1	 -30.0	 30.0;
	7765	 6386	 0.731178	 1.985165	 0.0	 15	 15	 15	 0.0	 0.0	 1	 -30.0	 30.0;
	11447	 9820	 0.001349	 0.01345	 0.0	 2337	 2337	 2337	 0.0	 0.0	 1	 -30.0	 30.0;
	945	 11447	 0.00051	 0.00643	 0.0	 4898	 4898	 4898	 0.0	 0.0	 1	 -30.0	 30.0;
	10905	 9820	 0.00137	 0.013159	 0.0	 2388	 2388	 2388	 0.0	 0.0	 1	 -30.0	 30.0;
	945	 10905	 0.0005	 0.00655	 0.0	 4809	 4809	 4809	 0.0	 0.0	 1	 -30.0	 30.0;
	13354	 9636	 0.001	 0.425381	 0.0	 90	 90	 90	 0.0	 0.0	 1	 -30.0	 30.0;
	9506	 9636	 4.659141	 9.407202	 0.0	 4	 4	 4	 0.0	 0.0	 1	 -30.0	 30.0;
	1172	 9636	 1.022853	 3.286357	 0.0	 10	 10	 10	 0.0	 0.0	 1	 -30.0	 30.0;
	9636	 5569	 1.18795	 4.384626	 0.0	 7	 7	 7	 0.0	 0.0	 1	 -30.0	 30.0;
	9636	 8176	 1.213781	 4.303324	 0.0	 8	 8	 8	 0.0	 0.0	 1	 -30.0	 30.0;
	6825	 9636	 8.581024	 12.40582	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	10957	 9636	 0.203857	 1.400623	 0.0	 23	 23	 23	 0.0	 0.0	 1	 -30.0	 30.0;
	9636	 5569	 0.00082	 0.0099	 0.0	 3180	 3180	 3180	 0.0	 0.0	 1	 -30.0	 30.0;
	10957	 9636	 0.00056	 0.0066	 0.0	 4769	 4769	 4769	 0.0	 0.0	 1	 -30.0	 30.0;
	6570	 9636	 0.00031	 0.00634	 0.0	 4977	 4977	 4977	 0.0	 0.0	 1	 -30.0	 30.0;
	9506	 13354	 4.02687	 9.790858	 0.0	 4	 4	 4	 0.0	 0.0	 1	 -30.0	 30.0;
	1172	 13354	 1.000554	 3.350416	 0.0	 11	 11	 11	 0.0	 0.0	 1	 -30.0	 30.0;
	13354	 8176	 0.00081	 0.0101	 0.0	 3745	 3745	 3745	 0.0	 0.0	 1	 -30.0	 30.0;
	13354	 5569	 1.418213	 3.650623	 0.0	 10	 10	 10	 0.0	 0.0	 1	 -30.0	 30.0;
	13354	 8176	 1.263504	 4.137327	 0.0	 9	 9	 9	 0.0	 0.0	 1	 -30.0	 30.0;
	6825	 13354	 8.415512	 12.67105	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	10957	 13354	 0.172188	 1.486496	 0.0	 26	 26	 26	 0.0	 0.0	 1	 -30.0	 30.0;
	7733	 9820	 0.008531	 0.04201	 0.0	 737	 737	 737	 0.0	 0.0	 1	 -30.0	 30.0;
	7733	 9820	 0.19088	 1.317025	 0.0	 24	 24	 24	 0.0	 0.0	 1	 -30.0	 30.0;
	3193	 9820	 0.20351	 1.242748	 0.0	 26	 26	 26	 0.0	 0.0	 1	 -30.0	 30.0;
	9820	 10603	 0.003419	 0.02226	 0.0	 1403	 1403	 1403	 0.0	 0.0	 1	 -30.0	 30.0;
	9820	 6386	 0.05611	 0.44343	 0.0	 71	 71	 71	 0.0	 0.0	 1	 -30.0	 30.0;
	3193	 9820	 0.00869	 0.041091	 0.0	 753	 753	 753	 0.0	 0.0	 1	 -30.0	 30.0;
	9820	 6102	 0.003349	 0.02268	 0.0	 1378	 1378	 1378	 0.0	 0.0	 1	 -30.0	 30.0;
	13306	 9820	 0.00176	 0.018651	 0.0	 1687	 1687	 1687	 0.0	 0.0	 1	 -30.0	 30.0;
	11905	 2741	 0.00019	 0.00245	 0.0	 12855	 12855	 12855	 0.0	 0.0	 1	 -30.0	 30.0;
	11905	 2741	 0.00019	 0.00227	 0.0	 13867	 13867	 13867	 0.0	 0.0	 1	 -30.0	 30.0;
	7915	 5569	 0.00018	 0.00209	 0.0	 15058	 15058	 15058	 0.0	 0.0	 1	 -30.0	 30.0;
	3170	 8176	 0.00017	 0.00213	 0.0	 14783	 14783	 14783	 0.0	 0.0	 1	 -30.0	 30.0;
	9863	 622	 0.00024	 0.0025	 0.0	 12578	 12578	 12578	 0.0	 0.0	 1	 -30.0	 30.0;
	9506	 1172	 0.897576	 2.903878	 0.0	 11	 11	 11	 0.0	 0.0	 1	 -30.0	 30.0;
	6825	 9506	 0.01432	 0.301302	 0.0	 105	 105	 105	 0.0	 0.0	 1	 -30.0	 30.0;
	8391	 9506	 0.00025	 0.00245	 0.0	 12827	 12827	 12827	 0.0	 0.0	 1	 -30.0	 30.0;
	9506	 10957	 3.381094	 7.270776	 0.0	 4	 4	 4	 0.0	 0.0	 1	 -30.0	 30.0;
	687	 4490	 0.00142	 0.01435	 0.0	 2191	 2191	 2191	 0.0	 0.0	 1	 -30.0	 30.0;
	687	 1550	 0.00023	 0.00181	 0.0	 17313	 17313	 17313	 0.0	 0.0	 1	 -30.0	 30.0;
	10313	 4490	 0.00139	 0.01463	 0.0	 2150	 2150	 2150	 0.0	 0.0	 1	 -30.0	 30.0;
	10313	 10000	 0.00023	 0.00178	 0.0	 17600	 17600	 17600	 0.0	 0.0	 1	 -30.0	 30.0;
	1665	 4798	 0.00047	 0.00384	 0.0	 8165	 8165	 8165	 0.0	 0.0	 1	 -30.0	 30.0;
	1665	 4307	 0.0005	 0.00403	 0.0	 7779	 7779	 7779	 0.0	 0.0	 1	 -30.0	 30.0;
	7278	 4307	 0.00025	 0.00236	 0.0	 13310	 13310	 13310	 0.0	 0.0	 1	 -30.0	 30.0;
	1665	 4490	 0.838573	 2.37223	 0.0	 13	 13	 13	 0.0	 0.0	 1	 -30.0	 30.0;
	7278	 1665	 0.078193	 0.509841	 0.0	 62	 62	 62	 0.0	 0.0	 1	 -30.0	 30.0;
	13017	 1665	 5.654848	 7.590028	 0.0	 4	 4	 4	 0.0	 0.0	 1	 -30.0	 30.0;
	12197	 4490	 0.0009	 0.0069	 0.0	 4540	 4540	 4540	 0.0	 0.0	 1	 -30.0	 30.0;
	13017	 12197	 0.0002	 0.00149	 0.0	 21012	 21012	 21012	 0.0	 0.0	 1	 -30.0	 30.0;
	13536	 4490	 0.00092	 0.00675	 0.0	 4637	 4637	 4637	 0.0	 0.0	 1	 -30.0	 30.0;
	13017	 13536	 0.0002	 0.00145	 0.0	 21581	 21581	 21581	 0.0	 0.0	 1	 -30.0	 30.0;
	7278	 4490	 0.413608	 1.666759	 0.0	 19	 19	 19	 0.0	 0.0	 1	 -30.0	 30.0;
	13017	 4490	 0.03562	 0.272507	 0.0	 115	 115	 115	 0.0	 0.0	 1	 -30.0	 30.0;
	7162	 906	 0.0001	 0.00144	 0.0	 21883	 21883	 21883	 0.0	 0.0	 1	 -30.0	 30.0;
	12866	 7162	 9e-05	 0.00129	 0.0	 24427	 24427	 24427	 0.0	 0.0	 1	 -30.0	 30.0;
	2272	 9667	 0.0001	 0.00133	 0.0	 23684	 23684	 23684	 0.0	 0.0	 1	 -30.0	 30.0;
	12866	 2272	 9e-05	 0.00132	 0.0	 23875	 23875	 23875	 0.0	 0.0	 1	 -30.0	 30.0;
	906	 6344	 0.00063	 0.00676	 0.0	 4653	 4653	 4653	 0.0	 0.0	 1	 -30.0	 30.0;
	9667	 3353	 0.00065	 0.00662	 0.0	 4749	 4749	 4749	 0.0	 0.0	 1	 -30.0	 30.0;
	6362	 6344	 0.00017	 0.00236	 0.0	 13350	 13350	 13350	 0.0	 0.0	 1	 -30.0	 30.0;
	6362	 3353	 0.00017	 0.00219	 0.0	 14381	 14381	 14381	 0.0	 0.0	 1	 -30.0	 30.0;
	1758	 13213	 0.0017	 0.007469	 0.0	 4124	 4124	 4124	 0.0	 0.0	 1	 -30.0	 30.0;
	13213	 9140	 0.001039	 0.005599	 0.0	 5547	 5547	 5547	 0.0	 0.0	 1	 -30.0	 30.0;
	1758	 10921	 0.001729	 0.00731	 0.0	 4206	 4206	 4206	 0.0	 0.0	 1	 -30.0	 30.0;
	10921	 141	 0.001021	 0.0057	 0.0	 6552	 6552	 6552	 0.0	 0.0	 1	 -30.0	 30.0;
	1758	 2554	 0.00168	 0.007159	 0.0	 4296	 4296	 4296	 0.0	 0.0	 1	 -30.0	 30.0;
	2554	 9140	 0.00112	 0.00495	 0.0	 6224	 6224	 6224	 0.0	 0.0	 1	 -30.0	 30.0;
	13213	 10921	 0.001	 0.364917	 0.0	 87	 87	 87	 0.0	 0.0	 1	 -30.0	 30.0;
	1758	 13213	 0.106669	 0.821178	 0.0	 39	 39	 39	 0.0	 0.0	 1	 -30.0	 30.0;
	13213	 9140	 0.0977	 0.935248	 0.0	 34	 34	 34	 0.0	 0.0	 1	 -30.0	 30.0;
	13213	 141	 0.10481	 0.756446	 0.0	 50	 50	 50	 0.0	 0.0	 1	 -30.0	 30.0;
	1758	 10921	 0.094539	 0.895083	 0.0	 36	 36	 36	 0.0	 0.0	 1	 -30.0	 30.0;
	10921	 9140	 0.09563	 0.921384	 0.0	 35	 35	 35	 0.0	 0.0	 1	 -30.0	 30.0;
	10921	 141	 0.085479	 0.810062	 0.0	 47	 47	 47	 0.0	 0.0	 1	 -30.0	 30.0;
	6362	 5353	 0.0002	 0.0021	 0.0	 14974	 14974	 14974	 0.0	 0.0	 1	 -30.0	 30.0;
	5353	 9567	 0.00051	 0.00613	 0.0	 5136	 5136	 5136	 0.0	 0.0	 1	 -30.0	 30.0;
	10699	 8993	 0.00062	 0.006331	 0.0	 4966	 4966	 4966	 0.0	 0.0	 1	 -30.0	 30.0;
	8993	 2264	 0.00075	 0.00981	 0.0	 3211	 3211	 3211	 0.0	 0.0	 1	 -30.0	 30.0;
	6362	 2342	 0.00105	 0.01369	 0.0	 2301	 2301	 2301	 0.0	 0.0	 1	 -30.0	 30.0;
	2342	 722	 0.00132	 0.01291	 0.0	 2435	 2435	 2435	 0.0	 0.0	 1	 -30.0	 30.0;
	6362	 8975	 0.00103	 0.01395	 0.0	 2259	 2259	 2259	 0.0	 0.0	 1	 -30.0	 30.0;
	8975	 11650	 0.00134	 0.01263	 0.0	 2488	 2488	 2488	 0.0	 0.0	 1	 -30.0	 30.0;
	6362	 8653	 0.269647	 1.156579	 0.0	 27	 27	 27	 0.0	 0.0	 1	 -30.0	 30.0;
	478	 6362	 0.06211	 0.718075	 0.0	 44	 44	 44	 0.0	 0.0	 1	 -30.0	 30.0;
	6362	 866	 0.00062	 0.005	 0.0	 6270	 6270	 6270	 0.0	 0.0	 1	 -30.0	 30.0;
	7322	 6362	 0.00031	 0.00248	 0.0	 12639	 12639	 12639	 0.0	 0.0	 1	 -30.0	 30.0;
	6362	 3429	 0.0006	 0.0051	 0.0	 6152	 6152	 6152	 0.0	 0.0	 1	 -30.0	 30.0;
	1167	 3932	 0.007331	 0.044461	 0.0	 701	 701	 701	 0.0	 0.0	 1	 -30.0	 30.0;
	1167	 3932	 0.00718	 0.0453	 0.0	 689	 689	 689	 0.0	 0.0	 1	 -30.0	 30.0;
	10699	 556	 0.0002	 0.00211	 0.0	 14904	 14904	 14904	 0.0	 0.0	 1	 -30.0	 30.0;
	439	 556	 0.000659	 0.002909	 0.0	 10591	 10591	 10591	 0.0	 0.0	 1	 -30.0	 30.0;
	9732	 10899	 0.00088	 0.0079	 0.0	 3974	 3974	 3974	 0.0	 0.0	 1	 -30.0	 30.0;
	13454	 2749	 0.00089	 0.00774	 0.0	 4055	 4055	 4055	 0.0	 0.0	 1	 -30.0	 30.0;
	8313	 6380	 0.00089	 0.00706	 0.0	 4439	 4439	 4439	 0.0	 0.0	 1	 -30.0	 30.0;
	2174	 2648	 0.0009	 0.0069	 0.0	 4540	 4540	 4540	 0.0	 0.0	 1	 -30.0	 30.0;
	7131	 2174	 0.527957	 1.890097	 0.0	 17	 17	 17	 0.0	 0.0	 1	 -30.0	 30.0;
	13017	 2174	 6.434972	 8.855956	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	6550	 2174	 0.02292	 0.469398	 0.0	 68	 68	 68	 0.0	 0.0	 1	 -30.0	 30.0;
	964	 2174	 0.03034	 0.81482	 0.0	 39	 39	 39	 0.0	 0.0	 1	 -30.0	 30.0;
	13282	 2174	 0.225173	 1.343006	 0.0	 24	 24	 24	 0.0	 0.0	 1	 -30.0	 30.0;
	7767	 4900	 0.0001	 0.00122	 0.0	 25805	 25805	 25805	 0.0	 0.0	 1	 -30.0	 30.0;
	11732	 4900	 0.00025	 0.00221	 0.0	 14203	 14203	 14203	 0.0	 0.0	 1	 -30.0	 30.0;
	131	 10838	 2.696676	 13.13573	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	131	 8035	 3.125	 11.9903	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	5912	 131	 0.00054	 0.00664	 0.0	 4742	 4742	 4742	 0.0	 0.0	 1	 -30.0	 30.0;
	11812	 131	 0.899169	 5.002355	 0.0	 7	 7	 7	 0.0	 0.0	 1	 -30.0	 30.0;
	12474	 131	 0.06172	 1.437119	 0.0	 22	 22	 22	 0.0	 0.0	 1	 -30.0	 30.0;
	91	 131	 0.521247	 2.927216	 0.0	 11	 11	 11	 0.0	 0.0	 1	 -30.0	 30.0;
	11732	 131	 0.00397	 0.614771	 0.0	 52	 52	 52	 0.0	 0.0	 1	 -30.0	 30.0;
	12274	 131	 0.956579	 5.569321	 0.0	 6	 6	 6	 0.0	 0.0	 1	 -30.0	 30.0;
	3895	 131	 0.071011	 1.246122	 0.0	 26	 26	 26	 0.0	 0.0	 1	 -30.0	 30.0;
	1789	 131	 22.47576	 40.81994	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	919	 131	 0.00141	 0.00778	 0.0	 3995	 3995	 3995	 0.0	 0.0	 1	 -30.0	 30.0;
	1747	 2648	 0.00021	 0.00179	 0.0	 17527	 17527	 17527	 0.0	 0.0	 1	 -30.0	 30.0;
	6550	 6380	 0.00021	 0.00175	 0.0	 17922	 17922	 17922	 0.0	 0.0	 1	 -30.0	 30.0;
	7454	 5003	 0.00051	 0.00411	 0.0	 7627	 7627	 7627	 0.0	 0.0	 1	 -30.0	 30.0;
	2586	 11186	 0.00052	 0.00402	 0.0	 7793	 7793	 7793	 0.0	 0.0	 1	 -30.0	 30.0;
	5003	 11186	 0.00439	 0.248677	 0.0	 128	 128	 128	 0.0	 0.0	 1	 -30.0	 30.0;
	7733	 3193	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	7733	 3193	 0.001	 0.289959	 0.0	 109	 109	 109	 0.0	 0.0	 1	 -30.0	 30.0;
	7733	 5496	 9.9e-05	 0.000789	 0.0	 39724	 39724	 39724	 0.0	 0.0	 1	 -30.0	 30.0;
	7733	 6386	 0.13343	 0.727438	 0.0	 43	 43	 43	 0.0	 0.0	 1	 -30.0	 30.0;
	3193	 6386	 0.11368	 0.773802	 0.0	 41	 41	 41	 0.0	 0.0	 1	 -30.0	 30.0;
	752	 10995	 0.0001	 0.0011	 0.0	 28598	 28598	 28598	 0.0	 0.0	 1	 -30.0	 30.0;
	7211	 752	 0.00069	 0.00512	 0.0	 6115	 6115	 6115	 0.0	 0.0	 1	 -30.0	 30.0;
	2739	 2055	 0.0001	 0.00102	 0.0	 30821	 30821	 30821	 0.0	 0.0	 1	 -30.0	 30.0;
	3504	 2739	 0.0007	 0.005	 0.0	 6257	 6257	 6257	 0.0	 0.0	 1	 -30.0	 30.0;
	8269	 5671	 0.00031	 0.00399	 0.0	 7893	 7893	 7893	 0.0	 0.0	 1	 -30.0	 30.0;
	10838	 8269	 9e-05	 0.00103	 0.0	 30551	 30551	 30551	 0.0	 0.0	 1	 -30.0	 30.0;
	5671	 7845	 0.00021	 0.00231	 0.0	 13619	 13619	 13619	 0.0	 0.0	 1	 -30.0	 30.0;
	7845	 3052	 8e-05	 0.00082	 0.0	 38340	 38340	 38340	 0.0	 0.0	 1	 -30.0	 30.0;
	3052	 4721	 0.00016	 0.00203	 0.0	 15513	 15513	 15513	 0.0	 0.0	 1	 -30.0	 30.0;
	4721	 8765	 3e-05	 0.00036	 0.0	 87440	 87440	 87440	 0.0	 0.0	 1	 -30.0	 30.0;
	91	 8765	 0.00061	 0.00766	 0.0	 4111	 4111	 4111	 0.0	 0.0	 1	 -30.0	 30.0;
	10838	 8035	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	10838	 8035	 0.01257	 0.43678	 0.0	 73	 73	 73	 0.0	 0.0	 1	 -30.0	 30.0;
	11812	 10838	 22.73892	 49.0	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	12474	 10838	 4.844044	 19.18698	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	91	 10838	 0.001	 1.752701	 0.0	 19	 19	 19	 0.0	 0.0	 1	 -30.0	 30.0;
	11732	 10838	 0.908172	 6.096537	 0.0	 6	 6	 6	 0.0	 0.0	 1	 -30.0	 30.0;
	10349	 10838	 4.358657	 9.756232	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	12274	 10838	 25.29224	 66.18213	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	3895	 10838	 1.071399	 5.397922	 0.0	 6	 6	 6	 0.0	 0.0	 1	 -30.0	 30.0;
	1789	 10838	 0.155789	 0.985526	 0.0	 32	 32	 32	 0.0	 0.0	 1	 -30.0	 30.0;
	11812	 8035	 23.51524	 49.62604	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	12474	 8035	 5.179155	 18.97368	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	91	 8035	 0.0144	 1.921053	 0.0	 17	 17	 17	 0.0	 0.0	 1	 -30.0	 30.0;
	11732	 8035	 0.997091	 6.027978	 0.0	 6	 6	 6	 0.0	 0.0	 1	 -30.0	 30.0;
	10349	 8035	 4.636704	 9.781162	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	12274	 8035	 29.33518	 59.12049	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	3895	 8035	 1.098269	 5.695983	 0.0	 6	 6	 6	 0.0	 0.0	 1	 -30.0	 30.0;
	1789	 8035	 0.00085	 0.00853	 0.0	 3685	 3685	 3685	 0.0	 0.0	 1	 -30.0	 30.0;
	1789	 8035	 0.15653	 1.070014	 0.0	 30	 30	 30	 0.0	 0.0	 1	 -30.0	 30.0;
	8888	 8653	 0.00015	 0.00148	 0.0	 21235	 21235	 21235	 0.0	 0.0	 1	 -30.0	 30.0;
	699	 8653	 0.00014	 0.00167	 0.0	 18849	 18849	 18849	 0.0	 0.0	 1	 -30.0	 30.0;
	478	 8653	 0.525672	 1.551039	 0.0	 20	 20	 20	 0.0	 0.0	 1	 -30.0	 30.0;
	9465	 2160	 0.00411	 0.01861	 0.0	 1658	 1658	 1658	 0.0	 0.0	 1	 -30.0	 30.0;
	6102	 9465	 0.000969	 0.005841	 0.0	 5335	 5335	 5335	 0.0	 0.0	 1	 -30.0	 30.0;
	2160	 3932	 0.004581	 0.02156	 0.0	 1434	 1434	 1434	 0.0	 0.0	 1	 -30.0	 30.0;
	3775	 9492	 0.00026	 0.00323	 0.0	 9748	 9748	 9748	 0.0	 0.0	 1	 -30.0	 30.0;
	3775	 9492	 0.00026	 0.00329	 0.0	 9572	 9572	 9572	 0.0	 0.0	 1	 -30.0	 30.0;
	272	 6868	 6e-05	 0.00065	 0.0	 48391	 48391	 48391	 0.0	 0.0	 1	 -30.0	 30.0;
	6868	 2257	 0.00038	 0.00377	 0.0	 8337	 8337	 8337	 0.0	 0.0	 1	 -30.0	 30.0;
	4883	 13020	 6e-05	 0.00066	 0.0	 47664	 47664	 47664	 0.0	 0.0	 1	 -30.0	 30.0;
	13020	 4997	 0.00038	 0.00369	 0.0	 8516	 8516	 8516	 0.0	 0.0	 1	 -30.0	 30.0;
	272	 4883	 0.01122	 0.71669	 0.0	 45	 45	 45	 0.0	 0.0	 1	 -30.0	 30.0;
	7997	 272	 25.10803	 39.16205	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	272	 6414	 32.07964	 43.87258	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	272	 12406	 0.427673	 3.90554	 0.0	 9	 9	 9	 0.0	 0.0	 1	 -30.0	 30.0;
	272	 8314	 0.418573	 3.979224	 0.0	 8	 8	 8	 0.0	 0.0	 1	 -30.0	 30.0;
	9085	 272	 23.26662	 36.54363	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	7997	 4883	 25.59141	 38.34626	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	4883	 6414	 32.6849	 42.93906	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	4883	 12406	 0.409481	 3.684488	 0.0	 9	 9	 9	 0.0	 0.0	 1	 -30.0	 30.0;
	4883	 8314	 0.464072	 3.610803	 0.0	 9	 9	 9	 0.0	 0.0	 1	 -30.0	 30.0;
	9085	 4883	 23.70568	 35.76593	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	1467	 5005	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	1467	 5005	 0.001	 0.19151	 0.0	 165	 165	 165	 0.0	 0.0	 1	 -30.0	 30.0;
	1467	 5923	 17.56446	 20.66736	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	1467	 1752	 13.87645	 21.76446	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	1467	 644	 1.145248	 3.637603	 0.0	 9	 9	 9	 0.0	 0.0	 1	 -30.0	 30.0;
	1467	 2726	 1.372004	 3.186983	 0.0	 10	 10	 10	 0.0	 0.0	 1	 -30.0	 30.0;
	5344	 1467	 0.119159	 0.998905	 0.0	 32	 32	 32	 0.0	 0.0	 1	 -30.0	 30.0;
	1467	 2264	 6.052479	 9.575826	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	4342	 1467	 4.474793	 10.74483	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	1684	 1467	 4.534711	 10.47087	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	5005	 5923	 18.49236	 22.54545	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	5005	 1752	 13.69401	 22.82645	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	5005	 644	 1.333636	 3.866942	 0.0	 8	 8	 8	 0.0	 0.0	 1	 -30.0	 30.0;
	5005	 2726	 1.179442	 4.148554	 0.0	 8	 8	 8	 0.0	 0.0	 1	 -30.0	 30.0;
	5344	 5005	 0.114281	 1.035289	 0.0	 31	 31	 31	 0.0	 0.0	 1	 -30.0	 30.0;
	5005	 2264	 5.617769	 11.75372	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	4342	 5005	 4.939669	 11.00083	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	1684	 5005	 4.903306	 10.93058	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	11272	 2055	 2e-05	 0.00021	 0.0	 149739	 149739	 149739	 0.0	 0.0	 1	 -30.0	 30.0;
	11272	 4941	 0.00028	 0.00263	 0.0	 11943	 11943	 11943	 0.0	 0.0	 1	 -30.0	 30.0;
	4767	 10995	 2e-05	 0.00023	 0.0	 136820	 136820	 136820	 0.0	 0.0	 1	 -30.0	 30.0;
	4767	 10496	 0.00027	 0.00268	 0.0	 11727	 11727	 11727	 0.0	 0.0	 1	 -30.0	 30.0;
	1758	 9140	 0.02601	 0.665517	 0.0	 48	 48	 48	 0.0	 0.0	 1	 -30.0	 30.0;
	1758	 141	 0.028591	 0.528326	 0.0	 72	 72	 72	 0.0	 0.0	 1	 -30.0	 30.0;
	2019	 3464	 0.01088	 0.212832	 0.0	 149	 149	 149	 0.0	 0.0	 1	 -30.0	 30.0;
	3498	 3464	 0.00032	 0.00331	 0.0	 9499	 9499	 9499	 0.0	 0.0	 1	 -30.0	 30.0;
	6250	 3464	 0.00031	 0.00306	 0.0	 10271	 10271	 10271	 0.0	 0.0	 1	 -30.0	 30.0;
	1172	 353	 0.00057	 0.01002	 0.0	 3148	 3148	 3148	 0.0	 0.0	 1	 -30.0	 30.0;
	1172	 3252	 0.00053	 0.00558	 0.0	 5636	 5636	 5636	 0.0	 0.0	 1	 -30.0	 30.0;
	1172	 5569	 22.58241	 30.56787	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	1172	 8176	 22.12119	 31.16759	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	6825	 1172	 1.627632	 4.119529	 0.0	 8	 8	 8	 0.0	 0.0	 1	 -30.0	 30.0;
	12961	 1172	 0.0003	 0.00319	 0.0	 9859	 9859	 9859	 0.0	 0.0	 1	 -30.0	 30.0;
	10957	 1172	 0.00232	 0.519501	 0.0	 61	 61	 61	 0.0	 0.0	 1	 -30.0	 30.0;
	1172	 13309	 0.00058	 0.00981	 0.0	 3215	 3215	 3215	 0.0	 0.0	 1	 -30.0	 30.0;
	13441	 13309	 0.00065	 0.00643	 0.0	 4888	 4888	 4888	 0.0	 0.0	 1	 -30.0	 30.0;
	6598	 353	 0.00063	 0.00655	 0.0	 4801	 4801	 4801	 0.0	 0.0	 1	 -30.0	 30.0;
	2872	 7278	 0.001	 0.215229	 0.0	 147	 147	 147	 0.0	 0.0	 1	 -30.0	 30.0;
	2872	 2019	 0.00102	 0.00911	 0.0	 3446	 3446	 3446	 0.0	 0.0	 1	 -30.0	 30.0;
	7278	 9595	 0.00094	 0.00901	 0.0	 3487	 3487	 3487	 0.0	 0.0	 1	 -30.0	 30.0;
	13017	 7278	 3.359072	 5.253809	 0.0	 6	 6	 6	 0.0	 0.0	 1	 -30.0	 30.0;
	1550	 797	 0.00019	 0.00221	 0.0	 14241	 14241	 14241	 0.0	 0.0	 1	 -30.0	 30.0;
	2019	 1550	 0.00039	 0.00355	 0.0	 8845	 8845	 8845	 0.0	 0.0	 1	 -30.0	 30.0;
	1550	 1649	 0.0001	 0.00073	 0.0	 42870	 42870	 42870	 0.0	 0.0	 1	 -30.0	 30.0;
	10000	 880	 0.00018	 0.00226	 0.0	 13933	 13933	 13933	 0.0	 0.0	 1	 -30.0	 30.0;
	12309	 10000	 0.00038	 0.00368	 0.0	 8539	 8539	 8539	 0.0	 0.0	 1	 -30.0	 30.0;
	10000	 10400	 0.00047	 0.00386	 0.0	 8124	 8124	 8124	 0.0	 0.0	 1	 -30.0	 30.0;
	9140	 141	 0.001	 0.309525	 0.0	 123	 123	 123	 0.0	 0.0	 1	 -30.0	 30.0;
	4180	 3119	 0.000711	 0.00393	 0.0	 7910	 7910	 7910	 0.0	 0.0	 1	 -30.0	 30.0;
	4180	 11169	 0.001219	 0.00569	 0.0	 5429	 5429	 5429	 0.0	 0.0	 1	 -30.0	 30.0;
	4262	 9176	 0.00125	 0.005581	 0.0	 5523	 5523	 5523	 0.0	 0.0	 1	 -30.0	 30.0;
	3119	 9176	 0.0007	 0.00401	 0.0	 7760	 7760	 7760	 0.0	 0.0	 1	 -30.0	 30.0;
	13017	 7131	 0.0599	 0.313109	 0.0	 100	 100	 100	 0.0	 0.0	 1	 -30.0	 30.0;
	7131	 4762	 0.00051	 0.00517	 0.0	 6081	 6081	 6081	 0.0	 0.0	 1	 -30.0	 30.0;
	7131	 6550	 0.92403	 2.090097	 0.0	 14	 14	 14	 0.0	 0.0	 1	 -30.0	 30.0;
	7131	 964	 0.05633	 0.587403	 0.0	 54	 54	 54	 0.0	 0.0	 1	 -30.0	 30.0;
	7131	 13282	 0.333109	 1.178601	 0.0	 26	 26	 26	 0.0	 0.0	 1	 -30.0	 30.0;
	439	 10545	 0.0002	 0.002599	 0.0	 12118	 12118	 12118	 0.0	 0.0	 1	 -30.0	 30.0;
	3025	 5912	 6e-05	 0.00066	 0.0	 47664	 47664	 47664	 0.0	 0.0	 1	 -30.0	 30.0;
	5912	 797	 0.00203	 0.01921	 0.0	 1636	 1636	 1636	 0.0	 0.0	 1	 -30.0	 30.0;
	5912	 12274	 0.00132	 0.01562	 0.0	 2016	 2016	 2016	 0.0	 0.0	 1	 -30.0	 30.0;
	5912	 2741	 0.00039	 0.00541	 0.0	 5824	 5824	 5824	 0.0	 0.0	 1	 -30.0	 30.0;
	5912	 12274	 0.0013	 0.01592	 0.0	 1978	 1978	 1978	 0.0	 0.0	 1	 -30.0	 30.0;
	5912	 9744	 0.00084	 0.00852	 0.0	 3690	 3690	 3690	 0.0	 0.0	 1	 -30.0	 30.0;
	3025	 4398	 0.00016	 0.0017	 0.0	 18500	 18500	 18500	 0.0	 0.0	 1	 -30.0	 30.0;
	11824	 7454	 0.00092	 0.00761	 0.0	 4121	 4121	 4121	 0.0	 0.0	 1	 -30.0	 30.0;
	11824	 722	 0.00062	 0.00468	 0.0	 6691	 6691	 6691	 0.0	 0.0	 1	 -30.0	 30.0;
	8922	 2586	 0.00094	 0.00746	 0.0	 4202	 4202	 4202	 0.0	 0.0	 1	 -30.0	 30.0;
	8922	 11650	 0.00063	 0.00458	 0.0	 6833	 6833	 6833	 0.0	 0.0	 1	 -30.0	 30.0;
	7454	 2586	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	7454	 2586	 0.001	 0.227327	 0.0	 139	 139	 139	 0.0	 0.0	 1	 -30.0	 30.0;
	7454	 5380	 3e-05	 0.00034	 0.0	 92545	 92545	 92545	 0.0	 0.0	 1	 -30.0	 30.0;
	964	 7454	 0.00052	 0.00501	 0.0	 6272	 6272	 6272	 0.0	 0.0	 1	 -30.0	 30.0;
	5939	 2586	 0.00059	 0.00491	 0.0	 6388	 6388	 6388	 0.0	 0.0	 1	 -30.0	 30.0;
	357	 1752	 0.006229	 0.029719	 0.0	 1041	 1041	 1041	 0.0	 0.0	 1	 -30.0	 30.0;
	357	 644	 0.00194	 0.00924	 0.0	 3346	 3346	 3346	 0.0	 0.0	 1	 -30.0	 30.0;
	4507	 3773	 0.00189	 0.00769	 0.0	 3989	 3989	 3989	 0.0	 0.0	 1	 -30.0	 30.0;
	4507	 10991	 0.0037	 0.017021	 0.0	 1814	 1814	 1814	 0.0	 0.0	 1	 -30.0	 30.0;
	6740	 1645	 0.00168	 0.008719	 0.0	 3558	 3558	 3558	 0.0	 0.0	 1	 -30.0	 30.0;
	6740	 9023	 0.003771	 0.016669	 0.0	 1849	 1849	 1849	 0.0	 0.0	 1	 -30.0	 30.0;
	12951	 11169	 0.004669	 0.024729	 0.0	 1256	 1256	 1256	 0.0	 0.0	 1	 -30.0	 30.0;
	1696	 4262	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	1696	 4262	 0.00099	 0.00607	 0.0	 5136	 5136	 5136	 0.0	 0.0	 1	 -30.0	 30.0;
	12951	 1696	 0.00476	 0.02624	 0.0	 1185	 1185	 1185	 0.0	 0.0	 1	 -30.0	 30.0;
	1752	 8468	 0.00051	 0.00286	 0.0	 10874	 10874	 10874	 0.0	 0.0	 1	 -30.0	 30.0;
	1752	 8468	 0.0005	 0.002909	 0.0	 10702	 10702	 10702	 0.0	 0.0	 1	 -30.0	 30.0;
	5923	 1752	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	5923	 1752	 0.001	 0.18874	 0.0	 168	 168	 168	 0.0	 0.0	 1	 -30.0	 30.0;
	5923	 644	 0.704421	 2.986983	 0.0	 11	 11	 11	 0.0	 0.0	 1	 -30.0	 30.0;
	5923	 2726	 0.680207	 2.970661	 0.0	 11	 11	 11	 0.0	 0.0	 1	 -30.0	 30.0;
	5344	 5923	 4.389256	 10.44091	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	5923	 2264	 0.00861	 0.432252	 0.0	 74	 74	 74	 0.0	 0.0	 1	 -30.0	 30.0;
	4342	 5923	 0.006521	 0.039849	 0.0	 783	 783	 783	 0.0	 0.0	 1	 -30.0	 30.0;
	4342	 5923	 0.450599	 2.525826	 0.0	 13	 13	 13	 0.0	 0.0	 1	 -30.0	 30.0;
	1684	 5923	 0.51345	 2.178099	 0.0	 15	 15	 15	 0.0	 0.0	 1	 -30.0	 30.0;
	5923	 2801	 0.000159	 0.002091	 0.0	 15063	 15063	 15063	 0.0	 0.0	 1	 -30.0	 30.0;
	1752	 644	 0.547603	 3.122934	 0.0	 10	 10	 10	 0.0	 0.0	 1	 -30.0	 30.0;
	1752	 2726	 0.63281	 2.590496	 0.0	 12	 12	 12	 0.0	 0.0	 1	 -30.0	 30.0;
	5344	 1752	 4.541736	 8.227686	 0.0	 4	 4	 4	 0.0	 0.0	 1	 -30.0	 30.0;
	1752	 2264	 0.00687	 0.424525	 0.0	 75	 75	 75	 0.0	 0.0	 1	 -30.0	 30.0;
	4342	 1752	 0.394752	 2.341736	 0.0	 14	 14	 14	 0.0	 0.0	 1	 -30.0	 30.0;
	1684	 1752	 0.00638	 0.04063	 0.0	 769	 769	 769	 0.0	 0.0	 1	 -30.0	 30.0;
	1684	 1752	 0.459607	 1.981798	 0.0	 16	 16	 16	 0.0	 0.0	 1	 -30.0	 30.0;
	1752	 2772	 0.000159	 0.00213	 0.0	 14789	 14789	 14789	 0.0	 0.0	 1	 -30.0	 30.0;
	3773	 1645	 0.001	 0.319917	 0.0	 99	 99	 99	 0.0	 0.0	 1	 -30.0	 30.0;
	4860	 3773	 0.074539	 0.567996	 0.0	 56	 56	 56	 0.0	 0.0	 1	 -30.0	 30.0;
	4860	 1645	 0.054219	 0.438326	 0.0	 72	 72	 72	 0.0	 0.0	 1	 -30.0	 30.0;
	2382	 6053	 0.00049	 0.0046	 0.0	 6829	 6829	 6829	 0.0	 0.0	 1	 -30.0	 30.0;
	12058	 6053	 0.00063	 0.00676	 0.0	 4653	 4653	 4653	 0.0	 0.0	 1	 -30.0	 30.0;
	2382	 3288	 0.02777	 0.440042	 0.0	 72	 72	 72	 0.0	 0.0	 1	 -30.0	 30.0;
	5152	 3288	 0.02704	 0.444668	 0.0	 71	 71	 71	 0.0	 0.0	 1	 -30.0	 30.0;
	5152	 3288	 0.00048	 0.00469	 0.0	 6701	 6701	 6701	 0.0	 0.0	 1	 -30.0	 30.0;
	12058	 3288	 0.00062	 0.00626	 0.0	 5022	 5022	 5022	 0.0	 0.0	 1	 -30.0	 30.0;
	2382	 5152	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	2382	 5152	 0.001	 0.247292	 0.0	 128	 128	 128	 0.0	 0.0	 1	 -30.0	 30.0;
	2382	 8683	 3e-05	 0.00035	 0.0	 89920	 89920	 89920	 0.0	 0.0	 1	 -30.0	 30.0;
	11902	 2382	 0.00014	 0.00118	 0.0	 26583	 26583	 26583	 0.0	 0.0	 1	 -30.0	 30.0;
	5152	 11391	 3e-05	 0.00034	 0.0	 92545	 92545	 92545	 0.0	 0.0	 1	 -30.0	 30.0;
	6595	 8683	 0.00072	 0.00903	 0.0	 4189	 4189	 4189	 0.0	 0.0	 1	 -30.0	 30.0;
	6595	 11391	 0.00082	 0.00885	 0.0	 4269	 4269	 4269	 0.0	 0.0	 1	 -30.0	 30.0;
	10899	 1366	 0.00012	 0.00093	 0.0	 33686	 33686	 33686	 0.0	 0.0	 1	 -30.0	 30.0;
	10147	 10603	 0.000831	 0.004229	 0.0	 7330	 7330	 7330	 0.0	 0.0	 1	 -30.0	 30.0;
	13375	 6102	 0.000841	 0.00414	 0.0	 7478	 7478	 7478	 0.0	 0.0	 1	 -30.0	 30.0;
	12961	 8888	 0.00049	 0.00607	 0.0	 5187	 5187	 5187	 0.0	 0.0	 1	 -30.0	 30.0;
	10957	 3252	 0.00048	 0.00567	 0.0	 5552	 5552	 5552	 0.0	 0.0	 1	 -30.0	 30.0;
	10957	 699	 0.00047	 0.00578	 0.0	 5447	 5447	 5447	 0.0	 0.0	 1	 -30.0	 30.0;
	7997	 9085	 6e-05	 0.00069	 0.0	 54276	 54276	 54276	 0.0	 0.0	 1	 -30.0	 30.0;
	7997	 6414	 0.198269	 1.245429	 0.0	 31	 31	 31	 0.0	 0.0	 1	 -30.0	 30.0;
	7997	 12406	 28.23615	 48.46122	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	7997	 8314	 32.00069	 47.49169	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	7997	 9085	 0.001	 0.339079	 0.0	 111	 111	 111	 0.0	 0.0	 1	 -30.0	 30.0;
	5569	 8176	 0.001	 0.23876	 0.0	 133	 133	 133	 0.0	 0.0	 1	 -30.0	 30.0;
	10957	 5569	 7.242382	 14.44598	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	10957	 8176	 7.08795	 14.71814	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	13629	 8158	 0.00493	 0.059419	 0.0	 530	 530	 530	 0.0	 0.0	 1	 -30.0	 30.0;
	13629	 8158	 0.01006	 0.07863	 0.0	 399	 399	 399	 0.0	 0.0	 1	 -30.0	 30.0;
	13629	 8267	 0.001	 0.434587	 0.0	 73	 73	 73	 0.0	 0.0	 1	 -30.0	 30.0;
	13629	 4147	 0.001	 0.434132	 0.0	 73	 73	 73	 0.0	 0.0	 1	 -30.0	 30.0;
	13629	 6581	 9.525206	 20.12748	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	13629	 11448	 0.490393	 3.121901	 0.0	 10	 10	 10	 0.0	 0.0	 1	 -30.0	 30.0;
	13629	 2359	 0.324483	 3.440909	 0.0	 10	 10	 10	 0.0	 0.0	 1	 -30.0	 30.0;
	13629	 8608	 7.110331	 13.27211	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	13629	 4055	 8.147314	 13.64236	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	13629	 8156	 1.873657	 4.730165	 0.0	 7	 7	 7	 0.0	 0.0	 1	 -30.0	 30.0;
	13629	 6030	 1.953223	 4.544628	 0.0	 7	 7	 7	 0.0	 0.0	 1	 -30.0	 30.0;
	13629	 917	 0.893533	 3.267562	 0.0	 10	 10	 10	 0.0	 0.0	 1	 -30.0	 30.0;
	13629	 4995	 0.947417	 3.197521	 0.0	 10	 10	 10	 0.0	 0.0	 1	 -30.0	 30.0;
	13629	 12407	 1.735227	 5.478926	 0.0	 6	 6	 6	 0.0	 0.0	 1	 -30.0	 30.0;
	12043	 13629	 49.21281	 47.44215	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	9823	 13629	 21.70248	 30.12603	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	13629	 6896	 9.99835	 24.78719	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	13629	 10979	 10.26198	 26.88017	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	13629	 1535	 0.625785	 4.196281	 0.0	 8	 8	 8	 0.0	 0.0	 1	 -30.0	 30.0;
	5183	 13629	 0.531426	 3.034091	 0.0	 11	 11	 11	 0.0	 0.0	 1	 -30.0	 30.0;
	7916	 13629	 3.245868	 10.84669	 0.0	 4	 4	 4	 0.0	 0.0	 1	 -30.0	 30.0;
	3743	 13629	 3.282025	 10.98388	 0.0	 4	 4	 4	 0.0	 0.0	 1	 -30.0	 30.0;
	13629	 2256	 0.002919	 0.01451	 0.0	 2135	 2135	 2135	 0.0	 0.0	 1	 -30.0	 30.0;
	13629	 2256	 0.001	 0.67564	 0.0	 47	 47	 47	 0.0	 0.0	 1	 -30.0	 30.0;
	13629	 7691	 0.227169	 1.409215	 0.0	 23	 23	 23	 0.0	 0.0	 1	 -30.0	 30.0;
	13629	 6065	 0.192229	 1.194917	 0.0	 27	 27	 27	 0.0	 0.0	 1	 -30.0	 30.0;
	13629	 2256	 0.002979	 0.0142	 0.0	 2178	 2178	 2178	 0.0	 0.0	 1	 -30.0	 30.0;
	7548	 8045	 0.000151	 0.0015	 0.0	 20953	 20953	 20953	 0.0	 0.0	 1	 -30.0	 30.0;
	7548	 6386	 0.000151	 0.001461	 0.0	 21506	 21506	 21506	 0.0	 0.0	 1	 -30.0	 30.0;
	9492	 2123	 0.00136	 0.0167	 0.0	 1886	 1886	 1886	 0.0	 0.0	 1	 -30.0	 30.0;
	8267	 4147	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	8267	 4147	 0.001	 0.256632	 0.0	 124	 124	 124	 0.0	 0.0	 1	 -30.0	 30.0;
	6581	 8267	 6.78595	 11.8655	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	11448	 8267	 1.097169	 5.085744	 0.0	 7	 7	 7	 0.0	 0.0	 1	 -30.0	 30.0;
	2359	 8267	 0.904029	 5.181818	 0.0	 7	 7	 7	 0.0	 0.0	 1	 -30.0	 30.0;
	8608	 8267	 4.170248	 8.645247	 0.0	 4	 4	 4	 0.0	 0.0	 1	 -30.0	 30.0;
	4055	 8267	 4.773967	 8.884503	 0.0	 4	 4	 4	 0.0	 0.0	 1	 -30.0	 30.0;
	8156	 8267	 0.874421	 3.172727	 0.0	 10	 10	 10	 0.0	 0.0	 1	 -30.0	 30.0;
	6030	 8267	 1.05436	 2.929339	 0.0	 11	 11	 11	 0.0	 0.0	 1	 -30.0	 30.0;
	917	 8267	 0.513368	 2.495455	 0.0	 13	 13	 13	 0.0	 0.0	 1	 -30.0	 30.0;
	4995	 8267	 0.604525	 2.218802	 0.0	 14	 14	 14	 0.0	 0.0	 1	 -30.0	 30.0;
	12407	 8267	 1.308616	 3.033264	 0.0	 10	 10	 10	 0.0	 0.0	 1	 -30.0	 30.0;
	12043	 8267	 39.69008	 38.26033	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	9823	 8267	 17.11942	 22.4938	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	6896	 8267	 20.47789	 32.19835	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	10979	 8267	 21.35331	 30.98554	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	1535	 8267	 1.604091	 6.167149	 0.0	 5	 5	 5	 0.0	 0.0	 1	 -30.0	 30.0;
	5183	 8267	 1.137851	 5.037397	 0.0	 7	 7	 7	 0.0	 0.0	 1	 -30.0	 30.0;
	7916	 8267	 6.625413	 15.09483	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	3743	 8267	 6.196074	 16.5874	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	4717	 8267	 59.24587	 56.3595	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	8267	 2256	 0.086409	 1.077231	 0.0	 30	 30	 30	 0.0	 0.0	 1	 -30.0	 30.0;
	7691	 8267	 0.080841	 0.916612	 0.0	 35	 35	 35	 0.0	 0.0	 1	 -30.0	 30.0;
	6065	 8267	 0.07195	 0.701488	 0.0	 45	 45	 45	 0.0	 0.0	 1	 -30.0	 30.0;
	6581	 4147	 5.952479	 12.55207	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	11448	 4147	 1.208636	 4.790289	 0.0	 7	 7	 7	 0.0	 0.0	 1	 -30.0	 30.0;
	2359	 4147	 0.897293	 4.88781	 0.0	 7	 7	 7	 0.0	 0.0	 1	 -30.0	 30.0;
	8608	 4147	 4.399793	 8.436157	 0.0	 4	 4	 4	 0.0	 0.0	 1	 -30.0	 30.0;
	4055	 4147	 4.466736	 9.775413	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	8156	 4147	 0.924855	 3.415083	 0.0	 9	 9	 9	 0.0	 0.0	 1	 -30.0	 30.0;
	6030	 4147	 1.008368	 3.168595	 0.0	 10	 10	 10	 0.0	 0.0	 1	 -30.0	 30.0;
	917	 4147	 0.519401	 2.533471	 0.0	 13	 13	 13	 0.0	 0.0	 1	 -30.0	 30.0;
	4995	 4147	 0.611653	 2.252893	 0.0	 14	 14	 14	 0.0	 0.0	 1	 -30.0	 30.0;
	12407	 4147	 1.180868	 3.490496	 0.0	 9	 9	 9	 0.0	 0.0	 1	 -30.0	 30.0;
	12043	 4147	 38.08471	 41.4876	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	9823	 4147	 19.69132	 22.41116	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	6896	 4147	 21.63017	 31.43802	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	10979	 4147	 20.91529	 32.94215	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	1535	 4147	 1.695537	 6.03657	 0.0	 6	 6	 6	 0.0	 0.0	 1	 -30.0	 30.0;
	5183	 4147	 1.302851	 4.551033	 0.0	 7	 7	 7	 0.0	 0.0	 1	 -30.0	 30.0;
	7916	 4147	 5.718182	 16.36116	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	3743	 4147	 6.683678	 15.9062	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	4147	 2256	 0.10661	 0.987583	 0.0	 32	 32	 32	 0.0	 0.0	 1	 -30.0	 30.0;
	7691	 4147	 0.079729	 0.948512	 0.0	 34	 34	 34	 0.0	 0.0	 1	 -30.0	 30.0;
	6065	 4147	 0.06449	 0.807169	 0.0	 40	 40	 40	 0.0	 0.0	 1	 -30.0	 30.0;
	6065	 4147	 0.002151	 0.02656	 0.0	 1186	 1186	 1186	 0.0	 0.0	 1	 -30.0	 30.0;
	9492	 7042	 0.00094	 0.01246	 0.0	 2528	 2528	 2528	 0.0	 0.0	 1	 -30.0	 30.0;
	7042	 7108	 0.00109	 0.00971	 0.0	 3233	 3233	 3233	 0.0	 0.0	 1	 -30.0	 30.0;
	9492	 4338	 0.00099	 0.01086	 0.0	 2897	 2897	 2897	 0.0	 0.0	 1	 -30.0	 30.0;
	9492	 4338	 0.00092	 0.0127	 0.0	 2481	 2481	 2481	 0.0	 0.0	 1	 -30.0	 30.0;
	4338	 7108	 0.00097	 0.01101	 0.0	 2858	 2858	 2858	 0.0	 0.0	 1	 -30.0	 30.0;
	644	 2726	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	644	 2726	 0.001	 0.236901	 0.0	 134	 134	 134	 0.0	 0.0	 1	 -30.0	 30.0;
	5344	 644	 1.033202	 3.18595	 0.0	 10	 10	 10	 0.0	 0.0	 1	 -30.0	 30.0;
	2264	 644	 0.07336	 0.952996	 0.0	 34	 34	 34	 0.0	 0.0	 1	 -30.0	 30.0;
	4342	 644	 4.823554	 9.755785	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	1684	 644	 4.344835	 10.74711	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	11263	 644	 0.000789	 0.01039	 0.0	 3032	 3032	 3032	 0.0	 0.0	 1	 -30.0	 30.0;
	5344	 2726	 0.877293	 3.230992	 0.0	 10	 10	 10	 0.0	 0.0	 1	 -30.0	 30.0;
	2264	 2726	 0.08095	 0.839008	 0.0	 38	 38	 38	 0.0	 0.0	 1	 -30.0	 30.0;
	4342	 2726	 4.635744	 9.702067	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	1684	 2726	 4.775207	 9.229752	 0.0	 4	 4	 4	 0.0	 0.0	 1	 -30.0	 30.0;
	9595	 3498	 0.00017	 0.0018	 0.0	 17471	 17471	 17471	 0.0	 0.0	 1	 -30.0	 30.0;
	12309	 6250	 0.00017	 0.00184	 0.0	 17095	 17095	 17095	 0.0	 0.0	 1	 -30.0	 30.0;
	2281	 4941	 6e-05	 0.00055	 0.0	 57093	 57093	 57093	 0.0	 0.0	 1	 -30.0	 30.0;
	8094	 10496	 5e-05	 0.00051	 0.0	 61641	 61641	 61641	 0.0	 0.0	 1	 -30.0	 30.0;
	10367	 9178	 4.9e-05	 0.000194	 0.0	 157864	 157864	 157864	 0.0	 0.0	 1	 -30.0	 30.0;
	10367	 9178	 0.001	 0.502417	 0.0	 63	 63	 63	 0.0	 0.0	 1	 -30.0	 30.0;
	10367	 722	 0.11597	 1.150069	 0.0	 28	 28	 28	 0.0	 0.0	 1	 -30.0	 30.0;
	10367	 6355	 0.00027	 0.00201	 0.0	 15576	 15576	 15576	 0.0	 0.0	 1	 -30.0	 30.0;
	10367	 478	 12.69044	 26.69945	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	8529	 10367	 5.039543	 12.54224	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	5951	 10367	 4.861565	 13.04917	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	9178	 722	 0.131427	 1.127078	 0.0	 28	 28	 28	 0.0	 0.0	 1	 -30.0	 30.0;
	9178	 3605	 0.00034	 0.00324	 0.0	 9696	 9696	 9696	 0.0	 0.0	 1	 -30.0	 30.0;
	9178	 478	 14.34765	 23.73407	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	8529	 9178	 4.937535	 12.78878	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	5951	 9178	 4.758934	 13.29571	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	5344	 418	 0.00189	 0.01011	 0.0	 3072	 3072	 3072	 0.0	 0.0	 1	 -30.0	 30.0;
	5344	 10864	 0.00193	 0.009901	 0.0	 3132	 3132	 3132	 0.0	 0.0	 1	 -30.0	 30.0;
	475	 10864	 0.00095	 0.004461	 0.0	 6926	 6926	 6926	 0.0	 0.0	 1	 -30.0	 30.0;
	475	 8634	 0.000841	 0.00505	 0.0	 6170	 6170	 6170	 0.0	 0.0	 1	 -30.0	 30.0;
	9415	 5344	 0.00074	 0.00837	 0.0	 4516	 4516	 4516	 0.0	 0.0	 1	 -30.0	 30.0;
	5344	 2264	 3.807645	 6.613017	 0.0	 5	 5	 5	 0.0	 0.0	 1	 -30.0	 30.0;
	4342	 5344	 0.512211	 2.208058	 0.0	 14	 14	 14	 0.0	 0.0	 1	 -30.0	 30.0;
	1684	 5344	 0.432727	 2.575207	 0.0	 13	 13	 13	 0.0	 0.0	 1	 -30.0	 30.0;
	5344	 475	 0.00551	 0.13675	 0.0	 231	 231	 231	 0.0	 0.0	 1	 -30.0	 30.0;
	12058	 9673	 0.00018	 0.00165	 0.0	 19031	 19031	 19031	 0.0	 0.0	 1	 -30.0	 30.0;
	12058	 2275	 0.00017	 0.00168	 0.0	 18707	 18707	 18707	 0.0	 0.0	 1	 -30.0	 30.0;
	4398	 7767	 0.00022	 0.00207	 0.0	 15175	 15175	 15175	 0.0	 0.0	 1	 -30.0	 30.0;
	8285	 8566	 6e-05	 0.000531	 0.0	 59111	 59111	 59111	 0.0	 0.0	 1	 -30.0	 30.0;
	6581	 6464	 6e-05	 0.000521	 0.0	 60231	 60231	 60231	 0.0	 0.0	 1	 -30.0	 30.0;
	6581	 8608	 2.538636	 7.69814	 0.0	 4	 4	 4	 0.0	 0.0	 1	 -30.0	 30.0;
	6581	 4055	 2.881818	 7.882025	 0.0	 4	 4	 4	 0.0	 0.0	 1	 -30.0	 30.0;
	6581	 8156	 0.648822	 3.687603	 0.0	 9	 9	 9	 0.0	 0.0	 1	 -30.0	 30.0;
	6581	 6030	 0.662004	 3.615496	 0.0	 9	 9	 9	 0.0	 0.0	 1	 -30.0	 30.0;
	6581	 917	 0.347417	 1.771488	 0.0	 18	 18	 18	 0.0	 0.0	 1	 -30.0	 30.0;
	6581	 4995	 0.302727	 2.122521	 0.0	 15	 15	 15	 0.0	 0.0	 1	 -30.0	 30.0;
	6581	 12407	 0.13874	 1.055682	 0.0	 30	 30	 30	 0.0	 0.0	 1	 -30.0	 30.0;
	12043	 6581	 32.21488	 46.94215	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	9823	 6581	 16.64897	 25.36157	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	6581	 2256	 31.40496	 45.72727	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	6581	 7691	 1.96531	 5.971488	 0.0	 6	 6	 6	 0.0	 0.0	 1	 -30.0	 30.0;
	6581	 6065	 1.628843	 5.349793	 0.0	 6	 6	 6	 0.0	 0.0	 1	 -30.0	 30.0;
	8566	 12407	 0.003831	 0.04362	 0.0	 722	 722	 722	 0.0	 0.0	 1	 -30.0	 30.0;
	6464	 12407	 0.003901	 0.042711	 0.0	 737	 737	 737	 0.0	 0.0	 1	 -30.0	 30.0;
	11812	 12474	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	11812	 12474	 0.03143	 0.812673	 0.0	 39	 39	 39	 0.0	 0.0	 1	 -30.0	 30.0;
	10786	 11812	 6e-05	 0.00062	 0.0	 50711	 50711	 50711	 0.0	 0.0	 1	 -30.0	 30.0;
	91	 11812	 5.540582	 14.44598	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	11732	 11812	 0.171863	 2.799169	 0.0	 12	 12	 12	 0.0	 0.0	 1	 -30.0	 30.0;
	10349	 11812	 31.73753	 62.63988	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	12274	 11812	 0.0037	 0.670762	 0.0	 48	 48	 48	 0.0	 0.0	 1	 -30.0	 30.0;
	3895	 11812	 4.69723	 16.67659	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	1789	 11812	 13.8608	 37.26524	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	8094	 12474	 6e-05	 0.00063	 0.0	 49913	 49913	 49913	 0.0	 0.0	 1	 -30.0	 30.0;
	91	 12474	 0.842036	 5.10651	 0.0	 7	 7	 7	 0.0	 0.0	 1	 -30.0	 30.0;
	11732	 12474	 0.001	 0.767382	 0.0	 42	 42	 42	 0.0	 0.0	 1	 -30.0	 30.0;
	12274	 12474	 0.0122	 0.920499	 0.0	 35	 35	 35	 0.0	 0.0	 1	 -30.0	 30.0;
	3895	 12474	 0.831094	 4.707341	 0.0	 7	 7	 7	 0.0	 0.0	 1	 -30.0	 30.0;
	1789	 12474	 13.1392	 39.18767	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	11616	 10786	 0.00022	 0.0023	 0.0	 13672	 13672	 13672	 0.0	 0.0	 1	 -30.0	 30.0;
	12129	 2281	 0.00022	 0.00213	 0.0	 14752	 14752	 14752	 0.0	 0.0	 1	 -30.0	 30.0;
	12269	 6414	 0.00034	 0.003	 0.0	 10463	 10463	 10463	 0.0	 0.0	 1	 -30.0	 30.0;
	478	 12269	 0.00022	 0.00172	 0.0	 18217	 18217	 18217	 0.0	 0.0	 1	 -30.0	 30.0;
	7393	 6414	 0.00034	 0.00294	 0.0	 10673	 10673	 10673	 0.0	 0.0	 1	 -30.0	 30.0;
	3019	 7393	 0.00022	 0.00168	 0.0	 18643	 18643	 18643	 0.0	 0.0	 1	 -30.0	 30.0;
	12406	 6414	 25.47853	 44.51731	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	8314	 6414	 24.93629	 45.35734	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	9085	 6414	 0.138622	 1.351247	 0.0	 28	 28	 28	 0.0	 0.0	 1	 -30.0	 30.0;
	4342	 2264	 1.420021	 4.04938	 0.0	 8	 8	 8	 0.0	 0.0	 1	 -30.0	 30.0;
	1684	 2264	 1.226446	 4.635537	 0.0	 7	 7	 7	 0.0	 0.0	 1	 -30.0	 30.0;
	2264	 8468	 0.000771	 0.0083	 0.0	 3790	 3790	 3790	 0.0	 0.0	 1	 -30.0	 30.0;
	3986	 12363	 0.00449	 0.023349	 0.0	 1329	 1329	 1329	 0.0	 0.0	 1	 -30.0	 30.0;
	935	 10379	 0.001	 0.313037	 0.0	 101	 101	 101	 0.0	 0.0	 1	 -30.0	 30.0;
	935	 12951	 0.025331	 0.364938	 0.0	 87	 87	 87	 0.0	 0.0	 1	 -30.0	 30.0;
	935	 12951	 0.004219	 0.018211	 0.0	 1690	 1690	 1690	 0.0	 0.0	 1	 -30.0	 30.0;
	10379	 12951	 0.02581	 0.357169	 0.0	 89	 89	 89	 0.0	 0.0	 1	 -30.0	 30.0;
	10379	 12951	 0.00413	 0.01686	 0.0	 1820	 1820	 1820	 0.0	 0.0	 1	 -30.0	 30.0;
	722	 3393	 0.00018	 0.00157	 0.0	 19989	 19989	 19989	 0.0	 0.0	 1	 -30.0	 30.0;
	478	 722	 4.622922	 11.33102	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	8529	 722	 1.337465	 6.217936	 0.0	 5	 5	 5	 0.0	 0.0	 1	 -30.0	 30.0;
	5951	 722	 1.319252	 5.765305	 0.0	 6	 6	 6	 0.0	 0.0	 1	 -30.0	 30.0;
	11650	 5812	 0.00017	 0.0016	 0.0	 19632	 19632	 19632	 0.0	 0.0	 1	 -30.0	 30.0;
	11650	 6355	 0.00017	 0.00163	 0.0	 19275	 19275	 19275	 0.0	 0.0	 1	 -30.0	 30.0;
	11650	 5809	 2e-05	 0.00022	 0.0	 142990	 142990	 142990	 0.0	 0.0	 1	 -30.0	 30.0;
	10991	 9023	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	10991	 9023	 0.01018	 0.46657	 0.0	 68	 68	 68	 0.0	 0.0	 1	 -30.0	 30.0;
	8960	 10991	 0.00887	 0.046021	 0.0	 674	 674	 674	 0.0	 0.0	 1	 -30.0	 30.0;
	6196	 10991	 0.007479	 0.02551	 0.0	 1189	 1189	 1189	 0.0	 0.0	 1	 -30.0	 30.0;
	2313	 9023	 0.00762	 0.024979	 0.0	 1210	 1210	 1210	 0.0	 0.0	 1	 -30.0	 30.0;
	10899	 3393	 0.00034	 0.00277	 0.0	 11319	 11319	 11319	 0.0	 0.0	 1	 -30.0	 30.0;
	2749	 5812	 0.00035	 0.00271	 0.0	 11560	 11560	 11560	 0.0	 0.0	 1	 -30.0	 30.0;
	6598	 3605	 0.00146	 0.01134	 0.0	 2763	 2763	 2763	 0.0	 0.0	 1	 -30.0	 30.0;
	4342	 1684	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	4342	 1684	 0.001	 0.250041	 0.0	 127	 127	 127	 0.0	 0.0	 1	 -30.0	 30.0;
	4342	 12614	 0.00031	 0.00232	 0.0	 13496	 13496	 13496	 0.0	 0.0	 1	 -30.0	 30.0;
	4860	 8960	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	4860	 8960	 0.001	 0.319463	 0.0	 99	 99	 99	 0.0	 0.0	 1	 -30.0	 30.0;
	4860	 12951	 0.002479	 0.011479	 0.0	 2690	 2690	 2690	 0.0	 0.0	 1	 -30.0	 30.0;
	4860	 1779	 1.778616	 5.164256	 0.0	 6	 6	 6	 0.0	 0.0	 1	 -30.0	 30.0;
	3119	 4860	 0.00644	 0.026229	 0.0	 1170	 1170	 1170	 0.0	 0.0	 1	 -30.0	 30.0;
	6012	 4860	 0.342769	 1.509876	 0.0	 21	 21	 21	 0.0	 0.0	 1	 -30.0	 30.0;
	8960	 12951	 0.002521	 0.01124	 0.0	 2743	 2743	 2743	 0.0	 0.0	 1	 -30.0	 30.0;
	8960	 1779	 1.29219	 4.678099	 0.0	 7	 7	 7	 0.0	 0.0	 1	 -30.0	 30.0;
	6012	 8960	 0.236529	 1.420661	 0.0	 22	 22	 22	 0.0	 0.0	 1	 -30.0	 30.0;
	11448	 2359	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	11448	 2359	 0.05505	 0.67124	 0.0	 47	 47	 47	 0.0	 0.0	 1	 -30.0	 30.0;
	366	 11448	 4.467975	 11.21446	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	11448	 8156	 34.72521	 52.45248	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	11448	 6030	 36.34711	 50.63223	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	11448	 917	 22.76033	 33.1281	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	11448	 4995	 21.48554	 36.70661	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	11448	 12407	 39.50826	 49.23967	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	6896	 11448	 17.04917	 42.27893	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	10979	 11448	 16.04855	 40.82025	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	11448	 1535	 0.053771	 1.208946	 0.0	 27	 27	 27	 0.0	 0.0	 1	 -30.0	 30.0;
	11448	 1535	 0.003281	 0.016341	 0.0	 1896	 1896	 1896	 0.0	 0.0	 1	 -30.0	 30.0;
	5183	 11448	 0.825227	 5.014463	 0.0	 7	 7	 7	 0.0	 0.0	 1	 -30.0	 30.0;
	11448	 7014	 4.278926	 11.33285	 0.0	 4	 4	 4	 0.0	 0.0	 1	 -30.0	 30.0;
	11448	 12720	 3.46157	 11.98905	 0.0	 4	 4	 4	 0.0	 0.0	 1	 -30.0	 30.0;
	7916	 11448	 4.532025	 17.77417	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	7916	 11448	 0.009169	 0.03831	 0.0	 964	 964	 964	 0.0	 0.0	 1	 -30.0	 30.0;
	3743	 11448	 4.582645	 17.99917	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	11448	 9401	 4.507231	 15.28285	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	11448	 2256	 0.001	 1.211157	 0.0	 27	 27	 27	 0.0	 0.0	 1	 -30.0	 30.0;
	11448	 7691	 7.098967	 16.7219	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	11448	 6065	 6.249587	 14.57107	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	366	 2359	 3.945041	 12.27665	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	2359	 8156	 34.19215	 51.58471	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	2359	 6030	 31.52686	 50.73347	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	2359	 917	 18.00289	 35.73554	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	2359	 4995	 21.65083	 34.30165	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	2359	 12407	 35.85331	 52.29959	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	6896	 2359	 18.05847	 51.41322	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	10979	 2359	 21.28512	 43.97521	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	2359	 1535	 0.036771	 0.970744	 0.0	 33	 33	 33	 0.0	 0.0	 1	 -30.0	 30.0;
	5183	 2359	 0.78843	 6.091736	 0.0	 6	 6	 6	 0.0	 0.0	 1	 -30.0	 30.0;
	2359	 7014	 3.228512	 12.74483	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	2359	 12720	 3.551653	 11.03347	 0.0	 4	 4	 4	 0.0	 0.0	 1	 -30.0	 30.0;
	7916	 2359	 5.941736	 18.63595	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	3743	 2359	 4.915083	 20.96901	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	3743	 2359	 0.01039	 0.037539	 0.0	 975	 975	 975	 0.0	 0.0	 1	 -30.0	 30.0;
	2359	 9401	 4.096281	 15.0905	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	2359	 2256	 0.001	 1.352211	 0.0	 24	 24	 24	 0.0	 0.0	 1	 -30.0	 30.0;
	2359	 7691	 6.635537	 16.54979	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	2359	 6065	 5.82438	 14.40847	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	5951	 3019	 0.00046	 0.00466	 0.0	 6746	 6746	 6746	 0.0	 0.0	 1	 -30.0	 30.0;
	8529	 478	 0.03625	 0.46376	 0.0	 68	 68	 68	 0.0	 0.0	 1	 -30.0	 30.0;
	8529	 478	 0.00045	 0.00475	 0.0	 6621	 6621	 6621	 0.0	 0.0	 1	 -30.0	 30.0;
	5951	 478	 0.04062	 0.4091	 0.0	 77	 77	 77	 0.0	 0.0	 1	 -30.0	 30.0;
	11448	 2256	 0.006271	 0.0373	 0.0	 836	 836	 836	 0.0	 0.0	 1	 -30.0	 30.0;
	945	 8045	 0.000331	 0.00331	 0.0	 9496	 9496	 9496	 0.0	 0.0	 1	 -30.0	 30.0;
	945	 6386	 0.000341	 0.00324	 0.0	 9696	 9696	 9696	 0.0	 0.0	 1	 -30.0	 30.0;
	945	 2113	 0.00013	 0.00132	 0.0	 23815	 23815	 23815	 0.0	 0.0	 1	 -30.0	 30.0;
	8608	 4055	 0.001	 0.1802	 0.0	 176	 176	 176	 0.0	 0.0	 1	 -30.0	 30.0;
	8608	 8156	 0.04812	 0.726715	 0.0	 44	 44	 44	 0.0	 0.0	 1	 -30.0	 30.0;
	8608	 8156	 0.005169	 0.036401	 0.0	 860	 860	 860	 0.0	 0.0	 1	 -30.0	 30.0;
	8608	 6030	 0.04006	 0.78624	 0.0	 41	 41	 41	 0.0	 0.0	 1	 -30.0	 30.0;
	917	 8608	 0.559318	 2.376033	 0.0	 13	 13	 13	 0.0	 0.0	 1	 -30.0	 30.0;
	4995	 8608	 0.574607	 2.433264	 0.0	 13	 13	 13	 0.0	 0.0	 1	 -30.0	 30.0;
	8608	 12407	 0.449463	 2.310744	 0.0	 14	 14	 14	 0.0	 0.0	 1	 -30.0	 30.0;
	12043	 8608	 0.18062	 1.392789	 0.0	 23	 23	 23	 0.0	 0.0	 1	 -30.0	 30.0;
	9823	 8608	 0.092211	 0.750041	 0.0	 42	 42	 42	 0.0	 0.0	 1	 -30.0	 30.0;
	6896	 8608	 6.405372	 12.55372	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	10979	 8608	 5.734504	 14.28161	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	5183	 8608	 15.87066	 21.82231	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	7916	 8608	 45.78719	 60.88223	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	3743	 8608	 52.13017	 54.55165	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	4717	 8608	 0.615	 2.63781	 0.0	 12	 12	 12	 0.0	 0.0	 1	 -30.0	 30.0;
	8608	 2256	 16.26798	 23.5124	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	8608	 7691	 0.818636	 3.652686	 0.0	 9	 9	 9	 0.0	 0.0	 1	 -30.0	 30.0;
	8608	 6065	 0.670434	 2.968182	 0.0	 11	 11	 11	 0.0	 0.0	 1	 -30.0	 30.0;
	4055	 8156	 0.041711	 0.912376	 0.0	 35	 35	 35	 0.0	 0.0	 1	 -30.0	 30.0;
	4055	 6030	 0.04611	 0.822479	 0.0	 39	 39	 39	 0.0	 0.0	 1	 -30.0	 30.0;
	4055	 6030	 0.005271	 0.03561	 0.0	 878	 878	 878	 0.0	 0.0	 1	 -30.0	 30.0;
	917	 4055	 0.605434	 2.534091	 0.0	 13	 13	 13	 0.0	 0.0	 1	 -30.0	 30.0;
	4995	 4055	 0.542851	 2.99876	 0.0	 11	 11	 11	 0.0	 0.0	 1	 -30.0	 30.0;
	4055	 12407	 0.520909	 2.569628	 0.0	 13	 13	 13	 0.0	 0.0	 1	 -30.0	 30.0;
	12043	 4055	 0.177789	 1.458264	 0.0	 22	 22	 22	 0.0	 0.0	 1	 -30.0	 30.0;
	9823	 4055	 0.09881	 0.801281	 0.0	 40	 40	 40	 0.0	 0.0	 1	 -30.0	 30.0;
	6896	 4055	 6.124793	 15.47397	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	10979	 4055	 5.91157	 16.17149	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	5183	 4055	 14.54876	 25.34091	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	7916	 4055	 54.67355	 60.11777	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	4717	 4055	 0.802355	 2.58657	 0.0	 12	 12	 12	 0.0	 0.0	 1	 -30.0	 30.0;
	4055	 2256	 19.94897	 25.18388	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	4055	 7691	 1.027479	 3.393802	 0.0	 9	 9	 9	 0.0	 0.0	 1	 -30.0	 30.0;
	4055	 6065	 0.843471	 3.042975	 0.0	 11	 11	 11	 0.0	 0.0	 1	 -30.0	 30.0;
	13017	 10967	 0.00078	 0.00782	 0.0	 4020	 4020	 4020	 0.0	 0.0	 1	 -30.0	 30.0;
	13017	 6550	 7.575485	 11.77562	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	13017	 964	 1.23705	 3.353947	 0.0	 9	 9	 9	 0.0	 0.0	 1	 -30.0	 30.0;
	13017	 13282	 3.429501	 6.941136	 0.0	 5	 5	 5	 0.0	 0.0	 1	 -30.0	 30.0;
	13017	 2182	 0.00076	 0.00797	 0.0	 3946	 3946	 3946	 0.0	 0.0	 1	 -30.0	 30.0;
	12151	 2182	 0.00025	 0.00233	 0.0	 13480	 13480	 13480	 0.0	 0.0	 1	 -30.0	 30.0;
	3291	 10967	 0.00179	 0.01397	 0.0	 2243	 2243	 2243	 0.0	 0.0	 1	 -30.0	 30.0;
	11732	 91	 0.173643	 1.472438	 0.0	 22	 22	 22	 0.0	 0.0	 1	 -30.0	 30.0;
	91	 12274	 5.182133	 18.94529	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	91	 3895	 0.188989	 1.114889	 0.0	 28	 28	 28	 0.0	 0.0	 1	 -30.0	 30.0;
	1789	 91	 1.860596	 8.193906	 0.0	 4	 4	 4	 0.0	 0.0	 1	 -30.0	 30.0;
	366	 469	 0.00424	 0.029211	 0.0	 1071	 1071	 1071	 0.0	 0.0	 1	 -30.0	 30.0;
	366	 1535	 6.176859	 17.47149	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	5183	 366	 10.52665	 27.33264	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	366	 7014	 0.202	 1.377087	 0.0	 28	 28	 28	 0.0	 0.0	 1	 -30.0	 30.0;
	366	 12720	 0.19876	 1.343988	 0.0	 28	 28	 28	 0.0	 0.0	 1	 -30.0	 30.0;
	366	 12720	 0.00545	 0.042341	 0.0	 889	 889	 889	 0.0	 0.0	 1	 -30.0	 30.0;
	7916	 366	 7.300207	 16.26798	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	3743	 366	 6.816736	 17.84773	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	366	 9401	 3.997727	 8.729958	 0.0	 4	 4	 4	 0.0	 0.0	 1	 -30.0	 30.0;
	366	 2256	 15.84711	 34.44008	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	366	 1566	 30.61777	 53.27893	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	366	 5754	 36.28512	 62.88017	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	91	 3895	 0.00082	 0.01007	 0.0	 3127	 3127	 3127	 0.0	 0.0	 1	 -30.0	 30.0;
	10917	 11296	 0.0005	 0.004169	 0.0	 7523	 7523	 7523	 0.0	 0.0	 1	 -30.0	 30.0;
	7916	 10917	 0.00525	 0.033151	 0.0	 1131	 1131	 1131	 0.0	 0.0	 1	 -30.0	 30.0;
	11296	 5666	 0.001969	 0.01718	 0.0	 1827	 1827	 1827	 0.0	 0.0	 1	 -30.0	 30.0;
	5666	 6288	 0.001289	 0.009229	 0.0	 3390	 3390	 3390	 0.0	 0.0	 1	 -30.0	 30.0;
	6288	 5792	 0.00043	 0.00349	 0.0	 8983	 8983	 8983	 0.0	 0.0	 1	 -30.0	 30.0;
	5792	 4871	 0.000979	 0.008901	 0.0	 3528	 3528	 3528	 0.0	 0.0	 1	 -30.0	 30.0;
	4871	 469	 0.000219	 0.00155	 0.0	 20179	 20179	 20179	 0.0	 0.0	 1	 -30.0	 30.0;
	10288	 10446	 0.00025	 0.00319	 0.0	 9872	 9872	 9872	 0.0	 0.0	 1	 -30.0	 30.0;
	10288	 10446	 0.00024	 0.00295	 0.0	 10673	 10673	 10673	 0.0	 0.0	 1	 -30.0	 30.0;
	6550	 1061	 0.00022	 0.00171	 0.0	 18322	 18322	 18322	 0.0	 0.0	 1	 -30.0	 30.0;
	10047	 1061	 0.0005	 0.00382	 0.0	 8200	 8200	 8200	 0.0	 0.0	 1	 -30.0	 30.0;
	1747	 3657	 0.0002	 0.00192	 0.0	 16364	 16364	 16364	 0.0	 0.0	 1	 -30.0	 30.0;
	10047	 3657	 0.0005	 0.00383	 0.0	 8178	 8178	 8178	 0.0	 0.0	 1	 -30.0	 30.0;
	8156	 6030	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	8156	 6030	 0.001	 0.268678	 0.0	 118	 118	 118	 0.0	 0.0	 1	 -30.0	 30.0;
	917	 8156	 0.042159	 0.956198	 0.0	 34	 34	 34	 0.0	 0.0	 1	 -30.0	 30.0;
	917	 8156	 0.002341	 0.022341	 0.0	 1407	 1407	 1407	 0.0	 0.0	 1	 -30.0	 30.0;
	4995	 8156	 0.04555	 0.93969	 0.0	 34	 34	 34	 0.0	 0.0	 1	 -30.0	 30.0;
	8156	 12407	 0.077909	 1.08686	 0.0	 29	 29	 29	 0.0	 0.0	 1	 -30.0	 30.0;
	6495	 8156	 0.0003	 0.003289	 0.0	 11488	 11488	 11488	 0.0	 0.0	 1	 -30.0	 30.0;
	12043	 8156	 1.527831	 6.098554	 0.0	 6	 6	 6	 0.0	 0.0	 1	 -30.0	 30.0;
	9823	 8156	 0.958926	 2.68595	 0.0	 12	 12	 12	 0.0	 0.0	 1	 -30.0	 30.0;
	6896	 8156	 28.84298	 48.1157	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	10979	 8156	 33.55372	 46.46901	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	1535	 8156	 47.90702	 63.74587	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	5183	 8156	 28.68802	 30.77066	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	4717	 8156	 4.526653	 11.10372	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	8156	 2256	 6.754959	 11.13905	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	8156	 7691	 0.105229	 1.236012	 0.0	 26	 26	 26	 0.0	 0.0	 1	 -30.0	 30.0;
	8156	 6065	 0.085781	 1.020186	 0.0	 31	 31	 31	 0.0	 0.0	 1	 -30.0	 30.0;
	917	 6030	 0.044289	 0.919483	 0.0	 35	 35	 35	 0.0	 0.0	 1	 -30.0	 30.0;
	4995	 6030	 0.047781	 0.901963	 0.0	 35	 35	 35	 0.0	 0.0	 1	 -30.0	 30.0;
	6030	 12407	 0.076341	 1.006446	 0.0	 32	 32	 32	 0.0	 0.0	 1	 -30.0	 30.0;
	9067	 6030	 0.0003	 0.00336	 0.0	 11247	 11247	 11247	 0.0	 0.0	 1	 -30.0	 30.0;
	12043	 6030	 1.621322	 5.733678	 0.0	 6	 6	 6	 0.0	 0.0	 1	 -30.0	 30.0;
	9823	 6030	 0.903202	 2.852273	 0.0	 11	 11	 11	 0.0	 0.0	 1	 -30.0	 30.0;
	6896	 6030	 30.65289	 49.86157	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	10979	 6030	 32.78719	 47.26653	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	1535	 6030	 44.17355	 62.70041	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	5183	 6030	 25.07438	 35.58471	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	4717	 6030	 5.060744	 9.753098	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	6030	 2256	 6.015083	 12.60103	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	6030	 7691	 0.099409	 1.193017	 0.0	 27	 27	 27	 0.0	 0.0	 1	 -30.0	 30.0;
	6030	 7691	 0.002021	 0.01812	 0.0	 1733	 1733	 1733	 0.0	 0.0	 1	 -30.0	 30.0;
	6030	 6065	 0.09157	 0.961405	 0.0	 33	 33	 33	 0.0	 0.0	 1	 -30.0	 30.0;
	6825	 8391	 0.00032	 0.00387	 0.0	 8135	 8135	 8135	 0.0	 0.0	 1	 -30.0	 30.0;
	6825	 5257	 0.00038	 0.00378	 0.0	 8315	 8315	 8315	 0.0	 0.0	 1	 -30.0	 30.0;
	5250	 9863	 0.00032	 0.00394	 0.0	 7991	 7991	 7991	 0.0	 0.0	 1	 -30.0	 30.0;
	5250	 887	 0.00038	 0.0037	 0.0	 8493	 8493	 8493	 0.0	 0.0	 1	 -30.0	 30.0;
	6825	 10957	 6.036911	 10.78324	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	9492	 10446	 0.0008	 0.00945	 0.0	 3331	 3331	 3331	 0.0	 0.0	 1	 -30.0	 30.0;
	10446	 909	 0.00079	 0.00828	 0.0	 3798	 3798	 3798	 0.0	 0.0	 1	 -30.0	 30.0;
	9492	 10446	 0.00078	 0.00964	 0.0	 3267	 3267	 3267	 0.0	 0.0	 1	 -30.0	 30.0;
	10446	 909	 0.00081	 0.00811	 0.0	 3876	 3876	 3876	 0.0	 0.0	 1	 -30.0	 30.0;
	917	 4995	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	917	 4995	 0.001	 0.26281	 0.0	 121	 121	 121	 0.0	 0.0	 1	 -30.0	 30.0;
	917	 12407	 0.001	 0.461798	 0.0	 69	 69	 69	 0.0	 0.0	 1	 -30.0	 30.0;
	917	 12407	 0.00164	 0.020729	 0.0	 1520	 1520	 1520	 0.0	 0.0	 1	 -30.0	 30.0;
	12043	 917	 7.774793	 17.76901	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	9823	 917	 3.756405	 9.209917	 0.0	 4	 4	 4	 0.0	 0.0	 1	 -30.0	 30.0;
	917	 1535	 27.82645	 45.00826	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	5183	 917	 20.96901	 31.09711	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	4717	 917	 18.12293	 35.08471	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	917	 2256	 3.360124	 8.657025	 0.0	 4	 4	 4	 0.0	 0.0	 1	 -30.0	 30.0;
	917	 7691	 0.14569	 1.294938	 0.0	 25	 25	 25	 0.0	 0.0	 1	 -30.0	 30.0;
	917	 6065	 0.125919	 1.049607	 0.0	 30	 30	 30	 0.0	 0.0	 1	 -30.0	 30.0;
	4995	 12407	 0.001	 0.471508	 0.0	 67	 67	 67	 0.0	 0.0	 1	 -30.0	 30.0;
	4995	 12407	 0.001599	 0.02112	 0.0	 1492	 1492	 1492	 0.0	 0.0	 1	 -30.0	 30.0;
	12043	 4995	 8.624174	 16.76653	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	9823	 4995	 4.365909	 9.241321	 0.0	 4	 4	 4	 0.0	 0.0	 1	 -30.0	 30.0;
	4995	 1535	 29.57231	 44.15909	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	5183	 4995	 22.67562	 29.81818	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	4717	 4995	 22.21281	 29.92975	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	4995	 2256	 3.288017	 9.179959	 0.0	 4	 4	 4	 0.0	 0.0	 1	 -30.0	 30.0;
	4995	 7691	 0.15644	 1.276653	 0.0	 25	 25	 25	 0.0	 0.0	 1	 -30.0	 30.0;
	4995	 6065	 0.124669	 1.119298	 0.0	 29	 29	 29	 0.0	 0.0	 1	 -30.0	 30.0;
	12043	 12407	 6.748554	 16.31901	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	9823	 12407	 3.853099	 7.976446	 0.0	 4	 4	 4	 0.0	 0.0	 1	 -30.0	 30.0;
	1535	 12407	 53.92562	 59.04132	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	5183	 12407	 37.32851	 39.04752	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	4717	 12407	 16.76198	 30.60331	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	12407	 2256	 6.070868	 12.11942	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	7691	 12407	 0.29624	 1.60312	 0.0	 20	 20	 20	 0.0	 0.0	 1	 -30.0	 30.0;
	6065	 12407	 0.293884	 1.293946	 0.0	 24	 24	 24	 0.0	 0.0	 1	 -30.0	 30.0;
	11732	 12274	 0.15633	 3.578947	 0.0	 9	 9	 9	 0.0	 0.0	 1	 -30.0	 30.0;
	11732	 3895	 0.242957	 1.518213	 0.0	 21	 21	 21	 0.0	 0.0	 1	 -30.0	 30.0;
	11732	 1789	 8.069251	 24.53047	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	11732	 9866	 0.00029	 0.00357	 0.0	 8819	 8819	 8819	 0.0	 0.0	 1	 -30.0	 30.0;
	3498	 7835	 0.00012	 0.00131	 0.0	 24012	 24012	 24012	 0.0	 0.0	 1	 -30.0	 30.0;
	12043	 9823	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	12043	 9823	 0.001	 0.168909	 0.0	 188	 188	 188	 0.0	 0.0	 1	 -30.0	 30.0;
	12043	 6896	 0.837231	 3.56405	 0.0	 9	 9	 9	 0.0	 0.0	 1	 -30.0	 30.0;
	12043	 10979	 0.690682	 3.987397	 0.0	 8	 8	 8	 0.0	 0.0	 1	 -30.0	 30.0;
	12043	 10979	 0.00988	 0.05469	 0.0	 569	 569	 569	 0.0	 0.0	 1	 -30.0	 30.0;
	5183	 12043	 5.606818	 11.56529	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	7916	 12043	 15.6624	 27.83058	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	3743	 12043	 16.76116	 26.42355	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	12043	 4717	 0.039521	 0.57	 0.0	 56	 56	 56	 0.0	 0.0	 1	 -30.0	 30.0;
	12043	 2256	 25.64463	 32.3843	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	12043	 7691	 12.49401	 21.31612	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	12043	 6065	 10.90826	 18.38058	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	9823	 6896	 0.367355	 2.263636	 0.0	 14	 14	 14	 0.0	 0.0	 1	 -30.0	 30.0;
	9823	 10979	 0.394566	 2.152479	 0.0	 15	 15	 15	 0.0	 0.0	 1	 -30.0	 30.0;
	5183	 9823	 2.95062	 6.117354	 0.0	 5	 5	 5	 0.0	 0.0	 1	 -30.0	 30.0;
	7916	 9823	 8.41281	 14.42025	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	3743	 9823	 8.672314	 14.29339	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	9823	 4717	 0.0192	 0.321384	 0.0	 99	 99	 99	 0.0	 0.0	 1	 -30.0	 30.0;
	9823	 2256	 12.78037	 18.27831	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	9823	 7691	 6.830371	 10.80145	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	9823	 6065	 5.092149	 10.9593	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	7108	 10349	 0.00043	 0.00522	 0.0	 6031	 6031	 6031	 0.0	 0.0	 1	 -30.0	 30.0;
	1789	 10349	 0.00184	 0.01667	 0.0	 1884	 1884	 1884	 0.0	 0.0	 1	 -30.0	 30.0;
	1789	 10349	 0.248089	 2.761427	 0.0	 12	 12	 12	 0.0	 0.0	 1	 -30.0	 30.0;
	7245	 7922	 0.00037	 0.00464	 0.0	 6787	 6787	 6787	 0.0	 0.0	 1	 -30.0	 30.0;
	7245	 8379	 0.00059	 0.00694	 0.0	 4536	 4536	 4536	 0.0	 0.0	 1	 -30.0	 30.0;
	12406	 12866	 0.00027	 0.00348	 0.0	 9050	 9050	 9050	 0.0	 0.0	 1	 -30.0	 30.0;
	8314	 12866	 0.00027	 0.00354	 0.0	 8898	 8898	 8898	 0.0	 0.0	 1	 -30.0	 30.0;
	12406	 8314	 0.02114	 0.839889	 0.0	 38	 38	 38	 0.0	 0.0	 1	 -30.0	 30.0;
	9085	 12406	 30.32756	 43.46053	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	9085	 8314	 30.89958	 42.53601	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	6896	 10979	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	6896	 10979	 0.001	 0.238595	 0.0	 133	 133	 133	 0.0	 0.0	 1	 -30.0	 30.0;
	5183	 6896	 0.256632	 1.964752	 0.0	 16	 16	 16	 0.0	 0.0	 1	 -30.0	 30.0;
	7916	 6896	 0.63343	 3.574793	 0.0	 11	 11	 11	 0.0	 0.0	 1	 -30.0	 30.0;
	3743	 6896	 0.709752	 3.284711	 0.0	 12	 12	 12	 0.0	 0.0	 1	 -30.0	 30.0;
	3743	 6896	 0.01324	 0.090909	 0.0	 413	 413	 413	 0.0	 0.0	 1	 -30.0	 30.0;
	4717	 6896	 0.000591	 1.201426	 0.0	 27	 27	 27	 0.0	 0.0	 1	 -30.0	 30.0;
	6896	 2256	 1.821963	 7.541736	 0.0	 5	 5	 5	 0.0	 0.0	 1	 -30.0	 30.0;
	5183	 10979	 0.210826	 2.191942	 0.0	 15	 15	 15	 0.0	 0.0	 1	 -30.0	 30.0;
	7916	 10979	 0.746074	 3.056198	 0.0	 13	 13	 13	 0.0	 0.0	 1	 -30.0	 30.0;
	3743	 10979	 0.740041	 3.16219	 0.0	 12	 12	 12	 0.0	 0.0	 1	 -30.0	 30.0;
	4717	 10979	 0.000841	 1.29095	 0.0	 25	 25	 25	 0.0	 0.0	 1	 -30.0	 30.0;
	10979	 2256	 2.154545	 7.118182	 0.0	 5	 5	 5	 0.0	 0.0	 1	 -30.0	 30.0;
	7922	 2780	 8e-05	 0.00105	 0.0	 29997	 29997	 29997	 0.0	 0.0	 1	 -30.0	 30.0;
	12129	 12274	 0.00025	 0.00186	 0.0	 16832	 16832	 16832	 0.0	 0.0	 1	 -30.0	 30.0;
	1535	 8158	 9.1e-05	 0.000581	 0.0	 53713	 53713	 53713	 0.0	 0.0	 1	 -30.0	 30.0;
	11616	 12274	 0.00023	 0.00211	 0.0	 14883	 14883	 14883	 0.0	 0.0	 1	 -30.0	 30.0;
	6949	 11804	 8e-05	 0.00107	 0.0	 29439	 29439	 29439	 0.0	 0.0	 1	 -30.0	 30.0;
	6949	 12274	 2e-05	 0.0002	 0.0	 157153	 157153	 157153	 0.0	 0.0	 1	 -30.0	 30.0;
	3477	 2478	 0.00063	 0.00406	 0.0	 7689	 7689	 7689	 0.0	 0.0	 1	 -30.0	 30.0;
	3477	 1535	 9.1e-05	 0.00056	 0.0	 55676	 55676	 55676	 0.0	 0.0	 1	 -30.0	 30.0;
	13127	 4828	 0.00064	 0.003969	 0.0	 7858	 7858	 7858	 0.0	 0.0	 1	 -30.0	 30.0;
	1535	 13127	 9.1e-05	 0.00055	 0.0	 56662	 56662	 56662	 0.0	 0.0	 1	 -30.0	 30.0;
	12274	 2780	 2e-05	 0.0002	 0.0	 157153	 157153	 157153	 0.0	 0.0	 1	 -30.0	 30.0;
	11804	 7124	 0.00091	 0.01097	 0.0	 2870	 2870	 2870	 0.0	 0.0	 1	 -30.0	 30.0;
	2478	 3613	 0.00711	 0.045841	 0.0	 681	 681	 681	 0.0	 0.0	 1	 -30.0	 30.0;
	4828	 12870	 0.00724	 0.044849	 0.0	 696	 696	 696	 0.0	 0.0	 1	 -30.0	 30.0;
	3895	 12274	 5.952838	 17.29294	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	1789	 12274	 20.08726	 50.82479	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	5183	 1535	 4.890702	 15.41012	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	7014	 1535	 5.639256	 15.40868	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	12720	 1535	 4.76281	 15.7	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	7916	 1535	 21.2624	 53.66529	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	3743	 1535	 25.16942	 46.14463	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	1535	 9401	 5.023554	 17.83409	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	1535	 2256	 0.483492	 3.46095	 0.0	 10	 10	 10	 0.0	 0.0	 1	 -30.0	 30.0;
	166	 1535	 0.000211	 0.0012	 0.0	 25926	 25926	 25926	 0.0	 0.0	 1	 -30.0	 30.0;
	1535	 7691	 9.888017	 20.17066	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	1535	 6065	 9.581818	 15.8126	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	2123	 1522	 0.00015	 0.00151	 0.0	 20817	 20817	 20817	 0.0	 0.0	 1	 -30.0	 30.0;
	7124	 7022	 0.00044	 0.00443	 0.0	 7096	 7096	 7096	 0.0	 0.0	 1	 -30.0	 30.0;
	3613	 13629	 0.00301	 0.01868	 0.0	 1670	 1670	 1670	 0.0	 0.0	 1	 -30.0	 30.0;
	12870	 13629	 0.00268	 0.02118	 0.0	 1480	 1480	 1480	 0.0	 0.0	 1	 -30.0	 30.0;
	8379	 1522	 0.00044	 0.00433	 0.0	 7258	 7258	 7258	 0.0	 0.0	 1	 -30.0	 30.0;
	7022	 2123	 0.00015	 0.00148	 0.0	 21235	 21235	 21235	 0.0	 0.0	 1	 -30.0	 30.0;
	5183	 7014	 36.67975	 64.23967	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	5183	 12720	 34.68595	 57.82851	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	7916	 5183	 0.001	 0.997107	 0.0	 39	 39	 39	 0.0	 0.0	 1	 -30.0	 30.0;
	3743	 5183	 0.001	 0.990558	 0.0	 39	 39	 39	 0.0	 0.0	 1	 -30.0	 30.0;
	3743	 5183	 0.00389	 0.03206	 0.0	 1175	 1175	 1175	 0.0	 0.0	 1	 -30.0	 30.0;
	5183	 4717	 2.394421	 10.2281	 0.0	 4	 4	 4	 0.0	 0.0	 1	 -30.0	 30.0;
	5183	 2256	 0.001	 0.942996	 0.0	 34	 34	 34	 0.0	 0.0	 1	 -30.0	 30.0;
	5183	 7691	 7.162397	 16.07149	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	5183	 6065	 6.970248	 12.65785	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	6656	 9032	 0.00041	 0.00489	 0.0	 6437	 6437	 6437	 0.0	 0.0	 1	 -30.0	 30.0;
	12987	 9032	 0.00035	 0.00415	 0.0	 7585	 7585	 7585	 0.0	 0.0	 1	 -30.0	 30.0;
	3895	 6447	 0.00041	 0.00478	 0.0	 6585	 6585	 6585	 0.0	 0.0	 1	 -30.0	 30.0;
	12987	 6447	 0.00036	 0.00406	 0.0	 7750	 7750	 7750	 0.0	 0.0	 1	 -30.0	 30.0;
	6656	 10903	 0.00069	 0.00736	 0.0	 4274	 4274	 4274	 0.0	 0.0	 1	 -30.0	 30.0;
	9866	 6656	 0.00035	 0.00355	 0.0	 8855	 8855	 8855	 0.0	 0.0	 1	 -30.0	 30.0;
	3504	 6656	 0.0003	 0.0037	 0.0	 8510	 8510	 8510	 0.0	 0.0	 1	 -30.0	 30.0;
	3895	 8234	 0.00079	 0.00639	 0.0	 4906	 4906	 4906	 0.0	 0.0	 1	 -30.0	 30.0;
	1789	 3895	 10.65028	 23.35249	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	7211	 3895	 0.00035	 0.00375	 0.0	 8387	 8387	 8387	 0.0	 0.0	 1	 -30.0	 30.0;
	919	 3895	 0.00035	 0.00368	 0.0	 8545	 8545	 8545	 0.0	 0.0	 1	 -30.0	 30.0;
	7014	 12720	 0.0	 0.0002	 0.0	 187958	 187958	 187958	 0.0	 0.0	 1	 -30.0	 30.0;
	7014	 12720	 0.001	 0.307397	 0.0	 123	 123	 123	 0.0	 0.0	 1	 -30.0	 30.0;
	7916	 7014	 30.07851	 44.4938	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	3743	 7014	 28.13843	 48.89876	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	7014	 9401	 1.021095	 4.339256	 0.0	 9	 9	 9	 0.0	 0.0	 1	 -30.0	 30.0;
	7014	 2256	 19.04773	 44.46694	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	7014	 1566	 11.71198	 25.83058	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	7014	 5754	 13.4062	 28.03306	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	7916	 12720	 25.77686	 44.3843	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	3743	 12720	 29.27686	 39.66322	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	12720	 9401	 0.90343	 4.251446	 0.0	 9	 9	 9	 0.0	 0.0	 1	 -30.0	 30.0;
	12720	 2256	 15.67913	 46.04752	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	12720	 1566	 10.06777	 25.78512	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	12720	 5754	 11.7936	 27.51653	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	6933	 8234	 0.00037	 0.00319	 0.0	 9837	 9837	 9837	 0.0	 0.0	 1	 -30.0	 30.0;
	4218	 10903	 0.00037	 0.0032	 0.0	 9806	 9806	 9806	 0.0	 0.0	 1	 -30.0	 30.0;
	4762	 13432	 6e-05	 0.00057	 0.0	 55112	 55112	 55112	 0.0	 0.0	 1	 -30.0	 30.0;
	13282	 4762	 0.00081	 0.00793	 0.0	 3963	 3963	 3963	 0.0	 0.0	 1	 -30.0	 30.0;
	7916	 3743	 0.0	 0.0002	 0.0	 187958	 187958	 187958	 0.0	 0.0	 1	 -30.0	 30.0;
	7916	 3743	 0.001	 0.218595	 0.0	 172	 172	 172	 0.0	 0.0	 1	 -30.0	 30.0;
	7916	 4717	 5.508884	 16.92169	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	7916	 2256	 0.417335	 3.096901	 0.0	 13	 13	 13	 0.0	 0.0	 1	 -30.0	 30.0;
	7916	 7691	 35.56405	 45.20868	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	7916	 6065	 26.29545	 47.22107	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	3743	 4717	 5.134091	 18.53492	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	3743	 2256	 0.373512	 3.536364	 0.0	 11	 11	 11	 0.0	 0.0	 1	 -30.0	 30.0;
	3743	 7691	 31.99174	 51.7624	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	3743	 6065	 26.61157	 47.82645	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	9401	 2256	 22.02479	 61.94007	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	1566	 9401	 0.20395	 1.135248	 0.0	 33	 33	 33	 0.0	 0.0	 1	 -30.0	 30.0;
	5754	 9401	 0.207314	 1.339256	 0.0	 28	 28	 28	 0.0	 0.0	 1	 -30.0	 30.0;
	4717	 2256	 15.82955	 28.76446	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	4717	 7691	 27.39876	 40.44215	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	4717	 6065	 23.59711	 35.69835	 0.0	 1	 1	 1	 0.0	 0.0	 1	 -30.0	 30.0;
	7691	 2256	 1.210248	 3.369008	 0.0	 9	 9	 9	 0.0	 0.0	 1	 -30.0	 30.0;
	6065	 2256	 0.914421	 3.375826	 0.0	 10	 10	 10	 0.0	 0.0	 1	 -30.0	 30.0;
	6196	 1779	 0.005729	 0.02032	 0.0	 1497	 1497	 1497	 0.0	 0.0	 1	 -30.0	 30.0;
	2313	 1779	 0.005841	 0.019909	 0.0	 1523	 1523	 1523	 0.0	 0.0	 1	 -30.0	 30.0;
	6012	 1779	 0.084781	 0.493471	 0.0	 64	 64	 64	 0.0	 0.0	 1	 -30.0	 30.0;
	8529	 5951	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	8529	 5951	 0.001	 0.19356	 0.0	 164	 164	 164	 0.0	 0.0	 1	 -30.0	 30.0;
	8529	 12058	 0.00192	 0.01356	 0.0	 2307	 2307	 2307	 0.0	 0.0	 1	 -30.0	 30.0;
	5951	 12058	 0.00172	 0.01537	 0.0	 2043	 2043	 2043	 0.0	 0.0	 1	 -30.0	 30.0;
	2741	 6180	 0.00035	 0.00346	 0.0	 9083	 9083	 9083	 0.0	 0.0	 1	 -30.0	 30.0;
	1566	 5754	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	1566	 5754	 0.001	 0.159719	 0.0	 198	 198	 198	 0.0	 0.0	 1	 -30.0	 30.0;
	1566	 8815	 0.000341	 0.00199	 0.0	 15646	 15646	 15646	 0.0	 0.0	 1	 -30.0	 30.0;
	8815	 12039	 0.00219	 0.012901	 0.0	 2414	 2414	 2414	 0.0	 0.0	 1	 -30.0	 30.0;
	12039	 6478	 0.002531	 0.013539	 0.0	 2294	 2294	 2294	 0.0	 0.0	 1	 -30.0	 30.0;
	6478	 10573	 0.002281	 0.01263	 0.0	 2462	 2462	 2462	 0.0	 0.0	 1	 -30.0	 30.0;
	10573	 166	 0.00232	 0.01393	 0.0	 2237	 2237	 2237	 0.0	 0.0	 1	 -30.0	 30.0;
	1747	 2897	 0.00043	 0.00418	 0.0	 7518	 7518	 7518	 0.0	 0.0	 1	 -30.0	 30.0;
	964	 6550	 0.113102	 0.936981	 0.0	 34	 34	 34	 0.0	 0.0	 1	 -30.0	 30.0;
	6550	 1670	 0.00043	 0.00419	 0.0	 7500	 7500	 7500	 0.0	 0.0	 1	 -30.0	 30.0;
	13282	 6550	 0.124889	 1.006302	 0.0	 32	 32	 32	 0.0	 0.0	 1	 -30.0	 30.0;
	3746	 12363	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	3746	 12363	 0.003651	 0.01288	 0.0	 2360	 2360	 2360	 0.0	 0.0	 1	 -30.0	 30.0;
	12363	 5547	 0.004021	 0.01951	 0.0	 1586	 1586	 1586	 0.0	 0.0	 1	 -30.0	 30.0;
	964	 1651	 0.00057	 0.00402	 0.0	 7780	 7780	 7780	 0.0	 0.0	 1	 -30.0	 30.0;
	5939	 13282	 0.00064	 0.00448	 0.0	 6980	 6980	 6980	 0.0	 0.0	 1	 -30.0	 30.0;
	964	 13282	 0.00646	 0.473407	 0.0	 67	 67	 67	 0.0	 0.0	 1	 -30.0	 30.0;
	4756	 2897	 8e-05	 0.00061	 0.0	 51343	 51343	 51343	 0.0	 0.0	 1	 -30.0	 30.0;
	1128	 1670	 6e-05	 0.00065	 0.0	 48391	 48391	 48391	 0.0	 0.0	 1	 -30.0	 30.0;
	6012	 6196	 0.00012	 0.000461	 0.0	 66310	 66310	 66310	 0.0	 0.0	 1	 -30.0	 30.0;
	6012	 2313	 0.00013	 0.00045	 0.0	 67437	 67437	 67437	 0.0	 0.0	 1	 -30.0	 30.0;
	7691	 6065	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	7691	 6065	 0.001	 0.249814	 0.0	 127	 127	 127	 0.0	 0.0	 1	 -30.0	 30.0;
	12684	 3043	 0.0001	 0.00075	 0.0	 41748	 41748	 41748	 0.0	 0.0	 1	 -30.0	 30.0;
	12684	 10965	 0.0038	 0.11597	 0.0	 327	 327	 327	 0.0	 0.0	 1	 -30.0	 30.0;
	12684	 10965	 0.0001	 0.00081	 0.0	 46486	 46486	 46486	 0.0	 0.0	 1	 -30.0	 30.0;
	9948	 3043	 0.0001	 0.00094	 0.0	 33415	 33415	 33415	 0.0	 0.0	 1	 -30.0	 30.0;
	9948	 3043	 9e-05	 0.00107	 0.0	 29418	 29418	 29418	 0.0	 0.0	 1	 -30.0	 30.0;
	89	 9948	 7e-05	 0.00085	 0.0	 37037	 37037	 37037	 0.0	 0.0	 1	 -30.0	 30.0;
	89	 9948	 8e-05	 0.00081	 0.0	 38808	 38808	 38808	 0.0	 0.0	 1	 -30.0	 30.0;
	3043	 10965	 0.00018	 0.00171	 0.0	 22065	 22065	 22065	 0.0	 0.0	 1	 -30.0	 30.0;
	89	 3635	 0.00017	 0.00191	 0.0	 16473	 16473	 16473	 0.0	 0.0	 1	 -30.0	 30.0;
	89	 3635	 0.00016	 0.00194	 0.0	 16228	 16228	 16228	 0.0	 0.0	 1	 -30.0	 30.0;
	89	 11659	 0.0005	 0.00317	 0.0	 9843	 9843	 9843	 0.0	 0.0	 1	 -30.0	 30.0;
	89	 11659	 0.00048	 0.00322	 0.0	 9703	 9703	 9703	 0.0	 0.0	 1	 -30.0	 30.0;
	10965	 6385	 0.00427	 0.19732	 0.0	 191	 191	 191	 0.0	 0.0	 1	 -30.0	 30.0;
	10965	 6385	 0.0001	 0.00122	 0.0	 30710	 30710	 30710	 0.0	 0.0	 1	 -30.0	 30.0;
	10965	 6385	 0.0001	 0.00119	 0.0	 31479	 31479	 31479	 0.0	 0.0	 1	 -30.0	 30.0;
	6385	 6595	 0.0024	 0.02048	 0.0	 1824	 1824	 1824	 0.0	 0.0	 1	 -30.0	 30.0;
	6385	 284	 0.00042	 0.00474	 0.0	 7900	 7900	 7900	 0.0	 0.0	 1	 -30.0	 30.0;
	5297	 2962	 0.0	 0.0002	 0.0	 187958	 187958	 187958	 0.0	 0.0	 1	 -30.0	 30.0;
	5297	 2962	 0.003409	 0.129831	 0.0	 290	 290	 290	 0.0	 0.0	 1	 -30.0	 30.0;
	5297	 313	 0.00605	 0.024031	 0.0	 1517	 1517	 1517	 0.0	 0.0	 1	 -30.0	 30.0;
	2962	 313	 0.005919	 0.0245	 0.0	 1492	 1492	 1492	 0.0	 0.0	 1	 -30.0	 30.0;
	4127	 9057	 0.406364	 1.478988	 0.0	 21	 21	 21	 0.0	 0.0	 1	 -30.0	 30.0;
	4127	 587	 0.12912	 0.95312	 0.0	 33	 33	 33	 0.0	 0.0	 1	 -30.0	 30.0;
	4127	 7275	 0.23062	 0.90281	 0.0	 34	 34	 34	 0.0	 0.0	 1	 -30.0	 30.0;
	1611	 4127	 0.05107	 0.366901	 0.0	 86	 86	 86	 0.0	 0.0	 1	 -30.0	 30.0;
	4127	 587	 0.00207	 0.0168	 0.0	 1867	 1867	 1867	 0.0	 0.0	 1	 -30.0	 30.0;
	4127	 2319	 0.00119	 0.009659	 0.0	 3246	 3246	 3246	 0.0	 0.0	 1	 -30.0	 30.0;
	3879	 4127	 0.120151	 0.700041	 0.0	 45	 45	 45	 0.0	 0.0	 1	 -30.0	 30.0;
	4127	 8543	 0.032581	 0.326756	 0.0	 97	 97	 97	 0.0	 0.0	 1	 -30.0	 30.0;
	5470	 8061	 2e-05	 0.0002	 0.0	 157153	 157153	 157153	 0.0	 0.0	 1	 -30.0	 30.0;
	5470	 1355	 0.00025	 0.00344	 0.0	 9159	 9159	 9159	 0.0	 0.0	 1	 -30.0	 30.0;
	5470	 1355	 0.01671	 0.288767	 0.0	 110	 110	 110	 0.0	 0.0	 1	 -30.0	 30.0;
	5470	 9499	 0.01954	 0.281191	 0.0	 113	 113	 113	 0.0	 0.0	 1	 -30.0	 30.0;
	9156	 5470	 0.00356	 0.222701	 0.0	 142	 142	 142	 0.0	 0.0	 1	 -30.0	 30.0;
	9156	 5470	 0.00271	 0.199571	 0.0	 159	 159	 159	 0.0	 0.0	 1	 -30.0	 30.0;
	6804	 8061	 0.00016	 0.00253	 0.0	 12461	 12461	 12461	 0.0	 0.0	 1	 -30.0	 30.0;
	9156	 8061	 0.00018	 0.00214	 0.0	 14709	 14709	 14709	 0.0	 0.0	 1	 -30.0	 30.0;
	9057	 587	 0.002091	 0.0138	 0.0	 2264	 2264	 2264	 0.0	 0.0	 1	 -30.0	 30.0;
	9057	 587	 0.291467	 1.202521	 0.0	 26	 26	 26	 0.0	 0.0	 1	 -30.0	 30.0;
	7275	 9057	 0.204719	 0.794277	 0.0	 39	 39	 39	 0.0	 0.0	 1	 -30.0	 30.0;
	1611	 9057	 0.026401	 0.214814	 0.0	 146	 146	 146	 0.0	 0.0	 1	 -30.0	 30.0;
	1611	 9057	 0.00295	 0.01256	 0.0	 2449	 2449	 2449	 0.0	 0.0	 1	 -30.0	 30.0;
	6301	 11453	 0.359525	 1.423657	 0.0	 22	 22	 22	 0.0	 0.0	 1	 -30.0	 30.0;
	3085	 11453	 0.32907	 1.339607	 0.0	 23	 23	 23	 0.0	 0.0	 1	 -30.0	 30.0;
	3085	 11453	 0.00469	 0.03913	 0.0	 802	 802	 802	 0.0	 0.0	 1	 -30.0	 30.0;
	3817	 11453	 0.000841	 0.00544	 0.0	 5739	 5739	 5739	 0.0	 0.0	 1	 -30.0	 30.0;
	3817	 11453	 0.014581	 0.16557	 0.0	 191	 191	 191	 0.0	 0.0	 1	 -30.0	 30.0;
	7035	 11453	 1.038884	 1.650227	 0.0	 17	 17	 17	 0.0	 0.0	 1	 -30.0	 30.0;
	11123	 11453	 0.863926	 1.96155	 0.0	 15	 15	 15	 0.0	 0.0	 1	 -30.0	 30.0;
	80	 587	 0.005081	 0.02426	 0.0	 1275	 1275	 1275	 0.0	 0.0	 1	 -30.0	 30.0;
	2314	 80	 0.470062	 1.363636	 0.0	 22	 22	 22	 0.0	 0.0	 1	 -30.0	 30.0;
	80	 12360	 0.035969	 0.35219	 0.0	 90	 90	 90	 0.0	 0.0	 1	 -30.0	 30.0;
	80	 13555	 0.0033	 0.01864	 0.0	 1669	 1669	 1669	 0.0	 0.0	 1	 -30.0	 30.0;
	80	 13555	 0.018021	 0.1825	 0.0	 173	 173	 173	 0.0	 0.0	 1	 -30.0	 30.0;
	7437	 1170	 0.002651	 0.027659	 0.0	 1137	 1137	 1137	 0.0	 0.0	 1	 -30.0	 30.0;
	7456	 7437	 0.00226	 0.04061	 0.0	 777	 777	 777	 0.0	 0.0	 1	 -30.0	 30.0;
	7437	 12202	 0.000711	 0.0098	 0.0	 3215	 3215	 3215	 0.0	 0.0	 1	 -30.0	 30.0;
	3278	 7437	 0.002211	 0.037599	 0.0	 839	 839	 839	 0.0	 0.0	 1	 -30.0	 30.0;
	6046	 3462	 0.0016	 0.01356	 0.0	 2314	 2314	 2314	 0.0	 0.0	 1	 -30.0	 30.0;
	6046	 3462	 0.00165	 0.01328	 0.0	 2361	 2361	 2361	 0.0	 0.0	 1	 -30.0	 30.0;
	9156	 1355	 0.01336	 0.25865	 0.0	 122	 122	 122	 0.0	 0.0	 1	 -30.0	 30.0;
	9156	 1355	 0.00015	 0.00253	 0.0	 12464	 12464	 12464	 0.0	 0.0	 1	 -30.0	 30.0;
	10358	 2376	 0.00225	 0.02106	 0.0	 1492	 1492	 1492	 0.0	 0.0	 1	 -30.0	 30.0;
	6207	 2376	 0.00426	 0.03506	 0.0	 895	 895	 895	 0.0	 0.0	 1	 -30.0	 30.0;
	9898	 2376	 0.00043	 0.00581	 0.0	 5422	 5422	 5422	 0.0	 0.0	 1	 -30.0	 30.0;
	7275	 5802	 0.001151	 0.009909	 0.0	 3167	 3167	 3167	 0.0	 0.0	 1	 -30.0	 30.0;
	1611	 5802	 0.000961	 0.00751	 0.0	 4173	 4173	 4173	 0.0	 0.0	 1	 -30.0	 30.0;
	1209	 5802	 0.00032	 0.00324	 0.0	 9702	 9702	 9702	 0.0	 0.0	 1	 -30.0	 30.0;
	10358	 2376	 0.00245	 0.02191	 0.0	 1433	 1433	 1433	 0.0	 0.0	 1	 -30.0	 30.0;
	1620	 2376	 0.00037	 0.00606	 0.0	 5203	 5203	 5203	 0.0	 0.0	 1	 -30.0	 30.0;
	10196	 2376	 0.0029	 0.0289	 0.0	 1088	 1088	 1088	 0.0	 0.0	 1	 -30.0	 30.0;
	10308	 587	 0.000151	 0.00156	 0.0	 20155	 20155	 20155	 0.0	 0.0	 1	 -30.0	 30.0;
	13436	 587	 0.00014	 0.00144	 0.0	 21833	 21833	 21833	 0.0	 0.0	 1	 -30.0	 30.0;
	7275	 587	 0.026841	 0.406942	 0.0	 78	 78	 78	 0.0	 0.0	 1	 -30.0	 30.0;
	1611	 587	 0.025909	 0.304649	 0.0	 104	 104	 104	 0.0	 0.0	 1	 -30.0	 30.0;
	3772	 1177	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	3772	 1177	 0.001	 0.18678	 0.0	 170	 170	 170	 0.0	 0.0	 1	 -30.0	 30.0;
	7892	 3772	 0.989958	 2.675	 0.0	 12	 12	 12	 0.0	 0.0	 1	 -30.0	 30.0;
	5412	 3772	 0.994529	 2.704017	 0.0	 11	 11	 11	 0.0	 0.0	 1	 -30.0	 30.0;
	6108	 3772	 0.154938	 0.902078	 0.0	 35	 35	 35	 0.0	 0.0	 1	 -30.0	 30.0;
	4839	 3772	 0.141247	 1.002008	 0.0	 32	 32	 32	 0.0	 0.0	 1	 -30.0	 30.0;
	13476	 3772	 0.01709	 0.303539	 0.0	 104	 104	 104	 0.0	 0.0	 1	 -30.0	 30.0;
	3772	 10879	 0.00081	 0.00826	 0.0	 3806	 3806	 3806	 0.0	 0.0	 1	 -30.0	 30.0;
	3772	 6046	 0.00174	 0.01199	 0.0	 2608	 2608	 2608	 0.0	 0.0	 1	 -30.0	 30.0;
	3772	 9048	 0.00136	 0.012	 0.0	 2616	 2616	 2616	 0.0	 0.0	 1	 -30.0	 30.0;
	7892	 1177	 1.135249	 2.306648	 0.0	 13	 13	 13	 0.0	 0.0	 1	 -30.0	 30.0;
	5412	 1177	 1.077147	 2.483726	 0.0	 12	 12	 12	 0.0	 0.0	 1	 -30.0	 30.0;
	6108	 1177	 0.140319	 0.988089	 0.0	 32	 32	 32	 0.0	 0.0	 1	 -30.0	 30.0;
	4839	 1177	 0.15108	 0.940582	 0.0	 34	 34	 34	 0.0	 0.0	 1	 -30.0	 30.0;
	13476	 1177	 0.00045	 0.00442	 0.0	 7110	 7110	 7110	 0.0	 0.0	 1	 -30.0	 30.0;
	13476	 1177	 0.01578	 0.332528	 0.0	 95	 95	 95	 0.0	 0.0	 1	 -30.0	 30.0;
	6916	 1177	 0.00032	 0.00308	 0.0	 10201	 10201	 10201	 0.0	 0.0	 1	 -30.0	 30.0;
	487	 6804	 0.00018	 0.0025	 0.0	 12603	 12603	 12603	 0.0	 0.0	 1	 -30.0	 30.0;
	4172	 6804	 0.03152	 0.366053	 0.0	 86	 86	 86	 0.0	 0.0	 1	 -30.0	 30.0;
	2314	 5524	 0.00251	 0.13469	 0.0	 235	 235	 235	 0.0	 0.0	 1	 -30.0	 30.0;
	2314	 6301	 0.00943	 0.04787	 0.0	 648	 648	 648	 0.0	 0.0	 1	 -30.0	 30.0;
	2314	 12360	 0.002781	 0.02494	 0.0	 1259	 1259	 1259	 0.0	 0.0	 1	 -30.0	 30.0;
	2314	 12360	 0.22876	 0.857376	 0.0	 36	 36	 36	 0.0	 0.0	 1	 -30.0	 30.0;
	2314	 13555	 0.113521	 0.454752	 0.0	 68	 68	 68	 0.0	 0.0	 1	 -30.0	 30.0;
	10358	 11151	 0.00159	 0.01603	 0.0	 1961	 1961	 1961	 0.0	 0.0	 1	 -30.0	 30.0;
	5524	 3085	 0.00924	 0.04881	 0.0	 636	 636	 636	 0.0	 0.0	 1	 -30.0	 30.0;
	5524	 13555	 0.00643	 0.027271	 0.0	 1128	 1128	 1128	 0.0	 0.0	 1	 -30.0	 30.0;
	10358	 6207	 0.00183	 0.01368	 0.0	 2289	 2289	 2289	 0.0	 0.0	 1	 -30.0	 30.0;
	12064	 7805	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	12064	 7805	 0.001	 0.191392	 0.0	 166	 166	 166	 0.0	 0.0	 1	 -30.0	 30.0;
	4740	 12064	 0.00081	 0.00981	 0.0	 3209	 3209	 3209	 0.0	 0.0	 1	 -30.0	 30.0;
	12064	 7244	 0.090907	 0.571413	 0.0	 55	 55	 55	 0.0	 0.0	 1	 -30.0	 30.0;
	12064	 7244	 0.00058	 0.00647	 0.0	 4863	 4863	 4863	 0.0	 0.0	 1	 -30.0	 30.0;
	12064	 13259	 0.441572	 1.595429	 0.0	 20	 20	 20	 0.0	 0.0	 1	 -30.0	 30.0;
	12064	 7096	 0.0463	 0.493158	 0.0	 64	 64	 64	 0.0	 0.0	 1	 -30.0	 30.0;
	12064	 8694	 0.053	 0.456427	 0.0	 69	 69	 69	 0.0	 0.0	 1	 -30.0	 30.0;
	8694	 7805	 0.00048	 0.00707	 0.0	 4458	 4458	 4458	 0.0	 0.0	 1	 -30.0	 30.0;
	7805	 7244	 0.0007	 0.00626	 0.0	 5015	 5015	 5015	 0.0	 0.0	 1	 -30.0	 30.0;
	7805	 7244	 0.099273	 0.491122	 0.0	 64	 64	 64	 0.0	 0.0	 1	 -30.0	 30.0;
	7805	 13259	 0.411558	 1.466205	 0.0	 21	 21	 21	 0.0	 0.0	 1	 -30.0	 30.0;
	7805	 7096	 0.05226	 0.428179	 0.0	 74	 74	 74	 0.0	 0.0	 1	 -30.0	 30.0;
	7805	 8694	 0.04979	 0.473137	 0.0	 67	 67	 67	 0.0	 0.0	 1	 -30.0	 30.0;
	10503	 11644	 0.00018	 0.00218	 0.0	 14441	 14441	 14441	 0.0	 0.0	 1	 -30.0	 30.0;
	5633	 1025	 0.344619	 1.353116	 0.0	 23	 23	 23	 0.0	 0.0	 1	 -30.0	 30.0;
	5633	 3417	 0.581787	 1.764958	 0.0	 17	 17	 17	 0.0	 0.0	 1	 -30.0	 30.0;
	5633	 11636	 0.075831	 0.835526	 0.0	 38	 38	 38	 0.0	 0.0	 1	 -30.0	 30.0;
	5633	 11636	 0.00095	 0.0105	 0.0	 2997	 2997	 2997	 0.0	 0.0	 1	 -30.0	 30.0;
	5633	 2948	 0.081281	 0.782202	 0.0	 41	 41	 41	 0.0	 0.0	 1	 -30.0	 30.0;
	5633	 10879	 0.06719	 0.554377	 0.0	 57	 57	 57	 0.0	 0.0	 1	 -30.0	 30.0;
	5633	 9048	 0.00409	 0.271641	 0.0	 117	 117	 117	 0.0	 0.0	 1	 -30.0	 30.0;
	5633	 9048	 0.00041	 0.00351	 0.0	 8939	 8939	 8939	 0.0	 0.0	 1	 -30.0	 30.0;
	11698	 949	 0.00138	 0.008789	 0.0	 3551	 3551	 3551	 0.0	 0.0	 1	 -30.0	 30.0;
	11698	 4819	 0.002331	 0.01832	 0.0	 1711	 1711	 1711	 0.0	 0.0	 1	 -30.0	 30.0;
	1025	 3417	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	1025	 3417	 0.001	 0.311717	 0.0	 102	 102	 102	 0.0	 0.0	 1	 -30.0	 30.0;
	2265	 1025	 0.00043	 0.00408	 0.0	 7700	 7700	 7700	 0.0	 0.0	 1	 -30.0	 30.0;
	1025	 11636	 0.083899	 0.525478	 0.0	 60	 60	 60	 0.0	 0.0	 1	 -30.0	 30.0;
	1025	 2948	 0.07124	 0.605921	 0.0	 52	 52	 52	 0.0	 0.0	 1	 -30.0	 30.0;
	1025	 11644	 0.00013	 0.00147	 0.0	 21405	 21405	 21405	 0.0	 0.0	 1	 -30.0	 30.0;
	1025	 10879	 2.055194	 4.798753	 0.0	 7	 7	 7	 0.0	 0.0	 1	 -30.0	 30.0;
	13259	 1025	 0.00048	 0.00587	 0.0	 5364	 5364	 5364	 0.0	 0.0	 1	 -30.0	 30.0;
	9048	 1025	 0.81115	 2.560526	 0.0	 12	 12	 12	 0.0	 0.0	 1	 -30.0	 30.0;
	1432	 11698	 0.00095	 0.004169	 0.0	 7388	 7388	 7388	 0.0	 0.0	 1	 -30.0	 30.0;
	3636	 11698	 0.01012	 0.04631	 0.0	 667	 667	 667	 0.0	 0.0	 1	 -30.0	 30.0;
	4328	 3417	 0.00013	 0.0014	 0.0	 22466	 22466	 22466	 0.0	 0.0	 1	 -30.0	 30.0;
	1691	 3417	 0.00013	 0.00143	 0.0	 21999	 21999	 21999	 0.0	 0.0	 1	 -30.0	 30.0;
	3417	 11636	 0.091447	 0.726385	 0.0	 44	 44	 44	 0.0	 0.0	 1	 -30.0	 30.0;
	3417	 11636	 0.00093	 0.00869	 0.0	 3615	 3615	 3615	 0.0	 0.0	 1	 -30.0	 30.0;
	3417	 2948	 0.089307	 0.727078	 0.0	 44	 44	 44	 0.0	 0.0	 1	 -30.0	 30.0;
	3417	 10879	 3.590651	 5.504778	 0.0	 5	 5	 5	 0.0	 0.0	 1	 -30.0	 30.0;
	4172	 3417	 0.00047	 0.00544	 0.0	 5785	 5785	 5785	 0.0	 0.0	 1	 -30.0	 30.0;
	9048	 3417	 1.2741	 3.747645	 0.0	 8	 8	 8	 0.0	 0.0	 1	 -30.0	 30.0;
	2354	 6180	 0.00142	 0.01566	 0.0	 2009	 2009	 2009	 0.0	 0.0	 1	 -30.0	 30.0;
	2948	 9744	 0.00082	 0.00794	 0.0	 3958	 3958	 3958	 0.0	 0.0	 1	 -30.0	 30.0;
	7892	 5412	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	7892	 5412	 0.001	 0.149882	 0.0	 211	 211	 211	 0.0	 0.0	 1	 -30.0	 30.0;
	6108	 7892	 0.088033	 0.626579	 0.0	 50	 50	 50	 0.0	 0.0	 1	 -30.0	 30.0;
	6108	 7892	 0.001	 0.00866	 0.0	 3624	 3624	 3624	 0.0	 0.0	 1	 -30.0	 30.0;
	4839	 7892	 0.090852	 0.619418	 0.0	 51	 51	 51	 0.0	 0.0	 1	 -30.0	 30.0;
	13476	 7892	 0.87133	 2.390028	 0.0	 13	 13	 13	 0.0	 0.0	 1	 -30.0	 30.0;
	6108	 5412	 0.087632	 0.633012	 0.0	 50	 50	 50	 0.0	 0.0	 1	 -30.0	 30.0;
	4839	 5412	 0.097832	 0.57669	 0.0	 55	 55	 55	 0.0	 0.0	 1	 -30.0	 30.0;
	13476	 5412	 0.857064	 2.463089	 0.0	 13	 13	 13	 0.0	 0.0	 1	 -30.0	 30.0;
	5412	 6046	 0.0004	 0.0039	 0.0	 8058	 8058	 8058	 0.0	 0.0	 1	 -30.0	 30.0;
	6301	 3085	 0.001	 0.486508	 0.0	 65	 65	 65	 0.0	 0.0	 1	 -30.0	 30.0;
	3817	 6301	 0.003909	 0.034711	 0.0	 905	 905	 905	 0.0	 0.0	 1	 -30.0	 30.0;
	3817	 6301	 0.497789	 2.055971	 0.0	 15	 15	 15	 0.0	 0.0	 1	 -30.0	 30.0;
	6301	 7035	 0.357087	 1.677376	 0.0	 19	 19	 19	 0.0	 0.0	 1	 -30.0	 30.0;
	6301	 11123	 0.349194	 1.694876	 0.0	 19	 19	 19	 0.0	 0.0	 1	 -30.0	 30.0;
	3817	 3085	 0.438409	 2.013802	 0.0	 16	 16	 16	 0.0	 0.0	 1	 -30.0	 30.0;
	3085	 7035	 0.307107	 1.517831	 0.0	 21	 21	 21	 0.0	 0.0	 1	 -30.0	 30.0;
	3085	 11123	 0.354174	 1.443988	 0.0	 22	 22	 22	 0.0	 0.0	 1	 -30.0	 30.0;
	12733	 3576	 0.00274	 0.144159	 0.0	 220	 220	 220	 0.0	 0.0	 1	 -30.0	 30.0;
	12733	 2600	 0.00039	 0.00175	 0.0	 17618	 17618	 17618	 0.0	 0.0	 1	 -30.0	 30.0;
	3576	 13196	 0.000401	 0.001711	 0.0	 17975	 17975	 17975	 0.0	 0.0	 1	 -30.0	 30.0;
	2354	 7451	 0.06537	 0.54912	 0.0	 58	 58	 58	 0.0	 0.0	 1	 -30.0	 30.0;
	2354	 2265	 0.00098	 0.00852	 0.0	 3684	 3684	 3684	 0.0	 0.0	 1	 -30.0	 30.0;
	2354	 2265	 0.076039	 0.582729	 0.0	 54	 54	 54	 0.0	 0.0	 1	 -30.0	 30.0;
	2354	 2843	 0.00185	 0.01418	 0.0	 2209	 2209	 2209	 0.0	 0.0	 1	 -30.0	 30.0;
	12109	 2354	 0.790374	 2.170014	 0.0	 14	 14	 14	 0.0	 0.0	 1	 -30.0	 30.0;
	2393	 949	 0.00188	 0.0087	 0.0	 3549	 3549	 3549	 0.0	 0.0	 1	 -30.0	 30.0;
	2393	 5190	 0.042461	 0.437066	 0.0	 72	 72	 72	 0.0	 0.0	 1	 -30.0	 30.0;
	3742	 5190	 0.00068	 0.008531	 0.0	 3691	 3691	 3691	 0.0	 0.0	 1	 -30.0	 30.0;
	5633	 11636	 0.00107	 0.01108	 0.0	 2838	 2838	 2838	 0.0	 0.0	 1	 -30.0	 30.0;
	5633	 10879	 0.00092	 0.00947	 0.0	 3320	 3320	 3320	 0.0	 0.0	 1	 -30.0	 30.0;
	6108	 4839	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	6108	 4839	 0.001	 0.196378	 0.0	 161	 161	 161	 0.0	 0.0	 1	 -30.0	 30.0;
	6108	 13476	 0.102652	 0.915512	 0.0	 35	 35	 35	 0.0	 0.0	 1	 -30.0	 30.0;
	4839	 13476	 0.110602	 0.871537	 0.0	 36	 36	 36	 0.0	 0.0	 1	 -30.0	 30.0;
	8836	 4839	 0.00153	 0.01371	 0.0	 2290	 2290	 2290	 0.0	 0.0	 1	 -30.0	 30.0;
	13171	 4839	 0.00296	 0.02271	 0.0	 1380	 1380	 1380	 0.0	 0.0	 1	 -30.0	 30.0;
	7451	 2265	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	7451	 2265	 0.001	 0.229661	 0.0	 138	 138	 138	 0.0	 0.0	 1	 -30.0	 30.0;
	7451	 2843	 0.00076	 0.0066	 0.0	 4755	 4755	 4755	 0.0	 0.0	 1	 -30.0	 30.0;
	12109	 7451	 0.134051	 0.802355	 0.0	 39	 39	 39	 0.0	 0.0	 1	 -30.0	 30.0;
	12109	 2265	 0.136413	 0.960942	 0.0	 33	 33	 33	 0.0	 0.0	 1	 -30.0	 30.0;
	12566	 13196	 0.0027	 0.02195	 0.0	 1429	 1429	 1429	 0.0	 0.0	 1	 -30.0	 30.0;
	12566	 4819	 0.001211	 0.004961	 0.0	 6186	 6186	 6186	 0.0	 0.0	 1	 -30.0	 30.0;
	3038	 10308	 0.010091	 0.211612	 0.0	 150	 150	 150	 0.0	 0.0	 1	 -30.0	 30.0;
	3038	 13436	 0.008349	 0.215682	 0.0	 147	 147	 147	 0.0	 0.0	 1	 -30.0	 30.0;
	1611	 3038	 0.000401	 0.001781	 0.0	 17303	 17303	 17303	 0.0	 0.0	 1	 -30.0	 30.0;
	10308	 13436	 0.00076	 0.205461	 0.0	 154	 154	 154	 0.0	 0.0	 1	 -30.0	 30.0;
	13259	 9898	 0.00086	 0.0138	 0.0	 2285	 2285	 2285	 0.0	 0.0	 1	 -30.0	 30.0;
	4172	 1620	 0.00101	 0.01174	 0.0	 2681	 2681	 2681	 0.0	 0.0	 1	 -30.0	 30.0;
	11636	 2948	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	11636	 2948	 0.001	 0.17286	 0.0	 183	 183	 183	 0.0	 0.0	 1	 -30.0	 30.0;
	11636	 10879	 0.917036	 2.770706	 0.0	 11	 11	 11	 0.0	 0.0	 1	 -30.0	 30.0;
	9048	 11636	 0.299162	 1.508587	 0.0	 21	 21	 21	 0.0	 0.0	 1	 -30.0	 30.0;
	2948	 10879	 0.973546	 2.445291	 0.0	 13	 13	 13	 0.0	 0.0	 1	 -30.0	 30.0;
	9048	 2948	 0.335817	 1.383795	 0.0	 23	 23	 23	 0.0	 0.0	 1	 -30.0	 30.0;
	1131	 7035	 0.00114	 0.00625	 0.0	 4972	 4972	 4972	 0.0	 0.0	 1	 -30.0	 30.0;
	7341	 1131	 0.00069	 0.00343	 0.0	 9029	 9029	 9029	 0.0	 0.0	 1	 -30.0	 30.0;
	10504	 1131	 0.000669	 0.00349	 0.0	 8889	 8889	 8889	 0.0	 0.0	 1	 -30.0	 30.0;
	7609	 1131	 0.00264	 0.01612	 0.0	 1934	 1934	 1934	 0.0	 0.0	 1	 -30.0	 30.0;
	4740	 6207	 0.001	 0.01303	 0.0	 2418	 2418	 2418	 0.0	 0.0	 1	 -30.0	 30.0;
	1340	 6207	 0.00018	 0.00112	 0.0	 27846	 27846	 27846	 0.0	 0.0	 1	 -30.0	 30.0;
	8777	 1910	 0.000771	 0.0027	 0.0	 11250	 11250	 11250	 0.0	 0.0	 1	 -30.0	 30.0;
	1688	 1910	 0.000719	 0.003039	 0.0	 10115	 10115	 10115	 0.0	 0.0	 1	 -30.0	 30.0;
	1910	 11123	 0.00138	 0.005409	 0.0	 5659	 5659	 5659	 0.0	 0.0	 1	 -30.0	 30.0;
	2620	 11151	 0.00017	 0.0011	 0.0	 28379	 28379	 28379	 0.0	 0.0	 1	 -30.0	 30.0;
	1611	 7275	 0.01424	 0.207211	 0.0	 153	 153	 153	 0.0	 0.0	 1	 -30.0	 30.0;
	12360	 7275	 0.00288	 0.023031	 0.0	 1361	 1361	 1361	 0.0	 0.0	 1	 -30.0	 30.0;
	13476	 9156	 0.00059	 0.00738	 0.0	 4267	 4267	 4267	 0.0	 0.0	 1	 -30.0	 30.0;
	6114	 7096	 2e-05	 0.0002	 0.0	 157153	 157153	 157153	 0.0	 0.0	 1	 -30.0	 30.0;
	4740	 9661	 0.00034	 0.00243	 0.0	 12874	 12874	 12874	 0.0	 0.0	 1	 -30.0	 30.0;
	9156	 9499	 0.00939	 0.239481	 0.0	 132	 132	 132	 0.0	 0.0	 1	 -30.0	 30.0;
	9156	 9499	 0.0003	 0.00385	 0.0	 8180	 8180	 8180	 0.0	 0.0	 1	 -30.0	 30.0;
	9194	 12202	 0.00082	 0.0117	 0.0	 2694	 2694	 2694	 0.0	 0.0	 1	 -30.0	 30.0;
	9194	 1170	 0.000831	 0.010711	 0.0	 2941	 2941	 2941	 0.0	 0.0	 1	 -30.0	 30.0;
	6796	 3026	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	6796	 3026	 0.001	 0.424958	 0.0	 75	 75	 75	 0.0	 0.0	 1	 -30.0	 30.0;
	6796	 4172	 0.00035	 0.00315	 0.0	 9967	 9967	 9967	 0.0	 0.0	 1	 -30.0	 30.0;
	6796	 4172	 0.01362	 0.396288	 0.0	 80	 80	 80	 0.0	 0.0	 1	 -30.0	 30.0;
	6796	 9156	 0.088213	 0.739543	 0.0	 43	 43	 43	 0.0	 0.0	 1	 -30.0	 30.0;
	3026	 4172	 0.01388	 0.388199	 0.0	 82	 82	 82	 0.0	 0.0	 1	 -30.0	 30.0;
	3026	 9156	 0.0012	 0.01148	 0.0	 2737	 2737	 2737	 0.0	 0.0	 1	 -30.0	 30.0;
	3026	 9156	 0.086413	 0.754086	 0.0	 42	 42	 42	 0.0	 0.0	 1	 -30.0	 30.0;
	487	 13259	 0.00049	 0.00475	 0.0	 6615	 6615	 6615	 0.0	 0.0	 1	 -30.0	 30.0;
	584	 8189	 0.002669	 0.01443	 0.0	 2153	 2153	 2153	 0.0	 0.0	 1	 -30.0	 30.0;
	5190	 949	 0.00338	 0.01488	 0.0	 2071	 2071	 2071	 0.0	 0.0	 1	 -30.0	 30.0;
	3879	 13196	 0.00101	 0.005841	 0.0	 5329	 5329	 5329	 0.0	 0.0	 1	 -30.0	 30.0;
	9898	 2843	 0.00034	 0.00381	 0.0	 8258	 8258	 8258	 0.0	 0.0	 1	 -30.0	 30.0;
	12109	 2843	 0.00017	 0.00223	 0.0	 14124	 14124	 14124	 0.0	 0.0	 1	 -30.0	 30.0;
	8543	 2600	 0.00161	 0.013789	 0.0	 2276	 2276	 2276	 0.0	 0.0	 1	 -30.0	 30.0;
	2843	 1894	 0.00032	 0.00234	 0.0	 13375	 13375	 13375	 0.0	 0.0	 1	 -30.0	 30.0;
	9048	 10879	 0.01246	 0.249882	 0.0	 127	 127	 127	 0.0	 0.0	 1	 -30.0	 30.0;
	7244	 4172	 0.00073	 0.00838	 0.0	 3756	 3756	 3756	 0.0	 0.0	 1	 -30.0	 30.0;
	7244	 13259	 0.01019	 0.13124	 0.0	 240	 240	 240	 0.0	 0.0	 1	 -30.0	 30.0;
	7244	 13259	 0.00078	 0.00873	 0.0	 3604	 3604	 3604	 0.0	 0.0	 1	 -30.0	 30.0;
	7244	 7096	 0.463179	 1.173823	 0.0	 26	 26	 26	 0.0	 0.0	 1	 -30.0	 30.0;
	7244	 8694	 0.428629	 1.321537	 0.0	 23	 23	 23	 0.0	 0.0	 1	 -30.0	 30.0;
	9156	 4172	 0.099591	 0.647687	 0.0	 49	 49	 49	 0.0	 0.0	 1	 -30.0	 30.0;
	1820	 4172	 0.00019	 0.00245	 0.0	 12855	 12855	 12855	 0.0	 0.0	 1	 -30.0	 30.0;
	13259	 7096	 1.591828	 3.383587	 0.0	 9	 9	 9	 0.0	 0.0	 1	 -30.0	 30.0;
	13259	 8694	 1.558587	 3.254017	 0.0	 9	 9	 9	 0.0	 0.0	 1	 -30.0	 30.0;
	3817	 7035	 1.410971	 2.609298	 0.0	 11	 11	 11	 0.0	 0.0	 1	 -30.0	 30.0;
	3817	 11123	 1.456178	 2.474793	 0.0	 12	 12	 12	 0.0	 0.0	 1	 -30.0	 30.0;
	7035	 11123	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	7035	 11123	 0.001	 0.139341	 0.0	 227	 227	 227	 0.0	 0.0	 1	 -30.0	 30.0;
	7096	 8694	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	7096	 8694	 0.001	 0.196801	 0.0	 161	 161	 161	 0.0	 0.0	 1	 -30.0	 30.0;
	11387	 2319	 0.00025	 0.00232	 0.0	 13537	 13537	 13537	 0.0	 0.0	 1	 -30.0	 30.0;
	8543	 11387	 0.000719	 0.005461	 0.0	 5735	 5735	 5735	 0.0	 0.0	 1	 -30.0	 30.0;
	2319	 9426	 0.00012	 0.00069	 0.0	 45102	 45102	 45102	 0.0	 0.0	 1	 -30.0	 30.0;
	9571	 2319	 0.003099	 0.11999	 0.0	 264	 264	 264	 0.0	 0.0	 1	 -30.0	 30.0;
	12360	 13555	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	12360	 13555	 0.001	 0.13145	 0.0	 241	 241	 241	 0.0	 0.0	 1	 -30.0	 30.0;
	3879	 8543	 0.10799	 0.554256	 0.0	 56	 56	 56	 0.0	 0.0	 1	 -30.0	 30.0;
	12271	 12622	 0.00077	 0.00927	 0.0	 3396	 3396	 3396	 0.0	 0.0	 1	 -30.0	 30.0;
	9567	 12622	 0.00078	 0.00908	 0.0	 3467	 3467	 3467	 0.0	 0.0	 1	 -30.0	 30.0;
	7123	 6414	 0.00038	 0.0045	 0.0	 6995	 6995	 6995	 0.0	 0.0	 1	 -30.0	 30.0;
	6414	 9450	 0.00147	 0.0125	 0.0	 3015	 3015	 3015	 0.0	 0.0	 1	 -30.0	 30.0;
	9745	 6414	 0.00039	 0.00441	 0.0	 7135	 7135	 7135	 0.0	 0.0	 1	 -30.0	 30.0;
	6414	 1759	 0.00202	 0.01654	 0.0	 2277	 2277	 2277	 0.0	 0.0	 1	 -30.0	 30.0;
	9567	 12271	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	9567	 12271	 0.00147	 0.112341	 0.0	 282	 282	 282	 0.0	 0.0	 1	 -30.0	 30.0;
	9567	 7123	 0.00069	 0.00564	 0.0	 5560	 5560	 5560	 0.0	 0.0	 1	 -30.0	 30.0;
	12271	 9745	 0.00068	 0.00574	 0.0	 5465	 5465	 5465	 0.0	 0.0	 1	 -30.0	 30.0;
	7123	 9745	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	7123	 9745	 0.00088	 0.07777	 0.0	 407	 407	 407	 0.0	 0.0	 1	 -30.0	 30.0;
	866	 7123	 0.00062	 0.00515	 0.0	 6090	 6090	 6090	 0.0	 0.0	 1	 -30.0	 30.0;
	3429	 9745	 0.0007	 0.00505	 0.0	 6196	 6196	 6196	 0.0	 0.0	 1	 -30.0	 30.0;
	866	 3429	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	866	 3429	 0.00076	 0.06481	 0.0	 488	 488	 488	 0.0	 0.0	 1	 -30.0	 30.0;
	4472	 673	 0.00011	 0.00149	 0.0	 21143	 21143	 21143	 0.0	 0.0	 1	 -30.0	 30.0;
	8588	 2750	 9.9e-05	 0.000979	 0.0	 32102	 32102	 32102	 0.0	 0.0	 1	 -30.0	 30.0;
	7095	 7494	 0.01788	 0.227831	 0.0	 139	 139	 139	 0.0	 0.0	 1	 -30.0	 30.0;
	7095	 7494	 0.004669	 0.015969	 0.0	 1899	 1899	 1899	 0.0	 0.0	 1	 -30.0	 30.0;
	9978	 7095	 0.011229	 0.03868	 0.0	 785	 785	 785	 0.0	 0.0	 1	 -30.0	 30.0;
	3460	 7095	 0.01001	 0.043841	 0.0	 703	 703	 703	 0.0	 0.0	 1	 -30.0	 30.0;
	7095	 700	 0.002151	 0.01032	 0.0	 2997	 2997	 2997	 0.0	 0.0	 1	 -30.0	 30.0;
	6245	 8592	 0.003281	 0.017901	 0.0	 1736	 1736	 1736	 0.0	 0.0	 1	 -30.0	 30.0;
	3497	 6245	 0.005271	 0.026909	 0.0	 1152	 1152	 1152	 0.0	 0.0	 1	 -30.0	 30.0;
	6245	 12457	 0.00044	 0.002169	 0.0	 14273	 14273	 14273	 0.0	 0.0	 1	 -30.0	 30.0;
	6245	 12457	 0.00045	 0.00213	 0.0	 14510	 14510	 14510	 0.0	 0.0	 1	 -30.0	 30.0;
	4556	 9091	 0.452251	 2.097438	 0.0	 15	 15	 15	 0.0	 0.0	 1	 -30.0	 30.0;
	9091	 1723	 0.247659	 1.380679	 0.0	 23	 23	 23	 0.0	 0.0	 1	 -30.0	 30.0;
	1771	 9091	 0.436378	 1.290097	 0.0	 24	 24	 24	 0.0	 0.0	 1	 -30.0	 30.0;
	7818	 9091	 0.218089	 1.220914	 0.0	 26	 26	 26	 0.0	 0.0	 1	 -30.0	 30.0;
	7012	 9091	 0.0612	 1.024169	 0.0	 31	 31	 31	 0.0	 0.0	 1	 -30.0	 30.0;
	8784	 9091	 0.06168	 0.959765	 0.0	 33	 33	 33	 0.0	 0.0	 1	 -30.0	 30.0;
	8784	 9091	 0.0011	 0.00838	 0.0	 3738	 3738	 3738	 0.0	 0.0	 1	 -30.0	 30.0;
	10047	 9091	 0.05459	 0.962258	 0.0	 33	 33	 33	 0.0	 0.0	 1	 -30.0	 30.0;
	7818	 9091	 0.00126	 0.01278	 0.0	 2460	 2460	 2460	 0.0	 0.0	 1	 -30.0	 30.0;
	7472	 10836	 5e-05	 0.000229	 0.0	 134762	 134762	 134762	 0.0	 0.0	 1	 -30.0	 30.0;
	6735	 7472	 0.001331	 0.009331	 0.0	 3352	 3352	 3352	 0.0	 0.0	 1	 -30.0	 30.0;
	7472	 13600	 6e-05	 0.00031	 0.0	 100039	 100039	 100039	 0.0	 0.0	 1	 -30.0	 30.0;
	6735	 9394	 0.00155	 0.00805	 0.0	 3854	 3854	 3854	 0.0	 0.0	 1	 -30.0	 30.0;
	9394	 228	 0.351674	 1.414483	 0.0	 22	 22	 22	 0.0	 0.0	 1	 -30.0	 30.0;
	6735	 9394	 0.239545	 1.416095	 0.0	 22	 22	 22	 0.0	 0.0	 1	 -30.0	 30.0;
	7624	 2750	 0.00011	 0.00088	 0.0	 35618	 35618	 35618	 0.0	 0.0	 1	 -30.0	 30.0;
	2312	 673	 0.00012	 0.00064	 0.0	 48510	 48510	 48510	 0.0	 0.0	 1	 -30.0	 30.0;
	12086	 673	 0.002349	 0.01088	 0.0	 2838	 2838	 2838	 0.0	 0.0	 1	 -30.0	 30.0;
	12086	 673	 0.0023	 0.011099	 0.0	 2787	 2787	 2787	 0.0	 0.0	 1	 -30.0	 30.0;
	673	 1209	 0.004771	 0.03713	 0.0	 844	 844	 844	 0.0	 0.0	 1	 -30.0	 30.0;
	11874	 2750	 0.00056	 0.0013	 0.0	 22316	 22316	 22316	 0.0	 0.0	 1	 -30.0	 30.0;
	10015	 2750	 0.001091	 0.007409	 0.0	 4218	 4218	 4218	 0.0	 0.0	 1	 -30.0	 30.0;
	10015	 2750	 0.00168	 0.007479	 0.0	 4121	 4121	 4121	 0.0	 0.0	 1	 -30.0	 30.0;
	2027	 2750	 0.003151	 0.01876	 0.0	 1661	 1661	 1661	 0.0	 0.0	 1	 -30.0	 30.0;
	1664	 3793	 0.005719	 0.255764	 0.0	 124	 124	 124	 0.0	 0.0	 1	 -30.0	 30.0;
	568	 1664	 0.000599	 0.00294	 0.0	 10528	 10528	 10528	 0.0	 0.0	 1	 -30.0	 30.0;
	568	 3793	 0.00062	 0.00288	 0.0	 10723	 10723	 10723	 0.0	 0.0	 1	 -30.0	 30.0;
	8260	 7011	 0.001169	 0.012591	 0.0	 2498	 2498	 2498	 0.0	 0.0	 1	 -30.0	 30.0;
	8260	 7011	 0.00131	 0.01119	 0.0	 2804	 2804	 2804	 0.0	 0.0	 1	 -30.0	 30.0;
	2150	 7011	 0.000159	 0.00137	 0.0	 22903	 22903	 22903	 0.0	 0.0	 1	 -30.0	 30.0;
	6036	 7011	 0.000159	 0.001341	 0.0	 23392	 23392	 23392	 0.0	 0.0	 1	 -30.0	 30.0;
	12560	 11092	 0.00051	 0.0025	 0.0	 12380	 12380	 12380	 0.0	 0.0	 1	 -30.0	 30.0;
	6561	 10372	 0.00031	 0.001289	 0.0	 23826	 23826	 23826	 0.0	 0.0	 1	 -30.0	 30.0;
	12560	 10372	 0.05163	 0.55124	 0.0	 58	 58	 58	 0.0	 0.0	 1	 -30.0	 30.0;
	11208	 10372	 0.201229	 1.043864	 0.0	 30	 30	 30	 0.0	 0.0	 1	 -30.0	 30.0;
	11358	 10015	 1.027128	 2.385331	 0.0	 13	 13	 13	 0.0	 0.0	 1	 -30.0	 30.0;
	11358	 239	 0.288306	 1.382335	 0.0	 23	 23	 23	 0.0	 0.0	 1	 -30.0	 30.0;
	10225	 11358	 0.05949	 0.340661	 0.0	 92	 92	 92	 0.0	 0.0	 1	 -30.0	 30.0;
	11358	 3751	 0.007211	 0.030409	 0.0	 1011	 1011	 1011	 0.0	 0.0	 1	 -30.0	 30.0;
	12769	 11358	 0.899153	 2.660744	 0.0	 12	 12	 12	 0.0	 0.0	 1	 -30.0	 30.0;
	8118	 11358	 0.809979	 2.92686	 0.0	 11	 11	 11	 0.0	 0.0	 1	 -30.0	 30.0;
	11358	 7766	 0.00251	 0.011211	 0.0	 2750	 2750	 2750	 0.0	 0.0	 1	 -30.0	 30.0;
	3636	 7018	 0.08695	 0.512231	 0.0	 61	 61	 61	 0.0	 0.0	 1	 -30.0	 30.0;
	3636	 13016	 0.006289	 0.693946	 0.0	 46	 46	 46	 0.0	 0.0	 1	 -30.0	 30.0;
	2365	 3636	 0.140669	 0.495269	 0.0	 62	 62	 62	 0.0	 0.0	 1	 -30.0	 30.0;
	9625	 3636	 0.00882	 0.041831	 0.0	 739	 739	 739	 0.0	 0.0	 1	 -30.0	 30.0;
	10196	 2605	 2e-05	 0.00025	 0.0	 125947	 125947	 125947	 0.0	 0.0	 1	 -30.0	 30.0;
	7527	 6511	 0.000159	 0.00074	 0.0	 41734	 41734	 41734	 0.0	 0.0	 1	 -30.0	 30.0;
	1425	 9736	 0.004469	 0.139591	 0.0	 227	 227	 227	 0.0	 0.0	 1	 -30.0	 30.0;
	1425	 3452	 0.001039	 0.006211	 0.0	 5017	 5017	 5017	 0.0	 0.0	 1	 -30.0	 30.0;
	1950	 13449	 0.00813	 0.186659	 0.0	 170	 170	 170	 0.0	 0.0	 1	 -30.0	 30.0;
	1950	 3452	 0.00101	 0.00625	 0.0	 4990	 4990	 4990	 0.0	 0.0	 1	 -30.0	 30.0;
	8659	 831	 8.1e-05	 0.000781	 0.0	 40229	 40229	 40229	 0.0	 0.0	 1	 -30.0	 30.0;
	8659	 10149	 0.0003	 0.002031	 0.0	 15386	 15386	 15386	 0.0	 0.0	 1	 -30.0	 30.0;
	7126	 831	 9.1e-05	 0.000719	 0.0	 43585	 43585	 43585	 0.0	 0.0	 1	 -30.0	 30.0;
	7126	 3731	 0.00086	 0.005581	 0.0	 5594	 5594	 5594	 0.0	 0.0	 1	 -30.0	 30.0;
	6564	 1723	 0.00062	 0.00605	 0.0	 5194	 5194	 5194	 0.0	 0.0	 1	 -30.0	 30.0;
	3227	 831	 0.00181	 0.009599	 0.0	 3234	 3234	 3234	 0.0	 0.0	 1	 -30.0	 30.0;
	9245	 831	 0.00099	 0.00481	 0.0	 6433	 6433	 6433	 0.0	 0.0	 1	 -30.0	 30.0;
	831	 6591	 0.00038	 0.00218	 0.0	 14275	 14275	 14275	 0.0	 0.0	 1	 -30.0	 30.0;
	5394	 1983	 0.00031	 0.00342	 0.0	 9199	 9199	 9199	 0.0	 0.0	 1	 -30.0	 30.0;
	10400	 1983	 0.00083	 0.00929	 0.0	 3387	 3387	 3387	 0.0	 0.0	 1	 -30.0	 30.0;
	4734	 1983	 0.00074	 0.00793	 0.0	 3967	 3967	 3967	 0.0	 0.0	 1	 -30.0	 30.0;
	4506	 4734	 0.00016	 0.00166	 0.0	 18941	 18941	 18941	 0.0	 0.0	 1	 -30.0	 30.0;
	1983	 12051	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	1983	 12051	 0.01471	 0.443012	 0.0	 72	 72	 72	 0.0	 0.0	 1	 -30.0	 30.0;
	1872	 12051	 0.00037	 0.00337	 0.0	 9318	 9318	 9318	 0.0	 0.0	 1	 -30.0	 30.0;
	9978	 4168	 0.001461	 0.006711	 0.0	 4600	 4600	 4600	 0.0	 0.0	 1	 -30.0	 30.0;
	2638	 4168	 0.001479	 0.00656	 0.0	 4698	 4698	 4698	 0.0	 0.0	 1	 -30.0	 30.0;
	10576	 7018	 0.00068	 0.0113	 0.0	 2791	 2791	 2791	 0.0	 0.0	 1	 -30.0	 30.0;
	7155	 4506	 0.00019	 0.00196	 0.0	 16041	 16041	 16041	 0.0	 0.0	 1	 -30.0	 30.0;
	11867	 4506	 0.00019	 0.00198	 0.0	 15881	 15881	 15881	 0.0	 0.0	 1	 -30.0	 30.0;
	1872	 7835	 0.00886	 0.294079	 0.0	 108	 108	 108	 0.0	 0.0	 1	 -30.0	 30.0;
	1872	 7835	 0.00028	 0.00275	 0.0	 11428	 11428	 11428	 0.0	 0.0	 1	 -30.0	 30.0;
	5394	 7835	 0.01321	 0.296717	 0.0	 107	 107	 107	 0.0	 0.0	 1	 -30.0	 30.0;
	12294	 13042	 0.001	 0.169901	 0.0	 186	 186	 186	 0.0	 0.0	 1	 -30.0	 30.0;
	12294	 228	 0.03111	 0.255	 0.0	 123	 123	 123	 0.0	 0.0	 1	 -30.0	 30.0;
	6735	 12294	 0.00057	 0.002849	 0.0	 10872	 10872	 10872	 0.0	 0.0	 1	 -30.0	 30.0;
	13042	 228	 0.03143	 0.234731	 0.0	 134	 134	 134	 0.0	 0.0	 1	 -30.0	 30.0;
	6735	 13042	 0.000581	 0.002789	 0.0	 11088	 11088	 11088	 0.0	 0.0	 1	 -30.0	 30.0;
	12698	 7216	 0.00157	 0.007	 0.0	 4404	 4404	 4404	 0.0	 0.0	 1	 -30.0	 30.0;
	12698	 996	 0.00131	 0.00636	 0.0	 4865	 4865	 4865	 0.0	 0.0	 1	 -30.0	 30.0;
	10914	 7216	 0.001669	 0.00724	 0.0	 4252	 4252	 4252	 0.0	 0.0	 1	 -30.0	 30.0;
	7216	 9396	 0.00663	 0.249339	 0.0	 127	 127	 127	 0.0	 0.0	 1	 -30.0	 30.0;
	7216	 1648	 0.000169	 0.00032	 0.0	 87286	 87286	 87286	 0.0	 0.0	 1	 -30.0	 30.0;
	7216	 5806	 0.000151	 0.00038	 0.0	 77250	 77250	 77250	 0.0	 0.0	 1	 -30.0	 30.0;
	7216	 3804	 0.000841	 0.009581	 0.0	 3285	 3285	 3285	 0.0	 0.0	 1	 -30.0	 30.0;
	7216	 793	 0.0355	 0.360558	 0.0	 88	 88	 88	 0.0	 0.0	 1	 -30.0	 30.0;
	7216	 996	 0.027539	 0.325145	 0.0	 97	 97	 97	 0.0	 0.0	 1	 -30.0	 30.0;
	7216	 5661	 0.025271	 0.339442	 0.0	 93	 93	 93	 0.0	 0.0	 1	 -30.0	 30.0;
	7216	 8211	 0.000169	 0.000219	 0.0	 114188	 114188	 114188	 0.0	 0.0	 1	 -30.0	 30.0;
	3486	 228	 0.000401	 0.0018	 0.0	 17129	 17129	 17129	 0.0	 0.0	 1	 -30.0	 30.0;
	6735	 3486	 0.00205	 0.01162	 0.0	 2678	 2678	 2678	 0.0	 0.0	 1	 -30.0	 30.0;
	3881	 3486	 0.000651	 0.0045	 0.0	 6948	 6948	 6948	 0.0	 0.0	 1	 -30.0	 30.0;
	4233	 228	 0.00038	 0.00187	 0.0	 16554	 16554	 16554	 0.0	 0.0	 1	 -30.0	 30.0;
	6735	 4233	 0.002091	 0.01139	 0.0	 2728	 2728	 2728	 0.0	 0.0	 1	 -30.0	 30.0;
	3881	 4233	 0.00064	 0.004169	 0.0	 7489	 7489	 7489	 0.0	 0.0	 1	 -30.0	 30.0;
	6735	 228	 0.03551	 0.421116	 0.0	 75	 75	 75	 0.0	 0.0	 1	 -30.0	 30.0;
	6735	 1246	 0.090159	 0.624236	 0.0	 51	 51	 51	 0.0	 0.0	 1	 -30.0	 30.0;
	6735	 10093	 0.025919	 0.457603	 0.0	 69	 69	 69	 0.0	 0.0	 1	 -30.0	 30.0;
	6735	 3748	 0.140581	 0.992087	 0.0	 32	 32	 32	 0.0	 0.0	 1	 -30.0	 30.0;
	6735	 4956	 0.00082	 0.007331	 0.0	 4283	 4283	 4283	 0.0	 0.0	 1	 -30.0	 30.0;
	12086	 6981	 0.008469	 0.038599	 0.0	 800	 800	 800	 0.0	 0.0	 1	 -30.0	 30.0;
	12086	 9444	 0.003729	 0.012081	 0.0	 2499	 2499	 2499	 0.0	 0.0	 1	 -30.0	 30.0;
	10225	 10015	 0.071281	 0.33186	 0.0	 94	 94	 94	 0.0	 0.0	 1	 -30.0	 30.0;
	10225	 10015	 0.011919	 0.055651	 0.0	 556	 556	 556	 0.0	 0.0	 1	 -30.0	 30.0;
	10015	 13635	 0.0038	 0.01182	 0.0	 2545	 2545	 2545	 0.0	 0.0	 1	 -30.0	 30.0;
	4506	 1820	 0.00233	 0.0191	 0.0	 1642	 1642	 1642	 0.0	 0.0	 1	 -30.0	 30.0;
	4506	 9278	 0.00258	 0.02125	 0.0	 1476	 1476	 1476	 0.0	 0.0	 1	 -30.0	 30.0;
	4506	 1820	 0.00246	 0.01795	 0.0	 1744	 1744	 1744	 0.0	 0.0	 1	 -30.0	 30.0;
	4506	 13547	 0.00231	 0.02199	 0.0	 1429	 1429	 1429	 0.0	 0.0	 1	 -30.0	 30.0;
	10400	 4506	 0.00105	 0.0114	 0.0	 2760	 2760	 2760	 0.0	 0.0	 1	 -30.0	 30.0;
	4506	 148	 0.00268	 0.02035	 0.0	 1539	 1539	 1539	 0.0	 0.0	 1	 -30.0	 30.0;
	3227	 2839	 0.00124	 0.005711	 0.0	 5406	 5406	 5406	 0.0	 0.0	 1	 -30.0	 30.0;
	3227	 13598	 0.0002	 0.0022	 0.0	 14299	 14299	 14299	 0.0	 0.0	 1	 -30.0	 30.0;
	3227	 3982	 0.00019	 0.00225	 0.0	 13990	 13990	 13990	 0.0	 0.0	 1	 -30.0	 30.0;
	3227	 10055	 0.001169	 0.005159	 0.0	 5972	 5972	 5972	 0.0	 0.0	 1	 -30.0	 30.0;
	3227	 10045	 0.001271	 0.005591	 0.0	 5510	 5510	 5510	 0.0	 0.0	 1	 -30.0	 30.0;
	3227	 4841	 0.00182	 0.01218	 0.0	 2565	 2565	 2565	 0.0	 0.0	 1	 -30.0	 30.0;
	3227	 10493	 0.00107	 0.005789	 0.0	 5366	 5366	 5366	 0.0	 0.0	 1	 -30.0	 30.0;
	9468	 118	 0.00026	 0.00275	 0.0	 11436	 11436	 11436	 0.0	 0.0	 1	 -30.0	 30.0;
	9468	 1149	 0.0001	 0.00093	 0.0	 33771	 33771	 33771	 0.0	 0.0	 1	 -30.0	 30.0;
	13539	 4244	 0.00019	 0.00166	 0.0	 18906	 18906	 18906	 0.0	 0.0	 1	 -30.0	 30.0;
	13539	 4244	 0.00019	 0.00163	 0.0	 19249	 19249	 19249	 0.0	 0.0	 1	 -30.0	 30.0;
	5541	 7990	 0.00126	 0.00953	 0.0	 3286	 3286	 3286	 0.0	 0.0	 1	 -30.0	 30.0;
	5541	 11324	 0.00131	 0.00994	 0.0	 3151	 3151	 3151	 0.0	 0.0	 1	 -30.0	 30.0;
	2771	 7990	 0.00128	 0.00933	 0.0	 3355	 3355	 3355	 0.0	 0.0	 1	 -30.0	 30.0;
	2771	 13521	 0.00134	 0.00972	 0.0	 3220	 3220	 3220	 0.0	 0.0	 1	 -30.0	 30.0;
	5541	 2771	 0.001	 0.180201	 0.0	 176	 176	 176	 0.0	 0.0	 1	 -30.0	 30.0;
	5541	 11324	 1.365928	 3.472299	 0.0	 9	 9	 9	 0.0	 0.0	 1	 -30.0	 30.0;
	5541	 13521	 0.186177	 1.029224	 0.0	 31	 31	 31	 0.0	 0.0	 1	 -30.0	 30.0;
	992	 5541	 0.98608	 2.33608	 0.0	 13	 13	 13	 0.0	 0.0	 1	 -30.0	 30.0;
	5541	 11314	 0.487888	 1.618975	 0.0	 19	 19	 19	 0.0	 0.0	 1	 -30.0	 30.0;
	5541	 6768	 0.850277	 2.290235	 0.0	 13	 13	 13	 0.0	 0.0	 1	 -30.0	 30.0;
	2771	 11324	 1.29162	 3.486565	 0.0	 9	 9	 9	 0.0	 0.0	 1	 -30.0	 30.0;
	2771	 13521	 0.201801	 0.8991	 0.0	 35	 35	 35	 0.0	 0.0	 1	 -30.0	 30.0;
	992	 2771	 0.842729	 2.35651	 0.0	 13	 13	 13	 0.0	 0.0	 1	 -30.0	 30.0;
	2771	 11314	 0.415547	 1.630194	 0.0	 19	 19	 19	 0.0	 0.0	 1	 -30.0	 30.0;
	2771	 6768	 0.830956	 1.995914	 0.0	 15	 15	 15	 0.0	 0.0	 1	 -30.0	 30.0;
	700	 13243	 0.005729	 0.021281	 0.0	 1434	 1434	 1434	 0.0	 0.0	 1	 -30.0	 30.0;
	700	 13243	 0.005081	 0.029331	 0.0	 1062	 1062	 1062	 0.0	 0.0	 1	 -30.0	 30.0;
	10203	 13243	 0.00576	 0.035781	 0.0	 872	 872	 872	 0.0	 0.0	 1	 -30.0	 30.0;
	7494	 13243	 0.002021	 0.00976	 0.0	 3170	 3170	 3170	 0.0	 0.0	 1	 -30.0	 30.0;
	4593	 13243	 0.00563	 0.03313	 0.0	 940	 940	 940	 0.0	 0.0	 1	 -30.0	 30.0;
	12918	 5993	 0.001	 0.260568	 0.0	 122	 122	 122	 0.0	 0.0	 1	 -30.0	 30.0;
	10087	 12918	 0.127098	 1.298546	 0.0	 25	 25	 25	 0.0	 0.0	 1	 -30.0	 30.0;
	8361	 12918	 0.04182	 0.986219	 0.0	 32	 32	 32	 0.0	 0.0	 1	 -30.0	 30.0;
	8361	 12918	 0.00129	 0.01393	 0.0	 2258	 2258	 2258	 0.0	 0.0	 1	 -30.0	 30.0;
	3229	 12918	 0.00082	 0.00915	 0.0	 3439	 3439	 3439	 0.0	 0.0	 1	 -30.0	 30.0;
	490	 12918	 0.00119	 0.01287	 0.0	 2444	 2444	 2444	 0.0	 0.0	 1	 -30.0	 30.0;
	10087	 5993	 0.118677	 1.418975	 0.0	 23	 23	 23	 0.0	 0.0	 1	 -30.0	 30.0;
	10087	 5993	 0.00148	 0.01585	 0.0	 1985	 1985	 1985	 0.0	 0.0	 1	 -30.0	 30.0;
	8361	 5993	 0.04574	 0.913504	 0.0	 35	 35	 35	 0.0	 0.0	 1	 -30.0	 30.0;
	680	 5993	 0.00116	 0.01192	 0.0	 2638	 2638	 2638	 0.0	 0.0	 1	 -30.0	 30.0;
	10400	 1649	 0.06698	 0.909972	 0.0	 35	 35	 35	 0.0	 0.0	 1	 -30.0	 30.0;
	10400	 1649	 0.00042	 0.00331	 0.0	 9468	 9468	 9468	 0.0	 0.0	 1	 -30.0	 30.0;
	1626	 6080	 0.002591	 0.01299	 0.0	 2385	 2385	 2385	 0.0	 0.0	 1	 -30.0	 30.0;
	6080	 3278	 0.01169	 0.067849	 0.0	 459	 459	 459	 0.0	 0.0	 1	 -30.0	 30.0;
	10734	 5459	 0.00074	 0.00368	 0.0	 8416	 8416	 8416	 0.0	 0.0	 1	 -30.0	 30.0;
	10734	 239	 0.00064	 0.0042	 0.0	 7435	 7435	 7435	 0.0	 0.0	 1	 -30.0	 30.0;
	10734	 7766	 0.0018	 0.01139	 0.0	 2740	 2740	 2740	 0.0	 0.0	 1	 -30.0	 30.0;
	1195	 5459	 0.00082	 0.003401	 0.0	 9029	 9029	 9029	 0.0	 0.0	 1	 -30.0	 30.0;
	1195	 239	 0.00069	 0.00381	 0.0	 8158	 8158	 8158	 0.0	 0.0	 1	 -30.0	 30.0;
	1195	 7766	 0.00189	 0.01094	 0.0	 2846	 2846	 2846	 0.0	 0.0	 1	 -30.0	 30.0;
	5459	 7573	 0.000151	 0.000711	 0.0	 43458	 43458	 43458	 0.0	 0.0	 1	 -30.0	 30.0;
	5459	 1924	 0.00013	 0.000789	 0.0	 39503	 39503	 39503	 0.0	 0.0	 1	 -30.0	 30.0;
	5459	 10749	 5e-05	 0.00024	 0.0	 128848	 128848	 128848	 0.0	 0.0	 1	 -30.0	 30.0;
	5459	 1225	 5e-05	 0.00025	 0.0	 123896	 123896	 123896	 0.0	 0.0	 1	 -30.0	 30.0;
	12769	 5459	 0.00012	 0.000711	 0.0	 43808	 43808	 43808	 0.0	 0.0	 1	 -30.0	 30.0;
	8118	 5459	 0.00011	 0.000719	 0.0	 43428	 43428	 43428	 0.0	 0.0	 1	 -30.0	 30.0;
	959	 6104	 0.003091	 0.015719	 0.0	 1972	 1972	 1972	 0.0	 0.0	 1	 -30.0	 30.0;
	6104	 12768	 0.018159	 0.39124	 0.0	 81	 81	 81	 0.0	 0.0	 1	 -30.0	 30.0;
	6104	 9268	 0.169419	 0.883946	 0.0	 36	 36	 36	 0.0	 0.0	 1	 -30.0	 30.0;
	6104	 5095	 0.656054	 1.65126	 0.0	 18	 18	 18	 0.0	 0.0	 1	 -30.0	 30.0;
	6104	 7630	 0.452913	 1.939091	 0.0	 16	 16	 16	 0.0	 0.0	 1	 -30.0	 30.0;
	6104	 12875	 0.055969	 0.74907	 0.0	 43	 43	 43	 0.0	 0.0	 1	 -30.0	 30.0;
	5550	 6104	 0.549483	 1.897438	 0.0	 16	 16	 16	 0.0	 0.0	 1	 -30.0	 30.0;
	5687	 6104	 0.483574	 1.959731	 0.0	 16	 16	 16	 0.0	 0.0	 1	 -30.0	 30.0;
	6104	 11156	 0.279731	 1.818967	 0.0	 18	 18	 18	 0.0	 0.0	 1	 -30.0	 30.0;
	6104	 11156	 0.006521	 0.02749	 0.0	 1119	 1119	 1119	 0.0	 0.0	 1	 -30.0	 30.0;
	10904	 8870	 0.07687	 1.255956	 0.0	 26	 26	 26	 0.0	 0.0	 1	 -30.0	 30.0;
	10904	 8870	 0.00068	 0.00577	 0.0	 5437	 5437	 5437	 0.0	 0.0	 1	 -30.0	 30.0;
	6561	 10188	 0.00812	 0.12314	 0.0	 256	 256	 256	 0.0	 0.0	 1	 -30.0	 30.0;
	22	 6561	 0.00157	 0.007031	 0.0	 4385	 4385	 4385	 0.0	 0.0	 1	 -30.0	 30.0;
	5227	 6561	 0.001599	 0.00688	 0.0	 4472	 4472	 4472	 0.0	 0.0	 1	 -30.0	 30.0;
	6561	 12560	 0.00113	 0.00724	 0.0	 4311	 4311	 4311	 0.0	 0.0	 1	 -30.0	 30.0;
	6561	 12560	 0.001271	 0.007091	 0.0	 4385	 4385	 4385	 0.0	 0.0	 1	 -30.0	 30.0;
	959	 12875	 0.000919	 0.005211	 0.0	 5970	 5970	 5970	 0.0	 0.0	 1	 -30.0	 30.0;
	10914	 9245	 0.00199	 0.010219	 0.0	 3035	 3035	 3035	 0.0	 0.0	 1	 -30.0	 30.0;
	10914	 7486	 0.005409	 0.02475	 0.0	 1247	 1247	 1247	 0.0	 0.0	 1	 -30.0	 30.0;
	10914	 1136	 0.00482	 0.02805	 0.0	 1110	 1110	 1110	 0.0	 0.0	 1	 -30.0	 30.0;
	10914	 4749	 0.028479	 0.302273	 0.0	 105	 105	 105	 0.0	 0.0	 1	 -30.0	 30.0;
	10914	 9268	 0.11506	 0.606198	 0.0	 52	 52	 52	 0.0	 0.0	 1	 -30.0	 30.0;
	10914	 9245	 0.025271	 0.321983	 0.0	 98	 98	 98	 0.0	 0.0	 1	 -30.0	 30.0;
	10914	 8458	 0.00194	 0.010091	 0.0	 3074	 3074	 3074	 0.0	 0.0	 1	 -30.0	 30.0;
	10914	 4749	 0.00314	 0.019719	 0.0	 1582	 1582	 1582	 0.0	 0.0	 1	 -30.0	 30.0;
	12475	 10271	 0.00042	 0.00384	 0.0	 8178	 8178	 8178	 0.0	 0.0	 1	 -30.0	 30.0;
	12475	 1149	 0.00031	 0.00229	 0.0	 13669	 13669	 13669	 0.0	 0.0	 1	 -30.0	 30.0;
	12475	 1605	 0.00024	 0.00235	 0.0	 13372	 13372	 13372	 0.0	 0.0	 1	 -30.0	 30.0;
	12475	 2728	 0.00103	 0.01072	 0.0	 2934	 2934	 2934	 0.0	 0.0	 1	 -30.0	 30.0;
	3503	 12560	 0.00275	 0.01311	 0.0	 2359	 2359	 2359	 0.0	 0.0	 1	 -30.0	 30.0;
	3503	 4305	 0.001771	 0.01225	 0.0	 2553	 2553	 2553	 0.0	 0.0	 1	 -30.0	 30.0;
	462	 8592	 0.001	 0.385207	 0.0	 83	 83	 83	 0.0	 0.0	 1	 -30.0	 30.0;
	462	 8592	 0.003349	 0.022711	 0.0	 1376	 1376	 1376	 0.0	 0.0	 1	 -30.0	 30.0;
	462	 7521	 0.00032	 0.001531	 0.0	 20196	 20196	 20196	 0.0	 0.0	 1	 -30.0	 30.0;
	462	 8936	 0.359525	 1.472438	 0.0	 21	 21	 21	 0.0	 0.0	 1	 -30.0	 30.0;
	462	 7527	 1.632355	 4.693388	 0.0	 7	 7	 7	 0.0	 0.0	 1	 -30.0	 30.0;
	462	 11961	 0.08494	 0.651364	 0.0	 49	 49	 49	 0.0	 0.0	 1	 -30.0	 30.0;
	462	 3731	 0.052581	 0.671529	 0.0	 47	 47	 47	 0.0	 0.0	 1	 -30.0	 30.0;
	12457	 462	 0.12794	 1.157789	 0.0	 28	 28	 28	 0.0	 0.0	 1	 -30.0	 30.0;
	996	 462	 0.002461	 0.014531	 0.0	 2144	 2144	 2144	 0.0	 0.0	 1	 -30.0	 30.0;
	11205	 9944	 0.002659	 0.013271	 0.0	 2334	 2334	 2334	 0.0	 0.0	 1	 -30.0	 30.0;
	11205	 9944	 0.002711	 0.01299	 0.0	 2381	 2381	 2381	 0.0	 0.0	 1	 -30.0	 30.0;
	6855	 7527	 3.9e-05	 0.0002	 0.0	 155017	 155017	 155017	 0.0	 0.0	 1	 -30.0	 30.0;
	928	 7527	 5e-05	 0.00031	 0.0	 100595	 100595	 100595	 0.0	 0.0	 1	 -30.0	 30.0;
	5214	 10026	 0.00089	 0.00698	 0.0	 4490	 4490	 4490	 0.0	 0.0	 1	 -30.0	 30.0;
	5214	 7818	 0.00028	 0.00271	 0.0	 11595	 11595	 11595	 0.0	 0.0	 1	 -30.0	 30.0;
	2427	 4556	 0.00025	 0.00273	 0.0	 11523	 11523	 11523	 0.0	 0.0	 1	 -30.0	 30.0;
	2427	 1723	 0.00027	 0.00238	 0.0	 13188	 13188	 13188	 0.0	 0.0	 1	 -30.0	 30.0;
	2427	 7818	 0.00027	 0.00277	 0.0	 11350	 11350	 11350	 0.0	 0.0	 1	 -30.0	 30.0;
	4556	 1723	 0.00808	 0.60428	 0.0	 53	 53	 53	 0.0	 0.0	 1	 -30.0	 30.0;
	1771	 4556	 0.01086	 0.386371	 0.0	 82	 82	 82	 0.0	 0.0	 1	 -30.0	 30.0;
	4556	 7818	 0.03494	 0.767659	 0.0	 42	 42	 42	 0.0	 0.0	 1	 -30.0	 30.0;
	4556	 7012	 0.0265	 0.810665	 0.0	 39	 39	 39	 0.0	 0.0	 1	 -30.0	 30.0;
	8784	 4556	 0.524993	 2.841898	 0.0	 11	 11	 11	 0.0	 0.0	 1	 -30.0	 30.0;
	10047	 4556	 0.475568	 2.62313	 0.0	 12	 12	 12	 0.0	 0.0	 1	 -30.0	 30.0;
	12769	 239	 0.02113	 0.408595	 0.0	 78	 78	 78	 0.0	 0.0	 1	 -30.0	 30.0;
	8118	 239	 0.022469	 0.384442	 0.0	 83	 83	 83	 0.0	 0.0	 1	 -30.0	 30.0;
	13547	 2201	 0.00045	 0.0038	 0.0	 8255	 8255	 8255	 0.0	 0.0	 1	 -30.0	 30.0;
	13547	 2201	 0.00047	 0.00374	 0.0	 8380	 8380	 8380	 0.0	 0.0	 1	 -30.0	 30.0;
	12768	 11310	 0.00019	 0.00086	 0.0	 35865	 35865	 35865	 0.0	 0.0	 1	 -30.0	 30.0;
	9268	 12768	 0.542397	 1.40281	 0.0	 22	 22	 22	 0.0	 0.0	 1	 -30.0	 30.0;
	5095	 12768	 1.299236	 2.713017	 0.0	 11	 11	 11	 0.0	 0.0	 1	 -30.0	 30.0;
	12768	 7630	 1.066591	 3.481612	 0.0	 9	 9	 9	 0.0	 0.0	 1	 -30.0	 30.0;
	12768	 12875	 0.276529	 1.159153	 0.0	 27	 27	 27	 0.0	 0.0	 1	 -30.0	 30.0;
	5550	 12768	 1.192211	 3.154339	 0.0	 10	 10	 10	 0.0	 0.0	 1	 -30.0	 30.0;
	5687	 12768	 1.210785	 2.840289	 0.0	 11	 11	 11	 0.0	 0.0	 1	 -30.0	 30.0;
	11156	 12768	 0.804979	 2.837397	 0.0	 11	 11	 11	 0.0	 0.0	 1	 -30.0	 30.0;
	1246	 13179	 9.1e-05	 0.00055	 0.0	 56662	 56662	 56662	 0.0	 0.0	 1	 -30.0	 30.0;
	10093	 1246	 0.009909	 0.377748	 0.0	 84	 84	 84	 0.0	 0.0	 1	 -30.0	 30.0;
	1246	 3748	 0.914793	 3.247727	 0.0	 10	 10	 10	 0.0	 0.0	 1	 -30.0	 30.0;
	4372	 13179	 0.000349	 0.002159	 0.0	 14444	 14444	 14444	 0.0	 0.0	 1	 -30.0	 30.0;
	10093	 11310	 0.00132	 0.00624	 0.0	 4953	 4953	 4953	 0.0	 0.0	 1	 -30.0	 30.0;
	10093	 13179	 0.00088	 0.005159	 0.0	 6036	 6036	 6036	 0.0	 0.0	 1	 -30.0	 30.0;
	8454	 3748	 0.001349	 0.01051	 0.0	 2982	 2982	 2982	 0.0	 0.0	 1	 -30.0	 30.0;
	784	 2886	 0.000539	 0.003099	 0.0	 10042	 10042	 10042	 0.0	 0.0	 1	 -30.0	 30.0;
	784	 4956	 0.00207	 0.01182	 0.0	 2633	 2633	 2633	 0.0	 0.0	 1	 -30.0	 30.0;
	10188	 12560	 0.000539	 0.003159	 0.0	 9857	 9857	 9857	 0.0	 0.0	 1	 -30.0	 30.0;
	10188	 4305	 0.004081	 0.0247	 0.0	 1262	 1262	 1262	 0.0	 0.0	 1	 -30.0	 30.0;
	11136	 6099	 0.000531	 0.003521	 0.0	 8871	 8871	 8871	 0.0	 0.0	 1	 -30.0	 30.0;
	11676	 3799	 0.000539	 0.00345	 0.0	 9047	 9047	 9047	 0.0	 0.0	 1	 -30.0	 30.0;
	2365	 11676	 0.005169	 0.02325	 0.0	 1327	 1327	 1327	 0.0	 0.0	 1	 -30.0	 30.0;
	11205	 1136	 0.000669	 0.004099	 0.0	 7606	 7606	 7606	 0.0	 0.0	 1	 -30.0	 30.0;
	11205	 8603	 0.000599	 0.00344	 0.0	 9047	 9047	 9047	 0.0	 0.0	 1	 -30.0	 30.0;
	3460	 11205	 0.00139	 0.008919	 0.0	 3500	 3500	 3500	 0.0	 0.0	 1	 -30.0	 30.0;
	11205	 7486	 0.00069	 0.00419	 0.0	 7439	 7439	 7439	 0.0	 0.0	 1	 -30.0	 30.0;
	2638	 11205	 0.001539	 0.008099	 0.0	 3832	 3832	 3832	 0.0	 0.0	 1	 -30.0	 30.0;
	9268	 3870	 0.00062	 0.00356	 0.0	 8742	 8742	 8742	 0.0	 0.0	 1	 -30.0	 30.0;
	3870	 12875	 0.001091	 0.006479	 0.0	 4808	 4808	 4808	 0.0	 0.0	 1	 -30.0	 30.0;
	13249	 10728	 6e-05	 0.00052	 0.0	 60345	 60345	 60345	 0.0	 0.0	 1	 -30.0	 30.0;
	13249	 11674	 0.00023	 0.00485	 0.0	 6506	 6506	 6506	 0.0	 0.0	 1	 -30.0	 30.0;
	7818	 10728	 7e-05	 0.00051	 0.0	 61361	 61361	 61361	 0.0	 0.0	 1	 -30.0	 30.0;
	10962	 8592	 5e-05	 0.000229	 0.0	 134762	 134762	 134762	 0.0	 0.0	 1	 -30.0	 30.0;
	1865	 8592	 8.1e-05	 0.0003	 0.0	 101652	 101652	 101652	 0.0	 0.0	 1	 -30.0	 30.0;
	6021	 8592	 6e-05	 0.000341	 0.0	 91231	 91231	 91231	 0.0	 0.0	 1	 -30.0	 30.0;
	8936	 8592	 0.339112	 2.39938	 0.0	 14	 14	 14	 0.0	 0.0	 1	 -30.0	 30.0;
	7527	 8592	 0.982252	 4.492975	 0.0	 7	 7	 7	 0.0	 0.0	 1	 -30.0	 30.0;
	8592	 11961	 0.299979	 2.042583	 0.0	 16	 16	 16	 0.0	 0.0	 1	 -30.0	 30.0;
	8592	 3731	 0.216508	 1.7125	 0.0	 19	 19	 19	 0.0	 0.0	 1	 -30.0	 30.0;
	122	 8592	 0.002841	 0.01551	 0.0	 2004	 2004	 2004	 0.0	 0.0	 1	 -30.0	 30.0;
	12457	 8592	 0.00326	 1.128223	 0.0	 28	 28	 28	 0.0	 0.0	 1	 -30.0	 30.0;
	6683	 8592	 0.00232	 0.016961	 0.0	 1846	 1846	 1846	 0.0	 0.0	 1	 -30.0	 30.0;
	3153	 8592	 0.003979	 0.02513	 0.0	 1242	 1242	 1242	 0.0	 0.0	 1	 -30.0	 30.0;
	10794	 8592	 0.002281	 0.017289	 0.0	 1812	 1812	 1812	 0.0	 0.0	 1	 -30.0	 30.0;
	1771	 1723	 0.111143	 0.652313	 0.0	 48	 48	 48	 0.0	 0.0	 1	 -30.0	 30.0;
	23	 1723	 0.00045	 0.00399	 0.0	 7867	 7867	 7867	 0.0	 0.0	 1	 -30.0	 30.0;
	7818	 1723	 0.01009	 0.588213	 0.0	 54	 54	 54	 0.0	 0.0	 1	 -30.0	 30.0;
	7012	 1723	 0.0029	 0.60196	 0.0	 53	 53	 53	 0.0	 0.0	 1	 -30.0	 30.0;
	8784	 1723	 0.468573	 2.303532	 0.0	 14	 14	 14	 0.0	 0.0	 1	 -30.0	 30.0;
	10047	 1723	 0.401032	 2.262812	 0.0	 14	 14	 14	 0.0	 0.0	 1	 -30.0	 30.0;
	7818	 1723	 0.00054	 0.00451	 0.0	 6955	 6955	 6955	 0.0	 0.0	 1	 -30.0	 30.0;
	23	 1723	 0.0004	 0.00439	 0.0	 7166	 7166	 7166	 0.0	 0.0	 1	 -30.0	 30.0;
	3382	 3748	 0.00132	 0.0077	 0.0	 4044	 4044	 4044	 0.0	 0.0	 1	 -30.0	 30.0;
	3382	 12875	 0.002289	 0.013909	 0.0	 2241	 2241	 2241	 0.0	 0.0	 1	 -30.0	 30.0;
	7330	 4570	 0.00015	 0.00153	 0.0	 20547	 20547	 20547	 0.0	 0.0	 1	 -30.0	 30.0;
	7330	 9013	 0.00022	 0.00174	 0.0	 18011	 18011	 18011	 0.0	 0.0	 1	 -30.0	 30.0;
	7330	 13631	 0.00031	 0.00276	 0.0	 11374	 11374	 11374	 0.0	 0.0	 1	 -30.0	 30.0;
	10093	 3748	 0.498802	 2.231818	 0.0	 14	 14	 14	 0.0	 0.0	 1	 -30.0	 30.0;
	10093	 12875	 0.00243	 0.01461	 0.0	 2133	 2133	 2133	 0.0	 0.0	 1	 -30.0	 30.0;
	10093	 4956	 0.0013	 0.005919	 0.0	 5213	 5213	 5213	 0.0	 0.0	 1	 -30.0	 30.0;
	7527	 8936	 2.422314	 7.164876	 0.0	 5	 5	 5	 0.0	 0.0	 1	 -30.0	 30.0;
	7527	 8936	 0.005271	 0.03874	 0.0	 808	 808	 808	 0.0	 0.0	 1	 -30.0	 30.0;
	8936	 11961	 0.157781	 1.324793	 0.0	 24	 24	 24	 0.0	 0.0	 1	 -30.0	 30.0;
	8936	 11961	 0.00695	 0.055591	 0.0	 564	 564	 564	 0.0	 0.0	 1	 -30.0	 30.0;
	8936	 3731	 0.211777	 1.52969	 0.0	 21	 21	 21	 0.0	 0.0	 1	 -30.0	 30.0;
	12457	 8936	 0.1823	 1.686529	 0.0	 19	 19	 19	 0.0	 0.0	 1	 -30.0	 30.0;
	3081	 6522	 2.525346	 8.326177	 0.0	 4	 4	 4	 0.0	 0.0	 1	 -30.0	 30.0;
	3081	 6522	 0.00086	 0.00871	 0.0	 3610	 3610	 3610	 0.0	 0.0	 1	 -30.0	 30.0;
	6522	 2602	 0.13018	 1.288158	 0.0	 25	 25	 25	 0.0	 0.0	 1	 -30.0	 30.0;
	6522	 5257	 5.25734	 15.96122	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	6522	 10026	 0.196787	 1.606648	 0.0	 20	 20	 20	 0.0	 0.0	 1	 -30.0	 30.0;
	12854	 2602	 0.00124	 0.01282	 0.0	 2453	 2453	 2453	 0.0	 0.0	 1	 -30.0	 30.0;
	22	 5227	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	22	 5227	 0.227149	 1.244607	 0.0	 25	 25	 25	 0.0	 0.0	 1	 -30.0	 30.0;
	22	 2886	 0.024581	 0.402459	 0.0	 79	 79	 79	 0.0	 0.0	 1	 -30.0	 30.0;
	3881	 22	 0.04388	 0.657934	 0.0	 48	 48	 48	 0.0	 0.0	 1	 -30.0	 30.0;
	10203	 22	 0.12525	 0.756384	 0.0	 42	 42	 42	 0.0	 0.0	 1	 -30.0	 30.0;
	4593	 22	 0.18987	 0.937128	 0.0	 34	 34	 34	 0.0	 0.0	 1	 -30.0	 30.0;
	22	 12980	 0.00163	 0.007031	 0.0	 4377	 4377	 4377	 0.0	 0.0	 1	 -30.0	 30.0;
	5227	 2886	 0.456736	 1.546157	 0.0	 20	 20	 20	 0.0	 0.0	 1	 -30.0	 30.0;
	3881	 5227	 0.03062	 0.528388	 0.0	 60	 60	 60	 0.0	 0.0	 1	 -30.0	 30.0;
	10203	 5227	 0.192099	 0.773678	 0.0	 40	 40	 40	 0.0	 0.0	 1	 -30.0	 30.0;
	4593	 5227	 0.027081	 0.45345	 0.0	 70	 70	 70	 0.0	 0.0	 1	 -30.0	 30.0;
	4593	 5227	 0.002211	 0.01299	 0.0	 2398	 2398	 2398	 0.0	 0.0	 1	 -30.0	 30.0;
	2977	 8996	 0.00344	 0.015909	 0.0	 1941	 1941	 1941	 0.0	 0.0	 1	 -30.0	 30.0;
	1771	 7818	 0.123539	 0.685277	 0.0	 46	 46	 46	 0.0	 0.0	 1	 -30.0	 30.0;
	1771	 7012	 0.096593	 0.575748	 0.0	 55	 55	 55	 0.0	 0.0	 1	 -30.0	 30.0;
	1771	 8784	 0.225512	 1.104709	 0.0	 29	 29	 29	 0.0	 0.0	 1	 -30.0	 30.0;
	1771	 10047	 0.17135	 1.111427	 0.0	 29	 29	 29	 0.0	 0.0	 1	 -30.0	 30.0;
	1771	 7818	 0.00117	 0.00907	 0.0	 3454	 3454	 3454	 0.0	 0.0	 1	 -30.0	 30.0;
	5686	 2525	 3e-05	 0.00039	 0.0	 80755	 80755	 80755	 0.0	 0.0	 1	 -30.0	 30.0;
	909	 5686	 0.00079	 0.0065	 0.0	 4825	 4825	 4825	 0.0	 0.0	 1	 -30.0	 30.0;
	6916	 5686	 0.00091	 0.00755	 0.0	 4154	 4154	 4154	 0.0	 0.0	 1	 -30.0	 30.0;
	909	 5686	 0.00081	 0.00636	 0.0	 4927	 4927	 4927	 0.0	 0.0	 1	 -30.0	 30.0;
	6916	 5686	 0.00086	 0.00818	 0.0	 3841	 3841	 3841	 0.0	 0.0	 1	 -30.0	 30.0;
	3497	 7527	 0.003979	 0.02364	 0.0	 1318	 1318	 1318	 0.0	 0.0	 1	 -30.0	 30.0;
	7527	 11961	 6.941322	 16.0093	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	7527	 3731	 6.73657	 15.66095	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	12457	 7527	 0.185229	 2.220661	 0.0	 15	 15	 15	 0.0	 0.0	 1	 -30.0	 30.0;
	3081	 2602	 5.786496	 13.8054	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	3081	 5257	 0.04375	 0.648878	 0.0	 49	 49	 49	 0.0	 0.0	 1	 -30.0	 30.0;
	3081	 887	 0.0008	 0.00847	 0.0	 3713	 3713	 3713	 0.0	 0.0	 1	 -30.0	 30.0;
	3081	 10026	 0.19205	 1.80741	 0.0	 18	 18	 18	 0.0	 0.0	 1	 -30.0	 30.0;
	3081	 10026	 0.00157	 0.01084	 0.0	 2884	 2884	 2884	 0.0	 0.0	 1	 -30.0	 30.0;
	6598	 3081	 0.00155	 0.01203	 0.0	 2605	 2605	 2605	 0.0	 0.0	 1	 -30.0	 30.0;
	3081	 6051	 0.00062	 0.00656	 0.0	 4794	 4794	 4794	 0.0	 0.0	 1	 -30.0	 30.0;
	3081	 2602	 0.00203	 0.0219	 0.0	 1437	 1437	 1437	 0.0	 0.0	 1	 -30.0	 30.0;
	3081	 11534	 0.00017	 0.00135	 0.0	 23215	 23215	 23215	 0.0	 0.0	 1	 -30.0	 30.0;
	7151	 10045	 0.000341	 0.001729	 0.0	 17924	 17924	 17924	 0.0	 0.0	 1	 -30.0	 30.0;
	5095	 7151	 0.00101	 0.00926	 0.0	 3392	 3392	 3392	 0.0	 0.0	 1	 -30.0	 30.0;
	3452	 7151	 0.00055	 0.00262	 0.0	 11800	 11800	 11800	 0.0	 0.0	 1	 -30.0	 30.0;
	2839	 10045	 0.018781	 0.265517	 0.0	 119	 119	 119	 0.0	 0.0	 1	 -30.0	 30.0;
	7235	 2839	 0.0298	 0.392211	 0.0	 81	 81	 81	 0.0	 0.0	 1	 -30.0	 30.0;
	2839	 3425	 0.00057	 0.002841	 0.0	 10902	 10902	 10902	 0.0	 0.0	 1	 -30.0	 30.0;
	3452	 2839	 0.00943	 0.27814	 0.0	 114	 114	 114	 0.0	 0.0	 1	 -30.0	 30.0;
	7235	 10045	 0.027961	 0.338967	 0.0	 93	 93	 93	 0.0	 0.0	 1	 -30.0	 30.0;
	10045	 5195	 0.000581	 0.002781	 0.0	 11119	 11119	 11119	 0.0	 0.0	 1	 -30.0	 30.0;
	3452	 10045	 0.010831	 0.239876	 0.0	 132	 132	 132	 0.0	 0.0	 1	 -30.0	 30.0;
	7235	 8228	 0.00261	 0.01243	 0.0	 2487	 2487	 2487	 0.0	 0.0	 1	 -30.0	 30.0;
	3819	 9396	 0.00214	 0.01187	 0.0	 2619	 2619	 2619	 0.0	 0.0	 1	 -30.0	 30.0;
	793	 9396	 0.04931	 0.648058	 0.0	 49	 49	 49	 0.0	 0.0	 1	 -30.0	 30.0;
	793	 9396	 0.001711	 0.010781	 0.0	 2894	 2894	 2894	 0.0	 0.0	 1	 -30.0	 30.0;
	9396	 6496	 0.00068	 0.003271	 0.0	 9455	 9455	 9455	 0.0	 0.0	 1	 -30.0	 30.0;
	996	 9396	 0.07599	 0.788884	 0.0	 40	 40	 40	 0.0	 0.0	 1	 -30.0	 30.0;
	5661	 9396	 0.05989	 0.967314	 0.0	 33	 33	 33	 0.0	 0.0	 1	 -30.0	 30.0;
	10610	 9396	 0.00036	 0.002719	 0.0	 11517	 11517	 11517	 0.0	 0.0	 1	 -30.0	 30.0;
	1179	 1605	 0.00022	 0.00201	 0.0	 15622	 15622	 15622	 0.0	 0.0	 1	 -30.0	 30.0;
	8361	 1179	 0.04617	 0.493712	 0.0	 64	 64	 64	 0.0	 0.0	 1	 -30.0	 30.0;
	1179	 10846	 0.00031	 0.00302	 0.0	 10405	 10405	 10405	 0.0	 0.0	 1	 -30.0	 30.0;
	10087	 8361	 0.001	 0.254681	 0.0	 125	 125	 125	 0.0	 0.0	 1	 -30.0	 30.0;
	10087	 2728	 0.00034	 0.00288	 0.0	 10893	 10893	 10893	 0.0	 0.0	 1	 -30.0	 30.0;
	4030	 13521	 8e-05	 0.00085	 0.0	 36999	 36999	 36999	 0.0	 0.0	 1	 -30.0	 30.0;
	4030	 13521	 8e-05	 0.00087	 0.0	 36155	 36155	 36155	 0.0	 0.0	 1	 -30.0	 30.0;
	4030	 13521	 7e-05	 0.00089	 0.0	 35383	 35383	 35383	 0.0	 0.0	 1	 -30.0	 30.0;
	4735	 8996	 0.808079	 2.998967	 0.0	 11	 11	 11	 0.0	 0.0	 1	 -30.0	 30.0;
	444	 8996	 0.11606	 0.766157	 0.0	 41	 41	 41	 0.0	 0.0	 1	 -30.0	 30.0;
	6259	 8996	 0.044669	 0.42969	 0.0	 74	 74	 74	 0.0	 0.0	 1	 -30.0	 30.0;
	6259	 8996	 0.0045	 0.023841	 0.0	 1302	 1302	 1302	 0.0	 0.0	 1	 -30.0	 30.0;
	5946	 3742	 0.009969	 0.07739	 0.0	 405	 405	 405	 0.0	 0.0	 1	 -30.0	 30.0;
	7609	 5946	 0.01431	 0.10638	 0.0	 295	 295	 295	 0.0	 0.0	 1	 -30.0	 30.0;
	5946	 7456	 0.00774	 0.06957	 0.0	 452	 452	 452	 0.0	 0.0	 1	 -30.0	 30.0;
	185	 3742	 0.016669	 0.26188	 0.0	 121	 121	 121	 0.0	 0.0	 1	 -30.0	 30.0;
	13016	 3742	 0.009969	 0.061409	 0.0	 508	 508	 508	 0.0	 0.0	 1	 -30.0	 30.0;
	185	 3742	 0.001729	 0.00995	 0.0	 3128	 3128	 3128	 0.0	 0.0	 1	 -30.0	 30.0;
	1820	 8836	 0.0015	 0.01398	 0.0	 2247	 2247	 2247	 0.0	 0.0	 1	 -30.0	 30.0;
	6916	 1820	 0.00243	 0.01942	 0.0	 1614	 1614	 1614	 0.0	 0.0	 1	 -30.0	 30.0;
	12543	 6981	 0.00455	 0.02705	 0.0	 1152	 1152	 1152	 0.0	 0.0	 1	 -30.0	 30.0;
	7766	 12543	 0.004331	 0.01676	 0.0	 1825	 1825	 1825	 0.0	 0.0	 1	 -30.0	 30.0;
	12543	 2779	 0.24907	 0.891963	 0.0	 35	 35	 35	 0.0	 0.0	 1	 -30.0	 30.0;
	12543	 6981	 0.033831	 0.228099	 0.0	 137	 137	 137	 0.0	 0.0	 1	 -30.0	 30.0;
	444	 4735	 0.344318	 0.959132	 0.0	 31	 31	 31	 0.0	 0.0	 1	 -30.0	 30.0;
	4735	 6259	 0.087211	 0.561364	 0.0	 56	 56	 56	 0.0	 0.0	 1	 -30.0	 30.0;
	4735	 2128	 0.003909	 0.019531	 0.0	 1586	 1586	 1586	 0.0	 0.0	 1	 -30.0	 30.0;
	9641	 1149	 0.01509	 0.413102	 0.0	 77	 77	 77	 0.0	 0.0	 1	 -30.0	 30.0;
	9641	 2791	 9e-05	 0.001	 0.0	 31461	 31461	 31461	 0.0	 0.0	 1	 -30.0	 30.0;
	9641	 6117	 0.00094	 0.00943	 0.0	 3334	 3334	 3334	 0.0	 0.0	 1	 -30.0	 30.0;
	9641	 6597	 0.03361	 0.58162	 0.0	 55	 55	 55	 0.0	 0.0	 1	 -30.0	 30.0;
	6079	 3229	 0.0001	 0.00107	 0.0	 29393	 29393	 29393	 0.0	 0.0	 1	 -30.0	 30.0;
	6079	 148	 0.00084	 0.00882	 0.0	 3566	 3566	 3566	 0.0	 0.0	 1	 -30.0	 30.0;
	3497	 444	 0.00501	 0.021599	 0.0	 1425	 1425	 1425	 0.0	 0.0	 1	 -30.0	 30.0;
	444	 6259	 0.04149	 0.219607	 0.0	 142	 142	 142	 0.0	 0.0	 1	 -30.0	 30.0;
	444	 2536	 0.000781	 0.00744	 0.0	 4223	 4223	 4223	 0.0	 0.0	 1	 -30.0	 30.0;
	8677	 11860	 0.011789	 0.277645	 0.0	 114	 114	 114	 0.0	 0.0	 1	 -30.0	 30.0;
	8677	 11860	 0.0052	 0.02574	 0.0	 1203	 1203	 1203	 0.0	 0.0	 1	 -30.0	 30.0;
	11860	 9658	 0.031669	 0.507603	 0.0	 63	 63	 63	 0.0	 0.0	 1	 -30.0	 30.0;
	11860	 9658	 0.00438	 0.025461	 0.0	 1223	 1223	 1223	 0.0	 0.0	 1	 -30.0	 30.0;
	1626	 11860	 0.27186	 0.993388	 0.0	 31	 31	 31	 0.0	 0.0	 1	 -30.0	 30.0;
	118	 1149	 0.0037	 0.327618	 0.0	 97	 97	 97	 0.0	 0.0	 1	 -30.0	 30.0;
	1149	 6597	 0.01026	 0.269931	 0.0	 117	 117	 117	 0.0	 0.0	 1	 -30.0	 30.0;
	568	 870	 0.000281	 0.0023	 0.0	 13633	 13633	 13633	 0.0	 0.0	 1	 -30.0	 30.0;
	11136	 1431	 0.000539	 0.005021	 0.0	 6256	 6256	 6256	 0.0	 0.0	 1	 -30.0	 30.0;
	11136	 7018	 0.251054	 1.054483	 0.0	 30	 30	 30	 0.0	 0.0	 1	 -30.0	 30.0;
	9625	 11136	 0.00539	 0.022409	 0.0	 1371	 1371	 1371	 0.0	 0.0	 1	 -30.0	 30.0;
	2779	 1209	 0.18813	 0.545888	 0.0	 55	 55	 55	 0.0	 0.0	 1	 -30.0	 30.0;
	2779	 2027	 0.02382	 0.200979	 0.0	 157	 157	 157	 0.0	 0.0	 1	 -30.0	 30.0;
	2779	 2027	 0.00375	 0.019289	 0.0	 1608	 1608	 1608	 0.0	 0.0	 1	 -30.0	 30.0;
	2779	 3751	 0.003151	 0.01874	 0.0	 1663	 1663	 1663	 0.0	 0.0	 1	 -30.0	 30.0;
	2779	 6981	 0.02419	 0.20719	 0.0	 152	 152	 152	 0.0	 0.0	 1	 -30.0	 30.0;
	6965	 8677	 0.005479	 0.022531	 0.0	 1363	 1363	 1363	 0.0	 0.0	 1	 -30.0	 30.0;
	6965	 545	 0.008581	 0.133581	 0.0	 236	 236	 236	 0.0	 0.0	 1	 -30.0	 30.0;
	10229	 5661	 0.000849	 0.00436	 0.0	 7112	 7112	 7112	 0.0	 0.0	 1	 -30.0	 30.0;
	5557	 4944	 0.0004	 0.00418	 0.0	 7523	 7523	 7523	 0.0	 0.0	 1	 -30.0	 30.0;
	5557	 490	 0.00023	 0.00253	 0.0	 12434	 12434	 12434	 0.0	 0.0	 1	 -30.0	 30.0;
	7488	 3881	 0.000659	 0.006909	 0.0	 4552	 4552	 4552	 0.0	 0.0	 1	 -30.0	 30.0;
	5557	 3447	 0.14356	 0.922161	 0.0	 34	 34	 34	 0.0	 0.0	 1	 -30.0	 30.0;
	5557	 3260	 0.05061	 0.949861	 0.0	 34	 34	 34	 0.0	 0.0	 1	 -30.0	 30.0;
	3546	 10045	 0.001669	 0.19101	 0.0	 166	 166	 166	 0.0	 0.0	 1	 -30.0	 30.0;
	5710	 3546	 0.008901	 0.19594	 0.0	 162	 162	 162	 0.0	 0.0	 1	 -30.0	 30.0;
	5710	 10045	 0.008849	 0.207376	 0.0	 153	 153	 153	 0.0	 0.0	 1	 -30.0	 30.0;
	854	 3229	 0.04068	 0.314813	 0.0	 100	 100	 100	 0.0	 0.0	 1	 -30.0	 30.0;
	854	 148	 0.001	 0.358151	 0.0	 89	 89	 89	 0.0	 0.0	 1	 -30.0	 30.0;
	854	 148	 0.00029	 0.00339	 0.0	 9284	 9284	 9284	 0.0	 0.0	 1	 -30.0	 30.0;
	854	 9278	 0.001	 0.381247	 0.0	 83	 83	 83	 0.0	 0.0	 1	 -30.0	 30.0;
	5394	 1872	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	5394	 1872	 0.001	 0.261032	 0.0	 122	 122	 122	 0.0	 0.0	 1	 -30.0	 30.0;
	7216	 3421	 5e-05	 0.000409	 0.0	 76660	 76660	 76660	 0.0	 0.0	 1	 -30.0	 30.0;
	10610	 7216	 0.00036	 0.00411	 0.0	 7657	 7657	 7657	 0.0	 0.0	 1	 -30.0	 30.0;
	6637	 2431	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	6637	 2431	 0.06963	 0.647459	 0.0	 49	 49	 49	 0.0	 0.0	 1	 -30.0	 30.0;
	793	 6637	 0.00138	 0.00794	 0.0	 3920	 3920	 3920	 0.0	 0.0	 1	 -30.0	 30.0;
	996	 6637	 0.04905	 0.618285	 0.0	 51	 51	 51	 0.0	 0.0	 1	 -30.0	 30.0;
	10794	 6637	 0.01481	 0.65845	 0.0	 48	 48	 48	 0.0	 0.0	 1	 -30.0	 30.0;
	6683	 6637	 0.057229	 0.834525	 0.0	 38	 38	 38	 0.0	 0.0	 1	 -30.0	 30.0;
	122	 2431	 0.00276	 0.034271	 0.0	 919	 919	 919	 0.0	 0.0	 1	 -30.0	 30.0;
	996	 2431	 0.045901	 0.629938	 0.0	 51	 51	 51	 0.0	 0.0	 1	 -30.0	 30.0;
	10794	 2431	 0.05236	 0.804298	 0.0	 40	 40	 40	 0.0	 0.0	 1	 -30.0	 30.0;
	6683	 2431	 0.010979	 0.705971	 0.0	 45	 45	 45	 0.0	 0.0	 1	 -30.0	 30.0;
	5394	 3229	 0.00111	 0.00985	 0.0	 3187	 3187	 3187	 0.0	 0.0	 1	 -30.0	 30.0;
	5257	 2602	 12.66967	 25.61427	 0.0	 2	 2	 2	 0.0	 0.0	 1	 -30.0	 30.0;
	2602	 10026	 0.7509	 2.64626	 0.0	 12	 12	 12	 0.0	 0.0	 1	 -30.0	 30.0;
	11961	 3731	 0.001	 0.522603	 0.0	 61	 61	 61	 0.0	 0.0	 1	 -30.0	 30.0;
	11961	 3731	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	12457	 11961	 1.015517	 3.518182	 0.0	 9	 9	 9	 0.0	 0.0	 1	 -30.0	 30.0;
	5661	 11961	 0.00274	 0.01674	 0.0	 1863	 1863	 1863	 0.0	 0.0	 1	 -30.0	 30.0;
	13280	 11961	 0.001031	 0.006669	 0.0	 4681	 4681	 4681	 0.0	 0.0	 1	 -30.0	 30.0;
	12457	 3731	 0.827397	 3.941942	 0.0	 8	 8	 8	 0.0	 0.0	 1	 -30.0	 30.0;
	5364	 2602	 0.00018	 0.00147	 0.0	 21329	 21329	 21329	 0.0	 0.0	 1	 -30.0	 30.0;
	7756	 2602	 0.00025	 0.00253	 0.0	 12425	 12425	 12425	 0.0	 0.0	 1	 -30.0	 30.0;
	5562	 2602	 0.00045	 0.00372	 0.0	 8430	 8430	 8430	 0.0	 0.0	 1	 -30.0	 30.0;
	1609	 2602	 0.00019	 0.00142	 0.0	 22049	 22049	 22049	 0.0	 0.0	 1	 -30.0	 30.0;
	8890	 2602	 0.00017	 0.00161	 0.0	 19511	 19511	 19511	 0.0	 0.0	 1	 -30.0	 30.0;
	6776	 2536	 0.00031	 0.00387	 0.0	 8137	 8137	 8137	 0.0	 0.0	 1	 -30.0	 30.0;
	9268	 10850	 0.00057	 0.00261	 0.0	 11824	 11824	 11824	 0.0	 0.0	 1	 -30.0	 30.0;
	9268	 2718	 0.000591	 0.002591	 0.0	 11886	 11886	 11886	 0.0	 0.0	 1	 -30.0	 30.0;
	3819	 996	 0.001599	 0.00775	 0.0	 3992	 3992	 3992	 0.0	 0.0	 1	 -30.0	 30.0;
	793	 996	 0.014031	 0.614215	 0.0	 52	 52	 52	 0.0	 0.0	 1	 -30.0	 30.0;
	793	 5661	 0.012341	 0.556384	 0.0	 57	 57	 57	 0.0	 0.0	 1	 -30.0	 30.0;
	793	 5661	 0.001599	 0.00738	 0.0	 4184	 4184	 4184	 0.0	 0.0	 1	 -30.0	 30.0;
	12850	 2525	 0.077687	 1.036288	 0.0	 31	 31	 31	 0.0	 0.0	 1	 -30.0	 30.0;
	12850	 909	 0.00057	 0.00542	 0.0	 5796	 5796	 5796	 0.0	 0.0	 1	 -30.0	 30.0;
	12850	 909	 0.001	 0.513781	 0.0	 62	 62	 62	 0.0	 0.0	 1	 -30.0	 30.0;
	12850	 2114	 0.01036	 0.396828	 0.0	 80	 80	 80	 0.0	 0.0	 1	 -30.0	 30.0;
	12850	 2114	 0.00067	 0.00594	 0.0	 5285	 5285	 5285	 0.0	 0.0	 1	 -30.0	 30.0;
	12850	 6916	 0.897853	 2.161981	 0.0	 14	 14	 14	 0.0	 0.0	 1	 -30.0	 30.0;
	2114	 6268	 0.0015	 0.01442	 0.0	 2179	 2179	 2179	 0.0	 0.0	 1	 -30.0	 30.0;
	6916	 6268	 0.00139	 0.01387	 0.0	 2267	 2267	 2267	 0.0	 0.0	 1	 -30.0	 30.0;
	909	 2525	 0.001	 0.795637	 0.0	 40	 40	 40	 0.0	 0.0	 1	 -30.0	 30.0;
	2114	 2525	 0.230298	 1.27597	 0.0	 25	 25	 25	 0.0	 0.0	 1	 -30.0	 30.0;
	6916	 2525	 0.05565	 0.673331	 0.0	 47	 47	 47	 0.0	 0.0	 1	 -30.0	 30.0;
	13539	 23	 0.00019	 0.00214	 0.0	 14703	 14703	 14703	 0.0	 0.0	 1	 -30.0	 30.0;
	13539	 23	 0.00019	 0.00198	 0.0	 15881	 15881	 15881	 0.0	 0.0	 1	 -30.0	 30.0;
	7818	 7012	 0.07358	 0.966343	 0.0	 33	 33	 33	 0.0	 0.0	 1	 -30.0	 30.0;
	8784	 7818	 0.06384	 1.43054	 0.0	 23	 23	 23	 0.0	 0.0	 1	 -30.0	 30.0;
	10047	 7818	 0.076281	 1.166136	 0.0	 28	 28	 28	 0.0	 0.0	 1	 -30.0	 30.0;
	8784	 7012	 0.210457	 1.788158	 0.0	 18	 18	 18	 0.0	 0.0	 1	 -30.0	 30.0;
	10047	 7012	 0.185533	 1.718213	 0.0	 19	 19	 19	 0.0	 0.0	 1	 -30.0	 30.0;
	7818	 7012	 2e-05	 0.00024	 0.0	 131160	 131160	 131160	 0.0	 0.0	 1	 -30.0	 30.0;
	490	 5784	 0.01408	 0.37133	 0.0	 86	 86	 86	 0.0	 0.0	 1	 -30.0	 30.0;
	680	 5784	 0.01647	 0.363712	 0.0	 87	 87	 87	 0.0	 0.0	 1	 -30.0	 30.0;
	680	 5784	 0.00068	 0.00621	 0.0	 5057	 5057	 5057	 0.0	 0.0	 1	 -30.0	 30.0;
	5784	 148	 0.00079	 0.00807	 0.0	 3896	 3896	 3896	 0.0	 0.0	 1	 -30.0	 30.0;
	2728	 8361	 0.00052	 0.00514	 0.0	 6115	 6115	 6115	 0.0	 0.0	 1	 -30.0	 30.0;
	148	 3229	 0.111198	 0.57367	 0.0	 55	 55	 55	 0.0	 0.0	 1	 -30.0	 30.0;
	9278	 3229	 0.126101	 0.495623	 0.0	 62	 62	 62	 0.0	 0.0	 1	 -30.0	 30.0;
	6259	 2128	 0.0032	 0.016281	 0.0	 1904	 1904	 1904	 0.0	 0.0	 1	 -30.0	 30.0;
	6259	 2128	 0.003659	 0.01407	 0.0	 2173	 2173	 2173	 0.0	 0.0	 1	 -30.0	 30.0;
	6259	 2536	 0.002281	 0.010039	 0.0	 3069	 3069	 3069	 0.0	 0.0	 1	 -30.0	 30.0;
	6259	 2536	 0.001919	 0.011669	 0.0	 2672	 2672	 2672	 0.0	 0.0	 1	 -30.0	 30.0;
	1431	 7018	 0.00236	 0.02263	 0.0	 1389	 1389	 1389	 0.0	 0.0	 1	 -30.0	 30.0;
	568	 1431	 0.009849	 0.054531	 0.0	 571	 571	 571	 0.0	 0.0	 1	 -30.0	 30.0;
	2027	 1209	 0.02949	 0.13405	 0.0	 231	 231	 231	 0.0	 0.0	 1	 -30.0	 30.0;
	2027	 1209	 0.005021	 0.030341	 0.0	 1028	 1028	 1028	 0.0	 0.0	 1	 -30.0	 30.0;
	5257	 11534	 0.00076	 0.00675	 0.0	 4651	 4651	 4651	 0.0	 0.0	 1	 -30.0	 30.0;
	5257	 10026	 0.568047	 3.572576	 0.0	 9	 9	 9	 0.0	 0.0	 1	 -30.0	 30.0;
	2778	 6496	 0.003419	 0.014531	 0.0	 2117	 2117	 2117	 0.0	 0.0	 1	 -30.0	 30.0;
	2886	 2778	 0.002979	 0.016461	 0.0	 1889	 1889	 1889	 0.0	 0.0	 1	 -30.0	 30.0;
	9268	 4749	 0.09382	 0.44438	 0.0	 70	 70	 70	 0.0	 0.0	 1	 -30.0	 30.0;
	11208	 4749	 0.003789	 0.02306	 0.0	 1352	 1352	 1352	 0.0	 0.0	 1	 -30.0	 30.0;
	3897	 5562	 0.00014	 0.00108	 0.0	 29005	 29005	 29005	 0.0	 0.0	 1	 -30.0	 30.0;
	3897	 13539	 0.00015	 0.00119	 0.0	 26336	 26336	 26336	 0.0	 0.0	 1	 -30.0	 30.0;
	2791	 13539	 0.00031	 0.00232	 0.0	 13496	 13496	 13496	 0.0	 0.0	 1	 -30.0	 30.0;
	2556	 2791	 0.00025	 0.00193	 0.0	 16231	 16231	 16231	 0.0	 0.0	 1	 -30.0	 30.0;
	13539	 11674	 0.137791	 1.05367	 0.0	 30	 30	 30	 0.0	 0.0	 1	 -30.0	 30.0;
	13539	 10846	 0.00054	 0.00395	 0.0	 7924	 7924	 7924	 0.0	 0.0	 1	 -30.0	 30.0;
	8044	 3881	 0.00113	 0.012581	 0.0	 2501	 2501	 2501	 0.0	 0.0	 1	 -30.0	 30.0;
	8044	 568	 0.00238	 0.02086	 0.0	 1505	 1505	 1505	 0.0	 0.0	 1	 -30.0	 30.0;
	8044	 10203	 0.127331	 1.369545	 0.0	 23	 23	 23	 0.0	 0.0	 1	 -30.0	 30.0;
	8044	 3171	 0.699669	 2.452893	 0.0	 13	 13	 13	 0.0	 0.0	 1	 -30.0	 30.0;
	13339	 9658	 0.00331	 0.025159	 0.0	 1245	 1245	 1245	 0.0	 0.0	 1	 -30.0	 30.0;
	909	 2114	 0.01975	 0.825554	 0.0	 39	 39	 39	 0.0	 0.0	 1	 -30.0	 30.0;
	6916	 909	 0.507639	 2.270152	 0.0	 14	 14	 14	 0.0	 0.0	 1	 -30.0	 30.0;
	8677	 9658	 0.20336	 0.874897	 0.0	 36	 36	 36	 0.0	 0.0	 1	 -30.0	 30.0;
	8677	 545	 0.00732	 0.030659	 0.0	 1003	 1003	 1003	 0.0	 0.0	 1	 -30.0	 30.0;
	1626	 8677	 0.075401	 0.292748	 0.0	 105	 105	 105	 0.0	 0.0	 1	 -30.0	 30.0;
	1626	 8677	 0.00314	 0.02136	 0.0	 1464	 1464	 1464	 0.0	 0.0	 1	 -30.0	 30.0;
	13547	 10196	 0.00044	 0.00325	 0.0	 9632	 9632	 9632	 0.0	 0.0	 1	 -30.0	 30.0;
	73	 3452	 0.00076	 0.00364	 0.0	 8495	 8495	 8495	 0.0	 0.0	 1	 -30.0	 30.0;
	73	 8685	 0.00075	 0.00474	 0.0	 6583	 6583	 6583	 0.0	 0.0	 1	 -30.0	 30.0;
	9268	 5095	 3.557851	 5.439876	 0.0	 5	 5	 5	 0.0	 0.0	 1	 -30.0	 30.0;
	9268	 7630	 4.011157	 6.327273	 0.0	 5	 5	 5	 0.0	 0.0	 1	 -30.0	 30.0;
	9268	 12875	 0.006	 0.327025	 0.0	 97	 97	 97	 0.0	 0.0	 1	 -30.0	 30.0;
	5550	 9268	 3.78905	 6.419628	 0.0	 5	 5	 5	 0.0	 0.0	 1	 -30.0	 30.0;
	5687	 9268	 3.833471	 5.760331	 0.0	 5	 5	 5	 0.0	 0.0	 1	 -30.0	 30.0;
	5710	 9268	 0.000841	 0.00362	 0.0	 8500	 8500	 8500	 0.0	 0.0	 1	 -30.0	 30.0;
	9268	 2854	 0.03	 0.279855	 0.0	 113	 113	 113	 0.0	 0.0	 1	 -30.0	 30.0;
	9268	 2854	 0.00107	 0.004849	 0.0	 6362	 6362	 6362	 0.0	 0.0	 1	 -30.0	 30.0;
	9268	 11156	 3.092975	 5.176033	 0.0	 6	 6	 6	 0.0	 0.0	 1	 -30.0	 30.0;
	9268	 11156	 0.02688	 0.291116	 0.0	 109	 109	 109	 0.0	 0.0	 1	 -30.0	 30.0;
	9268	 11156	 0.00188	 0.0132	 0.0	 2370	 2370	 2370	 0.0	 0.0	 1	 -30.0	 30.0;
	9571	 2027	 0.001469	 0.00724	 0.0	 4276	 4276	 4276	 0.0	 0.0	 1	 -30.0	 30.0;
	9571	 2027	 0.0015	 0.007081	 0.0	 4365	 4365	 4365	 0.0	 0.0	 1	 -30.0	 30.0;
	4956	 7069	 0.0017	 0.00806	 0.0	 3835	 3835	 3835	 0.0	 0.0	 1	 -30.0	 30.0;
	2886	 3744	 0.00369	 0.016091	 0.0	 1914	 1914	 1914	 0.0	 0.0	 1	 -30.0	 30.0;
	12560	 10354	 0.00301	 0.0177	 0.0	 1760	 1760	 1760	 0.0	 0.0	 1	 -30.0	 30.0;
	9013	 6971	 5e-05	 0.00053	 0.0	 59336	 59336	 59336	 0.0	 0.0	 1	 -30.0	 30.0;
	4944	 5773	 6e-05	 0.0005	 0.0	 62725	 62725	 62725	 0.0	 0.0	 1	 -30.0	 30.0;
	4944	 8353	 4e-05	 0.00047	 0.0	 66966	 66966	 66966	 0.0	 0.0	 1	 -30.0	 30.0;
	12875	 238	 0.00174	 0.016521	 0.0	 1902	 1902	 1902	 0.0	 0.0	 1	 -30.0	 30.0;
	12000	 8077	 0.00019	 0.00196	 0.0	 16041	 16041	 16041	 0.0	 0.0	 1	 -30.0	 30.0;
	2728	 9397	 0.00074	 0.00584	 0.0	 5366	 5366	 5366	 0.0	 0.0	 1	 -30.0	 30.0;
	12000	 2453	 0.00019	 0.00183	 0.0	 17169	 17169	 17169	 0.0	 0.0	 1	 -30.0	 30.0;
	9013	 3732	 0.00018	 0.00186	 0.0	 16904	 16904	 16904	 0.0	 0.0	 1	 -30.0	 30.0;
	8784	 10047	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	8784	 10047	 0.001	 0.413968	 0.0	 77	 77	 77	 0.0	 0.0	 1	 -30.0	 30.0;
	8784	 7818	 0.00215	 0.02177	 0.0	 1444	 1444	 1444	 0.0	 0.0	 1	 -30.0	 30.0;
	10225	 6981	 0.008659	 0.0422	 0.0	 734	 734	 734	 0.0	 0.0	 1	 -30.0	 30.0;
	118	 7121	 0.00029	 0.00252	 0.0	 12453	 12453	 12453	 0.0	 0.0	 1	 -30.0	 30.0;
	118	 6597	 0.0343	 0.612763	 0.0	 52	 52	 52	 0.0	 0.0	 1	 -30.0	 30.0;
	3748	 4305	 0.00036	 0.00195	 0.0	 15930	 15930	 15930	 0.0	 0.0	 1	 -30.0	 30.0;
	3748	 4305	 0.000409	 0.00213	 0.0	 14564	 14564	 14564	 0.0	 0.0	 1	 -30.0	 30.0;
	7235	 3985	 0.00118	 0.008719	 0.0	 3591	 3591	 3591	 0.0	 0.0	 1	 -30.0	 30.0;
	5550	 7235	 0.0053	 0.023409	 0.0	 1317	 1317	 1317	 0.0	 0.0	 1	 -30.0	 30.0;
	5687	 7235	 0.005401	 0.022909	 0.0	 1343	 1343	 1343	 0.0	 0.0	 1	 -30.0	 30.0;
	8685	 7235	 0.000901	 0.00412	 0.0	 7490	 7490	 7490	 0.0	 0.0	 1	 -30.0	 30.0;
	7235	 3452	 0.05139	 0.435785	 0.0	 72	 72	 72	 0.0	 0.0	 1	 -30.0	 30.0;
	5095	 7630	 0.01661	 0.339194	 0.0	 94	 94	 94	 0.0	 0.0	 1	 -30.0	 30.0;
	5095	 12875	 2.441736	 4.517975	 0.0	 7	 7	 7	 0.0	 0.0	 1	 -30.0	 30.0;
	5550	 5095	 0.03336	 0.374174	 0.0	 85	 85	 85	 0.0	 0.0	 1	 -30.0	 30.0;
	5687	 5095	 0.033219	 0.37814	 0.0	 84	 84	 84	 0.0	 0.0	 1	 -30.0	 30.0;
	5095	 6591	 0.003151	 0.017599	 0.0	 1767	 1767	 1767	 0.0	 0.0	 1	 -30.0	 30.0;
	11156	 5095	 0.02231	 0.393079	 0.0	 81	 81	 81	 0.0	 0.0	 1	 -30.0	 30.0;
	9487	 5364	 0.0005	 0.00519	 0.0	 6059	 6059	 6059	 0.0	 0.0	 1	 -30.0	 30.0;
	9487	 12671	 0.00024	 0.00227	 0.0	 13839	 13839	 13839	 0.0	 0.0	 1	 -30.0	 30.0;
	9487	 7121	 0.00049	 0.00529	 0.0	 5946	 5946	 5946	 0.0	 0.0	 1	 -30.0	 30.0;
	9487	 7869	 0.00036	 0.00305	 0.0	 10286	 10286	 10286	 0.0	 0.0	 1	 -30.0	 30.0;
	6824	 8260	 0.00264	 0.014781	 0.0	 2104	 2104	 2104	 0.0	 0.0	 1	 -30.0	 30.0;
	10082	 8260	 0.002539	 0.01357	 0.0	 2289	 2289	 2289	 0.0	 0.0	 1	 -30.0	 30.0;
	3171	 8260	 0.0053	 0.021599	 0.0	 1421	 1421	 1421	 0.0	 0.0	 1	 -30.0	 30.0;
	9726	 8260	 0.003091	 0.01568	 0.0	 1977	 1977	 1977	 0.0	 0.0	 1	 -30.0	 30.0;
	13614	 8260	 0.00274	 0.0127	 0.0	 2432	 2432	 2432	 0.0	 0.0	 1	 -30.0	 30.0;
	3171	 8260	 0.04224	 0.3325	 0.0	 95	 95	 95	 0.0	 0.0	 1	 -30.0	 30.0;
	8616	 7990	 0.00086	 0.00873	 0.0	 3601	 3601	 3601	 0.0	 0.0	 1	 -30.0	 30.0;
	13547	 7990	 0.00206	 0.01561	 0.0	 2007	 2007	 2007	 0.0	 0.0	 1	 -30.0	 30.0;
	5413	 13521	 0.00032	 0.00271	 0.0	 11576	 11576	 11576	 0.0	 0.0	 1	 -30.0	 30.0;
	680	 5413	 0.00051	 0.00524	 0.0	 6000	 6000	 6000	 0.0	 0.0	 1	 -30.0	 30.0;
	379	 11324	 0.00032	 0.00265	 0.0	 11834	 11834	 11834	 0.0	 0.0	 1	 -30.0	 30.0;
	490	 379	 0.0005	 0.00534	 0.0	 5890	 5890	 5890	 0.0	 0.0	 1	 -30.0	 30.0;
	11324	 13521	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	11324	 13521	 0.163629	 1.021814	 0.0	 31	 31	 31	 0.0	 0.0	 1	 -30.0	 30.0;
	992	 11324	 0.001	 0.350312	 0.0	 91	 91	 91	 0.0	 0.0	 1	 -30.0	 30.0;
	11314	 11324	 0.0571	 0.699515	 0.0	 46	 46	 46	 0.0	 0.0	 1	 -30.0	 30.0;
	5515	 11324	 0.00022	 0.00214	 0.0	 14684	 14684	 14684	 0.0	 0.0	 1	 -30.0	 30.0;
	6768	 11324	 0.05584	 0.597071	 0.0	 53	 53	 53	 0.0	 0.0	 1	 -30.0	 30.0;
	3260	 13521	 0.00044	 0.00329	 0.0	 9517	 9517	 9517	 0.0	 0.0	 1	 -30.0	 30.0;
	992	 13521	 0.0684	 0.765166	 0.0	 42	 42	 42	 0.0	 0.0	 1	 -30.0	 30.0;
	992	 13521	 0.0005	 0.00377	 0.0	 8306	 8306	 8306	 0.0	 0.0	 1	 -30.0	 30.0;
	11314	 13521	 0.02916	 0.635783	 0.0	 50	 50	 50	 0.0	 0.0	 1	 -30.0	 30.0;
	7161	 13521	 0.00021	 0.00218	 0.0	 14423	 14423	 14423	 0.0	 0.0	 1	 -30.0	 30.0;
	6768	 13521	 0.076648	 0.893421	 0.0	 36	 36	 36	 0.0	 0.0	 1	 -30.0	 30.0;
	9978	 11546	 0.003581	 0.01713	 0.0	 1805	 1805	 1805	 0.0	 0.0	 1	 -30.0	 30.0;
	3460	 176	 0.003651	 0.01676	 0.0	 1842	 1842	 1842	 0.0	 0.0	 1	 -30.0	 30.0;
	6117	 8691	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	6117	 8691	 0.001	 0.363179	 0.0	 87	 87	 87	 0.0	 0.0	 1	 -30.0	 30.0;
	6117	 2728	 0.03201	 0.610942	 0.0	 52	 52	 52	 0.0	 0.0	 1	 -30.0	 30.0;
	8691	 2728	 0.03493	 0.703809	 0.0	 45	 45	 45	 0.0	 0.0	 1	 -30.0	 30.0;
	8691	 4570	 0.00038	 0.00378	 0.0	 8315	 8315	 8315	 0.0	 0.0	 1	 -30.0	 30.0;
	1626	 9658	 0.662562	 1.966736	 0.0	 16	 16	 16	 0.0	 0.0	 1	 -30.0	 30.0;
	1626	 9658	 0.007461	 0.03539	 0.0	 874	 874	 874	 0.0	 0.0	 1	 -30.0	 30.0;
	6916	 2114	 1.057548	 2.384834	 0.0	 13	 13	 13	 0.0	 0.0	 1	 -30.0	 30.0;
	2886	 11546	 0.00313	 0.015591	 0.0	 1987	 1987	 1987	 0.0	 0.0	 1	 -30.0	 30.0;
	2886	 176	 0.00325	 0.01495	 0.0	 2065	 2065	 2065	 0.0	 0.0	 1	 -30.0	 30.0;
	3881	 2886	 0.174211	 0.885269	 0.0	 36	 36	 36	 0.0	 0.0	 1	 -30.0	 30.0;
	10203	 2886	 0.05432	 0.507293	 0.0	 62	 62	 62	 0.0	 0.0	 1	 -30.0	 30.0;
	4593	 2886	 0.315744	 1.143306	 0.0	 27	 27	 27	 0.0	 0.0	 1	 -30.0	 30.0;
	11208	 12560	 0.106531	 0.728988	 0.0	 43	 43	 43	 0.0	 0.0	 1	 -30.0	 30.0;
	4944	 2728	 0.00046	 0.00355	 0.0	 8825	 8825	 8825	 0.0	 0.0	 1	 -30.0	 30.0;
	9013	 2728	 0.00046	 0.00356	 0.0	 8800	 8800	 8800	 0.0	 0.0	 1	 -30.0	 30.0;
	3985	 7630	 0.00056	 0.00351	 0.0	 8887	 8887	 8887	 0.0	 0.0	 1	 -30.0	 30.0;
	11156	 3985	 0.001271	 0.00699	 0.0	 4447	 4447	 4447	 0.0	 0.0	 1	 -30.0	 30.0;
	7630	 12875	 2.229752	 5.528926	 0.0	 6	 6	 6	 0.0	 0.0	 1	 -30.0	 30.0;
	5550	 7630	 0.186169	 1.134959	 0.0	 28	 28	 28	 0.0	 0.0	 1	 -30.0	 30.0;
	5687	 7630	 0.191419	 0.99374	 0.0	 32	 32	 32	 0.0	 0.0	 1	 -30.0	 30.0;
	11156	 7630	 0.001	 0.342025	 0.0	 93	 93	 93	 0.0	 0.0	 1	 -30.0	 30.0;
	13631	 8870	 8e-05	 0.00071	 0.0	 44210	 44210	 44210	 0.0	 0.0	 1	 -30.0	 30.0;
	12000	 8870	 0.00047	 0.00487	 0.0	 6457	 6457	 6457	 0.0	 0.0	 1	 -30.0	 30.0;
	5550	 12875	 2.630992	 4.595455	 0.0	 6	 6	 6	 0.0	 0.0	 1	 -30.0	 30.0;
	5687	 12875	 2.602893	 4.194835	 0.0	 7	 7	 7	 0.0	 0.0	 1	 -30.0	 30.0;
	5710	 12875	 0.002849	 0.0122	 0.0	 2522	 2522	 2522	 0.0	 0.0	 1	 -30.0	 30.0;
	11156	 12875	 1.630455	 4.689463	 0.0	 7	 7	 7	 0.0	 0.0	 1	 -30.0	 30.0;
	4570	 8870	 0.136641	 1.051662	 0.0	 30	 30	 30	 0.0	 0.0	 1	 -30.0	 30.0;
	979	 8870	 0.00035	 0.00282	 0.0	 11116	 11116	 11116	 0.0	 0.0	 1	 -30.0	 30.0;
	8616	 13547	 0.00092	 0.0092	 0.0	 3417	 3417	 3417	 0.0	 0.0	 1	 -30.0	 30.0;
	3447	 3260	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	3447	 3260	 0.02074	 0.459238	 0.0	 69	 69	 69	 0.0	 0.0	 1	 -30.0	 30.0;
	3447	 12000	 0.00025	 0.00224	 0.0	 14015	 14015	 14015	 0.0	 0.0	 1	 -30.0	 30.0;
	11208	 4305	 0.000651	 0.0037	 0.0	 8408	 8408	 8408	 0.0	 0.0	 1	 -30.0	 30.0;
	5550	 5687	 0.001	 0.238182	 0.0	 133	 133	 133	 0.0	 0.0	 1	 -30.0	 30.0;
	5550	 11156	 0.168469	 0.943719	 0.0	 33	 33	 33	 0.0	 0.0	 1	 -30.0	 30.0;
	5687	 11156	 0.1577	 0.919711	 0.0	 34	 34	 34	 0.0	 0.0	 1	 -30.0	 30.0;
	9444	 7018	 0.0033	 0.023531	 0.0	 1330	 1330	 1330	 0.0	 0.0	 1	 -30.0	 30.0;
	13635	 7018	 0.00336	 0.023031	 0.0	 1358	 1358	 1358	 0.0	 0.0	 1	 -30.0	 30.0;
	13016	 7018	 0.050961	 0.353843	 0.0	 89	 89	 89	 0.0	 0.0	 1	 -30.0	 30.0;
	2365	 7018	 0.07906	 0.386591	 0.0	 81	 81	 81	 0.0	 0.0	 1	 -30.0	 30.0;
	2365	 7018	 0.00224	 0.02005	 0.0	 1566	 1566	 1566	 0.0	 0.0	 1	 -30.0	 30.0;
	9625	 7018	 0.001979	 0.018841	 0.0	 1668	 1668	 1668	 0.0	 0.0	 1	 -30.0	 30.0;
	4841	 31	 0.0003	 0.002669	 0.0	 11761	 11761	 11761	 0.0	 0.0	 1	 -30.0	 30.0;
	2602	 2556	 0.00017	 0.00166	 0.0	 18930	 18930	 18930	 0.0	 0.0	 1	 -30.0	 30.0;
	1609	 6597	 0.00057	 0.00619	 0.0	 5082	 5082	 5082	 0.0	 0.0	 1	 -30.0	 30.0;
	8890	 9108	 8e-05	 0.00082	 0.0	 38340	 38340	 38340	 0.0	 0.0	 1	 -30.0	 30.0;
	996	 5661	 0.001	 0.452087	 0.0	 70	 70	 70	 0.0	 0.0	 1	 -30.0	 30.0;
	996	 10794	 0.028289	 0.776901	 0.0	 41	 41	 41	 0.0	 0.0	 1	 -30.0	 30.0;
	996	 6683	 0.027469	 0.75064	 0.0	 43	 43	 43	 0.0	 0.0	 1	 -30.0	 30.0;
	5661	 3153	 0.001409	 0.00714	 0.0	 4341	 4341	 4341	 0.0	 0.0	 1	 -30.0	 30.0;
	7766	 9726	 0.00776	 0.04488	 0.0	 694	 694	 694	 0.0	 0.0	 1	 -30.0	 30.0;
	979	 3566	 0.00028	 0.0023	 0.0	 13633	 13633	 13633	 0.0	 0.0	 1	 -30.0	 30.0;
	4685	 979	 0.00015	 0.00155	 0.0	 20285	 20285	 20285	 0.0	 0.0	 1	 -30.0	 30.0;
	6683	 772	 0.000229	 0.00113	 0.0	 27397	 27397	 27397	 0.0	 0.0	 1	 -30.0	 30.0;
	10794	 4895	 0.00024	 0.001099	 0.0	 28081	 28081	 28081	 0.0	 0.0	 1	 -30.0	 30.0;
	9444	 13016	 0.000651	 0.005031	 0.0	 6227	 6227	 6227	 0.0	 0.0	 1	 -30.0	 30.0;
	13635	 13016	 0.000581	 0.0057	 0.0	 5514	 5514	 5514	 0.0	 0.0	 1	 -30.0	 30.0;
	2365	 13016	 0.395351	 1.062603	 0.0	 28	 28	 28	 0.0	 0.0	 1	 -30.0	 30.0;
	680	 12000	 0.00073	 0.00574	 0.0	 5460	 5460	 5460	 0.0	 0.0	 1	 -30.0	 30.0;
	8305	 9013	 0.00074	 0.00562	 0.0	 5573	 5573	 5573	 0.0	 0.0	 1	 -30.0	 30.0;
	1149	 6597	 0.00021	 0.00217	 0.0	 14489	 14489	 14489	 0.0	 0.0	 1	 -30.0	 30.0;
	12769	 8118	 0.001	 0.253636	 0.0	 125	 125	 125	 0.0	 0.0	 1	 -30.0	 30.0;
	11436	 4685	 0.00078	 0.00691	 0.0	 4543	 4543	 4543	 0.0	 0.0	 1	 -30.0	 30.0;
	8305	 9278	 0.00135	 0.01007	 0.0	 3109	 3109	 3109	 0.0	 0.0	 1	 -30.0	 30.0;
	3881	 10203	 0.048271	 0.517335	 0.0	 61	 61	 61	 0.0	 0.0	 1	 -30.0	 30.0;
	3881	 10203	 0.001901	 0.01187	 0.0	 2628	 2628	 2628	 0.0	 0.0	 1	 -30.0	 30.0;
	3881	 4593	 0.02499	 0.413099	 0.0	 77	 77	 77	 0.0	 0.0	 1	 -30.0	 30.0;
	3881	 4593	 0.00186	 0.01099	 0.0	 2834	 2834	 2834	 0.0	 0.0	 1	 -30.0	 30.0;
	490	 680	 0.00351	 0.296032	 0.0	 107	 107	 107	 0.0	 0.0	 1	 -30.0	 30.0;
	3425	 13449	 0.000169	 0.000789	 0.0	 39147	 39147	 39147	 0.0	 0.0	 1	 -30.0	 30.0;
	3452	 3425	 0.000211	 0.001031	 0.0	 30016	 30016	 30016	 0.0	 0.0	 1	 -30.0	 30.0;
	5195	 9736	 0.00038	 0.001909	 0.0	 16229	 16229	 16229	 0.0	 0.0	 1	 -30.0	 30.0;
	3452	 5195	 0.000219	 0.001	 0.0	 30857	 30857	 30857	 0.0	 0.0	 1	 -30.0	 30.0;
	992	 11314	 0.0114	 0.491198	 0.0	 65	 65	 65	 0.0	 0.0	 1	 -30.0	 30.0;
	992	 6768	 0.0111	 0.44741	 0.0	 71	 71	 71	 0.0	 0.0	 1	 -30.0	 30.0;
	10203	 4593	 0.065849	 0.525558	 0.0	 60	 60	 60	 0.0	 0.0	 1	 -30.0	 30.0;
	10203	 12980	 0.00095	 0.0053	 0.0	 5867	 5867	 5867	 0.0	 0.0	 1	 -30.0	 30.0;
	8685	 3452	 0.00139	 0.008281	 0.0	 3762	 3762	 3762	 0.0	 0.0	 1	 -30.0	 30.0;
	10055	 10493	 0.001	 0.26688	 0.0	 119	 119	 119	 0.0	 0.0	 1	 -30.0	 30.0;
	7766	 2890	 0.00036	 0.00286	 0.0	 10959	 10959	 10959	 0.0	 0.0	 1	 -30.0	 30.0;
	11156	 2854	 0.02231	 0.26281	 0.0	 120	 120	 120	 0.0	 0.0	 1	 -30.0	 30.0;
	11156	 2854	 0.001669	 0.01064	 0.0	 2933	 2933	 2933	 0.0	 0.0	 1	 -30.0	 30.0;
	7818	 11573	 3e-05	 0.00031	 0.0	 101421	 101421	 101421	 0.0	 0.0	 1	 -30.0	 30.0;
	7818	 638	 3e-05	 0.0003	 0.0	 104769	 104769	 104769	 0.0	 0.0	 1	 -30.0	 30.0;
	11674	 10846	 0.0004	 0.00637	 0.0	 4950	 4950	 4950	 0.0	 0.0	 1	 -30.0	 30.0;
	11436	 7869	 0.00018	 0.0019	 0.0	 16551	 16551	 16551	 0.0	 0.0	 1	 -30.0	 30.0;
	11436	 12671	 0.00032	 0.00267	 0.0	 11747	 11747	 11747	 0.0	 0.0	 1	 -30.0	 30.0;
	5515	 11314	 0.00023	 0.00202	 0.0	 15537	 15537	 15537	 0.0	 0.0	 1	 -30.0	 30.0;
	11314	 6768	 0.001	 0.382043	 0.0	 83	 83	 83	 0.0	 0.0	 1	 -30.0	 30.0;
	11571	 13614	 0.00011	 0.00075	 0.0	 41671	 41671	 41671	 0.0	 0.0	 1	 -30.0	 30.0;
	13035	 13614	 0.00013	 0.000531	 0.0	 57781	 57781	 57781	 0.0	 0.0	 1	 -30.0	 30.0;
	10794	 6683	 0.010909	 0.62314	 0.0	 51	 51	 51	 0.0	 0.0	 1	 -30.0	 30.0;
	2128	 2536	 0.005969	 0.037081	 0.0	 842	 842	 842	 0.0	 0.0	 1	 -30.0	 30.0;
	6598	 13441	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	6598	 13441	 0.001	 0.39696	 0.0	 80	 80	 80	 0.0	 0.0	 1	 -30.0	 30.0;
	6598	 12362	 0.192888	 1.242729	 0.0	 26	 26	 26	 0.0	 0.0	 1	 -30.0	 30.0;
	13441	 2323	 0.00078	 0.00629	 0.0	 4984	 4984	 4984	 0.0	 0.0	 1	 -30.0	 30.0;
	13441	 12362	 0.215693	 1.63338	 0.0	 20	 20	 20	 0.0	 0.0	 1	 -30.0	 30.0;
	2323	 12362	 0.00048	 0.00397	 0.0	 7899	 7899	 7899	 0.0	 0.0	 1	 -30.0	 30.0;
	6051	 12362	 0.00049	 0.00388	 0.0	 8077	 8077	 8077	 0.0	 0.0	 1	 -30.0	 30.0;
	10610	 12872	 0.000211	 0.00113	 0.0	 27479	 27479	 27479	 0.0	 0.0	 1	 -30.0	 30.0;
	7161	 6768	 3e-05	 0.00035	 0.0	 89920	 89920	 89920	 0.0	 0.0	 1	 -30.0	 30.0;
	568	 3171	 0.007409	 0.042281	 0.0	 736	 736	 736	 0.0	 0.0	 1	 -30.0	 30.0;
	5479	 9571	 0.00012	 0.0007	 0.0	 44476	 44476	 44476	 0.0	 0.0	 1	 -30.0	 30.0;
	148	 9278	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	148	 9278	 0.001	 0.284017	 0.0	 112	 112	 112	 0.0	 0.0	 1	 -30.0	 30.0;
	12987	 12151	 1.997645	 4.178116	 0.0	 7	 7	 7	 0.0	 0.0	 1	 -30.0	 30.0;
	12987	 4498	 0.00015	 0.00152	 0.0	 20681	 20681	 20681	 0.0	 0.0	 1	 -30.0	 30.0;
	12987	 1823	 0.00014	 0.00141	 0.0	 22293	 22293	 22293	 0.0	 0.0	 1	 -30.0	 30.0;
	12987	 6933	 0.00103	 0.00914	 0.0	 3435	 3435	 3435	 0.0	 0.0	 1	 -30.0	 30.0;
	12987	 4218	 0.00105	 0.00896	 0.0	 3502	 3502	 3502	 0.0	 0.0	 1	 -30.0	 30.0;
	3291	 12987	 0.334702	 1.492936	 0.0	 21	 21	 21	 0.0	 0.0	 1	 -30.0	 30.0;
	3291	 12987	 0.00142	 0.01428	 0.0	 2202	 2202	 2202	 0.0	 0.0	 1	 -30.0	 30.0;
	739	 12987	 0.340893	 1.460526	 0.0	 22	 22	 22	 0.0	 0.0	 1	 -30.0	 30.0;
	739	 12987	 0.00139	 0.01455	 0.0	 2162	 2162	 2162	 0.0	 0.0	 1	 -30.0	 30.0;
	582	 6840	 0.0004	 0.00376	 0.0	 8354	 8354	 8354	 0.0	 0.0	 1	 -30.0	 30.0;
	582	 7757	 0.00101	 0.01129	 0.0	 2787	 2787	 2787	 0.0	 0.0	 1	 -30.0	 30.0;
	582	 6704	 0.00076	 0.0089	 0.0	 3537	 3537	 3537	 0.0	 0.0	 1	 -30.0	 30.0;
	582	 6840	 0.0004	 0.00368	 0.0	 8534	 8534	 8534	 0.0	 0.0	 1	 -30.0	 30.0;
	582	 3839	 0.00099	 0.01151	 0.0	 2735	 2735	 2735	 0.0	 0.0	 1	 -30.0	 30.0;
	582	 1320	 0.00075	 0.00824	 0.0	 3818	 3818	 3818	 0.0	 0.0	 1	 -30.0	 30.0;
	11659	 6850	 0.00156	 0.01568	 0.0	 2005	 2005	 2005	 0.0	 0.0	 1	 -30.0	 30.0;
	11659	 6850	 0.00152	 0.01599	 0.0	 1967	 1967	 1967	 0.0	 0.0	 1	 -30.0	 30.0;
	712	 10235	 0.00539	 0.01612	 0.0	 1859	 1859	 1859	 0.0	 0.0	 1	 -30.0	 30.0;
	712	 10235	 0.0048	 0.018271	 0.0	 1673	 1673	 1673	 0.0	 0.0	 1	 -30.0	 30.0;
	12052	 1224	 0.008729	 0.034159	 0.0	 896	 896	 896	 0.0	 0.0	 1	 -30.0	 30.0;
	12052	 1224	 0.00855	 0.03482	 0.0	 881	 881	 881	 0.0	 0.0	 1	 -30.0	 30.0;
	6106	 2716	 0.00146	 0.00651	 0.0	 5635	 5635	 5635	 0.0	 0.0	 1	 -30.0	 30.0;
	748	 2716	 0.134252	 0.771745	 0.0	 48	 48	 48	 0.0	 0.0	 1	 -30.0	 30.0;
	748	 2716	 0.00072	 0.00587	 0.0	 6357	 6357	 6357	 0.0	 0.0	 1	 -30.0	 30.0;
	748	 2716	 0.00071	 0.006	 0.0	 6222	 6222	 6222	 0.0	 0.0	 1	 -30.0	 30.0;
	9319	 2716	 0.00013	 0.00132	 0.0	 28342	 28342	 28342	 0.0	 0.0	 1	 -30.0	 30.0;
	2684	 2716	 0.322853	 1.362742	 0.0	 27	 27	 27	 0.0	 0.0	 1	 -30.0	 30.0;
	4092	 13230	 0.161841	 1.112975	 0.0	 34	 34	 34	 0.0	 0.0	 1	 -30.0	 30.0;
	4092	 13230	 0.00356	 0.022409	 0.0	 1657	 1657	 1657	 0.0	 0.0	 1	 -30.0	 30.0;
	645	 13230	 0.211508	 1.021529	 0.0	 37	 37	 37	 0.0	 0.0	 1	 -30.0	 30.0;
	645	 13230	 0.00838	 0.038479	 0.0	 955	 955	 955	 0.0	 0.0	 1	 -30.0	 30.0;
	712	 13230	 0.912748	 1.922025	 0.0	 18	 18	 18	 0.0	 0.0	 1	 -30.0	 30.0;
	11046	 12063	 0.005211	 0.016901	 0.0	 1786	 1786	 1786	 0.0	 0.0	 1	 -30.0	 30.0;
	11046	 12063	 0.219566	 0.646591	 0.0	 47	 47	 47	 0.0	 0.0	 1	 -30.0	 30.0;
	11046	 12063	 0.00531	 0.016539	 0.0	 1819	 1819	 1819	 0.0	 0.0	 1	 -30.0	 30.0;
	7632	 10638	 0.140519	 0.391918	 0.0	 76	 76	 76	 0.0	 0.0	 1	 -30.0	 30.0;
	6973	 7632	 0.00131	 0.01484	 0.0	 2121	 2121	 2121	 0.0	 0.0	 1	 -30.0	 30.0;
	7632	 6704	 0.05123	 0.434093	 0.0	 73	 73	 73	 0.0	 0.0	 1	 -30.0	 30.0;
	7632	 6704	 0.0006	 0.00673	 0.0	 4675	 4675	 4675	 0.0	 0.0	 1	 -30.0	 30.0;
	7632	 12335	 0.05191	 0.445222	 0.0	 71	 71	 71	 0.0	 0.0	 1	 -30.0	 30.0;
	5154	 7632	 0.736704	 3.325	 0.0	 10	 10	 10	 0.0	 0.0	 1	 -30.0	 30.0;
	3988	 7632	 2.622299	 8.981301	 0.0	 4	 4	 4	 0.0	 0.0	 1	 -30.0	 30.0;
	7574	 9460	 0.0	 0.0002	 0.0	 187958	 187958	 187958	 0.0	 0.0	 1	 -30.0	 30.0;
	7574	 9460	 0.001	 0.291627	 0.0	 129	 129	 129	 0.0	 0.0	 1	 -30.0	 30.0;
	3536	 7574	 0.00016	 0.00138	 0.0	 27059	 27059	 27059	 0.0	 0.0	 1	 -30.0	 30.0;
	6285	 7574	 0.00017	 0.00135	 0.0	 27628	 27628	 27628	 0.0	 0.0	 1	 -30.0	 30.0;
	702	 9460	 0.00017	 0.00133	 0.0	 28037	 28037	 28037	 0.0	 0.0	 1	 -30.0	 30.0;
	1964	 9460	 0.00017	 0.0013	 0.0	 28673	 28673	 28673	 0.0	 0.0	 1	 -30.0	 30.0;
	11659	 3536	 0.00189	 0.01446	 0.0	 2602	 2602	 2602	 0.0	 0.0	 1	 -30.0	 30.0;
	6285	 1393	 0.00074	 0.00698	 0.0	 5356	 5356	 5356	 0.0	 0.0	 1	 -30.0	 30.0;
	11659	 702	 0.00193	 0.01416	 0.0	 2655	 2655	 2655	 0.0	 0.0	 1	 -30.0	 30.0;
	1964	 6128	 0.00073	 0.00711	 0.0	 5260	 5260	 5260	 0.0	 0.0	 1	 -30.0	 30.0;
	3291	 12151	 0.136731	 0.910873	 0.0	 35	 35	 35	 0.0	 0.0	 1	 -30.0	 30.0;
	3291	 12151	 0.00128	 0.0134	 0.0	 2347	 2347	 2347	 0.0	 0.0	 1	 -30.0	 30.0;
	739	 12151	 0.13394	 0.92874	 0.0	 34	 34	 34	 0.0	 0.0	 1	 -30.0	 30.0;
	8715	 3115	 0.271641	 0.707964	 0.0	 50	 50	 50	 0.0	 0.0	 1	 -30.0	 30.0;
	8715	 3115	 0.00037	 0.0037	 0.0	 10110	 10110	 10110	 0.0	 0.0	 1	 -30.0	 30.0;
	8715	 3115	 0.00038	 0.00363	 0.0	 10300	 10300	 10300	 0.0	 0.0	 1	 -30.0	 30.0;
	5154	 3115	 0.00156	 0.01473	 0.0	 2562	 2562	 2562	 0.0	 0.0	 1	 -30.0	 30.0;
	3988	 3115	 0.00159	 0.01442	 0.0	 2616	 2616	 2616	 0.0	 0.0	 1	 -30.0	 30.0;
	12223	 2049	 0.01049	 0.04336	 0.0	 851	 851	 851	 0.0	 0.0	 1	 -30.0	 30.0;
	4639	 2049	 0.010271	 0.04418	 0.0	 837	 837	 837	 0.0	 0.0	 1	 -30.0	 30.0;
	11046	 2049	 0.00881	 0.037021	 0.0	 831	 831	 831	 0.0	 0.0	 1	 -30.0	 30.0;
	11366	 2049	 0.004409	 0.01682	 0.0	 1817	 1817	 1817	 0.0	 0.0	 1	 -30.0	 30.0;
	11366	 2049	 0.00432	 0.017151	 0.0	 1786	 1786	 1786	 0.0	 0.0	 1	 -30.0	 30.0;
	10997	 2049	 0.01025	 0.042341	 0.0	 726	 726	 726	 0.0	 0.0	 1	 -30.0	 30.0;
	5521	 3921	 0.05386	 0.203789	 0.0	 150	 150	 150	 0.0	 0.0	 1	 -30.0	 30.0;
	5521	 3921	 0.005	 0.017849	 0.0	 1705	 1705	 1705	 0.0	 0.0	 1	 -30.0	 30.0;
	5521	 3921	 0.004909	 0.01824	 0.0	 1673	 1673	 1673	 0.0	 0.0	 1	 -30.0	 30.0;
	3921	 4615	 0.442645	 0.98938	 0.0	 30	 30	 30	 0.0	 0.0	 1	 -30.0	 30.0;
	3921	 4615	 0.00789	 0.025831	 0.0	 1170	 1170	 1170	 0.0	 0.0	 1	 -30.0	 30.0;
	3921	 4615	 0.00774	 0.02638	 0.0	 1149	 1149	 1149	 0.0	 0.0	 1	 -30.0	 30.0;
	9450	 748	 0.00141	 0.01209	 0.0	 3089	 3089	 3089	 0.0	 0.0	 1	 -30.0	 30.0;
	9450	 6457	 0.104079	 0.42973	 0.0	 86	 86	 86	 0.0	 0.0	 1	 -30.0	 30.0;
	1393	 6840	 0.00139	 0.01016	 0.0	 3700	 3700	 3700	 0.0	 0.0	 1	 -30.0	 30.0;
	6128	 6840	 0.00142	 0.00994	 0.0	 3779	 3779	 3779	 0.0	 0.0	 1	 -30.0	 30.0;
	3106	 571	 9e-05	 0.00064	 0.0	 48875	 48875	 48875	 0.0	 0.0	 1	 -30.0	 30.0;
	3106	 6933	 0.195942	 0.820914	 0.0	 38	 38	 38	 0.0	 0.0	 1	 -30.0	 30.0;
	3106	 4218	 0.199778	 0.804155	 0.0	 39	 39	 39	 0.0	 0.0	 1	 -30.0	 30.0;
	739	 3106	 0.02836	 0.37876	 0.0	 84	 84	 84	 0.0	 0.0	 1	 -30.0	 30.0;
	571	 6933	 0.00109	 0.00814	 0.0	 3847	 3847	 3847	 0.0	 0.0	 1	 -30.0	 30.0;
	739	 571	 0.00054	 0.00424	 0.0	 7391	 7391	 7391	 0.0	 0.0	 1	 -30.0	 30.0;
	4520	 748	 0.00263	 0.02613	 0.0	 1432	 1432	 1432	 0.0	 0.0	 1	 -30.0	 30.0;
	748	 10099	 0.00166	 0.01885	 0.0	 1987	 1987	 1987	 0.0	 0.0	 1	 -30.0	 30.0;
	748	 2684	 0.847576	 2.035042	 0.0	 18	 18	 18	 0.0	 0.0	 1	 -30.0	 30.0;
	1759	 748	 0.00094	 0.00794	 0.0	 4702	 4702	 4702	 0.0	 0.0	 1	 -30.0	 30.0;
	4092	 1987	 0.014081	 0.055831	 0.0	 659	 659	 659	 0.0	 0.0	 1	 -30.0	 30.0;
	4092	 645	 2.006198	 3.572314	 0.0	 10	 10	 10	 0.0	 0.0	 1	 -30.0	 30.0;
	4092	 645	 0.0122	 0.05982	 0.0	 616	 616	 616	 0.0	 0.0	 1	 -30.0	 30.0;
	4092	 712	 0.30564	 1.254566	 0.0	 30	 30	 30	 0.0	 0.0	 1	 -30.0	 30.0;
	4092	 712	 0.0235	 0.076229	 0.0	 476	 476	 476	 0.0	 0.0	 1	 -30.0	 30.0;
	4092	 4615	 0.029969	 0.12889	 0.0	 287	 287	 287	 0.0	 0.0	 1	 -30.0	 30.0;
	4092	 4615	 0.02932	 0.119341	 0.0	 309	 309	 309	 0.0	 0.0	 1	 -30.0	 30.0;
	9680	 6596	 0.00699	 0.02886	 0.0	 1064	 1064	 1064	 0.0	 0.0	 1	 -30.0	 30.0;
	6596	 1224	 0.004909	 0.014719	 0.0	 2036	 2036	 2036	 0.0	 0.0	 1	 -30.0	 30.0;
	3960	 10997	 0.005591	 0.01814	 0.0	 1665	 1665	 1665	 0.0	 0.0	 1	 -30.0	 30.0;
	3960	 10997	 0.00569	 0.01776	 0.0	 1694	 1694	 1694	 0.0	 0.0	 1	 -30.0	 30.0;
	10638	 6704	 0.03624	 0.415741	 0.0	 76	 76	 76	 0.0	 0.0	 1	 -30.0	 30.0;
	10638	 12335	 0.03359	 0.482777	 0.0	 66	 66	 66	 0.0	 0.0	 1	 -30.0	 30.0;
	10638	 12335	 0.00088	 0.01001	 0.0	 3144	 3144	 3144	 0.0	 0.0	 1	 -30.0	 30.0;
	10638	 1320	 0.001	 0.00981	 0.0	 3204	 3204	 3204	 0.0	 0.0	 1	 -30.0	 30.0;
	5154	 10638	 0.706579	 3.541136	 0.0	 9	 9	 9	 0.0	 0.0	 1	 -30.0	 30.0;
	3988	 10638	 2.102562	 10.3982	 0.0	 3	 3	 3	 0.0	 0.0	 1	 -30.0	 30.0;
	712	 1987	 0.00962	 0.03813	 0.0	 804	 804	 804	 0.0	 0.0	 1	 -30.0	 30.0;
	11254	 7543	 0.04235	 0.255499	 0.0	 122	 122	 122	 0.0	 0.0	 1	 -30.0	 30.0;
	11254	 10219	 0.03604	 0.287562	 0.0	 109	 109	 109	 0.0	 0.0	 1	 -30.0	 30.0;
	11254	 10219	 0.00069	 0.00676	 0.0	 4649	 4649	 4649	 0.0	 0.0	 1	 -30.0	 30.0;
	11254	 6772	 0.02303	 0.242479	 0.0	 156	 156	 156	 0.0	 0.0	 1	 -30.0	 30.0;
	6595	 11254	 0.002	 0.02189	 0.0	 1726	 1726	 1726	 0.0	 0.0	 1	 -30.0	 30.0;
	7757	 3988	 0.00063	 0.00569	 0.0	 5518	 5518	 5518	 0.0	 0.0	 1	 -30.0	 30.0;
	3839	 5154	 0.00064	 0.00557	 0.0	 5634	 5634	 5634	 0.0	 0.0	 1	 -30.0	 30.0;
	7543	 10219	 0.001	 0.193123	 0.0	 164	 164	 164	 0.0	 0.0	 1	 -30.0	 30.0;
	7543	 6772	 0.01778	 0.156988	 0.0	 241	 241	 241	 0.0	 0.0	 1	 -30.0	 30.0;
	7543	 6772	 0.00104	 0.00843	 0.0	 4467	 4467	 4467	 0.0	 0.0	 1	 -30.0	 30.0;
	3291	 7543	 0.00096	 0.01465	 0.0	 2152	 2152	 2152	 0.0	 0.0	 1	 -30.0	 30.0;
	6595	 7543	 0.003	 0.02517	 0.0	 1497	 1497	 1497	 0.0	 0.0	 1	 -30.0	 30.0;
	10219	 6772	 0.462929	 1.374931	 0.0	 27	 27	 27	 0.0	 0.0	 1	 -30.0	 30.0;
	853	 10219	 0.00244	 0.01729	 0.0	 2173	 2173	 2173	 0.0	 0.0	 1	 -30.0	 30.0;
	739	 10219	 0.00094	 0.01356	 0.0	 2324	 2324	 2324	 0.0	 0.0	 1	 -30.0	 30.0;
	12223	 9924	 0.01526	 0.05118	 0.0	 704	 704	 704	 0.0	 0.0	 1	 -30.0	 30.0;
	4639	 9924	 0.01555	 0.05011	 0.0	 717	 717	 717	 0.0	 0.0	 1	 -30.0	 30.0;
	645	 712	 0.26188	 0.583802	 0.0	 60	 60	 60	 0.0	 0.0	 1	 -30.0	 30.0;
	4520	 11659	 0.0036	 0.04	 0.0	 945	 945	 945	 0.0	 0.0	 1	 -30.0	 30.0;
	4520	 727	 0.00363	 0.03446	 0.0	 1095	 1095	 1095	 0.0	 0.0	 1	 -30.0	 30.0;
	4520	 2684	 0.00099	 0.01049	 0.0	 3568	 3568	 3568	 0.0	 0.0	 1	 -30.0	 30.0;
	13256	 6772	 0.00332	 0.03036	 0.0	 1231	 1231	 1231	 0.0	 0.0	 1	 -30.0	 30.0;
	5724	 2021	 0.00027	 0.00309	 0.0	 10184	 10184	 10184	 0.0	 0.0	 1	 -30.0	 30.0;
	7666	 2021	 0.00031	 0.00303	 0.0	 10371	 10371	 10371	 0.0	 0.0	 1	 -30.0	 30.0;
	5521	 4615	 0.027099	 0.21312	 0.0	 148	 148	 148	 0.0	 0.0	 1	 -30.0	 30.0;
	5521	 4615	 0.00357	 0.011021	 0.0	 2727	 2727	 2727	 0.0	 0.0	 1	 -30.0	 30.0;
	5521	 4615	 0.00351	 0.01126	 0.0	 2679	 2679	 2679	 0.0	 0.0	 1	 -30.0	 30.0;
	11659	 727	 0.00037	 0.00418	 0.0	 7528	 7528	 7528	 0.0	 0.0	 1	 -30.0	 30.0;
	6056	 9680	 0.04124	 0.192349	 0.0	 161	 161	 161	 0.0	 0.0	 1	 -30.0	 30.0;
	6056	 9680	 0.015669	 0.064711	 0.0	 475	 475	 475	 0.0	 0.0	 1	 -30.0	 30.0;
	6056	 9680	 0.016	 0.06349	 0.0	 483	 483	 483	 0.0	 0.0	 1	 -30.0	 30.0;
	9680	 1224	 0.012281	 0.03676	 0.0	 816	 816	 816	 0.0	 0.0	 1	 -30.0	 30.0;
	11046	 277	 0.02043	 0.19226	 0.0	 164	 164	 164	 0.0	 0.0	 1	 -30.0	 30.0;
	11046	 277	 0.00287	 0.01095	 0.0	 2791	 2791	 2791	 0.0	 0.0	 1	 -30.0	 30.0;
	11046	 277	 0.00281	 0.011169	 0.0	 2743	 2743	 2743	 0.0	 0.0	 1	 -30.0	 30.0;
	6457	 10099	 0.00054	 0.00596	 0.0	 6282	 6282	 6282	 0.0	 0.0	 1	 -30.0	 30.0;
	6458	 6457	 0.00134	 0.01244	 0.0	 3005	 3005	 3005	 0.0	 0.0	 1	 -30.0	 30.0;
	1393	 6128	 0.001	 0.265693	 0.0	 142	 142	 142	 0.0	 0.0	 1	 -30.0	 30.0;
	13256	 1393	 0.15358	 0.524508	 0.0	 69	 69	 69	 0.0	 0.0	 1	 -30.0	 30.0;
	10502	 1393	 0.613823	 2.118352	 0.0	 18	 18	 18	 0.0	 0.0	 1	 -30.0	 30.0;
	10502	 1393	 0.00081	 0.0077	 0.0	 4856	 4856	 4856	 0.0	 0.0	 1	 -30.0	 30.0;
	1393	 5154	 0.00228	 0.02083	 0.0	 1811	 1811	 1811	 0.0	 0.0	 1	 -30.0	 30.0;
	13256	 6128	 0.168047	 0.592382	 0.0	 62	 62	 62	 0.0	 0.0	 1	 -30.0	 30.0;
	13256	 6128	 0.0008	 0.00785	 0.0	 4765	 4765	 4765	 0.0	 0.0	 1	 -30.0	 30.0;
	10502	 6128	 0.698199	 2.371468	 0.0	 16	 16	 16	 0.0	 0.0	 1	 -30.0	 30.0;
	6128	 3988	 0.00232	 0.02039	 0.0	 1849	 1849	 1849	 0.0	 0.0	 1	 -30.0	 30.0;
	3291	 8715	 0.00177	 0.01939	 0.0	 1949	 1949	 1949	 0.0	 0.0	 1	 -30.0	 30.0;
	739	 8715	 0.00173	 0.01976	 0.0	 1913	 1913	 1913	 0.0	 0.0	 1	 -30.0	 30.0;
	13256	 10502	 0.0	 0.0002	 0.0	 187958	 187958	 187958	 0.0	 0.0	 1	 -30.0	 30.0;
	13256	 10502	 0.001	 0.213047	 0.0	 177	 177	 177	 0.0	 0.0	 1	 -30.0	 30.0;
	13256	 3988	 0.00194	 0.01469	 0.0	 2561	 2561	 2561	 0.0	 0.0	 1	 -30.0	 30.0;
	853	 13256	 0.00123	 0.00838	 0.0	 4439	 4439	 4439	 0.0	 0.0	 1	 -30.0	 30.0;
	13256	 5273	 0.00121	 0.0116	 0.0	 3224	 3224	 3224	 0.0	 0.0	 1	 -30.0	 30.0;
	13256	 6595	 0.00346	 0.03846	 0.0	 974	 974	 974	 0.0	 0.0	 1	 -30.0	 30.0;
	10502	 5154	 0.00198	 0.01438	 0.0	 2614	 2614	 2614	 0.0	 0.0	 1	 -30.0	 30.0;
	10502	 6595	 0.00338	 0.0392	 0.0	 956	 956	 956	 0.0	 0.0	 1	 -30.0	 30.0;
	10502	 284	 0.00248	 0.02446	 0.0	 1530	 1530	 1530	 0.0	 0.0	 1	 -30.0	 30.0;
	6933	 4218	 0.001	 0.26367	 0.0	 120	 120	 120	 0.0	 0.0	 1	 -30.0	 30.0;
	739	 6933	 0.580512	 1.382895	 0.0	 22	 22	 22	 0.0	 0.0	 1	 -30.0	 30.0;
	2509	 6933	 0.00094	 0.00807	 0.0	 3888	 3888	 3888	 0.0	 0.0	 1	 -30.0	 30.0;
	6973	 4218	 0.00232	 0.01638	 0.0	 1910	 1910	 1910	 0.0	 0.0	 1	 -30.0	 30.0;
	3291	 4218	 0.00217	 0.0131	 0.0	 2379	 2379	 2379	 0.0	 0.0	 1	 -30.0	 30.0;
	739	 4218	 0.568421	 1.409488	 0.0	 21	 21	 21	 0.0	 0.0	 1	 -30.0	 30.0;
	2512	 8132	 0.005331	 0.017341	 0.0	 1742	 1742	 1742	 0.0	 0.0	 1	 -30.0	 30.0;
	6973	 12335	 0.00199	 0.02218	 0.0	 1419	 1419	 1419	 0.0	 0.0	 1	 -30.0	 30.0;
	6973	 5154	 0.00163	 0.01513	 0.0	 2076	 2076	 2076	 0.0	 0.0	 1	 -30.0	 30.0;
	6973	 3988	 0.00159	 0.01541	 0.0	 2039	 2039	 2039	 0.0	 0.0	 1	 -30.0	 30.0;
	6973	 2509	 0.00136	 0.00959	 0.0	 3262	 3262	 3262	 0.0	 0.0	 1	 -30.0	 30.0;
	6973	 5724	 0.00042	 0.00496	 0.0	 6346	 6346	 6346	 0.0	 0.0	 1	 -30.0	 30.0;
	6973	 7666	 0.00041	 0.00505	 0.0	 6235	 6235	 6235	 0.0	 0.0	 1	 -30.0	 30.0;
	11046	 10997	 0.016591	 0.06199	 0.0	 493	 493	 493	 0.0	 0.0	 1	 -30.0	 30.0;
	6704	 12335	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	6704	 12335	 0.001	 0.404868	 0.0	 79	 79	 79	 0.0	 0.0	 1	 -30.0	 30.0;
	5154	 6704	 0.130547	 2.317729	 0.0	 14	 14	 14	 0.0	 0.0	 1	 -30.0	 30.0;
	3988	 6704	 0.431627	 6.284488	 0.0	 6	 6	 6	 0.0	 0.0	 1	 -30.0	 30.0;
	5154	 12335	 0.127403	 2.421884	 0.0	 14	 14	 14	 0.0	 0.0	 1	 -30.0	 30.0;
	3988	 12335	 0.397583	 6.979917	 0.0	 5	 5	 5	 0.0	 0.0	 1	 -30.0	 30.0;
	2684	 6458	 0.00356	 0.03374	 0.0	 1109	 1109	 1109	 0.0	 0.0	 1	 -30.0	 30.0;
	5154	 3988	 0.00164	 0.14108	 0.0	 224	 224	 224	 0.0	 0.0	 1	 -30.0	 30.0;
	6595	 6458	 0.00058	 0.00658	 0.0	 5691	 5691	 5691	 0.0	 0.0	 1	 -30.0	 30.0;
	6595	 6458	 0.00065	 0.00645	 0.0	 5799	 5799	 5799	 0.0	 0.0	 1	 -30.0	 30.0;
	5273	 284	 0.079079	 0.405817	 0.0	 91	 91	 91	 0.0	 0.0	 1	 -30.0	 30.0;
	5273	 284	 0.00139	 0.01268	 0.0	 2947	 2947	 2947	 0.0	 0.0	 1	 -30.0	 30.0;
	3291	 739	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	3291	 739	 0.001	 0.270111	 0.0	 117	 117	 117	 0.0	 0.0	 1	 -30.0	 30.0;
	12396	 9924	 0.185091	 0.839215	 0.0	 44	 44	 44	 0.0	 0.0	 1	 -30.0	 30.0;
	12396	 9924	 0.004651	 0.039669	 0.0	 942	 942	 942	 0.0	 0.0	 1	 -30.0	 30.0;
	12396	 9924	 0.00476	 0.042841	 0.0	 873	 873	 873	 0.0	 0.0	 1	 -30.0	 30.0;
	6595	 284	 0.0018	 0.02033	 0.0	 1842	 1842	 1842	 0.0	 0.0	 1	 -30.0	 30.0;
	795	 10162	 0.001	 0.335748	 0.0	 95	 95	 95	 0.0	 0.0	 1	 -30.0	 30.0;
	5724	 795	 0.0001	 0.00068	 0.0	 45958	 45958	 45958	 0.0	 0.0	 1	 -30.0	 30.0;
	7666	 10162	 0.0001	 0.00067	 0.0	 46629	 46629	 46629	 0.0	 0.0	 1	 -30.0	 30.0;
	7187	 13593	 0.026107	 0.07605	 0.0	 393	 393	 393	 0.0	 0.0	 1	 -30.0	 30.0;
	11834	 7187	 0.019727	 0.062124	 0.0	 485	 485	 485	 0.0	 0.0	 1	 -30.0	 30.0;
	7296	 13593	 0.026603	 0.074438	 0.0	 400	 400	 400	 0.0	 0.0	 1	 -30.0	 30.0;
	11834	 7296	 0.020107	 0.060851	 0.0	 493	 493	 493	 0.0	 0.0	 1	 -30.0	 30.0;
	3869	 9774	 0.014017	 0.040471	 0.0	 738	 738	 738	 0.0	 0.0	 1	 -30.0	 30.0;
	9774	 1978	 0.012488	 0.045289	 0.0	 673	 673	 673	 0.0	 0.0	 1	 -30.0	 30.0;
	9202	 8058	 0.014281	 0.039612	 0.0	 751	 751	 751	 0.0	 0.0	 1	 -30.0	 30.0;
	8058	 10723	 0.010826	 0.032686	 0.0	 918	 918	 918	 0.0	 0.0	 1	 -30.0	 30.0;
	6549	 9825	 0.012554	 0.049893	 0.0	 614	 614	 614	 0.0	 0.0	 1	 -30.0	 30.0;
	9825	 11940	 0.00705	 0.023174	 0.0	 1305	 1305	 1305	 0.0	 0.0	 1	 -30.0	 30.0;
	6442	 7230	 0.018818	 0.054132	 0.0	 552	 552	 552	 0.0	 0.0	 1	 -30.0	 30.0;
	1978	 7230	 0.032769	 0.043661	 0.0	 579	 579	 579	 0.0	 0.0	 1	 -30.0	 30.0;
	8295	 6549	 0.015322	 0.049653	 0.0	 608	 608	 608	 0.0	 0.0	 1	 -30.0	 30.0;
	3632	 968	 0.002413	 0.006917	 0.0	 4312	 4312	 4312	 0.0	 0.0	 1	 -30.0	 30.0;
	968	 7795	 0.010537	 0.025917	 0.0	 1130	 1130	 1130	 0.0	 0.0	 1	 -30.0	 30.0;
	6442	 3869	 0.009124	 0.032314	 0.0	 941	 941	 941	 0.0	 0.0	 1	 -30.0	 30.0;
	6442	 9202	 0.008934	 0.032934	 0.0	 926	 926	 926	 0.0	 0.0	 1	 -30.0	 30.0;
	13593	 5994	 0.0	 0.000413	 0.0	 76483	 76483	 76483	 0.0	 0.0	 1	 -30.0	 30.0;
	6988	 5994	 0.015562	 0.044669	 0.0	 668	 668	 668	 0.0	 0.0	 1	 -30.0	 30.0;
	9637	 5994	 0.013	 0.049983	 0.0	 612	 612	 612	 0.0	 0.0	 1	 -30.0	 30.0;
	13593	 7165	 0.014347	 0.041182	 0.0	 725	 725	 725	 0.0	 0.0	 1	 -30.0	 30.0;
	13593	 7165	 0.014628	 0.040322	 0.0	 737	 737	 737	 0.0	 0.0	 1	 -30.0	 30.0;
	2445	 1003	 0.017446	 0.029752	 0.0	 916	 916	 916	 0.0	 0.0	 1	 -30.0	 30.0;
	2445	 9624	 0.031579	 0.070992	 0.0	 407	 407	 407	 0.0	 0.0	 1	 -30.0	 30.0;
	10419	 2445	 0.007843	 0.018793	 0.0	 1552	 1552	 1552	 0.0	 0.0	 1	 -30.0	 30.0;
	6467	 2445	 0.007992	 0.018413	 0.0	 1574	 1574	 1574	 0.0	 0.0	 1	 -30.0	 30.0;
	8612	 11275	 0.001271	 0.016781	 0.0	 1877	 1877	 1877	 0.0	 0.0	 1	 -30.0	 30.0;
	8612	 11275	 0.00124	 0.015539	 0.0	 2027	 2027	 2027	 0.0	 0.0	 1	 -30.0	 30.0;
	1003	 6442	 0.033777	 0.06419	 0.0	 436	 436	 436	 0.0	 0.0	 1	 -30.0	 30.0;
	6442	 1687	 0.014347	 0.028397	 0.0	 993	 993	 993	 0.0	 0.0	 1	 -30.0	 30.0;
	9624	 6442	 0.023331	 0.052182	 0.0	 553	 553	 553	 0.0	 0.0	 1	 -30.0	 30.0;
	6442	 10119	 0.009446	 0.022636	 0.0	 1288	 1288	 1288	 0.0	 0.0	 1	 -30.0	 30.0;
	10723	 1978	 0.006992	 0.025488	 0.0	 1196	 1196	 1196	 0.0	 0.0	 1	 -30.0	 30.0;
	10119	 1687	 0.003339	 0.008851	 0.0	 3340	 3340	 3340	 0.0	 0.0	 1	 -30.0	 30.0;
	6988	 12899	 0.016471	 0.06081	 0.0	 502	 502	 502	 0.0	 0.0	 1	 -30.0	 30.0;
	10855	 9637	 0.020149	 0.058727	 0.0	 509	 509	 509	 0.0	 0.0	 1	 -30.0	 30.0;
	7165	 893	 0.013992	 0.054	 0.0	 567	 567	 567	 0.0	 0.0	 1	 -30.0	 30.0;
	7165	 5862	 0.013686	 0.05	 0.0	 610	 610	 610	 0.0	 0.0	 1	 -30.0	 30.0;
	7165	 6625	 0.000223	 0.000826	 0.0	 36920	 36920	 36920	 0.0	 0.0	 1	 -30.0	 30.0;
	7165	 2262	 0.000248	 0.00081	 0.0	 37289	 37289	 37289	 0.0	 0.0	 1	 -30.0	 30.0;
	13369	 12899	 0.036512	 0.098843	 0.0	 300	 300	 300	 0.0	 0.0	 1	 -30.0	 30.0;
	893	 302	 0.012876	 0.037438	 0.0	 798	 798	 798	 0.0	 0.0	 1	 -30.0	 30.0;
	5862	 302	 0.013124	 0.036636	 0.0	 812	 812	 812	 0.0	 0.0	 1	 -30.0	 30.0;
	3289	 10419	 0.013909	 0.033041	 0.0	 882	 882	 882	 0.0	 0.0	 1	 -30.0	 30.0;
	7795	 6467	 0.014182	 0.032372	 0.0	 894	 894	 894	 0.0	 0.0	 1	 -30.0	 30.0;
	7516	 12260	 0.00474	 0.027521	 0.0	 1132	 1132	 1132	 0.0	 0.0	 1	 -30.0	 30.0;
	7516	 10027	 0.00538	 0.026969	 0.0	 1149	 1149	 1149	 0.0	 0.0	 1	 -30.0	 30.0;
	7120	 11940	 0.020372	 0.06276	 0.0	 479	 479	 479	 0.0	 0.0	 1	 -30.0	 30.0;
	13369	 10855	 0.0	 0.000413	 0.0	 76483	 76483	 76483	 0.0	 0.0	 1	 -30.0	 30.0;
	9006	 8612	 0.0053	 0.02831	 0.0	 1097	 1097	 1097	 0.0	 0.0	 1	 -30.0	 30.0;
	9006	 8612	 0.00601	 0.02774	 0.0	 1113	 1113	 1113	 0.0	 0.0	 1	 -30.0	 30.0;
	12260	 9006	 0.00113	 0.006229	 0.0	 4990	 4990	 4990	 0.0	 0.0	 1	 -30.0	 30.0;
	10027	 9006	 0.001151	 0.00611	 0.0	 5081	 5081	 5081	 0.0	 0.0	 1	 -30.0	 30.0;
	3632	 3289	 0.014364	 0.029529	 0.0	 962	 962	 962	 0.0	 0.0	 1	 -30.0	 30.0;
	7120	 3632	 0.009017	 0.019727	 0.0	 1457	 1457	 1457	 0.0	 0.0	 1	 -30.0	 30.0;
	7120	 3632	 0.00919	 0.019314	 0.0	 1477	 1477	 1477	 0.0	 0.0	 1	 -30.0	 30.0;
	10027	 6702	 9.1e-05	 0.000219	 0.0	 133194	 133194	 133194	 0.0	 0.0	 1	 -30.0	 30.0;
	12260	 6702	 9.1e-05	 0.000229	 0.0	 128186	 128186	 128186	 0.0	 0.0	 1	 -30.0	 30.0;
	8295	 7120	 0.00205	 0.00562	 0.0	 5281	 5281	 5281	 0.0	 0.0	 1	 -30.0	 30.0;
	302	 8295	 0.016	 0.049818	 0.0	 604	 604	 604	 0.0	 0.0	 1	 -30.0	 30.0;
	302	 8295	 0.014331	 0.054347	 0.0	 563	 563	 563	 0.0	 0.0	 1	 -30.0	 30.0;
	9829	 7120	 0.00738	 0.021149	 0.0	 1411	 1411	 1411	 0.0	 0.0	 1	 -30.0	 30.0;
	302	 9829	 0.011256	 0.027769	 0.0	 1055	 1055	 1055	 0.0	 0.0	 1	 -30.0	 30.0;
	737	 7120	 0.007207	 0.019587	 0.0	 1514	 1514	 1514	 0.0	 0.0	 1	 -30.0	 30.0;
	302	 737	 0.01195	 0.024826	 0.0	 1147	 1147	 1147	 0.0	 0.0	 1	 -30.0	 30.0;
	8266	 4567	 0.00796	 0.04504	 0.0	 691	 691	 691	 0.0	 0.0	 1	 -30.0	 30.0;
	8266	 10128	 0.00844	 0.068649	 0.0	 457	 457	 457	 0.0	 0.0	 1	 -30.0	 30.0;
	8266	 8557	 0.021551	 0.0842	 0.0	 364	 364	 364	 0.0	 0.0	 1	 -30.0	 30.0;
	6172	 9494	 0.002809	 0.01632	 0.0	 1908	 1908	 1908	 0.0	 0.0	 1	 -30.0	 30.0;
	6172	 538	 0.00028	 0.00084	 0.0	 35675	 35675	 35675	 0.0	 0.0	 1	 -30.0	 30.0;
	6172	 538	 0.00032	 0.000822	 0.0	 35810	 35810	 35810	 0.0	 0.0	 1	 -30.0	 30.0;
	6172	 4072	 0.007711	 0.054271	 0.0	 577	 577	 577	 0.0	 0.0	 1	 -30.0	 30.0;
	6172	 6615	 0.002298	 0.017129	 0.0	 1828	 1828	 1828	 0.0	 0.0	 1	 -30.0	 30.0;
	13305	 13201	 0.004711	 0.026049	 0.0	 1194	 1194	 1194	 0.0	 0.0	 1	 -30.0	 30.0;
	13305	 7936	 0.008462	 0.03792	 0.0	 814	 814	 814	 0.0	 0.0	 1	 -30.0	 30.0;
	1615	 2539	 0.00095	 0.01117	 0.0	 2818	 2818	 2818	 0.0	 0.0	 1	 -30.0	 30.0;
	1615	 7453	 0.00142	 0.01429	 0.0	 2200	 2200	 2200	 0.0	 0.0	 1	 -30.0	 30.0;
	8420	 11585	 0.000569	 0.005382	 0.0	 5837	 5837	 5837	 0.0	 0.0	 1	 -30.0	 30.0;
	4842	 2932	 0.00984	 0.04424	 0.0	 697	 697	 697	 0.0	 0.0	 1	 -30.0	 30.0;
	4842	 6286	 0.0166	 0.105449	 0.0	 296	 296	 296	 0.0	 0.0	 1	 -30.0	 30.0;
	1201	 10931	 0.007209	 0.034969	 0.0	 885	 885	 885	 0.0	 0.0	 1	 -30.0	 30.0;
	1201	 2391	 0.023951	 0.07004	 0.0	 427	 427	 427	 0.0	 0.0	 1	 -30.0	 30.0;
	13201	 3261	 0.002258	 0.01644	 0.0	 1904	 1904	 1904	 0.0	 0.0	 1	 -30.0	 30.0;
	1212	 1965	 0.00948	 0.02892	 0.0	 1038	 1038	 1038	 0.0	 0.0	 1	 -30.0	 30.0;
	1212	 3690	 0.01224	 0.04384	 0.0	 694	 694	 694	 0.0	 0.0	 1	 -30.0	 30.0;
	3364	 3690	 0.016	 0.062369	 0.0	 491	 491	 491	 0.0	 0.0	 1	 -30.0	 30.0;
	3364	 3204	 0.020422	 0.082729	 0.0	 371	 371	 371	 0.0	 0.0	 1	 -30.0	 30.0;
	3364	 3204	 0.020009	 0.08436	 0.0	 365	 365	 365	 0.0	 0.0	 1	 -30.0	 30.0;
	6517	 3204	 0.010702	 0.030338	 0.0	 982	 982	 982	 0.0	 0.0	 1	 -30.0	 30.0;
	6517	 3204	 0.010902	 0.02968	 0.0	 1000	 1000	 1000	 0.0	 0.0	 1	 -30.0	 30.0;
	8174	 3813	 0.00848	 0.040809	 0.0	 758	 758	 758	 0.0	 0.0	 1	 -30.0	 30.0;
	8174	 2315	 0.012862	 0.05772	 0.0	 535	 535	 535	 0.0	 0.0	 1	 -30.0	 30.0;
	8161	 2539	 0.00047	 0.00546	 0.0	 5764	 5764	 5764	 0.0	 0.0	 1	 -30.0	 30.0;
	11298	 11245	 0.002871	 0.02108	 0.0	 1485	 1485	 1485	 0.0	 0.0	 1	 -30.0	 30.0;
	11298	 6286	 0.004849	 0.02916	 0.0	 1069	 1069	 1069	 0.0	 0.0	 1	 -30.0	 30.0;
	11298	 6286	 0.004751	 0.029711	 0.0	 1050	 1050	 1050	 0.0	 0.0	 1	 -30.0	 30.0;
	7530	 6286	 0.001569	 0.005489	 0.0	 5534	 5534	 5534	 0.0	 0.0	 1	 -30.0	 30.0;
	9727	 9500	 0.0003	 0.00316	 0.0	 9952	 9952	 9952	 0.0	 0.0	 1	 -30.0	 30.0;
	9727	 7453	 0.00114	 0.01207	 0.0	 2606	 2606	 2606	 0.0	 0.0	 1	 -30.0	 30.0;
	9727	 8871	 0.00147	 0.01724	 0.0	 1826	 1826	 1826	 0.0	 0.0	 1	 -30.0	 30.0;
	9727	 13640	 0.00039	 0.00552	 0.0	 5709	 5709	 5709	 0.0	 0.0	 1	 -30.0	 30.0;
	9494	 4072	 0.004991	 0.036511	 0.0	 858	 858	 858	 0.0	 0.0	 1	 -30.0	 30.0;
	9494	 13365	 0.007302	 0.041071	 0.0	 758	 758	 758	 0.0	 0.0	 1	 -30.0	 30.0;
	2337	 8699	 0.00022	 0.00305	 0.0	 10330	 10330	 10330	 0.0	 0.0	 1	 -30.0	 30.0;
	2337	 428	 0.00074	 0.00834	 0.0	 3773	 3773	 3773	 0.0	 0.0	 1	 -30.0	 30.0;
	2337	 6191	 0.00126	 0.0174	 0.0	 1811	 1811	 1811	 0.0	 0.0	 1	 -30.0	 30.0;
	6209	 4567	 0.00216	 0.012578	 0.0	 2476	 2476	 2476	 0.0	 0.0	 1	 -30.0	 30.0;
	6209	 944	 0.001329	 0.0106	 0.0	 2957	 2957	 2957	 0.0	 0.0	 1	 -30.0	 30.0;
	6209	 10128	 0.006049	 0.063742	 0.0	 494	 494	 494	 0.0	 0.0	 1	 -30.0	 30.0;
	7828	 12468	 0.006769	 0.02648	 0.0	 1156	 1156	 1156	 0.0	 0.0	 1	 -30.0	 30.0;
	7828	 11956	 0.016022	 0.047791	 0.0	 627	 627	 627	 0.0	 0.0	 1	 -30.0	 30.0;
	7828	 4072	 0.02884	 0.096209	 0.0	 315	 315	 315	 0.0	 0.0	 1	 -30.0	 30.0;
	10911	 11956	 0.00656	 0.024578	 0.0	 1242	 1242	 1242	 0.0	 0.0	 1	 -30.0	 30.0;
	10911	 1965	 0.00388	 0.017342	 0.0	 1778	 1778	 1778	 0.0	 0.0	 1	 -30.0	 30.0;
	10911	 1962	 0.01772	 0.064978	 0.0	 469	 469	 469	 0.0	 0.0	 1	 -30.0	 30.0;
	4567	 948	 0.01312	 0.052809	 0.0	 581	 581	 581	 0.0	 0.0	 1	 -30.0	 30.0;
	4567	 944	 0.001738	 0.002889	 0.0	 9369	 9369	 9369	 0.0	 0.0	 1	 -30.0	 30.0;
	948	 10739	 0.001169	 0.003489	 0.0	 8585	 8585	 8585	 0.0	 0.0	 1	 -30.0	 30.0;
	6086	 11053	 0.00368	 0.035022	 0.0	 897	 897	 897	 0.0	 0.0	 1	 -30.0	 30.0;
	6086	 9989	 0.001391	 0.010338	 0.0	 3029	 3029	 3029	 0.0	 0.0	 1	 -30.0	 30.0;
	6086	 6744	 0.004222	 0.030831	 0.0	 1016	 1016	 1016	 0.0	 0.0	 1	 -30.0	 30.0;
	4333	 8312	 0.004271	 0.036089	 0.0	 870	 870	 870	 0.0	 0.0	 1	 -30.0	 30.0;
	4333	 11053	 0.00596	 0.04024	 0.0	 777	 777	 777	 0.0	 0.0	 1	 -30.0	 30.0;
	5655	 7468	 0.011529	 0.046698	 0.0	 657	 657	 657	 0.0	 0.0	 1	 -30.0	 30.0;
	5655	 3690	 0.02252	 0.087338	 0.0	 351	 351	 351	 0.0	 0.0	 1	 -30.0	 30.0;
	9664	 2045	 0.004071	 0.035591	 0.0	 882	 882	 882	 0.0	 0.0	 1	 -30.0	 30.0;
	9664	 6744	 0.004138	 0.0386	 0.0	 814	 814	 814	 0.0	 0.0	 1	 -30.0	 30.0;
	4075	 8690	 0.010911	 0.027231	 0.0	 1077	 1077	 1077	 0.0	 0.0	 1	 -30.0	 30.0;
	120	 9526	 0.00256	 0.024622	 0.0	 1277	 1277	 1277	 0.0	 0.0	 1	 -30.0	 30.0;
	120	 6744	 0.005129	 0.040671	 0.0	 771	 771	 771	 0.0	 0.0	 1	 -30.0	 30.0;
	12468	 10931	 0.005462	 0.032671	 0.0	 954	 954	 954	 0.0	 0.0	 1	 -30.0	 30.0;
	12468	 2391	 0.002871	 0.014209	 0.0	 2180	 2180	 2180	 0.0	 0.0	 1	 -30.0	 30.0;
	12468	 2391	 0.002929	 0.013911	 0.0	 2222	 2222	 2222	 0.0	 0.0	 1	 -30.0	 30.0;
	12468	 10247	 0.003422	 0.011009	 0.0	 2740	 2740	 2740	 0.0	 0.0	 1	 -30.0	 30.0;
	9526	 11053	 0.00212	 0.016769	 0.0	 1869	 1869	 1869	 0.0	 0.0	 1	 -30.0	 30.0;
	9493	 7453	 0.00125	 0.01387	 0.0	 2269	 2269	 2269	 0.0	 0.0	 1	 -30.0	 30.0;
	12719	 3690	 0.004289	 0.017071	 0.0	 1795	 1795	 1795	 0.0	 0.0	 1	 -30.0	 30.0;
	12719	 7692	 0.0084	 0.024738	 0.0	 1210	 1210	 1210	 0.0	 0.0	 1	 -30.0	 30.0;
	8690	 6286	 0.01044	 0.039671	 0.0	 771	 771	 771	 0.0	 0.0	 1	 -30.0	 30.0;
	8690	 6286	 0.010218	 0.040418	 0.0	 758	 758	 758	 0.0	 0.0	 1	 -30.0	 30.0;
	8690	 5502	 0.008351	 0.02432	 0.0	 1229	 1229	 1229	 0.0	 0.0	 1	 -30.0	 30.0;
	2045	 3449	 0.00188	 0.006711	 0.0	 4533	 4533	 4533	 0.0	 0.0	 1	 -30.0	 30.0;
	2045	 13365	 0.00132	 0.00352	 0.0	 8403	 8403	 8403	 0.0	 0.0	 1	 -30.0	 30.0;
	10869	 6191	 0.00113	 0.01322	 0.0	 2381	 2381	 2381	 0.0	 0.0	 1	 -30.0	 30.0;
	10869	 2539	 0.00098	 0.01301	 0.0	 2422	 2422	 2422	 0.0	 0.0	 1	 -30.0	 30.0;
	2932	 7936	 0.005271	 0.05104	 0.0	 616	 616	 616	 0.0	 0.0	 1	 -30.0	 30.0;
	2932	 11036	 0.017458	 0.109631	 0.0	 285	 285	 285	 0.0	 0.0	 1	 -30.0	 30.0;
	2932	 327	 0.002831	 0.01016	 0.0	 2995	 2995	 2995	 0.0	 0.0	 1	 -30.0	 30.0;
	2932	 327	 0.001978	 0.010902	 0.0	 2851	 2851	 2851	 0.0	 0.0	 1	 -30.0	 30.0;
	428	 6191	 0.00059	 0.00764	 0.0	 4123	 4123	 4123	 0.0	 0.0	 1	 -30.0	 30.0;
	1909	 11956	 0.000231	 0.000769	 0.0	 39340	 39340	 39340	 0.0	 0.0	 1	 -30.0	 30.0;
	8312	 3261	 0.002809	 0.02468	 0.0	 1272	 1272	 1272	 0.0	 0.0	 1	 -30.0	 30.0;
	8312	 11585	 0.009942	 0.050222	 0.0	 617	 617	 617	 0.0	 0.0	 1	 -30.0	 30.0;
	6191	 7978	 0.00117	 0.01756	 0.0	 1795	 1795	 1795	 0.0	 0.0	 1	 -30.0	 30.0;
	6191	 11904	 9e-05	 0.0017	 0.0	 18555	 18555	 18555	 0.0	 0.0	 1	 -30.0	 30.0;
	3261	 9353	 0.002569	 0.02344	 0.0	 1340	 1340	 1340	 0.0	 0.0	 1	 -30.0	 30.0;
	3261	 6919	 0.00144	 0.011369	 0.0	 2757	 2757	 2757	 0.0	 0.0	 1	 -30.0	 30.0;
	13381	 12066	 0.002129	 0.019689	 0.0	 1596	 1596	 1596	 0.0	 0.0	 1	 -30.0	 30.0;
	6286	 11036	 0.00756	 0.048378	 0.0	 646	 646	 646	 0.0	 0.0	 1	 -30.0	 30.0;
	6286	 7468	 0.031138	 0.104969	 0.0	 289	 289	 289	 0.0	 0.0	 1	 -30.0	 30.0;
	7978	 8871	 0.00043	 0.00623	 0.0	 5059	 5059	 5059	 0.0	 0.0	 1	 -30.0	 30.0;
	11053	 3654	 0.000769	 0.005769	 0.0	 5428	 5428	 5428	 0.0	 0.0	 1	 -30.0	 30.0;
	1065	 6744	 0.01464	 0.043018	 0.0	 696	 696	 696	 0.0	 0.0	 1	 -30.0	 30.0;
	1065	 194	 0.006609	 0.014329	 0.0	 2002	 2002	 2002	 0.0	 0.0	 1	 -30.0	 30.0;
	3156	 8871	 0.00021	 0.00252	 0.0	 12492	 12492	 12492	 0.0	 0.0	 1	 -30.0	 30.0;
	6425	 6744	 0.002689	 0.019791	 0.0	 1582	 1582	 1582	 0.0	 0.0	 1	 -30.0	 30.0;
	6425	 6744	 0.002738	 0.01936	 0.0	 1616	 1616	 1616	 0.0	 0.0	 1	 -30.0	 30.0;
	6425	 6744	 0.001338	 0.010018	 0.0	 3126	 3126	 3126	 0.0	 0.0	 1	 -30.0	 30.0;
	9989	 6744	 0.001698	 0.012871	 0.0	 2434	 2434	 2434	 0.0	 0.0	 1	 -30.0	 30.0;
	2353	 6744	 0.00384	 0.028342	 0.0	 1105	 1105	 1105	 0.0	 0.0	 1	 -30.0	 30.0;
	4072	 12066	 0.00616	 0.033618	 0.0	 925	 925	 925	 0.0	 0.0	 1	 -30.0	 30.0;
	4072	 1962	 0.01488	 0.045698	 0.0	 658	 658	 658	 0.0	 0.0	 1	 -30.0	 30.0;
	9500	 13640	 4e-05	 0.00051	 0.0	 61747	 61747	 61747	 0.0	 0.0	 1	 -30.0	 30.0;
	2391	 3813	 0.028751	 0.090409	 0.0	 333	 333	 333	 0.0	 0.0	 1	 -30.0	 30.0;
	2391	 2315	 0.00092	 0.004609	 0.0	 6721	 6721	 6721	 0.0	 0.0	 1	 -30.0	 30.0;
	5788	 3690	 0.005151	 0.012329	 0.0	 2365	 2365	 2365	 0.0	 0.0	 1	 -30.0	 30.0;
	9353	 6919	 0.002129	 0.018	 0.0	 1743	 1743	 1743	 0.0	 0.0	 1	 -30.0	 30.0;
	327	 8557	 0.008929	 0.041471	 0.0	 745	 745	 745	 0.0	 0.0	 1	 -30.0	 30.0;
	327	 3005	 0.0222	 0.091822	 0.0	 335	 335	 335	 0.0	 0.0	 1	 -30.0	 30.0;
	5502	 7692	 0.005671	 0.021169	 0.0	 1442	 1442	 1442	 0.0	 0.0	 1	 -30.0	 30.0;
	6919	 3005	 0.00956	 0.035551	 0.0	 859	 859	 859	 0.0	 0.0	 1	 -30.0	 30.0;
	3204	 12066	 0.003169	 0.021911	 0.0	 1427	 1427	 1427	 0.0	 0.0	 1	 -30.0	 30.0;
	3204	 12066	 0.00324	 0.021471	 0.0	 1455	 1455	 1455	 0.0	 0.0	 1	 -30.0	 30.0;
	3204	 6744	 0.01168	 0.055391	 0.0	 558	 558	 558	 0.0	 0.0	 1	 -30.0	 30.0;
	3204	 6744	 0.011902	 0.054209	 0.0	 570	 570	 570	 0.0	 0.0	 1	 -30.0	 30.0;
	6744	 194	 0.01908	 0.062769	 0.0	 482	 482	 482	 0.0	 0.0	 1	 -30.0	 30.0;
	2315	 6615	 0.001591	 0.011098	 0.0	 2818	 2818	 2818	 0.0	 0.0	 1	 -30.0	 30.0;
	9598	 1833	 0.003289	 0.019091	 0.0	 1631	 1631	 1631	 0.0	 0.0	 1	 -30.0	 30.0;
	9598	 2381	 0.004169	 0.025349	 0.0	 1230	 1230	 1230	 0.0	 0.0	 1	 -30.0	 30.0;
	9598	 6027	 0.00439	 0.023909	 0.0	 1300	 1300	 1300	 0.0	 0.0	 1	 -30.0	 30.0;
	6915	 6230	 0.00156	 0.01956	 0.0	 1610	 1610	 1610	 0.0	 0.0	 1	 -30.0	 30.0;
	6230	 10840	 0.00029	 0.00391	 0.0	 8057	 8057	 8057	 0.0	 0.0	 1	 -30.0	 30.0;
	6230	 8556	 0.00179	 0.02522	 0.0	 1250	 1250	 1250	 0.0	 0.0	 1	 -30.0	 30.0;
	2105	 6230	 0.00079	 0.00756	 0.0	 4156	 4156	 4156	 0.0	 0.0	 1	 -30.0	 30.0;
	6230	 11657	 0.00027	 0.00281	 0.0	 11190	 11190	 11190	 0.0	 0.0	 1	 -30.0	 30.0;
	6230	 11657	 0.00026	 0.00286	 0.0	 11000	 11000	 11000	 0.0	 0.0	 1	 -30.0	 30.0;
	3205	 403	 0.000281	 0.00213	 0.0	 14703	 14703	 14703	 0.0	 0.0	 1	 -30.0	 30.0;
	3205	 7360	 0.000419	 0.00299	 0.0	 10463	 10463	 10463	 0.0	 0.0	 1	 -30.0	 30.0;
	5504	 7037	 0.001659	 0.009091	 0.0	 3419	 3419	 3419	 0.0	 0.0	 1	 -30.0	 30.0;
	5504	 9105	 0.00439	 0.03324	 0.0	 943	 943	 943	 0.0	 0.0	 1	 -30.0	 30.0;
	8722	 12834	 0.000841	 0.00612	 0.0	 5114	 5114	 5114	 0.0	 0.0	 1	 -30.0	 30.0;
	8722	 290	 0.003341	 0.022841	 0.0	 1369	 1369	 1369	 0.0	 0.0	 1	 -30.0	 30.0;
	8722	 5149	 0.00581	 0.04232	 0.0	 740	 740	 740	 0.0	 0.0	 1	 -30.0	 30.0;
	8722	 2025	 0.00495	 0.02919	 0.0	 1067	 1067	 1067	 0.0	 0.0	 1	 -30.0	 30.0;
	8722	 8144	 0.01789	 0.07795	 0.0	 395	 395	 395	 0.0	 0.0	 1	 -30.0	 30.0;
	8722	 7253	 0.00186	 0.014289	 0.0	 2193	 2193	 2193	 0.0	 0.0	 1	 -30.0	 30.0;
	8722	 3372	 0.002281	 0.014401	 0.0	 2167	 2167	 2167	 0.0	 0.0	 1	 -30.0	 30.0;
	6617	 4257	 0.00031	 0.00132	 0.0	 23296	 23296	 23296	 0.0	 0.0	 1	 -30.0	 30.0;
	6617	 10130	 0.001349	 0.0077	 0.0	 4041	 4041	 4041	 0.0	 0.0	 1	 -30.0	 30.0;
	8288	 8640	 0.00586	 0.02574	 0.0	 1197	 1197	 1197	 0.0	 0.0	 1	 -30.0	 30.0;
	8288	 8801	 0.00556	 0.020211	 0.0	 1507	 1507	 1507	 0.0	 0.0	 1	 -30.0	 30.0;
	7580	 12019	 0.00026	 0.001159	 0.0	 26594	 26594	 26594	 0.0	 0.0	 1	 -30.0	 30.0;
	12019	 9729	 0.000599	 0.002419	 0.0	 12676	 12676	 12676	 0.0	 0.0	 1	 -30.0	 30.0;
	4522	 10455	 0.0005	 0.00386	 0.0	 8116	 8116	 8116	 0.0	 0.0	 1	 -30.0	 30.0;
	4522	 8972	 0.00107	 0.008289	 0.0	 3780	 3780	 3780	 0.0	 0.0	 1	 -30.0	 30.0;
	4522	 8972	 0.001091	 0.00811	 0.0	 3861	 3861	 3861	 0.0	 0.0	 1	 -30.0	 30.0;
	10866	 4522	 0.00038	 0.00255	 0.0	 12252	 12252	 12252	 0.0	 0.0	 1	 -30.0	 30.0;
	7580	 9448	 0.000271	 0.000979	 0.0	 31096	 31096	 31096	 0.0	 0.0	 1	 -30.0	 30.0;
	3375	 2340	 7e-05	 0.00076	 0.0	 41388	 41388	 41388	 0.0	 0.0	 1	 -30.0	 30.0;
	3375	 401	 0.000521	 0.003901	 0.0	 8026	 8026	 8026	 0.0	 0.0	 1	 -30.0	 30.0;
	6915	 12143	 0.0016	 0.01839	 0.0	 1712	 1712	 1712	 0.0	 0.0	 1	 -30.0	 30.0;
	8410	 1975	 0.007651	 0.058781	 0.0	 533	 533	 533	 0.0	 0.0	 1	 -30.0	 30.0;
	8410	 9114	 0.00394	 0.02182	 0.0	 1425	 1425	 1425	 0.0	 0.0	 1	 -30.0	 30.0;
	8410	 5778	 0.003461	 0.03005	 0.0	 1045	 1045	 1045	 0.0	 0.0	 1	 -30.0	 30.0;
	8410	 6867	 0.00337	 0.01831	 0.0	 1697	 1697	 1697	 0.0	 0.0	 1	 -30.0	 30.0;
	11809	 6293	 0.000581	 0.00194	 0.0	 15598	 15598	 15598	 0.0	 0.0	 1	 -30.0	 30.0;
	10837	 6293	 0.000539	 0.001719	 0.0	 17534	 17534	 17534	 0.0	 0.0	 1	 -30.0	 30.0;
	1388	 1303	 0.00249	 0.03075	 0.0	 1024	 1024	 1024	 0.0	 0.0	 1	 -30.0	 30.0;
	1303	 6472	 0.0014	 0.01409	 0.0	 2231	 2231	 2231	 0.0	 0.0	 1	 -30.0	 30.0;
	11503	 9648	 0.008	 0.050031	 0.0	 624	 624	 624	 0.0	 0.0	 1	 -30.0	 30.0;
	11503	 8144	 0.002211	 0.01562	 0.0	 2003	 2003	 2003	 0.0	 0.0	 1	 -30.0	 30.0;
	12645	 5358	 0.00281	 0.021831	 0.0	 1436	 1436	 1436	 0.0	 0.0	 1	 -30.0	 30.0;
	12645	 11469	 0.000711	 0.004919	 0.0	 6356	 6356	 6356	 0.0	 0.0	 1	 -30.0	 30.0;
	4198	 12948	 0.001841	 0.00738	 0.0	 4153	 4153	 4153	 0.0	 0.0	 1	 -30.0	 30.0;
	4198	 5103	 0.002849	 0.008979	 0.0	 3354	 3354	 3354	 0.0	 0.0	 1	 -30.0	 30.0;
	12305	 5358	 0.00232	 0.014099	 0.0	 2211	 2211	 2211	 0.0	 0.0	 1	 -30.0	 30.0;
	12305	 5358	 0.00237	 0.0138	 0.0	 2256	 2256	 2256	 0.0	 0.0	 1	 -30.0	 30.0;
	12305	 10085	 0.00081	 0.004591	 0.0	 6776	 6776	 6776	 0.0	 0.0	 1	 -30.0	 30.0;
	12305	 9686	 0.002219	 0.010469	 0.0	 2952	 2952	 2952	 0.0	 0.0	 1	 -30.0	 30.0;
	2317	 2672	 0.001081	 0.00851	 0.0	 3683	 3683	 3683	 0.0	 0.0	 1	 -30.0	 30.0;
	2672	 11725	 0.00087	 0.006969	 0.0	 4498	 4498	 4498	 0.0	 0.0	 1	 -30.0	 30.0;
	2672	 11725	 0.00088	 0.006831	 0.0	 4587	 4587	 4587	 0.0	 0.0	 1	 -30.0	 30.0;
	2672	 6828	 0.000349	 0.00237	 0.0	 13186	 13186	 13186	 0.0	 0.0	 1	 -30.0	 30.0;
	1030	 9509	 0.00232	 0.00924	 0.0	 3316	 3316	 3316	 0.0	 0.0	 1	 -30.0	 30.0;
	1030	 5566	 0.00812	 0.03669	 0.0	 841	 841	 841	 0.0	 0.0	 1	 -30.0	 30.0;
	3116	 9822	 0.003521	 0.02825	 0.0	 1110	 1110	 1110	 0.0	 0.0	 1	 -30.0	 30.0;
	3116	 6962	 0.00264	 0.017651	 0.0	 1770	 1770	 1770	 0.0	 0.0	 1	 -30.0	 30.0;
	11187	 9509	 0.00486	 0.02149	 0.0	 1434	 1434	 1434	 0.0	 0.0	 1	 -30.0	 30.0;
	11187	 9886	 0.006831	 0.034669	 0.0	 894	 894	 894	 0.0	 0.0	 1	 -30.0	 30.0;
	11187	 10340	 0.017211	 0.108151	 0.0	 289	 289	 289	 0.0	 0.0	 1	 -30.0	 30.0;
	11187	 12082	 0.00063	 0.00475	 0.0	 6593	 6593	 6593	 0.0	 0.0	 1	 -30.0	 30.0;
	11187	 12082	 0.00062	 0.004841	 0.0	 6473	 6473	 6473	 0.0	 0.0	 1	 -30.0	 30.0;
	1388	 3599	 0.0009	 0.01092	 0.0	 2883	 2883	 2883	 0.0	 0.0	 1	 -30.0	 30.0;
	3599	 10105	 0.00124	 0.01096	 0.0	 2864	 2864	 2864	 0.0	 0.0	 1	 -30.0	 30.0;
	4478	 4248	 0.003211	 0.00176	 0.0	 8627	 8627	 8627	 0.0	 0.0	 1	 -30.0	 30.0;
	4478	 11469	 0.001521	 0.008031	 0.0	 3865	 3865	 3865	 0.0	 0.0	 1	 -30.0	 30.0;
	7896	 2714	 0.0005	 0.00441	 0.0	 7118	 7118	 7118	 0.0	 0.0	 1	 -30.0	 30.0;
	7896	 2130	 0.00247	 0.02573	 0.0	 1223	 1223	 1223	 0.0	 0.0	 1	 -30.0	 30.0;
	7896	 1810	 0.00042	 0.00367	 0.0	 8552	 8552	 8552	 0.0	 0.0	 1	 -30.0	 30.0;
	10888	 6271	 0.0023	 0.01644	 0.0	 1903	 1903	 1903	 0.0	 0.0	 1	 -30.0	 30.0;
	10888	 6271	 0.00226	 0.01676	 0.0	 1868	 1868	 1868	 0.0	 0.0	 1	 -30.0	 30.0;
	10888	 6271	 0.0023	 0.0162	 0.0	 1931	 1931	 1931	 0.0	 0.0	 1	 -30.0	 30.0;
	10888	 6271	 0.00225	 0.015	 0.0	 2083	 2083	 2083	 0.0	 0.0	 1	 -30.0	 30.0;
	3354	 8661	 0.007281	 0.035729	 0.0	 867	 867	 867	 0.0	 0.0	 1	 -30.0	 30.0;
	3191	 8661	 0.001919	 0.00945	 0.0	 3276	 3276	 3276	 0.0	 0.0	 1	 -30.0	 30.0;
	5604	 1680	 0.005211	 0.02981	 0.0	 1044	 1044	 1044	 0.0	 0.0	 1	 -30.0	 30.0;
	5604	 10130	 0.000659	 0.00586	 0.0	 5357	 5357	 5357	 0.0	 0.0	 1	 -30.0	 30.0;
	5604	 10130	 0.000591	 0.00664	 0.0	 4739	 4739	 4739	 0.0	 0.0	 1	 -30.0	 30.0;
	5604	 2537	 0.011969	 0.07424	 0.0	 421	 421	 421	 0.0	 0.0	 1	 -30.0	 30.0;
	2317	 4418	 0.000531	 0.003919	 0.0	 7988	 7988	 7988	 0.0	 0.0	 1	 -30.0	 30.0;
	6059	 4929	 0.001521	 0.00718	 0.0	 4304	 4304	 4304	 0.0	 0.0	 1	 -30.0	 30.0;
	6059	 4929	 0.001211	 0.00613	 0.0	 5056	 5056	 5056	 0.0	 0.0	 1	 -30.0	 30.0;
	6059	 7041	 0.00676	 0.03725	 0.0	 835	 835	 835	 0.0	 0.0	 1	 -30.0	 30.0;
	6059	 10176	 0.00399	 0.018091	 0.0	 1706	 1706	 1706	 0.0	 0.0	 1	 -30.0	 30.0;
	9739	 7610	 0.000341	 0.00339	 0.0	 9272	 9272	 9272	 0.0	 0.0	 1	 -30.0	 30.0;
	9739	 6027	 0.001271	 0.0102	 0.0	 3074	 3074	 3074	 0.0	 0.0	 1	 -30.0	 30.0;
	9739	 6027	 0.00125	 0.010401	 0.0	 3016	 3016	 3016	 0.0	 0.0	 1	 -30.0	 30.0;
	7118	 745	 0.00261	 0.016651	 0.0	 1875	 1875	 1875	 0.0	 0.0	 1	 -30.0	 30.0;
	13552	 745	 0.000219	 0.002409	 0.0	 13059	 13059	 13059	 0.0	 0.0	 1	 -30.0	 30.0;
	9886	 6960	 0.00601	 0.02814	 0.0	 1098	 1098	 1098	 0.0	 0.0	 1	 -30.0	 30.0;
	6960	 10230	 0.008969	 0.03787	 0.0	 812	 812	 812	 0.0	 0.0	 1	 -30.0	 30.0;
	6960	 6294	 0.00232	 0.01094	 0.0	 2825	 2825	 2825	 0.0	 0.0	 1	 -30.0	 30.0;
	1388	 10105	 0.00196	 0.02382	 0.0	 1322	 1322	 1322	 0.0	 0.0	 1	 -30.0	 30.0;
	1388	 10506	 0.00422	 0.03598	 0.0	 872	 872	 872	 0.0	 0.0	 1	 -30.0	 30.0;
	1388	 10506	 0.0043	 0.03522	 0.0	 891	 891	 891	 0.0	 0.0	 1	 -30.0	 30.0;
	12544	 1388	 0.00208	 0.01691	 0.0	 1854	 1854	 1854	 0.0	 0.0	 1	 -30.0	 30.0;
	1388	 3905	 0.00544	 0.05439	 0.0	 578	 578	 578	 0.0	 0.0	 1	 -30.0	 30.0;
	1388	 205	 0.00239	 0.02598	 0.0	 1211	 1211	 1211	 0.0	 0.0	 1	 -30.0	 30.0;
	1388	 570	 0.00396	 0.03096	 0.0	 1013	 1013	 1013	 0.0	 0.0	 1	 -30.0	 30.0;
	1388	 570	 0.00353	 0.03509	 0.0	 896	 896	 896	 0.0	 0.0	 1	 -30.0	 30.0;
	5387	 13117	 0.000531	 0.003729	 0.0	 8387	 8387	 8387	 0.0	 0.0	 1	 -30.0	 30.0;
	5387	 13117	 0.00038	 0.0025	 0.0	 12492	 12492	 12492	 0.0	 0.0	 1	 -30.0	 30.0;
	5387	 13117	 0.00039	 0.00244	 0.0	 12784	 12784	 12784	 0.0	 0.0	 1	 -30.0	 30.0;
	5387	 2029	 0.00836	 0.044521	 0.0	 698	 698	 698	 0.0	 0.0	 1	 -30.0	 30.0;
	2306	 1524	 0.00264	 0.03029	 0.0	 1039	 1039	 1039	 0.0	 0.0	 1	 -30.0	 30.0;
	2306	 9878	 0.00396	 0.04589	 0.0	 686	 686	 686	 0.0	 0.0	 1	 -30.0	 30.0;
	12613	 9746	 0.00411	 0.021729	 0.0	 1429	 1429	 1429	 0.0	 0.0	 1	 -30.0	 30.0;
	12613	 10844	 0.00607	 0.0285	 0.0	 1085	 1085	 1085	 0.0	 0.0	 1	 -30.0	 30.0;
	11948	 2940	 0.00075	 0.0047	 0.0	 6637	 6637	 6637	 0.0	 0.0	 1	 -30.0	 30.0;
	6470	 2940	 0.00114	 0.007969	 0.0	 3924	 3924	 3924	 0.0	 0.0	 1	 -30.0	 30.0;
	4530	 4189	 0.00036	 0.00324	 0.0	 9690	 9690	 9690	 0.0	 0.0	 1	 -30.0	 30.0;
	4530	 13271	 0.00094	 0.00874	 0.0	 3594	 3594	 3594	 0.0	 0.0	 1	 -30.0	 30.0;
	3545	 10628	 0.00949	 0.05145	 0.0	 604	 604	 604	 0.0	 0.0	 1	 -30.0	 30.0;
	3545	 7193	 0.011719	 0.0337	 0.0	 886	 886	 886	 0.0	 0.0	 1	 -30.0	 30.0;
	4446	 3545	 0.0022	 0.012331	 0.0	 2522	 2522	 2522	 0.0	 0.0	 1	 -30.0	 30.0;
	6137	 6365	 0.00038	 0.00448	 0.0	 7026	 7026	 7026	 0.0	 0.0	 1	 -30.0	 30.0;
	6137	 8556	 0.00098	 0.01126	 0.0	 2795	 2795	 2795	 0.0	 0.0	 1	 -30.0	 30.0;
	53	 8622	 0.00055	 0.00621	 0.0	 5067	 5067	 5067	 0.0	 0.0	 1	 -30.0	 30.0;
	53	 2965	 0.00163	 0.01287	 0.0	 2435	 2435	 2435	 0.0	 0.0	 1	 -30.0	 30.0;
	9185	 13349	 0.0018	 0.01886	 0.0	 1668	 1668	 1668	 0.0	 0.0	 1	 -30.0	 30.0;
	9185	 13349	 0.0047	 0.024969	 0.0	 1244	 1244	 1244	 0.0	 0.0	 1	 -30.0	 30.0;
	9185	 3807	 0.009711	 0.059669	 0.0	 523	 523	 523	 0.0	 0.0	 1	 -30.0	 30.0;
	9185	 7582	 0.005271	 0.03451	 0.0	 905	 905	 905	 0.0	 0.0	 1	 -30.0	 30.0;
	1301	 1682	 0.016169	 0.11936	 0.0	 263	 263	 263	 0.0	 0.0	 1	 -30.0	 30.0;
	1301	 1908	 0.00226	 0.014789	 0.0	 2112	 2112	 2112	 0.0	 0.0	 1	 -30.0	 30.0;
	12834	 2015	 0.00151	 0.01081	 0.0	 2894	 2894	 2894	 0.0	 0.0	 1	 -30.0	 30.0;
	1029	 6829	 0.00228	 0.0217	 0.0	 1448	 1448	 1448	 0.0	 0.0	 1	 -30.0	 30.0;
	1029	 5263	 0.00137	 0.01593	 0.0	 1976	 1976	 1976	 0.0	 0.0	 1	 -30.0	 30.0;
	12004	 5573	 0.00099	 0.0121	 0.0	 2602	 2602	 2602	 0.0	 0.0	 1	 -30.0	 30.0;
	12004	 3230	 0.0	 0.01881	 0.0	 1680	 1680	 1680	 0.0	 0.0	 1	 -30.0	 30.0;
	12004	 456	 0.00143	 0.0163	 0.0	 1931	 1931	 1931	 0.0	 0.0	 1	 -30.0	 30.0;
	12004	 10680	 0.00057	 0.00562	 0.0	 5592	 5592	 5592	 0.0	 0.0	 1	 -30.0	 30.0;
	12004	 10680	 0.00055	 0.00572	 0.0	 5497	 5497	 5497	 0.0	 0.0	 1	 -30.0	 30.0;
	12004	 9505	 0.00057	 0.00658	 0.0	 4783	 4783	 4783	 0.0	 0.0	 1	 -30.0	 30.0;
	12004	 7826	 0.00075	 0.0082	 0.0	 3837	 3837	 3837	 0.0	 0.0	 1	 -30.0	 30.0;
	12004	 1156	 0.00253	 0.02153	 0.0	 1458	 1458	 1458	 0.0	 0.0	 1	 -30.0	 30.0;
	290	 12668	 0.00236	 0.011219	 0.0	 2756	 2756	 2756	 0.0	 0.0	 1	 -30.0	 30.0;
	4623	 7770	 0.00173	 0.0154	 0.0	 2039	 2039	 2039	 0.0	 0.0	 1	 -30.0	 30.0;
	4623	 3958	 0.00385	 0.04172	 0.0	 754	 754	 754	 0.0	 0.0	 1	 -30.0	 30.0;
	4623	 3958	 0.00377	 0.04251	 0.0	 741	 741	 741	 0.0	 0.0	 1	 -30.0	 30.0;
	4623	 2130	 0.00199	 0.02121	 0.0	 1483	 1483	 1483	 0.0	 0.0	 1	 -30.0	 30.0;
	4623	 1625	 0.00236	 0.01933	 0.0	 1623	 1623	 1623	 0.0	 0.0	 1	 -30.0	 30.0;
	4623	 1625	 0.00241	 0.01891	 0.0	 1658	 1658	 1658	 0.0	 0.0	 1	 -30.0	 30.0;
	3279	 5001	 0.000521	 0.004729	 0.0	 6640	 6640	 6640	 0.0	 0.0	 1	 -30.0	 30.0;
	3279	 7745	 0.00094	 0.005581	 0.0	 5582	 5582	 5582	 0.0	 0.0	 1	 -30.0	 30.0;
	6821	 1567	 0.00134	 0.01324	 0.0	 2374	 2374	 2374	 0.0	 0.0	 1	 -30.0	 30.0;
	6821	 4089	 0.00073	 0.00638	 0.0	 4919	 4919	 4919	 0.0	 0.0	 1	 -30.0	 30.0;
	2064	 3531	 0.00248	 0.02774	 0.0	 1135	 1135	 1135	 0.0	 0.0	 1	 -30.0	 30.0;
	2064	 701	 0.00152	 0.013	 0.0	 2414	 2414	 2414	 0.0	 0.0	 1	 -30.0	 30.0;
	2064	 701	 0.00155	 0.01272	 0.0	 2466	 2466	 2466	 0.0	 0.0	 1	 -30.0	 30.0;
	2064	 12079	 0.00117	 0.01301	 0.0	 2419	 2419	 2419	 0.0	 0.0	 1	 -30.0	 30.0;
	2064	 4503	 0.00197	 0.02054	 0.0	 1531	 1531	 1531	 0.0	 0.0	 1	 -30.0	 30.0;
	2064	 13287	 0.00157	 0.01909	 0.0	 1650	 1650	 1650	 0.0	 0.0	 1	 -30.0	 30.0;
	4418	 6529	 0.00107	 0.008669	 0.0	 3617	 3617	 3617	 0.0	 0.0	 1	 -30.0	 30.0;
	6529	 2134	 0.000469	 0.00314	 0.0	 9950	 9950	 9950	 0.0	 0.0	 1	 -30.0	 30.0;
	1692	 1026	 0.000409	 0.00305	 0.0	 10265	 10265	 10265	 0.0	 0.0	 1	 -30.0	 30.0;
	1755	 1026	 0.00569	 0.032979	 0.0	 944	 944	 944	 0.0	 0.0	 1	 -30.0	 30.0;
	5124	 13135	 0.00087	 0.006771	 0.0	 4628	 4628	 4628	 0.0	 0.0	 1	 -30.0	 30.0;
	5124	 12668	 0.002151	 0.014039	 0.0	 2225	 2225	 2225	 0.0	 0.0	 1	 -30.0	 30.0;
	9299	 9908	 9.9e-05	 0.00043	 0.0	 71587	 71587	 71587	 0.0	 0.0	 1	 -30.0	 30.0;
	9446	 9299	 0.000151	 0.0005	 0.0	 60477	 60477	 60477	 0.0	 0.0	 1	 -30.0	 30.0;
	11501	 3189	 0.001531	 0.00812	 0.0	 3823	 3823	 3823	 0.0	 0.0	 1	 -30.0	 30.0;
	11501	 3189	 0.00113	 0.00857	 0.0	 3655	 3655	 3655	 0.0	 0.0	 1	 -30.0	 30.0;
	6242	 10547	 0.00226	 0.01868	 0.0	 1679	 1679	 1679	 0.0	 0.0	 1	 -30.0	 30.0;
	6242	 6828	 0.000401	 0.00239	 0.0	 13035	 13035	 13035	 0.0	 0.0	 1	 -30.0	 30.0;
	6211	 2732	 0.001169	 0.008349	 0.0	 3747	 3747	 3747	 0.0	 0.0	 1	 -30.0	 30.0;
	6211	 9226	 0.00324	 0.02312	 0.0	 1354	 1354	 1354	 0.0	 0.0	 1	 -30.0	 30.0;
	905	 6399	 0.006031	 0.034789	 0.0	 895	 895	 895	 0.0	 0.0	 1	 -30.0	 30.0;
	905	 1157	 0.0103	 0.05269	 0.0	 589	 589	 589	 0.0	 0.0	 1	 -30.0	 30.0;
	4268	 10105	 0.00129	 0.01494	 0.0	 2107	 2107	 2107	 0.0	 0.0	 1	 -30.0	 30.0;
	4268	 10105	 0.00126	 0.01523	 0.0	 2067	 2067	 2067	 0.0	 0.0	 1	 -30.0	 30.0;
	7259	 7193	 0.001031	 0.00601	 0.0	 5181	 5181	 5181	 0.0	 0.0	 1	 -30.0	 30.0;
	7259	 7193	 0.00105	 0.00588	 0.0	 5289	 5289	 5289	 0.0	 0.0	 1	 -30.0	 30.0;
	3786	 8475	 0.00197	 0.01719	 0.0	 1826	 1826	 1826	 0.0	 0.0	 1	 -30.0	 30.0;
	3786	 2775	 0.00114	 0.01237	 0.0	 2543	 2543	 2543	 0.0	 0.0	 1	 -30.0	 30.0;
	3786	 5833	 0.00314	 0.02868	 0.0	 1095	 1095	 1095	 0.0	 0.0	 1	 -30.0	 30.0;
	3786	 1543	 0.00294	 0.03326	 0.0	 947	 947	 947	 0.0	 0.0	 1	 -30.0	 30.0;
	3786	 1543	 0.00288	 0.0308	 0.0	 1022	 1022	 1022	 0.0	 0.0	 1	 -30.0	 30.0;
	3786	 1156	 0.00088	 0.02821	 0.0	 1120	 1120	 1120	 0.0	 0.0	 1	 -30.0	 30.0;
	6115	 9734	 0.00152	 0.01702	 0.0	 1849	 1849	 1849	 0.0	 0.0	 1	 -30.0	 30.0;
	6115	 10704	 0.00022	 0.00209	 0.0	 15031	 15031	 15031	 0.0	 0.0	 1	 -30.0	 30.0;
	2557	 9993	 0.00087	 0.005	 0.0	 6224	 6224	 6224	 0.0	 0.0	 1	 -30.0	 30.0;
	2557	 5778	 0.000711	 0.00439	 0.0	 7103	 7103	 7103	 0.0	 0.0	 1	 -30.0	 30.0;
	2557	 5778	 0.000729	 0.004289	 0.0	 7261	 7261	 7261	 0.0	 0.0	 1	 -30.0	 30.0;
	6841	 9431	 0.001031	 0.00549	 0.0	 5655	 5655	 5655	 0.0	 0.0	 1	 -30.0	 30.0;
	6841	 760	 0.003219	 0.01512	 0.0	 2044	 2044	 2044	 0.0	 0.0	 1	 -30.0	 30.0;
	6841	 875	 0.007271	 0.031419	 0.0	 980	 980	 980	 0.0	 0.0	 1	 -30.0	 30.0;
	6841	 4803	 0.02145	 0.085781	 0.0	 358	 358	 358	 0.0	 0.0	 1	 -30.0	 30.0;
	8978	 10984	 0.002841	 0.017771	 0.0	 1756	 1756	 1756	 0.0	 0.0	 1	 -30.0	 30.0;
	8978	 4149	 0.003331	 0.017289	 0.0	 1795	 1795	 1795	 0.0	 0.0	 1	 -30.0	 30.0;
	2059	 3354	 0.01524	 0.064091	 0.0	 480	 480	 480	 0.0	 0.0	 1	 -30.0	 30.0;
	7404	 7479	 0.000831	 0.0052	 0.0	 5999	 5999	 5999	 0.0	 0.0	 1	 -30.0	 30.0;
	7479	 340	 0.00164	 0.0103	 0.0	 3029	 3029	 3029	 0.0	 0.0	 1	 -30.0	 30.0;
	5823	 6224	 0.00139	 0.00864	 0.0	 3610	 3610	 3610	 0.0	 0.0	 1	 -30.0	 30.0;
	5823	 9844	 0.00143	 0.00764	 0.0	 4064	 4064	 4064	 0.0	 0.0	 1	 -30.0	 30.0;
	5823	 8419	 0.000229	 0.00126	 0.0	 24666	 24666	 24666	 0.0	 0.0	 1	 -30.0	 30.0;
	5823	 8419	 0.000211	 0.00143	 0.0	 21853	 21853	 21853	 0.0	 0.0	 1	 -30.0	 30.0;
	1377	 2214	 0.0008	 0.01072	 0.0	 2939	 2939	 2939	 0.0	 0.0	 1	 -30.0	 30.0;
	1377	 6743	 0.00067	 0.00661	 0.0	 4755	 4755	 4755	 0.0	 0.0	 1	 -30.0	 30.0;
	1377	 4003	 0.0003	 0.00427	 0.0	 7380	 7380	 7380	 0.0	 0.0	 1	 -30.0	 30.0;
	1377	 4003	 0.00068	 0.00648	 0.0	 4848	 4848	 4848	 0.0	 0.0	 1	 -30.0	 30.0;
	2280	 12048	 0.0002	 0.001289	 0.0	 24216	 24216	 24216	 0.0	 0.0	 1	 -30.0	 30.0;
	2280	 5895	 0.00013	 0.000961	 0.0	 32573	 32573	 32573	 0.0	 0.0	 1	 -30.0	 30.0;
	8383	 6365	 0.00118	 0.01285	 0.0	 2448	 2448	 2448	 0.0	 0.0	 1	 -30.0	 30.0;
	8383	 7640	 0.00062	 0.00577	 0.0	 5444	 5444	 5444	 0.0	 0.0	 1	 -30.0	 30.0;
	13625	 1996	 9.1e-05	 0.000289	 0.0	 104253	 104253	 104253	 0.0	 0.0	 1	 -30.0	 30.0;
	13625	 1996	 9.1e-05	 0.000271	 0.0	 110496	 110496	 110496	 0.0	 0.0	 1	 -30.0	 30.0;
	13625	 9649	 0.0003	 0.002719	 0.0	 11548	 11548	 11548	 0.0	 0.0	 1	 -30.0	 30.0;
	13625	 9986	 0.00049	 0.002091	 0.0	 14708	 14708	 14708	 0.0	 0.0	 1	 -30.0	 30.0;
	13625	 19	 0.000159	 0.001461	 0.0	 21494	 21494	 21494	 0.0	 0.0	 1	 -30.0	 30.0;
	631	 8970	 0.00301	 0.02281	 0.0	 1373	 1373	 1373	 0.0	 0.0	 1	 -30.0	 30.0;
	4323	 8970	 0.0027	 0.019979	 0.0	 1567	 1567	 1567	 0.0	 0.0	 1	 -30.0	 30.0;
	2036	 946	 0.00019	 0.000539	 0.0	 55271	 55271	 55271	 0.0	 0.0	 1	 -30.0	 30.0;
	946	 9986	 0.000169	 0.00061	 0.0	 49903	 49903	 49903	 0.0	 0.0	 1	 -30.0	 30.0;
	6462	 7911	 0.00163	 0.00939	 0.0	 3315	 3315	 3315	 0.0	 0.0	 1	 -30.0	 30.0;
	6462	 7911	 0.001159	 0.009031	 0.0	 3470	 3470	 3470	 0.0	 0.0	 1	 -30.0	 30.0;
	6462	 5966	 9.9e-05	 0.00037	 0.0	 82471	 82471	 82471	 0.0	 0.0	 1	 -30.0	 30.0;
	8184	 1370	 0.003789	 0.01805	 0.0	 1713	 1713	 1713	 0.0	 0.0	 1	 -30.0	 30.0;
	8184	 13134	 0.00069	 0.00389	 0.0	 7996	 7996	 7996	 0.0	 0.0	 1	 -30.0	 30.0;
	6312	 11645	 0.00201	 0.01845	 0.0	 1702	 1702	 1702	 0.0	 0.0	 1	 -30.0	 30.0;
	9878	 11645	 0.00121	 0.00902	 0.0	 3471	 3471	 3471	 0.0	 0.0	 1	 -30.0	 30.0;
	6662	 2775	 0.00155	 0.01573	 0.0	 1999	 1999	 1999	 0.0	 0.0	 1	 -30.0	 30.0;
	6662	 3864	 0.00031	 0.00274	 0.0	 11456	 11456	 11456	 0.0	 0.0	 1	 -30.0	 30.0;
	6662	 5833	 0.00047	 0.00563	 0.0	 5592	 5592	 5592	 0.0	 0.0	 1	 -30.0	 30.0;
	6662	 5198	 0.00066	 0.00721	 0.0	 4363	 4363	 4363	 0.0	 0.0	 1	 -30.0	 30.0;
	10992	 7037	 0.00326	 0.016711	 0.0	 1856	 1856	 1856	 0.0	 0.0	 1	 -30.0	 30.0;
	10992	 4173	 0.002479	 0.01262	 0.0	 2457	 2457	 2457	 0.0	 0.0	 1	 -30.0	 30.0;
	10992	 4173	 0.00243	 0.01286	 0.0	 2414	 2414	 2414	 0.0	 0.0	 1	 -30.0	 30.0;
	10992	 6367	 0.004521	 0.02306	 0.0	 1345	 1345	 1345	 0.0	 0.0	 1	 -30.0	 30.0;
	10992	 1814	 0.00211	 0.00899	 0.0	 3421	 3421	 3421	 0.0	 0.0	 1	 -30.0	 30.0;
	10992	 286	 0.001289	 0.005651	 0.0	 5450	 5450	 5450	 0.0	 0.0	 1	 -30.0	 30.0;
	10992	 4937	 0.002479	 0.009021	 0.0	 3377	 3377	 3377	 0.0	 0.0	 1	 -30.0	 30.0;
	10992	 9448	 0.00151	 0.010521	 0.0	 2972	 2972	 2972	 0.0	 0.0	 1	 -30.0	 30.0;
	7876	 5919	 0.00101	 0.004151	 0.0	 7394	 7394	 7394	 0.0	 0.0	 1	 -30.0	 30.0;
	7876	 1147	 0.015599	 0.079	 0.0	 393	 393	 393	 0.0	 0.0	 1	 -30.0	 30.0;
	7876	 4466	 0.013961	 0.067591	 0.0	 458	 458	 458	 0.0	 0.0	 1	 -30.0	 30.0;
	7876	 1756	 0.007099	 0.043169	 0.0	 723	 723	 723	 0.0	 0.0	 1	 -30.0	 30.0;
	3457	 7382	 0.00317	 0.02987	 0.0	 1052	 1052	 1052	 0.0	 0.0	 1	 -30.0	 30.0;
	3457	 3958	 0.00081	 0.0088	 0.0	 3575	 3575	 3575	 0.0	 0.0	 1	 -30.0	 30.0;
	3457	 3958	 0.00098	 0.00961	 0.0	 3270	 3270	 3270	 0.0	 0.0	 1	 -30.0	 30.0;
	3457	 257	 0.00194	 0.02225	 0.0	 1415	 1415	 1415	 0.0	 0.0	 1	 -30.0	 30.0;
	13307	 7294	 0.001031	 0.006349	 0.0	 4911	 4911	 4911	 0.0	 0.0	 1	 -30.0	 30.0;
	13307	 656	 0.00668	 0.0297	 0.0	 1038	 1038	 1038	 0.0	 0.0	 1	 -30.0	 30.0;
	7041	 3643	 0.00439	 0.02236	 0.0	 1387	 1387	 1387	 0.0	 0.0	 1	 -30.0	 30.0;
	3643	 9362	 0.00249	 0.01349	 0.0	 2303	 2303	 2303	 0.0	 0.0	 1	 -30.0	 30.0;
	2949	 6682	 0.001969	 0.01205	 0.0	 2588	 2588	 2588	 0.0	 0.0	 1	 -30.0	 30.0;
	2949	 6733	 0.000461	 0.003031	 0.0	 10303	 10303	 10303	 0.0	 0.0	 1	 -30.0	 30.0;
	5272	 407	 0.00444	 0.023479	 0.0	 1322	 1322	 1322	 0.0	 0.0	 1	 -30.0	 30.0;
	5272	 6790	 0.00175	 0.01288	 0.0	 2431	 2431	 2431	 0.0	 0.0	 1	 -30.0	 30.0;
	5272	 6790	 0.001711	 0.01312	 0.0	 2388	 2388	 2388	 0.0	 0.0	 1	 -30.0	 30.0;
	2214	 847	 0.0008	 0.00784	 0.0	 4009	 4009	 4009	 0.0	 0.0	 1	 -30.0	 30.0;
	2214	 13478	 0.00051	 0.00612	 0.0	 5144	 5144	 5144	 0.0	 0.0	 1	 -30.0	 30.0;
	4789	 10464	 0.00137	 0.00905	 0.0	 3451	 3451	 3451	 0.0	 0.0	 1	 -30.0	 30.0;
	4789	 7118	 0.002771	 0.021409	 0.0	 1464	 1464	 1464	 0.0	 0.0	 1	 -30.0	 30.0;
	4789	 7118	 0.00314	 0.020979	 0.0	 1490	 1490	 1490	 0.0	 0.0	 1	 -30.0	 30.0;
	4789	 6026	 0.002	 0.01118	 0.0	 2782	 2782	 2782	 0.0	 0.0	 1	 -30.0	 30.0;
	11809	 1018	 0.00119	 0.00875	 0.0	 3578	 3578	 3578	 0.0	 0.0	 1	 -30.0	 30.0;
	11809	 10051	 0.00031	 0.00236	 0.0	 13271	 13271	 13271	 0.0	 0.0	 1	 -30.0	 30.0;
	11809	 11469	 0.000831	 0.00539	 0.0	 5792	 5792	 5792	 0.0	 0.0	 1	 -30.0	 30.0;
	407	 10780	 0.004349	 0.02394	 0.0	 1299	 1299	 1299	 0.0	 0.0	 1	 -30.0	 30.0;
	1709	 12300	 0.0007	 0.00782	 0.0	 4024	 4024	 4024	 0.0	 0.0	 1	 -30.0	 30.0;
	1709	 2449	 0.00046	 0.00432	 0.0	 7271	 7271	 7271	 0.0	 0.0	 1	 -30.0	 30.0;
	1709	 4420	 0.00049	 0.00617	 0.0	 5104	 5104	 5104	 0.0	 0.0	 1	 -30.0	 30.0;
	1709	 1543	 0.00127	 0.01514	 0.0	 2080	 2080	 2080	 0.0	 0.0	 1	 -30.0	 30.0;
	5206	 2731	 0.00232	 0.01843	 0.0	 1701	 1701	 1701	 0.0	 0.0	 1	 -30.0	 30.0;
	5206	 2140	 0.00488	 0.032151	 0.0	 972	 972	 972	 0.0	 0.0	 1	 -30.0	 30.0;
	1996	 5285	 0.000229	 0.00136	 0.0	 22904	 22904	 22904	 0.0	 0.0	 1	 -30.0	 30.0;
	1996	 9986	 0.0003	 0.001531	 0.0	 20247	 20247	 20247	 0.0	 0.0	 1	 -30.0	 30.0;
	1996	 4544	 0.00026	 0.00126	 0.0	 24553	 24553	 24553	 0.0	 0.0	 1	 -30.0	 30.0;
	1996	 8663	 0.00056	 0.002091	 0.0	 14593	 14593	 14593	 0.0	 0.0	 1	 -30.0	 30.0;
	6472	 4268	 0.00103	 0.0093	 0.0	 3376	 3376	 3376	 0.0	 0.0	 1	 -30.0	 30.0;
	6472	 3492	 0.00183	 0.01689	 0.0	 1860	 1860	 1860	 0.0	 0.0	 1	 -30.0	 30.0;
	10312	 7542	 0.00324	 0.01095	 0.0	 2767	 2767	 2767	 0.0	 0.0	 1	 -30.0	 30.0;
	352	 12118	 0.001419	 0.008539	 0.0	 3650	 3650	 3650	 0.0	 0.0	 1	 -30.0	 30.0;
	352	 5001	 0.00068	 0.00438	 0.0	 7127	 7127	 7127	 0.0	 0.0	 1	 -30.0	 30.0;
	4189	 11083	 0.00178	 0.01651	 0.0	 1903	 1903	 1903	 0.0	 0.0	 1	 -30.0	 30.0;
	4189	 6322	 0.00151	 0.01827	 0.0	 1724	 1724	 1724	 0.0	 0.0	 1	 -30.0	 30.0;
	4189	 6322	 0.00148	 0.01862	 0.0	 1692	 1692	 1692	 0.0	 0.0	 1	 -30.0	 30.0;
	4268	 3492	 0.00201	 0.02546	 0.0	 1237	 1237	 1237	 0.0	 0.0	 1	 -30.0	 30.0;
	4268	 3492	 0.00197	 0.02357	 0.0	 1336	 1336	 1336	 0.0	 0.0	 1	 -30.0	 30.0;
	5507	 5001	 0.001091	 0.00775	 0.0	 4036	 4036	 4036	 0.0	 0.0	 1	 -30.0	 30.0;
	5507	 1399	 0.000841	 0.006669	 0.0	 4700	 4700	 4700	 0.0	 0.0	 1	 -30.0	 30.0;
	1311	 5766	 0.00151	 0.012081	 0.0	 2595	 2595	 2595	 0.0	 0.0	 1	 -30.0	 30.0;
	1311	 10929	 0.00032	 0.002521	 0.0	 12430	 12430	 12430	 0.0	 0.0	 1	 -30.0	 30.0;
	3461	 2125	 0.006091	 0.03019	 0.0	 1026	 1026	 1026	 0.0	 0.0	 1	 -30.0	 30.0;
	3461	 11213	 0.003651	 0.016461	 0.0	 1874	 1874	 1874	 0.0	 0.0	 1	 -30.0	 30.0;
	3461	 4865	 0.00076	 0.00425	 0.0	 7317	 7317	 7317	 0.0	 0.0	 1	 -30.0	 30.0;
	3461	 4865	 0.00087	 0.004031	 0.0	 7660	 7660	 7660	 0.0	 0.0	 1	 -30.0	 30.0;
	2343	 5766	 0.000651	 0.004729	 0.0	 6618	 6618	 6618	 0.0	 0.0	 1	 -30.0	 30.0;
	2343	 2504	 0.00045	 0.00337	 0.0	 9291	 9291	 9291	 0.0	 0.0	 1	 -30.0	 30.0;
	4173	 706	 0.001539	 0.00839	 0.0	 3704	 3704	 3704	 0.0	 0.0	 1	 -30.0	 30.0;
	4173	 706	 0.001919	 0.010479	 0.0	 2966	 2966	 2966	 0.0	 0.0	 1	 -30.0	 30.0;
	706	 12040	 0.001169	 0.007031	 0.0	 4432	 4432	 4432	 0.0	 0.0	 1	 -30.0	 30.0;
	2707	 706	 0.00739	 0.034081	 0.0	 906	 906	 906	 0.0	 0.0	 1	 -30.0	 30.0;
	7171	 706	 0.00164	 0.00964	 0.0	 3231	 3231	 3231	 0.0	 0.0	 1	 -30.0	 30.0;
	8585	 706	 0.00206	 0.012	 0.0	 2595	 2595	 2595	 0.0	 0.0	 1	 -30.0	 30.0;
	7854	 706	 0.000961	 0.00531	 0.0	 5854	 5854	 5854	 0.0	 0.0	 1	 -30.0	 30.0;
	5198	 9891	 6e-05	 0.00029	 0.0	 106663	 106663	 106663	 0.0	 0.0	 1	 -30.0	 30.0;
	1908	 7037	 0.001919	 0.013151	 0.0	 2377	 2377	 2377	 0.0	 0.0	 1	 -30.0	 30.0;
	1227	 7037	 0.00019	 0.00107	 0.0	 29067	 29067	 29067	 0.0	 0.0	 1	 -30.0	 30.0;
	1227	 7037	 0.00018	 0.001091	 0.0	 28567	 28567	 28567	 0.0	 0.0	 1	 -30.0	 30.0;
	8272	 3531	 0.00147	 0.01714	 0.0	 1837	 1837	 1837	 0.0	 0.0	 1	 -30.0	 30.0;
	3905	 3531	 0.00143	 0.01632	 0.0	 1929	 1929	 1929	 0.0	 0.0	 1	 -30.0	 30.0;
	3905	 3531	 0.00142	 0.01416	 0.0	 2220	 2220	 2220	 0.0	 0.0	 1	 -30.0	 30.0;
	3905	 3531	 0.00145	 0.01386	 0.0	 2267	 2267	 2267	 0.0	 0.0	 1	 -30.0	 30.0;
	3531	 13287	 0.00073	 0.00732	 0.0	 4294	 4294	 4294	 0.0	 0.0	 1	 -30.0	 30.0;
	1692	 1755	 0.009039	 0.05989	 0.0	 522	 522	 522	 0.0	 0.0	 1	 -30.0	 30.0;
	1692	 8177	 0.007919	 0.04975	 0.0	 628	 628	 628	 0.0	 0.0	 1	 -30.0	 30.0;
	9993	 1386	 0.000521	 0.005841	 0.0	 5387	 5387	 5387	 0.0	 0.0	 1	 -30.0	 30.0;
	9993	 1591	 0.000521	 0.0028	 0.0	 11091	 11091	 11091	 0.0	 0.0	 1	 -30.0	 30.0;
	9603	 1543	 0.0007	 0.00744	 0.0	 4227	 4227	 4227	 0.0	 0.0	 1	 -30.0	 30.0;
	9603	 5915	 0.00159	 0.0148	 0.0	 2123	 2123	 2123	 0.0	 0.0	 1	 -30.0	 30.0;
	253	 6238	 0.000659	 0.005151	 0.0	 6083	 6083	 6083	 0.0	 0.0	 1	 -30.0	 30.0;
	10547	 6238	 0.000729	 0.004901	 0.0	 6375	 6375	 6375	 0.0	 0.0	 1	 -30.0	 30.0;
	6743	 5854	 0.00064	 0.00772	 0.0	 4078	 4078	 4078	 0.0	 0.0	 1	 -30.0	 30.0;
	11069	 9042	 0.00018	 0.00093	 0.0	 33347	 33347	 33347	 0.0	 0.0	 1	 -30.0	 30.0;
	11069	 12048	 0.00019	 0.00118	 0.0	 26429	 26429	 26429	 0.0	 0.0	 1	 -30.0	 30.0;
	10866	 11069	 0.000409	 0.002341	 0.0	 13292	 13292	 13292	 0.0	 0.0	 1	 -30.0	 30.0;
	9175	 1460	 0.00087	 0.006591	 0.0	 4752	 4752	 4752	 0.0	 0.0	 1	 -30.0	 30.0;
	9175	 4415	 0.00162	 0.0098	 0.0	 3181	 3181	 3181	 0.0	 0.0	 1	 -30.0	 30.0;
	205	 7770	 0.00096	 0.00849	 0.0	 3697	 3697	 3697	 0.0	 0.0	 1	 -30.0	 30.0;
	9039	 10126	 0.000341	 0.001081	 0.0	 27867	 27867	 27867	 0.0	 0.0	 1	 -30.0	 30.0;
	9039	 10126	 0.0003	 0.001219	 0.0	 25162	 25162	 25162	 0.0	 0.0	 1	 -30.0	 30.0;
	9039	 11868	 9.9e-05	 0.00076	 0.0	 41215	 41215	 41215	 0.0	 0.0	 1	 -30.0	 30.0;
	9039	 11868	 0.00011	 0.00074	 0.0	 42222	 42222	 42222	 0.0	 0.0	 1	 -30.0	 30.0;
	2288	 7118	 0.00151	 0.009039	 0.0	 3447	 3447	 3447	 0.0	 0.0	 1	 -30.0	 30.0;
	2288	 8982	 0.00356	 0.02331	 0.0	 1340	 1340	 1340	 0.0	 0.0	 1	 -30.0	 30.0;
	11764	 2036	 0.000281	 0.00169	 0.0	 18438	 18438	 18438	 0.0	 0.0	 1	 -30.0	 30.0;
	11764	 9649	 0.000169	 0.001531	 0.0	 20508	 20508	 20508	 0.0	 0.0	 1	 -30.0	 30.0;
	11764	 12820	 0.00038	 0.00326	 0.0	 9625	 9625	 9625	 0.0	 0.0	 1	 -30.0	 30.0;
	1567	 9646	 0.00136	 0.01738	 0.0	 1812	 1812	 1812	 0.0	 0.0	 1	 -30.0	 30.0;
	9431	 760	 0.00186	 0.0133	 0.0	 2353	 2353	 2353	 0.0	 0.0	 1	 -30.0	 30.0;
	9431	 760	 0.00182	 0.01356	 0.0	 2309	 2309	 2309	 0.0	 0.0	 1	 -30.0	 30.0;
	2630	 9431	 0.002531	 0.015919	 0.0	 1960	 1960	 1960	 0.0	 0.0	 1	 -30.0	 30.0;
	9431	 9858	 0.00289	 0.015969	 0.0	 1947	 1947	 1947	 0.0	 0.0	 1	 -30.0	 30.0;
	1612	 2943	 0.001771	 0.01107	 0.0	 2818	 2818	 2818	 0.0	 0.0	 1	 -30.0	 30.0;
	6177	 2943	 0.007969	 0.04238	 0.0	 733	 733	 733	 0.0	 0.0	 1	 -30.0	 30.0;
	4173	 297	 0.00013	 0.00062	 0.0	 49864	 49864	 49864	 0.0	 0.0	 1	 -30.0	 30.0;
	4173	 427	 0.0002	 0.00201	 0.0	 15638	 15638	 15638	 0.0	 0.0	 1	 -30.0	 30.0;
	701	 13545	 0.00095	 0.01024	 0.0	 3072	 3072	 3072	 0.0	 0.0	 1	 -30.0	 30.0;
	1625	 13545	 0.00553	 0.04909	 0.0	 640	 640	 640	 0.0	 0.0	 1	 -30.0	 30.0;
	4596	 9509	 0.009229	 0.03693	 0.0	 830	 830	 830	 0.0	 0.0	 1	 -30.0	 30.0;
	5566	 9509	 0.00451	 0.028469	 0.0	 1096	 1096	 1096	 0.0	 0.0	 1	 -30.0	 30.0;
	9509	 8799	 0.003591	 0.01906	 0.0	 1629	 1629	 1629	 0.0	 0.0	 1	 -30.0	 30.0;
	9509	 10844	 0.010159	 0.05169	 0.0	 600	 600	 600	 0.0	 0.0	 1	 -30.0	 30.0;
	112	 3007	 0.00039	 0.003099	 0.0	 10113	 10113	 10113	 0.0	 0.0	 1	 -30.0	 30.0;
	112	 10032	 0.000729	 0.0048	 0.0	 6507	 6507	 6507	 0.0	 0.0	 1	 -30.0	 30.0;
	10450	 9734	 0.00141	 0.01296	 0.0	 2423	 2423	 2423	 0.0	 0.0	 1	 -30.0	 30.0;
	5419	 5041	 0.001969	 0.019229	 0.0	 1635	 1635	 1635	 0.0	 0.0	 1	 -30.0	 30.0;
	5419	 13240	 0.001081	 0.0105	 0.0	 2993	 2993	 2993	 0.0	 0.0	 1	 -30.0	 30.0;
	5419	 13240	 0.00105	 0.010711	 0.0	 2935	 2935	 2935	 0.0	 0.0	 1	 -30.0	 30.0;
	8272	 4089	 0.00052	 0.00449	 0.0	 6989	 6989	 6989	 0.0	 0.0	 1	 -30.0	 30.0;
	4929	 9362	 0.01024	 0.056349	 0.0	 552	 552	 552	 0.0	 0.0	 1	 -30.0	 30.0;
	4929	 2171	 0.004599	 0.023659	 0.0	 1311	 1311	 1311	 0.0	 0.0	 1	 -30.0	 30.0;
	4929	 4705	 0.010021	 0.057409	 0.0	 543	 543	 543	 0.0	 0.0	 1	 -30.0	 30.0;
	4929	 4803	 0.00275	 0.01525	 0.0	 2039	 2039	 2039	 0.0	 0.0	 1	 -30.0	 30.0;
	1009	 4869	 0.00107	 0.01122	 0.0	 2803	 2803	 2803	 0.0	 0.0	 1	 -30.0	 30.0;
	1009	 11083	 0.00242	 0.02336	 0.0	 1345	 1345	 1345	 0.0	 0.0	 1	 -30.0	 30.0;
	1009	 5263	 0.00165	 0.01303	 0.0	 2405	 2405	 2405	 0.0	 0.0	 1	 -30.0	 30.0;
	1009	 5263	 0.00155	 0.01332	 0.0	 2356	 2356	 2356	 0.0	 0.0	 1	 -30.0	 30.0;
	10220	 8692	 0.00087	 0.005469	 0.0	 5704	 5704	 5704	 0.0	 0.0	 1	 -30.0	 30.0;
	10220	 8692	 0.002281	 0.011909	 0.0	 2606	 2606	 2606	 0.0	 0.0	 1	 -30.0	 30.0;
	10220	 1368	 0.00106	 0.01076	 0.0	 2922	 2922	 2922	 0.0	 0.0	 1	 -30.0	 30.0;
	10220	 7790	 0.001409	 0.01618	 0.0	 1945	 1945	 1945	 0.0	 0.0	 1	 -30.0	 30.0;
	10220	 3480	 0.00306	 0.015521	 0.0	 1997	 1997	 1997	 0.0	 0.0	 1	 -30.0	 30.0;
	5646	 7404	 0.000969	 0.006831	 0.0	 4579	 4579	 4579	 0.0	 0.0	 1	 -30.0	 30.0;
	5646	 340	 0.002531	 0.016961	 0.0	 1842	 1842	 1842	 0.0	 0.0	 1	 -30.0	 30.0;
	1457	 390	 0.01207	 0.077901	 0.0	 401	 401	 401	 0.0	 0.0	 1	 -30.0	 30.0;
	1457	 10130	 0.014091	 0.080581	 0.0	 387	 387	 387	 0.0	 0.0	 1	 -30.0	 30.0;
	1457	 2537	 0.003289	 0.01481	 0.0	 2083	 2083	 2083	 0.0	 0.0	 1	 -30.0	 30.0;
	1457	 245	 0.003349	 0.0145	 0.0	 2123	 2123	 2123	 0.0	 0.0	 1	 -30.0	 30.0;
	1315	 5566	 0.005651	 0.026479	 0.0	 1167	 1167	 1167	 0.0	 0.0	 1	 -30.0	 30.0;
	1315	 11213	 0.01193	 0.064669	 0.0	 481	 481	 481	 0.0	 0.0	 1	 -30.0	 30.0;
	9746	 7463	 0.004151	 0.017281	 0.0	 1778	 1778	 1778	 0.0	 0.0	 1	 -30.0	 30.0;
	8018	 10464	 0.00213	 0.014091	 0.0	 2217	 2217	 2217	 0.0	 0.0	 1	 -30.0	 30.0;
	6367	 2707	 0.00113	 0.00651	 0.0	 4781	 4781	 4781	 0.0	 0.0	 1	 -30.0	 30.0;
	6367	 2707	 0.001159	 0.00637	 0.0	 4879	 4879	 4879	 0.0	 0.0	 1	 -30.0	 30.0;
	6367	 9448	 0.00611	 0.03288	 0.0	 945	 945	 945	 0.0	 0.0	 1	 -30.0	 30.0;
	13233	 1203	 0.00012	 0.00156	 0.0	 20189	 20189	 20189	 0.0	 0.0	 1	 -30.0	 30.0;
	13233	 1203	 0.00013	 0.00153	 0.0	 20572	 20572	 20572	 0.0	 0.0	 1	 -30.0	 30.0;
	13233	 9883	 0.00285	 0.03071	 0.0	 1025	 1025	 1025	 0.0	 0.0	 1	 -30.0	 30.0;
	8692	 4149	 0.00676	 0.03787	 0.0	 822	 822	 822	 0.0	 0.0	 1	 -30.0	 30.0;
	8692	 13367	 0.004461	 0.023521	 0.0	 1320	 1320	 1320	 0.0	 0.0	 1	 -30.0	 30.0;
	6340	 900	 0.00064	 0.0078	 0.0	 4037	 4037	 4037	 0.0	 0.0	 1	 -30.0	 30.0;
	6340	 900	 0.00065	 0.00764	 0.0	 4120	 4120	 4120	 0.0	 0.0	 1	 -30.0	 30.0;
	6340	 847	 0.00066	 0.00602	 0.0	 5216	 5216	 5216	 0.0	 0.0	 1	 -30.0	 30.0;
	6340	 6519	 0.00149	 0.01224	 0.0	 2562	 2562	 2562	 0.0	 0.0	 1	 -30.0	 30.0;
	6340	 1163	 0.00061	 0.00582	 0.0	 5398	 5398	 5398	 0.0	 0.0	 1	 -30.0	 30.0;
	5358	 10085	 0.001461	 0.00744	 0.0	 4167	 4167	 4167	 0.0	 0.0	 1	 -30.0	 30.0;
	5358	 11469	 0.00386	 0.02406	 0.0	 1297	 1297	 1297	 0.0	 0.0	 1	 -30.0	 30.0;
	5358	 13224	 0.00306	 0.01555	 0.0	 1994	 1994	 1994	 0.0	 0.0	 1	 -30.0	 30.0;
	5358	 13224	 0.003	 0.01586	 0.0	 1957	 1957	 1957	 0.0	 0.0	 1	 -30.0	 30.0;
	5349	 6045	 0.003271	 0.020651	 0.0	 1511	 1511	 1511	 0.0	 0.0	 1	 -30.0	 30.0;
	6045	 11168	 0.000849	 0.00657	 0.0	 4769	 4769	 4769	 0.0	 0.0	 1	 -30.0	 30.0;
	2352	 4419	 0.000211	 0.001169	 0.0	 26592	 26592	 26592	 0.0	 0.0	 1	 -30.0	 30.0;
	2352	 11725	 0.000469	 0.00345	 0.0	 9073	 9073	 9073	 0.0	 0.0	 1	 -30.0	 30.0;
	7241	 205	 0.00126	 0.0145	 0.0	 2171	 2171	 2171	 0.0	 0.0	 1	 -30.0	 30.0;
	2794	 8640	 0.008219	 0.04925	 0.0	 633	 633	 633	 0.0	 0.0	 1	 -30.0	 30.0;
	2794	 11738	 0.006771	 0.04132	 0.0	 755	 755	 755	 0.0	 0.0	 1	 -30.0	 30.0;
	10870	 11116	 0.000841	 0.004539	 0.0	 6843	 6843	 6843	 0.0	 0.0	 1	 -30.0	 30.0;
	10870	 5566	 0.00701	 0.03161	 0.0	 976	 976	 976	 0.0	 0.0	 1	 -30.0	 30.0;
	10870	 6294	 0.000781	 0.004271	 0.0	 7276	 7276	 7276	 0.0	 0.0	 1	 -30.0	 30.0;
	10870	 1358	 0.00049	 0.0032	 0.0	 9758	 9758	 9758	 0.0	 0.0	 1	 -30.0	 30.0;
	5107	 5595	 0.000331	 0.00199	 0.0	 15658	 15658	 15658	 0.0	 0.0	 1	 -30.0	 30.0;
	1911	 5595	 0.00032	 0.002031	 0.0	 15364	 15364	 15364	 0.0	 0.0	 1	 -30.0	 30.0;
	5595	 8005	 9.1e-05	 0.00057	 0.0	 54724	 54724	 54724	 0.0	 0.0	 1	 -30.0	 30.0;
	7813	 1227	 0.001651	 0.006789	 0.0	 4521	 4521	 4521	 0.0	 0.0	 1	 -30.0	 30.0;
	7813	 4937	 0.001461	 0.007229	 0.0	 4283	 4283	 4283	 0.0	 0.0	 1	 -30.0	 30.0;
	5919	 13367	 0.00437	 0.023979	 0.0	 1296	 1296	 1296	 0.0	 0.0	 1	 -30.0	 30.0;
	3046	 696	 0.00781	 0.04595	 0.0	 678	 678	 678	 0.0	 0.0	 1	 -30.0	 30.0;
	3046	 9114	 0.0015	 0.006531	 0.0	 4714	 4714	 4714	 0.0	 0.0	 1	 -30.0	 30.0;
	8377	 12040	 0.001031	 0.006469	 0.0	 4823	 4823	 4823	 0.0	 0.0	 1	 -30.0	 30.0;
	4003	 4412	 0.00183	 0.01686	 0.0	 1863	 1863	 1863	 0.0	 0.0	 1	 -30.0	 30.0;
	4003	 900	 0.0002	 0.00294	 0.0	 10720	 10720	 10720	 0.0	 0.0	 1	 -30.0	 30.0;
	4003	 900	 0.00021	 0.00288	 0.0	 10939	 10939	 10939	 0.0	 0.0	 1	 -30.0	 30.0;
	4003	 7382	 0.00171	 0.01889	 0.0	 1666	 1666	 1666	 0.0	 0.0	 1	 -30.0	 30.0;
	10506	 3958	 0.00069	 0.00565	 0.0	 5550	 5550	 5550	 0.0	 0.0	 1	 -30.0	 30.0;
	10506	 3958	 0.0007	 0.00553	 0.0	 5667	 5667	 5667	 0.0	 0.0	 1	 -30.0	 30.0;
	10371	 5568	 0.00011	 0.00115	 0.0	 27343	 27343	 27343	 0.0	 0.0	 1	 -30.0	 30.0;
	10371	 9773	 0.00012	 0.00126	 0.0	 24957	 24957	 24957	 0.0	 0.0	 1	 -30.0	 30.0;
	10371	 13271	 0.00326	 0.02919	 0.0	 1076	 1076	 1076	 0.0	 0.0	 1	 -30.0	 30.0;
	10371	 7407	 0.00092	 0.00876	 0.0	 3587	 3587	 3587	 0.0	 0.0	 1	 -30.0	 30.0;
	8401	 10126	 0.00087	 0.005409	 0.0	 5766	 5766	 5766	 0.0	 0.0	 1	 -30.0	 30.0;
	8401	 10032	 0.00131	 0.00701	 0.0	 4430	 4430	 4430	 0.0	 0.0	 1	 -30.0	 30.0;
	10578	 9731	 0.002531	 0.018781	 0.0	 1667	 1667	 1667	 0.0	 0.0	 1	 -30.0	 30.0;
	10578	 12923	 0.00894	 0.056909	 0.0	 549	 549	 549	 0.0	 0.0	 1	 -30.0	 30.0;
	8019	 7294	 0.00187	 0.010659	 0.0	 2919	 2919	 2919	 0.0	 0.0	 1	 -30.0	 30.0;
	11267	 7294	 0.00286	 0.01538	 0.0	 2020	 2020	 2020	 0.0	 0.0	 1	 -30.0	 30.0;
	7294	 7271	 0.0008	 0.00444	 0.0	 7002	 7002	 7002	 0.0	 0.0	 1	 -30.0	 30.0;
	1443	 11566	 0.00545	 0.03936	 0.0	 795	 795	 795	 0.0	 0.0	 1	 -30.0	 30.0;
	10886	 11566	 0.00119	 0.009031	 0.0	 3468	 3468	 3468	 0.0	 0.0	 1	 -30.0	 30.0;
	64	 8256	 0.00295	 0.0162	 0.0	 1919	 1919	 1919	 0.0	 0.0	 1	 -30.0	 30.0;
	64	 9025	 0.001581	 0.0087	 0.0	 3573	 3573	 3573	 0.0	 0.0	 1	 -30.0	 30.0;
	64	 3615	 0.007729	 0.025401	 0.0	 1190	 1190	 1190	 0.0	 0.0	 1	 -30.0	 30.0;
	11438	 2907	 0.00013	 0.001461	 0.0	 21536	 21536	 21536	 0.0	 0.0	 1	 -30.0	 30.0;
	11438	 8565	 0.000341	 0.02219	 0.0	 1424	 1424	 1424	 0.0	 0.0	 1	 -30.0	 30.0;
	11438	 5895	 0.00018	 0.001211	 0.0	 25801	 25801	 25801	 0.0	 0.0	 1	 -30.0	 30.0;
	11438	 11776	 0.003099	 0.0147	 0.0	 2103	 2103	 2103	 0.0	 0.0	 1	 -30.0	 30.0;
	11438	 11776	 0.003159	 0.014401	 0.0	 2143	 2143	 2143	 0.0	 0.0	 1	 -30.0	 30.0;
	10126	 6266	 0.00281	 0.01305	 0.0	 2367	 2367	 2367	 0.0	 0.0	 1	 -30.0	 30.0;
	10126	 13135	 0.002281	 0.01075	 0.0	 2875	 2875	 2875	 0.0	 0.0	 1	 -30.0	 30.0;
	10126	 13135	 0.00232	 0.010521	 0.0	 2932	 2932	 2932	 0.0	 0.0	 1	 -30.0	 30.0;
	10126	 5021	 0.000151	 0.000841	 0.0	 36969	 36969	 36969	 0.0	 0.0	 1	 -30.0	 30.0;
	10157	 3807	 0.002771	 0.012091	 0.0	 2547	 2547	 2547	 0.0	 0.0	 1	 -30.0	 30.0;
	10157	 8144	 0.00613	 0.03005	 0.0	 1030	 1030	 1030	 0.0	 0.0	 1	 -30.0	 30.0;
	2125	 11213	 0.003219	 0.02486	 0.0	 1261	 1261	 1261	 0.0	 0.0	 1	 -30.0	 30.0;
	9042	 11868	 0.000211	 0.001331	 0.0	 23440	 23440	 23440	 0.0	 0.0	 1	 -30.0	 30.0;
	12544	 2714	 0.00185	 0.01917	 0.0	 1641	 1641	 1641	 0.0	 0.0	 1	 -30.0	 30.0;
	1814	 1227	 0.00082	 0.00381	 0.0	 8106	 8106	 8106	 0.0	 0.0	 1	 -30.0	 30.0;
	11878	 11466	 0.00075	 0.004531	 0.0	 6878	 6878	 6878	 0.0	 0.0	 1	 -30.0	 30.0;
	11878	 11466	 0.000729	 0.00419	 0.0	 7428	 7428	 7428	 0.0	 0.0	 1	 -30.0	 30.0;
	11878	 40	 0.02626	 0.15576	 0.0	 200	 200	 200	 0.0	 0.0	 1	 -30.0	 30.0;
	11878	 10878	 0.011469	 0.03937	 0.0	 771	 771	 771	 0.0	 0.0	 1	 -30.0	 30.0;
	10455	 12048	 0.00011	 0.00061	 0.0	 50961	 50961	 50961	 0.0	 0.0	 1	 -30.0	 30.0;
	10455	 1530	 0.000531	 0.00313	 0.0	 9950	 9950	 9950	 0.0	 0.0	 1	 -30.0	 30.0;
	10455	 8972	 0.001211	 0.00864	 0.0	 3621	 3621	 3621	 0.0	 0.0	 1	 -30.0	 30.0;
	253	 6828	 0.00094	 0.006289	 0.0	 4968	 4968	 4968	 0.0	 0.0	 1	 -30.0	 30.0;
	1060	 5909	 0.001	 0.00886	 0.0	 3543	 3543	 3543	 0.0	 0.0	 1	 -30.0	 30.0;
	9886	 4596	 0.001979	 0.010469	 0.0	 2965	 2965	 2965	 0.0	 0.0	 1	 -30.0	 30.0;
	9886	 4596	 0.0017	 0.00855	 0.0	 3624	 3624	 3624	 0.0	 0.0	 1	 -30.0	 30.0;
	4596	 2997	 0.00757	 0.04624	 0.0	 675	 675	 675	 0.0	 0.0	 1	 -30.0	 30.0;
	4596	 5795	 0.001719	 0.00794	 0.0	 3889	 3889	 3889	 0.0	 0.0	 1	 -30.0	 30.0;
	4596	 5795	 0.00176	 0.007781	 0.0	 3960	 3960	 3960	 0.0	 0.0	 1	 -30.0	 30.0;
	4566	 1285	 0.00126	 0.0053	 0.0	 5799	 5799	 5799	 0.0	 0.0	 1	 -30.0	 30.0;
	4566	 1756	 0.00444	 0.022789	 0.0	 1361	 1361	 1361	 0.0	 0.0	 1	 -30.0	 30.0;
	701	 3492	 0.00163	 0.0145	 0.0	 2165	 2165	 2165	 0.0	 0.0	 1	 -30.0	 30.0;
	9886	 390	 0.003281	 0.02124	 0.0	 1470	 1470	 1470	 0.0	 0.0	 1	 -30.0	 30.0;
	9886	 5795	 0.004979	 0.025271	 0.0	 1227	 1227	 1227	 0.0	 0.0	 1	 -30.0	 30.0;
	13117	 3441	 0.0072	 0.055289	 0.0	 567	 567	 567	 0.0	 0.0	 1	 -30.0	 30.0;
	13117	 6993	 0.00787	 0.04582	 0.0	 680	 680	 680	 0.0	 0.0	 1	 -30.0	 30.0;
	13117	 8177	 0.003961	 0.017711	 0.0	 1741	 1741	 1741	 0.0	 0.0	 1	 -30.0	 30.0;
	3441	 5536	 0.00756	 0.04826	 0.0	 647	 647	 647	 0.0	 0.0	 1	 -30.0	 30.0;
	288	 4466	 0.003401	 0.02086	 0.0	 1495	 1495	 1495	 0.0	 0.0	 1	 -30.0	 30.0;
	288	 5796	 0.001341	 0.00669	 0.0	 4630	 4630	 4630	 0.0	 0.0	 1	 -30.0	 30.0;
	11243	 13129	 6e-05	 0.000581	 0.0	 54080	 54080	 54080	 0.0	 0.0	 1	 -30.0	 30.0;
	11243	 8663	 9.1e-05	 0.00074	 0.0	 42367	 42367	 42367	 0.0	 0.0	 1	 -30.0	 30.0;
	10837	 11031	 0.000531	 0.00175	 0.0	 17273	 17273	 17273	 0.0	 0.0	 1	 -30.0	 30.0;
	1602	 7446	 0.00116	 0.01159	 0.0	 2712	 2712	 2712	 0.0	 0.0	 1	 -30.0	 30.0;
	1602	 6322	 0.00038	 0.00457	 0.0	 6889	 6889	 6889	 0.0	 0.0	 1	 -30.0	 30.0;
	4419	 11725	 0.000729	 0.00405	 0.0	 7676	 7676	 7676	 0.0	 0.0	 1	 -30.0	 30.0;
	403	 10321	 0.000331	 0.001919	 0.0	 16221	 16221	 16221	 0.0	 0.0	 1	 -30.0	 30.0;
	5878	 6900	 0.00086	 0.01029	 0.0	 3060	 3060	 3060	 0.0	 0.0	 1	 -30.0	 30.0;
	10884	 5878	 0.00027	 0.00332	 0.0	 9483	 9483	 9483	 0.0	 0.0	 1	 -30.0	 30.0;
	4948	 8268	 0.00012	 0.00156	 0.0	 20189	 20189	 20189	 0.0	 0.0	 1	 -30.0	 30.0;
	4948	 8268	 0.00012	 0.001531	 0.0	 20569	 20569	 20569	 0.0	 0.0	 1	 -30.0	 30.0;
	12954	 2923	 0.00256	 0.014211	 0.0	 2188	 2188	 2188	 0.0	 0.0	 1	 -30.0	 30.0;
	12954	 6470	 0.00049	 0.00338	 0.0	 9249	 9249	 9249	 0.0	 0.0	 1	 -30.0	 30.0;
	8752	 2025	 0.007531	 0.04444	 0.0	 701	 701	 701	 0.0	 0.0	 1	 -30.0	 30.0;
	8752	 8144	 0.007409	 0.03226	 0.0	 955	 955	 955	 0.0	 0.0	 1	 -30.0	 30.0;
	4557	 11983	 0.001789	 0.012841	 0.0	 2437	 2437	 2437	 0.0	 0.0	 1	 -30.0	 30.0;
	4557	 6027	 0.001831	 0.01257	 0.0	 2487	 2487	 2487	 0.0	 0.0	 1	 -30.0	 30.0;
	2327	 5336	 0.000169	 0.00143	 0.0	 21937	 21937	 21937	 0.0	 0.0	 1	 -30.0	 30.0;
	2327	 10032	 0.00088	 0.005099	 0.0	 6105	 6105	 6105	 0.0	 0.0	 1	 -30.0	 30.0;
	4412	 10924	 0.0004	 0.00479	 0.0	 6572	 6572	 6572	 0.0	 0.0	 1	 -30.0	 30.0;
	4412	 10924	 0.00052	 0.00481	 0.0	 6529	 6529	 6529	 0.0	 0.0	 1	 -30.0	 30.0;
	4412	 2052	 0.00135	 0.01431	 0.0	 2198	 2198	 2198	 0.0	 0.0	 1	 -30.0	 30.0;
	4412	 1163	 0.00051	 0.00549	 0.0	 5729	 5729	 5729	 0.0	 0.0	 1	 -30.0	 30.0;
	1018	 10051	 0.00105	 0.007969	 0.0	 3930	 3930	 3930	 0.0	 0.0	 1	 -30.0	 30.0;
	1018	 1334	 0.00339	 0.020531	 0.0	 1518	 1518	 1518	 0.0	 0.0	 1	 -30.0	 30.0;
	1018	 4248	 0.00169	 0.009331	 0.0	 3332	 3332	 3332	 0.0	 0.0	 1	 -30.0	 30.0;
	5258	 6131	 0.00374	 0.01905	 0.0	 1628	 1628	 1628	 0.0	 0.0	 1	 -30.0	 30.0;
	5258	 7695	 0.00487	 0.026341	 0.0	 1180	 1180	 1180	 0.0	 0.0	 1	 -30.0	 30.0;
	3801	 12225	 0.00057	 0.004581	 0.0	 6843	 6843	 6843	 0.0	 0.0	 1	 -30.0	 30.0;
	3801	 12668	 0.000409	 0.00301	 0.0	 10399	 10399	 10399	 0.0	 0.0	 1	 -30.0	 30.0;
	2068	 5516	 9.1e-05	 0.00076	 0.0	 41268	 41268	 41268	 0.0	 0.0	 1	 -30.0	 30.0;
	2068	 9031	 0.003919	 0.01682	 0.0	 1829	 1829	 1829	 0.0	 0.0	 1	 -30.0	 30.0;
	8475	 1524	 0.00117	 0.0131	 0.0	 2402	 2402	 2402	 0.0	 0.0	 1	 -30.0	 30.0;
	2059	 7254	 0.008271	 0.02787	 0.0	 1087	 1087	 1087	 0.0	 0.0	 1	 -30.0	 30.0;
	2059	 1612	 0.016599	 0.0572	 0.0	 531	 531	 531	 0.0	 0.0	 1	 -30.0	 30.0;
	2059	 1468	 0.00999	 0.057	 0.0	 546	 546	 546	 0.0	 0.0	 1	 -30.0	 30.0;
	2059	 1468	 0.01132	 0.05586	 0.0	 555	 555	 555	 0.0	 0.0	 1	 -30.0	 30.0;
	10704	 6878	 4e-05	 0.00045	 0.0	 69919	 69919	 69919	 0.0	 0.0	 1	 -30.0	 30.0;
	7254	 7404	 0.003281	 0.01038	 0.0	 2902	 2902	 2902	 0.0	 0.0	 1	 -30.0	 30.0;
	6324	 108	 0.003711	 0.01725	 0.0	 1791	 1791	 1791	 0.0	 0.0	 1	 -30.0	 30.0;
	6324	 9264	 0.00069	 0.00232	 0.0	 13051	 13051	 13051	 0.0	 0.0	 1	 -30.0	 30.0;
	11468	 2945	 0.004151	 0.02436	 0.0	 1279	 1279	 1279	 0.0	 0.0	 1	 -30.0	 30.0;
	7542	 2945	 0.006781	 0.028729	 0.0	 1071	 1071	 1071	 0.0	 0.0	 1	 -30.0	 30.0;
	5107	 10032	 0.000331	 0.00151	 0.0	 20434	 20434	 20434	 0.0	 0.0	 1	 -30.0	 30.0;
	1911	 10032	 0.000331	 0.001479	 0.0	 20842	 20842	 20842	 0.0	 0.0	 1	 -30.0	 30.0;
	5433	 12810	 0.0001	 0.00144	 0.0	 21883	 21883	 21883	 0.0	 0.0	 1	 -30.0	 30.0;
	5433	 8622	 0.00027	 0.00221	 0.0	 14188	 14188	 14188	 0.0	 0.0	 1	 -30.0	 30.0;
	1743	 6727	 0.0001	 0.00141	 0.0	 22347	 22347	 22347	 0.0	 0.0	 1	 -30.0	 30.0;
	1743	 3958	 0.00054	 0.00546	 0.0	 5758	 5758	 5758	 0.0	 0.0	 1	 -30.0	 30.0;
	10884	 12810	 7e-05	 0.00053	 0.0	 59086	 59086	 59086	 0.0	 0.0	 1	 -30.0	 30.0;
	6727	 10884	 6e-05	 0.0006	 0.0	 52385	 52385	 52385	 0.0	 0.0	 1	 -30.0	 30.0;
	11031	 6419	 0.000341	 0.00245	 0.0	 12770	 12770	 12770	 0.0	 0.0	 1	 -30.0	 30.0;
	11031	 11469	 0.000841	 0.006719	 0.0	 4665	 4665	 4665	 0.0	 0.0	 1	 -30.0	 30.0;
	11718	 297	 0.000401	 0.00164	 0.0	 18710	 18710	 18710	 0.0	 0.0	 1	 -30.0	 30.0;
	760	 10780	 0.004409	 0.032531	 0.0	 963	 963	 963	 0.0	 0.0	 1	 -30.0	 30.0;
	631	 1617	 0.001961	 0.013581	 0.0	 2302	 2302	 2302	 0.0	 0.0	 1	 -30.0	 30.0;
	2707	 7171	 0.006659	 0.03437	 0.0	 903	 903	 903	 0.0	 0.0	 1	 -30.0	 30.0;
	5970	 2279	 9.1e-05	 0.0007	 0.0	 44749	 44749	 44749	 0.0	 0.0	 1	 -30.0	 30.0;
	5970	 3379	 0.00051	 0.004211	 0.0	 7447	 7447	 7447	 0.0	 0.0	 1	 -30.0	 30.0;
	9991	 2504	 0.00043	 0.0027	 0.0	 11554	 11554	 11554	 0.0	 0.0	 1	 -30.0	 30.0;
	9991	 3684	 0.00038	 0.00306	 0.0	 10244	 10244	 10244	 0.0	 0.0	 1	 -30.0	 30.0;
	12892	 2120	 0.001461	 0.009479	 0.0	 3294	 3294	 3294	 0.0	 0.0	 1	 -30.0	 30.0;
	12892	 10856	 0.001841	 0.011081	 0.0	 2813	 2813	 2813	 0.0	 0.0	 1	 -30.0	 30.0;
	1368	 10984	 0.00094	 0.007169	 0.0	 4369	 4369	 4369	 0.0	 0.0	 1	 -30.0	 30.0;
	8800	 11828	 0.00082	 0.00846	 0.0	 3717	 3717	 3717	 0.0	 0.0	 1	 -30.0	 30.0;
	8800	 10884	 0.00029	 0.00325	 0.0	 9681	 9681	 9681	 0.0	 0.0	 1	 -30.0	 30.0;
	11725	 5863	 0.000781	 0.0062	 0.0	 5055	 5055	 5055	 0.0	 0.0	 1	 -30.0	 30.0;
	11725	 3928	 8.1e-05	 0.00187	 0.0	 16876	 16876	 16876	 0.0	 0.0	 1	 -30.0	 30.0;
	11725	 3275	 8.1e-05	 0.001909	 0.0	 16532	 16532	 16532	 0.0	 0.0	 1	 -30.0	 30.0;
	10044	 1524	 0.00113	 0.00956	 0.0	 3282	 3282	 3282	 0.0	 0.0	 1	 -30.0	 30.0;
	10044	 1524	 0.00115	 0.00935	 0.0	 3354	 3354	 3354	 0.0	 0.0	 1	 -30.0	 30.0;
	13279	 6501	 0.00161	 0.02036	 0.0	 1547	 1547	 1547	 0.0	 0.0	 1	 -30.0	 30.0;
	13279	 6501	 0.00157	 0.02075	 0.0	 1518	 1518	 1518	 0.0	 0.0	 1	 -30.0	 30.0;
	10990	 5766	 0.00101	 0.007401	 0.0	 4229	 4229	 4229	 0.0	 0.0	 1	 -30.0	 30.0;
	10990	 10929	 0.00087	 0.00711	 0.0	 4410	 4410	 4410	 0.0	 0.0	 1	 -30.0	 30.0;
	5256	 8622	 0.00135	 0.01442	 0.0	 2181	 2181	 2181	 0.0	 0.0	 1	 -30.0	 30.0;
	5256	 2965	 0.00176	 0.01441	 0.0	 2176	 2176	 2176	 0.0	 0.0	 1	 -30.0	 30.0;
	2630	 10780	 0.00682	 0.03187	 0.0	 970	 970	 970	 0.0	 0.0	 1	 -30.0	 30.0;
	11828	 1982	 0.00109	 0.00987	 0.0	 3181	 3181	 3181	 0.0	 0.0	 1	 -30.0	 30.0;
	6829	 11828	 0.00273	 0.02829	 0.0	 1112	 1112	 1112	 0.0	 0.0	 1	 -30.0	 30.0;
	2503	 4414	 0.001581	 0.011289	 0.0	 2772	 2772	 2772	 0.0	 0.0	 1	 -30.0	 30.0;
	2503	 5001	 0.001669	 0.013099	 0.0	 2393	 2393	 2393	 0.0	 0.0	 1	 -30.0	 30.0;
	2541	 2279	 9.9e-05	 0.00069	 0.0	 45315	 45315	 45315	 0.0	 0.0	 1	 -30.0	 30.0;
	2541	 3379	 9.9e-05	 0.000669	 0.0	 46708	 46708	 46708	 0.0	 0.0	 1	 -30.0	 30.0;
	7180	 5492	 0.000591	 0.00382	 0.0	 8172	 8172	 8172	 0.0	 0.0	 1	 -30.0	 30.0;
	7180	 13224	 0.00524	 0.02276	 0.0	 1353	 1353	 1353	 0.0	 0.0	 1	 -30.0	 30.0;
	5492	 9686	 0.002719	 0.01143	 0.0	 2689	 2689	 2689	 0.0	 0.0	 1	 -30.0	 30.0;
	1068	 12631	 0.00294	 0.02744	 0.0	 1145	 1145	 1145	 0.0	 0.0	 1	 -30.0	 30.0;
	1068	 10840	 0.0011	 0.01339	 0.0	 2352	 2352	 2352	 0.0	 0.0	 1	 -30.0	 30.0;
	1068	 8556	 0.00193	 0.01695	 0.0	 1852	 1852	 1852	 0.0	 0.0	 1	 -30.0	 30.0;
	1068	 7100	 0.00134	 0.01054	 0.0	 2973	 2973	 2973	 0.0	 0.0	 1	 -30.0	 30.0;
	8883	 1068	 0.00245	 0.02064	 0.0	 1520	 1520	 1520	 0.0	 0.0	 1	 -30.0	 30.0;
	1975	 9822	 0.001841	 0.00901	 0.0	 3435	 3435	 3435	 0.0	 0.0	 1	 -30.0	 30.0;
	1975	 9822	 0.00187	 0.00882	 0.0	 3504	 3504	 3504	 0.0	 0.0	 1	 -30.0	 30.0;
	3864	 1156	 0.00197	 0.02312	 0.0	 1362	 1362	 1362	 0.0	 0.0	 1	 -30.0	 30.0;
	6365	 10840	 0.00078	 0.00887	 0.0	 3548	 3548	 3548	 0.0	 0.0	 1	 -30.0	 30.0;
	12553	 7911	 0.003771	 0.0288	 0.0	 1088	 1088	 1088	 0.0	 0.0	 1	 -30.0	 30.0;
	12553	 12478	 0.000909	 0.00737	 0.0	 4254	 4254	 4254	 0.0	 0.0	 1	 -30.0	 30.0;
	2052	 10924	 0.00086	 0.00783	 0.0	 4011	 4011	 4011	 0.0	 0.0	 1	 -30.0	 30.0;
	2052	 10924	 0.00095	 0.00855	 0.0	 3672	 3672	 3672	 0.0	 0.0	 1	 -30.0	 30.0;
	449	 10924	 0.00012	 0.00157	 0.0	 20061	 20061	 20061	 0.0	 0.0	 1	 -30.0	 30.0;
	449	 10924	 0.00013	 0.00154	 0.0	 20439	 20439	 20439	 0.0	 0.0	 1	 -30.0	 30.0;
	7471	 9448	 0.00089	 0.004771	 0.0	 6509	 6509	 6509	 0.0	 0.0	 1	 -30.0	 30.0;
	7471	 2038	 0.002	 0.00881	 0.0	 3497	 3497	 3497	 0.0	 0.0	 1	 -30.0	 30.0;
	9362	 10340	 0.007711	 0.035331	 0.0	 874	 874	 874	 0.0	 0.0	 1	 -30.0	 30.0;
	10340	 10130	 0.005919	 0.030419	 0.0	 1020	 1020	 1020	 0.0	 0.0	 1	 -30.0	 30.0;
	10340	 2537	 0.0053	 0.031719	 0.0	 983	 983	 983	 0.0	 0.0	 1	 -30.0	 30.0;
	6266	 2808	 0.00025	 0.001289	 0.0	 24058	 24058	 24058	 0.0	 0.0	 1	 -30.0	 30.0;
	2537	 2997	 0.0062	 0.040039	 0.0	 780	 780	 780	 0.0	 0.0	 1	 -30.0	 30.0;
	7446	 7952	 0.0008	 0.00707	 0.0	 4440	 4440	 4440	 0.0	 0.0	 1	 -30.0	 30.0;
	7446	 7258	 0.0002	 0.00207	 0.0	 15189	 15189	 15189	 0.0	 0.0	 1	 -30.0	 30.0;
	7446	 6524	 0.00036	 0.00322	 0.0	 9749	 9749	 9749	 0.0	 0.0	 1	 -30.0	 30.0;
	1604	 8880	 0.0023	 0.0157	 0.0	 1991	 1991	 1991	 0.0	 0.0	 1	 -30.0	 30.0;
	1604	 6177	 0.003479	 0.021159	 0.0	 1474	 1474	 1474	 0.0	 0.0	 1	 -30.0	 30.0;
	5833	 5002	 0.00107	 0.01013	 0.0	 3101	 3101	 3101	 0.0	 0.0	 1	 -30.0	 30.0;
	2036	 9986	 0.00025	 0.000909	 0.0	 33506	 33506	 33506	 0.0	 0.0	 1	 -30.0	 30.0;
	2036	 4544	 0.00037	 0.00188	 0.0	 16486	 16486	 16486	 0.0	 0.0	 1	 -30.0	 30.0;
	13602	 5796	 0.0003	 0.00145	 0.0	 21333	 21333	 21333	 0.0	 0.0	 1	 -30.0	 30.0;
	13602	 5438	 0.001419	 0.007539	 0.0	 4118	 4118	 4118	 0.0	 0.0	 1	 -30.0	 30.0;
	12631	 2395	 0.0012	 0.0122	 0.0	 2577	 2577	 2577	 0.0	 0.0	 1	 -30.0	 30.0;
	12631	 3687	 0.00397	 0.02936	 0.0	 1067	 1067	 1067	 0.0	 0.0	 1	 -30.0	 30.0;
	12631	 9878	 0.00092	 0.01112	 0.0	 2831	 2831	 2831	 0.0	 0.0	 1	 -30.0	 30.0;
	12631	 10884	 0.00387	 0.0452	 0.0	 697	 697	 697	 0.0	 0.0	 1	 -30.0	 30.0;
	12631	 1810	 0.00432	 0.03156	 0.0	 992	 992	 992	 0.0	 0.0	 1	 -30.0	 30.0;
	3905	 1625	 0.00407	 0.03937	 0.0	 799	 799	 799	 0.0	 0.0	 1	 -30.0	 30.0;
	3905	 1625	 0.00415	 0.03856	 0.0	 815	 815	 815	 0.0	 0.0	 1	 -30.0	 30.0;
	13349	 7463	 0.00869	 0.05343	 0.0	 584	 584	 584	 0.0	 0.0	 1	 -30.0	 30.0;
	13349	 3076	 0.0068	 0.036961	 0.0	 841	 841	 841	 0.0	 0.0	 1	 -30.0	 30.0;
	13349	 3807	 0.01805	 0.095469	 0.0	 326	 326	 326	 0.0	 0.0	 1	 -30.0	 30.0;
	11116	 5795	 0.00045	 0.00206	 0.0	 14981	 14981	 14981	 0.0	 0.0	 1	 -30.0	 30.0;
	696	 10544	 0.0095	 0.037159	 0.0	 824	 824	 824	 0.0	 0.0	 1	 -30.0	 30.0;
	696	 7353	 0.02106	 0.0885	 0.0	 348	 348	 348	 0.0	 0.0	 1	 -30.0	 30.0;
	10840	 8556	 0.00157	 0.02318	 0.0	 1360	 1360	 1360	 0.0	 0.0	 1	 -30.0	 30.0;
	10840	 957	 0.00032	 0.00282	 0.0	 11130	 11130	 11130	 0.0	 0.0	 1	 -30.0	 30.0;
	10840	 7223	 0.00165	 0.01605	 0.0	 1958	 1958	 1958	 0.0	 0.0	 1	 -30.0	 30.0;
	7911	 719	 0.00107	 0.00714	 0.0	 4376	 4376	 4376	 0.0	 0.0	 1	 -30.0	 30.0;
	7911	 719	 0.000961	 0.00555	 0.0	 5608	 5608	 5608	 0.0	 0.0	 1	 -30.0	 30.0;
	7911	 12577	 0.00074	 0.00461	 0.0	 6766	 6766	 6766	 0.0	 0.0	 1	 -30.0	 30.0;
	7911	 10321	 0.00076	 0.00451	 0.0	 6907	 6907	 6907	 0.0	 0.0	 1	 -30.0	 30.0;
	7911	 5966	 0.001419	 0.01093	 0.0	 2866	 2866	 2866	 0.0	 0.0	 1	 -30.0	 30.0;
	7911	 12478	 0.003729	 0.024599	 0.0	 1270	 1270	 1270	 0.0	 0.0	 1	 -30.0	 30.0;
	3492	 10272	 0.00233	 0.01992	 0.0	 1575	 1575	 1575	 0.0	 0.0	 1	 -30.0	 30.0;
	3492	 10272	 0.00238	 0.01949	 0.0	 1609	 1609	 1609	 0.0	 0.0	 1	 -30.0	 30.0;
	3492	 7021	 0.00217	 0.0253	 0.0	 1244	 1244	 1244	 0.0	 0.0	 1	 -30.0	 30.0;
	3492	 7021	 0.00212	 0.02579	 0.0	 1221	 1221	 1221	 0.0	 0.0	 1	 -30.0	 30.0;
	3492	 1625	 0.00458	 0.04138	 0.0	 759	 759	 759	 0.0	 0.0	 1	 -30.0	 30.0;
	5566	 807	 0.01555	 0.089841	 0.0	 347	 347	 347	 0.0	 0.0	 1	 -30.0	 30.0;
	9198	 5566	 0.00274	 0.0168	 0.0	 1856	 1856	 1856	 0.0	 0.0	 1	 -30.0	 30.0;
	5566	 6294	 0.005831	 0.032211	 0.0	 965	 965	 965	 0.0	 0.0	 1	 -30.0	 30.0;
	5566	 6136	 0.006669	 0.031341	 0.0	 986	 986	 986	 0.0	 0.0	 1	 -30.0	 30.0;
	11468	 7542	 0.01081	 0.0538	 0.0	 576	 576	 576	 0.0	 0.0	 1	 -30.0	 30.0;
	11468	 1468	 0.005581	 0.02457	 0.0	 1254	 1254	 1254	 0.0	 0.0	 1	 -30.0	 30.0;
	11468	 1468	 0.00569	 0.024039	 0.0	 1279	 1279	 1279	 0.0	 0.0	 1	 -30.0	 30.0;
	1352	 10906	 0.002081	 0.01294	 0.0	 2411	 2411	 2411	 0.0	 0.0	 1	 -30.0	 30.0;
	1352	 7181	 0.001599	 0.00919	 0.0	 3387	 3387	 3387	 0.0	 0.0	 1	 -30.0	 30.0;
	7640	 8556	 0.00083	 0.00768	 0.0	 4090	 4090	 4090	 0.0	 0.0	 1	 -30.0	 30.0;
	3189	 11983	 0.004979	 0.024099	 0.0	 1284	 1284	 1284	 0.0	 0.0	 1	 -30.0	 30.0;
	3189	 11983	 0.005081	 0.023591	 0.0	 1309	 1309	 1309	 0.0	 0.0	 1	 -30.0	 30.0;
	5568	 2395	 0.00412	 0.03917	 0.0	 802	 802	 802	 0.0	 0.0	 1	 -30.0	 30.0;
	2395	 7100	 0.00086	 0.00798	 0.0	 3936	 3936	 3936	 0.0	 0.0	 1	 -30.0	 30.0;
	4779	 2395	 0.00087	 0.00961	 0.0	 3274	 3274	 3274	 0.0	 0.0	 1	 -30.0	 30.0;
	12143	 2395	 0.00095	 0.01034	 0.0	 3043	 3043	 3043	 0.0	 0.0	 1	 -30.0	 30.0;
	6105	 2395	 0.00211	 0.0196	 0.0	 1603	 1603	 1603	 0.0	 0.0	 1	 -30.0	 30.0;
	10544	 7353	 0.00963	 0.05281	 0.0	 589	 589	 589	 0.0	 0.0	 1	 -30.0	 30.0;
	1529	 5489	 0.00018	 0.001349	 0.0	 23210	 23210	 23210	 0.0	 0.0	 1	 -30.0	 30.0;
	1529	 9448	 0.000961	 0.006021	 0.0	 5181	 5181	 5181	 0.0	 0.0	 1	 -30.0	 30.0;
	1529	 9448	 0.000979	 0.00589	 0.0	 5291	 5291	 5291	 0.0	 0.0	 1	 -30.0	 30.0;
	1617	 4415	 0.000461	 0.002729	 0.0	 11413	 11413	 11413	 0.0	 0.0	 1	 -30.0	 30.0;
	1397	 12940	 0.005039	 0.01901	 0.0	 1607	 1607	 1607	 0.0	 0.0	 1	 -30.0	 30.0;
	1397	 6746	 0.00812	 0.028919	 0.0	 1052	 1052	 1052	 0.0	 0.0	 1	 -30.0	 30.0;
	9646	 10183	 0.00106	 0.01005	 0.0	 3126	 3126	 3126	 0.0	 0.0	 1	 -30.0	 30.0;
	8556	 9883	 0.00074	 0.0081	 0.0	 3884	 3884	 3884	 0.0	 0.0	 1	 -30.0	 30.0;
	11983	 9025	 0.012961	 0.03605	 0.0	 825	 825	 825	 0.0	 0.0	 1	 -30.0	 30.0;
	11983	 9025	 0.00844	 0.0378	 0.0	 816	 816	 816	 0.0	 0.0	 1	 -30.0	 30.0;
	11983	 7541	 0.000591	 0.004169	 0.0	 7502	 7502	 7502	 0.0	 0.0	 1	 -30.0	 30.0;
	6294	 8799	 0.003091	 0.012289	 0.0	 2493	 2493	 2493	 0.0	 0.0	 1	 -30.0	 30.0;
	6682	 6733	 0.000969	 0.0053	 0.0	 5863	 5863	 5863	 0.0	 0.0	 1	 -30.0	 30.0;
	3450	 3846	 0.00161	 0.012919	 0.0	 2427	 2427	 2427	 0.0	 0.0	 1	 -30.0	 30.0;
	3450	 3846	 0.003219	 0.01795	 0.0	 1733	 1733	 1733	 0.0	 0.0	 1	 -30.0	 30.0;
	3450	 5377	 0.004331	 0.025	 0.0	 1245	 1245	 1245	 0.0	 0.0	 1	 -30.0	 30.0;
	3450	 5377	 0.004409	 0.02445	 0.0	 1272	 1272	 1272	 0.0	 0.0	 1	 -30.0	 30.0;
	7118	 8982	 0.00425	 0.02014	 0.0	 1535	 1535	 1535	 0.0	 0.0	 1	 -30.0	 30.0;
	7118	 10085	 0.009531	 0.060979	 0.0	 512	 512	 512	 0.0	 0.0	 1	 -30.0	 30.0;
	7118	 2713	 0.002409	 0.0135	 0.0	 2304	 2304	 2304	 0.0	 0.0	 1	 -30.0	 30.0;
	1512	 12079	 0.0006	 0.00662	 0.0	 4753	 4753	 4753	 0.0	 0.0	 1	 -30.0	 30.0;
	1512	 4089	 0.00173	 0.01701	 0.0	 1848	 1848	 1848	 0.0	 0.0	 1	 -30.0	 30.0;
	9362	 1680	 0.004289	 0.018531	 0.0	 1661	 1661	 1661	 0.0	 0.0	 1	 -30.0	 30.0;
	9362	 10130	 0.006919	 0.039789	 0.0	 783	 783	 783	 0.0	 0.0	 1	 -30.0	 30.0;
	9362	 10130	 0.007591	 0.035539	 0.0	 870	 870	 870	 0.0	 0.0	 1	 -30.0	 30.0;
	9362	 10176	 0.00961	 0.05225	 0.0	 595	 595	 595	 0.0	 0.0	 1	 -30.0	 30.0;
	5409	 2731	 0.000581	 0.004599	 0.0	 6815	 6815	 6815	 0.0	 0.0	 1	 -30.0	 30.0;
	5409	 2731	 0.00057	 0.00469	 0.0	 6686	 6686	 6686	 0.0	 0.0	 1	 -30.0	 30.0;
	5409	 2731	 0.00087	 0.003159	 0.0	 9641	 9641	 9641	 0.0	 0.0	 1	 -30.0	 30.0;
	2383	 7610	 0.00018	 0.001419	 0.0	 22084	 22084	 22084	 0.0	 0.0	 1	 -30.0	 30.0;
	2383	 9822	 0.00195	 0.018841	 0.0	 1668	 1668	 1668	 0.0	 0.0	 1	 -30.0	 30.0;
	108	 12948	 0.00293	 0.01293	 0.0	 2383	 2383	 2383	 0.0	 0.0	 1	 -30.0	 30.0;
	2171	 4705	 0.001969	 0.010599	 0.0	 2931	 2931	 2931	 0.0	 0.0	 1	 -30.0	 30.0;
	10207	 1210	 3.9e-05	 0.000591	 0.0	 53332	 53332	 53332	 0.0	 0.0	 1	 -30.0	 30.0;
	10207	 608	 0.00364	 0.02431	 0.0	 1286	 1286	 1286	 0.0	 0.0	 1	 -30.0	 30.0;
	10207	 2134	 0.00114	 0.007211	 0.0	 4327	 4327	 4327	 0.0	 0.0	 1	 -30.0	 30.0;
	719	 6224	 0.001271	 0.008659	 0.0	 3610	 3610	 3610	 0.0	 0.0	 1	 -30.0	 30.0;
	719	 9844	 0.00105	 0.00668	 0.0	 4672	 4672	 4672	 0.0	 0.0	 1	 -30.0	 30.0;
	5568	 9773	 0.00011	 0.00122	 0.0	 25787	 25787	 25787	 0.0	 0.0	 1	 -30.0	 30.0;
	5568	 5263	 0.00117	 0.0124	 0.0	 2537	 2537	 2537	 0.0	 0.0	 1	 -30.0	 30.0;
	5568	 6105	 0.00168	 0.01891	 0.0	 1664	 1664	 1664	 0.0	 0.0	 1	 -30.0	 30.0;
	1147	 11466	 0.00132	 0.008281	 0.0	 3767	 3767	 3767	 0.0	 0.0	 1	 -30.0	 30.0;
	1147	 12350	 0.004531	 0.01924	 0.0	 1599	 1599	 1599	 0.0	 0.0	 1	 -30.0	 30.0;
	1147	 1756	 0.007841	 0.041909	 0.0	 741	 741	 741	 0.0	 0.0	 1	 -30.0	 30.0;
	2052	 456	 0.00113	 0.01235	 0.0	 2548	 2548	 2548	 0.0	 0.0	 1	 -30.0	 30.0;
	2052	 456	 0.00128	 0.0121	 0.0	 2597	 2597	 2597	 0.0	 0.0	 1	 -30.0	 30.0;
	2052	 12743	 0.0015	 0.01792	 0.0	 1757	 1757	 1757	 0.0	 0.0	 1	 -30.0	 30.0;
	6733	 13134	 0.00111	 0.005281	 0.0	 5854	 5854	 5854	 0.0	 0.0	 1	 -30.0	 30.0;
	6733	 13134	 0.00113	 0.005169	 0.0	 5970	 5970	 5970	 0.0	 0.0	 1	 -30.0	 30.0;
	8801	 216	 0.00563	 0.03255	 0.0	 957	 957	 957	 0.0	 0.0	 1	 -30.0	 30.0;
	1682	 216	 0.005289	 0.022539	 0.0	 1365	 1365	 1365	 0.0	 0.0	 1	 -30.0	 30.0;
	216	 9105	 0.007159	 0.05086	 0.0	 616	 616	 616	 0.0	 0.0	 1	 -30.0	 30.0;
	216	 5435	 0.009669	 0.05649	 0.0	 552	 552	 552	 0.0	 0.0	 1	 -30.0	 30.0;
	216	 9031	 0.0092	 0.052169	 0.0	 597	 597	 597	 0.0	 0.0	 1	 -30.0	 30.0;
	6312	 7440	 0.00197	 0.01594	 0.0	 1967	 1967	 1967	 0.0	 0.0	 1	 -30.0	 30.0;
	6312	 9878	 0.00343	 0.02573	 0.0	 1217	 1217	 1217	 0.0	 0.0	 1	 -30.0	 30.0;
	6312	 12143	 0.00151	 0.01485	 0.0	 2117	 2117	 2117	 0.0	 0.0	 1	 -30.0	 30.0;
	6312	 7407	 0.00092	 0.01042	 0.0	 3020	 3020	 3020	 0.0	 0.0	 1	 -30.0	 30.0;
	6312	 11782	 0.00029	 0.00336	 0.0	 9367	 9367	 9367	 0.0	 0.0	 1	 -30.0	 30.0;
	2120	 6582	 0.001711	 0.01255	 0.0	 2494	 2494	 2494	 0.0	 0.0	 1	 -30.0	 30.0;
	2120	 2140	 0.005	 0.03962	 0.0	 791	 791	 791	 0.0	 0.0	 1	 -30.0	 30.0;
	1203	 1673	 0.0014	 0.01687	 0.0	 1866	 1866	 1866	 0.0	 0.0	 1	 -30.0	 30.0;
	1203	 1673	 0.00067	 0.00678	 0.0	 4637	 4637	 4637	 0.0	 0.0	 1	 -30.0	 30.0;
	1203	 1673	 0.00065	 0.00692	 0.0	 4545	 4545	 4545	 0.0	 0.0	 1	 -30.0	 30.0;
	8883	 1203	 0.00137	 0.01524	 0.0	 2065	 2065	 2065	 0.0	 0.0	 1	 -30.0	 30.0;
	5642	 999	 0.00424	 0.02376	 0.0	 1309	 1309	 1309	 0.0	 0.0	 1	 -30.0	 30.0;
	5642	 8469	 0.005591	 0.031711	 0.0	 981	 981	 981	 0.0	 0.0	 1	 -30.0	 30.0;
	5642	 3173	 0.00138	 0.00649	 0.0	 4761	 4761	 4761	 0.0	 0.0	 1	 -30.0	 30.0;
	5642	 3173	 0.00107	 0.00544	 0.0	 5698	 5698	 5698	 0.0	 0.0	 1	 -30.0	 30.0;
	7440	 6448	 3e-05	 0.00041	 0.0	 76837	 76837	 76837	 0.0	 0.0	 1	 -30.0	 30.0;
	7440	 6448	 3e-05	 0.00041	 0.0	 76837	 76837	 76837	 0.0	 0.0	 1	 -30.0	 30.0;
	7440	 7258	 0.00044	 0.00342	 0.0	 9161	 9161	 9161	 0.0	 0.0	 1	 -30.0	 30.0;
	10906	 3595	 0.003841	 0.01737	 0.0	 1776	 1776	 1776	 0.0	 0.0	 1	 -30.0	 30.0;
	10886	 2732	 0.001771	 0.01337	 0.0	 2343	 2343	 2343	 0.0	 0.0	 1	 -30.0	 30.0;
	711	 3807	 0.00139	 0.007349	 0.0	 4224	 4224	 4224	 0.0	 0.0	 1	 -30.0	 30.0;
	711	 8144	 0.00625	 0.03463	 0.0	 898	 898	 898	 0.0	 0.0	 1	 -30.0	 30.0;
	7463	 6399	 0.00055	 0.00255	 0.0	 12109	 12109	 12109	 0.0	 0.0	 1	 -30.0	 30.0;
	9648	 5149	 0.00489	 0.043331	 0.0	 725	 725	 725	 0.0	 0.0	 1	 -30.0	 30.0;
	12877	 4466	 0.00145	 0.013099	 0.0	 2397	 2397	 2397	 0.0	 0.0	 1	 -30.0	 30.0;
	12877	 1793	 0.004039	 0.02881	 0.0	 1086	 1086	 1086	 0.0	 0.0	 1	 -30.0	 30.0;
	3191	 7271	 0.002219	 0.00988	 0.0	 3120	 3120	 3120	 0.0	 0.0	 1	 -30.0	 30.0;
	7745	 4414	 0.001919	 0.0153	 0.0	 2049	 2049	 2049	 0.0	 0.0	 1	 -30.0	 30.0;
	12824	 1982	 0.00189	 0.01319	 0.0	 2371	 2371	 2371	 0.0	 0.0	 1	 -30.0	 30.0;
	7592	 2504	 0.00011	 0.000659	 0.0	 47279	 47279	 47279	 0.0	 0.0	 1	 -30.0	 30.0;
	7592	 3684	 0.00011	 0.00064	 0.0	 48642	 48642	 48642	 0.0	 0.0	 1	 -30.0	 30.0;
	7592	 4359	 0.000211	 0.00111	 0.0	 27957	 27957	 27957	 0.0	 0.0	 1	 -30.0	 30.0;
	9986	 11718	 0.000469	 0.001669	 0.0	 18221	 18221	 18221	 0.0	 0.0	 1	 -30.0	 30.0;
	8626	 1210	 6e-05	 0.000849	 0.0	 37113	 37113	 37113	 0.0	 0.0	 1	 -30.0	 30.0;
	10450	 10711	 0.00051	 0.00597	 0.0	 5272	 5272	 5272	 0.0	 0.0	 1	 -30.0	 30.0;
	10450	 10183	 0.00119	 0.01087	 0.0	 2889	 2889	 2889	 0.0	 0.0	 1	 -30.0	 30.0;
	8489	 10450	 0.00219	 0.01922	 0.0	 1633	 1633	 1633	 0.0	 0.0	 1	 -30.0	 30.0;
	8622	 3958	 0.00051	 0.00465	 0.0	 6753	 6753	 6753	 0.0	 0.0	 1	 -30.0	 30.0;
	13135	 10031	 0.00055	 0.0067	 0.0	 4699	 4699	 4699	 0.0	 0.0	 1	 -30.0	 30.0;
	3595	 1235	 0.005099	 0.027349	 0.0	 1136	 1136	 1136	 0.0	 0.0	 1	 -30.0	 30.0;
	4705	 4080	 0.000599	 0.003961	 0.0	 7885	 7885	 7885	 0.0	 0.0	 1	 -30.0	 30.0;
	4705	 4803	 0.005461	 0.032719	 0.0	 953	 953	 953	 0.0	 0.0	 1	 -30.0	 30.0;
	11989	 4149	 0.00349	 0.02256	 0.0	 1384	 1384	 1384	 0.0	 0.0	 1	 -30.0	 30.0;
	11989	 2570	 0.00132	 0.00861	 0.0	 3627	 3627	 3627	 0.0	 0.0	 1	 -30.0	 30.0;
	8484	 6898	 0.0045	 0.01838	 0.0	 1670	 1670	 1670	 0.0	 0.0	 1	 -30.0	 30.0;
	8484	 1973	 0.004289	 0.019719	 0.0	 1566	 1566	 1566	 0.0	 0.0	 1	 -30.0	 30.0;
	12118	 4359	 0.001409	 0.00881	 0.0	 3541	 3541	 3541	 0.0	 0.0	 1	 -30.0	 30.0;
	1673	 9663	 0.00212	 0.01857	 0.0	 1691	 1691	 1691	 0.0	 0.0	 1	 -30.0	 30.0;
	1673	 11248	 0.00049	 0.00574	 0.0	 5484	 5484	 5484	 0.0	 0.0	 1	 -30.0	 30.0;
	1673	 1097	 0.00184	 0.021	 0.0	 1499	 1499	 1499	 0.0	 0.0	 1	 -30.0	 30.0;
	3846	 6995	 0.00593	 0.037409	 0.0	 834	 834	 834	 0.0	 0.0	 1	 -30.0	 30.0;
	3173	 6131	 0.00514	 0.024169	 0.0	 1279	 1279	 1279	 0.0	 0.0	 1	 -30.0	 30.0;
	5573	 4184	 0.00041	 0.00492	 0.0	 6399	 6399	 6399	 0.0	 0.0	 1	 -30.0	 30.0;
	5198	 4184	 0.00296	 0.02677	 0.0	 1173	 1173	 1173	 0.0	 0.0	 1	 -30.0	 30.0;
	7193	 807	 0.0072	 0.03406	 0.0	 908	 908	 908	 0.0	 0.0	 1	 -30.0	 30.0;
	5001	 10150	 0.00043	 0.00276	 0.0	 11309	 11309	 11309	 0.0	 0.0	 1	 -30.0	 30.0;
	5001	 11776	 0.001789	 0.013469	 0.0	 2325	 2325	 2325	 0.0	 0.0	 1	 -30.0	 30.0;
	7171	 10856	 0.00163	 0.011091	 0.0	 2818	 2818	 2818	 0.0	 0.0	 1	 -30.0	 30.0;
	7171	 9287	 0.00036	 0.002651	 0.0	 11807	 11807	 11807	 0.0	 0.0	 1	 -30.0	 30.0;
	13129	 19	 0.00013	 0.00132	 0.0	 23815	 23815	 23815	 0.0	 0.0	 1	 -30.0	 30.0;
	13129	 427	 0.000169	 0.001659	 0.0	 18942	 18942	 18942	 0.0	 0.0	 1	 -30.0	 30.0;
	6501	 7404	 0.00136	 0.012831	 0.0	 2449	 2449	 2449	 0.0	 0.0	 1	 -30.0	 30.0;
	6501	 7404	 0.00139	 0.01256	 0.0	 2500	 2500	 2500	 0.0	 0.0	 1	 -30.0	 30.0;
	6501	 7695	 0.00126	 0.009521	 0.0	 3289	 3289	 3289	 0.0	 0.0	 1	 -30.0	 30.0;
	6501	 7695	 0.00143	 0.009331	 0.0	 3347	 3347	 3347	 0.0	 0.0	 1	 -30.0	 30.0;
	5377	 6501	 0.00164	 0.012961	 0.0	 2418	 2418	 2418	 0.0	 0.0	 1	 -30.0	 30.0;
	5377	 6501	 0.001599	 0.012	 0.0	 2610	 2610	 2610	 0.0	 0.0	 1	 -30.0	 30.0;
	10130	 4257	 0.001271	 0.00524	 0.0	 5859	 5859	 5859	 0.0	 0.0	 1	 -30.0	 30.0;
	4869	 13271	 0.00226	 0.02465	 0.0	 1277	 1277	 1277	 0.0	 0.0	 1	 -30.0	 30.0;
	3362	 5285	 0.00032	 0.0015	 0.0	 20595	 20595	 20595	 0.0	 0.0	 1	 -30.0	 30.0;
	3362	 8663	 0.00032	 0.00112	 0.0	 27118	 27118	 27118	 0.0	 0.0	 1	 -30.0	 30.0;
	4779	 7223	 0.00075	 0.00817	 0.0	 3851	 3851	 3851	 0.0	 0.0	 1	 -30.0	 30.0;
	12008	 2907	 0.00037	 0.0027	 0.0	 11591	 11591	 11591	 0.0	 0.0	 1	 -30.0	 30.0;
	2907	 9908	 3.9e-05	 0.000219	 0.0	 142001	 142001	 142001	 0.0	 0.0	 1	 -30.0	 30.0;
	3076	 875	 0.012781	 0.05762	 0.0	 536	 536	 536	 0.0	 0.0	 1	 -30.0	 30.0;
	8565	 1530	 0.00036	 0.001289	 0.0	 23603	 23603	 23603	 0.0	 0.0	 1	 -30.0	 30.0;
	8880	 1682	 0.006771	 0.039349	 0.0	 792	 792	 792	 0.0	 0.0	 1	 -30.0	 30.0;
	4493	 11248	 0.00292	 0.02831	 0.0	 1110	 1110	 1110	 0.0	 0.0	 1	 -30.0	 30.0;
	4493	 2965	 0.00134	 0.01229	 0.0	 2556	 2556	 2556	 0.0	 0.0	 1	 -30.0	 30.0;
	12008	 8005	 0.00011	 0.00063	 0.0	 49392	 49392	 49392	 0.0	 0.0	 1	 -30.0	 30.0;
	10620	 4466	 0.0003	 0.003331	 0.0	 9445	 9445	 9445	 0.0	 0.0	 1	 -30.0	 30.0;
	10620	 5438	 0.001289	 0.01555	 0.0	 2025	 2025	 2025	 0.0	 0.0	 1	 -30.0	 30.0;
	9908	 8626	 0.00011	 0.0017	 0.0	 18543	 18543	 18543	 0.0	 0.0	 1	 -30.0	 30.0;
	9908	 7745	 0.00043	 0.00249	 0.0	 12501	 12501	 12501	 0.0	 0.0	 1	 -30.0	 30.0;
	1612	 6835	 0.002651	 0.016771	 0.0	 1861	 1861	 1861	 0.0	 0.0	 1	 -30.0	 30.0;
	5103	 1612	 0.0082	 0.025081	 0.0	 1198	 1198	 1198	 0.0	 0.0	 1	 -30.0	 30.0;
	5021	 10031	 0.00037	 0.002781	 0.0	 11260	 11260	 11260	 0.0	 0.0	 1	 -30.0	 30.0;
	2029	 7193	 0.010719	 0.054719	 0.0	 567	 567	 567	 0.0	 0.0	 1	 -30.0	 30.0;
	4446	 7193	 0.006469	 0.04074	 0.0	 766	 766	 766	 0.0	 0.0	 1	 -30.0	 30.0;
	11083	 13271	 0.00101	 0.01274	 0.0	 2472	 2472	 2472	 0.0	 0.0	 1	 -30.0	 30.0;
	4466	 8681	 9.1e-05	 0.05076	 0.0	 623	 623	 623	 0.0	 0.0	 1	 -30.0	 30.0;
	4466	 5349	 0.00588	 0.03938	 0.0	 794	 794	 794	 0.0	 0.0	 1	 -30.0	 30.0;
	4466	 5438	 0.003591	 0.022099	 0.0	 1411	 1411	 1411	 0.0	 0.0	 1	 -30.0	 30.0;
	4466	 11168	 0.00555	 0.032521	 0.0	 958	 958	 958	 0.0	 0.0	 1	 -30.0	 30.0;
	10044	 456	 0.00116	 0.01347	 0.0	 2337	 2337	 2337	 0.0	 0.0	 1	 -30.0	 30.0;
	10044	 456	 0.00113	 0.01247	 0.0	 2523	 2523	 2523	 0.0	 0.0	 1	 -30.0	 30.0;
	7382	 257	 0.00107	 0.00871	 0.0	 3600	 3600	 3600	 0.0	 0.0	 1	 -30.0	 30.0;
	7382	 6519	 0.00078	 0.00609	 0.0	 5145	 5145	 5145	 0.0	 0.0	 1	 -30.0	 30.0;
	3687	 9883	 0.00075	 0.00604	 0.0	 5190	 5190	 5190	 0.0	 0.0	 1	 -30.0	 30.0;
	7181	 9822	 0.00224	 0.011091	 0.0	 2792	 2792	 2792	 0.0	 0.0	 1	 -30.0	 30.0;
	5863	 10150	 0.001961	 0.013969	 0.0	 2240	 2240	 2240	 0.0	 0.0	 1	 -30.0	 30.0;
	1833	 7541	 0.001271	 0.00761	 0.0	 4095	 4095	 4095	 0.0	 0.0	 1	 -30.0	 30.0;
	9773	 9878	 0.00374	 0.03581	 0.0	 878	 878	 878	 0.0	 0.0	 1	 -30.0	 30.0;
	9773	 9878	 0.00385	 0.03284	 0.0	 956	 956	 956	 0.0	 0.0	 1	 -30.0	 30.0;
	9773	 9878	 0.00392	 0.03216	 0.0	 975	 975	 975	 0.0	 0.0	 1	 -30.0	 30.0;
	9773	 13271	 0.00307	 0.03131	 0.0	 1005	 1005	 1005	 0.0	 0.0	 1	 -30.0	 30.0;
	11466	 40	 0.027	 0.131289	 0.0	 236	 236	 236	 0.0	 0.0	 1	 -30.0	 30.0;
	9264	 8019	 0.005539	 0.0195	 0.0	 1559	 1559	 1559	 0.0	 0.0	 1	 -30.0	 30.0;
	7404	 340	 0.003099	 0.017849	 0.0	 1744	 1744	 1744	 0.0	 0.0	 1	 -30.0	 30.0;
	7404	 7695	 0.002831	 0.014099	 0.0	 2197	 2197	 2197	 0.0	 0.0	 1	 -30.0	 30.0;
	5915	 3230	 0.0	 0.01368	 0.0	 2310	 2310	 2310	 0.0	 0.0	 1	 -30.0	 30.0;
	6177	 6835	 0.01082	 0.079719	 0.0	 393	 393	 393	 0.0	 0.0	 1	 -30.0	 30.0;
	1060	 3958	 0.00102	 0.00941	 0.0	 3338	 3338	 3338	 0.0	 0.0	 1	 -30.0	 30.0;
	1060	 877	 0.00183	 0.01819	 0.0	 1728	 1728	 1728	 0.0	 0.0	 1	 -30.0	 30.0;
	1060	 570	 0.00028	 0.00346	 0.0	 9100	 9100	 9100	 0.0	 0.0	 1	 -30.0	 30.0;
	5766	 3684	 0.0012	 0.00982	 0.0	 3193	 3193	 3193	 0.0	 0.0	 1	 -30.0	 30.0;
	3958	 3761	 0.00027	 0.0032	 0.0	 9837	 9837	 9837	 0.0	 0.0	 1	 -30.0	 30.0;
	3958	 11270	 0.00064	 0.00679	 0.0	 4632	 4632	 4632	 0.0	 0.0	 1	 -30.0	 30.0;
	3958	 12155	 0.00047	 0.00442	 0.0	 7107	 7107	 7107	 0.0	 0.0	 1	 -30.0	 30.0;
	608	 12940	 0.00493	 0.017599	 0.0	 1729	 1729	 1729	 0.0	 0.0	 1	 -30.0	 30.0;
	608	 6004	 0.00207	 0.0153	 0.0	 2046	 2046	 2046	 0.0	 0.0	 1	 -30.0	 30.0;
	10680	 456	 0.00094	 0.0092	 0.0	 3416	 3416	 3416	 0.0	 0.0	 1	 -30.0	 30.0;
	10680	 456	 0.00095	 0.00901	 0.0	 3487	 3487	 3487	 0.0	 0.0	 1	 -30.0	 30.0;
	1334	 3983	 0.00101	 0.00719	 0.0	 4351	 4351	 4351	 0.0	 0.0	 1	 -30.0	 30.0;
	5489	 9729	 0.000419	 0.00331	 0.0	 9468	 9468	 9468	 0.0	 0.0	 1	 -30.0	 30.0;
	8982	 2713	 0.002099	 0.015599	 0.0	 2007	 2007	 2007	 0.0	 0.0	 1	 -30.0	 30.0;
	9878	 12824	 0.00163	 0.01283	 0.0	 2443	 2443	 2443	 0.0	 0.0	 1	 -30.0	 30.0;
	9878	 10884	 0.00445	 0.03788	 0.0	 829	 829	 829	 0.0	 0.0	 1	 -30.0	 30.0;
	9878	 6829	 0.00092	 0.00703	 0.0	 4456	 4456	 4456	 0.0	 0.0	 1	 -30.0	 30.0;
	375	 40	 9.1e-05	 0.000961	 0.0	 32723	 32723	 32723	 0.0	 0.0	 1	 -30.0	 30.0;
	10886	 375	 0.00387	 0.028599	 0.0	 1095	 1095	 1095	 0.0	 0.0	 1	 -30.0	 30.0;
	375	 7714	 0.00949	 0.06625	 0.0	 472	 472	 472	 0.0	 0.0	 1	 -30.0	 30.0;
	375	 6555	 0.00414	 0.035331	 0.0	 888	 888	 888	 0.0	 0.0	 1	 -30.0	 30.0;
	375	 7714	 0.009781	 0.065581	 0.0	 477	 477	 477	 0.0	 0.0	 1	 -30.0	 30.0;
	1973	 40	 0.02818	 0.116099	 0.0	 265	 265	 265	 0.0	 0.0	 1	 -30.0	 30.0;
	40	 3035	 0.00324	 0.01912	 0.0	 1629	 1629	 1629	 0.0	 0.0	 1	 -30.0	 30.0;
	4332	 9883	 0.00135	 0.01609	 0.0	 1957	 1957	 1957	 0.0	 0.0	 1	 -30.0	 30.0;
	9025	 8256	 0.00294	 0.0182	 0.0	 1714	 1714	 1714	 0.0	 0.0	 1	 -30.0	 30.0;
	12985	 8681	 0.000711	 0.00649	 0.0	 4839	 4839	 4839	 0.0	 0.0	 1	 -30.0	 30.0;
	650	 12985	 0.002651	 0.01375	 0.0	 2256	 2256	 2256	 0.0	 0.0	 1	 -30.0	 30.0;
	1793	 8681	 0.00105	 0.008469	 0.0	 3702	 3702	 3702	 0.0	 0.0	 1	 -30.0	 30.0;
	1227	 6582	 0.002229	 0.016461	 0.0	 1902	 1902	 1902	 0.0	 0.0	 1	 -30.0	 30.0;
	1227	 6582	 0.002281	 0.01613	 0.0	 1940	 1940	 1940	 0.0	 0.0	 1	 -30.0	 30.0;
	882	 6582	 0.003341	 0.012651	 0.0	 2415	 2415	 2415	 0.0	 0.0	 1	 -30.0	 30.0;
	882	 6582	 0.003271	 0.012901	 0.0	 2374	 2374	 2374	 0.0	 0.0	 1	 -30.0	 30.0;
	9491	 12754	 0.00101	 0.01218	 0.0	 2585	 2585	 2585	 0.0	 0.0	 1	 -30.0	 30.0;
	9491	 10894	 0.0009	 0.0095	 0.0	 3311	 3311	 3311	 0.0	 0.0	 1	 -30.0	 30.0;
	12754	 6878	 0.00098	 0.01241	 0.0	 2538	 2538	 2538	 0.0	 0.0	 1	 -30.0	 30.0;
	8018	 2770	 0.001219	 0.00951	 0.0	 3295	 3295	 3295	 0.0	 0.0	 1	 -30.0	 30.0;
	8018	 6470	 0.001789	 0.01382	 0.0	 2267	 2267	 2267	 0.0	 0.0	 1	 -30.0	 30.0;
	8018	 6470	 0.00175	 0.014081	 0.0	 2227	 2227	 2227	 0.0	 0.0	 1	 -30.0	 30.0;
	11140	 4937	 9.1e-05	 0.00087	 0.0	 36111	 36111	 36111	 0.0	 0.0	 1	 -30.0	 30.0;
	11140	 4937	 9.1e-05	 0.00086	 0.0	 36526	 36526	 36526	 0.0	 0.0	 1	 -30.0	 30.0;
	11140	 12384	 0.000229	 0.00236	 0.0	 13322	 13322	 13322	 0.0	 0.0	 1	 -30.0	 30.0;
	999	 7552	 0.00125	 0.00557	 0.0	 5534	 5534	 5534	 0.0	 0.0	 1	 -30.0	 30.0;
	3076	 7582	 0.00757	 0.04013	 0.0	 774	 774	 774	 0.0	 0.0	 1	 -30.0	 30.0;
	2418	 257	 0.00157	 0.01604	 0.0	 1960	 1960	 1960	 0.0	 0.0	 1	 -30.0	 30.0;
	2418	 257	 0.00154	 0.01634	 0.0	 1925	 1925	 1925	 0.0	 0.0	 1	 -30.0	 30.0;
	257	 2965	 0.00169	 0.02383	 0.0	 1323	 1323	 1323	 0.0	 0.0	 1	 -30.0	 30.0;
	2465	 257	 0.00068	 0.0089	 0.0	 3539	 3539	 3539	 0.0	 0.0	 1	 -30.0	 30.0;
	2633	 6746	 0.010289	 0.036651	 0.0	 830	 830	 830	 0.0	 0.0	 1	 -30.0	 30.0;
	2633	 6746	 0.00563	 0.03395	 0.0	 918	 918	 918	 0.0	 0.0	 1	 -30.0	 30.0;
	4497	 8327	 0.003591	 0.02763	 0.0	 1134	 1134	 1134	 0.0	 0.0	 1	 -30.0	 30.0;
	4497	 8327	 0.00351	 0.028159	 0.0	 1114	 1114	 1114	 0.0	 0.0	 1	 -30.0	 30.0;
	8327	 6995	 0.00143	 0.00838	 0.0	 3716	 3716	 3716	 0.0	 0.0	 1	 -30.0	 30.0;
	11213	 6294	 0.01213	 0.06156	 0.0	 504	 504	 504	 0.0	 0.0	 1	 -30.0	 30.0;
	9025	 7552	 0.004789	 0.022849	 0.0	 1354	 1354	 1354	 0.0	 0.0	 1	 -30.0	 30.0;
	777	 4876	 0.00019	 0.00211	 0.0	 14910	 14910	 14910	 0.0	 0.0	 1	 -30.0	 30.0;
	777	 12577	 0.000331	 0.002349	 0.0	 13316	 13316	 13316	 0.0	 0.0	 1	 -30.0	 30.0;
	777	 7360	 9.1e-05	 0.000539	 0.0	 57786	 57786	 57786	 0.0	 0.0	 1	 -30.0	 30.0;
	9505	 9663	 0.00088	 0.00776	 0.0	 4045	 4045	 4045	 0.0	 0.0	 1	 -30.0	 30.0;
	6829	 6900	 0.00039	 0.00368	 0.0	 8536	 8536	 8536	 0.0	 0.0	 1	 -30.0	 30.0;
	9731	 2959	 0.00275	 0.01268	 0.0	 2435	 2435	 2435	 0.0	 0.0	 1	 -30.0	 30.0;
	9731	 13295	 0.00205	 0.00874	 0.0	 3519	 3519	 3519	 0.0	 0.0	 1	 -30.0	 30.0;
	9731	 1756	 0.00082	 0.00519	 0.0	 6012	 6012	 6012	 0.0	 0.0	 1	 -30.0	 30.0;
	3807	 1157	 0.00519	 0.02355	 0.0	 1310	 1310	 1310	 0.0	 0.0	 1	 -30.0	 30.0;
	4803	 9858	 0.016711	 0.08874	 0.0	 350	 350	 350	 0.0	 0.0	 1	 -30.0	 30.0;
	10856	 6460	 0.005099	 0.022659	 0.0	 1361	 1361	 1361	 0.0	 0.0	 1	 -30.0	 30.0;
	10856	 11738	 0.001469	 0.01213	 0.0	 2586	 2586	 2586	 0.0	 0.0	 1	 -30.0	 30.0;
	10856	 11738	 0.001659	 0.01189	 0.0	 2632	 2632	 2632	 0.0	 0.0	 1	 -30.0	 30.0;
	1443	 6555	 0.000521	 0.00374	 0.0	 8366	 8366	 8366	 0.0	 0.0	 1	 -30.0	 30.0;
	1443	 7353	 0.006461	 0.048349	 0.0	 648	 648	 648	 0.0	 0.0	 1	 -30.0	 30.0;
	12754	 10711	 0.00293	 0.0257	 0.0	 1222	 1222	 1222	 0.0	 0.0	 1	 -30.0	 30.0;
	12754	 5903	 0.00178	 0.0157	 0.0	 2000	 2000	 2000	 0.0	 0.0	 1	 -30.0	 30.0;
	8489	 12754	 0.00115	 0.01332	 0.0	 2363	 2363	 2363	 0.0	 0.0	 1	 -30.0	 30.0;
	12754	 3132	 0.00078	 0.00752	 0.0	 4179	 4179	 4179	 0.0	 0.0	 1	 -30.0	 30.0;
	116	 4323	 3.9e-05	 0.00037	 0.0	 84901	 84901	 84901	 0.0	 0.0	 1	 -30.0	 30.0;
	11948	 6470	 0.0012	 0.006729	 0.0	 4622	 4622	 4622	 0.0	 0.0	 1	 -30.0	 30.0;
	41	 4865	 0.000211	 0.001659	 0.0	 18888	 18888	 18888	 0.0	 0.0	 1	 -30.0	 30.0;
	9497	 12225	 0.001659	 0.011919	 0.0	 2625	 2625	 2625	 0.0	 0.0	 1	 -30.0	 30.0;
	9497	 10032	 0.002	 0.0133	 0.0	 2349	 2349	 2349	 0.0	 0.0	 1	 -30.0	 30.0;
	6419	 11469	 0.00105	 0.00837	 0.0	 3745	 3745	 3745	 0.0	 0.0	 1	 -30.0	 30.0;
	4149	 7790	 0.00138	 0.014979	 0.0	 2100	 2100	 2100	 0.0	 0.0	 1	 -30.0	 30.0;
	8377	 9986	 0.0	 0.0003	 0.0	 105292	 105292	 105292	 0.0	 0.0	 1	 -30.0	 30.0;
	4292	 9986	 0.0	 0.0003	 0.0	 105292	 105292	 105292	 0.0	 0.0	 1	 -30.0	 30.0;
	4292	 7854	 0.00164	 0.00782	 0.0	 3954	 3954	 3954	 0.0	 0.0	 1	 -30.0	 30.0;
	5349	 344	 0.007099	 0.04044	 0.0	 770	 770	 770	 0.0	 0.0	 1	 -30.0	 30.0;
	340	 1468	 0.00181	 0.00914	 0.0	 3391	 3391	 3391	 0.0	 0.0	 1	 -30.0	 30.0;
	2105	 10769	 0.00027	 0.00247	 0.0	 12713	 12713	 12713	 0.0	 0.0	 1	 -30.0	 30.0;
	10769	 7258	 0.00266	 0.03206	 0.0	 982	 982	 982	 0.0	 0.0	 1	 -30.0	 30.0;
	5778	 1386	 0.000591	 0.005081	 0.0	 6176	 6176	 6176	 0.0	 0.0	 1	 -30.0	 30.0;
	5778	 6867	 0.002229	 0.016099	 0.0	 1944	 1944	 1944	 0.0	 0.0	 1	 -30.0	 30.0;
	5915	 7826	 0.00205	 0.02585	 0.0	 1219	 1219	 1219	 0.0	 0.0	 1	 -30.0	 30.0;
	11470	 5854	 0.00101	 0.0091	 0.0	 3450	 3450	 3450	 0.0	 0.0	 1	 -30.0	 30.0;
	11470	 5903	 0.001	 0.00871	 0.0	 3603	 3603	 3603	 0.0	 0.0	 1	 -30.0	 30.0;
	5457	 11673	 0.00112	 0.00895	 0.0	 3502	 3502	 3502	 0.0	 0.0	 1	 -30.0	 30.0;
	5457	 11673	 0.001099	 0.008289	 0.0	 3778	 3778	 3778	 0.0	 0.0	 1	 -30.0	 30.0;
	5457	 4518	 0.001289	 0.0095	 0.0	 3295	 3295	 3295	 0.0	 0.0	 1	 -30.0	 30.0;
	5457	 4518	 0.00126	 0.00968	 0.0	 3236	 3236	 3236	 0.0	 0.0	 1	 -30.0	 30.0;
	6322	 7952	 0.00065	 0.00723	 0.0	 4352	 4352	 4352	 0.0	 0.0	 1	 -30.0	 30.0;
	2770	 6026	 0.001781	 0.012669	 0.0	 2470	 2470	 2470	 0.0	 0.0	 1	 -30.0	 30.0;
	5833	 1543	 0.00086	 0.00956	 0.0	 3291	 3291	 3291	 0.0	 0.0	 1	 -30.0	 30.0;
	5833	 1156	 0.00248	 0.02429	 0.0	 1294	 1294	 1294	 0.0	 0.0	 1	 -30.0	 30.0;
	5833	 6614	 0.00151	 0.01699	 0.0	 1852	 1852	 1852	 0.0	 0.0	 1	 -30.0	 30.0;
	8585	 5435	 0.003159	 0.01537	 0.0	 2014	 2014	 2014	 0.0	 0.0	 1	 -30.0	 30.0;
	12079	 4503	 0.00075	 0.00683	 0.0	 4598	 4598	 4598	 0.0	 0.0	 1	 -30.0	 30.0;
	12079	 4089	 0.00223	 0.02524	 0.0	 1247	 1247	 1247	 0.0	 0.0	 1	 -30.0	 30.0;
	5854	 5903	 0.00191	 0.0208	 0.0	 1513	 1513	 1513	 0.0	 0.0	 1	 -30.0	 30.0;
	2418	 5854	 0.00074	 0.00784	 0.0	 4012	 4012	 4012	 0.0	 0.0	 1	 -30.0	 30.0;
	2418	 5854	 0.00073	 0.00799	 0.0	 3937	 3937	 3937	 0.0	 0.0	 1	 -30.0	 30.0;
	2015	 5336	 0.000789	 0.00482	 0.0	 6468	 6468	 6468	 0.0	 0.0	 1	 -30.0	 30.0;
	3007	 2015	 0.000789	 0.004409	 0.0	 7053	 7053	 7053	 0.0	 0.0	 1	 -30.0	 30.0;
	4080	 4803	 0.005461	 0.03161	 0.0	 985	 985	 985	 0.0	 0.0	 1	 -30.0	 30.0;
	2340	 7745	 6e-05	 0.00087	 0.0	 36222	 36222	 36222	 0.0	 0.0	 1	 -30.0	 30.0;
	4575	 9844	 0.00593	 0.040961	 0.0	 764	 764	 764	 0.0	 0.0	 1	 -30.0	 30.0;
	4575	 7353	 0.003771	 0.030841	 0.0	 1017	 1017	 1017	 0.0	 0.0	 1	 -30.0	 30.0;
	9446	 401	 0.00038	 0.001461	 0.0	 20925	 20925	 20925	 0.0	 0.0	 1	 -30.0	 30.0;
	401	 6004	 0.00149	 0.00938	 0.0	 3326	 3326	 3326	 0.0	 0.0	 1	 -30.0	 30.0;
	401	 6004	 0.001521	 0.00918	 0.0	 3395	 3395	 3395	 0.0	 0.0	 1	 -30.0	 30.0;
	2959	 6898	 0.00407	 0.015469	 0.0	 1975	 1975	 1975	 0.0	 0.0	 1	 -30.0	 30.0;
	7253	 2015	 0.00082	 0.006219	 0.0	 5036	 5036	 5036	 0.0	 0.0	 1	 -30.0	 30.0;
	3822	 2808	 0.00161	 0.00888	 0.0	 3501	 3501	 3501	 0.0	 0.0	 1	 -30.0	 30.0;
	3822	 11776	 0.00118	 0.006461	 0.0	 4810	 4810	 4810	 0.0	 0.0	 1	 -30.0	 30.0;
	10031	 8972	 0.00082	 0.009091	 0.0	 3461	 3461	 3461	 0.0	 0.0	 1	 -30.0	 30.0;
	6867	 6588	 0.01893	 0.0848	 0.0	 364	 364	 364	 0.0	 0.0	 1	 -30.0	 30.0;
	6867	 6588	 0.01313	 0.082409	 0.0	 379	 379	 379	 0.0	 0.0	 1	 -30.0	 30.0;
	6867	 1591	 0.000281	 0.00149	 0.0	 20833	 20833	 20833	 0.0	 0.0	 1	 -30.0	 30.0;
	7713	 4503	 0.00019	 0.00199	 0.0	 15802	 15802	 15802	 0.0	 0.0	 1	 -30.0	 30.0;
	4503	 7713	 0.0002	 0.00188	 0.0	 16708	 16708	 16708	 0.0	 0.0	 1	 -30.0	 30.0;
	245	 2537	 0.003159	 0.025331	 0.0	 1238	 1238	 1238	 0.0	 0.0	 1	 -30.0	 30.0;
	11267	 2038	 0.00445	 0.01886	 0.0	 1631	 1631	 1631	 0.0	 0.0	 1	 -30.0	 30.0;
	8469	 1235	 0.00461	 0.02205	 0.0	 1403	 1403	 1403	 0.0	 0.0	 1	 -30.0	 30.0;
	5795	 12082	 0.00061	 0.00494	 0.0	 6347	 6347	 6347	 0.0	 0.0	 1	 -30.0	 30.0;
	5795	 1358	 0.00082	 0.00462	 0.0	 6732	 6732	 6732	 0.0	 0.0	 1	 -30.0	 30.0;
	3345	 12820	 0.000331	 0.003271	 0.0	 9608	 9608	 9608	 0.0	 0.0	 1	 -30.0	 30.0;
	3345	 11738	 0.00056	 0.004081	 0.0	 7669	 7669	 7669	 0.0	 0.0	 1	 -30.0	 30.0;
	9115	 1370	 0.00163	 0.007521	 0.0	 4105	 4105	 4105	 0.0	 0.0	 1	 -30.0	 30.0;
	9115	 13134	 0.001659	 0.00736	 0.0	 4187	 4187	 4187	 0.0	 0.0	 1	 -30.0	 30.0;
	2731	 2140	 0.00719	 0.049211	 0.0	 636	 636	 636	 0.0	 0.0	 1	 -30.0	 30.0;
	10929	 2808	 6e-05	 0.00039	 0.0	 80052	 80052	 80052	 0.0	 0.0	 1	 -30.0	 30.0;
	1472	 8779	 0.00288	 0.018	 0.0	 1733	 1733	 1733	 0.0	 0.0	 1	 -30.0	 30.0;
	1472	 9612	 0.00288	 0.0182	 0.0	 1715	 1715	 1715	 0.0	 0.0	 1	 -30.0	 30.0;
	1472	 7714	 0.00111	 0.008531	 0.0	 3672	 3672	 3672	 0.0	 0.0	 1	 -30.0	 30.0;
	1472	 6271	 0.00307	 0.022289	 0.0	 1404	 1404	 1404	 0.0	 0.0	 1	 -30.0	 30.0;
	4420	 6614	 0.00091	 0.00868	 0.0	 3620	 3620	 3620	 0.0	 0.0	 1	 -30.0	 30.0;
	5903	 13478	 0.00098	 0.0118	 0.0	 2668	 2668	 2668	 0.0	 0.0	 1	 -30.0	 30.0;
	5903	 10894	 0.00053	 0.00591	 0.0	 5324	 5324	 5324	 0.0	 0.0	 1	 -30.0	 30.0;
	5903	 3132	 0.00086	 0.00991	 0.0	 3176	 3176	 3176	 0.0	 0.0	 1	 -30.0	 30.0;
	10230	 4865	 0.00545	 0.034099	 0.0	 915	 915	 915	 0.0	 0.0	 1	 -30.0	 30.0;
	2923	 3589	 0.00095	 0.006091	 0.0	 5124	 5124	 5124	 0.0	 0.0	 1	 -30.0	 30.0;
	5198	 1156	 0.00305	 0.0272	 0.0	 1155	 1155	 1155	 0.0	 0.0	 1	 -30.0	 30.0;
	1227	 7198	 0.000281	 0.001841	 0.0	 16962	 16962	 16962	 0.0	 0.0	 1	 -30.0	 30.0;
	1227	 9448	 0.004531	 0.02451	 0.0	 1268	 1268	 1268	 0.0	 0.0	 1	 -30.0	 30.0;
	6460	 2140	 0.00618	 0.02961	 0.0	 1045	 1045	 1045	 0.0	 0.0	 1	 -30.0	 30.0;
	11673	 5041	 0.00064	 0.004461	 0.0	 7010	 7010	 7010	 0.0	 0.0	 1	 -30.0	 30.0;
	1285	 6206	 0.00143	 0.00513	 0.0	 5932	 5932	 5932	 0.0	 0.0	 1	 -30.0	 30.0;
	1285	 1756	 0.0052	 0.021841	 0.0	 1407	 1407	 1407	 0.0	 0.0	 1	 -30.0	 30.0;
	882	 7198	 0.00138	 0.008669	 0.0	 3599	 3599	 3599	 0.0	 0.0	 1	 -30.0	 30.0;
	9448	 882	 0.00314	 0.013169	 0.0	 2334	 2334	 2334	 0.0	 0.0	 1	 -30.0	 30.0;
	6206	 3480	 0.002479	 0.01331	 0.0	 2334	 2334	 2334	 0.0	 0.0	 1	 -30.0	 30.0;
	3275	 3928	 7e-05	 0.00194	 0.0	 16272	 16272	 16272	 0.0	 0.0	 1	 -30.0	 30.0;
	13552	 6470	 0.001159	 0.00931	 0.0	 3367	 3367	 3367	 0.0	 0.0	 1	 -30.0	 30.0;
	7854	 9287	 0.00062	 0.003669	 0.0	 8489	 8489	 8489	 0.0	 0.0	 1	 -30.0	 30.0;
	3615	 7542	 0.015969	 0.056711	 0.0	 537	 537	 537	 0.0	 0.0	 1	 -30.0	 30.0;
	7542	 5516	 0.0085	 0.03719	 0.0	 828	 828	 828	 0.0	 0.0	 1	 -30.0	 30.0;
	3983	 1370	 0.001531	 0.00732	 0.0	 4224	 4224	 4224	 0.0	 0.0	 1	 -30.0	 30.0;
	3983	 1370	 0.00205	 0.01062	 0.0	 2921	 2921	 2921	 0.0	 0.0	 1	 -30.0	 30.0;
	7258	 7952	 0.00091	 0.01056	 0.0	 2981	 2981	 2981	 0.0	 0.0	 1	 -30.0	 30.0;
	1156	 12743	 0.00167	 0.02069	 0.0	 1522	 1522	 1522	 0.0	 0.0	 1	 -30.0	 30.0;
	9198	 6294	 0.002719	 0.016219	 0.0	 1921	 1921	 1921	 0.0	 0.0	 1	 -30.0	 30.0;
	12143	 6448	 0.002	 0.02376	 0.0	 1325	 1325	 1325	 0.0	 0.0	 1	 -30.0	 30.0;
	12143	 6448	 0.00226	 0.02328	 0.0	 1351	 1351	 1351	 0.0	 0.0	 1	 -30.0	 30.0;
	11168	 650	 0.004151	 0.02119	 0.0	 1463	 1463	 1463	 0.0	 0.0	 1	 -30.0	 30.0;
	13295	 12350	 0.001841	 0.010909	 0.0	 2856	 2856	 2856	 0.0	 0.0	 1	 -30.0	 30.0;
	6294	 6136	 0.000669	 0.00399	 0.0	 7808	 7808	 7808	 0.0	 0.0	 1	 -30.0	 30.0;
	957	 11657	 8e-05	 0.00098	 0.0	 32126	 32126	 32126	 0.0	 0.0	 1	 -30.0	 30.0;
	4876	 7360	 0.0002	 0.0025	 0.0	 12595	 12595	 12595	 0.0	 0.0	 1	 -30.0	 30.0;
	7996	 7714	 0.006219	 0.031599	 0.0	 981	 981	 981	 0.0	 0.0	 1	 -30.0	 30.0;
	7996	 2034	 0.00438	 0.023169	 0.0	 1340	 1340	 1340	 0.0	 0.0	 1	 -30.0	 30.0;
	8986	 6271	 0.00581	 0.03088	 0.0	 1006	 1006	 1006	 0.0	 0.0	 1	 -30.0	 30.0;
	8986	 6271	 0.0065	 0.02637	 0.0	 1164	 1164	 1164	 0.0	 0.0	 1	 -30.0	 30.0;
	6829	 877	 0.00198	 0.02208	 0.0	 1425	 1425	 1425	 0.0	 0.0	 1	 -30.0	 30.0;
	4497	 1235	 0.00093	 0.006659	 0.0	 4698	 4698	 4698	 0.0	 0.0	 1	 -30.0	 30.0;
	4497	 1235	 0.000909	 0.006789	 0.0	 4612	 4612	 4612	 0.0	 0.0	 1	 -30.0	 30.0;
	5915	 1543	 0.00244	 0.01919	 0.0	 1633	 1633	 1633	 0.0	 0.0	 1	 -30.0	 30.0;
	3372	 12668	 0.00194	 0.01549	 0.0	 2024	 2024	 2024	 0.0	 0.0	 1	 -30.0	 30.0;
	2381	 5966	 0.0002	 0.001479	 0.0	 21165	 21165	 21165	 0.0	 0.0	 1	 -30.0	 30.0;
	6588	 11673	 0.001091	 0.009461	 0.0	 3317	 3317	 3317	 0.0	 0.0	 1	 -30.0	 30.0;
	11673	 9660	 0.003081	 0.00899	 0.0	 3324	 3324	 3324	 0.0	 0.0	 1	 -30.0	 30.0;
	9660	 2062	 0.00357	 0.0138	 0.0	 2216	 2216	 2216	 0.0	 0.0	 1	 -30.0	 30.0;
	3589	 11166	 0.001229	 0.00986	 0.0	 3179	 3179	 3179	 0.0	 0.0	 1	 -30.0	 30.0;
	2829	 13462	 0.001211	 0.00913	 0.0	 3430	 3430	 3430	 0.0	 0.0	 1	 -30.0	 30.0;
	7258	 11782	 0.00116	 0.01053	 0.0	 2982	 2982	 2982	 0.0	 0.0	 1	 -30.0	 30.0;
	6828	 8268	 0.0017	 0.009781	 0.0	 3182	 3182	 3182	 0.0	 0.0	 1	 -30.0	 30.0;
	6828	 8268	 0.001521	 0.011091	 0.0	 2822	 2822	 2822	 0.0	 0.0	 1	 -30.0	 30.0;
	286	 656	 0.0043	 0.0233	 0.0	 1334	 1334	 1334	 0.0	 0.0	 1	 -30.0	 30.0;
	3862	 6524	 0.00019	 0.0016	 0.0	 19605	 19605	 19605	 0.0	 0.0	 1	 -30.0	 30.0;
	6993	 12225	 0.00838	 0.072479	 0.0	 433	 433	 433	 0.0	 0.0	 1	 -30.0	 30.0;
	6993	 1399	 0.00787	 0.049211	 0.0	 634	 634	 634	 0.0	 0.0	 1	 -30.0	 30.0;
	650	 344	 0.00557	 0.03376	 0.0	 924	 924	 924	 0.0	 0.0	 1	 -30.0	 30.0;
	6224	 10146	 0.01213	 0.06564	 0.0	 474	 474	 474	 0.0	 0.0	 1	 -30.0	 30.0;
	10800	 4518	 0.003531	 0.01086	 0.0	 2767	 2767	 2767	 0.0	 0.0	 1	 -30.0	 30.0;
	10800	 10878	 0.0158	 0.057031	 0.0	 534	 534	 534	 0.0	 0.0	 1	 -30.0	 30.0;
	1097	 2965	 0.00289	 0.0244	 0.0	 1286	 1286	 1286	 0.0	 0.0	 1	 -30.0	 30.0;
	2279	 6027	 0.000521	 0.00413	 0.0	 7589	 7589	 7589	 0.0	 0.0	 1	 -30.0	 30.0;
	3379	 6027	 0.000531	 0.004039	 0.0	 7754	 7754	 7754	 0.0	 0.0	 1	 -30.0	 30.0;
	344	 2570	 0.00431	 0.02226	 0.0	 1394	 1394	 1394	 0.0	 0.0	 1	 -30.0	 30.0;
	4359	 6004	 0.00163	 0.00899	 0.0	 3458	 3458	 3458	 0.0	 0.0	 1	 -30.0	 30.0;
	6829	 1810	 0.00274	 0.02428	 0.0	 1293	 1293	 1293	 0.0	 0.0	 1	 -30.0	 30.0;
	9226	 8779	 0.0093	 0.056979	 0.0	 548	 548	 548	 0.0	 0.0	 1	 -30.0	 30.0;
	9226	 12923	 0.011281	 0.080039	 0.0	 391	 391	 391	 0.0	 0.0	 1	 -30.0	 30.0;
	9226	 8204	 0.00449	 0.02376	 0.0	 1307	 1307	 1307	 0.0	 0.0	 1	 -30.0	 30.0;
	3761	 12155	 0.00014	 0.00148	 0.0	 21248	 21248	 21248	 0.0	 0.0	 1	 -30.0	 30.0;
	5536	 12225	 0.0055	 0.033659	 0.0	 927	 927	 927	 0.0	 0.0	 1	 -30.0	 30.0;
	6555	 7954	 0.00249	 0.02082	 0.0	 1507	 1507	 1507	 0.0	 0.0	 1	 -30.0	 30.0;
	2465	 2965	 0.00164	 0.02252	 0.0	 1399	 1399	 1399	 0.0	 0.0	 1	 -30.0	 30.0;
	8419	 3039	 0.000961	 0.0047	 0.0	 6585	 6585	 6585	 0.0	 0.0	 1	 -30.0	 30.0;
	8419	 3039	 0.000979	 0.004599	 0.0	 6718	 6718	 6718	 0.0	 0.0	 1	 -30.0	 30.0;
	11270	 570	 0.00057	 0.00515	 0.0	 6097	 6097	 6097	 0.0	 0.0	 1	 -30.0	 30.0;
	12225	 10032	 0.00143	 0.011651	 0.0	 2691	 2691	 2691	 0.0	 0.0	 1	 -30.0	 30.0;
	2134	 6004	 0.00126	 0.009211	 0.0	 3398	 3398	 3398	 0.0	 0.0	 1	 -30.0	 30.0;
	8779	 1012	 9.1e-05	 0.000211	 0.0	 137464	 137464	 137464	 0.0	 0.0	 1	 -30.0	 30.0;
	9612	 1012	 0.000211	 0.000711	 0.0	 42591	 42591	 42591	 0.0	 0.0	 1	 -30.0	 30.0;
	9612	 8204	 0.01095	 0.07062	 0.0	 443	 443	 443	 0.0	 0.0	 1	 -30.0	 30.0;
	3035	 8204	 0.00125	 0.007281	 0.0	 4276	 4276	 4276	 0.0	 0.0	 1	 -30.0	 30.0;
	3035	 8204	 0.001	 0.0045	 0.0	 6853	 6853	 6853	 0.0	 0.0	 1	 -30.0	 30.0;
	7954	 7353	 0.00282	 0.026419	 0.0	 1189	 1189	 1189	 0.0	 0.0	 1	 -30.0	 30.0;
	13224	 9686	 0.003479	 0.01456	 0.0	 2111	 2111	 2111	 0.0	 0.0	 1	 -30.0	 30.0;
	7714	 6271	 0.005521	 0.03418	 0.0	 913	 913	 913	 0.0	 0.0	 1	 -30.0	 30.0;
	7714	 6271	 0.00563	 0.033461	 0.0	 931	 931	 931	 0.0	 0.0	 1	 -30.0	 30.0;
	7353	 6962	 0.00095	 0.0072	 0.0	 4350	 4350	 4350	 0.0	 0.0	 1	 -30.0	 30.0;
	7353	 10146	 0.00093	 0.007159	 0.0	 4376	 4376	 4376	 0.0	 0.0	 1	 -30.0	 30.0;
	2034	 6271	 0.00988	 0.058651	 0.0	 532	 532	 532	 0.0	 0.0	 1	 -30.0	 30.0;
	9729	 12384	 3.9e-05	 0.00044	 0.0	 71510	 71510	 71510	 0.0	 0.0	 1	 -30.0	 30.0;
	9729	 12384	 3.9e-05	 0.00043	 0.0	 73159	 73159	 73159	 0.0	 0.0	 1	 -30.0	 30.0;
	8226	 7917	 0.00018	 0.000781	 0.0	 39412	 39412	 39412	 0.0	 0.0	 1	 -30.0	 30.0;
	6321	 11066	 0.002961	 0.01669	 0.0	 1864	 1864	 1864	 0.0	 0.0	 1	 -30.0	 30.0;
	8434	 5760	 0.00056	 0.00432	 0.0	 7252	 7252	 7252	 0.0	 0.0	 1	 -30.0	 30.0;
	9867	 12476	 0.0002	 0.00246	 0.0	 12799	 12799	 12799	 0.0	 0.0	 1	 -30.0	 30.0;
	9867	 6599	 0.0003	 0.00377	 0.0	 8353	 8353	 8353	 0.0	 0.0	 1	 -30.0	 30.0;
	5046	 13471	 0.00014	 0.00057	 0.0	 53817	 53817	 53817	 0.0	 0.0	 1	 -30.0	 30.0;
	4215	 13471	 0.00013	 0.000729	 0.0	 42657	 42657	 42657	 0.0	 0.0	 1	 -30.0	 30.0;
	2033	 13471	 0.00012	 0.000581	 0.0	 53244	 53244	 53244	 0.0	 0.0	 1	 -30.0	 30.0;
	2634	 13471	 0.00011	 0.00064	 0.0	 48642	 48642	 48642	 0.0	 0.0	 1	 -30.0	 30.0;
	5721	 13471	 0.00019	 0.00056	 0.0	 53416	 53416	 53416	 0.0	 0.0	 1	 -30.0	 30.0;
	9083	 13001	 0.00062	 0.004909	 0.0	 6384	 6384	 6384	 0.0	 0.0	 1	 -30.0	 30.0;
	13300	 11517	 7e-05	 0.00076	 0.0	 41388	 41388	 41388	 0.0	 0.0	 1	 -30.0	 30.0;
	13300	 13605	 0.00066	 0.00622	 0.0	 5051	 5051	 5051	 0.0	 0.0	 1	 -30.0	 30.0;
	13300	 3010	 0.00054	 0.00752	 0.0	 4190	 4190	 4190	 0.0	 0.0	 1	 -30.0	 30.0;
	13300	 36	 0.00105	 0.00877	 0.0	 3577	 3577	 3577	 0.0	 0.0	 1	 -30.0	 30.0;
	924	 13177	 8e-05	 0.00091	 0.0	 34578	 34578	 34578	 0.0	 0.0	 1	 -30.0	 30.0;
	924	 6741	 0.00056	 0.00719	 0.0	 4380	 4380	 4380	 0.0	 0.0	 1	 -30.0	 30.0;
	3475	 8047	 0.000531	 0.002039	 0.0	 14992	 14992	 14992	 0.0	 0.0	 1	 -30.0	 30.0;
	3475	 1798	 0.008659	 0.03769	 0.0	 817	 817	 817	 0.0	 0.0	 1	 -30.0	 30.0;
	3475	 13250	 0.003849	 0.021099	 0.0	 1473	 1473	 1473	 0.0	 0.0	 1	 -30.0	 30.0;
	3475	 12568	 0.00688	 0.035969	 0.0	 863	 863	 863	 0.0	 0.0	 1	 -30.0	 30.0;
	3475	 10058	 0.006729	 0.03713	 0.0	 838	 838	 838	 0.0	 0.0	 1	 -30.0	 30.0;
	3475	 4969	 0.00111	 0.006651	 0.0	 4685	 4685	 4685	 0.0	 0.0	 1	 -30.0	 30.0;
	3475	 936	 0.0023	 0.008909	 0.0	 3433	 3433	 3433	 0.0	 0.0	 1	 -30.0	 30.0;
	3475	 3737	 0.000841	 0.00313	 0.0	 9747	 9747	 9747	 0.0	 0.0	 1	 -30.0	 30.0;
	3475	 7793	 0.003521	 0.017479	 0.0	 1772	 1772	 1772	 0.0	 0.0	 1	 -30.0	 30.0;
	4397	 1039	 3.9e-05	 0.00025	 0.0	 124840	 124840	 124840	 0.0	 0.0	 1	 -30.0	 30.0;
	4369	 3319	 0.000159	 0.000729	 0.0	 42335	 42335	 42335	 0.0	 0.0	 1	 -30.0	 30.0;
	12797	 10943	 0.005281	 0.032099	 0.0	 972	 972	 972	 0.0	 0.0	 1	 -30.0	 30.0;
	12797	 10943	 0.005651	 0.029419	 0.0	 1055	 1055	 1055	 0.0	 0.0	 1	 -30.0	 30.0;
	1266	 5393	 0.000271	 0.00036	 0.0	 70101	 70101	 70101	 0.0	 0.0	 1	 -30.0	 30.0;
	12926	 10303	 0.00044	 0.00143	 0.0	 21113	 21113	 21113	 0.0	 0.0	 1	 -30.0	 30.0;
	12926	 5753	 0.000159	 0.00074	 0.0	 41734	 41734	 41734	 0.0	 0.0	 1	 -30.0	 30.0;
	3246	 2813	 0.00019	 0.000591	 0.0	 50883	 50883	 50883	 0.0	 0.0	 1	 -30.0	 30.0;
	7493	 4212	 0.00019	 0.00087	 0.0	 35472	 35472	 35472	 0.0	 0.0	 1	 -30.0	 30.0;
	9692	 7207	 0.002591	 0.013659	 0.0	 2273	 2273	 2273	 0.0	 0.0	 1	 -30.0	 30.0;
	9692	 10710	 0.00305	 0.01168	 0.0	 2617	 2617	 2617	 0.0	 0.0	 1	 -30.0	 30.0;
	606	 4776	 0.000159	 0.000599	 0.0	 50969	 50969	 50969	 0.0	 0.0	 1	 -30.0	 30.0;
	606	 4776	 0.000159	 0.00062	 0.0	 49351	 49351	 49351	 0.0	 0.0	 1	 -30.0	 30.0;
	4732	 7207	 0.00101	 0.004229	 0.0	 7265	 7265	 7265	 0.0	 0.0	 1	 -30.0	 30.0;
	4732	 6274	 0.00319	 0.018651	 0.0	 1670	 1670	 1670	 0.0	 0.0	 1	 -30.0	 30.0;
	4732	 10710	 0.000729	 0.00337	 0.0	 9162	 9162	 9162	 0.0	 0.0	 1	 -30.0	 30.0;
	1647	 1694	 0.002961	 0.012831	 0.0	 2399	 2399	 2399	 0.0	 0.0	 1	 -30.0	 30.0;
	1647	 11678	 0.000591	 0.00339	 0.0	 9180	 9180	 9180	 0.0	 0.0	 1	 -30.0	 30.0;
	13172	 3466	 0.00024	 0.001219	 0.0	 25425	 25425	 25425	 0.0	 0.0	 1	 -30.0	 30.0;
	12795	 4279	 0.006219	 0.036341	 0.0	 857	 857	 857	 0.0	 0.0	 1	 -30.0	 30.0;
	12795	 8788	 0.001841	 0.01193	 0.0	 2617	 2617	 2617	 0.0	 0.0	 1	 -30.0	 30.0;
	4805	 10642	 0.001409	 0.01113	 0.0	 2816	 2816	 2816	 0.0	 0.0	 1	 -30.0	 30.0;
	4805	 426	 0.00151	 0.00768	 0.0	 4036	 4036	 4036	 0.0	 0.0	 1	 -30.0	 30.0;
	4805	 4435	 0.00599	 0.03313	 0.0	 939	 939	 939	 0.0	 0.0	 1	 -30.0	 30.0;
	4805	 4953	 0.001771	 0.010151	 0.0	 3066	 3066	 3066	 0.0	 0.0	 1	 -30.0	 30.0;
	543	 1154	 0.00074	 0.00311	 0.0	 9881	 9881	 9881	 0.0	 0.0	 1	 -30.0	 30.0;
	543	 1154	 0.000729	 0.003159	 0.0	 9744	 9744	 9744	 0.0	 0.0	 1	 -30.0	 30.0;
	4667	 11443	 0.005271	 0.01906	 0.0	 1598	 1598	 1598	 0.0	 0.0	 1	 -30.0	 30.0;
	4667	 7938	 0.00906	 0.053151	 0.0	 586	 586	 586	 0.0	 0.0	 1	 -30.0	 30.0;
	4667	 2641	 0.00405	 0.0153	 0.0	 1996	 1996	 1996	 0.0	 0.0	 1	 -30.0	 30.0;
	9942	 7878	 0.00055	 0.003961	 0.0	 7899	 7899	 7899	 0.0	 0.0	 1	 -30.0	 30.0;
	9942	 7878	 0.00055	 0.003729	 0.0	 8381	 8381	 8381	 0.0	 0.0	 1	 -30.0	 30.0;
	9942	 2296	 0.00107	 0.007789	 0.0	 4018	 4018	 4018	 0.0	 0.0	 1	 -30.0	 30.0;
	9942	 2296	 0.00112	 0.00775	 0.0	 4034	 4034	 4034	 0.0	 0.0	 1	 -30.0	 30.0;
	9942	 2296	 0.001031	 0.00775	 0.0	 4041	 4041	 4041	 0.0	 0.0	 1	 -30.0	 30.0;
	9942	 3493	 0.00062	 0.003219	 0.0	 9636	 9636	 9636	 0.0	 0.0	 1	 -30.0	 30.0;
	9942	 1346	 0.00068	 0.002659	 0.0	 11510	 11510	 11510	 0.0	 0.0	 1	 -30.0	 30.0;
	13517	 738	 0.00193	 0.012479	 0.0	 2502	 2502	 2502	 0.0	 0.0	 1	 -30.0	 30.0;
	13517	 4340	 0.001159	 0.007229	 0.0	 4315	 4315	 4315	 0.0	 0.0	 1	 -30.0	 30.0;
	13517	 4246	 0.00137	 0.008729	 0.0	 3575	 3575	 3575	 0.0	 0.0	 1	 -30.0	 30.0;
	13517	 4246	 0.001401	 0.00855	 0.0	 3646	 3646	 3646	 0.0	 0.0	 1	 -30.0	 30.0;
	13517	 4246	 0.001331	 0.008521	 0.0	 3663	 3663	 3663	 0.0	 0.0	 1	 -30.0	 30.0;
	10331	 3147	 0.00031	 0.00081	 0.0	 36421	 36421	 36421	 0.0	 0.0	 1	 -30.0	 30.0;
	10331	 11861	 0.000341	 0.00119	 0.0	 25518	 25518	 25518	 0.0	 0.0	 1	 -30.0	 30.0;
	10331	 6577	 0.00031	 0.001281	 0.0	 23967	 23967	 23967	 0.0	 0.0	 1	 -30.0	 30.0;
	10331	 6228	 0.00094	 0.0035	 0.0	 8717	 8717	 8717	 0.0	 0.0	 1	 -30.0	 30.0;
	12595	 7709	 7e-05	 0.000651	 0.0	 48244	 48244	 48244	 0.0	 0.0	 1	 -30.0	 30.0;
	7969	 5396	 0.00019	 0.00124	 0.0	 25180	 25180	 25180	 0.0	 0.0	 1	 -30.0	 30.0;
	7969	 4212	 0.000331	 0.002539	 0.0	 12337	 12337	 12337	 0.0	 0.0	 1	 -30.0	 30.0;
	4543	 5236	 0.0016	 0.02113	 0.0	 1491	 1491	 1491	 0.0	 0.0	 1	 -30.0	 30.0;
	11390	 12662	 0.000909	 0.004711	 0.0	 6584	 6584	 6584	 0.0	 0.0	 1	 -30.0	 30.0;
	11390	 12662	 0.00088	 0.004969	 0.0	 6260	 6260	 6260	 0.0	 0.0	 1	 -30.0	 30.0;
	5	 12839	 0.001841	 0.0088	 0.0	 3514	 3514	 3514	 0.0	 0.0	 1	 -30.0	 30.0;
	5	 11276	 0.01013	 0.04238	 0.0	 725	 725	 725	 0.0	 0.0	 1	 -30.0	 30.0;
	9749	 4225	 0.00059	 0.00802	 0.0	 3928	 3928	 3928	 0.0	 0.0	 1	 -30.0	 30.0;
	9749	 4225	 0.00054	 0.0079	 0.0	 3990	 3990	 3990	 0.0	 0.0	 1	 -30.0	 30.0;
	9749	 5763	 0.00171	 0.02128	 0.0	 1480	 1480	 1480	 0.0	 0.0	 1	 -30.0	 30.0;
	9749	 5763	 0.00174	 0.02084	 0.0	 1511	 1511	 1511	 0.0	 0.0	 1	 -30.0	 30.0;
	9749	 9633	 0.00086	 0.01433	 0.0	 2201	 2201	 2201	 0.0	 0.0	 1	 -30.0	 30.0;
	9749	 9633	 0.00087	 0.01404	 0.0	 2246	 2246	 2246	 0.0	 0.0	 1	 -30.0	 30.0;
	9749	 5623	 0.00126	 0.01447	 0.0	 2175	 2175	 2175	 0.0	 0.0	 1	 -30.0	 30.0;
	9749	 8232	 0.00122	 0.01509	 0.0	 2087	 2087	 2087	 0.0	 0.0	 1	 -30.0	 30.0;
	9749	 8232	 0.00154	 0.019	 0.0	 1658	 1658	 1658	 0.0	 0.0	 1	 -30.0	 30.0;
	7207	 7194	 0.00474	 0.03564	 0.0	 879	 879	 879	 0.0	 0.0	 1	 -30.0	 30.0;
	7207	 8676	 0.006	 0.047849	 0.0	 656	 656	 656	 0.0	 0.0	 1	 -30.0	 30.0;
	7207	 7631	 0.008039	 0.03375	 0.0	 911	 911	 911	 0.0	 0.0	 1	 -30.0	 30.0;
	10011	 10710	 2.1e-05	 0.000211	 0.0	 148968	 148968	 148968	 0.0	 0.0	 1	 -30.0	 30.0;
	12238	 5367	 0.00045	 0.002341	 0.0	 13251	 13251	 13251	 0.0	 0.0	 1	 -30.0	 30.0;
	3966	 13022	 0.000669	 0.004281	 0.0	 7291	 7291	 7291	 0.0	 0.0	 1	 -30.0	 30.0;
	13659	 13022	 0.00068	 0.00419	 0.0	 7442	 7442	 7442	 0.0	 0.0	 1	 -30.0	 30.0;
	4462	 5428	 0.000729	 0.00431	 0.0	 7227	 7227	 7227	 0.0	 0.0	 1	 -30.0	 30.0;
	4462	 5428	 0.000591	 0.004651	 0.0	 6738	 6738	 6738	 0.0	 0.0	 1	 -30.0	 30.0;
	4462	 13138	 0.00099	 0.005081	 0.0	 6103	 6103	 6103	 0.0	 0.0	 1	 -30.0	 30.0;
	2234	 13237	 0.00212	 0.013031	 0.0	 2393	 2393	 2393	 0.0	 0.0	 1	 -30.0	 30.0;
	2234	 5194	 0.002159	 0.01275	 0.0	 2443	 2443	 2443	 0.0	 0.0	 1	 -30.0	 30.0;
	12849	 5446	 0.00025	 0.00095	 0.0	 32156	 32156	 32156	 0.0	 0.0	 1	 -30.0	 30.0;
	12849	 5446	 0.000271	 0.00089	 0.0	 33953	 33953	 33953	 0.0	 0.0	 1	 -30.0	 30.0;
	12849	 4005	 0.001961	 0.012409	 0.0	 2515	 2515	 2515	 0.0	 0.0	 1	 -30.0	 30.0;
	12849	 12264	 0.00044	 0.00207	 0.0	 14927	 14927	 14927	 0.0	 0.0	 1	 -30.0	 30.0;
	12849	 12552	 0.000469	 0.00143	 0.0	 20990	 20990	 20990	 0.0	 0.0	 1	 -30.0	 30.0;
	12849	 9611	 0.001271	 0.01406	 0.0	 2238	 2238	 2238	 0.0	 0.0	 1	 -30.0	 30.0;
	12849	 9611	 0.00124	 0.013021	 0.0	 2415	 2415	 2415	 0.0	 0.0	 1	 -30.0	 30.0;
	12849	 7971	 0.000409	 0.00239	 0.0	 13028	 13028	 13028	 0.0	 0.0	 1	 -30.0	 30.0;
	12849	 319	 0.00094	 0.005	 0.0	 6209	 6209	 6209	 0.0	 0.0	 1	 -30.0	 30.0;
	12849	 4469	 0.000219	 0.0007	 0.0	 43067	 43067	 43067	 0.0	 0.0	 1	 -30.0	 30.0;
	12849	 9893	 6e-05	 0.00025	 0.0	 122861	 122861	 122861	 0.0	 0.0	 1	 -30.0	 30.0;
	12849	 7698	 5e-05	 0.000229	 0.0	 134762	 134762	 134762	 0.0	 0.0	 1	 -30.0	 30.0;
	5537	 3942	 0.00019	 0.000909	 0.0	 34015	 34015	 34015	 0.0	 0.0	 1	 -30.0	 30.0;
	3251	 8065	 0.001711	 0.00782	 0.0	 3946	 3946	 3946	 0.0	 0.0	 1	 -30.0	 30.0;
	3251	 9955	 0.002651	 0.01176	 0.0	 2621	 2621	 2621	 0.0	 0.0	 1	 -30.0	 30.0;
	11386	 655	 0.001409	 0.010599	 0.0	 2955	 2955	 2955	 0.0	 0.0	 1	 -30.0	 30.0;
	11386	 7779	 0.001419	 0.010219	 0.0	 3062	 3062	 3062	 0.0	 0.0	 1	 -30.0	 30.0;
	1190	 5763	 0.00013	 0.00212	 0.0	 14872	 14872	 14872	 0.0	 0.0	 1	 -30.0	 30.0;
	1190	 1158	 0.00026	 0.00313	 0.0	 10058	 10058	 10058	 0.0	 0.0	 1	 -30.0	 30.0;
	6613	 3262	 0.0047	 0.0318	 0.0	 983	 983	 983	 0.0	 0.0	 1	 -30.0	 30.0;
	6613	 9938	 0.00136	 0.00768	 0.0	 4050	 4050	 4050	 0.0	 0.0	 1	 -30.0	 30.0;
	6613	 8426	 0.005669	 0.027789	 0.0	 1114	 1114	 1114	 0.0	 0.0	 1	 -30.0	 30.0;
	9794	 9150	 0.004409	 0.033091	 0.0	 947	 947	 947	 0.0	 0.0	 1	 -30.0	 30.0;
	9794	 2032	 0.01056	 0.044469	 0.0	 692	 692	 692	 0.0	 0.0	 1	 -30.0	 30.0;
	9794	 10468	 0.01963	 0.07736	 0.0	 396	 396	 396	 0.0	 0.0	 1	 -30.0	 30.0;
	9794	 10895	 0.01157	 0.04694	 0.0	 654	 654	 654	 0.0	 0.0	 1	 -30.0	 30.0;
	8915	 1228	 0.000479	 0.00255	 0.0	 12175	 12175	 12175	 0.0	 0.0	 1	 -30.0	 30.0;
	11078	 1228	 0.000469	 0.00236	 0.0	 13128	 13128	 13128	 0.0	 0.0	 1	 -30.0	 30.0;
	1695	 2203	 0.01237	 0.067039	 0.0	 464	 464	 464	 0.0	 0.0	 1	 -30.0	 30.0;
	1695	 12559	 0.0132	 0.056229	 0.0	 547	 547	 547	 0.0	 0.0	 1	 -30.0	 30.0;
	5839	 6011	 0.00026	 0.001711	 0.0	 18252	 18252	 18252	 0.0	 0.0	 1	 -30.0	 30.0;
	5839	 6011	 0.000271	 0.001669	 0.0	 18682	 18682	 18682	 0.0	 0.0	 1	 -30.0	 30.0;
	9998	 6400	 0.000211	 0.000401	 0.0	 69711	 69711	 69711	 0.0	 0.0	 1	 -30.0	 30.0;
	3099	 8460	 0.00105	 0.005159	 0.0	 6000	 6000	 6000	 0.0	 0.0	 1	 -30.0	 30.0;
	8287	 4479	 0.00212	 0.00931	 0.0	 3309	 3309	 3309	 0.0	 0.0	 1	 -30.0	 30.0;
	902	 9920	 0.000151	 0.00068	 0.0	 45348	 45348	 45348	 0.0	 0.0	 1	 -30.0	 30.0;
	7886	 7195	 0.00019	 0.00082	 0.0	 37527	 37527	 37527	 0.0	 0.0	 1	 -30.0	 30.0;
	5786	 9955	 0.003219	 0.01405	 0.0	 2192	 2192	 2192	 0.0	 0.0	 1	 -30.0	 30.0;
	9788	 13544	 0.007271	 0.033159	 0.0	 931	 931	 931	 0.0	 0.0	 1	 -30.0	 30.0;
	9788	 11829	 0.006659	 0.03132	 0.0	 987	 987	 987	 0.0	 0.0	 1	 -30.0	 30.0;
	5026	 4088	 0.00057	 0.00668	 0.0	 4712	 4712	 4712	 0.0	 0.0	 1	 -30.0	 30.0;
	5026	 10309	 0.00057	 0.00758	 0.0	 4156	 4156	 4156	 0.0	 0.0	 1	 -30.0	 30.0;
	5026	 10309	 0.00039	 0.00607	 0.0	 5194	 5194	 5194	 0.0	 0.0	 1	 -30.0	 30.0;
	5026	 2348	 0.00155	 0.0179	 0.0	 1759	 1759	 1759	 0.0	 0.0	 1	 -30.0	 30.0;
	5026	 6736	 0.00036	 0.00485	 0.0	 6495	 6495	 6495	 0.0	 0.0	 1	 -30.0	 30.0;
	8307	 2413	 0.000581	 0.004229	 0.0	 7400	 7400	 7400	 0.0	 0.0	 1	 -30.0	 30.0;
	8307	 12054	 0.00056	 0.00431	 0.0	 7268	 7268	 7268	 0.0	 0.0	 1	 -30.0	 30.0;
	8307	 8496	 0.003099	 0.020531	 0.0	 1522	 1522	 1522	 0.0	 0.0	 1	 -30.0	 30.0;
	8307	 4621	 0.00118	 0.016919	 0.0	 1863	 1863	 1863	 0.0	 0.0	 1	 -30.0	 30.0;
	8307	 7730	 0.00188	 0.01407	 0.0	 2226	 2226	 2226	 0.0	 0.0	 1	 -30.0	 30.0;
	8307	 2392	 0.00545	 0.04082	 0.0	 768	 768	 768	 0.0	 0.0	 1	 -30.0	 30.0;
	10642	 655	 0.00214	 0.01639	 0.0	 1912	 1912	 1912	 0.0	 0.0	 1	 -30.0	 30.0;
	10642	 6955	 0.002479	 0.01549	 0.0	 2014	 2014	 2014	 0.0	 0.0	 1	 -30.0	 30.0;
	2621	 11642	 0.000159	 0.001229	 0.0	 25490	 25490	 25490	 0.0	 0.0	 1	 -30.0	 30.0;
	2621	 3790	 0.00026	 0.00162	 0.0	 19252	 19252	 19252	 0.0	 0.0	 1	 -30.0	 30.0;
	2621	 10090	 0.000159	 0.00113	 0.0	 27681	 27681	 27681	 0.0	 0.0	 1	 -30.0	 30.0;
	2621	 13078	 0.000461	 0.003219	 0.0	 9714	 9714	 9714	 0.0	 0.0	 1	 -30.0	 30.0;
	2621	 6144	 0.000159	 0.001229	 0.0	 25490	 25490	 25490	 0.0	 0.0	 1	 -30.0	 30.0;
	2291	 738	 0.000229	 0.00139	 0.0	 22423	 22423	 22423	 0.0	 0.0	 1	 -30.0	 30.0;
	4078	 738	 0.0002	 0.00156	 0.0	 20084	 20084	 20084	 0.0	 0.0	 1	 -30.0	 30.0;
	1919	 6911	 0.00145	 0.00824	 0.0	 3776	 3776	 3776	 0.0	 0.0	 1	 -30.0	 30.0;
	1919	 738	 0.00069	 0.005	 0.0	 6259	 6259	 6259	 0.0	 0.0	 1	 -30.0	 30.0;
	1251	 5445	 0.00036	 0.00455	 0.0	 6921	 6921	 6921	 0.0	 0.0	 1	 -30.0	 30.0;
	1251	 5445	 0.00036	 0.00453	 0.0	 6952	 6952	 6952	 0.0	 0.0	 1	 -30.0	 30.0;
	12241	 11033	 0.00066	 0.00997	 0.0	 3162	 3162	 3162	 0.0	 0.0	 1	 -30.0	 30.0;
	12241	 11033	 0.00064	 0.01016	 0.0	 3103	 3103	 3103	 0.0	 0.0	 1	 -30.0	 30.0;
	9209	 1753	 9.9e-05	 0.00044	 0.0	 70039	 70039	 70039	 0.0	 0.0	 1	 -30.0	 30.0;
	1753	 6486	 6e-05	 0.000469	 0.0	 66806	 66806	 66806	 0.0	 0.0	 1	 -30.0	 30.0;
	1753	 835	 3.9e-05	 0.000341	 0.0	 92032	 92032	 92032	 0.0	 0.0	 1	 -30.0	 30.0;
	1753	 1829	 0.002531	 0.01943	 0.0	 1613	 1613	 1613	 0.0	 0.0	 1	 -30.0	 30.0;
	1753	 5428	 0.00945	 0.06418	 0.0	 487	 487	 487	 0.0	 0.0	 1	 -30.0	 30.0;
	13498	 320	 0.000591	 0.002831	 0.0	 10923	 10923	 10923	 0.0	 0.0	 1	 -30.0	 30.0;
	10251	 320	 0.00087	 0.00387	 0.0	 7964	 7964	 7964	 0.0	 0.0	 1	 -30.0	 30.0;
	1041	 6488	 0.0015	 0.01785	 0.0	 1764	 1764	 1764	 0.0	 0.0	 1	 -30.0	 30.0;
	1041	 6488	 0.00147	 0.0182	 0.0	 1730	 1730	 1730	 0.0	 0.0	 1	 -30.0	 30.0;
	1777	 934	 0.00151	 0.0113	 0.0	 2771	 2771	 2771	 0.0	 0.0	 1	 -30.0	 30.0;
	1777	 934	 0.001479	 0.011521	 0.0	 2720	 2720	 2720	 0.0	 0.0	 1	 -30.0	 30.0;
	1777	 12691	 0.00174	 0.010341	 0.0	 3013	 3013	 3013	 0.0	 0.0	 1	 -30.0	 30.0;
	1777	 12691	 0.001659	 0.01206	 0.0	 2595	 2595	 2595	 0.0	 0.0	 1	 -30.0	 30.0;
	12078	 2847	 0.00069	 0.000479	 0.0	 37606	 37606	 37606	 0.0	 0.0	 1	 -30.0	 30.0;
	12078	 11726	 0.00044	 0.00139	 0.0	 21666	 21666	 21666	 0.0	 0.0	 1	 -30.0	 30.0;
	1489	 13380	 0.002039	 0.01601	 0.0	 1958	 1958	 1958	 0.0	 0.0	 1	 -30.0	 30.0;
	1489	 10933	 0.01349	 0.05662	 0.0	 543	 543	 543	 0.0	 0.0	 1	 -30.0	 30.0;
	1489	 457	 0.00082	 0.00438	 0.0	 7089	 7089	 7089	 0.0	 0.0	 1	 -30.0	 30.0;
	1489	 457	 0.0008	 0.004461	 0.0	 6970	 6970	 6970	 0.0	 0.0	 1	 -30.0	 30.0;
	1489	 7458	 0.001091	 0.00888	 0.0	 3531	 3531	 3531	 0.0	 0.0	 1	 -30.0	 30.0;
	1489	 7458	 0.00111	 0.007039	 0.0	 4433	 4433	 4433	 0.0	 0.0	 1	 -30.0	 30.0;
	3628	 12484	 0.000849	 0.00537	 0.0	 5811	 5811	 5811	 0.0	 0.0	 1	 -30.0	 30.0;
	9062	 13162	 0.00061	 0.00275	 0.0	 11214	 11214	 11214	 0.0	 0.0	 1	 -30.0	 30.0;
	9068	 11274	 0.00141	 0.0188	 0.0	 1676	 1676	 1676	 0.0	 0.0	 1	 -30.0	 30.0;
	9068	 9685	 0.00121	 0.01427	 0.0	 2206	 2206	 2206	 0.0	 0.0	 1	 -30.0	 30.0;
	3391	 12003	 0.001711	 0.007159	 0.0	 4292	 4292	 4292	 0.0	 0.0	 1	 -30.0	 30.0;
	3391	 13011	 0.00545	 0.02381	 0.0	 1294	 1294	 1294	 0.0	 0.0	 1	 -30.0	 30.0;
	3391	 6083	 0.000771	 0.004331	 0.0	 7181	 7181	 7181	 0.0	 0.0	 1	 -30.0	 30.0;
	3391	 3998	 0.00414	 0.03282	 0.0	 955	 955	 955	 0.0	 0.0	 1	 -30.0	 30.0;
	3391	 9262	 0.00264	 0.011521	 0.0	 2673	 2673	 2673	 0.0	 0.0	 1	 -30.0	 30.0;
	3391	 9334	 0.00261	 0.011	 0.0	 2795	 2795	 2795	 0.0	 0.0	 1	 -30.0	 30.0;
	3391	 12412	 0.00239	 0.00919	 0.0	 3327	 3327	 3327	 0.0	 0.0	 1	 -30.0	 30.0;
	3391	 4134	 0.000539	 0.00226	 0.0	 13596	 13596	 13596	 0.0	 0.0	 1	 -30.0	 30.0;
	3391	 10056	 0.00325	 0.017979	 0.0	 1729	 1729	 1729	 0.0	 0.0	 1	 -30.0	 30.0;
	1766	 6661	 0.00076	 0.0071	 0.0	 4424	 4424	 4424	 0.0	 0.0	 1	 -30.0	 30.0;
	1168	 12412	 0.000651	 0.00343	 0.0	 9048	 9048	 9048	 0.0	 0.0	 1	 -30.0	 30.0;
	3286	 6389	 0.001219	 0.00812	 0.0	 3847	 3847	 3847	 0.0	 0.0	 1	 -30.0	 30.0;
	3286	 1162	 0.00243	 0.01439	 0.0	 2165	 2165	 2165	 0.0	 0.0	 1	 -30.0	 30.0;
	13566	 9117	 0.0006	 0.00839	 0.0	 3756	 3756	 3756	 0.0	 0.0	 1	 -30.0	 30.0;
	13566	 9117	 0.00059	 0.00856	 0.0	 3682	 3682	 3682	 0.0	 0.0	 1	 -30.0	 30.0;
	13566	 8243	 0.00087	 0.01328	 0.0	 2374	 2374	 2374	 0.0	 0.0	 1	 -30.0	 30.0;
	13566	 8243	 0.00073	 0.01595	 0.0	 1979	 1979	 1979	 0.0	 0.0	 1	 -30.0	 30.0;
	4205	 5378	 0.00163	 0.002039	 0.0	 12101	 12101	 12101	 0.0	 0.0	 1	 -30.0	 30.0;
	4205	 5378	 0.001659	 0.002	 0.0	 12156	 12156	 12156	 0.0	 0.0	 1	 -30.0	 30.0;
	83	 8374	 0.00339	 0.019669	 0.0	 1583	 1583	 1583	 0.0	 0.0	 1	 -30.0	 30.0;
	83	 3377	 0.00239	 0.017281	 0.0	 1811	 1811	 1811	 0.0	 0.0	 1	 -30.0	 30.0;
	9532	 11801	 0.00032	 0.00112	 0.0	 27118	 27118	 27118	 0.0	 0.0	 1	 -30.0	 30.0;
	9532	 8620	 0.0018	 0.01401	 0.0	 2237	 2237	 2237	 0.0	 0.0	 1	 -30.0	 30.0;
	9532	 8620	 0.00212	 0.012469	 0.0	 2498	 2498	 2498	 0.0	 0.0	 1	 -30.0	 30.0;
	11601	 4090	 0.00063	 0.00411	 0.0	 7597	 7597	 7597	 0.0	 0.0	 1	 -30.0	 30.0;
	9407	 6043	 0.009729	 0.03505	 0.0	 869	 869	 869	 0.0	 0.0	 1	 -30.0	 30.0;
	9407	 5222	 0.01007	 0.03056	 0.0	 982	 982	 982	 0.0	 0.0	 1	 -30.0	 30.0;
	7189	 4031	 0.00042	 0.00623	 0.0	 5059	 5059	 5059	 0.0	 0.0	 1	 -30.0	 30.0;
	7189	 523	 0.00036	 0.00722	 0.0	 4370	 4370	 4370	 0.0	 0.0	 1	 -30.0	 30.0;
	7189	 9633	 0.00053	 0.0078	 0.0	 4041	 4041	 4041	 0.0	 0.0	 1	 -30.0	 30.0;
	7189	 2746	 0.00109	 0.0173	 0.0	 1823	 1823	 1823	 0.0	 0.0	 1	 -30.0	 30.0;
	7189	 8497	 0.00071	 0.01144	 0.0	 2756	 2756	 2756	 0.0	 0.0	 1	 -30.0	 30.0;
	7189	 5623	 0.00157	 0.01884	 0.0	 1671	 1671	 1671	 0.0	 0.0	 1	 -30.0	 30.0;
	7189	 5249	 0.00032	 0.00384	 0.0	 8198	 8198	 8198	 0.0	 0.0	 1	 -30.0	 30.0;
	11334	 2558	 0.00041	 0.00649	 0.0	 4858	 4858	 4858	 0.0	 0.0	 1	 -30.0	 30.0;
	11334	 11442	 0.0004	 0.00658	 0.0	 4792	 4792	 4792	 0.0	 0.0	 1	 -30.0	 30.0;
	11334	 9633	 0.00054	 0.00763	 0.0	 4130	 4130	 4130	 0.0	 0.0	 1	 -30.0	 30.0;
	11334	 2746	 0.00107	 0.01602	 0.0	 1968	 1968	 1968	 0.0	 0.0	 1	 -30.0	 30.0;
	11334	 8497	 0.0007	 0.01165	 0.0	 2707	 2707	 2707	 0.0	 0.0	 1	 -30.0	 30.0;
	11334	 8232	 0.0016	 0.01844	 0.0	 1707	 1707	 1707	 0.0	 0.0	 1	 -30.0	 30.0;
	11334	 5249	 0.00032	 0.00376	 0.0	 8371	 8371	 8371	 0.0	 0.0	 1	 -30.0	 30.0;
	6766	 244	 0.00212	 0.01207	 0.0	 2578	 2578	 2578	 0.0	 0.0	 1	 -30.0	 30.0;
	4533	 3350	 5e-05	 0.00037	 0.0	 84603	 84603	 84603	 0.0	 0.0	 1	 -30.0	 30.0;
	9150	 12997	 0.00355	 0.024651	 0.0	 1269	 1269	 1269	 0.0	 0.0	 1	 -30.0	 30.0;
	9124	 12744	 0.00675	 0.04145	 0.0	 753	 753	 753	 0.0	 0.0	 1	 -30.0	 30.0;
	8047	 10444	 0.00195	 0.014341	 0.0	 2183	 2183	 2183	 0.0	 0.0	 1	 -30.0	 30.0;
	12320	 6392	 0.00018	 0.00043	 0.0	 67762	 67762	 67762	 0.0	 0.0	 1	 -30.0	 30.0;
	12320	 4212	 0.00037	 0.000969	 0.0	 30454	 30454	 30454	 0.0	 0.0	 1	 -30.0	 30.0;
	890	 1902	 0.00257	 0.017169	 0.0	 1820	 1820	 1820	 0.0	 0.0	 1	 -30.0	 30.0;
	890	 7887	 0.00076	 0.00399	 0.0	 7777	 7777	 7777	 0.0	 0.0	 1	 -30.0	 30.0;
	890	 7887	 0.00075	 0.00406	 0.0	 7651	 7651	 7651	 0.0	 0.0	 1	 -30.0	 30.0;
	890	 4974	 0.003901	 0.023961	 0.0	 1302	 1302	 1302	 0.0	 0.0	 1	 -30.0	 30.0;
	890	 1116	 0.00249	 0.019211	 0.0	 1631	 1631	 1631	 0.0	 0.0	 1	 -30.0	 30.0;
	5393	 4212	 0.00025	 0.001159	 0.0	 26642	 26642	 26642	 0.0	 0.0	 1	 -30.0	 30.0;
	1920	 13477	 0.00195	 0.02924	 0.0	 1078	 1078	 1078	 0.0	 0.0	 1	 -30.0	 30.0;
	1920	 5981	 0.00152	 0.01527	 0.0	 2059	 2059	 2059	 0.0	 0.0	 1	 -30.0	 30.0;
	1920	 11182	 0.00149	 0.01558	 0.0	 2019	 2019	 2019	 0.0	 0.0	 1	 -30.0	 30.0;
	1920	 1554	 0.00253	 0.0276	 0.0	 1140	 1140	 1140	 0.0	 0.0	 1	 -30.0	 30.0;
	1920	 1554	 0.00263	 0.02648	 0.0	 1188	 1188	 1188	 0.0	 0.0	 1	 -30.0	 30.0;
	1920	 3376	 0.00077	 0.0092	 0.0	 3422	 3422	 3422	 0.0	 0.0	 1	 -30.0	 30.0;
	1920	 6157	 0.00112	 0.01705	 0.0	 1849	 1849	 1849	 0.0	 0.0	 1	 -30.0	 30.0;
	8521	 12611	 0.00226	 0.01101	 0.0	 2811	 2811	 2811	 0.0	 0.0	 1	 -30.0	 30.0;
	8521	 8718	 0.004531	 0.029039	 0.0	 1075	 1075	 1075	 0.0	 0.0	 1	 -30.0	 30.0;
	8521	 11774	 0.002081	 0.030409	 0.0	 1037	 1037	 1037	 0.0	 0.0	 1	 -30.0	 30.0;
	8521	 5779	 0.0053	 0.03257	 0.0	 958	 958	 958	 0.0	 0.0	 1	 -30.0	 30.0;
	8521	 4848	 0.00513	 0.041901	 0.0	 749	 749	 749	 0.0	 0.0	 1	 -30.0	 30.0;
	8521	 6956	 0.001461	 0.01056	 0.0	 2964	 2964	 2964	 0.0	 0.0	 1	 -30.0	 30.0;
	5497	 1162	 0.0005	 0.002591	 0.0	 11971	 11971	 11971	 0.0	 0.0	 1	 -30.0	 30.0;
	8992	 1294	 0.00055	 0.0033	 0.0	 9442	 9442	 9442	 0.0	 0.0	 1	 -30.0	 30.0;
	5888	 9561	 0.002289	 0.01763	 0.0	 1777	 1777	 1777	 0.0	 0.0	 1	 -30.0	 30.0;
	5888	 3083	 0.0075	 0.043531	 0.0	 716	 716	 716	 0.0	 0.0	 1	 -30.0	 30.0;
	8322	 4974	 0.00138	 0.019961	 0.0	 1579	 1579	 1579	 0.0	 0.0	 1	 -30.0	 30.0;
	8322	 1139	 0.00126	 0.018729	 0.0	 1683	 1683	 1683	 0.0	 0.0	 1	 -30.0	 30.0;
	3319	 13581	 0.00038	 0.001331	 0.0	 22821	 22821	 22821	 0.0	 0.0	 1	 -30.0	 30.0;
	3319	 4966	 0.00019	 0.001461	 0.0	 21440	 21440	 21440	 0.0	 0.0	 1	 -30.0	 30.0;
	300	 6955	 0.002151	 0.013401	 0.0	 2328	 2328	 2328	 0.0	 0.0	 1	 -30.0	 30.0;
	300	 11424	 0.000789	 0.005669	 0.0	 5519	 5519	 5519	 0.0	 0.0	 1	 -30.0	 30.0;
	4638	 9840	 3e-05	 0.00042	 0.0	 75017	 75017	 75017	 0.0	 0.0	 1	 -30.0	 30.0;
	4638	 970	 0.00079	 0.00899	 0.0	 3501	 3501	 3501	 0.0	 0.0	 1	 -30.0	 30.0;
	4638	 970	 0.0008	 0.00879	 0.0	 3579	 3579	 3579	 0.0	 0.0	 1	 -30.0	 30.0;
	4638	 6512	 0.00334	 0.03393	 0.0	 927	 927	 927	 0.0	 0.0	 1	 -30.0	 30.0;
	4638	 2350	 0.00063	 0.00789	 0.0	 3991	 3991	 3991	 0.0	 0.0	 1	 -30.0	 30.0;
	4638	 3448	 0.0006	 0.00842	 0.0	 3742	 3742	 3742	 0.0	 0.0	 1	 -30.0	 30.0;
	12483	 11746	 0.00011	 0.00125	 0.0	 25173	 25173	 25173	 0.0	 0.0	 1	 -30.0	 30.0;
	12483	 9538	 0.00012	 0.001091	 0.0	 28780	 28780	 28780	 0.0	 0.0	 1	 -30.0	 30.0;
	12483	 11283	 9.9e-05	 0.00125	 0.0	 25191	 25191	 25191	 0.0	 0.0	 1	 -30.0	 30.0;
	12483	 609	 0.00294	 0.02443	 0.0	 1284	 1284	 1284	 0.0	 0.0	 1	 -30.0	 30.0;
	12483	 4086	 0.00144	 0.011151	 0.0	 2810	 2810	 2810	 0.0	 0.0	 1	 -30.0	 30.0;
	12483	 3502	 0.001831	 0.010849	 0.0	 2871	 2871	 2871	 0.0	 0.0	 1	 -30.0	 30.0;
	12483	 3502	 0.001599	 0.01055	 0.0	 2961	 2961	 2961	 0.0	 0.0	 1	 -30.0	 30.0;
	12483	 4315	 0.00144	 0.019591	 0.0	 1609	 1609	 1609	 0.0	 0.0	 1	 -30.0	 30.0;
	8282	 1420	 0.0133	 0.09551	 0.0	 328	 328	 328	 0.0	 0.0	 1	 -30.0	 30.0;
	8282	 6497	 0.009591	 0.073961	 0.0	 424	 424	 424	 0.0	 0.0	 1	 -30.0	 30.0;
	6488	 3891	 0.0007	 0.00671	 0.0	 4683	 4683	 4683	 0.0	 0.0	 1	 -30.0	 30.0;
	6488	 3891	 0.00072	 0.00658	 0.0	 4773	 4773	 4773	 0.0	 0.0	 1	 -30.0	 30.0;
	3378	 1154	 0.001901	 0.00964	 0.0	 3215	 3215	 3215	 0.0	 0.0	 1	 -30.0	 30.0;
	3378	 5010	 0.001711	 0.01189	 0.0	 2630	 2630	 2630	 0.0	 0.0	 1	 -30.0	 30.0;
	4637	 6956	 0.00025	 0.00187	 0.0	 16743	 16743	 16743	 0.0	 0.0	 1	 -30.0	 30.0;
	6158	 8034	 0.00043	 0.002211	 0.0	 14024	 14024	 14024	 0.0	 0.0	 1	 -30.0	 30.0;
	8292	 12299	 0.000401	 0.00243	 0.0	 12826	 12826	 12826	 0.0	 0.0	 1	 -30.0	 30.0;
	11443	 7462	 0.00336	 0.017	 0.0	 1823	 1823	 1823	 0.0	 0.0	 1	 -30.0	 30.0;
	10579	 1162	 0.005521	 0.031031	 0.0	 1003	 1003	 1003	 0.0	 0.0	 1	 -30.0	 30.0;
	6466	 3056	 9.9e-05	 0.00026	 0.0	 113538	 113538	 113538	 0.0	 0.0	 1	 -30.0	 30.0;
	9009	 3917	 0.00045	 0.00718	 0.0	 4391	 4391	 4391	 0.0	 0.0	 1	 -30.0	 30.0;
	9009	 6675	 0.00044	 0.00665	 0.0	 4740	 4740	 4740	 0.0	 0.0	 1	 -30.0	 30.0;
	9009	 11015	 0.00103	 0.01516	 0.0	 2079	 2079	 2079	 0.0	 0.0	 1	 -30.0	 30.0;
	9009	 10996	 0.00101	 0.01546	 0.0	 2039	 2039	 2039	 0.0	 0.0	 1	 -30.0	 30.0;
	7339	 32	 0.00045	 0.00608	 0.0	 5182	 5182	 5182	 0.0	 0.0	 1	 -30.0	 30.0;
	7339	 13621	 0.0004	 0.00501	 0.0	 6285	 6285	 6285	 0.0	 0.0	 1	 -30.0	 30.0;
	8926	 13308	 0.001729	 0.01337	 0.0	 2344	 2344	 2344	 0.0	 0.0	 1	 -30.0	 30.0;
	8926	 9096	 0.00264	 0.01489	 0.0	 2089	 2089	 2089	 0.0	 0.0	 1	 -30.0	 30.0;
	8926	 1242	 0.002341	 0.018961	 0.0	 1654	 1654	 1654	 0.0	 0.0	 1	 -30.0	 30.0;
	8926	 8338	 0.001841	 0.01363	 0.0	 2297	 2297	 2297	 0.0	 0.0	 1	 -30.0	 30.0;
	2058	 11287	 0.001219	 0.00949	 0.0	 3302	 3302	 3302	 0.0	 0.0	 1	 -30.0	 30.0;
	2058	 13308	 0.002271	 0.01151	 0.0	 2693	 2693	 2693	 0.0	 0.0	 1	 -30.0	 30.0;
	2058	 8721	 0.010781	 0.05775	 0.0	 538	 538	 538	 0.0	 0.0	 1	 -30.0	 30.0;
	2058	 10761	 0.00251	 0.013919	 0.0	 2234	 2234	 2234	 0.0	 0.0	 1	 -30.0	 30.0;
	2058	 203	 0.00101	 0.007331	 0.0	 4269	 4269	 4269	 0.0	 0.0	 1	 -30.0	 30.0;
	3572	 6043	 0.00061	 0.003909	 0.0	 7985	 7985	 7985	 0.0	 0.0	 1	 -30.0	 30.0;
	5857	 9324	 0.004289	 0.019331	 0.0	 1596	 1596	 1596	 0.0	 0.0	 1	 -30.0	 30.0;
	5857	 6043	 0.0008	 0.004401	 0.0	 7062	 7062	 7062	 0.0	 0.0	 1	 -30.0	 30.0;
	5857	 7077	 0.008099	 0.03519	 0.0	 875	 875	 875	 0.0	 0.0	 1	 -30.0	 30.0;
	5857	 11544	 0.00063	 0.004591	 0.0	 6817	 6817	 6817	 0.0	 0.0	 1	 -30.0	 30.0;
	4012	 11544	 0.000651	 0.00456	 0.0	 6858	 6858	 6858	 0.0	 0.0	 1	 -30.0	 30.0;
	3572	 8614	 0.00114	 0.00581	 0.0	 5335	 5335	 5335	 0.0	 0.0	 1	 -30.0	 30.0;
	3572	 3182	 0.001211	 0.00538	 0.0	 5728	 5728	 5728	 0.0	 0.0	 1	 -30.0	 30.0;
	961	 6290	 0.00418	 0.030159	 0.0	 1038	 1038	 1038	 0.0	 0.0	 1	 -30.0	 30.0;
	961	 12535	 0.00324	 0.02413	 0.0	 1298	 1298	 1298	 0.0	 0.0	 1	 -30.0	 30.0;
	961	 12535	 0.003169	 0.024591	 0.0	 1274	 1274	 1274	 0.0	 0.0	 1	 -30.0	 30.0;
	6530	 13308	 0.000219	 0.00088	 0.0	 34833	 34833	 34833	 0.0	 0.0	 1	 -30.0	 30.0;
	6530	 13308	 0.000289	 0.00095	 0.0	 31811	 31811	 31811	 0.0	 0.0	 1	 -30.0	 30.0;
	1294	 55	 0.0035	 0.022211	 0.0	 1405	 1405	 1405	 0.0	 0.0	 1	 -30.0	 30.0;
	1294	 13237	 0.00313	 0.02256	 0.0	 1387	 1387	 1387	 0.0	 0.0	 1	 -30.0	 30.0;
	8660	 13031	 0.000831	 0.00162	 0.0	 17349	 17349	 17349	 0.0	 0.0	 1	 -30.0	 30.0;
	4605	 12559	 0.002099	 0.01068	 0.0	 2903	 2903	 2903	 0.0	 0.0	 1	 -30.0	 30.0;
	1426	 12559	 0.00224	 0.00976	 0.0	 3155	 3155	 3155	 0.0	 0.0	 1	 -30.0	 30.0;
	12997	 2050	 0.00169	 0.01231	 0.0	 2543	 2543	 2543	 0.0	 0.0	 1	 -30.0	 30.0;
	9707	 13372	 0.00011	 0.00076	 0.0	 41134	 41134	 41134	 0.0	 0.0	 1	 -30.0	 30.0;
	13465	 13372	 0.00011	 0.00068	 0.0	 45856	 45856	 45856	 0.0	 0.0	 1	 -30.0	 30.0;
	10170	 9324	 0.005479	 0.021909	 0.0	 1399	 1399	 1399	 0.0	 0.0	 1	 -30.0	 30.0;
	10170	 13045	 0.003331	 0.017039	 0.0	 1820	 1820	 1820	 0.0	 0.0	 1	 -30.0	 30.0;
	7974	 6389	 0.000479	 0.001271	 0.0	 23256	 23256	 23256	 0.0	 0.0	 1	 -30.0	 30.0;
	10941	 4266	 0.00109	 0.01629	 0.0	 1935	 1935	 1935	 0.0	 0.0	 1	 -30.0	 30.0;
	10941	 4439	 4e-05	 0.00063	 0.0	 50038	 50038	 50038	 0.0	 0.0	 1	 -30.0	 30.0;
	806	 9181	 0.0053	 0.024531	 0.0	 1259	 1259	 1259	 0.0	 0.0	 1	 -30.0	 30.0;
	806	 3268	 0.004659	 0.021919	 0.0	 1410	 1410	 1410	 0.0	 0.0	 1	 -30.0	 30.0;
	806	 5395	 0.001659	 0.01043	 0.0	 2991	 2991	 2991	 0.0	 0.0	 1	 -30.0	 30.0;
	7319	 6084	 0.006961	 0.053539	 0.0	 586	 586	 586	 0.0	 0.0	 1	 -30.0	 30.0;
	2696	 7917	 0.00036	 0.00288	 0.0	 10884	 10884	 10884	 0.0	 0.0	 1	 -30.0	 30.0;
	2696	 7917	 0.00038	 0.003	 0.0	 10446	 10446	 10446	 0.0	 0.0	 1	 -30.0	 30.0;
	7987	 7274	 0.00048	 0.00643	 0.0	 4899	 4899	 4899	 0.0	 0.0	 1	 -30.0	 30.0;
	7987	 7274	 0.00051	 0.0066	 0.0	 4772	 4772	 4772	 0.0	 0.0	 1	 -30.0	 30.0;
	7987	 7274	 0.00046	 0.00729	 0.0	 4325	 4325	 4325	 0.0	 0.0	 1	 -30.0	 30.0;
	7987	 7948	 0.0006	 0.00868	 0.0	 3631	 3631	 3631	 0.0	 0.0	 1	 -30.0	 30.0;
	7987	 11402	 0.00068	 0.01076	 0.0	 2930	 2930	 2930	 0.0	 0.0	 1	 -30.0	 30.0;
	7987	 10071	 0.00066	 0.01096	 0.0	 2877	 2877	 2877	 0.0	 0.0	 1	 -30.0	 30.0;
	4445	 6692	 0.00101	 0.005099	 0.0	 6077	 6077	 6077	 0.0	 0.0	 1	 -30.0	 30.0;
	823	 12495	 0.003901	 0.02437	 0.0	 1280	 1280	 1280	 0.0	 0.0	 1	 -30.0	 30.0;
	823	 3211	 0.00276	 0.016461	 0.0	 1893	 1893	 1893	 0.0	 0.0	 1	 -30.0	 30.0;
	823	 11608	 0.00588	 0.047081	 0.0	 666	 666	 666	 0.0	 0.0	 1	 -30.0	 30.0;
	6350	 2641	 3.9e-05	 0.000219	 0.0	 142001	 142001	 142001	 0.0	 0.0	 1	 -30.0	 30.0;
	4119	 12862	 0.00131	 0.00538	 0.0	 5705	 5705	 5705	 0.0	 0.0	 1	 -30.0	 30.0;
	4094	 1554	 0.00679	 0.04679	 0.0	 669	 669	 669	 0.0	 0.0	 1	 -30.0	 30.0;
	4094	 13408	 0.00138	 0.01466	 0.0	 2146	 2146	 2146	 0.0	 0.0	 1	 -30.0	 30.0;
	13471	 13568	 0.003531	 0.01724	 0.0	 1795	 1795	 1795	 0.0	 0.0	 1	 -30.0	 30.0;
	13471	 2016	 0.01324	 0.06936	 0.0	 448	 448	 448	 0.0	 0.0	 1	 -30.0	 30.0;
	13471	 12559	 0.00363	 0.01743	 0.0	 1775	 1775	 1775	 0.0	 0.0	 1	 -30.0	 30.0;
	13471	 12559	 0.00257	 0.01662	 0.0	 1879	 1879	 1879	 0.0	 0.0	 1	 -30.0	 30.0;
	13471	 7396	 0.01399	 0.056289	 0.0	 545	 545	 545	 0.0	 0.0	 1	 -30.0	 30.0;
	13471	 1507	 0.00343	 0.01751	 0.0	 1771	 1771	 1771	 0.0	 0.0	 1	 -30.0	 30.0;
	13471	 1980	 0.00301	 0.015409	 0.0	 2012	 2012	 2012	 0.0	 0.0	 1	 -30.0	 30.0;
	13471	 2259	 0.00857	 0.033091	 0.0	 925	 925	 925	 0.0	 0.0	 1	 -30.0	 30.0;
	9018	 10058	 0.003341	 0.01689	 0.0	 1835	 1835	 1835	 0.0	 0.0	 1	 -30.0	 30.0;
	11206	 4350	 3.9e-05	 0.000219	 0.0	 142001	 142001	 142001	 0.0	 0.0	 1	 -30.0	 30.0;
	10767	 8175	 0.00087	 0.00714	 0.0	 4392	 4392	 4392	 0.0	 0.0	 1	 -30.0	 30.0;
	6895	 13408	 0.00011	 0.001	 0.0	 31398	 31398	 31398	 0.0	 0.0	 1	 -30.0	 30.0;
	2390	 7811	 0.000219	 0.00101	 0.0	 30565	 30565	 30565	 0.0	 0.0	 1	 -30.0	 30.0;
	5696	 7811	 0.000219	 0.001031	 0.0	 29969	 29969	 29969	 0.0	 0.0	 1	 -30.0	 30.0;
	12456	 7811	 0.000271	 0.00101	 0.0	 30207	 30207	 30207	 0.0	 0.0	 1	 -30.0	 30.0;
	5300	 7811	 0.000271	 0.000979	 0.0	 31096	 31096	 31096	 0.0	 0.0	 1	 -30.0	 30.0;
	3980	 7811	 0.000289	 0.00107	 0.0	 28500	 28500	 28500	 0.0	 0.0	 1	 -30.0	 30.0;
	7314	 7811	 0.000289	 0.00105	 0.0	 29005	 29005	 29005	 0.0	 0.0	 1	 -30.0	 30.0;
	6389	 8821	 0.001591	 0.012289	 0.0	 2550	 2550	 2550	 0.0	 0.0	 1	 -30.0	 30.0;
	3067	 7638	 0.000271	 0.001901	 0.0	 16450	 16450	 16450	 0.0	 0.0	 1	 -30.0	 30.0;
	3067	 9916	 0.00186	 0.010711	 0.0	 2906	 2906	 2906	 0.0	 0.0	 1	 -30.0	 30.0;
	1499	 5150	 1e-05	 0.0002	 0.0	 157740	 157740	 157740	 0.0	 0.0	 1	 -30.0	 30.0;
	5948	 1242	 0.000169	 0.000271	 0.0	 98903	 98903	 98903	 0.0	 0.0	 1	 -30.0	 30.0;
	6635	 1242	 0.000169	 0.00031	 0.0	 89464	 89464	 89464	 0.0	 0.0	 1	 -30.0	 30.0;
	2425	 8460	 0.00526	 0.03787	 0.0	 827	 827	 827	 0.0	 0.0	 1	 -30.0	 30.0;
	11923	 2115	 0.000229	 0.000599	 0.0	 49257	 49257	 49257	 0.0	 0.0	 1	 -30.0	 30.0;
	8249	 8034	 0.00089	 0.004091	 0.0	 7545	 7545	 7545	 0.0	 0.0	 1	 -30.0	 30.0;
	6575	 12299	 0.00093	 0.004	 0.0	 7692	 7692	 7692	 0.0	 0.0	 1	 -30.0	 30.0;
	13011	 12412	 0.00289	 0.013099	 0.0	 2355	 2355	 2355	 0.0	 0.0	 1	 -30.0	 30.0;
	3341	 9412	 0.002599	 0.016479	 0.0	 1894	 1894	 1894	 0.0	 0.0	 1	 -30.0	 30.0;
	668	 603	 0.00369	 0.02712	 0.0	 1155	 1155	 1155	 0.0	 0.0	 1	 -30.0	 30.0;
	668	 5664	 0.0062	 0.04864	 0.0	 645	 645	 645	 0.0	 0.0	 1	 -30.0	 30.0;
	668	 495	 0.008021	 0.059031	 0.0	 531	 531	 531	 0.0	 0.0	 1	 -30.0	 30.0;
	668	 10138	 0.004979	 0.0295	 0.0	 1056	 1056	 1056	 0.0	 0.0	 1	 -30.0	 30.0;
	12101	 5395	 0.001159	 0.005281	 0.0	 5843	 5843	 5843	 0.0	 0.0	 1	 -30.0	 30.0;
	6970	 11371	 0.00361	 0.01824	 0.0	 1699	 1699	 1699	 0.0	 0.0	 1	 -30.0	 30.0;
	6970	 2768	 0.001521	 0.01075	 0.0	 2910	 2910	 2910	 0.0	 0.0	 1	 -30.0	 30.0;
	6970	 6217	 0.00868	 0.041711	 0.0	 742	 742	 742	 0.0	 0.0	 1	 -30.0	 30.0;
	3725	 7804	 0.01118	 0.05986	 0.0	 519	 519	 519	 0.0	 0.0	 1	 -30.0	 30.0;
	3725	 11066	 0.003229	 0.02543	 0.0	 1233	 1233	 1233	 0.0	 0.0	 1	 -30.0	 30.0;
	3725	 11066	 0.00218	 0.01869	 0.0	 1679	 1679	 1679	 0.0	 0.0	 1	 -30.0	 30.0;
	3725	 11066	 0.001901	 0.021909	 0.0	 1437	 1437	 1437	 0.0	 0.0	 1	 -30.0	 30.0;
	3725	 11753	 0.00974	 0.043969	 0.0	 702	 702	 702	 0.0	 0.0	 1	 -30.0	 30.0;
	3725	 10585	 0.003461	 0.01814	 0.0	 1711	 1711	 1711	 0.0	 0.0	 1	 -30.0	 30.0;
	3725	 2220	 0.00487	 0.027669	 0.0	 1125	 1125	 1125	 0.0	 0.0	 1	 -30.0	 30.0;
	11642	 1657	 0.000651	 0.003961	 0.0	 7870	 7870	 7870	 0.0	 0.0	 1	 -30.0	 30.0;
	12857	 8007	 0.00169	 0.00887	 0.0	 3499	 3499	 3499	 0.0	 0.0	 1	 -30.0	 30.0;
	4464	 13138	 0.001711	 0.01336	 0.0	 2346	 2346	 2346	 0.0	 0.0	 1	 -30.0	 30.0;
	2238	 1385	 0.00031	 0.000539	 0.0	 50801	 50801	 50801	 0.0	 0.0	 1	 -30.0	 30.0;
	2904	 2041	 0.0027	 0.01157	 0.0	 2659	 2659	 2659	 0.0	 0.0	 1	 -30.0	 30.0;
	5220	 934	 0.000909	 0.006901	 0.0	 4539	 4539	 4539	 0.0	 0.0	 1	 -30.0	 30.0;
	5220	 1154	 0.001729	 0.01214	 0.0	 2576	 2576	 2576	 0.0	 0.0	 1	 -30.0	 30.0;
	609	 5112	 0.00614	 0.03106	 0.0	 998	 998	 998	 0.0	 0.0	 1	 -30.0	 30.0;
	609	 11662	 0.00418	 0.02388	 0.0	 1303	 1303	 1303	 0.0	 0.0	 1	 -30.0	 30.0;
	4741	 1783	 0.00238	 0.017771	 0.0	 1762	 1762	 1762	 0.0	 0.0	 1	 -30.0	 30.0;
	4741	 2574	 8.1e-05	 0.00063	 0.0	 49730	 49730	 49730	 0.0	 0.0	 1	 -30.0	 30.0;
	10813	 544	 0.001599	 0.01618	 0.0	 1943	 1943	 1943	 0.0	 0.0	 1	 -30.0	 30.0;
	6240	 3018	 0.00532	 0.026961	 0.0	 1150	 1150	 1150	 0.0	 0.0	 1	 -30.0	 30.0;
	6240	 3018	 0.00361	 0.02814	 0.0	 1114	 1114	 1114	 0.0	 0.0	 1	 -30.0	 30.0;
	6240	 8095	 0.002469	 0.01025	 0.0	 2996	 2996	 2996	 0.0	 0.0	 1	 -30.0	 30.0;
	9324	 2581	 0.005229	 0.02675	 0.0	 1159	 1159	 1159	 0.0	 0.0	 1	 -30.0	 30.0;
	9324	 2581	 0.00512	 0.02726	 0.0	 1139	 1139	 1139	 0.0	 0.0	 1	 -30.0	 30.0;
	9324	 11544	 0.00355	 0.01694	 0.0	 1826	 1826	 1826	 0.0	 0.0	 1	 -30.0	 30.0;
	6927	 10683	 0.00139	 0.007659	 0.0	 4058	 4058	 4058	 0.0	 0.0	 1	 -30.0	 30.0;
	6927	 5877	 0.000169	 0.000669	 0.0	 45778	 45778	 45778	 0.0	 0.0	 1	 -30.0	 30.0;
	12800	 3285	 0.00111	 0.00712	 0.0	 4384	 4384	 4384	 0.0	 0.0	 1	 -30.0	 30.0;
	1275	 7576	 0.00031	 0.001901	 0.0	 16400	 16400	 16400	 0.0	 0.0	 1	 -30.0	 30.0;
	7509	 7576	 0.000281	 0.002091	 0.0	 14972	 14972	 14972	 0.0	 0.0	 1	 -30.0	 30.0;
	6178	 9593	 0.000281	 0.001651	 0.0	 18862	 18862	 18862	 0.0	 0.0	 1	 -30.0	 30.0;
	10735	 9593	 0.000271	 0.00169	 0.0	 18455	 18455	 18455	 0.0	 0.0	 1	 -30.0	 30.0;
	8522	 2863	 0.001521	 0.00843	 0.0	 3688	 3688	 3688	 0.0	 0.0	 1	 -30.0	 30.0;
	8522	 894	 0.000841	 0.0062	 0.0	 5049	 5049	 5049	 0.0	 0.0	 1	 -30.0	 30.0;
	5598	 3560	 0.00019	 0.00126	 0.0	 24790	 24790	 24790	 0.0	 0.0	 1	 -30.0	 30.0;
	1261	 9677	 0.000219	 0.00143	 0.0	 21835	 21835	 21835	 0.0	 0.0	 1	 -30.0	 30.0;
	5236	 11927	 0.00121	 0.01796	 0.0	 1755	 1755	 1755	 0.0	 0.0	 1	 -30.0	 30.0;
	5236	 11927	 0.0014	 0.01512	 0.0	 2081	 2081	 2081	 0.0	 0.0	 1	 -30.0	 30.0;
	9561	 3083	 0.008409	 0.063651	 0.0	 492	 492	 492	 0.0	 0.0	 1	 -30.0	 30.0;
	9561	 12662	 0.00918	 0.07344	 0.0	 427	 427	 427	 0.0	 0.0	 1	 -30.0	 30.0;
	9561	 889	 0.004219	 0.0345	 0.0	 909	 909	 909	 0.0	 0.0	 1	 -30.0	 30.0;
	9561	 889	 0.0042	 0.031651	 0.0	 990	 990	 990	 0.0	 0.0	 1	 -30.0	 30.0;
	6589	 11823	 0.00121	 0.01381	 0.0	 2279	 2279	 2279	 0.0	 0.0	 1	 -30.0	 30.0;
	6589	 10309	 0.00107	 0.01326	 0.0	 2375	 2375	 2375	 0.0	 0.0	 1	 -30.0	 30.0;
	7804	 8460	 0.003401	 0.02607	 0.0	 1202	 1202	 1202	 0.0	 0.0	 1	 -30.0	 30.0;
	5415	 26	 0.000289	 0.00138	 0.0	 22404	 22404	 22404	 0.0	 0.0	 1	 -30.0	 30.0;
	7503	 955	 0.001031	 0.006039	 0.0	 5156	 5156	 5156	 0.0	 0.0	 1	 -30.0	 30.0;
	1893	 955	 0.00105	 0.005909	 0.0	 5264	 5264	 5264	 0.0	 0.0	 1	 -30.0	 30.0;
	12449	 11161	 0.001091	 0.007901	 0.0	 3961	 3961	 3961	 0.0	 0.0	 1	 -30.0	 30.0;
	12449	 1621	 0.00332	 0.024021	 0.0	 1303	 1303	 1303	 0.0	 0.0	 1	 -30.0	 30.0;
	12449	 4436	 0.00344	 0.021419	 0.0	 1457	 1457	 1457	 0.0	 0.0	 1	 -30.0	 30.0;
	12449	 459	 0.00095	 0.010419	 0.0	 3020	 3020	 3020	 0.0	 0.0	 1	 -30.0	 30.0;
	12449	 459	 0.00093	 0.01062	 0.0	 2963	 2963	 2963	 0.0	 0.0	 1	 -30.0	 30.0;
	12449	 10966	 0.00474	 0.025409	 0.0	 1223	 1223	 1223	 0.0	 0.0	 1	 -30.0	 30.0;
	617	 2957	 0.000271	 0.000841	 0.0	 35750	 35750	 35750	 0.0	 0.0	 1	 -30.0	 30.0;
	10959	 9125	 0.000271	 0.00119	 0.0	 25882	 25882	 25882	 0.0	 0.0	 1	 -30.0	 30.0;
	10959	 2230	 0.000289	 0.00076	 0.0	 38849	 38849	 38849	 0.0	 0.0	 1	 -30.0	 30.0;
	11400	 2350	 0.00031	 0.00454	 0.0	 8338	 8338	 8338	 0.0	 0.0	 1	 -30.0	 30.0;
	11888	 3448	 0.00032	 0.0044	 0.0	 8600	 8600	 8600	 0.0	 0.0	 1	 -30.0	 30.0;
	13198	 2350	 0.00028	 0.00494	 0.0	 7668	 7668	 7668	 0.0	 0.0	 1	 -30.0	 30.0;
	1373	 3448	 0.00028	 0.00508	 0.0	 7457	 7457	 7457	 0.0	 0.0	 1	 -30.0	 30.0;
	13181	 2366	 0.000531	 0.00093	 0.0	 29496	 29496	 29496	 0.0	 0.0	 1	 -30.0	 30.0;
	13181	 7203	 0.0003	 0.001031	 0.0	 29418	 29418	 29418	 0.0	 0.0	 1	 -30.0	 30.0;
	3805	 13455	 0.00139	 0.02163	 0.0	 1458	 1458	 1458	 0.0	 0.0	 1	 -30.0	 30.0;
	3805	 13130	 0.00164	 0.02321	 0.0	 1358	 1358	 1358	 0.0	 0.0	 1	 -30.0	 30.0;
	5160	 13455	 0.00136	 0.02205	 0.0	 1430	 1430	 1430	 0.0	 0.0	 1	 -30.0	 30.0;
	5160	 13130	 0.0016	 0.02367	 0.0	 1332	 1332	 1332	 0.0	 0.0	 1	 -30.0	 30.0;
	2538	 12744	 0.002091	 0.01174	 0.0	 2649	 2649	 2649	 0.0	 0.0	 1	 -30.0	 30.0;
	2538	 12744	 0.001719	 0.00961	 0.0	 3236	 3236	 3236	 0.0	 0.0	 1	 -30.0	 30.0;
	8217	 1464	 0.012341	 0.076781	 0.0	 407	 407	 407	 0.0	 0.0	 1	 -30.0	 30.0;
	8217	 12744	 0.00176	 0.009419	 0.0	 3297	 3297	 3297	 0.0	 0.0	 1	 -30.0	 30.0;
	1578	 4134	 0.00031	 0.00182	 0.0	 17110	 17110	 17110	 0.0	 0.0	 1	 -30.0	 30.0;
	10821	 3917	 0.00386	 0.02348	 0.0	 1328	 1328	 1328	 0.0	 0.0	 1	 -30.0	 30.0;
	10821	 7013	 0.00017	 0.00104	 0.0	 29975	 29975	 29975	 0.0	 0.0	 1	 -30.0	 30.0;
	5197	 1229	 0.00061	 0.00808	 0.0	 3899	 3899	 3899	 0.0	 0.0	 1	 -30.0	 30.0;
	5197	 5623	 0.00059	 0.0067	 0.0	 4697	 4697	 4697	 0.0	 0.0	 1	 -30.0	 30.0;
	3395	 1465	 0.00059	 0.00748	 0.0	 4210	 4210	 4210	 0.0	 0.0	 1	 -30.0	 30.0;
	3395	 8232	 0.00061	 0.0063	 0.0	 4991	 4991	 4991	 0.0	 0.0	 1	 -30.0	 30.0;
	544	 1679	 0.001031	 0.008789	 0.0	 3570	 3570	 3570	 0.0	 0.0	 1	 -30.0	 30.0;
	544	 5121	 0.00051	 0.006169	 0.0	 5103	 5103	 5103	 0.0	 0.0	 1	 -30.0	 30.0;
	544	 12913	 0.0005	 0.00619	 0.0	 5087	 5087	 5087	 0.0	 0.0	 1	 -30.0	 30.0;
	2615	 11522	 0.00049	 0.00376	 0.0	 8331	 8331	 8331	 0.0	 0.0	 1	 -30.0	 30.0;
	2615	 11522	 0.000539	 0.003229	 0.0	 9649	 9649	 9649	 0.0	 0.0	 1	 -30.0	 30.0;
	2615	 5824	 0.001031	 0.00882	 0.0	 3558	 3558	 3558	 0.0	 0.0	 1	 -30.0	 30.0;
	2615	 13324	 0.000711	 0.00463	 0.0	 6744	 6744	 6744	 0.0	 0.0	 1	 -30.0	 30.0;
	2615	 3181	 0.000711	 0.004539	 0.0	 6876	 6876	 6876	 0.0	 0.0	 1	 -30.0	 30.0;
	5845	 3540	 0.00206	 0.015341	 0.0	 2041	 2041	 2041	 0.0	 0.0	 1	 -30.0	 30.0;
	5845	 3540	 0.002021	 0.01564	 0.0	 2003	 2003	 2003	 0.0	 0.0	 1	 -30.0	 30.0;
	8924	 13110	 0.00094	 0.005781	 0.0	 5394	 5394	 5394	 0.0	 0.0	 1	 -30.0	 30.0;
	8924	 1420	 0.002219	 0.016969	 0.0	 1846	 1846	 1846	 0.0	 0.0	 1	 -30.0	 30.0;
	11081	 2581	 0.00238	 0.01187	 0.0	 2610	 2610	 2610	 0.0	 0.0	 1	 -30.0	 30.0;
	11081	 4134	 0.00707	 0.03095	 0.0	 995	 995	 995	 0.0	 0.0	 1	 -30.0	 30.0;
	32	 9685	 0.00256	 0.03401	 0.0	 927	 927	 927	 0.0	 0.0	 1	 -30.0	 30.0;
	32	 3556	 0.00203	 0.02416	 0.0	 1303	 1303	 1303	 0.0	 0.0	 1	 -30.0	 30.0;
	32	 6741	 0.001	 0.01459	 0.0	 2160	 2160	 2160	 0.0	 0.0	 1	 -30.0	 30.0;
	32	 6212	 0.00103	 0.00987	 0.0	 3184	 3184	 3184	 0.0	 0.0	 1	 -30.0	 30.0;
	32	 7515	 0.00038	 0.00483	 0.0	 6520	 6520	 6520	 0.0	 0.0	 1	 -30.0	 30.0;
	32	 7515	 0.00041	 0.00398	 0.0	 7895	 7895	 7895	 0.0	 0.0	 1	 -30.0	 30.0;
	11274	 3556	 0.00167	 0.01721	 0.0	 1827	 1827	 1827	 0.0	 0.0	 1	 -30.0	 30.0;
	11274	 3010	 0.00098	 0.01487	 0.0	 2120	 2120	 2120	 0.0	 0.0	 1	 -30.0	 30.0;
	11274	 13621	 0.00042	 0.00342	 0.0	 9168	 9168	 9168	 0.0	 0.0	 1	 -30.0	 30.0;
	11274	 13621	 0.00019	 0.00248	 0.0	 12700	 12700	 12700	 0.0	 0.0	 1	 -30.0	 30.0;
	11274	 6212	 0.00105	 0.00966	 0.0	 3251	 3251	 3251	 0.0	 0.0	 1	 -30.0	 30.0;
	11274	 5150	 0.00043	 0.00473	 0.0	 6651	 6651	 6651	 0.0	 0.0	 1	 -30.0	 30.0;
	11274	 5150	 0.00041	 0.00397	 0.0	 7915	 7915	 7915	 0.0	 0.0	 1	 -30.0	 30.0;
	2677	 7219	 0.00051	 0.00514	 0.0	 6116	 6116	 6116	 0.0	 0.0	 1	 -30.0	 30.0;
	167	 7219	 0.00053	 0.00503	 0.0	 6246	 6246	 6246	 0.0	 0.0	 1	 -30.0	 30.0;
	11371	 5520	 0.00455	 0.022771	 0.0	 1361	 1361	 1361	 0.0	 0.0	 1	 -30.0	 30.0;
	11371	 5520	 0.00557	 0.02055	 0.0	 1484	 1484	 1484	 0.0	 0.0	 1	 -30.0	 30.0;
	11371	 5520	 0.00339	 0.02026	 0.0	 1538	 1538	 1538	 0.0	 0.0	 1	 -30.0	 30.0;
	7251	 13274	 0.00237	 0.01068	 0.0	 2888	 2888	 2888	 0.0	 0.0	 1	 -30.0	 30.0;
	7251	 11276	 0.0037	 0.019479	 0.0	 1594	 1594	 1594	 0.0	 0.0	 1	 -30.0	 30.0;
	8935	 11583	 0.01407	 0.056849	 0.0	 540	 540	 540	 0.0	 0.0	 1	 -30.0	 30.0;
	8935	 6666	 0.001669	 0.015409	 0.0	 2039	 2039	 2039	 0.0	 0.0	 1	 -30.0	 30.0;
	8935	 6666	 0.001711	 0.015091	 0.0	 2080	 2080	 2080	 0.0	 0.0	 1	 -30.0	 30.0;
	12716	 5445	 0.00172	 0.01619	 0.0	 1941	 1941	 1941	 0.0	 0.0	 1	 -30.0	 30.0;
	12716	 11033	 0.00029	 0.00447	 0.0	 7052	 7052	 7052	 0.0	 0.0	 1	 -30.0	 30.0;
	12716	 11033	 0.00033	 0.00387	 0.0	 8133	 8133	 8133	 0.0	 0.0	 1	 -30.0	 30.0;
	12716	 6081	 0.00079	 0.01154	 0.0	 2731	 2731	 2731	 0.0	 0.0	 1	 -30.0	 30.0;
	12716	 6081	 0.00077	 0.01177	 0.0	 2678	 2678	 2678	 0.0	 0.0	 1	 -30.0	 30.0;
	12716	 6187	 0.00127	 0.01498	 0.0	 2102	 2102	 2102	 0.0	 0.0	 1	 -30.0	 30.0;
	2529	 235	 0.00214	 0.012599	 0.0	 2472	 2472	 2472	 0.0	 0.0	 1	 -30.0	 30.0;
	6234	 3473	 0.000159	 0.00125	 0.0	 25068	 25068	 25068	 0.0	 0.0	 1	 -30.0	 30.0;
	5446	 7726	 0.000211	 0.000669	 0.0	 45030	 45030	 45030	 0.0	 0.0	 1	 -30.0	 30.0;
	1087	 12264	 0.000341	 0.001169	 0.0	 25940	 25940	 25940	 0.0	 0.0	 1	 -30.0	 30.0;
	1087	 13332	 0.00024	 0.001469	 0.0	 21222	 21222	 21222	 0.0	 0.0	 1	 -30.0	 30.0;
	1087	 4469	 0.00018	 0.000669	 0.0	 45595	 45595	 45595	 0.0	 0.0	 1	 -30.0	 30.0;
	3609	 2580	 0.00033	 0.00683	 0.0	 4620	 4620	 4620	 0.0	 0.0	 1	 -30.0	 30.0;
	3609	 5981	 0.00121	 0.01211	 0.0	 2596	 2596	 2596	 0.0	 0.0	 1	 -30.0	 30.0;
	3609	 11182	 0.00123	 0.01185	 0.0	 2652	 2652	 2652	 0.0	 0.0	 1	 -30.0	 30.0;
	3609	 6212	 0.00058	 0.0097	 0.0	 3251	 3251	 3251	 0.0	 0.0	 1	 -30.0	 30.0;
	3609	 7515	 0.00103	 0.01292	 0.0	 2438	 2438	 2438	 0.0	 0.0	 1	 -30.0	 30.0;
	3609	 5150	 0.00116	 0.01266	 0.0	 2485	 2485	 2485	 0.0	 0.0	 1	 -30.0	 30.0;
	10683	 5877	 0.0013	 0.006841	 0.0	 4537	 4537	 4537	 0.0	 0.0	 1	 -30.0	 30.0;
	4349	 1507	 6e-05	 0.000349	 0.0	 89200	 89200	 89200	 0.0	 0.0	 1	 -30.0	 30.0;
	3865	 7567	 0.000169	 0.0007	 0.0	 43865	 43865	 43865	 0.0	 0.0	 1	 -30.0	 30.0;
	12696	 2876	 0.000169	 0.000719	 0.0	 42767	 42767	 42767	 0.0	 0.0	 1	 -30.0	 30.0;
	1265	 11146	 0.000271	 0.001031	 0.0	 29632	 29632	 29632	 0.0	 0.0	 1	 -30.0	 30.0;
	1798	 5367	 0.008271	 0.036841	 0.0	 837	 837	 837	 0.0	 0.0	 1	 -30.0	 30.0;
	7878	 3942	 0.002969	 0.02299	 0.0	 1363	 1363	 1363	 0.0	 0.0	 1	 -30.0	 30.0;
	9	 6777	 0.00124	 0.01273	 0.0	 2470	 2470	 2470	 0.0	 0.0	 1	 -30.0	 30.0;
	9	 11015	 0.00106	 0.00989	 0.0	 3176	 3176	 3176	 0.0	 0.0	 1	 -30.0	 30.0;
	9	 7711	 7e-05	 0.00029	 0.0	 105881	 105881	 105881	 0.0	 0.0	 1	 -30.0	 30.0;
	9	 7889	 9e-05	 0.00079	 0.0	 39728	 39728	 39728	 0.0	 0.0	 1	 -30.0	 30.0;
	9	 2936	 0.00196	 0.02049	 0.0	 1535	 1535	 1535	 0.0	 0.0	 1	 -30.0	 30.0;
	9	 6905	 0.00158	 0.01519	 0.0	 2069	 2069	 2069	 0.0	 0.0	 1	 -30.0	 30.0;
	9087	 3917	 0.00172	 0.01811	 0.0	 1737	 1737	 1737	 0.0	 0.0	 1	 -30.0	 30.0;
	9087	 10996	 0.00096	 0.01121	 0.0	 2808	 2808	 2808	 0.0	 0.0	 1	 -30.0	 30.0;
	9087	 2936	 0.00147	 0.01707	 0.0	 1844	 1844	 1844	 0.0	 0.0	 1	 -30.0	 30.0;
	11842	 6777	 0.00129	 0.0129	 0.0	 2437	 2437	 2437	 0.0	 0.0	 1	 -30.0	 30.0;
	11842	 6675	 0.00179	 0.01737	 0.0	 1809	 1809	 1809	 0.0	 0.0	 1	 -30.0	 30.0;
	11842	 2936	 0.00131	 0.01935	 0.0	 1629	 1629	 1629	 0.0	 0.0	 1	 -30.0	 30.0;
	2951	 1217	 0.003901	 0.01614	 0.0	 1903	 1903	 1903	 0.0	 0.0	 1	 -30.0	 30.0;
	2951	 1217	 0.002591	 0.014771	 0.0	 2107	 2107	 2107	 0.0	 0.0	 1	 -30.0	 30.0;
	2951	 1217	 0.00224	 0.0173	 0.0	 1811	 1811	 1811	 0.0	 0.0	 1	 -30.0	 30.0;
	2951	 11912	 0.00012	 0.000849	 0.0	 36840	 36840	 36840	 0.0	 0.0	 1	 -30.0	 30.0;
	2951	 5097	 0.00394	 0.03039	 0.0	 1031	 1031	 1031	 0.0	 0.0	 1	 -30.0	 30.0;
	2951	 5293	 0.00189	 0.01	 0.0	 3104	 3104	 3104	 0.0	 0.0	 1	 -30.0	 30.0;
	2951	 3994	 0.00032	 0.00257	 0.0	 12197	 12197	 12197	 0.0	 0.0	 1	 -30.0	 30.0;
	2951	 3994	 0.00038	 0.00224	 0.0	 13903	 13903	 13903	 0.0	 0.0	 1	 -30.0	 30.0;
	2951	 12485	 0.00751	 0.03955	 0.0	 785	 785	 785	 0.0	 0.0	 1	 -30.0	 30.0;
	2951	 1632	 0.00086	 0.006531	 0.0	 4796	 4796	 4796	 0.0	 0.0	 1	 -30.0	 30.0;
	2951	 27	 0.00087	 0.006591	 0.0	 4752	 4752	 4752	 0.0	 0.0	 1	 -30.0	 30.0;
	13110	 1420	 0.003031	 0.02276	 0.0	 1376	 1376	 1376	 0.0	 0.0	 1	 -30.0	 30.0;
	13110	 2958	 0.006331	 0.03911	 0.0	 798	 798	 798	 0.0	 0.0	 1	 -30.0	 30.0;
	13110	 6475	 0.00605	 0.02986	 0.0	 1037	 1037	 1037	 0.0	 0.0	 1	 -30.0	 30.0;
	13110	 9795	 0.003919	 0.01612	 0.0	 1905	 1905	 1905	 0.0	 0.0	 1	 -30.0	 30.0;
	13110	 7048	 0.002039	 0.0108	 0.0	 2874	 2874	 2874	 0.0	 0.0	 1	 -30.0	 30.0;
	13110	 10497	 0.006289	 0.026271	 0.0	 1170	 1170	 1170	 0.0	 0.0	 1	 -30.0	 30.0;
	4225	 4088	 0.00042	 0.00547	 0.0	 5758	 5758	 5758	 0.0	 0.0	 1	 -30.0	 30.0;
	4225	 4088	 0.00043	 0.00536	 0.0	 5875	 5875	 5875	 0.0	 0.0	 1	 -30.0	 30.0;
	4225	 227	 0.00147	 0.01373	 0.0	 2288	 2288	 2288	 0.0	 0.0	 1	 -30.0	 30.0;
	4225	 227	 0.00131	 0.01555	 0.0	 2025	 2025	 2025	 0.0	 0.0	 1	 -30.0	 30.0;
	4225	 2348	 0.00221	 0.02217	 0.0	 1418	 1418	 1418	 0.0	 0.0	 1	 -30.0	 30.0;
	4225	 1158	 0.00224	 0.0217	 0.0	 1448	 1448	 1448	 0.0	 0.0	 1	 -30.0	 30.0;
	13581	 9920	 0.00095	 0.003289	 0.0	 9227	 9227	 9227	 0.0	 0.0	 1	 -30.0	 30.0;
	13581	 4966	 0.000229	 0.00082	 0.0	 37102	 37102	 37102	 0.0	 0.0	 1	 -30.0	 30.0;
	13581	 2587	 0.00068	 0.00306	 0.0	 10077	 10077	 10077	 0.0	 0.0	 1	 -30.0	 30.0;
	13581	 5472	 0.00049	 0.00256	 0.0	 12119	 12119	 12119	 0.0	 0.0	 1	 -30.0	 30.0;
	13581	 5449	 0.000531	 0.0022	 0.0	 13958	 13958	 13958	 0.0	 0.0	 1	 -30.0	 30.0;
	13581	 10989	 0.00136	 0.00956	 0.0	 3272	 3272	 3272	 0.0	 0.0	 1	 -30.0	 30.0;
	13581	 10989	 0.0012	 0.010729	 0.0	 2926	 2926	 2926	 0.0	 0.0	 1	 -30.0	 30.0;
	13581	 10989	 0.00105	 0.00861	 0.0	 3642	 3642	 3642	 0.0	 0.0	 1	 -30.0	 30.0;
	13581	 3444	 0.000591	 0.006969	 0.0	 4517	 4517	 4517	 0.0	 0.0	 1	 -30.0	 30.0;
	4005	 12552	 0.00025	 0.0008	 0.0	 37687	 37687	 37687	 0.0	 0.0	 1	 -30.0	 30.0;
	4005	 319	 0.00113	 0.00632	 0.0	 4920	 4920	 4920	 0.0	 0.0	 1	 -30.0	 30.0;
	665	 3010	 0.0003	 0.00275	 0.0	 11419	 11419	 11419	 0.0	 0.0	 1	 -30.0	 30.0;
	7464	 1829	 0.00836	 0.051659	 0.0	 604	 604	 604	 0.0	 0.0	 1	 -30.0	 30.0;
	7464	 1829	 0.01338	 0.073469	 0.0	 423	 423	 423	 0.0	 0.0	 1	 -30.0	 30.0;
	7464	 2508	 0.0027	 0.02089	 0.0	 1500	 1500	 1500	 0.0	 0.0	 1	 -30.0	 30.0;
	7464	 6475	 0.003419	 0.02636	 0.0	 1189	 1189	 1189	 0.0	 0.0	 1	 -30.0	 30.0;
	7464	 9358	 0.009531	 0.033711	 0.0	 902	 902	 902	 0.0	 0.0	 1	 -30.0	 30.0;
	3506	 11823	 0.0004	 0.00707	 0.0	 4461	 4461	 4461	 0.0	 0.0	 1	 -30.0	 30.0;
	3768	 11823	 0.00035	 0.00701	 0.0	 4501	 4501	 4501	 0.0	 0.0	 1	 -30.0	 30.0;
	11925	 9913	 0.00194	 0.01751	 0.0	 1793	 1793	 1793	 0.0	 0.0	 1	 -30.0	 30.0;
	11925	 9913	 0.00156	 0.01936	 0.0	 1627	 1627	 1627	 0.0	 0.0	 1	 -30.0	 30.0;
	6777	 1361	 0.00078	 0.00941	 0.0	 3346	 3346	 3346	 0.0	 0.0	 1	 -30.0	 30.0;
	6777	 1361	 0.00074	 0.00969	 0.0	 3251	 3251	 3251	 0.0	 0.0	 1	 -30.0	 30.0;
	6777	 5846	 0.00042	 0.00532	 0.0	 5920	 5920	 5920	 0.0	 0.0	 1	 -30.0	 30.0;
	6777	 5846	 0.0004	 0.00473	 0.0	 6655	 6655	 6655	 0.0	 0.0	 1	 -30.0	 30.0;
	6777	 5846	 0.0006	 0.00499	 0.0	 6285	 6285	 6285	 0.0	 0.0	 1	 -30.0	 30.0;
	2296	 3455	 0.00086	 0.00638	 0.0	 4907	 4907	 4907	 0.0	 0.0	 1	 -30.0	 30.0;
	2296	 3455	 0.000969	 0.00625	 0.0	 4995	 4995	 4995	 0.0	 0.0	 1	 -30.0	 30.0;
	2296	 13302	 0.002781	 0.01725	 0.0	 1808	 1808	 1808	 0.0	 0.0	 1	 -30.0	 30.0;
	5589	 1162	 0.005031	 0.028081	 0.0	 1108	 1108	 1108	 0.0	 0.0	 1	 -30.0	 30.0;
	7975	 1356	 1e-05	 0.00021	 0.0	 150246	 150246	 150246	 0.0	 0.0	 1	 -30.0	 30.0;
	1892	 1356	 1e-05	 0.00025	 0.0	 126249	 126249	 126249	 0.0	 0.0	 1	 -30.0	 30.0;
	742	 1356	 2e-05	 0.00031	 0.0	 101684	 101684	 101684	 0.0	 0.0	 1	 -30.0	 30.0;
	4294	 1356	 3e-05	 0.0004	 0.0	 78748	 78748	 78748	 0.0	 0.0	 1	 -30.0	 30.0;
	6679	 9331	 0.000841	 0.00474	 0.0	 6562	 6562	 6562	 0.0	 0.0	 1	 -30.0	 30.0;
	6679	 9331	 0.00082	 0.00487	 0.0	 6397	 6397	 6397	 0.0	 0.0	 1	 -30.0	 30.0;
	9996	 2274	 0.00186	 0.011979	 0.0	 2606	 2606	 2606	 0.0	 0.0	 1	 -30.0	 30.0;
	12212	 7779	 0.00056	 0.003021	 0.0	 10281	 10281	 10281	 0.0	 0.0	 1	 -30.0	 30.0;
	9082	 7779	 0.00055	 0.003081	 0.0	 10093	 10093	 10093	 0.0	 0.0	 1	 -30.0	 30.0;
	13605	 13583	 0.00114	 0.01063	 0.0	 2955	 2955	 2955	 0.0	 0.0	 1	 -30.0	 30.0;
	3831	 8642	 0.003719	 0.02295	 0.0	 1359	 1359	 1359	 0.0	 0.0	 1	 -30.0	 30.0;
	3831	 10399	 0.006669	 0.04288	 0.0	 728	 728	 728	 0.0	 0.0	 1	 -30.0	 30.0;
	4216	 8428	 0.00243	 0.0198	 0.0	 1584	 1584	 1584	 0.0	 0.0	 1	 -30.0	 30.0;
	4216	 5428	 0.00845	 0.04339	 0.0	 715	 715	 715	 0.0	 0.0	 1	 -30.0	 30.0;
	3735	 12862	 0.00219	 0.015169	 0.0	 2061	 2061	 2061	 0.0	 0.0	 1	 -30.0	 30.0;
	3735	 3018	 0.00357	 0.0302	 0.0	 1039	 1039	 1039	 0.0	 0.0	 1	 -30.0	 30.0;
	7343	 11066	 0.005849	 0.032419	 0.0	 959	 959	 959	 0.0	 0.0	 1	 -30.0	 30.0;
	13077	 1621	 0.00406	 0.01688	 0.0	 1820	 1820	 1820	 0.0	 0.0	 1	 -30.0	 30.0;
	10818	 4848	 0.00113	 0.0065	 0.0	 4788	 4788	 4788	 0.0	 0.0	 1	 -30.0	 30.0;
	1786	 6497	 0.0068	 0.04613	 0.0	 678	 678	 678	 0.0	 0.0	 1	 -30.0	 30.0;
	1786	 2804	 0.00337	 0.02011	 0.0	 1550	 1550	 1550	 0.0	 0.0	 1	 -30.0	 30.0;
	11861	 10494	 0.00011	 0.0005	 0.0	 61700	 61700	 61700	 0.0	 0.0	 1	 -30.0	 30.0;
	10112	 7192	 0.003711	 0.018521	 0.0	 1673	 1673	 1673	 0.0	 0.0	 1	 -30.0	 30.0;
	10112	 1835	 0.000271	 0.00145	 0.0	 21414	 21414	 21414	 0.0	 0.0	 1	 -30.0	 30.0;
	12331	 6906	 0.00326	 0.01824	 0.0	 1705	 1705	 1705	 0.0	 0.0	 1	 -30.0	 30.0;
	13250	 10444	 0.00118	 0.00712	 0.0	 4377	 4377	 4377	 0.0	 0.0	 1	 -30.0	 30.0;
	13250	 10058	 0.00482	 0.02232	 0.0	 1384	 1384	 1384	 0.0	 0.0	 1	 -30.0	 30.0;
	10782	 10258	 0.00013	 0.000469	 0.0	 64904	 64904	 64904	 0.0	 0.0	 1	 -30.0	 30.0;
	10782	 9125	 0.000229	 0.00075	 0.0	 40281	 40281	 40281	 0.0	 0.0	 1	 -30.0	 30.0;
	11595	 2863	 0.004591	 0.035021	 0.0	 895	 895	 895	 0.0	 0.0	 1	 -30.0	 30.0;
	11595	 2050	 0.005469	 0.03924	 0.0	 798	 798	 798	 0.0	 0.0	 1	 -30.0	 30.0;
	11595	 2050	 0.00536	 0.0403	 0.0	 777	 777	 777	 0.0	 0.0	 1	 -30.0	 30.0;
	11595	 169	 0.00424	 0.033031	 0.0	 949	 949	 949	 0.0	 0.0	 1	 -30.0	 30.0;
	8137	 6311	 2e-05	 0.00024	 0.0	 131160	 131160	 131160	 0.0	 0.0	 1	 -30.0	 30.0;
	8137	 2523	 1e-05	 0.00021	 0.0	 150246	 150246	 150246	 0.0	 0.0	 1	 -30.0	 30.0;
	8137	 5445	 0.00286	 0.03653	 0.0	 863	 863	 863	 0.0	 0.0	 1	 -30.0	 30.0;
	8137	 6297	 0.00117	 0.01183	 0.0	 2658	 2658	 2658	 0.0	 0.0	 1	 -30.0	 30.0;
	8137	 5315	 0.00103	 0.01336	 0.0	 2358	 2358	 2358	 0.0	 0.0	 1	 -30.0	 30.0;
	8137	 13480	 0.00156	 0.01969	 0.0	 1600	 1600	 1600	 0.0	 0.0	 1	 -30.0	 30.0;
	8137	 9592	 0.00449	 0.05772	 0.0	 546	 546	 546	 0.0	 0.0	 1	 -30.0	 30.0;
	8137	 5299	 0.00259	 0.03469	 0.0	 909	 909	 909	 0.0	 0.0	 1	 -30.0	 30.0;
	1420	 6073	 0.000219	 0.00118	 0.0	 26320	 26320	 26320	 0.0	 0.0	 1	 -30.0	 30.0;
	1420	 2820	 6e-05	 0.00095	 0.0	 33184	 33184	 33184	 0.0	 0.0	 1	 -30.0	 30.0;
	1420	 4636	 6e-05	 0.000651	 0.0	 48317	 48317	 48317	 0.0	 0.0	 1	 -30.0	 30.0;
	1420	 5253	 8.1e-05	 0.000841	 0.0	 37387	 37387	 37387	 0.0	 0.0	 1	 -30.0	 30.0;
	1420	 6416	 0.00274	 0.020831	 0.0	 1504	 1504	 1504	 0.0	 0.0	 1	 -30.0	 30.0;
	1420	 8183	 0.004781	 0.027729	 0.0	 1123	 1123	 1123	 0.0	 0.0	 1	 -30.0	 30.0;
	1420	 8183	 0.002849	 0.02093	 0.0	 1496	 1496	 1496	 0.0	 0.0	 1	 -30.0	 30.0;
	1420	 9795	 0.00513	 0.03014	 0.0	 1034	 1034	 1034	 0.0	 0.0	 1	 -30.0	 30.0;
	1420	 10497	 0.00113	 0.00651	 0.0	 4781	 4781	 4781	 0.0	 0.0	 1	 -30.0	 30.0;
	1420	 7861	 0.00125	 0.00707	 0.0	 4400	 4400	 4400	 0.0	 0.0	 1	 -30.0	 30.0;
	10896	 7779	 0.003349	 0.01463	 0.0	 2105	 2105	 2105	 0.0	 0.0	 1	 -30.0	 30.0;
	10896	 2184	 0.00245	 0.0122	 0.0	 2539	 2539	 2539	 0.0	 0.0	 1	 -30.0	 30.0;
	1844	 1829	 0.00587	 0.036521	 0.0	 854	 854	 854	 0.0	 0.0	 1	 -30.0	 30.0;
	1844	 1829	 0.00569	 0.03774	 0.0	 828	 828	 828	 0.0	 0.0	 1	 -30.0	 30.0;
	1844	 1829	 0.006031	 0.03545	 0.0	 879	 879	 879	 0.0	 0.0	 1	 -30.0	 30.0;
	1844	 11576	 0.000531	 0.00301	 0.0	 10335	 10335	 10335	 0.0	 0.0	 1	 -30.0	 30.0;
	1844	 9412	 0.00076	 0.006099	 0.0	 5140	 5140	 5140	 0.0	 0.0	 1	 -30.0	 30.0;
	1126	 10564	 0.008841	 0.028919	 0.0	 1045	 1045	 1045	 0.0	 0.0	 1	 -30.0	 30.0;
	1126	 5757	 0.00169	 0.007091	 0.0	 4334	 4334	 4334	 0.0	 0.0	 1	 -30.0	 30.0;
	1126	 5709	 0.001031	 0.00361	 0.0	 8414	 8414	 8414	 0.0	 0.0	 1	 -30.0	 30.0;
	1126	 4437	 0.00813	 0.030961	 0.0	 987	 987	 987	 0.0	 0.0	 1	 -30.0	 30.0;
	7726	 9143	 0.00013	 0.00068	 0.0	 45626	 45626	 45626	 0.0	 0.0	 1	 -30.0	 30.0;
	5396	 5662	 0.000211	 0.000729	 0.0	 41622	 41622	 41622	 0.0	 0.0	 1	 -30.0	 30.0;
	5396	 5662	 0.000169	 0.000669	 0.0	 45778	 45778	 45778	 0.0	 0.0	 1	 -30.0	 30.0;
	5396	 4212	 0.000669	 0.00251	 0.0	 12161	 12161	 12161	 0.0	 0.0	 1	 -30.0	 30.0;
	5396	 4212	 0.000711	 0.00238	 0.0	 12717	 12717	 12717	 0.0	 0.0	 1	 -30.0	 30.0;
	5396	 1679	 0.000229	 0.00238	 0.0	 13211	 13211	 13211	 0.0	 0.0	 1	 -30.0	 30.0;
	5396	 5121	 0.0007	 0.0065	 0.0	 4832	 4832	 4832	 0.0	 0.0	 1	 -30.0	 30.0;
	5396	 12913	 0.00061	 0.006031	 0.0	 5211	 5211	 5211	 0.0	 0.0	 1	 -30.0	 30.0;
	9470	 7807	 0.000281	 0.0018	 0.0	 17339	 17339	 17339	 0.0	 0.0	 1	 -30.0	 30.0;
	9470	 5824	 0.000211	 0.002409	 0.0	 13063	 13063	 13063	 0.0	 0.0	 1	 -30.0	 30.0;
	1707	 1905	 0.00056	 0.00773	 0.0	 4076	 4076	 4076	 0.0	 0.0	 1	 -30.0	 30.0;
	1707	 36	 0.0023	 0.01581	 0.0	 1978	 1978	 1978	 0.0	 0.0	 1	 -30.0	 30.0;
	10943	 5367	 0.005039	 0.032151	 0.0	 971	 971	 971	 0.0	 0.0	 1	 -30.0	 30.0;
	10943	 140	 0.00364	 0.01713	 0.0	 1804	 1804	 1804	 0.0	 0.0	 1	 -30.0	 30.0;
	10943	 2663	 0.002169	 0.012409	 0.0	 2508	 2508	 2508	 0.0	 0.0	 1	 -30.0	 30.0;
	518	 4608	 0.00113	 0.004719	 0.0	 6510	 6510	 6510	 0.0	 0.0	 1	 -30.0	 30.0;
	518	 9611	 0.00113	 0.004979	 0.0	 6187	 6187	 6187	 0.0	 0.0	 1	 -30.0	 30.0;
	4608	 6928	 0.00264	 0.01174	 0.0	 2626	 2626	 2626	 0.0	 0.0	 1	 -30.0	 30.0;
	3803	 11583	 0.00494	 0.03181	 0.0	 982	 982	 982	 0.0	 0.0	 1	 -30.0	 30.0;
	3803	 3018	 0.003711	 0.023961	 0.0	 1303	 1303	 1303	 0.0	 0.0	 1	 -30.0	 30.0;
	6084	 13033	 0.001409	 0.01101	 0.0	 2846	 2846	 2846	 0.0	 0.0	 1	 -30.0	 30.0;
	6084	 2316	 0.001169	 0.00593	 0.0	 5227	 5227	 5227	 0.0	 0.0	 1	 -30.0	 30.0;
	6084	 2316	 0.00118	 0.00587	 0.0	 5276	 5276	 5276	 0.0	 0.0	 1	 -30.0	 30.0;
	6084	 5559	 0.00264	 0.012469	 0.0	 2479	 2479	 2479	 0.0	 0.0	 1	 -30.0	 30.0;
	6084	 5559	 0.002349	 0.01414	 0.0	 2204	 2204	 2204	 0.0	 0.0	 1	 -30.0	 30.0;
	5375	 6031	 0.00014	 0.0007	 0.0	 44249	 44249	 44249	 0.0	 0.0	 1	 -30.0	 30.0;
	9685	 7792	 3e-05	 0.00054	 0.0	 58406	 58406	 58406	 0.0	 0.0	 1	 -30.0	 30.0;
	9685	 10491	 3e-05	 0.00055	 0.0	 57347	 57347	 57347	 0.0	 0.0	 1	 -30.0	 30.0;
	9685	 5404	 4e-05	 0.00058	 0.0	 54332	 54332	 54332	 0.0	 0.0	 1	 -30.0	 30.0;
	9685	 7983	 4e-05	 0.00054	 0.0	 58336	 58336	 58336	 0.0	 0.0	 1	 -30.0	 30.0;
	9685	 6212	 0.00171	 0.02197	 0.0	 1434	 1434	 1434	 0.0	 0.0	 1	 -30.0	 30.0;
	9685	 6212	 0.00164	 0.02064	 0.0	 1526	 1526	 1526	 0.0	 0.0	 1	 -30.0	 30.0;
	9685	 6599	 0.00136	 0.01756	 0.0	 1794	 1794	 1794	 0.0	 0.0	 1	 -30.0	 30.0;
	9685	 634	 0.00097	 0.00942	 0.0	 3336	 3336	 3336	 0.0	 0.0	 1	 -30.0	 30.0;
	9685	 634	 0.00086	 0.01109	 0.0	 2840	 2840	 2840	 0.0	 0.0	 1	 -30.0	 30.0;
	9685	 634	 0.00085	 0.0113	 0.0	 2788	 2788	 2788	 0.0	 0.0	 1	 -30.0	 30.0;
	2212	 10056	 0.000979	 0.0058	 0.0	 5371	 5371	 5371	 0.0	 0.0	 1	 -30.0	 30.0;
	3556	 4999	 0.00052	 0.00593	 0.0	 5307	 5307	 5307	 0.0	 0.0	 1	 -30.0	 30.0;
	3556	 4999	 0.00046	 0.00672	 0.0	 4690	 4690	 4690	 0.0	 0.0	 1	 -30.0	 30.0;
	7192	 4790	 0.001151	 0.00636	 0.0	 4888	 4888	 4888	 0.0	 0.0	 1	 -30.0	 30.0;
	7192	 4790	 0.001031	 0.007211	 0.0	 4337	 4337	 4337	 0.0	 0.0	 1	 -30.0	 30.0;
	7192	 6906	 0.002341	 0.02286	 0.0	 1375	 1375	 1375	 0.0	 0.0	 1	 -30.0	 30.0;
	7192	 1835	 0.002281	 0.02518	 0.0	 1250	 1250	 1250	 0.0	 0.0	 1	 -30.0	 30.0;
	7192	 5757	 0.005479	 0.02114	 0.0	 1447	 1447	 1447	 0.0	 0.0	 1	 -30.0	 30.0;
	7192	 4299	 0.011159	 0.08856	 0.0	 354	 354	 354	 0.0	 0.0	 1	 -30.0	 30.0;
	7192	 8517	 0.000669	 0.00249	 0.0	 12252	 12252	 12252	 0.0	 0.0	 1	 -30.0	 30.0;
	7192	 11609	 0.00193	 0.01643	 0.0	 1910	 1910	 1910	 0.0	 0.0	 1	 -30.0	 30.0;
	7192	 4437	 0.00024	 0.0017	 0.0	 18399	 18399	 18399	 0.0	 0.0	 1	 -30.0	 30.0;
	3788	 281	 0.010159	 0.065849	 0.0	 475	 475	 475	 0.0	 0.0	 1	 -30.0	 30.0;
	710	 10802	 0.00294	 0.02131	 0.0	 1469	 1469	 1469	 0.0	 0.0	 1	 -30.0	 30.0;
	710	 12871	 0.018841	 0.07469	 0.0	 411	 411	 411	 0.0	 0.0	 1	 -30.0	 30.0;
	710	 9296	 0.015599	 0.052169	 0.0	 581	 581	 581	 0.0	 0.0	 1	 -30.0	 30.0;
	11583	 4519	 0.005831	 0.03969	 0.0	 788	 788	 788	 0.0	 0.0	 1	 -30.0	 30.0;
	11583	 3527	 0.00087	 0.00661	 0.0	 4738	 4738	 4738	 0.0	 0.0	 1	 -30.0	 30.0;
	11583	 8095	 0.00637	 0.024659	 0.0	 1241	 1241	 1241	 0.0	 0.0	 1	 -30.0	 30.0;
	9391	 4435	 0.0027	 0.020419	 0.0	 1534	 1534	 1534	 0.0	 0.0	 1	 -30.0	 30.0;
	9391	 5691	 0.000409	 0.00314	 0.0	 9976	 9976	 9976	 0.0	 0.0	 1	 -30.0	 30.0;
	9391	 13022	 0.001669	 0.01301	 0.0	 2409	 2409	 2409	 0.0	 0.0	 1	 -30.0	 30.0;
	9391	 13022	 0.00164	 0.01325	 0.0	 2366	 2366	 2366	 0.0	 0.0	 1	 -30.0	 30.0;
	1185	 6675	 0.00089	 0.00556	 0.0	 5610	 5610	 5610	 0.0	 0.0	 1	 -30.0	 30.0;
	1185	 6061	 0.00186	 0.01809	 0.0	 1737	 1737	 1737	 0.0	 0.0	 1	 -30.0	 30.0;
	1185	 4880	 0.00381	 0.02853	 0.0	 1098	 1098	 1098	 0.0	 0.0	 1	 -30.0	 30.0;
	8038	 3401	 0.012419	 0.072151	 0.0	 432	 432	 432	 0.0	 0.0	 1	 -30.0	 30.0;
	8038	 1984	 0.0042	 0.02556	 0.0	 1220	 1220	 1220	 0.0	 0.0	 1	 -30.0	 30.0;
	8038	 4090	 0.010771	 0.0493	 0.0	 626	 626	 626	 0.0	 0.0	 1	 -30.0	 30.0;
	8038	 2729	 0.010159	 0.04995	 0.0	 620	 620	 620	 0.0	 0.0	 1	 -30.0	 30.0;
	8038	 12978	 0.013169	 0.05113	 0.0	 599	 599	 599	 0.0	 0.0	 1	 -30.0	 30.0;
	12552	 10790	 0.000469	 0.001159	 0.0	 25264	 25264	 25264	 0.0	 0.0	 1	 -30.0	 30.0;
	12552	 9030	 0.000229	 0.00105	 0.0	 29393	 29393	 29393	 0.0	 0.0	 1	 -30.0	 30.0;
	4966	 1385	 0.000271	 0.001271	 0.0	 24306	 24306	 24306	 0.0	 0.0	 1	 -30.0	 30.0;
	2975	 6741	 0.00099	 0.01194	 0.0	 2637	 2637	 2637	 0.0	 0.0	 1	 -30.0	 30.0;
	2975	 6661	 0.00077	 0.01184	 0.0	 2663	 2663	 2663	 0.0	 0.0	 1	 -30.0	 30.0;
	2975	 7515	 0.00034	 0.00426	 0.0	 7392	 7392	 7392	 0.0	 0.0	 1	 -30.0	 30.0;
	7389	 3010	 0.00101	 0.01168	 0.0	 2695	 2695	 2695	 0.0	 0.0	 1	 -30.0	 30.0;
	7389	 6661	 0.00086	 0.01046	 0.0	 3010	 3010	 3010	 0.0	 0.0	 1	 -30.0	 30.0;
	7389	 5150	 0.00035	 0.00417	 0.0	 7549	 7549	 7549	 0.0	 0.0	 1	 -30.0	 30.0;
	3790	 2115	 0.000159	 0.00069	 0.0	 44610	 44610	 44610	 0.0	 0.0	 1	 -30.0	 30.0;
	11917	 8496	 0.000781	 0.00488	 0.0	 6392	 6392	 6392	 0.0	 0.0	 1	 -30.0	 30.0;
	11917	 6101	 0.000781	 0.00511	 0.0	 6111	 6111	 6111	 0.0	 0.0	 1	 -30.0	 30.0;
	11917	 4521	 0.00064	 0.003539	 0.0	 8784	 8784	 8784	 0.0	 0.0	 1	 -30.0	 30.0;
	11917	 4521	 0.00057	 0.003781	 0.0	 8261	 8261	 8261	 0.0	 0.0	 1	 -30.0	 30.0;
	11917	 4352	 0.000531	 0.00111	 0.0	 25671	 25671	 25671	 0.0	 0.0	 1	 -30.0	 30.0;
	11917	 10961	 0.000521	 0.00113	 0.0	 25386	 25386	 25386	 0.0	 0.0	 1	 -30.0	 30.0;
	11917	 8724	 0.00176	 0.00843	 0.0	 3668	 3668	 3668	 0.0	 0.0	 1	 -30.0	 30.0;
	11917	 13022	 0.002461	 0.01975	 0.0	 1588	 1588	 1588	 0.0	 0.0	 1	 -30.0	 30.0;
	2441	 9437	 0.000591	 0.00105	 0.0	 26216	 26216	 26216	 0.0	 0.0	 1	 -30.0	 30.0;
	2903	 2016	 0.00012	 0.00064	 0.0	 48510	 48510	 48510	 0.0	 0.0	 1	 -30.0	 30.0;
	3086	 2581	 0.000581	 0.004419	 0.0	 7088	 7088	 7088	 0.0	 0.0	 1	 -30.0	 30.0;
	9315	 2581	 0.000651	 0.004331	 0.0	 7213	 7213	 7213	 0.0	 0.0	 1	 -30.0	 30.0;
	6911	 4108	 0.001289	 0.008289	 0.0	 3766	 3766	 3766	 0.0	 0.0	 1	 -30.0	 30.0;
	7274	 13490	 0.00233	 0.03502	 0.0	 900	 900	 900	 0.0	 0.0	 1	 -30.0	 30.0;
	7274	 13490	 0.00238	 0.03781	 0.0	 834	 834	 834	 0.0	 0.0	 1	 -30.0	 30.0;
	7274	 2937	 0.00052	 0.00605	 0.0	 5202	 5202	 5202	 0.0	 0.0	 1	 -30.0	 30.0;
	7274	 7948	 0.00023	 0.00275	 0.0	 11447	 11447	 11447	 0.0	 0.0	 1	 -30.0	 30.0;
	7274	 11927	 0.00134	 0.01343	 0.0	 2341	 2341	 2341	 0.0	 0.0	 1	 -30.0	 30.0;
	7274	 11927	 0.00116	 0.01552	 0.0	 2030	 2030	 2030	 0.0	 0.0	 1	 -30.0	 30.0;
	11696	 1027	 0.004169	 0.027919	 0.0	 1119	 1119	 1119	 0.0	 0.0	 1	 -30.0	 30.0;
	11696	 1162	 0.00063	 0.008	 0.0	 3937	 3937	 3937	 0.0	 0.0	 1	 -30.0	 30.0;
	11696	 2660	 0.004841	 0.028581	 0.0	 1090	 1090	 1090	 0.0	 0.0	 1	 -30.0	 30.0;
	11696	 7985	 0.007419	 0.05787	 0.0	 542	 542	 542	 0.0	 0.0	 1	 -30.0	 30.0;
	6265	 3540	 0.002719	 0.020331	 0.0	 1540	 1540	 1540	 0.0	 0.0	 1	 -30.0	 30.0;
	3320	 9003	 0.000789	 0.005	 0.0	 6241	 6241	 6241	 0.0	 0.0	 1	 -30.0	 30.0;
	13572	 281	 0.00238	 0.013219	 0.0	 2352	 2352	 2352	 0.0	 0.0	 1	 -30.0	 30.0;
	13572	 4528	 0.003771	 0.02701	 0.0	 1159	 1159	 1159	 0.0	 0.0	 1	 -30.0	 30.0;
	6860	 6666	 0.001271	 0.00939	 0.0	 3334	 3334	 3334	 0.0	 0.0	 1	 -30.0	 30.0;
	13308	 9842	 0.000841	 0.00131	 0.0	 20291	 20291	 20291	 0.0	 0.0	 1	 -30.0	 30.0;
	12435	 5520	 0.005711	 0.043039	 0.0	 728	 728	 728	 0.0	 0.0	 1	 -30.0	 30.0;
	12435	 5520	 0.00562	 0.041901	 0.0	 748	 748	 748	 0.0	 0.0	 1	 -30.0	 30.0;
	12561	 4228	 0.00356	 0.019781	 0.0	 1572	 1572	 1572	 0.0	 0.0	 1	 -30.0	 30.0;
	12561	 235	 0.004841	 0.03149	 0.0	 992	 992	 992	 0.0	 0.0	 1	 -30.0	 30.0;
	1082	 12547	 0.00057	 0.00107	 0.0	 26055	 26055	 26055	 0.0	 0.0	 1	 -30.0	 30.0;
	10090	 7203	 0.000539	 0.00213	 0.0	 14377	 14377	 14377	 0.0	 0.0	 1	 -30.0	 30.0;
	655	 6955	 0.0007	 0.00425	 0.0	 7334	 7334	 7334	 0.0	 0.0	 1	 -30.0	 30.0;
	2065	 8040	 0.0012	 0.009531	 0.0	 3289	 3289	 3289	 0.0	 0.0	 1	 -30.0	 30.0;
	2065	 3942	 0.00206	 0.015901	 0.0	 1971	 1971	 1971	 0.0	 0.0	 1	 -30.0	 30.0;
	5291	 6928	 0.00063	 0.00312	 0.0	 9924	 9924	 9924	 0.0	 0.0	 1	 -30.0	 30.0;
	1768	 2936	 3e-05	 0.00041	 0.0	 76837	 76837	 76837	 0.0	 0.0	 1	 -30.0	 30.0;
	1574	 2936	 2e-05	 0.00043	 0.0	 73380	 73380	 73380	 0.0	 0.0	 1	 -30.0	 30.0;
	12142	 2936	 3e-05	 0.00039	 0.0	 80755	 80755	 80755	 0.0	 0.0	 1	 -30.0	 30.0;
	12250	 2936	 3e-05	 0.00038	 0.0	 82867	 82867	 82867	 0.0	 0.0	 1	 -30.0	 30.0;
	2008	 5132	 0.0008	 0.004151	 0.0	 7473	 7473	 7473	 0.0	 0.0	 1	 -30.0	 30.0;
	6674	 5132	 0.000901	 0.00381	 0.0	 8069	 8069	 8069	 0.0	 0.0	 1	 -30.0	 30.0;
	4438	 934	 0.000591	 0.004341	 0.0	 7210	 7210	 7210	 0.0	 0.0	 1	 -30.0	 30.0;
	4438	 934	 0.000591	 0.00405	 0.0	 7718	 7718	 7718	 0.0	 0.0	 1	 -30.0	 30.0;
	7324	 6661	 0.00218	 0.0275	 0.0	 1146	 1146	 1146	 0.0	 0.0	 1	 -30.0	 30.0;
	7324	 4416	 0.00184	 0.01677	 0.0	 1873	 1873	 1873	 0.0	 0.0	 1	 -30.0	 30.0;
	1100	 1361	 0.00058	 0.00807	 0.0	 3905	 3905	 3905	 0.0	 0.0	 1	 -30.0	 30.0;
	1100	 1361	 0.00056	 0.00823	 0.0	 3830	 3830	 3830	 0.0	 0.0	 1	 -30.0	 30.0;
	1100	 7219	 0.00123	 0.01146	 0.0	 2741	 2741	 2741	 0.0	 0.0	 1	 -30.0	 30.0;
	1100	 7219	 0.0011	 0.01298	 0.0	 2425	 2425	 2425	 0.0	 0.0	 1	 -30.0	 30.0;
	1100	 5846	 0.00156	 0.01585	 0.0	 1984	 1984	 1984	 0.0	 0.0	 1	 -30.0	 30.0;
	1100	 4194	 0.00226	 0.02781	 0.0	 1133	 1133	 1133	 0.0	 0.0	 1	 -30.0	 30.0;
	5520	 267	 0.00614	 0.02831	 0.0	 1091	 1091	 1091	 0.0	 0.0	 1	 -30.0	 30.0;
	5520	 3199	 0.00513	 0.03401	 0.0	 919	 919	 919	 0.0	 0.0	 1	 -30.0	 30.0;
	9969	 6047	 0.013219	 0.0597	 0.0	 517	 517	 517	 0.0	 0.0	 1	 -30.0	 30.0;
	8345	 10214	 0.012969	 0.06087	 0.0	 508	 508	 508	 0.0	 0.0	 1	 -30.0	 30.0;
	12745	 10970	 0.00437	 0.032831	 0.0	 954	 954	 954	 0.0	 0.0	 1	 -30.0	 30.0;
	12745	 3540	 0.005651	 0.033229	 0.0	 938	 938	 938	 0.0	 0.0	 1	 -30.0	 30.0;
	5600	 7985	 0.008969	 0.03625	 0.0	 846	 846	 846	 0.0	 0.0	 1	 -30.0	 30.0;
	5600	 11395	 0.012409	 0.05645	 0.0	 547	 547	 547	 0.0	 0.0	 1	 -30.0	 30.0;
	7320	 9331	 0.00038	 0.002271	 0.0	 13719	 13719	 13719	 0.0	 0.0	 1	 -30.0	 30.0;
	7576	 6011	 0.00138	 0.01089	 0.0	 2878	 2878	 2878	 0.0	 0.0	 1	 -30.0	 30.0;
	7576	 6011	 0.001539	 0.012521	 0.0	 2504	 2504	 2504	 0.0	 0.0	 1	 -30.0	 30.0;
	7576	 11295	 0.00205	 0.014229	 0.0	 2198	 2198	 2198	 0.0	 0.0	 1	 -30.0	 30.0;
	7576	 10636	 0.00026	 0.00164	 0.0	 19023	 19023	 19023	 0.0	 0.0	 1	 -30.0	 30.0;
	7576	 3550	 0.000289	 0.00169	 0.0	 18424	 18424	 18424	 0.0	 0.0	 1	 -30.0	 30.0;
	7779	 11074	 0.003349	 0.051211	 0.0	 616	 616	 616	 0.0	 0.0	 1	 -30.0	 30.0;
	8208	 6738	 0.00038	 0.001479	 0.0	 20686	 20686	 20686	 0.0	 0.0	 1	 -30.0	 30.0;
	2271	 8175	 0.00082	 0.00625	 0.0	 5012	 5012	 5012	 0.0	 0.0	 1	 -30.0	 30.0;
	4610	 4974	 0.00275	 0.015581	 0.0	 1997	 1997	 1997	 0.0	 0.0	 1	 -30.0	 30.0;
	8802	 8629	 0.000909	 0.00739	 0.0	 4243	 4243	 4243	 0.0	 0.0	 1	 -30.0	 30.0;
	5445	 12511	 0.00082	 0.01038	 0.0	 3034	 3034	 3034	 0.0	 0.0	 1	 -30.0	 30.0;
	5445	 11017	 0.00093	 0.01017	 0.0	 3094	 3094	 3094	 0.0	 0.0	 1	 -30.0	 30.0;
	5445	 13480	 0.00137	 0.01431	 0.0	 2198	 2198	 2198	 0.0	 0.0	 1	 -30.0	 30.0;
	5445	 2218	 0.00215	 0.02021	 0.0	 1555	 1555	 1555	 0.0	 0.0	 1	 -30.0	 30.0;
	1829	 6290	 0.01189	 0.058841	 0.0	 527	 527	 527	 0.0	 0.0	 1	 -30.0	 30.0;
	9843	 3627	 0.00104	 0.01241	 0.0	 2537	 2537	 2537	 0.0	 0.0	 1	 -30.0	 30.0;
	9843	 3627	 0.00092	 0.014	 0.0	 2252	 2252	 2252	 0.0	 0.0	 1	 -30.0	 30.0;
	9843	 3383	 0.00055	 0.00845	 0.0	 3731	 3731	 3731	 0.0	 0.0	 1	 -30.0	 30.0;
	9843	 3383	 0.00054	 0.00861	 0.0	 3662	 3662	 3662	 0.0	 0.0	 1	 -30.0	 30.0;
	9843	 6297	 0.00105	 0.01057	 0.0	 2974	 2974	 2974	 0.0	 0.0	 1	 -30.0	 30.0;
	9843	 5315	 0.00089	 0.01122	 0.0	 2807	 2807	 2807	 0.0	 0.0	 1	 -30.0	 30.0;
	9843	 10081	 0.00223	 0.02584	 0.0	 1218	 1218	 1218	 0.0	 0.0	 1	 -30.0	 30.0;
	13380	 7458	 0.00101	 0.007841	 0.0	 3996	 3996	 3996	 0.0	 0.0	 1	 -30.0	 30.0;
	13380	 7458	 0.001081	 0.008099	 0.0	 3866	 3866	 3866	 0.0	 0.0	 1	 -30.0	 30.0;
	705	 10497	 0.011081	 0.068479	 0.0	 456	 456	 456	 0.0	 0.0	 1	 -30.0	 30.0;
	13490	 2424	 2e-05	 0.00033	 0.0	 95544	 95544	 95544	 0.0	 0.0	 1	 -30.0	 30.0;
	13490	 13136	 1e-05	 0.00029	 0.0	 108858	 108858	 108858	 0.0	 0.0	 1	 -30.0	 30.0;
	13490	 12835	 0.00071	 0.00892	 0.0	 3531	 3531	 3531	 0.0	 0.0	 1	 -30.0	 30.0;
	13490	 13130	 0.00136	 0.01526	 0.0	 2062	 2062	 2062	 0.0	 0.0	 1	 -30.0	 30.0;
	8642	 11395	 0.005401	 0.036021	 0.0	 868	 868	 868	 0.0	 0.0	 1	 -30.0	 30.0;
	4529	 2946	 0.00437	 0.033719	 0.0	 930	 930	 930	 0.0	 0.0	 1	 -30.0	 30.0;
	4529	 1507	 0.005151	 0.034919	 0.0	 895	 895	 895	 0.0	 0.0	 1	 -30.0	 30.0;
	426	 7134	 0.00038	 0.00139	 0.0	 21921	 21921	 21921	 0.0	 0.0	 1	 -30.0	 30.0;
	426	 1548	 0.00037	 0.0015	 0.0	 20446	 20446	 20446	 0.0	 0.0	 1	 -30.0	 30.0;
	426	 6955	 0.00069	 0.004461	 0.0	 6998	 6998	 6998	 0.0	 0.0	 1	 -30.0	 30.0;
	2863	 7605	 0.00688	 0.040591	 0.0	 768	 768	 768	 0.0	 0.0	 1	 -30.0	 30.0;
	2863	 169	 0.001341	 0.008349	 0.0	 3736	 3736	 3736	 0.0	 0.0	 1	 -30.0	 30.0;
	2863	 169	 0.001229	 0.009669	 0.0	 3241	 3241	 3241	 0.0	 0.0	 1	 -30.0	 30.0;
	3194	 8360	 0.00137	 0.006039	 0.0	 5101	 5101	 5101	 0.0	 0.0	 1	 -30.0	 30.0;
	11029	 9593	 0.001919	 0.01261	 0.0	 2477	 2477	 2477	 0.0	 0.0	 1	 -30.0	 30.0;
	11029	 1228	 0.00163	 0.0095	 0.0	 3278	 3278	 3278	 0.0	 0.0	 1	 -30.0	 30.0;
	13162	 13033	 0.00488	 0.0497	 0.0	 633	 633	 633	 0.0	 0.0	 1	 -30.0	 30.0;
	13162	 6605	 0.001289	 0.0087	 0.0	 3592	 3592	 3592	 0.0	 0.0	 1	 -30.0	 30.0;
	13162	 5011	 0.00211	 0.01524	 0.0	 2054	 2054	 2054	 0.0	 0.0	 1	 -30.0	 30.0;
	13162	 5011	 0.00206	 0.015539	 0.0	 2016	 2016	 2016	 0.0	 0.0	 1	 -30.0	 30.0;
	13162	 5011	 0.00276	 0.01631	 0.0	 1910	 1910	 1910	 0.0	 0.0	 1	 -30.0	 30.0;
	13162	 9593	 0.00305	 0.019521	 0.0	 1599	 1599	 1599	 0.0	 0.0	 1	 -30.0	 30.0;
	13162	 3560	 0.000409	 0.0023	 0.0	 13522	 13522	 13522	 0.0	 0.0	 1	 -30.0	 30.0;
	13162	 9677	 0.00036	 0.00268	 0.0	 11682	 11682	 11682	 0.0	 0.0	 1	 -30.0	 30.0;
	8182	 9274	 0.00032	 0.00049	 0.0	 53974	 53974	 53974	 0.0	 0.0	 1	 -30.0	 30.0;
	1549	 9274	 0.00013	 0.000349	 0.0	 84816	 84816	 84816	 0.0	 0.0	 1	 -30.0	 30.0;
	2580	 6212	 0.0002	 0.00327	 0.0	 9642	 9642	 9642	 0.0	 0.0	 1	 -30.0	 30.0;
	1153	 3034	 0.000919	 0.00561	 0.0	 5557	 5557	 5557	 0.0	 0.0	 1	 -30.0	 30.0;
	1153	 3034	 0.00094	 0.00549	 0.0	 5672	 5672	 5672	 0.0	 0.0	 1	 -30.0	 30.0;
	1153	 11003	 0.00175	 0.01976	 0.0	 1593	 1593	 1593	 0.0	 0.0	 1	 -30.0	 30.0;
	1153	 9849	 0.001729	 0.019331	 0.0	 1628	 1628	 1628	 0.0	 0.0	 1	 -30.0	 30.0;
	3262	 9938	 0.00406	 0.02581	 0.0	 1209	 1209	 1209	 0.0	 0.0	 1	 -30.0	 30.0;
	3262	 1113	 0.00526	 0.025961	 0.0	 1193	 1193	 1193	 0.0	 0.0	 1	 -30.0	 30.0;
	4714	 1554	 0.00179	 0.02098	 0.0	 1501	 1501	 1501	 0.0	 0.0	 1	 -30.0	 30.0;
	4714	 8710	 0.00162	 0.02148	 0.0	 1467	 1467	 1467	 0.0	 0.0	 1	 -30.0	 30.0;
	4714	 13408	 0.00492	 0.04991	 0.0	 630	 630	 630	 0.0	 0.0	 1	 -30.0	 30.0;
	4714	 1356	 0.00109	 0.01361	 0.0	 2314	 2314	 2314	 0.0	 0.0	 1	 -30.0	 30.0;
	4714	 1356	 0.00097	 0.0153	 0.0	 2061	 2061	 2061	 0.0	 0.0	 1	 -30.0	 30.0;
	4714	 7219	 0.00322	 0.03022	 0.0	 1040	 1040	 1040	 0.0	 0.0	 1	 -30.0	 30.0;
	2203	 10795	 0.032831	 0.074151	 0.0	 390	 390	 390	 0.0	 0.0	 1	 -30.0	 30.0;
	2203	 10008	 0.01411	 0.058711	 0.0	 524	 524	 524	 0.0	 0.0	 1	 -30.0	 30.0;
	2203	 12559	 0.02725	 0.102979	 0.0	 297	 297	 297	 0.0	 0.0	 1	 -30.0	 30.0;
	2203	 4581	 0.012229	 0.04049	 0.0	 747	 747	 747	 0.0	 0.0	 1	 -30.0	 30.0;
	2203	 3832	 0.01994	 0.066719	 0.0	 454	 454	 454	 0.0	 0.0	 1	 -30.0	 30.0;
	2203	 6290	 0.018591	 0.07462	 0.0	 411	 411	 411	 0.0	 0.0	 1	 -30.0	 30.0;
	2203	 6646	 0.008979	 0.03251	 0.0	 937	 937	 937	 0.0	 0.0	 1	 -30.0	 30.0;
	2203	 6217	 0.016531	 0.086031	 0.0	 361	 361	 361	 0.0	 0.0	 1	 -30.0	 30.0;
	12750	 55	 0.003591	 0.02137	 0.0	 1458	 1458	 1458	 0.0	 0.0	 1	 -30.0	 30.0;
	12750	 4110	 0.00124	 0.008	 0.0	 3902	 3902	 3902	 0.0	 0.0	 1	 -30.0	 30.0;
	12750	 4110	 0.001271	 0.007831	 0.0	 3982	 3982	 3982	 0.0	 0.0	 1	 -30.0	 30.0;
	12750	 301	 0.000469	 0.00294	 0.0	 10610	 10610	 10610	 0.0	 0.0	 1	 -30.0	 30.0;
	12750	 6189	 0.000841	 0.003289	 0.0	 9305	 9305	 9305	 0.0	 0.0	 1	 -30.0	 30.0;
	3406	 2740	 0.00219	 0.016539	 0.0	 1894	 1894	 1894	 0.0	 0.0	 1	 -30.0	 30.0;
	3406	 8030	 0.002901	 0.020901	 0.0	 1497	 1497	 1497	 0.0	 0.0	 1	 -30.0	 30.0;
	11190	 333	 0.0002	 0.001211	 0.0	 25736	 25736	 25736	 0.0	 0.0	 1	 -30.0	 30.0;
	2111	 1980	 9.1e-05	 0.000479	 0.0	 64786	 64786	 64786	 0.0	 0.0	 1	 -30.0	 30.0;
	10260	 10411	 0.005461	 0.029469	 0.0	 1054	 1054	 1054	 0.0	 0.0	 1	 -30.0	 30.0;
	10260	 4848	 0.001979	 0.011289	 0.0	 2757	 2757	 2757	 0.0	 0.0	 1	 -30.0	 30.0;
	1765	 235	 0.0023	 0.01289	 0.0	 2413	 2413	 2413	 0.0	 0.0	 1	 -30.0	 30.0;
	8957	 3522	 0.000159	 0.00037	 0.0	 78436	 78436	 78436	 0.0	 0.0	 1	 -30.0	 30.0;
	13033	 5559	 0.002789	 0.01562	 0.0	 1991	 1991	 1991	 0.0	 0.0	 1	 -30.0	 30.0;
	8586	 8106	 0.002531	 0.012331	 0.0	 2510	 2510	 2510	 0.0	 0.0	 1	 -30.0	 30.0;
	8586	 11222	 0.00357	 0.023289	 0.0	 1341	 1341	 1341	 0.0	 0.0	 1	 -30.0	 30.0;
	8586	 2392	 0.00076	 0.006039	 0.0	 5190	 5190	 5190	 0.0	 0.0	 1	 -30.0	 30.0;
	5875	 2184	 0.000469	 0.00075	 0.0	 35710	 35710	 35710	 0.0	 0.0	 1	 -30.0	 30.0;
	262	 2184	 0.00044	 0.00069	 0.0	 38599	 38599	 38599	 0.0	 0.0	 1	 -30.0	 30.0;
	4279	 5028	 0.00561	 0.035521	 0.0	 879	 879	 879	 0.0	 0.0	 1	 -30.0	 30.0;
	12839	 1314	 0.004539	 0.03468	 0.0	 904	 904	 904	 0.0	 0.0	 1	 -30.0	 30.0;
	12839	 1314	 0.00175	 0.0067	 0.0	 4562	 4562	 4562	 0.0	 0.0	 1	 -30.0	 30.0;
	12839	 4994	 0.007461	 0.031419	 0.0	 979	 979	 979	 0.0	 0.0	 1	 -30.0	 30.0;
	4790	 4916	 0.00224	 0.012909	 0.0	 2411	 2411	 2411	 0.0	 0.0	 1	 -30.0	 30.0;
	7709	 26	 0.0003	 0.000961	 0.0	 31376	 31376	 31376	 0.0	 0.0	 1	 -30.0	 30.0;
	7709	 26	 0.00032	 0.001409	 0.0	 21862	 21862	 21862	 0.0	 0.0	 1	 -30.0	 30.0;
	7709	 2217	 0.002031	 0.0157	 0.0	 1996	 1996	 1996	 0.0	 0.0	 1	 -30.0	 30.0;
	7709	 9004	 0.00038	 0.00306	 0.0	 10244	 10244	 10244	 0.0	 0.0	 1	 -30.0	 30.0;
	7709	 7132	 0.00118	 0.0083	 0.0	 3768	 3768	 3768	 0.0	 0.0	 1	 -30.0	 30.0;
	7709	 7942	 0.001229	 0.00787	 0.0	 3966	 3966	 3966	 0.0	 0.0	 1	 -30.0	 30.0;
	8106	 8251	 0.00301	 0.01538	 0.0	 2016	 2016	 2016	 0.0	 0.0	 1	 -30.0	 30.0;
	5032	 7942	 0.00063	 0.00114	 0.0	 24252	 24252	 24252	 0.0	 0.0	 1	 -30.0	 30.0;
	5817	 7132	 0.00064	 0.00111	 0.0	 24653	 24653	 24653	 0.0	 0.0	 1	 -30.0	 30.0;
	603	 5664	 0.004919	 0.03837	 0.0	 817	 817	 817	 0.0	 0.0	 1	 -30.0	 30.0;
	9181	 5011	 0.001831	 0.008349	 0.0	 3696	 3696	 3696	 0.0	 0.0	 1	 -30.0	 30.0;
	2946	 592	 0.00536	 0.03188	 0.0	 978	 978	 978	 0.0	 0.0	 1	 -30.0	 30.0;
	4273	 13274	 0.00038	 0.001461	 0.0	 20925	 20925	 20925	 0.0	 0.0	 1	 -30.0	 30.0;
	4273	 13274	 0.000289	 0.001521	 0.0	 20403	 20403	 20403	 0.0	 0.0	 1	 -30.0	 30.0;
	13274	 3559	 0.00305	 0.016841	 0.0	 1846	 1846	 1846	 0.0	 0.0	 1	 -30.0	 30.0;
	13274	 11931	 0.001781	 0.012729	 0.0	 2458	 2458	 2458	 0.0	 0.0	 1	 -30.0	 30.0;
	2919	 11004	 0.00041	 0.00461	 0.0	 6825	 6825	 6825	 0.0	 0.0	 1	 -30.0	 30.0;
	2919	 11004	 0.0004	 0.0047	 0.0	 6697	 6697	 6697	 0.0	 0.0	 1	 -30.0	 30.0;
	6011	 6400	 0.00213	 0.01401	 0.0	 2230	 2230	 2230	 0.0	 0.0	 1	 -30.0	 30.0;
	6011	 3310	 0.001271	 0.00887	 0.0	 3526	 3526	 3526	 0.0	 0.0	 1	 -30.0	 30.0;
	6011	 4121	 0.00462	 0.02743	 0.0	 1136	 1136	 1136	 0.0	 0.0	 1	 -30.0	 30.0;
	3734	 10877	 0.001539	 0.00776	 0.0	 3993	 3993	 3993	 0.0	 0.0	 1	 -30.0	 30.0;
	10526	 13215	 0.00025	 0.00478	 0.0	 6600	 6600	 6600	 0.0	 0.0	 1	 -30.0	 30.0;
	7834	 13215	 0.00025	 0.00487	 0.0	 6478	 6478	 6478	 0.0	 0.0	 1	 -30.0	 30.0;
	11955	 13215	 0.00025	 0.00435	 0.0	 7250	 7250	 7250	 0.0	 0.0	 1	 -30.0	 30.0;
	9269	 13215	 0.00026	 0.00426	 0.0	 7402	 7402	 7402	 0.0	 0.0	 1	 -30.0	 30.0;
	1748	 13215	 0.00025	 0.00479	 0.0	 6586	 6586	 6586	 0.0	 0.0	 1	 -30.0	 30.0;
	6063	 13565	 0.000169	 0.00076	 0.0	 40572	 40572	 40572	 0.0	 0.0	 1	 -30.0	 30.0;
	6063	 11726	 0.00039	 0.00126	 0.0	 23949	 23949	 23949	 0.0	 0.0	 1	 -30.0	 30.0;
	3484	 1162	 0.011229	 0.074659	 0.0	 419	 419	 419	 0.0	 0.0	 1	 -30.0	 30.0;
	3484	 2660	 0.014521	 0.058081	 0.0	 528	 528	 528	 0.0	 0.0	 1	 -30.0	 30.0;
	3484	 13034	 0.00064	 0.003919	 0.0	 7955	 7955	 7955	 0.0	 0.0	 1	 -30.0	 30.0;
	3484	 7517	 0.014789	 0.07768	 0.0	 400	 400	 400	 0.0	 0.0	 1	 -30.0	 30.0;
	3484	 10138	 0.00938	 0.05355	 0.0	 582	 582	 582	 0.0	 0.0	 1	 -30.0	 30.0;
	3484	 2483	 0.00124	 0.004289	 0.0	 7075	 7075	 7075	 0.0	 0.0	 1	 -30.0	 30.0;
	7605	 12749	 0.00968	 0.04388	 0.0	 703	 703	 703	 0.0	 0.0	 1	 -30.0	 30.0;
	7605	 247	 0.008531	 0.067151	 0.0	 467	 467	 467	 0.0	 0.0	 1	 -30.0	 30.0;
	7605	 10895	 0.00731	 0.04106	 0.0	 758	 758	 758	 0.0	 0.0	 1	 -30.0	 30.0;
	10768	 8652	 0.004349	 0.02555	 0.0	 1219	 1219	 1219	 0.0	 0.0	 1	 -30.0	 30.0;
	10768	 13214	 0.00599	 0.03462	 0.0	 900	 900	 900	 0.0	 0.0	 1	 -30.0	 30.0;
	13031	 1162	 0.002961	 0.021591	 0.0	 1450	 1450	 1450	 0.0	 0.0	 1	 -30.0	 30.0;
	13031	 1162	 0.002901	 0.02206	 0.0	 1420	 1420	 1420	 0.0	 0.0	 1	 -30.0	 30.0;
	13031	 8821	 0.002979	 0.016969	 0.0	 1834	 1834	 1834	 0.0	 0.0	 1	 -30.0	 30.0;
	8374	 6148	 0.00312	 0.020021	 0.0	 1559	 1559	 1559	 0.0	 0.0	 1	 -30.0	 30.0;
	12547	 2813	 0.000219	 0.000909	 0.0	 33783	 33783	 33783	 0.0	 0.0	 1	 -30.0	 30.0;
	1976	 2813	 0.000219	 0.00093	 0.0	 33061	 33061	 33061	 0.0	 0.0	 1	 -30.0	 30.0;
	11866	 3009	 0.000151	 0.000289	 0.0	 96873	 96873	 96873	 0.0	 0.0	 1	 -30.0	 30.0;
	7237	 12150	 0.00563	 0.043599	 0.0	 719	 719	 719	 0.0	 0.0	 1	 -30.0	 30.0;
	7237	 6956	 0.000969	 0.00612	 0.0	 5098	 5098	 5098	 0.0	 0.0	 1	 -30.0	 30.0;
	3028	 5280	 0.005021	 0.020719	 0.0	 1482	 1482	 1482	 0.0	 0.0	 1	 -30.0	 30.0;
	3028	 6859	 0.00988	 0.041039	 0.0	 749	 749	 749	 0.0	 0.0	 1	 -30.0	 30.0;
	6834	 12739	 0.003159	 0.02011	 0.0	 1552	 1552	 1552	 0.0	 0.0	 1	 -30.0	 30.0;
	6834	 12739	 0.003219	 0.01969	 0.0	 1584	 1584	 1584	 0.0	 0.0	 1	 -30.0	 30.0;
	10431	 7917	 0.00049	 0.00238	 0.0	 13000	 13000	 13000	 0.0	 0.0	 1	 -30.0	 30.0;
	10431	 7917	 0.000479	 0.002419	 0.0	 12810	 12810	 12810	 0.0	 0.0	 1	 -30.0	 30.0;
	12146	 8318	 0.00264	 0.019729	 0.0	 1587	 1587	 1587	 0.0	 0.0	 1	 -30.0	 30.0;
	12146	 8318	 0.002581	 0.02011	 0.0	 1558	 1558	 1558	 0.0	 0.0	 1	 -30.0	 30.0;
	9437	 4916	 0.00037	 0.002831	 0.0	 11064	 11064	 11064	 0.0	 0.0	 1	 -30.0	 30.0;
	9437	 8273	 0.00213	 0.012789	 0.0	 2437	 2437	 2437	 0.0	 0.0	 1	 -30.0	 30.0;
	3401	 7229	 0.018669	 0.092281	 0.0	 336	 336	 336	 0.0	 0.0	 1	 -30.0	 30.0;
	1271	 13444	 3.9e-05	 0.000401	 0.0	 78402	 78402	 78402	 0.0	 0.0	 1	 -30.0	 30.0;
	5960	 13444	 6e-05	 0.00044	 0.0	 71132	 71132	 71132	 0.0	 0.0	 1	 -30.0	 30.0;
	9987	 3034	 6e-05	 0.0005	 0.0	 62725	 62725	 62725	 0.0	 0.0	 1	 -30.0	 30.0;
	8251	 3785	 0.001271	 0.007031	 0.0	 4421	 4421	 4421	 0.0	 0.0	 1	 -30.0	 30.0;
	8251	 11074	 0.00055	 0.003159	 0.0	 9851	 9851	 9851	 0.0	 0.0	 1	 -30.0	 30.0;
	8251	 11074	 0.00055	 0.00338	 0.0	 9225	 9225	 9225	 0.0	 0.0	 1	 -30.0	 30.0;
	8251	 11074	 0.00105	 0.004771	 0.0	 6466	 6466	 6466	 0.0	 0.0	 1	 -30.0	 30.0;
	8251	 2320	 0.003289	 0.015039	 0.0	 2052	 2052	 2052	 0.0	 0.0	 1	 -30.0	 30.0;
	1053	 1000	 0.00036	 0.004349	 0.0	 7239	 7239	 7239	 0.0	 0.0	 1	 -30.0	 30.0;
	5174	 1000	 0.00038	 0.003669	 0.0	 8564	 8564	 8564	 0.0	 0.0	 1	 -30.0	 30.0;
	9331	 3473	 0.00118	 0.00701	 0.0	 4444	 4444	 4444	 0.0	 0.0	 1	 -30.0	 30.0;
	9331	 3473	 0.001229	 0.00686	 0.0	 4533	 4533	 4533	 0.0	 0.0	 1	 -30.0	 30.0;
	9331	 8605	 0.00301	 0.0217	 0.0	 1442	 1442	 1442	 0.0	 0.0	 1	 -30.0	 30.0;
	9331	 8605	 0.003409	 0.01924	 0.0	 1617	 1617	 1617	 0.0	 0.0	 1	 -30.0	 30.0;
	9331	 8605	 0.003409	 0.01938	 0.0	 1606	 1606	 1606	 0.0	 0.0	 1	 -30.0	 30.0;
	11532	 13448	 0.002719	 0.02131	 0.0	 1471	 1471	 1471	 0.0	 0.0	 1	 -30.0	 30.0;
	9730	 2050	 0.00295	 0.01956	 0.0	 1597	 1597	 1597	 0.0	 0.0	 1	 -30.0	 30.0;
	7462	 8273	 0.001091	 0.00831	 0.0	 3769	 3769	 3769	 0.0	 0.0	 1	 -30.0	 30.0;
	4275	 8605	 0.00111	 0.008211	 0.0	 3813	 3813	 3813	 0.0	 0.0	 1	 -30.0	 30.0;
	7917	 5567	 0.002469	 0.015271	 0.0	 2042	 2042	 2042	 0.0	 0.0	 1	 -30.0	 30.0;
	7917	 11930	 0.00212	 0.01601	 0.0	 1956	 1956	 1956	 0.0	 0.0	 1	 -30.0	 30.0;
	7917	 3638	 0.00037	 0.0028	 0.0	 11184	 11184	 11184	 0.0	 0.0	 1	 -30.0	 30.0;
	7917	 8175	 0.00162	 0.01238	 0.0	 2530	 2530	 2530	 0.0	 0.0	 1	 -30.0	 30.0;
	7917	 8175	 0.001909	 0.01162	 0.0	 2683	 2683	 2683	 0.0	 0.0	 1	 -30.0	 30.0;
	7917	 8175	 0.001909	 0.010729	 0.0	 2899	 2899	 2899	 0.0	 0.0	 1	 -30.0	 30.0;
	7917	 5493	 0.00089	 0.00526	 0.0	 5922	 5922	 5922	 0.0	 0.0	 1	 -30.0	 30.0;
	7917	 8043	 0.00087	 0.00536	 0.0	 5818	 5818	 5818	 0.0	 0.0	 1	 -30.0	 30.0;
	7917	 8360	 0.001521	 0.01176	 0.0	 2664	 2664	 2664	 0.0	 0.0	 1	 -30.0	 30.0;
	13334	 3547	 0.00014	 0.000591	 0.0	 52008	 52008	 52008	 0.0	 0.0	 1	 -30.0	 30.0;
	1902	 1583	 0.003531	 0.028781	 0.0	 1090	 1090	 1090	 0.0	 0.0	 1	 -30.0	 30.0;
	3998	 12207	 0.004599	 0.03657	 0.0	 857	 857	 857	 0.0	 0.0	 1	 -30.0	 30.0;
	3998	 12329	 0.00307	 0.019159	 0.0	 1628	 1628	 1628	 0.0	 0.0	 1	 -30.0	 30.0;
	3998	 1582	 0.000581	 0.004461	 0.0	 7022	 7022	 7022	 0.0	 0.0	 1	 -30.0	 30.0;
	3998	 10056	 0.00164	 0.01161	 0.0	 2694	 2694	 2694	 0.0	 0.0	 1	 -30.0	 30.0;
	7232	 10048	 0.00057	 0.003281	 0.0	 9486	 9486	 9486	 0.0	 0.0	 1	 -30.0	 30.0;
	11342	 10204	 0.020419	 0.063669	 0.0	 473	 473	 473	 0.0	 0.0	 1	 -30.0	 30.0;
	10626	 4511	 0.01424	 0.04751	 0.0	 637	 637	 637	 0.0	 0.0	 1	 -30.0	 30.0;
	3042	 422	 0.00157	 0.008849	 0.0	 3515	 3515	 3515	 0.0	 0.0	 1	 -30.0	 30.0;
	3042	 3602	 0.01218	 0.07524	 0.0	 415	 415	 415	 0.0	 0.0	 1	 -30.0	 30.0;
	2316	 1109	 0.00037	 0.00151	 0.0	 20318	 20318	 20318	 0.0	 0.0	 1	 -30.0	 30.0;
	2821	 9097	 0.000219	 0.000531	 0.0	 54993	 54993	 54993	 0.0	 0.0	 1	 -30.0	 30.0;
	5810	 1980	 0.002849	 0.0137	 0.0	 2258	 2258	 2258	 0.0	 0.0	 1	 -30.0	 30.0;
	1361	 13477	 0.00116	 0.01692	 0.0	 1863	 1863	 1863	 0.0	 0.0	 1	 -30.0	 30.0;
	1361	 13477	 0.00133	 0.01462	 0.0	 2152	 2152	 2152	 0.0	 0.0	 1	 -30.0	 30.0;
	1361	 2936	 0.00063	 0.00821	 0.0	 3837	 3837	 3837	 0.0	 0.0	 1	 -30.0	 30.0;
	1361	 2936	 0.00064	 0.00804	 0.0	 3917	 3917	 3917	 0.0	 0.0	 1	 -30.0	 30.0;
	8243	 7888	 0.00126	 0.01272	 0.0	 2472	 2472	 2472	 0.0	 0.0	 1	 -30.0	 30.0;
	8243	 13408	 0.00337	 0.0494	 0.0	 638	 638	 638	 0.0	 0.0	 1	 -30.0	 30.0;
	8243	 10294	 0.0014	 0.0214	 0.0	 1473	 1473	 1473	 0.0	 0.0	 1	 -30.0	 30.0;
	8243	 10294	 0.00137	 0.02182	 0.0	 1445	 1445	 1445	 0.0	 0.0	 1	 -30.0	 30.0;
	8243	 13130	 0.00212	 0.02063	 0.0	 1524	 1524	 1524	 0.0	 0.0	 1	 -30.0	 30.0;
	12724	 11399	 0.00186	 0.01045	 0.0	 2976	 2976	 2976	 0.0	 0.0	 1	 -30.0	 30.0;
	12724	 11077	 0.00426	 0.021771	 0.0	 1424	 1424	 1424	 0.0	 0.0	 1	 -30.0	 30.0;
	12724	 11077	 0.002659	 0.020539	 0.0	 1526	 1526	 1526	 0.0	 0.0	 1	 -30.0	 30.0;
	12724	 6148	 0.00606	 0.049919	 0.0	 629	 629	 629	 0.0	 0.0	 1	 -30.0	 30.0;
	13477	 6157	 0.00109	 0.01192	 0.0	 2639	 2639	 2639	 0.0	 0.0	 1	 -30.0	 30.0;
	2184	 5760	 0.013021	 0.049219	 0.0	 621	 621	 621	 0.0	 0.0	 1	 -30.0	 30.0;
	2184	 6955	 0.00236	 0.01239	 0.0	 2505	 2505	 2505	 0.0	 0.0	 1	 -30.0	 30.0;
	2184	 6955	 0.0027	 0.015169	 0.0	 2051	 2051	 2051	 0.0	 0.0	 1	 -30.0	 30.0;
	6661	 4880	 0.00285	 0.03283	 0.0	 959	 959	 959	 0.0	 0.0	 1	 -30.0	 30.0;
	6661	 4880	 0.00529	 0.03969	 0.0	 789	 789	 789	 0.0	 0.0	 1	 -30.0	 30.0;
	1905	 4880	 0.00254	 0.03721	 0.0	 847	 847	 847	 0.0	 0.0	 1	 -30.0	 30.0;
	5367	 3889	 0.000159	 0.00069	 0.0	 44610	 44610	 44610	 0.0	 0.0	 1	 -30.0	 30.0;
	5367	 3889	 0.000229	 0.000979	 0.0	 31417	 31417	 31417	 0.0	 0.0	 1	 -30.0	 30.0;
	5367	 3889	 0.00024	 0.00082	 0.0	 36971	 36971	 36971	 0.0	 0.0	 1	 -30.0	 30.0;
	5367	 4682	 0.000169	 0.00075	 0.0	 41087	 41087	 41087	 0.0	 0.0	 1	 -30.0	 30.0;
	5367	 7157	 0.00368	 0.01756	 0.0	 1761	 1761	 1761	 0.0	 0.0	 1	 -30.0	 30.0;
	5367	 2663	 0.002599	 0.020659	 0.0	 1518	 1518	 1518	 0.0	 0.0	 1	 -30.0	 30.0;
	10021	 8087	 0.00018	 0.00064	 0.0	 47512	 47512	 47512	 0.0	 0.0	 1	 -30.0	 30.0;
	10021	 10282	 0.000159	 0.000771	 0.0	 40125	 40125	 40125	 0.0	 0.0	 1	 -30.0	 30.0;
	10021	 8652	 0.00357	 0.01981	 0.0	 1570	 1570	 1570	 0.0	 0.0	 1	 -30.0	 30.0;
	10021	 13214	 0.006021	 0.03205	 0.0	 969	 969	 969	 0.0	 0.0	 1	 -30.0	 30.0;
	1944	 9916	 0.001781	 0.01164	 0.0	 2683	 2683	 2683	 0.0	 0.0	 1	 -30.0	 30.0;
	1944	 10301	 0.002781	 0.018831	 0.0	 1660	 1660	 1660	 0.0	 0.0	 1	 -30.0	 30.0;
	3602	 8987	 0.000349	 0.00281	 0.0	 11156	 11156	 11156	 0.0	 0.0	 1	 -30.0	 30.0;
	130	 4954	 0.00313	 0.02444	 0.0	 1282	 1282	 1282	 0.0	 0.0	 1	 -30.0	 30.0;
	130	 4954	 0.00368	 0.02074	 0.0	 1500	 1500	 1500	 0.0	 0.0	 1	 -30.0	 30.0;
	3034	 4780	 9.1e-05	 0.001539	 0.0	 20489	 20489	 20489	 0.0	 0.0	 1	 -30.0	 30.0;
	3034	 3951	 0.00251	 0.01111	 0.0	 2774	 2774	 2774	 0.0	 0.0	 1	 -30.0	 30.0;
	3034	 9992	 0.003081	 0.017961	 0.0	 1734	 1734	 1734	 0.0	 0.0	 1	 -30.0	 30.0;
	3034	 9849	 0.005341	 0.030419	 0.0	 1023	 1023	 1023	 0.0	 0.0	 1	 -30.0	 30.0;
	3034	 11176	 9.9e-05	 0.00126	 0.0	 24993	 24993	 24993	 0.0	 0.0	 1	 -30.0	 30.0;
	13444	 1494	 0.002169	 0.017901	 0.0	 1752	 1752	 1752	 0.0	 0.0	 1	 -30.0	 30.0;
	3522	 9030	 0.00011	 0.00038	 0.0	 79847	 79847	 79847	 0.0	 0.0	 1	 -30.0	 30.0;
	2016	 13025	 0.00212	 0.00494	 0.0	 5876	 5876	 5876	 0.0	 0.0	 1	 -30.0	 30.0;
	2016	 11395	 0.018901	 0.077349	 0.0	 397	 397	 397	 0.0	 0.0	 1	 -30.0	 30.0;
	11574	 7811	 0.00957	 0.0395	 0.0	 778	 778	 778	 0.0	 0.0	 1	 -30.0	 30.0;
	11574	 10204	 0.02324	 0.063469	 0.0	 468	 468	 468	 0.0	 0.0	 1	 -30.0	 30.0;
	11405	 4851	 0.000531	 0.004331	 0.0	 7240	 7240	 7240	 0.0	 0.0	 1	 -30.0	 30.0;
	2797	 896	 0.002581	 0.006229	 0.0	 4685	 4685	 4685	 0.0	 0.0	 1	 -30.0	 30.0;
	9447	 1783	 0.00031	 0.002211	 0.0	 14149	 14149	 14149	 0.0	 0.0	 1	 -30.0	 30.0;
	1152	 10204	 0.01087	 0.06114	 0.0	 509	 509	 509	 0.0	 0.0	 1	 -30.0	 30.0;
	1152	 8620	 0.011581	 0.061099	 0.0	 508	 508	 508	 0.0	 0.0	 1	 -30.0	 30.0;
	11161	 4436	 0.002099	 0.016271	 0.0	 1926	 1926	 1926	 0.0	 0.0	 1	 -30.0	 30.0;
	735	 4889	 0.00093	 0.005461	 0.0	 5703	 5703	 5703	 0.0	 0.0	 1	 -30.0	 30.0;
	735	 7638	 0.009591	 0.037039	 0.0	 826	 826	 826	 0.0	 0.0	 1	 -30.0	 30.0;
	735	 1116	 0.002591	 0.017211	 0.0	 1815	 1815	 1815	 0.0	 0.0	 1	 -30.0	 30.0;
	735	 11080	 0.00164	 0.013651	 0.0	 2298	 2298	 2298	 0.0	 0.0	 1	 -30.0	 30.0;
	3946	 4974	 0.003219	 0.014719	 0.0	 2097	 2097	 2097	 0.0	 0.0	 1	 -30.0	 30.0;
	3946	 3180	 0.00401	 0.022229	 0.0	 1399	 1399	 1399	 0.0	 0.0	 1	 -30.0	 30.0;
	3946	 10301	 0.00126	 0.010211	 0.0	 3071	 3071	 3071	 0.0	 0.0	 1	 -30.0	 30.0;
	6052	 1607	 0.009169	 0.03993	 0.0	 772	 772	 772	 0.0	 0.0	 1	 -30.0	 30.0;
	6052	 5677	 0.001349	 0.006081	 0.0	 5072	 5072	 5072	 0.0	 0.0	 1	 -30.0	 30.0;
	2507	 12511	 0.00156	 0.01931	 0.0	 1631	 1631	 1631	 0.0	 0.0	 1	 -30.0	 30.0;
	2507	 11017	 0.00152	 0.01968	 0.0	 1601	 1601	 1601	 0.0	 0.0	 1	 -30.0	 30.0;
	2507	 11402	 0.00094	 0.01433	 0.0	 2200	 2200	 2200	 0.0	 0.0	 1	 -30.0	 30.0;
	2507	 10071	 0.00092	 0.01461	 0.0	 2158	 2158	 2158	 0.0	 0.0	 1	 -30.0	 30.0;
	2507	 1356	 0.00137	 0.02012	 0.0	 1567	 1567	 1567	 0.0	 0.0	 1	 -30.0	 30.0;
	2507	 1356	 0.00134	 0.02051	 0.0	 1537	 1537	 1537	 0.0	 0.0	 1	 -30.0	 30.0;
	5664	 6586	 0.00314	 0.042151	 0.0	 748	 748	 748	 0.0	 0.0	 1	 -30.0	 30.0;
	5664	 8754	 0.000651	 0.00494	 0.0	 6340	 6340	 6340	 0.0	 0.0	 1	 -30.0	 30.0;
	5664	 10138	 0.003961	 0.02426	 0.0	 1286	 1286	 1286	 0.0	 0.0	 1	 -30.0	 30.0;
	1215	 2348	 0.00013	 0.0015	 0.0	 20980	 20980	 20980	 0.0	 0.0	 1	 -30.0	 30.0;
	4360	 1158	 0.00013	 0.00147	 0.0	 21405	 21405	 21405	 0.0	 0.0	 1	 -30.0	 30.0;
	7051	 2348	 0.00011	 0.00172	 0.0	 18328	 18328	 18328	 0.0	 0.0	 1	 -30.0	 30.0;
	2892	 1158	 0.00012	 0.00166	 0.0	 18979	 18979	 18979	 0.0	 0.0	 1	 -30.0	 30.0;
	5683	 2348	 0.00012	 0.00168	 0.0	 18755	 18755	 18755	 0.0	 0.0	 1	 -30.0	 30.0;
	5500	 1158	 0.00012	 0.00172	 0.0	 18321	 18321	 18321	 0.0	 0.0	 1	 -30.0	 30.0;
	1075	 1000	 0.00093	 0.005669	 0.0	 5499	 5499	 5499	 0.0	 0.0	 1	 -30.0	 30.0;
	4178	 8175	 0.00105	 0.00506	 0.0	 6113	 6113	 6113	 0.0	 0.0	 1	 -30.0	 30.0;
	8277	 9096	 0.00113	 0.006539	 0.0	 4761	 4761	 4761	 0.0	 0.0	 1	 -30.0	 30.0;
	7571	 7938	 0.00037	 0.002919	 0.0	 10736	 10736	 10736	 0.0	 0.0	 1	 -30.0	 30.0;
	1027	 10399	 0.005169	 0.03738	 0.0	 838	 838	 838	 0.0	 0.0	 1	 -30.0	 30.0;
	5596	 1346	 0.00125	 0.006669	 0.0	 4656	 4656	 4656	 0.0	 0.0	 1	 -30.0	 30.0;
	9341	 3493	 0.001281	 0.00661	 0.0	 4692	 4692	 4692	 0.0	 0.0	 1	 -30.0	 30.0;
	281	 4299	 0.00226	 0.0138	 0.0	 2259	 2259	 2259	 0.0	 0.0	 1	 -30.0	 30.0;
	3616	 5150	 0.00213	 0.02677	 0.0	 1177	 1177	 1177	 0.0	 0.0	 1	 -30.0	 30.0;
	3616	 4880	 0.00154	 0.01919	 0.0	 1641	 1641	 1641	 0.0	 0.0	 1	 -30.0	 30.0;
	6666	 881	 0.00687	 0.04413	 0.0	 708	 708	 708	 0.0	 0.0	 1	 -30.0	 30.0;
	6666	 4716	 0.0045	 0.04725	 0.0	 666	 666	 666	 0.0	 0.0	 1	 -30.0	 30.0;
	6666	 10759	 0.00138	 0.00837	 0.0	 3724	 3724	 3724	 0.0	 0.0	 1	 -30.0	 30.0;
	4435	 9386	 0.000419	 0.001901	 0.0	 16227	 16227	 16227	 0.0	 0.0	 1	 -30.0	 30.0;
	4435	 9386	 0.00043	 0.00186	 0.0	 16547	 16547	 16547	 0.0	 0.0	 1	 -30.0	 30.0;
	8929	 6929	 0.003331	 0.015099	 0.0	 2043	 2043	 2043	 0.0	 0.0	 1	 -30.0	 30.0;
	4878	 9674	 0.002099	 0.01631	 0.0	 1921	 1921	 1921	 0.0	 0.0	 1	 -30.0	 30.0;
	6416	 8183	 0.001331	 0.01082	 0.0	 2898	 2898	 2898	 0.0	 0.0	 1	 -30.0	 30.0;
	6416	 9787	 0.00199	 0.00818	 0.0	 3753	 3753	 3753	 0.0	 0.0	 1	 -30.0	 30.0;
	6416	 9787	 0.00169	 0.008831	 0.0	 3514	 3514	 3514	 0.0	 0.0	 1	 -30.0	 30.0;
	1875	 7861	 0.001771	 0.014281	 0.0	 2196	 2196	 2196	 0.0	 0.0	 1	 -30.0	 30.0;
	881	 897	 0.003099	 0.01844	 0.0	 1690	 1690	 1690	 0.0	 0.0	 1	 -30.0	 30.0;
	5118	 2217	 0.003409	 0.01819	 0.0	 1707	 1707	 1707	 0.0	 0.0	 1	 -30.0	 30.0;
	2743	 3181	 0.00057	 0.00369	 0.0	 8460	 8460	 8460	 0.0	 0.0	 1	 -30.0	 30.0;
	11858	 8605	 0.001081	 0.00468	 0.0	 6577	 6577	 6577	 0.0	 0.0	 1	 -30.0	 30.0;
	5840	 8605	 0.00105	 0.004771	 0.0	 6466	 6466	 6466	 0.0	 0.0	 1	 -30.0	 30.0;
	12862	 897	 0.001979	 0.01549	 0.0	 2023	 2023	 2023	 0.0	 0.0	 1	 -30.0	 30.0;
	12862	 10759	 0.001469	 0.015151	 0.0	 2076	 2076	 2076	 0.0	 0.0	 1	 -30.0	 30.0;
	8496	 7431	 0.000711	 0.003969	 0.0	 7834	 7834	 7834	 0.0	 0.0	 1	 -30.0	 30.0;
	8496	 11073	 0.00051	 0.00274	 0.0	 11334	 11334	 11334	 0.0	 0.0	 1	 -30.0	 30.0;
	8496	 4621	 0.000521	 0.00306	 0.0	 10177	 10177	 10177	 0.0	 0.0	 1	 -30.0	 30.0;
	8496	 5105	 0.00188	 0.011841	 0.0	 2635	 2635	 2635	 0.0	 0.0	 1	 -30.0	 30.0;
	8496	 2251	 0.002469	 0.010539	 0.0	 2919	 2919	 2919	 0.0	 0.0	 1	 -30.0	 30.0;
	6101	 7730	 0.00045	 0.00351	 0.0	 8927	 8927	 8927	 0.0	 0.0	 1	 -30.0	 30.0;
	7478	 13565	 0.00037	 0.000659	 0.0	 41796	 41796	 41796	 0.0	 0.0	 1	 -30.0	 30.0;
	2957	 5601	 0.000401	 0.0007	 0.0	 39156	 39156	 39156	 0.0	 0.0	 1	 -30.0	 30.0;
	2957	 9097	 0.00014	 0.000531	 0.0	 57521	 57521	 57521	 0.0	 0.0	 1	 -30.0	 30.0;
	2957	 2349	 0.000289	 0.0013	 0.0	 23719	 23719	 23719	 0.0	 0.0	 1	 -30.0	 30.0;
	2957	 9125	 7e-05	 0.000289	 0.0	 106228	 106228	 106228	 0.0	 0.0	 1	 -30.0	 30.0;
	2957	 11146	 0.00051	 0.002151	 0.0	 14289	 14289	 14289	 0.0	 0.0	 1	 -30.0	 30.0;
	2957	 3981	 0.00037	 0.00157	 0.0	 19583	 19583	 19583	 0.0	 0.0	 1	 -30.0	 30.0;
	7414	 661	 0.00022	 0.00277	 0.0	 11368	 11368	 11368	 0.0	 0.0	 1	 -30.0	 30.0;
	7414	 661	 0.00025	 0.00271	 0.0	 11607	 11607	 11607	 0.0	 0.0	 1	 -30.0	 30.0;
	11183	 4370	 0.000271	 0.002081	 0.0	 15052	 15052	 15052	 0.0	 0.0	 1	 -30.0	 30.0;
	11183	 4370	 0.00025	 0.00231	 0.0	 13595	 13595	 13595	 0.0	 0.0	 1	 -30.0	 30.0;
	4621	 3349	 0.00095	 0.00331	 0.0	 9173	 9173	 9173	 0.0	 0.0	 1	 -30.0	 30.0;
	4621	 12893	 0.00093	 0.00336	 0.0	 9061	 9061	 9061	 0.0	 0.0	 1	 -30.0	 30.0;
	3583	 12913	 0.000341	 0.002211	 0.0	 14120	 14120	 14120	 0.0	 0.0	 1	 -30.0	 30.0;
	3789	 5121	 0.00032	 0.00232	 0.0	 13488	 13488	 13488	 0.0	 0.0	 1	 -30.0	 30.0;
	6064	 12568	 3.9e-05	 0.000271	 0.0	 115370	 115370	 115370	 0.0	 0.0	 1	 -30.0	 30.0;
	885	 227	 0.00075	 0.0101	 0.0	 3119	 3119	 3119	 0.0	 0.0	 1	 -30.0	 30.0;
	885	 8070	 0.00118	 0.01455	 0.0	 2164	 2164	 2164	 0.0	 0.0	 1	 -30.0	 30.0;
	5567	 13336	 0.0017	 0.0098	 0.0	 3176	 3176	 3176	 0.0	 0.0	 1	 -30.0	 30.0;
	5567	 13336	 0.001521	 0.01111	 0.0	 2817	 2817	 2817	 0.0	 0.0	 1	 -30.0	 30.0;
	5567	 4620	 0.000169	 0.001401	 0.0	 22385	 22385	 22385	 0.0	 0.0	 1	 -30.0	 30.0;
	5567	 1000	 0.002591	 0.01725	 0.0	 1811	 1811	 1811	 0.0	 0.0	 1	 -30.0	 30.0;
	5567	 8426	 0.000169	 0.001159	 0.0	 26969	 26969	 26969	 0.0	 0.0	 1	 -30.0	 30.0;
	5567	 6929	 0.00307	 0.01339	 0.0	 2300	 2300	 2300	 0.0	 0.0	 1	 -30.0	 30.0;
	3785	 2392	 0.002591	 0.013521	 0.0	 2295	 2295	 2295	 0.0	 0.0	 1	 -30.0	 30.0;
	13405	 13372	 0.000581	 0.005031	 0.0	 6238	 6238	 6238	 0.0	 0.0	 1	 -30.0	 30.0;
	10182	 8105	 0.001419	 0.00595	 0.0	 5164	 5164	 5164	 0.0	 0.0	 1	 -30.0	 30.0;
	970	 2124	 0.00205	 0.02664	 0.0	 1183	 1183	 1183	 0.0	 0.0	 1	 -30.0	 30.0;
	970	 3917	 0.00295	 0.03721	 0.0	 847	 847	 847	 0.0	 0.0	 1	 -30.0	 30.0;
	970	 6675	 0.00335	 0.03648	 0.0	 863	 863	 863	 0.0	 0.0	 1	 -30.0	 30.0;
	970	 2294	 0.00022	 0.00251	 0.0	 12537	 12537	 12537	 0.0	 0.0	 1	 -30.0	 30.0;
	970	 2961	 0.00059	 0.00651	 0.0	 4833	 4833	 4833	 0.0	 0.0	 1	 -30.0	 30.0;
	5234	 3083	 0.008539	 0.041979	 0.0	 738	 738	 738	 0.0	 0.0	 1	 -30.0	 30.0;
	5234	 4077	 0.001349	 0.0052	 0.0	 5880	 5880	 5880	 0.0	 0.0	 1	 -30.0	 30.0;
	5312	 11722	 0.00245	 0.013909	 0.0	 2237	 2237	 2237	 0.0	 0.0	 1	 -30.0	 30.0;
	5312	 3559	 0.001469	 0.008419	 0.0	 3697	 3697	 3697	 0.0	 0.0	 1	 -30.0	 30.0;
	7888	 13130	 0.00084	 0.00836	 0.0	 3760	 3760	 3760	 0.0	 0.0	 1	 -30.0	 30.0;
	10411	 5004	 0.002591	 0.017789	 0.0	 1758	 1758	 1758	 0.0	 0.0	 1	 -30.0	 30.0;
	10411	 1607	 0.009651	 0.05968	 0.0	 523	 523	 523	 0.0	 0.0	 1	 -30.0	 30.0;
	10877	 11003	 0.00143	 0.00799	 0.0	 3892	 3892	 3892	 0.0	 0.0	 1	 -30.0	 30.0;
	10877	 9849	 0.001969	 0.014909	 0.0	 2101	 2101	 2101	 0.0	 0.0	 1	 -30.0	 30.0;
	1464	 4954	 0.01039	 0.06406	 0.0	 487	 487	 487	 0.0	 0.0	 1	 -30.0	 30.0;
	6980	 4851	 0.000719	 0.005331	 0.0	 5873	 5873	 5873	 0.0	 0.0	 1	 -30.0	 30.0;
	12476	 6599	 0.00052	 0.00565	 0.0	 5568	 5568	 5568	 0.0	 0.0	 1	 -30.0	 30.0;
	12299	 10746	 0.002409	 0.019479	 0.0	 1610	 1610	 1610	 0.0	 0.0	 1	 -30.0	 30.0;
	12299	 10746	 0.00256	 0.019151	 0.0	 1635	 1635	 1635	 0.0	 0.0	 1	 -30.0	 30.0;
	12299	 4108	 0.00656	 0.02288	 0.0	 1328	 1328	 1328	 0.0	 0.0	 1	 -30.0	 30.0;
	5922	 10761	 0.0027	 0.014901	 0.0	 2086	 2086	 2086	 0.0	 0.0	 1	 -30.0	 30.0;
	5922	 8338	 0.003591	 0.01362	 0.0	 2243	 2243	 2243	 0.0	 0.0	 1	 -30.0	 30.0;
	10737	 3559	 0.002211	 0.01188	 0.0	 2614	 2614	 2614	 0.0	 0.0	 1	 -30.0	 30.0;
	10737	 11276	 0.00068	 0.00357	 0.0	 8692	 8692	 8692	 0.0	 0.0	 1	 -30.0	 30.0;
	10944	 2259	 0.000211	 0.000969	 0.0	 31852	 31852	 31852	 0.0	 0.0	 1	 -30.0	 30.0;
	13234	 4953	 9.9e-05	 0.000539	 0.0	 57640	 57640	 57640	 0.0	 0.0	 1	 -30.0	 30.0;
	2581	 9334	 0.00645	 0.0263	 0.0	 1167	 1167	 1167	 0.0	 0.0	 1	 -30.0	 30.0;
	6778	 8788	 0.00063	 0.001901	 0.0	 15773	 15773	 15773	 0.0	 0.0	 1	 -30.0	 30.0;
	2454	 5222	 0.000281	 0.000669	 0.0	 43532	 43532	 43532	 0.0	 0.0	 1	 -30.0	 30.0;
	11278	 5677	 0.000219	 0.00064	 0.0	 46697	 46697	 46697	 0.0	 0.0	 1	 -30.0	 30.0;
	13573	 4916	 0.00014	 0.00105	 0.0	 29820	 29820	 29820	 0.0	 0.0	 1	 -30.0	 30.0;
	12343	 12945	 0.003219	 0.020729	 0.0	 1506	 1506	 1506	 0.0	 0.0	 1	 -30.0	 30.0;
	12343	 12495	 0.00051	 0.003151	 0.0	 9896	 9896	 9896	 0.0	 0.0	 1	 -30.0	 30.0;
	12343	 12495	 0.000409	 0.00331	 0.0	 9471	 9471	 9471	 0.0	 0.0	 1	 -30.0	 30.0;
	8203	 9710	 0.002289	 0.017479	 0.0	 1792	 1792	 1792	 0.0	 0.0	 1	 -30.0	 30.0;
	8203	 1694	 0.002831	 0.01895	 0.0	 1649	 1649	 1649	 0.0	 0.0	 1	 -30.0	 30.0;
	8203	 9799	 0.006289	 0.036521	 0.0	 853	 853	 853	 0.0	 0.0	 1	 -30.0	 30.0;
	8203	 13294	 0.005651	 0.032169	 0.0	 968	 968	 968	 0.0	 0.0	 1	 -30.0	 30.0;
	8203	 10645	 0.00414	 0.02262	 0.0	 1374	 1374	 1374	 0.0	 0.0	 1	 -30.0	 30.0;
	5112	 9274	 0.01095	 0.05814	 0.0	 534	 534	 534	 0.0	 0.0	 1	 -30.0	 30.0;
	5112	 1445	 0.009	 0.0368	 0.0	 834	 834	 834	 0.0	 0.0	 1	 -30.0	 30.0;
	5112	 5545	 0.000229	 0.00181	 0.0	 17314	 17314	 17314	 0.0	 0.0	 1	 -30.0	 30.0;
	4684	 9611	 0.00119	 0.00726	 0.0	 4294	 4294	 4294	 0.0	 0.0	 1	 -30.0	 30.0;
	12744	 1086	 0.011771	 0.051669	 0.0	 597	 597	 597	 0.0	 0.0	 1	 -30.0	 30.0;
	227	 3090	 0.00209	 0.02279	 0.0	 1381	 1381	 1381	 0.0	 0.0	 1	 -30.0	 30.0;
	11066	 5760	 0.002031	 0.01443	 0.0	 2168	 2168	 2168	 0.0	 0.0	 1	 -30.0	 30.0;
	11066	 10062	 0.00145	 0.008479	 0.0	 3673	 3673	 3673	 0.0	 0.0	 1	 -30.0	 30.0;
	3627	 9059	 0.00124	 0.01433	 0.0	 2197	 2197	 2197	 0.0	 0.0	 1	 -30.0	 30.0;
	3627	 9059	 0.00127	 0.01402	 0.0	 2244	 2244	 2244	 0.0	 0.0	 1	 -30.0	 30.0;
	7129	 5386	 0.013039	 0.052841	 0.0	 581	 581	 581	 0.0	 0.0	 1	 -30.0	 30.0;
	3383	 9059	 0.00235	 0.02739	 0.0	 1150	 1150	 1150	 0.0	 0.0	 1	 -30.0	 30.0;
	3383	 9059	 0.0024	 0.02681	 0.0	 1174	 1174	 1174	 0.0	 0.0	 1	 -30.0	 30.0;
	3383	 6081	 0.00135	 0.02056	 0.0	 1534	 1534	 1534	 0.0	 0.0	 1	 -30.0	 30.0;
	3383	 1859	 0.00087	 0.01124	 0.0	 2802	 2802	 2802	 0.0	 0.0	 1	 -30.0	 30.0;
	5616	 247	 0.0012	 0.00818	 0.0	 3821	 3821	 3821	 0.0	 0.0	 1	 -30.0	 30.0;
	247	 9412	 0.006961	 0.05561	 0.0	 564	 564	 564	 0.0	 0.0	 1	 -30.0	 30.0;
	6400	 11592	 0.00105	 0.00763	 0.0	 4102	 4102	 4102	 0.0	 0.0	 1	 -30.0	 30.0;
	6400	 820	 0.000219	 0.00182	 0.0	 17232	 17232	 17232	 0.0	 0.0	 1	 -30.0	 30.0;
	6400	 13097	 3.9e-05	 0.0002	 0.0	 155017	 155017	 155017	 0.0	 0.0	 1	 -30.0	 30.0;
	6400	 13097	 4.5e-05	 0.000195	 0.0	 157839	 157839	 157839	 0.0	 0.0	 1	 -30.0	 30.0;
	6400	 6228	 0.0035	 0.022651	 0.0	 1379	 1379	 1379	 0.0	 0.0	 1	 -30.0	 30.0;
	5678	 4954	 0.004281	 0.02319	 0.0	 1340	 1340	 1340	 0.0	 0.0	 1	 -30.0	 30.0;
	5678	 1252	 0.003729	 0.014021	 0.0	 2178	 2178	 2178	 0.0	 0.0	 1	 -30.0	 30.0;
	10292	 3083	 0.00212	 0.01582	 0.0	 1979	 1979	 1979	 0.0	 0.0	 1	 -30.0	 30.0;
	12835	 13130	 0.00056	 0.00784	 0.0	 4019	 4019	 4019	 0.0	 0.0	 1	 -30.0	 30.0;
	4954	 11395	 0.004401	 0.01813	 0.0	 1694	 1694	 1694	 0.0	 0.0	 1	 -30.0	 30.0;
	4954	 11395	 0.005021	 0.02144	 0.0	 1435	 1435	 1435	 0.0	 0.0	 1	 -30.0	 30.0;
	9839	 4212	 0.00018	 0.000219	 0.0	 111427	 111427	 111427	 0.0	 0.0	 1	 -30.0	 30.0;
	12014	 4212	 0.000151	 0.000211	 0.0	 121741	 121741	 121741	 0.0	 0.0	 1	 -30.0	 30.0;
	6508	 4212	 0.000151	 0.000211	 0.0	 121741	 121741	 121741	 0.0	 0.0	 1	 -30.0	 30.0;
	2937	 8710	 0.00282	 0.02591	 0.0	 1212	 1212	 1212	 0.0	 0.0	 1	 -30.0	 30.0;
	9847	 3455	 0.00131	 0.008539	 0.0	 3657	 3657	 3657	 0.0	 0.0	 1	 -30.0	 30.0;
	7687	 10989	 0.002159	 0.015969	 0.0	 1961	 1961	 1961	 0.0	 0.0	 1	 -30.0	 30.0;
	10299	 13324	 0.00019	 0.000281	 0.0	 93122	 93122	 93122	 0.0	 0.0	 1	 -30.0	 30.0;
	8103	 3181	 0.0002	 0.000281	 0.0	 91583	 91583	 91583	 0.0	 0.0	 1	 -30.0	 30.0;
	5004	 11774	 0.00139	 0.00774	 0.0	 4017	 4017	 4017	 0.0	 0.0	 1	 -30.0	 30.0;
	934	 9289	 0.01101	 0.06739	 0.0	 463	 463	 463	 0.0	 0.0	 1	 -30.0	 30.0;
	934	 3940	 0.00063	 0.00463	 0.0	 6761	 6761	 6761	 0.0	 0.0	 1	 -30.0	 30.0;
	934	 12691	 0.002341	 0.009599	 0.0	 3197	 3197	 3197	 0.0	 0.0	 1	 -30.0	 30.0;
	11399	 6148	 0.00375	 0.021659	 0.0	 1438	 1438	 1438	 0.0	 0.0	 1	 -30.0	 30.0;
	2124	 8404	 0.00056	 0.00749	 0.0	 4206	 4206	 4206	 0.0	 0.0	 1	 -30.0	 30.0;
	158	 9674	 0.00118	 0.00926	 0.0	 3384	 3384	 3384	 0.0	 0.0	 1	 -30.0	 30.0;
	158	 8788	 0.002039	 0.013081	 0.0	 2386	 2386	 2386	 0.0	 0.0	 1	 -30.0	 30.0;
	2492	 10989	 0.00155	 0.010961	 0.0	 2854	 2854	 2854	 0.0	 0.0	 1	 -30.0	 30.0;
	4780	 11176	 3.9e-05	 0.00036	 0.0	 87233	 87233	 87233	 0.0	 0.0	 1	 -30.0	 30.0;
	261	 282	 0.00024	 0.000409	 0.0	 66610	 66610	 66610	 0.0	 0.0	 1	 -30.0	 30.0;
	12568	 8498	 0.000341	 0.001659	 0.0	 18651	 18651	 18651	 0.0	 0.0	 1	 -30.0	 30.0;
	12568	 7793	 0.005461	 0.024919	 0.0	 1239	 1239	 1239	 0.0	 0.0	 1	 -30.0	 30.0;
	11823	 10309	 0.00158	 0.02413	 0.0	 1307	 1307	 1307	 0.0	 0.0	 1	 -30.0	 30.0;
	11823	 13067	 0.00155	 0.02458	 0.0	 1283	 1283	 1283	 0.0	 0.0	 1	 -30.0	 30.0;
	11823	 10059	 0.00021	 0.00256	 0.0	 12298	 12298	 12298	 0.0	 0.0	 1	 -30.0	 30.0;
	11823	 10059	 0.00024	 0.00243	 0.0	 12936	 12936	 12936	 0.0	 0.0	 1	 -30.0	 30.0;
	11823	 2849	 0.00144	 0.02266	 0.0	 1392	 1392	 1392	 0.0	 0.0	 1	 -30.0	 30.0;
	11823	 2849	 0.0014	 0.02098	 0.0	 1503	 1503	 1503	 0.0	 0.0	 1	 -30.0	 30.0;
	11823	 12512	 0.00086	 0.01074	 0.0	 2932	 2932	 2932	 0.0	 0.0	 1	 -30.0	 30.0;
	12945	 12495	 0.003341	 0.02611	 0.0	 1200	 1200	 1200	 0.0	 0.0	 1	 -30.0	 30.0;
	320	 9913	 0.00387	 0.02063	 0.0	 1505	 1505	 1505	 0.0	 0.0	 1	 -30.0	 30.0;
	320	 9913	 0.00405	 0.018271	 0.0	 1688	 1688	 1688	 0.0	 0.0	 1	 -30.0	 30.0;
	320	 1686	 0.00101	 0.00462	 0.0	 6680	 6680	 6680	 0.0	 0.0	 1	 -30.0	 30.0;
	320	 3702	 0.00088	 0.00389	 0.0	 7921	 7921	 7921	 0.0	 0.0	 1	 -30.0	 30.0;
	320	 9799	 0.005081	 0.039	 0.0	 804	 804	 804	 0.0	 0.0	 1	 -30.0	 30.0;
	11722	 11276	 0.00257	 0.0208	 0.0	 1508	 1508	 1508	 0.0	 0.0	 1	 -30.0	 30.0;
	11722	 11276	 0.00251	 0.01926	 0.0	 1627	 1627	 1627	 0.0	 0.0	 1	 -30.0	 30.0;
	11722	 1493	 0.002531	 0.01314	 0.0	 2361	 2361	 2361	 0.0	 0.0	 1	 -30.0	 30.0;
	10407	 11515	 0.00132	 0.00869	 0.0	 3594	 3594	 3594	 0.0	 0.0	 1	 -30.0	 30.0;
	12397	 10852	 0.00082	 0.004021	 0.0	 7698	 7698	 7698	 0.0	 0.0	 1	 -30.0	 30.0;
	12397	 7112	 0.00143	 0.007479	 0.0	 4149	 4149	 4149	 0.0	 0.0	 1	 -30.0	 30.0;
	3995	 2508	 0.000659	 0.005771	 0.0	 5439	 5439	 5439	 0.0	 0.0	 1	 -30.0	 30.0;
	3995	 2508	 0.000591	 0.006539	 0.0	 4811	 4811	 4811	 0.0	 0.0	 1	 -30.0	 30.0;
	1850	 9183	 0.00589	 0.025599	 0.0	 1203	 1203	 1203	 0.0	 0.0	 1	 -30.0	 30.0;
	1850	 10204	 0.00614	 0.02343	 0.0	 1305	 1305	 1305	 0.0	 0.0	 1	 -30.0	 30.0;
	3917	 2564	 0.00155	 0.01994	 0.0	 1580	 1580	 1580	 0.0	 0.0	 1	 -30.0	 30.0;
	3917	 4880	 0.00205	 0.03218	 0.0	 980	 980	 980	 0.0	 0.0	 1	 -30.0	 30.0;
	6675	 4880	 0.00233	 0.03154	 0.0	 999	 999	 999	 0.0	 0.0	 1	 -30.0	 30.0;
	6924	 8338	 0.002341	 0.01982	 0.0	 1583	 1583	 1583	 0.0	 0.0	 1	 -30.0	 30.0;
	1563	 5545	 8.1e-05	 0.000521	 0.0	 59909	 59909	 59909	 0.0	 0.0	 1	 -30.0	 30.0;
	1981	 8095	 9.9e-05	 0.00069	 0.0	 45315	 45315	 45315	 0.0	 0.0	 1	 -30.0	 30.0;
	6274	 6715	 0.00276	 0.016419	 0.0	 1898	 1898	 1898	 0.0	 0.0	 1	 -30.0	 30.0;
	10303	 7195	 0.00036	 0.001229	 0.0	 24666	 24666	 24666	 0.0	 0.0	 1	 -30.0	 30.0;
	10303	 5499	 0.000229	 0.000711	 0.0	 42288	 42288	 42288	 0.0	 0.0	 1	 -30.0	 30.0;
	3547	 13332	 0.00013	 0.00099	 0.0	 31635	 31635	 31635	 0.0	 0.0	 1	 -30.0	 30.0;
	13302	 8040	 0.001159	 0.00689	 0.0	 4522	 4522	 4522	 0.0	 0.0	 1	 -30.0	 30.0;
	10058	 10485	 0.008531	 0.03045	 0.0	 999	 999	 999	 0.0	 0.0	 1	 -30.0	 30.0;
	7866	 11774	 0.000781	 0.004531	 0.0	 6871	 6871	 6871	 0.0	 0.0	 1	 -30.0	 30.0;
	7866	 11774	 0.00075	 0.00474	 0.0	 6583	 6583	 6583	 0.0	 0.0	 1	 -30.0	 30.0;
	8572	 5921	 0.002159	 0.008349	 0.0	 3663	 3663	 3663	 0.0	 0.0	 1	 -30.0	 30.0;
	4416	 12272	 0.00162	 0.01651	 0.0	 1905	 1905	 1905	 0.0	 0.0	 1	 -30.0	 30.0;
	1314	 9296	 0.01236	 0.044211	 0.0	 689	 689	 689	 0.0	 0.0	 1	 -30.0	 30.0;
	1314	 9296	 0.00825	 0.03989	 0.0	 776	 776	 776	 0.0	 0.0	 1	 -30.0	 30.0;
	1314	 3424	 0.02187	 0.066961	 0.0	 449	 449	 449	 0.0	 0.0	 1	 -30.0	 30.0;
	1314	 5844	 0.01212	 0.06661	 0.0	 467	 467	 467	 0.0	 0.0	 1	 -30.0	 30.0;
	5763	 2348	 0.00036	 0.00534	 0.0	 5902	 5902	 5902	 0.0	 0.0	 1	 -30.0	 30.0;
	9938	 1653	 0.000229	 0.00063	 0.0	 47123	 47123	 47123	 0.0	 0.0	 1	 -30.0	 30.0;
	9938	 11114	 0.000219	 0.000581	 0.0	 50874	 50874	 50874	 0.0	 0.0	 1	 -30.0	 30.0;
	5914	 5872	 0.000281	 0.00063	 0.0	 45791	 45791	 45791	 0.0	 0.0	 1	 -30.0	 30.0;
	2274	 2007	 0.005021	 0.035659	 0.0	 878	 878	 878	 0.0	 0.0	 1	 -30.0	 30.0;
	4504	 5395	 0.00174	 0.007901	 0.0	 3905	 3905	 3905	 0.0	 0.0	 1	 -30.0	 30.0;
	7638	 3180	 0.003919	 0.020581	 0.0	 1508	 1508	 1508	 0.0	 0.0	 1	 -30.0	 30.0;
	7638	 11931	 0.003341	 0.016349	 0.0	 1893	 1893	 1893	 0.0	 0.0	 1	 -30.0	 30.0;
	7638	 2104	 0.003271	 0.016669	 0.0	 1860	 1860	 1860	 0.0	 0.0	 1	 -30.0	 30.0;
	4002	 12559	 0.000151	 0.000659	 0.0	 46722	 46722	 46722	 0.0	 0.0	 1	 -30.0	 30.0;
	9372	 1607	 0.00736	 0.035659	 0.0	 868	 868	 868	 0.0	 0.0	 1	 -30.0	 30.0;
	9372	 5722	 0.00944	 0.042169	 0.0	 731	 731	 731	 0.0	 0.0	 1	 -30.0	 30.0;
	6512	 6937	 0.00068	 0.00652	 0.0	 4819	 4819	 4819	 0.0	 0.0	 1	 -30.0	 30.0;
	6512	 3448	 0.00188	 0.02281	 0.0	 1381	 1381	 1381	 0.0	 0.0	 1	 -30.0	 30.0;
	4974	 7761	 0.00168	 0.00956	 0.0	 3255	 3255	 3255	 0.0	 0.0	 1	 -30.0	 30.0;
	4974	 7761	 0.001669	 0.00981	 0.0	 3175	 3175	 3175	 0.0	 0.0	 1	 -30.0	 30.0;
	4974	 1116	 0.002229	 0.01599	 0.0	 1957	 1957	 1957	 0.0	 0.0	 1	 -30.0	 30.0;
	4974	 1116	 0.00218	 0.01631	 0.0	 1920	 1920	 1920	 0.0	 0.0	 1	 -30.0	 30.0;
	1554	 2936	 0.00238	 0.02124	 0.0	 1478	 1478	 1478	 0.0	 0.0	 1	 -30.0	 30.0;
	1554	 2936	 0.00194	 0.02023	 0.0	 1555	 1555	 1555	 0.0	 0.0	 1	 -30.0	 30.0;
	10795	 4581	 0.013831	 0.05955	 0.0	 517	 517	 517	 0.0	 0.0	 1	 -30.0	 30.0;
	10795	 627	 0.00876	 0.04875	 0.0	 638	 638	 638	 0.0	 0.0	 1	 -30.0	 30.0;
	4105	 2641	 0.0002	 0.00099	 0.0	 31275	 31275	 31275	 0.0	 0.0	 1	 -30.0	 30.0;
	1930	 2729	 0.00105	 0.00826	 0.0	 3794	 3794	 3794	 0.0	 0.0	 1	 -30.0	 30.0;
	3083	 1086	 0.0172	 0.06637	 0.0	 461	 461	 461	 0.0	 0.0	 1	 -30.0	 30.0;
	5280	 4090	 0.00305	 0.015781	 0.0	 1966	 1966	 1966	 0.0	 0.0	 1	 -30.0	 30.0;
	9592	 5299	 0.00208	 0.02105	 0.0	 1494	 1494	 1494	 0.0	 0.0	 1	 -30.0	 30.0;
	12495	 2804	 0.00614	 0.043729	 0.0	 716	 716	 716	 0.0	 0.0	 1	 -30.0	 30.0;
	12495	 8629	 0.000229	 0.001849	 0.0	 16954	 16954	 16954	 0.0	 0.0	 1	 -30.0	 30.0;
	8336	 8821	 0.00386	 0.025789	 0.0	 1212	 1212	 1212	 0.0	 0.0	 1	 -30.0	 30.0;
	8336	 3350	 0.002031	 0.012	 0.0	 2596	 2596	 2596	 0.0	 0.0	 1	 -30.0	 30.0;
	3770	 10989	 0.000591	 0.004	 0.0	 7813	 7813	 7813	 0.0	 0.0	 1	 -30.0	 30.0;
	1633	 3444	 9.1e-05	 0.00051	 0.0	 60973	 60973	 60973	 0.0	 0.0	 1	 -30.0	 30.0;
	11074	 8460	 0.00732	 0.039969	 0.0	 778	 778	 778	 0.0	 0.0	 1	 -30.0	 30.0;
	11074	 4700	 0.004581	 0.02031	 0.0	 1518	 1518	 1518	 0.0	 0.0	 1	 -30.0	 30.0;
	11222	 8460	 0.00132	 0.00537	 0.0	 5713	 5713	 5713	 0.0	 0.0	 1	 -30.0	 30.0;
	2508	 7048	 0.007521	 0.0387	 0.0	 802	 802	 802	 0.0	 0.0	 1	 -30.0	 30.0;
	10008	 7396	 0.005159	 0.031281	 0.0	 997	 997	 997	 0.0	 0.0	 1	 -30.0	 30.0;
	12234	 13028	 9.9e-05	 0.001159	 0.0	 27156	 27156	 27156	 0.0	 0.0	 1	 -30.0	 30.0;
	1268	 13028	 9.9e-05	 0.00113	 0.0	 27847	 27847	 27847	 0.0	 0.0	 1	 -30.0	 30.0;
	6605	 6394	 0.00019	 0.000909	 0.0	 34015	 34015	 34015	 0.0	 0.0	 1	 -30.0	 30.0;
	10463	 11424	 0.00107	 0.00413	 0.0	 7404	 7404	 7404	 0.0	 0.0	 1	 -30.0	 30.0;
	10059	 2953	 9e-05	 0.00058	 0.0	 53817	 53817	 53817	 0.0	 0.0	 1	 -30.0	 30.0;
	10059	 5913	 9e-05	 0.00059	 0.0	 52926	 52926	 52926	 0.0	 0.0	 1	 -30.0	 30.0;
	10059	 13403	 8e-05	 0.00053	 0.0	 58932	 58932	 58932	 0.0	 0.0	 1	 -30.0	 30.0;
	10059	 965	 8e-05	 0.00052	 0.0	 60039	 60039	 60039	 0.0	 0.0	 1	 -30.0	 30.0;
	9669	 13125	 0.000271	 0.00151	 0.0	 20590	 20590	 20590	 0.0	 0.0	 1	 -30.0	 30.0;
	13215	 9059	 0.00053	 0.00585	 0.0	 5378	 5378	 5378	 0.0	 0.0	 1	 -30.0	 30.0;
	13215	 9059	 0.00047	 0.00663	 0.0	 4753	 4753	 4753	 0.0	 0.0	 1	 -30.0	 30.0;
	13215	 9059	 0.00046	 0.00676	 0.0	 4662	 4662	 4662	 0.0	 0.0	 1	 -30.0	 30.0;
	13215	 9059	 0.00045	 0.00689	 0.0	 4575	 4575	 4575	 0.0	 0.0	 1	 -30.0	 30.0;
	13215	 12531	 0.00028	 0.00338	 0.0	 9314	 9314	 9314	 0.0	 0.0	 1	 -30.0	 30.0;
	13215	 12531	 0.0003	 0.00319	 0.0	 9859	 9859	 9859	 0.0	 0.0	 1	 -30.0	 30.0;
	2349	 12594	 0.00025	 0.00101	 0.0	 30359	 30359	 30359	 0.0	 0.0	 1	 -30.0	 30.0;
	282	 2813	 0.000281	 0.00119	 0.0	 25834	 25834	 25834	 0.0	 0.0	 1	 -30.0	 30.0;
	4165	 8105	 0.00018	 0.00063	 0.0	 48210	 48210	 48210	 0.0	 0.0	 1	 -30.0	 30.0;
	2958	 6475	 0.00382	 0.02868	 0.0	 1092	 1092	 1092	 0.0	 0.0	 1	 -30.0	 30.0;
	2958	 495	 0.00361	 0.0235	 0.0	 1329	 1329	 1329	 0.0	 0.0	 1	 -30.0	 30.0;
	2958	 6490	 0.00538	 0.03569	 0.0	 876	 876	 876	 0.0	 0.0	 1	 -30.0	 30.0;
	4927	 203	 6e-05	 0.000409	 0.0	 76413	 76413	 76413	 0.0	 0.0	 1	 -30.0	 30.0;
	1465	 4719	 9e-05	 0.00102	 0.0	 30849	 30849	 30849	 0.0	 0.0	 1	 -30.0	 30.0;
	1465	 10731	 0.0014	 0.01649	 0.0	 1909	 1909	 1909	 0.0	 0.0	 1	 -30.0	 30.0;
	1465	 4194	 0.00034	 0.00427	 0.0	 7375	 7375	 7375	 0.0	 0.0	 1	 -30.0	 30.0;
	1229	 4406	 0.0001	 0.00109	 0.0	 28859	 28859	 28859	 0.0	 0.0	 1	 -30.0	 30.0;
	1229	 9409	 0.00137	 0.01682	 0.0	 1872	 1872	 1872	 0.0	 0.0	 1	 -30.0	 30.0;
	1229	 5846	 0.00131	 0.01262	 0.0	 2490	 2490	 2490	 0.0	 0.0	 1	 -30.0	 30.0;
	10468	 13541	 0.00262	 0.019669	 0.0	 1592	 1592	 1592	 0.0	 0.0	 1	 -30.0	 30.0;
	10468	 3466	 0.00082	 0.00526	 0.0	 5934	 5934	 5934	 0.0	 0.0	 1	 -30.0	 30.0;
	10468	 3466	 0.000841	 0.005151	 0.0	 6053	 6053	 6053	 0.0	 0.0	 1	 -30.0	 30.0;
	10468	 3466	 0.000669	 0.005081	 0.0	 6164	 6164	 6164	 0.0	 0.0	 1	 -30.0	 30.0;
	10468	 13083	 0.001919	 0.012669	 0.0	 2466	 2466	 2466	 0.0	 0.0	 1	 -30.0	 30.0;
	55	 301	 0.002659	 0.02	 0.0	 1566	 1566	 1566	 0.0	 0.0	 1	 -30.0	 30.0;
	55	 5194	 0.003031	 0.02343	 0.0	 1338	 1338	 1338	 0.0	 0.0	 1	 -30.0	 30.0;
	9096	 6906	 0.01176	 0.059159	 0.0	 524	 524	 524	 0.0	 0.0	 1	 -30.0	 30.0;
	9096	 12329	 0.002469	 0.017531	 0.0	 1785	 1785	 1785	 0.0	 0.0	 1	 -30.0	 30.0;
	9096	 6738	 0.000669	 0.005729	 0.0	 5477	 5477	 5477	 0.0	 0.0	 1	 -30.0	 30.0;
	12207	 12492	 0.000781	 0.00876	 0.0	 3592	 3592	 3592	 0.0	 0.0	 1	 -30.0	 30.0;
	12207	 7938	 0.00062	 0.00482	 0.0	 6500	 6500	 6500	 0.0	 0.0	 1	 -30.0	 30.0;
	12207	 11176	 0.001349	 0.012599	 0.0	 2493	 2493	 2493	 0.0	 0.0	 1	 -30.0	 30.0;
	9992	 12492	 0.000979	 0.0082	 0.0	 3825	 3825	 3825	 0.0	 0.0	 1	 -30.0	 30.0;
	9992	 1242	 0.008091	 0.028831	 0.0	 1055	 1055	 1055	 0.0	 0.0	 1	 -30.0	 30.0;
	9992	 6738	 0.000711	 0.005969	 0.0	 5255	 5255	 5255	 0.0	 0.0	 1	 -30.0	 30.0;
	5836	 203	 0.00145	 0.00857	 0.0	 3635	 3635	 3635	 0.0	 0.0	 1	 -30.0	 30.0;
	1571	 1621	 0.00869	 0.03768	 0.0	 817	 817	 817	 0.0	 0.0	 1	 -30.0	 30.0;
	1571	 4436	 0.001719	 0.00837	 0.0	 3697	 3697	 3697	 0.0	 0.0	 1	 -30.0	 30.0;
	12559	 7811	 0.01582	 0.067349	 0.0	 457	 457	 457	 0.0	 0.0	 1	 -30.0	 30.0;
	12559	 7811	 0.01457	 0.06469	 0.0	 477	 477	 477	 0.0	 0.0	 1	 -30.0	 30.0;
	12559	 6646	 0.021711	 0.090539	 0.0	 340	 340	 340	 0.0	 0.0	 1	 -30.0	 30.0;
	12559	 4907	 0.00019	 0.000729	 0.0	 41929	 41929	 41929	 0.0	 0.0	 1	 -30.0	 30.0;
	1317	 7838	 0.001271	 0.00638	 0.0	 4856	 4856	 4856	 0.0	 0.0	 1	 -30.0	 30.0;
	1291	 9611	 3.9e-05	 0.0002	 0.0	 155017	 155017	 155017	 0.0	 0.0	 1	 -30.0	 30.0;
	9740	 6497	 0.000281	 0.00236	 0.0	 13291	 13291	 13291	 0.0	 0.0	 1	 -30.0	 30.0;
	11015	 3090	 0.00019	 0.00329	 0.0	 9586	 9586	 9586	 0.0	 0.0	 1	 -30.0	 30.0;
	10996	 8070	 0.00035	 0.00324	 0.0	 9693	 9693	 9693	 0.0	 0.0	 1	 -30.0	 30.0;
	9611	 13167	 0.00049	 0.00349	 0.0	 8963	 8963	 8963	 0.0	 0.0	 1	 -30.0	 30.0;
	9611	 13167	 0.000469	 0.00331	 0.0	 9449	 9449	 9449	 0.0	 0.0	 1	 -30.0	 30.0;
	9611	 2375	 0.00313	 0.01324	 0.0	 2322	 2322	 2322	 0.0	 0.0	 1	 -30.0	 30.0;
	9611	 13481	 0.001031	 0.006719	 0.0	 4647	 4647	 4647	 0.0	 0.0	 1	 -30.0	 30.0;
	9611	 13092	 0.00038	 0.00401	 0.0	 7843	 7843	 7843	 0.0	 0.0	 1	 -30.0	 30.0;
	738	 5265	 0.00037	 0.002849	 0.0	 10995	 10995	 10995	 0.0	 0.0	 1	 -30.0	 30.0;
	12492	 1494	 0.00032	 0.00256	 0.0	 12244	 12244	 12244	 0.0	 0.0	 1	 -30.0	 30.0;
	12492	 206	 0.00037	 0.00118	 0.0	 25543	 25543	 25543	 0.0	 0.0	 1	 -30.0	 30.0;
	12492	 6258	 0.00068	 0.001151	 0.0	 23628	 23628	 23628	 0.0	 0.0	 1	 -30.0	 30.0;
	1154	 5010	 0.00168	 0.009841	 0.0	 3164	 3164	 3164	 0.0	 0.0	 1	 -30.0	 30.0;
	12662	 13111	 0.000599	 0.002401	 0.0	 12765	 12765	 12765	 0.0	 0.0	 1	 -30.0	 30.0;
	3301	 6	 0.002169	 0.00911	 0.0	 3374	 3374	 3374	 0.0	 0.0	 1	 -30.0	 30.0;
	3301	 7077	 0.002849	 0.01282	 0.0	 2406	 2406	 2406	 0.0	 0.0	 1	 -30.0	 30.0;
	9125	 7838	 0.001229	 0.01207	 0.0	 2604	 2604	 2604	 0.0	 0.0	 1	 -30.0	 30.0;
	9125	 10989	 0.001289	 0.01089	 0.0	 2881	 2881	 2881	 0.0	 0.0	 1	 -30.0	 30.0;
	2849	 2350	 0.00093	 0.01036	 0.0	 3037	 3037	 3037	 0.0	 0.0	 1	 -30.0	 30.0;
	2849	 3448	 0.00083	 0.01174	 0.0	 2684	 2684	 2684	 0.0	 0.0	 1	 -30.0	 30.0;
	9710	 11515	 0.00118	 0.009469	 0.0	 3311	 3311	 3311	 0.0	 0.0	 1	 -30.0	 30.0;
	9710	 11515	 0.001151	 0.009651	 0.0	 3250	 3250	 3250	 0.0	 0.0	 1	 -30.0	 30.0;
	7948	 11927	 0.00101	 0.01327	 0.0	 2374	 2374	 2374	 0.0	 0.0	 1	 -30.0	 30.0;
	9183	 6148	 0.00364	 0.02486	 0.0	 1258	 1258	 1258	 0.0	 0.0	 1	 -30.0	 30.0;
	12385	 6955	 0.00056	 0.00425	 0.0	 7369	 7369	 7369	 0.0	 0.0	 1	 -30.0	 30.0;
	12385	 6715	 0.00369	 0.02681	 0.0	 1168	 1168	 1168	 0.0	 0.0	 1	 -30.0	 30.0;
	501	 11609	 0.000531	 0.00276	 0.0	 11239	 11239	 11239	 0.0	 0.0	 1	 -30.0	 30.0;
	3541	 11609	 0.000521	 0.00281	 0.0	 11053	 11053	 11053	 0.0	 0.0	 1	 -30.0	 30.0;
	7665	 11609	 0.000419	 0.00232	 0.0	 13399	 13399	 13399	 0.0	 0.0	 1	 -30.0	 30.0;
	3105	 11609	 0.000409	 0.00237	 0.0	 13134	 13134	 13134	 0.0	 0.0	 1	 -30.0	 30.0;
	12472	 13408	 0.00014	 0.00193	 0.0	 16324	 16324	 16324	 0.0	 0.0	 1	 -30.0	 30.0;
	3832	 8718	 0.003211	 0.01481	 0.0	 2085	 2085	 2085	 0.0	 0.0	 1	 -30.0	 30.0;
	1694	 8309	 0.00381	 0.01175	 0.0	 2558	 2558	 2558	 0.0	 0.0	 1	 -30.0	 30.0;
	1694	 9544	 0.003781	 0.02676	 0.0	 1169	 1169	 1169	 0.0	 0.0	 1	 -30.0	 30.0;
	3377	 5230	 0.000919	 0.005461	 0.0	 5704	 5704	 5704	 0.0	 0.0	 1	 -30.0	 30.0;
	3377	 13071	 0.000271	 0.001211	 0.0	 25455	 25455	 25455	 0.0	 0.0	 1	 -30.0	 30.0;
	3377	 12739	 0.002229	 0.017401	 0.0	 1801	 1801	 1801	 0.0	 0.0	 1	 -30.0	 30.0;
	3377	 12739	 0.00243	 0.017659	 0.0	 1773	 1773	 1773	 0.0	 0.0	 1	 -30.0	 30.0;
	3377	 12739	 0.002531	 0.01705	 0.0	 1833	 1833	 1833	 0.0	 0.0	 1	 -30.0	 30.0;
	13045	 7450	 0.012531	 0.05451	 0.0	 565	 565	 565	 0.0	 0.0	 1	 -30.0	 30.0;
	8404	 6937	 0.00087	 0.01212	 0.0	 2600	 2600	 2600	 0.0	 0.0	 1	 -30.0	 30.0;
	8404	 1269	 0.0006	 0.00802	 0.0	 3928	 3928	 3928	 0.0	 0.0	 1	 -30.0	 30.0;
	8404	 12272	 0.00072	 0.00667	 0.0	 4709	 4709	 4709	 0.0	 0.0	 1	 -30.0	 30.0;
	8404	 2961	 0.00234	 0.02626	 0.0	 1199	 1199	 1199	 0.0	 0.0	 1	 -30.0	 30.0;
	9892	 13083	 0.00038	 0.002969	 0.0	 10553	 10553	 10553	 0.0	 0.0	 1	 -30.0	 30.0;
	11582	 5753	 0.00024	 0.00045	 0.0	 61936	 61936	 61936	 0.0	 0.0	 1	 -30.0	 30.0;
	9835	 5753	 0.000229	 0.000409	 0.0	 67388	 67388	 67388	 0.0	 0.0	 1	 -30.0	 30.0;
	6306	 5753	 0.000281	 0.000401	 0.0	 64510	 64510	 64510	 0.0	 0.0	 1	 -30.0	 30.0;
	7807	 13541	 0.001211	 0.005271	 0.0	 5841	 5841	 5841	 0.0	 0.0	 1	 -30.0	 30.0;
	7807	 521	 0.000281	 0.00107	 0.0	 28553	 28553	 28553	 0.0	 0.0	 1	 -30.0	 30.0;
	7807	 11933	 0.00025	 0.001091	 0.0	 28222	 28222	 28222	 0.0	 0.0	 1	 -30.0	 30.0;
	5662	 2813	 0.00019	 0.00081	 0.0	 37967	 37967	 37967	 0.0	 0.0	 1	 -30.0	 30.0;
	5662	 2813	 0.00045	 0.00136	 0.0	 22051	 22051	 22051	 0.0	 0.0	 1	 -30.0	 30.0;
	5097	 812	 0.003461	 0.023289	 0.0	 1342	 1342	 1342	 0.0	 0.0	 1	 -30.0	 30.0;
	7280	 12094	 0.0013	 0.01609	 0.0	 1957	 1957	 1957	 0.0	 0.0	 1	 -30.0	 30.0;
	7280	 12094	 0.00128	 0.0164	 0.0	 1921	 1921	 1921	 0.0	 0.0	 1	 -30.0	 30.0;
	7280	 3891	 0.00089	 0.01082	 0.0	 2910	 2910	 2910	 0.0	 0.0	 1	 -30.0	 30.0;
	7280	 3891	 0.00087	 0.01102	 0.0	 2858	 2858	 2858	 0.0	 0.0	 1	 -30.0	 30.0;
	5559	 7758	 0.003349	 0.02514	 0.0	 1246	 1246	 1246	 0.0	 0.0	 1	 -30.0	 30.0;
	720	 3802	 0.0003	 0.00061	 0.0	 46468	 46468	 46468	 0.0	 0.0	 1	 -30.0	 30.0;
	211	 10746	 0.000289	 0.001211	 0.0	 25372	 25372	 25372	 0.0	 0.0	 1	 -30.0	 30.0;
	10630	 9358	 0.01301	 0.044091	 0.0	 688	 688	 688	 0.0	 0.0	 1	 -30.0	 30.0;
	10630	 2483	 0.02162	 0.065969	 0.0	 456	 456	 456	 0.0	 0.0	 1	 -30.0	 30.0;
	10970	 467	 0.006461	 0.05275	 0.0	 595	 595	 595	 0.0	 0.0	 1	 -30.0	 30.0;
	10159	 11726	 0.0002	 0.000271	 0.0	 93784	 93784	 93784	 0.0	 0.0	 1	 -30.0	 30.0;
	4849	 11726	 0.00018	 0.00026	 0.0	 99888	 99888	 99888	 0.0	 0.0	 1	 -30.0	 30.0;
	8197	 2483	 0.00032	 0.00188	 0.0	 16564	 16564	 16564	 0.0	 0.0	 1	 -30.0	 30.0;
	13541	 13083	 0.00105	 0.006591	 0.0	 4733	 4733	 4733	 0.0	 0.0	 1	 -30.0	 30.0;
	26	 9012	 0.00013	 0.00055	 0.0	 55892	 55892	 55892	 0.0	 0.0	 1	 -30.0	 30.0;
	11446	 7811	 0.006151	 0.04013	 0.0	 779	 779	 779	 0.0	 0.0	 1	 -30.0	 30.0;
	11446	 10204	 0.007159	 0.040591	 0.0	 767	 767	 767	 0.0	 0.0	 1	 -30.0	 30.0;
	3268	 4528	 0.00874	 0.048461	 0.0	 642	 642	 642	 0.0	 0.0	 1	 -30.0	 30.0;
	3268	 6943	 0.004159	 0.01606	 0.0	 1905	 1905	 1905	 0.0	 0.0	 1	 -30.0	 30.0;
	3268	 5395	 0.002919	 0.01912	 0.0	 1634	 1634	 1634	 0.0	 0.0	 1	 -30.0	 30.0;
	467	 6303	 0.00094	 0.00394	 0.0	 7799	 7799	 7799	 0.0	 0.0	 1	 -30.0	 30.0;
	467	 8412	 0.000901	 0.00395	 0.0	 7797	 7797	 7797	 0.0	 0.0	 1	 -30.0	 30.0;
	467	 3540	 0.003159	 0.017789	 0.0	 1749	 1749	 1749	 0.0	 0.0	 1	 -30.0	 30.0;
	467	 3540	 0.002419	 0.018331	 0.0	 1709	 1709	 1709	 0.0	 0.0	 1	 -30.0	 30.0;
	467	 7664	 0.00375	 0.018281	 0.0	 1693	 1693	 1693	 0.0	 0.0	 1	 -30.0	 30.0;
	4632	 3802	 0.00025	 0.001031	 0.0	 29775	 29775	 29775	 0.0	 0.0	 1	 -30.0	 30.0;
	6859	 7112	 0.00264	 0.01238	 0.0	 2496	 2496	 2496	 0.0	 0.0	 1	 -30.0	 30.0;
	6859	 7112	 0.001289	 0.00795	 0.0	 3923	 3923	 3923	 0.0	 0.0	 1	 -30.0	 30.0;
	6859	 13092	 0.00087	 0.003081	 0.0	 9867	 9867	 9867	 0.0	 0.0	 1	 -30.0	 30.0;
	13492	 7606	 0.000401	 0.00224	 0.0	 13881	 13881	 13881	 0.0	 0.0	 1	 -30.0	 30.0;
	82	 326	 0.0003	 0.00385	 0.0	 8180	 8180	 8180	 0.0	 0.0	 1	 -30.0	 30.0;
	4479	 1206	 0.00126	 0.008219	 0.0	 3799	 3799	 3799	 0.0	 0.0	 1	 -30.0	 30.0;
	213	 7450	 0.01905	 0.055729	 0.0	 537	 537	 537	 0.0	 0.0	 1	 -30.0	 30.0;
	213	 5222	 0.00201	 0.00444	 0.0	 6482	 6482	 6482	 0.0	 0.0	 1	 -30.0	 30.0;
	10564	 4220	 0.00101	 0.00324	 0.0	 9308	 9308	 9308	 0.0	 0.0	 1	 -30.0	 30.0;
	2075	 7013	 0.00105	 0.00677	 0.0	 4611	 4611	 4611	 0.0	 0.0	 1	 -30.0	 30.0;
	2075	 5623	 0.00039	 0.00502	 0.0	 6274	 6274	 6274	 0.0	 0.0	 1	 -30.0	 30.0;
	2075	 8232	 0.0004	 0.00492	 0.0	 6400	 6400	 6400	 0.0	 0.0	 1	 -30.0	 30.0;
	2075	 8070	 0.00051	 0.00617	 0.0	 5103	 5103	 5103	 0.0	 0.0	 1	 -30.0	 30.0;
	11026	 12417	 0.0003	 0.00314	 0.0	 10015	 10015	 10015	 0.0	 0.0	 1	 -30.0	 30.0;
	11026	 5623	 0.00051	 0.00668	 0.0	 4715	 4715	 4715	 0.0	 0.0	 1	 -30.0	 30.0;
	11026	 8232	 0.0005	 0.00678	 0.0	 4647	 4647	 4647	 0.0	 0.0	 1	 -30.0	 30.0;
	1783	 3472	 0.002909	 0.017	 0.0	 1832	 1832	 1832	 0.0	 0.0	 1	 -30.0	 30.0;
	1783	 1657	 0.00245	 0.011281	 0.0	 2737	 2737	 2737	 0.0	 0.0	 1	 -30.0	 30.0;
	1783	 7203	 0.0027	 0.01532	 0.0	 2031	 2031	 2031	 0.0	 0.0	 1	 -30.0	 30.0;
	1783	 7203	 0.00105	 0.011151	 0.0	 2821	 2821	 2821	 0.0	 0.0	 1	 -30.0	 30.0;
	1783	 6632	 0.00036	 0.002669	 0.0	 11729	 11729	 11729	 0.0	 0.0	 1	 -30.0	 30.0;
	1783	 816	 0.0018	 0.011169	 0.0	 2793	 2793	 2793	 0.0	 0.0	 1	 -30.0	 30.0;
	1783	 4350	 0.000711	 0.007771	 0.0	 4048	 4048	 4048	 0.0	 0.0	 1	 -30.0	 30.0;
	1783	 11640	 0.00036	 0.00257	 0.0	 12172	 12172	 12172	 0.0	 0.0	 1	 -30.0	 30.0;
	2217	 9004	 0.00201	 0.01195	 0.0	 2607	 2607	 2607	 0.0	 0.0	 1	 -30.0	 30.0;
	2217	 7132	 0.001091	 0.00731	 0.0	 4274	 4274	 4274	 0.0	 0.0	 1	 -30.0	 30.0;
	2217	 7942	 0.00105	 0.007591	 0.0	 4122	 4122	 4122	 0.0	 0.0	 1	 -30.0	 30.0;
	2217	 13324	 0.00299	 0.02256	 0.0	 1389	 1389	 1389	 0.0	 0.0	 1	 -30.0	 30.0;
	4436	 9530	 0.00036	 0.00288	 0.0	 10884	 10884	 10884	 0.0	 0.0	 1	 -30.0	 30.0;
	2224	 6604	 0.00589	 0.045599	 0.0	 688	 688	 688	 0.0	 0.0	 1	 -30.0	 30.0;
	2224	 5251	 0.00157	 0.0127	 0.0	 2469	 2469	 2469	 0.0	 0.0	 1	 -30.0	 30.0;
	2224	 5251	 0.00168	 0.011969	 0.0	 2614	 2614	 2614	 0.0	 0.0	 1	 -30.0	 30.0;
	2224	 11608	 0.00289	 0.021031	 0.0	 1488	 1488	 1488	 0.0	 0.0	 1	 -30.0	 30.0;
	1744	 4776	 0.00395	 0.025211	 0.0	 1238	 1238	 1238	 0.0	 0.0	 1	 -30.0	 30.0;
	1744	 13448	 0.002771	 0.021659	 0.0	 1447	 1447	 1447	 0.0	 0.0	 1	 -30.0	 30.0;
	1744	 8237	 0.002979	 0.016901	 0.0	 1841	 1841	 1841	 0.0	 0.0	 1	 -30.0	 30.0;
	12498	 8605	 0.007419	 0.034021	 0.0	 908	 908	 908	 0.0	 0.0	 1	 -30.0	 30.0;
	4266	 6599	 0.00056	 0.00813	 0.0	 3877	 3877	 3877	 0.0	 0.0	 1	 -30.0	 30.0;
	6	 2590	 0.00361	 0.015211	 0.0	 2021	 2021	 2021	 0.0	 0.0	 1	 -30.0	 30.0;
	11080	 10301	 0.000409	 0.003331	 0.0	 9413	 9413	 9413	 0.0	 0.0	 1	 -30.0	 30.0;
	5968	 9694	 0.004091	 0.019599	 0.0	 1578	 1578	 1578	 0.0	 0.0	 1	 -30.0	 30.0;
	5968	 9274	 0.00294	 0.012841	 0.0	 2398	 2398	 2398	 0.0	 0.0	 1	 -30.0	 30.0;
	6497	 8183	 0.020771	 0.080479	 0.0	 381	 381	 381	 0.0	 0.0	 1	 -30.0	 30.0;
	6497	 2804	 0.00662	 0.0513	 0.0	 611	 611	 611	 0.0	 0.0	 1	 -30.0	 30.0;
	6497	 2528	 0.00607	 0.04581	 0.0	 684	 684	 684	 0.0	 0.0	 1	 -30.0	 30.0;
	4370	 4776	 0.000669	 0.0042	 0.0	 7428	 7428	 7428	 0.0	 0.0	 1	 -30.0	 30.0;
	4370	 4564	 0.001271	 0.007419	 0.0	 4197	 4197	 4197	 0.0	 0.0	 1	 -30.0	 30.0;
	4370	 8237	 0.001599	 0.012271	 0.0	 2553	 2553	 2553	 0.0	 0.0	 1	 -30.0	 30.0;
	1252	 6839	 0.009599	 0.05024	 0.0	 618	 618	 618	 0.0	 0.0	 1	 -30.0	 30.0;
	1252	 761	 0.00149	 0.009219	 0.0	 3383	 3383	 3383	 0.0	 0.0	 1	 -30.0	 30.0;
	1252	 9955	 0.01488	 0.06724	 0.0	 459	 459	 459	 0.0	 0.0	 1	 -30.0	 30.0;
	1252	 8620	 0.003599	 0.024031	 0.0	 1300	 1300	 1300	 0.0	 0.0	 1	 -30.0	 30.0;
	1252	 8620	 0.00519	 0.024	 0.0	 1287	 1287	 1287	 0.0	 0.0	 1	 -30.0	 30.0;
	5230	 12270	 0.003461	 0.013349	 0.0	 2291	 2291	 2291	 0.0	 0.0	 1	 -30.0	 30.0;
	5011	 6228	 0.00105	 0.01236	 0.0	 2547	 2547	 2547	 0.0	 0.0	 1	 -30.0	 30.0;
	5011	 6228	 0.00199	 0.012331	 0.0	 2529	 2529	 2529	 0.0	 0.0	 1	 -30.0	 30.0;
	5011	 5395	 0.00711	 0.044711	 0.0	 698	 698	 698	 0.0	 0.0	 1	 -30.0	 30.0;
	9065	 5428	 0.006729	 0.02543	 0.0	 1201	 1201	 1201	 0.0	 0.0	 1	 -30.0	 30.0;
	13382	 5428	 0.005771	 0.02999	 0.0	 1035	 1035	 1035	 0.0	 0.0	 1	 -30.0	 30.0;
	10485	 140	 0.0048	 0.021771	 0.0	 1417	 1417	 1417	 0.0	 0.0	 1	 -30.0	 30.0;
	3961	 459	 0.00286	 0.02212	 0.0	 1417	 1417	 1417	 0.0	 0.0	 1	 -30.0	 30.0;
	1039	 12376	 0.00351	 0.02175	 0.0	 1434	 1434	 1434	 0.0	 0.0	 1	 -30.0	 30.0;
	1039	 10204	 0.008401	 0.0448	 0.0	 693	 693	 693	 0.0	 0.0	 1	 -30.0	 30.0;
	9155	 13028	 0.0018	 0.01187	 0.0	 2632	 2632	 2632	 0.0	 0.0	 1	 -30.0	 30.0;
	9155	 13028	 0.001831	 0.01163	 0.0	 2683	 2683	 2683	 0.0	 0.0	 1	 -30.0	 30.0;
	12683	 4315	 0.00075	 0.00538	 0.0	 5816	 5816	 5816	 0.0	 0.0	 1	 -30.0	 30.0;
	9633	 1173	 2e-05	 0.00033	 0.0	 95544	 95544	 95544	 0.0	 0.0	 1	 -30.0	 30.0;
	9633	 12161	 1e-05	 0.00034	 0.0	 92864	 92864	 92864	 0.0	 0.0	 1	 -30.0	 30.0;
	9059	 1345	 0.00023	 0.00258	 0.0	 12195	 12195	 12195	 0.0	 0.0	 1	 -30.0	 30.0;
	9059	 2595	 0.00023	 0.00252	 0.0	 12483	 12483	 12483	 0.0	 0.0	 1	 -30.0	 30.0;
	4700	 2141	 0.002031	 0.008531	 0.0	 3602	 3602	 3602	 0.0	 0.0	 1	 -30.0	 30.0;
	4700	 10585	 0.005349	 0.020789	 0.0	 1472	 1472	 1472	 0.0	 0.0	 1	 -30.0	 30.0;
	4212	 1509	 0.0002	 0.00082	 0.0	 37425	 37425	 37425	 0.0	 0.0	 1	 -30.0	 30.0;
	5760	 10062	 0.002091	 0.011219	 0.0	 2768	 2768	 2768	 0.0	 0.0	 1	 -30.0	 30.0;
	8821	 244	 0.00262	 0.016979	 0.0	 1839	 1839	 1839	 0.0	 0.0	 1	 -30.0	 30.0;
	8821	 244	 0.002669	 0.01663	 0.0	 1876	 1876	 1876	 0.0	 0.0	 1	 -30.0	 30.0;
	13071	 13203	 0.00025	 0.00118	 0.0	 26188	 26188	 26188	 0.0	 0.0	 1	 -30.0	 30.0;
	2218	 1702	 0.00056	 0.00715	 0.0	 4405	 4405	 4405	 0.0	 0.0	 1	 -30.0	 30.0;
	5753	 5499	 0.0007	 0.00455	 0.0	 6862	 6862	 6862	 0.0	 0.0	 1	 -30.0	 30.0;
	5753	 10193	 0.000331	 0.001711	 0.0	 18126	 18126	 18126	 0.0	 0.0	 1	 -30.0	 30.0;
	5753	 10193	 0.00011	 0.000781	 0.0	 40050	 40050	 40050	 0.0	 0.0	 1	 -30.0	 30.0;
	5753	 13142	 0.00111	 0.00664	 0.0	 4693	 4693	 4693	 0.0	 0.0	 1	 -30.0	 30.0;
	11004	 12094	 0.00066	 0.00838	 0.0	 3758	 3758	 3758	 0.0	 0.0	 1	 -30.0	 30.0;
	11004	 12094	 0.00064	 0.00854	 0.0	 3689	 3689	 3689	 0.0	 0.0	 1	 -30.0	 30.0;
	3466	 11522	 0.003091	 0.017091	 0.0	 1819	 1819	 1819	 0.0	 0.0	 1	 -30.0	 30.0;
	3466	 2007	 0.00643	 0.03687	 0.0	 844	 844	 844	 0.0	 0.0	 1	 -30.0	 30.0;
	13144	 11522	 0.00275	 0.01937	 0.0	 1615	 1615	 1615	 0.0	 0.0	 1	 -30.0	 30.0;
	12376	 8620	 0.00357	 0.021289	 0.0	 1464	 1464	 1464	 0.0	 0.0	 1	 -30.0	 30.0;
	2735	 10204	 0.000289	 0.002789	 0.0	 11266	 11266	 11266	 0.0	 0.0	 1	 -30.0	 30.0;
	1607	 9709	 0.002531	 0.01345	 0.0	 2308	 2308	 2308	 0.0	 0.0	 1	 -30.0	 30.0;
	6692	 955	 0.00162	 0.012159	 0.0	 2576	 2576	 2576	 0.0	 0.0	 1	 -30.0	 30.0;
	6692	 955	 0.00262	 0.01168	 0.0	 2639	 2639	 2639	 0.0	 0.0	 1	 -30.0	 30.0;
	13078	 1657	 0.00099	 0.006081	 0.0	 5127	 5127	 5127	 0.0	 0.0	 1	 -30.0	 30.0;
	13078	 9310	 0.000909	 0.005979	 0.0	 5224	 5224	 5224	 0.0	 0.0	 1	 -30.0	 30.0;
	4953	 601	 0.00011	 0.0008	 0.0	 39117	 39117	 39117	 0.0	 0.0	 1	 -30.0	 30.0;
	4953	 10594	 0.00011	 0.00068	 0.0	 45856	 45856	 45856	 0.0	 0.0	 1	 -30.0	 30.0;
	4953	 8724	 0.00207	 0.008341	 0.0	 3676	 3676	 3676	 0.0	 0.0	 1	 -30.0	 30.0;
	5757	 3662	 0.00019	 0.001031	 0.0	 30131	 30131	 30131	 0.0	 0.0	 1	 -30.0	 30.0;
	5844	 10787	 0.014039	 0.0667	 0.0	 464	 464	 464	 0.0	 0.0	 1	 -30.0	 30.0;
	4519	 13214	 0.004961	 0.03043	 0.0	 1025	 1025	 1025	 0.0	 0.0	 1	 -30.0	 30.0;
	3850	 8360	 0.00056	 0.003531	 0.0	 8836	 8836	 8836	 0.0	 0.0	 1	 -30.0	 30.0;
	1710	 12739	 0.001461	 0.00889	 0.0	 3507	 3507	 3507	 0.0	 0.0	 1	 -30.0	 30.0;
	11163	 10341	 6e-05	 0.000419	 0.0	 74627	 74627	 74627	 0.0	 0.0	 1	 -30.0	 30.0;
	7062	 9999	 0.00139	 0.005169	 0.0	 5902	 5902	 5902	 0.0	 0.0	 1	 -30.0	 30.0;
	6081	 1859	 0.00069	 0.00825	 0.0	 3816	 3816	 3816	 0.0	 0.0	 1	 -30.0	 30.0;
	5428	 6699	 0.004969	 0.030781	 0.0	 1014	 1014	 1014	 0.0	 0.0	 1	 -30.0	 30.0;
	5428	 13138	 0.00012	 0.000969	 0.0	 32351	 32351	 32351	 0.0	 0.0	 1	 -30.0	 30.0;
	11146	 7838	 0.001091	 0.010159	 0.0	 3092	 3092	 3092	 0.0	 0.0	 1	 -30.0	 30.0;
	3981	 7838	 0.000969	 0.00887	 0.0	 3541	 3541	 3541	 0.0	 0.0	 1	 -30.0	 30.0;
	6394	 9677	 0.00099	 0.006789	 0.0	 4605	 4605	 4605	 0.0	 0.0	 1	 -30.0	 30.0;
	12055	 3560	 0.001031	 0.00586	 0.0	 5309	 5309	 5309	 0.0	 0.0	 1	 -30.0	 30.0;
	10933	 7958	 0.00401	 0.03345	 0.0	 938	 938	 938	 0.0	 0.0	 1	 -30.0	 30.0;
	4969	 7793	 9.1e-05	 0.000349	 0.0	 87580	 87580	 87580	 0.0	 0.0	 1	 -30.0	 30.0;
	894	 333	 0.00125	 0.00745	 0.0	 4182	 4182	 4182	 0.0	 0.0	 1	 -30.0	 30.0;
	11295	 5921	 0.003711	 0.024219	 0.0	 1290	 1290	 1290	 0.0	 0.0	 1	 -30.0	 30.0;
	12094	 6599	 0.00169	 0.02156	 0.0	 1461	 1461	 1461	 0.0	 0.0	 1	 -30.0	 30.0;
	12094	 6599	 0.00171	 0.02114	 0.0	 1490	 1490	 1490	 0.0	 0.0	 1	 -30.0	 30.0;
	9593	 6228	 0.00088	 0.00562	 0.0	 5553	 5553	 5553	 0.0	 0.0	 1	 -30.0	 30.0;
	9593	 6228	 0.0008	 0.00618	 0.0	 5069	 5069	 5069	 0.0	 0.0	 1	 -30.0	 30.0;
	4228	 9003	 0.00161	 0.01014	 0.0	 3077	 3077	 3077	 0.0	 0.0	 1	 -30.0	 30.0;
	5785	 3502	 0.00032	 0.002031	 0.0	 15364	 15364	 15364	 0.0	 0.0	 1	 -30.0	 30.0;
	5785	 9544	 0.00011	 0.000659	 0.0	 47279	 47279	 47279	 0.0	 0.0	 1	 -30.0	 30.0;
	2746	 5623	 0.00042	 0.00505	 0.0	 6234	 6234	 6234	 0.0	 0.0	 1	 -30.0	 30.0;
	2746	 8232	 0.00043	 0.00494	 0.0	 6371	 6371	 6371	 0.0	 0.0	 1	 -30.0	 30.0;
	7408	 7203	 0.00038	 0.000711	 0.0	 39182	 39182	 39182	 0.0	 0.0	 1	 -30.0	 30.0;
	7408	 7203	 0.00037	 0.000659	 0.0	 41796	 41796	 41796	 0.0	 0.0	 1	 -30.0	 30.0;
	6061	 2350	 0.00248	 0.03096	 0.0	 1018	 1018	 1018	 0.0	 0.0	 1	 -30.0	 30.0;
	235	 5120	 0.00375	 0.019729	 0.0	 1573	 1573	 1573	 0.0	 0.0	 1	 -30.0	 30.0;
	235	 2729	 0.00518	 0.020021	 0.0	 1528	 1528	 1528	 0.0	 0.0	 1	 -30.0	 30.0;
	11675	 11931	 0.000771	 0.003711	 0.0	 8334	 8334	 8334	 0.0	 0.0	 1	 -30.0	 30.0;
	11675	 2104	 0.00076	 0.003789	 0.0	 8174	 8174	 8174	 0.0	 0.0	 1	 -30.0	 30.0;
	3290	 5194	 0.000781	 0.00574	 0.0	 5453	 5453	 5453	 0.0	 0.0	 1	 -30.0	 30.0;
	5185	 13237	 0.00089	 0.00562	 0.0	 5552	 5552	 5552	 0.0	 0.0	 1	 -30.0	 30.0;
	2875	 13167	 0.000331	 0.001401	 0.0	 21943	 21943	 21943	 0.0	 0.0	 1	 -30.0	 30.0;
	7555	 13167	 0.000401	 0.00137	 0.0	 22129	 22129	 22129	 0.0	 0.0	 1	 -30.0	 30.0;
	11678	 7606	 0.00051	 0.003349	 0.0	 9325	 9325	 9325	 0.0	 0.0	 1	 -30.0	 30.0;
	2920	 12691	 0.000461	 0.00168	 0.0	 18132	 18132	 18132	 0.0	 0.0	 1	 -30.0	 30.0;
	2920	 12691	 0.000469	 0.00164	 0.0	 18519	 18519	 18519	 0.0	 0.0	 1	 -30.0	 30.0;
	6839	 9955	 0.006081	 0.03114	 0.0	 996	 996	 996	 0.0	 0.0	 1	 -30.0	 30.0;
	11003	 1122	 0.005831	 0.02218	 0.0	 1378	 1378	 1378	 0.0	 0.0	 1	 -30.0	 30.0;
	13289	 7567	 0.00013	 0.000461	 0.0	 65948	 65948	 65948	 0.0	 0.0	 1	 -30.0	 30.0;
	5282	 2876	 0.00013	 0.000461	 0.0	 65948	 65948	 65948	 0.0	 0.0	 1	 -30.0	 30.0;
	1228	 5921	 0.00262	 0.020289	 0.0	 1545	 1545	 1545	 0.0	 0.0	 1	 -30.0	 30.0;
	1228	 4121	 0.00164	 0.01194	 0.0	 2621	 2621	 2621	 0.0	 0.0	 1	 -30.0	 30.0;
	10787	 12978	 0.006479	 0.02845	 0.0	 1083	 1083	 1083	 0.0	 0.0	 1	 -30.0	 30.0;
	11726	 2866	 0.00294	 0.014419	 0.0	 2147	 2147	 2147	 0.0	 0.0	 1	 -30.0	 30.0;
	11726	 2866	 0.00238	 0.01463	 0.0	 2132	 2132	 2132	 0.0	 0.0	 1	 -30.0	 30.0;
	11726	 2497	 0.002219	 0.00993	 0.0	 3105	 3105	 3105	 0.0	 0.0	 1	 -30.0	 30.0;
	1984	 3285	 0.008651	 0.04886	 0.0	 637	 637	 637	 0.0	 0.0	 1	 -30.0	 30.0;
	6604	 11608	 0.00464	 0.030979	 0.0	 1009	 1009	 1009	 0.0	 0.0	 1	 -30.0	 30.0;
	8497	 661	 0.00092	 0.00889	 0.0	 3535	 3535	 3535	 0.0	 0.0	 1	 -30.0	 30.0;
	8497	 661	 0.00093	 0.00869	 0.0	 3615	 3615	 3615	 0.0	 0.0	 1	 -30.0	 30.0;
	8497	 2595	 0.0022	 0.03485	 0.0	 905	 905	 905	 0.0	 0.0	 1	 -30.0	 30.0;
	8497	 10731	 0.00074	 0.00941	 0.0	 3347	 3347	 3347	 0.0	 0.0	 1	 -30.0	 30.0;
	8497	 9409	 0.00087	 0.00884	 0.0	 3557	 3557	 3557	 0.0	 0.0	 1	 -30.0	 30.0;
	8497	 2467	 0.00139	 0.01662	 0.0	 1894	 1894	 1894	 0.0	 0.0	 1	 -30.0	 30.0;
	13448	 872	 0.002781	 0.022979	 0.0	 1365	 1365	 1365	 0.0	 0.0	 1	 -30.0	 30.0;
	9289	 7856	 0.000521	 0.00407	 0.0	 7699	 7699	 7699	 0.0	 0.0	 1	 -30.0	 30.0;
	1024	 955	 0.008479	 0.032841	 0.0	 932	 932	 932	 0.0	 0.0	 1	 -30.0	 30.0;
	588	 10966	 0.005669	 0.02901	 0.0	 1069	 1069	 1069	 0.0	 0.0	 1	 -30.0	 30.0;
	5921	 4114	 0.001031	 0.004099	 0.0	 7474	 7474	 7474	 0.0	 0.0	 1	 -30.0	 30.0;
	5921	 11837	 0.00301	 0.018719	 0.0	 1667	 1667	 1667	 0.0	 0.0	 1	 -30.0	 30.0;
	2590	 4108	 0.00257	 0.01713	 0.0	 1824	 1824	 1824	 0.0	 0.0	 1	 -30.0	 30.0;
	7811	 10327	 0.010461	 0.03836	 0.0	 795	 795	 795	 0.0	 0.0	 1	 -30.0	 30.0;
	7811	 6031	 0.001719	 0.011531	 0.0	 2710	 2710	 2710	 0.0	 0.0	 1	 -30.0	 30.0;
	7811	 7150	 9.1e-05	 0.00056	 0.0	 55676	 55676	 55676	 0.0	 0.0	 1	 -30.0	 30.0;
	5722	 5677	 0.00476	 0.025289	 0.0	 1228	 1228	 1228	 0.0	 0.0	 1	 -30.0	 30.0;
	184	 2220	 0.000219	 0.00164	 0.0	 19092	 19092	 19092	 0.0	 0.0	 1	 -30.0	 30.0;
	285	 11753	 0.002159	 0.01163	 0.0	 2671	 2671	 2671	 0.0	 0.0	 1	 -30.0	 30.0;
	285	 2220	 0.00295	 0.01539	 0.0	 2016	 2016	 2016	 0.0	 0.0	 1	 -30.0	 30.0;
	4299	 4528	 0.007789	 0.033039	 0.0	 931	 931	 931	 0.0	 0.0	 1	 -30.0	 30.0;
	10724	 4437	 0.00026	 0.0013	 0.0	 23827	 23827	 23827	 0.0	 0.0	 1	 -30.0	 30.0;
	7400	 13294	 0.00162	 0.013229	 0.0	 2371	 2371	 2371	 0.0	 0.0	 1	 -30.0	 30.0;
	4564	 872	 0.007919	 0.04194	 0.0	 741	 741	 741	 0.0	 0.0	 1	 -30.0	 30.0;
	994	 12497	 0.001229	 0.00401	 0.0	 7532	 7532	 7532	 0.0	 0.0	 1	 -30.0	 30.0;
	7517	 7985	 0.008021	 0.042831	 0.0	 725	 725	 725	 0.0	 0.0	 1	 -30.0	 30.0;
	9709	 1122	 0.007711	 0.03006	 0.0	 1018	 1018	 1018	 0.0	 0.0	 1	 -30.0	 30.0;
	9694	 1139	 0.00261	 0.015469	 0.0	 2014	 2014	 2014	 0.0	 0.0	 1	 -30.0	 30.0;
	9263	 7150	 0.00139	 0.00536	 0.0	 5705	 5705	 5705	 0.0	 0.0	 1	 -30.0	 30.0;
	9263	 7150	 0.001419	 0.00525	 0.0	 5809	 5809	 5809	 0.0	 0.0	 1	 -30.0	 30.0;
	2685	 955	 0.006289	 0.032271	 0.0	 961	 961	 961	 0.0	 0.0	 1	 -30.0	 30.0;
	2685	 3018	 0.011031	 0.05625	 0.0	 552	 552	 552	 0.0	 0.0	 1	 -30.0	 30.0;
	244	 3350	 0.001841	 0.01324	 0.0	 2364	 2364	 2364	 0.0	 0.0	 1	 -30.0	 30.0;
	4110	 14	 0.000599	 0.00186	 0.0	 16165	 16165	 16165	 0.0	 0.0	 1	 -30.0	 30.0;
	6577	 6228	 0.00036	 0.001591	 0.0	 19365	 19365	 19365	 0.0	 0.0	 1	 -30.0	 30.0;
	13203	 12739	 0.003849	 0.027651	 0.0	 1132	 1132	 1132	 0.0	 0.0	 1	 -30.0	 30.0;
	1206	 6534	 0.00186	 0.00874	 0.0	 3535	 3535	 3535	 0.0	 0.0	 1	 -30.0	 30.0;
	12417	 3090	 0.00025	 0.00285	 0.0	 11041	 11041	 11041	 0.0	 0.0	 1	 -30.0	 30.0;
	1657	 11640	 0.00207	 0.008841	 0.0	 3479	 3479	 3479	 0.0	 0.0	 1	 -30.0	 30.0;
	1657	 9310	 6e-05	 0.00039	 0.0	 80052	 80052	 80052	 0.0	 0.0	 1	 -30.0	 30.0;
	10852	 7112	 0.002159	 0.008909	 0.0	 3446	 3446	 3446	 0.0	 0.0	 1	 -30.0	 30.0;
	5937	 9310	 0.000219	 0.00039	 0.0	 70621	 70621	 70621	 0.0	 0.0	 1	 -30.0	 30.0;
	7203	 3802	 0.00011	 0.000521	 0.0	 59321	 59321	 59321	 0.0	 0.0	 1	 -30.0	 30.0;
	7203	 3802	 0.00011	 0.00049	 0.0	 62899	 62899	 62899	 0.0	 0.0	 1	 -30.0	 30.0;
	7203	 816	 0.000771	 0.003789	 0.0	 8170	 8170	 8170	 0.0	 0.0	 1	 -30.0	 30.0;
	7203	 4350	 0.000229	 0.002849	 0.0	 11052	 11052	 11052	 0.0	 0.0	 1	 -30.0	 30.0;
	11753	 7664	 0.00445	 0.027599	 0.0	 1130	 1130	 1130	 0.0	 0.0	 1	 -30.0	 30.0;
	2433	 4880	 0.00218	 0.02	 0.0	 1571	 1571	 1571	 0.0	 0.0	 1	 -30.0	 30.0;
	2433	 6905	 0.00074	 0.00865	 0.0	 3639	 3639	 3639	 0.0	 0.0	 1	 -30.0	 30.0;
	955	 1745	 0.002531	 0.019419	 0.0	 1613	 1613	 1613	 0.0	 0.0	 1	 -30.0	 30.0;
	955	 11829	 0.003	 0.01631	 0.0	 1905	 1905	 1905	 0.0	 0.0	 1	 -30.0	 30.0;
	12841	 2041	 0.008461	 0.025081	 0.0	 1194	 1194	 1194	 0.0	 0.0	 1	 -30.0	 30.0;
	11276	 4994	 0.00382	 0.013669	 0.0	 2226	 2226	 2226	 0.0	 0.0	 1	 -30.0	 30.0;
	4528	 12497	 0.002581	 0.01814	 0.0	 1724	 1724	 1724	 0.0	 0.0	 1	 -30.0	 30.0;
	9849	 941	 0.00201	 0.012219	 0.0	 2551	 2551	 2551	 0.0	 0.0	 1	 -30.0	 30.0;
	13167	 6320	 0.00087	 0.001599	 0.0	 17353	 17353	 17353	 0.0	 0.0	 1	 -30.0	 30.0;
	1113	 7631	 0.00455	 0.02394	 0.0	 1297	 1297	 1297	 0.0	 0.0	 1	 -30.0	 30.0;
	2804	 8629	 0.005651	 0.041771	 0.0	 750	 750	 750	 0.0	 0.0	 1	 -30.0	 30.0;
	13326	 5877	 0.00069	 0.001271	 0.0	 21842	 21842	 21842	 0.0	 0.0	 1	 -30.0	 30.0;
	2740	 12386	 0.00068	 0.00269	 0.0	 11385	 11385	 11385	 0.0	 0.0	 1	 -30.0	 30.0;
	2740	 2878	 0.00036	 0.00261	 0.0	 11989	 11989	 11989	 0.0	 0.0	 1	 -30.0	 30.0;
	2740	 12210	 0.001669	 0.012031	 0.0	 2601	 2601	 2601	 0.0	 0.0	 1	 -30.0	 30.0;
	6943	 5395	 0.009669	 0.03513	 0.0	 867	 867	 867	 0.0	 0.0	 1	 -30.0	 30.0;
	6943	 12497	 0.001099	 0.00862	 0.0	 3636	 3636	 3636	 0.0	 0.0	 1	 -30.0	 30.0;
	1127	 2350	 0.0005	 0.00711	 0.0	 4432	 4432	 4432	 0.0	 0.0	 1	 -30.0	 30.0;
	9274	 1445	 0.003919	 0.017781	 0.0	 1735	 1735	 1735	 0.0	 0.0	 1	 -30.0	 30.0;
	9274	 13294	 0.00161	 0.019781	 0.0	 1592	 1592	 1592	 0.0	 0.0	 1	 -30.0	 30.0;
	9274	 1139	 0.0007	 0.01256	 0.0	 2512	 2512	 2512	 0.0	 0.0	 1	 -30.0	 30.0;
	7321	 7856	 0.000409	 0.0018	 0.0	 17113	 17113	 17113	 0.0	 0.0	 1	 -30.0	 30.0;
	2432	 7219	 2e-05	 0.00043	 0.0	 73380	 73380	 73380	 0.0	 0.0	 1	 -30.0	 30.0;
	13529	 7219	 3e-05	 0.0004	 0.0	 78748	 78748	 78748	 0.0	 0.0	 1	 -30.0	 30.0;
	422	 13544	 0.00968	 0.056659	 0.0	 550	 550	 550	 0.0	 0.0	 1	 -30.0	 30.0;
	11837	 5395	 0.003969	 0.02925	 0.0	 1071	 1071	 1071	 0.0	 0.0	 1	 -30.0	 30.0;
	8309	 13294	 0.00219	 0.01468	 0.0	 2129	 2129	 2129	 0.0	 0.0	 1	 -30.0	 30.0;
	8309	 12484	 0.000401	 0.003159	 0.0	 9920	 9920	 9920	 0.0	 0.0	 1	 -30.0	 30.0;
	8309	 10048	 0.000531	 0.003	 0.0	 10368	 10368	 10368	 0.0	 0.0	 1	 -30.0	 30.0;
	7606	 10645	 0.00136	 0.00576	 0.0	 5338	 5338	 5338	 0.0	 0.0	 1	 -30.0	 30.0;
	13028	 13294	 0.000849	 0.006289	 0.0	 4978	 4978	 4978	 0.0	 0.0	 1	 -30.0	 30.0;
	13028	 13294	 0.000841	 0.006409	 0.0	 4887	 4887	 4887	 0.0	 0.0	 1	 -30.0	 30.0;
	13028	 13294	 0.00045	 0.00506	 0.0	 6219	 6219	 6219	 0.0	 0.0	 1	 -30.0	 30.0;
	321	 5028	 0.003669	 0.02988	 0.0	 1050	 1050	 1050	 0.0	 0.0	 1	 -30.0	 30.0;
	761	 8620	 0.002	 0.01568	 0.0	 1999	 1999	 1999	 0.0	 0.0	 1	 -30.0	 30.0;
	3802	 3009	 0.00031	 0.0008	 0.0	 36817	 36817	 36817	 0.0	 0.0	 1	 -30.0	 30.0;
	1725	 7631	 0.00043	 0.00038	 0.0	 55045	 55045	 55045	 0.0	 0.0	 1	 -30.0	 30.0;
	10217	 8724	 0.00043	 0.002229	 0.0	 13915	 13915	 13915	 0.0	 0.0	 1	 -30.0	 30.0;
	7604	 8724	 0.00049	 0.00218	 0.0	 14137	 14137	 14137	 0.0	 0.0	 1	 -30.0	 30.0;
	5395	 9999	 0.00282	 0.01844	 0.0	 1694	 1694	 1694	 0.0	 0.0	 1	 -30.0	 30.0;
	1242	 2041	 0.00462	 0.014849	 0.0	 2032	 2032	 2032	 0.0	 0.0	 1	 -30.0	 30.0;
	7515	 4880	 0.00263	 0.04076	 0.0	 774	 774	 774	 0.0	 0.0	 1	 -30.0	 30.0;
	5120	 3502	 0.01062	 0.056719	 0.0	 548	 548	 548	 0.0	 0.0	 1	 -30.0	 30.0;
	6057	 4439	 0.0001	 0.00105	 0.0	 29948	 29948	 29948	 0.0	 0.0	 1	 -30.0	 30.0;
	12691	 13125	 0.00239	 0.017341	 0.0	 1805	 1805	 1805	 0.0	 0.0	 1	 -30.0	 30.0;
	5132	 3602	 0.001341	 0.010581	 0.0	 2962	 2962	 2962	 0.0	 0.0	 1	 -30.0	 30.0;
	5132	 8987	 0.00101	 0.007599	 0.0	 4121	 4121	 4121	 0.0	 0.0	 1	 -30.0	 30.0;
	592	 2259	 0.00011	 0.000289	 0.0	 102150	 102150	 102150	 0.0	 0.0	 1	 -30.0	 30.0;
	10294	 6599	 0.00146	 0.01769	 0.0	 1780	 1780	 1780	 0.0	 0.0	 1	 -30.0	 30.0;
	10294	 6599	 0.0013	 0.02004	 0.0	 1573	 1573	 1573	 0.0	 0.0	 1	 -30.0	 30.0;
	9955	 8105	 0.007909	 0.028349	 0.0	 1074	 1074	 1074	 0.0	 0.0	 1	 -30.0	 30.0;
	10842	 3527	 0.00012	 0.00049	 0.0	 62614	 62614	 62614	 0.0	 0.0	 1	 -30.0	 30.0;
	10842	 3527	 0.00012	 0.000479	 0.0	 63968	 63968	 63968	 0.0	 0.0	 1	 -30.0	 30.0;
	6599	 634	 0.00076	 0.01018	 0.0	 3095	 3095	 3095	 0.0	 0.0	 1	 -30.0	 30.0;
	6599	 634	 0.0009	 0.00865	 0.0	 3633	 3633	 3633	 0.0	 0.0	 1	 -30.0	 30.0;
	6599	 634	 0.00096	 0.01294	 0.0	 2435	 2435	 2435	 0.0	 0.0	 1	 -30.0	 30.0;
	6599	 634	 0.0004	 0.00756	 0.0	 4173	 4173	 4173	 0.0	 0.0	 1	 -30.0	 30.0;
	6599	 634	 0.00039	 0.00771	 0.0	 4092	 4092	 4092	 0.0	 0.0	 1	 -30.0	 30.0;
	6599	 4439	 0.00163	 0.02291	 0.0	 1376	 1376	 1376	 0.0	 0.0	 1	 -30.0	 30.0;
	4246	 4511	 0.00636	 0.03855	 0.0	 809	 809	 809	 0.0	 0.0	 1	 -30.0	 30.0;
	4246	 4511	 0.00639	 0.03863	 0.0	 807	 807	 807	 0.0	 0.0	 1	 -30.0	 30.0;
	1345	 2467	 0.00113	 0.01362	 0.0	 2312	 2312	 2312	 0.0	 0.0	 1	 -30.0	 30.0;
	2528	 7861	 0.00861	 0.05318	 0.0	 587	 587	 587	 0.0	 0.0	 1	 -30.0	 30.0;
	6854	 2392	 0.0012	 0.004669	 0.0	 6553	 6553	 6553	 0.0	 0.0	 1	 -30.0	 30.0;
	6854	 10341	 0.00018	 0.001091	 0.0	 28567	 28567	 28567	 0.0	 0.0	 1	 -30.0	 30.0;
	1745	 11829	 0.001401	 0.00612	 0.0	 5032	 5032	 5032	 0.0	 0.0	 1	 -30.0	 30.0;
	169	 333	 0.00068	 0.00387	 0.0	 8039	 8039	 8039	 0.0	 0.0	 1	 -30.0	 30.0;
	8318	 7758	 0.0043	 0.033591	 0.0	 933	 933	 933	 0.0	 0.0	 1	 -30.0	 30.0;
	5251	 7958	 0.003039	 0.01911	 0.0	 1633	 1633	 1633	 0.0	 0.0	 1	 -30.0	 30.0;
	4730	 178	 6e-05	 0.00111	 0.0	 28416	 28416	 28416	 0.0	 0.0	 1	 -30.0	 30.0;
	10310	 7008	 5e-05	 0.001091	 0.0	 28923	 28923	 28923	 0.0	 0.0	 1	 -30.0	 30.0;
	3428	 4822	 3.9e-05	 0.00089	 0.0	 35458	 35458	 35458	 0.0	 0.0	 1	 -30.0	 30.0;
	2710	 6572	 3.9e-05	 0.000901	 0.0	 35026	 35026	 35026	 0.0	 0.0	 1	 -30.0	 30.0;
	990	 6534	 0.000169	 0.00111	 0.0	 28133	 28133	 28133	 0.0	 0.0	 1	 -30.0	 30.0;
	1422	 7112	 0.000331	 0.0027	 0.0	 11613	 11613	 11613	 0.0	 0.0	 1	 -30.0	 30.0;
	9411	 2866	 0.00026	 0.00369	 0.0	 8540	 8540	 8540	 0.0	 0.0	 1	 -30.0	 30.0;
	2392	 10341	 0.000341	 0.00274	 0.0	 11440	 11440	 11440	 0.0	 0.0	 1	 -30.0	 30.0;
	7787	 10966	 0.00038	 0.00506	 0.0	 6226	 6226	 6226	 0.0	 0.0	 1	 -30.0	 30.0;
	3502	 9544	 0.00012	 0.000831	 0.0	 37622	 37622	 37622	 0.0	 0.0	 1	 -30.0	 30.0;
	1598	 872	 0.003031	 0.0123	 0.0	 2494	 2494	 2494	 0.0	 0.0	 1	 -30.0	 30.0;
	6955	 11424	 0.001521	 0.00774	 0.0	 4005	 4005	 4005	 0.0	 0.0	 1	 -30.0	 30.0;
	7219	 6187	 0.00059	 0.00552	 0.0	 5690	 5690	 5690	 0.0	 0.0	 1	 -30.0	 30.0;
	7219	 1702	 0.00053	 0.00625	 0.0	 5036	 5036	 5036	 0.0	 0.0	 1	 -30.0	 30.0;
	8724	 13022	 0.00143	 0.01076	 0.0	 2911	 2911	 2911	 0.0	 0.0	 1	 -30.0	 30.0;
	2564	 12512	 0.00056	 0.00593	 0.0	 5304	 5304	 5304	 0.0	 0.0	 1	 -30.0	 30.0;
	3540	 9003	 0.00205	 0.01461	 0.0	 2142	 2142	 2142	 0.0	 0.0	 1	 -30.0	 30.0;
	3018	 3285	 0.01068	 0.054521	 0.0	 569	 569	 569	 0.0	 0.0	 1	 -30.0	 30.0;
	13294	 12484	 0.00194	 0.011039	 0.0	 2819	 2819	 2819	 0.0	 0.0	 1	 -30.0	 30.0;
	13294	 10048	 0.00131	 0.010099	 0.0	 3102	 3102	 3102	 0.0	 0.0	 1	 -30.0	 30.0;
	13294	 4315	 0.001289	 0.014229	 0.0	 2211	 2211	 2211	 0.0	 0.0	 1	 -30.0	 30.0;
	7229	 4672	 0.00455	 0.027031	 0.0	 1153	 1153	 1153	 0.0	 0.0	 1	 -30.0	 30.0;
	7229	 4851	 0.00239	 0.01414	 0.0	 2203	 2203	 2203	 0.0	 0.0	 1	 -30.0	 30.0;
	7229	 5545	 0.004039	 0.029669	 0.0	 1055	 1055	 1055	 0.0	 0.0	 1	 -30.0	 30.0;
	7229	 5028	 0.001099	 0.007771	 0.0	 4025	 4025	 4025	 0.0	 0.0	 1	 -30.0	 30.0;
	7838	 2878	 0.00082	 0.00762	 0.0	 4122	 4122	 4122	 0.0	 0.0	 1	 -30.0	 30.0;
	7838	 6047	 0.000719	 0.0033	 0.0	 9353	 9353	 9353	 0.0	 0.0	 1	 -30.0	 30.0;
	7838	 8030	 0.000599	 0.00361	 0.0	 8632	 8632	 8632	 0.0	 0.0	 1	 -30.0	 30.0;
	7838	 12210	 0.000521	 0.004039	 0.0	 7757	 7757	 7757	 0.0	 0.0	 1	 -30.0	 30.0;
	7838	 7567	 0.000901	 0.0088	 0.0	 3571	 3571	 3571	 0.0	 0.0	 1	 -30.0	 30.0;
	10989	 10214	 0.000781	 0.00306	 0.0	 10003	 10003	 10003	 0.0	 0.0	 1	 -30.0	 30.0;
	10989	 3444	 0.000419	 0.00399	 0.0	 7874	 7874	 7874	 0.0	 0.0	 1	 -30.0	 30.0;
	10989	 2876	 0.000841	 0.009841	 0.0	 3199	 3199	 3199	 0.0	 0.0	 1	 -30.0	 30.0;
	9484	 8987	 0.004021	 0.03064	 0.0	 1023	 1023	 1023	 0.0	 0.0	 1	 -30.0	 30.0;
	7112	 10193	 0.0023	 0.009031	 0.0	 3390	 3390	 3390	 0.0	 0.0	 1	 -30.0	 30.0;
	7112	 10193	 0.002081	 0.009469	 0.0	 3259	 3259	 3259	 0.0	 0.0	 1	 -30.0	 30.0;
	7112	 8007	 0.00164	 0.008831	 0.0	 3517	 3517	 3517	 0.0	 0.0	 1	 -30.0	 30.0;
	7112	 13142	 0.00094	 0.00488	 0.0	 6356	 6356	 6356	 0.0	 0.0	 1	 -30.0	 30.0;
	7112	 13481	 0.000901	 0.00551	 0.0	 5658	 5658	 5658	 0.0	 0.0	 1	 -30.0	 30.0;
	7112	 13092	 0.00051	 0.005961	 0.0	 5280	 5280	 5280	 0.0	 0.0	 1	 -30.0	 30.0;
	2866	 2497	 0.00113	 0.004349	 0.0	 7030	 7030	 7030	 0.0	 0.0	 1	 -30.0	 30.0;
	2104	 9674	 0.002081	 0.013031	 0.0	 2394	 2394	 2394	 0.0	 0.0	 1	 -30.0	 30.0;
	1158	 6736	 0.00116	 0.01438	 0.0	 2190	 2190	 2190	 0.0	 0.0	 1	 -30.0	 30.0;
	12805	 6929	 0.00013	 0.001031	 0.0	 30397	 30397	 30397	 0.0	 0.0	 1	 -30.0	 30.0;
	6031	 896	 0.00036	 0.002659	 0.0	 11773	 11773	 11773	 0.0	 0.0	 1	 -30.0	 30.0;
	9999	 7856	 0.000771	 0.004539	 0.0	 6861	 6861	 6861	 0.0	 0.0	 1	 -30.0	 30.0;
	4808	 6001	 0.011902	 0.04088	 0.0	 742	 742	 742	 0.0	 0.0	 1	 -30.0	 30.0;
	252	 4808	 0.002231	 0.010138	 0.0	 3043	 3043	 3043	 0.0	 0.0	 1	 -30.0	 30.0;
	1639	 237	 0.00023	 0.0025	 0.0	 12582	 12582	 12582	 0.0	 0.0	 1	 -30.0	 30.0;
	1639	 237	 0.00023	 0.00254	 0.0	 12386	 12386	 12386	 0.0	 0.0	 1	 -30.0	 30.0;
	7298	 1639	 0.00179	 0.01478	 0.0	 2549	 2549	 2549	 0.0	 0.0	 1	 -30.0	 30.0;
	7298	 1639	 0.00183	 0.01446	 0.0	 2603	 2603	 2603	 0.0	 0.0	 1	 -30.0	 30.0;
	1639	 2194	 0.00031	 0.00312	 0.0	 10075	 10075	 10075	 0.0	 0.0	 1	 -30.0	 30.0;
	1523	 1639	 0.00031	 0.00289	 0.0	 10868	 10868	 10868	 0.0	 0.0	 1	 -30.0	 30.0;
	1283	 1639	 0.00021	 0.00194	 0.0	 16188	 16188	 16188	 0.0	 0.0	 1	 -30.0	 30.0;
	9626	 11157	 0.001489	 0.006249	 0.0	 4918	 4918	 4918	 0.0	 0.0	 1	 -30.0	 30.0;
	11343	 11157	 0.010209	 0.042502	 0.0	 723	 723	 723	 0.0	 0.0	 1	 -30.0	 30.0;
	9626	 9463	 0.001462	 0.006369	 0.0	 4834	 4834	 4834	 0.0	 0.0	 1	 -30.0	 30.0;
	9463	 12239	 0.0048	 0.01772	 0.0	 1721	 1721	 1721	 0.0	 0.0	 1	 -30.0	 30.0;
	9626	 8365	 0.00328	 0.01472	 0.0	 2095	 2095	 2095	 0.0	 0.0	 1	 -30.0	 30.0;
	675	 9626	 0.0	 0.000271	 0.0	 116559	 116559	 116559	 0.0	 0.0	 1	 -30.0	 30.0;
	12239	 9626	 0.002031	 0.007591	 0.0	 4020	 4020	 4020	 0.0	 0.0	 1	 -30.0	 30.0;
	6077	 10086	 0.00372	 0.014431	 0.0	 2120	 2120	 2120	 0.0	 0.0	 1	 -30.0	 30.0;
	5652	 6077	 0.0	 0.000271	 0.0	 116559	 116559	 116559	 0.0	 0.0	 1	 -30.0	 30.0;
	6077	 6701	 0.00108	 0.003698	 0.0	 8200	 8200	 8200	 0.0	 0.0	 1	 -30.0	 30.0;
	6077	 13319	 0.000431	 0.001658	 0.0	 18439	 18439	 18439	 0.0	 0.0	 1	 -30.0	 30.0;
	10086	 4731	 0.000782	 0.002662	 0.0	 11385	 11385	 11385	 0.0	 0.0	 1	 -30.0	 30.0;
	8365	 914	 0.001729	 0.005498	 0.0	 5481	 5481	 5481	 0.0	 0.0	 1	 -30.0	 30.0;
	11701	 2753	 0.00221	 0.01891	 0.0	 1975	 1975	 1975	 0.0	 0.0	 1	 -30.0	 30.0;
	12028	 2753	 0.00335	 0.03107	 0.0	 1203	 1203	 1203	 0.0	 0.0	 1	 -30.0	 30.0;
	2753	 642	 0.00109	 0.01324	 0.0	 2830	 2830	 2830	 0.0	 0.0	 1	 -30.0	 30.0;
	3087	 4118	 0.027218	 0.118858	 0.0	 260	 260	 260	 0.0	 0.0	 1	 -30.0	 30.0;
	9293	 3087	 0.002782	 0.010778	 0.0	 2838	 2838	 2838	 0.0	 0.0	 1	 -30.0	 30.0;
	3087	 3703	 0.03336	 0.110049	 0.0	 275	 275	 275	 0.0	 0.0	 1	 -30.0	 30.0;
	3087	 3703	 0.02972	 0.124729	 0.0	 247	 247	 247	 0.0	 0.0	 1	 -30.0	 30.0;
	3087	 13618	 0.00244	 0.009351	 0.0	 3269	 3269	 3269	 0.0	 0.0	 1	 -30.0	 30.0;
	3087	 13618	 0.002151	 0.009649	 0.0	 3196	 3196	 3196	 0.0	 0.0	 1	 -30.0	 30.0;
	3087	 13618	 0.00244	 0.009458	 0.0	 3234	 3234	 3234	 0.0	 0.0	 1	 -30.0	 30.0;
	9433	 8446	 0.017102	 0.080911	 0.0	 382	 382	 382	 0.0	 0.0	 1	 -30.0	 30.0;
	3512	 9433	 0.030871	 0.129529	 0.0	 238	 238	 238	 0.0	 0.0	 1	 -30.0	 30.0;
	9433	 2678	 0.008778	 0.041551	 0.0	 744	 744	 744	 0.0	 0.0	 1	 -30.0	 30.0;
	9433	 2678	 0.008591	 0.038471	 0.0	 802	 802	 802	 0.0	 0.0	 1	 -30.0	 30.0;
	9433	 2678	 0.01032	 0.038049	 0.0	 802	 802	 802	 0.0	 0.0	 1	 -30.0	 30.0;
	9433	 1014	 0.004151	 0.017409	 0.0	 1765	 1765	 1765	 0.0	 0.0	 1	 -30.0	 30.0;
	9433	 1014	 0.004062	 0.017751	 0.0	 1735	 1735	 1735	 0.0	 0.0	 1	 -30.0	 30.0;
	11444	 8932	 0.000338	 0.00156	 0.0	 19790	 19790	 19790	 0.0	 0.0	 1	 -30.0	 30.0;
	12617	 8932	 0.002689	 0.010018	 0.0	 3046	 3046	 3046	 0.0	 0.0	 1	 -30.0	 30.0;
	8932	 6345	 0.020471	 0.070289	 0.0	 432	 432	 432	 0.0	 0.0	 1	 -30.0	 30.0;
	5873	 4232	 4e-05	 0.000271	 0.0	 115310	 115310	 115310	 0.0	 0.0	 1	 -30.0	 30.0;
	7419	 5873	 0.023289	 0.097751	 0.0	 315	 315	 315	 0.0	 0.0	 1	 -30.0	 30.0;
	6677	 4232	 0.005969	 0.02292	 0.0	 1334	 1334	 1334	 0.0	 0.0	 1	 -30.0	 30.0;
	1312	 4232	 0.00428	 0.019138	 0.0	 1611	 1611	 1611	 0.0	 0.0	 1	 -30.0	 30.0;
	3645	 12617	 0.01588	 0.054529	 0.0	 557	 557	 557	 0.0	 0.0	 1	 -30.0	 30.0;
	9255	 6247	 0.0	 0.000271	 0.0	 116559	 116559	 116559	 0.0	 0.0	 1	 -30.0	 30.0;
	6247	 4487	 0.00368	 0.007311	 0.0	 3860	 3860	 3860	 0.0	 0.0	 1	 -30.0	 30.0;
	10344	 6247	 0.006369	 0.0324	 0.0	 957	 957	 957	 0.0	 0.0	 1	 -30.0	 30.0;
	1444	 6247	 0.000791	 0.003569	 0.0	 8641	 8641	 8641	 0.0	 0.0	 1	 -30.0	 30.0;
	6126	 6247	 0.000809	 0.003431	 0.0	 8961	 8961	 8961	 0.0	 0.0	 1	 -30.0	 30.0;
	4487	 8617	 0.008871	 0.004431	 0.0	 3186	 3186	 3186	 0.0	 0.0	 1	 -30.0	 30.0;
	13528	 7973	 0.0	 0.000271	 0.0	 116559	 116559	 116559	 0.0	 0.0	 1	 -30.0	 30.0;
	9798	 5047	 0.0	 0.000271	 0.0	 116559	 116559	 116559	 0.0	 0.0	 1	 -30.0	 30.0;
	11397	 5526	 0.0	 0.000271	 0.0	 116559	 116559	 116559	 0.0	 0.0	 1	 -30.0	 30.0;
	3873	 1312	 0.0	 0.000271	 0.0	 116559	 116559	 116559	 0.0	 0.0	 1	 -30.0	 30.0;
	911	 6565	 0.0	 0.000271	 0.0	 116559	 116559	 116559	 0.0	 0.0	 1	 -30.0	 30.0;
	1374	 11610	 0.0	 0.000271	 0.0	 116559	 116559	 116559	 0.0	 0.0	 1	 -30.0	 30.0;
	12941	 6568	 0.00096	 0.003391	 0.0	 8963	 8963	 8963	 0.0	 0.0	 1	 -30.0	 30.0;
	2773	 6568	 0.0	 0.000271	 0.0	 116559	 116559	 116559	 0.0	 0.0	 1	 -30.0	 30.0;
	6568	 9371	 0.004471	 0.021831	 0.0	 1418	 1418	 1418	 0.0	 0.0	 1	 -30.0	 30.0;
	6568	 5098	 0.00624	 0.03	 0.0	 1031	 1031	 1031	 0.0	 0.0	 1	 -30.0	 30.0;
	4840	 7947	 0.0008	 0.0038	 0.0	 8135	 8135	 8135	 0.0	 0.0	 1	 -30.0	 30.0;
	252	 4840	 0.010058	 0.035969	 0.0	 846	 846	 846	 0.0	 0.0	 1	 -30.0	 30.0;
	13183	 7947	 0.000782	 0.00352	 0.0	 8761	 8761	 8761	 0.0	 0.0	 1	 -30.0	 30.0;
	8650	 13183	 0.008471	 0.040089	 0.0	 771	 771	 771	 0.0	 0.0	 1	 -30.0	 30.0;
	11379	 8575	 0.00038	 0.00312	 0.0	 11961	 11961	 11961	 0.0	 0.0	 1	 -30.0	 30.0;
	11379	 8575	 0.00038	 0.00305	 0.0	 12231	 12231	 12231	 0.0	 0.0	 1	 -30.0	 30.0;
	884	 11379	 0.00255	 0.02375	 0.0	 1574	 1574	 1574	 0.0	 0.0	 1	 -30.0	 30.0;
	884	 11379	 0.0026	 0.02326	 0.0	 1607	 1607	 1607	 0.0	 0.0	 1	 -30.0	 30.0;
	11379	 8853	 0.00268	 0.03039	 0.0	 1233	 1233	 1233	 0.0	 0.0	 1	 -30.0	 30.0;
	11379	 8853	 0.00262	 0.02814	 0.0	 1331	 1331	 1331	 0.0	 0.0	 1	 -30.0	 30.0;
	3896	 12046	 0.000258	 0.000929	 0.0	 32762	 32762	 32762	 0.0	 0.0	 1	 -30.0	 30.0;
	4579	 12046	 0.003049	 0.013911	 0.0	 2219	 2219	 2219	 0.0	 0.0	 1	 -30.0	 30.0;
	3896	 8381	 0.000258	 0.000911	 0.0	 33362	 33362	 33362	 0.0	 0.0	 1	 -30.0	 30.0;
	11559	 8381	 0.000871	 0.003991	 0.0	 7733	 7733	 7733	 0.0	 0.0	 1	 -30.0	 30.0;
	8049	 4824	 0.024218	 0.1016	 0.0	 303	 303	 303	 0.0	 0.0	 1	 -30.0	 30.0;
	4824	 10042	 0.0	 0.000271	 0.0	 116559	 116559	 116559	 0.0	 0.0	 1	 -30.0	 30.0;
	3006	 3247	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	8049	 3006	 0.02372	 0.103591	 0.0	 298	 298	 298	 0.0	 0.0	 1	 -30.0	 30.0;
	3006	 10279	 0.0	 0.000271	 0.0	 116559	 116559	 116559	 0.0	 0.0	 1	 -30.0	 30.0;
	13554	 3247	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	237	 4835	 0.00038	 0.00396	 0.0	 7941	 7941	 7941	 0.0	 0.0	 1	 -30.0	 30.0;
	237	 4835	 0.00038	 0.00404	 0.0	 7785	 7785	 7785	 0.0	 0.0	 1	 -30.0	 30.0;
	237	 4835	 0.00042	 0.0036	 0.0	 8716	 8716	 8716	 0.0	 0.0	 1	 -30.0	 30.0;
	237	 4835	 0.00043	 0.00352	 0.0	 8908	 8908	 8908	 0.0	 0.0	 1	 -30.0	 30.0;
	7298	 237	 0.00177	 0.01845	 0.0	 2047	 2047	 2047	 0.0	 0.0	 1	 -30.0	 30.0;
	11610	 5564	 0.007831	 0.035089	 0.0	 879	 879	 879	 0.0	 0.0	 1	 -30.0	 30.0;
	11610	 10760	 0.002089	 0.007182	 0.0	 4224	 4224	 4224	 0.0	 0.0	 1	 -30.0	 30.0;
	7510	 5564	 0.008871	 0.034391	 0.0	 890	 890	 890	 0.0	 0.0	 1	 -30.0	 30.0;
	7510	 1991	 0.002129	 0.007031	 0.0	 4300	 4300	 4300	 0.0	 0.0	 1	 -30.0	 30.0;
	2911	 7510	 0.007222	 0.032831	 0.0	 940	 940	 940	 0.0	 0.0	 1	 -30.0	 30.0;
	7510	 11277	 0.006049	 0.021431	 0.0	 1419	 1419	 1419	 0.0	 0.0	 1	 -30.0	 30.0;
	4073	 12941	 0.0114	 0.005622	 0.0	 2486	 2486	 2486	 0.0	 0.0	 1	 -30.0	 30.0;
	4101	 3639	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	3639	 13173	 0.00976	 0.043991	 0.0	 701	 701	 701	 0.0	 0.0	 1	 -30.0	 30.0;
	5398	 1951	 0.017658	 0.0684	 0.0	 448	 448	 448	 0.0	 0.0	 1	 -30.0	 30.0;
	5398	 1951	 0.018	 0.067	 0.0	 456	 456	 456	 0.0	 0.0	 1	 -30.0	 30.0;
	1951	 11375	 0.003378	 0.009631	 0.0	 3095	 3095	 3095	 0.0	 0.0	 1	 -30.0	 30.0;
	1951	 7684	 0.016409	 0.07168	 0.0	 430	 430	 430	 0.0	 0.0	 1	 -30.0	 30.0;
	1951	 1941	 0.0182	 0.04612	 0.0	 638	 638	 638	 0.0	 0.0	 1	 -30.0	 30.0;
	1951	 4496	 0.004818	 0.017231	 0.0	 1766	 1766	 1766	 0.0	 0.0	 1	 -30.0	 30.0;
	10956	 7520	 0.000209	 0.000911	 0.0	 33796	 33796	 33796	 0.0	 0.0	 1	 -30.0	 30.0;
	10956	 3829	 0.000249	 0.000831	 0.0	 36412	 36412	 36412	 0.0	 0.0	 1	 -30.0	 30.0;
	12767	 7285	 0.00136	 0.006458	 0.0	 4787	 4787	 4787	 0.0	 0.0	 1	 -30.0	 30.0;
	7285	 7006	 0.002782	 0.013129	 0.0	 2354	 2354	 2354	 0.0	 0.0	 1	 -30.0	 30.0;
	9132	 2596	 0.008049	 0.036031	 0.0	 856	 856	 856	 0.0	 0.0	 1	 -30.0	 30.0;
	2596	 3818	 0.022311	 0.0864	 0.0	 354	 354	 354	 0.0	 0.0	 1	 -30.0	 30.0;
	974	 2170	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	9132	 2170	 0.00912	 0.035311	 0.0	 867	 867	 867	 0.0	 0.0	 1	 -30.0	 30.0;
	2170	 1719	 0.001471	 0.005489	 0.0	 5559	 5559	 5559	 0.0	 0.0	 1	 -30.0	 30.0;
	10587	 12770	 0.00058	 0.00639	 0.0	 5859	 5859	 5859	 0.0	 0.0	 1	 -30.0	 30.0;
	10587	 12770	 0.00057	 0.00651	 0.0	 5753	 5753	 5753	 0.0	 0.0	 1	 -30.0	 30.0;
	7496	 5871	 0.002111	 0.007542	 0.0	 4034	 4034	 4034	 0.0	 0.0	 1	 -30.0	 30.0;
	1713	 5871	 0.014049	 0.037031	 0.0	 798	 798	 798	 0.0	 0.0	 1	 -30.0	 30.0;
	393	 3896	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	393	 9903	 0.002071	 0.005609	 0.0	 5283	 5283	 5283	 0.0	 0.0	 1	 -30.0	 30.0;
	2805	 393	 0.00368	 0.016711	 0.0	 1846	 1846	 1846	 0.0	 0.0	 1	 -30.0	 30.0;
	2805	 393	 0.0036	 0.017018	 0.0	 1816	 1816	 1816	 0.0	 0.0	 1	 -30.0	 30.0;
	393	 11929	 0.00012	 0.000431	 0.0	 70604	 70604	 70604	 0.0	 0.0	 1	 -30.0	 30.0;
	3896	 10832	 0.00012	 0.000431	 0.0	 70604	 70604	 70604	 0.0	 0.0	 1	 -30.0	 30.0;
	7973	 8617	 0.01328	 0.031071	 0.0	 935	 935	 935	 0.0	 0.0	 1	 -30.0	 30.0;
	12426	 7973	 0.031911	 0.071711	 0.0	 403	 403	 403	 0.0	 0.0	 1	 -30.0	 30.0;
	9077	 5047	 0.000382	 0.001289	 0.0	 23496	 23496	 23496	 0.0	 0.0	 1	 -30.0	 30.0;
	2805	 9077	 0.002582	 0.00988	 0.0	 3094	 3094	 3094	 0.0	 0.0	 1	 -30.0	 30.0;
	3733	 5526	 0.00036	 0.001218	 0.0	 24871	 24871	 24871	 0.0	 0.0	 1	 -30.0	 30.0;
	3263	 3733	 0.002458	 0.00908	 0.0	 3358	 3358	 3358	 0.0	 0.0	 1	 -30.0	 30.0;
	10122	 8913	 0.000911	 0.003271	 0.0	 9303	 9303	 9303	 0.0	 0.0	 1	 -30.0	 30.0;
	252	 10122	 0.01436	 0.05344	 0.0	 571	 571	 571	 0.0	 0.0	 1	 -30.0	 30.0;
	230	 4148	 0.000462	 0.001631	 0.0	 18634	 18634	 18634	 0.0	 0.0	 1	 -30.0	 30.0;
	230	 8913	 0.000929	 0.0032	 0.0	 9480	 9480	 9480	 0.0	 0.0	 1	 -30.0	 30.0;
	12244	 4148	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	9173	 4148	 0.013391	 0.060849	 0.0	 507	 507	 507	 0.0	 0.0	 1	 -30.0	 30.0;
	1312	 7335	 0.010631	 0.048342	 0.0	 639	 639	 639	 0.0	 0.0	 1	 -30.0	 30.0;
	8446	 4829	 0.005498	 0.021302	 0.0	 1436	 1436	 1436	 0.0	 0.0	 1	 -30.0	 30.0;
	4829	 13318	 0.001449	 0.006329	 0.0	 4866	 4866	 4866	 0.0	 0.0	 1	 -30.0	 30.0;
	1191	 13187	 0.007951	 0.029329	 0.0	 1040	 1040	 1040	 0.0	 0.0	 1	 -30.0	 30.0;
	1191	 2678	 0.02072	 0.086938	 0.0	 354	 354	 354	 0.0	 0.0	 1	 -30.0	 30.0;
	347	 1191	 0.007182	 0.02672	 0.0	 1142	 1142	 1142	 0.0	 0.0	 1	 -30.0	 30.0;
	10616	 3388	 0.00424	 0.019129	 0.0	 1613	 1613	 1613	 0.0	 0.0	 1	 -30.0	 30.0;
	4118	 10616	 0.010542	 0.047938	 0.0	 644	 644	 644	 0.0	 0.0	 1	 -30.0	 30.0;
	10616	 13618	 0.016751	 0.06488	 0.0	 472	 472	 472	 0.0	 0.0	 1	 -30.0	 30.0;
	6565	 5255	 0.016671	 0.059071	 0.0	 515	 515	 515	 0.0	 0.0	 1	 -30.0	 30.0;
	6565	 9086	 0.00536	 0.024151	 0.0	 1277	 1277	 1277	 0.0	 0.0	 1	 -30.0	 30.0;
	8212	 4118	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	4118	 7739	 0.007089	 0.017938	 0.0	 1638	 1638	 1638	 0.0	 0.0	 1	 -30.0	 30.0;
	8171	 4118	 0.020849	 0.052831	 0.0	 557	 557	 557	 0.0	 0.0	 1	 -30.0	 30.0;
	8362	 7739	 0.010609	 0.005209	 0.0	 2673	 2673	 2673	 0.0	 0.0	 1	 -30.0	 30.0;
	3516	 7514	 0.020898	 0.098071	 0.0	 316	 316	 316	 0.0	 0.0	 1	 -30.0	 30.0;
	9533	 7514	 0.002258	 0.008409	 0.0	 3628	 3628	 3628	 0.0	 0.0	 1	 -30.0	 30.0;
	618	 9235	 0.00056	 0.00236	 0.0	 13023	 13023	 13023	 0.0	 0.0	 1	 -30.0	 30.0;
	9235	 1444	 0.014258	 0.064311	 0.0	 480	 480	 480	 0.0	 0.0	 1	 -30.0	 30.0;
	12947	 2832	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	9717	 2832	 0.040249	 0.143902	 0.0	 212	 212	 212	 0.0	 0.0	 1	 -30.0	 30.0;
	12933	 2832	 0.021778	 0.071862	 0.0	 421	 421	 421	 0.0	 0.0	 1	 -30.0	 30.0;
	2832	 6618	 0.022742	 0.09932	 0.0	 311	 311	 311	 0.0	 0.0	 1	 -30.0	 30.0;
	7682	 2832	 0.021511	 0.07092	 0.0	 427	 427	 427	 0.0	 0.0	 1	 -30.0	 30.0;
	7871	 6243	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	6243	 12473	 0.010818	 0.0454	 0.0	 677	 677	 677	 0.0	 0.0	 1	 -30.0	 30.0;
	3271	 6243	 0.013671	 0.059698	 0.0	 516	 516	 516	 0.0	 0.0	 1	 -30.0	 30.0;
	8748	 11441	 0.00011	 0.00059	 0.0	 62636	 62636	 62636	 0.0	 0.0	 1	 -30.0	 30.0;
	2551	 11441	 0.00093	 0.00993	 0.0	 3770	 3770	 3770	 0.0	 0.0	 1	 -30.0	 30.0;
	2922	 8748	 0.00037	 0.00305	 0.0	 12236	 12236	 12236	 0.0	 0.0	 1	 -30.0	 30.0;
	11252	 1428	 0.0001	 0.00066	 0.0	 47320	 47320	 47320	 0.0	 0.0	 1	 -30.0	 30.0;
	2551	 11252	 0.00105	 0.00973	 0.0	 3877	 3877	 3877	 0.0	 0.0	 1	 -30.0	 30.0;
	1428	 8526	 0.00037	 0.00298	 0.0	 10520	 10520	 10520	 0.0	 0.0	 1	 -30.0	 30.0;
	2922	 7298	 0.00105	 0.01196	 0.0	 3132	 3132	 3132	 0.0	 0.0	 1	 -30.0	 30.0;
	8526	 237	 0.00073	 0.00626	 0.0	 5012	 5012	 5012	 0.0	 0.0	 1	 -30.0	 30.0;
	5694	 11284	 0.00112	 0.002329	 0.0	 12223	 12223	 12223	 0.0	 0.0	 1	 -30.0	 30.0;
	5694	 8131	 0.0068	 0.032178	 0.0	 961	 961	 961	 0.0	 0.0	 1	 -30.0	 30.0;
	8083	 5694	 0.013871	 0.06308	 0.0	 490	 490	 490	 0.0	 0.0	 1	 -30.0	 30.0;
	9563	 6184	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	5713	 6184	 0.00636	 0.028689	 0.0	 1075	 1075	 1075	 0.0	 0.0	 1	 -30.0	 30.0;
	5290	 6184	 0.005231	 0.020942	 0.0	 1464	 1464	 1464	 0.0	 0.0	 1	 -30.0	 30.0;
	6536	 6184	 0.019129	 0.063111	 0.0	 479	 479	 479	 0.0	 0.0	 1	 -30.0	 30.0;
	6184	 150	 0.006649	 0.0298	 0.0	 1035	 1035	 1035	 0.0	 0.0	 1	 -30.0	 30.0;
	11284	 8296	 0.0006	 0.001609	 0.0	 18395	 18395	 18395	 0.0	 0.0	 1	 -30.0	 30.0;
	163	 618	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	12128	 618	 0.014849	 0.066942	 0.0	 461	 461	 461	 0.0	 0.0	 1	 -30.0	 30.0;
	12700	 8863	 0.00392	 0.009182	 0.0	 3164	 3164	 3164	 0.0	 0.0	 1	 -30.0	 30.0;
	8863	 5451	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	8863	 450	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	8863	 8643	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	3649	 9001	 0.00384	 0.00936	 0.0	 3123	 3123	 3123	 0.0	 0.0	 1	 -30.0	 30.0;
	9001	 4541	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	9001	 9531	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	9001	 2255	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	3649	 12700	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	5451	 10876	 0.02008	 0.09128	 0.0	 338	 338	 338	 0.0	 0.0	 1	 -30.0	 30.0;
	5976	 4541	 0.023991	 0.092942	 0.0	 330	 330	 330	 0.0	 0.0	 1	 -30.0	 30.0;
	8339	 450	 0.01384	 0.06552	 0.0	 472	 472	 472	 0.0	 0.0	 1	 -30.0	 30.0;
	542	 9531	 0.00476	 0.022538	 0.0	 1372	 1372	 1372	 0.0	 0.0	 1	 -30.0	 30.0;
	8643	 3629	 0.00496	 0.016382	 0.0	 1846	 1846	 1846	 0.0	 0.0	 1	 -30.0	 30.0;
	2255	 11339	 0.00244	 0.008049	 0.0	 3756	 3756	 3756	 0.0	 0.0	 1	 -30.0	 30.0;
	13246	 822	 0.000671	 0.002502	 0.0	 12194	 12194	 12194	 0.0	 0.0	 1	 -30.0	 30.0;
	822	 7359	 0.0066	 0.029569	 0.0	 1043	 1043	 1043	 0.0	 0.0	 1	 -30.0	 30.0;
	13246	 10805	 0.000689	 0.002449	 0.0	 12417	 12417	 12417	 0.0	 0.0	 1	 -30.0	 30.0;
	139	 10805	 0.007271	 0.024969	 0.0	 1215	 1215	 1215	 0.0	 0.0	 1	 -30.0	 30.0;
	7762	 13246	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	5713	 4681	 0.007649	 0.031849	 0.0	 965	 965	 965	 0.0	 0.0	 1	 -30.0	 30.0;
	10606	 8631	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	10606	 10364	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	419	 10606	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	5040	 8631	 0.019471	 0.074818	 0.0	 409	 409	 409	 0.0	 0.0	 1	 -30.0	 30.0;
	9040	 10364	 0.009231	 0.041622	 0.0	 741	 741	 741	 0.0	 0.0	 1	 -30.0	 30.0;
	3931	 12565	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	11067	 9293	 0.000258	 0.001089	 0.0	 28225	 28225	 28225	 0.0	 0.0	 1	 -30.0	 30.0;
	11067	 5294	 0.019871	 0.042889	 0.0	 669	 669	 669	 0.0	 0.0	 1	 -30.0	 30.0;
	5294	 12565	 0.00076	 0.001978	 0.0	 14907	 14907	 14907	 0.0	 0.0	 1	 -30.0	 30.0;
	8825	 12565	 0.000751	 0.001831	 0.0	 15962	 15962	 15962	 0.0	 0.0	 1	 -30.0	 30.0;
	11613	 8825	 0.039151	 0.088	 0.0	 328	 328	 328	 0.0	 0.0	 1	 -30.0	 30.0;
	586	 8062	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	8062	 4100	 0.032351	 0.141289	 0.0	 218	 218	 218	 0.0	 0.0	 1	 -30.0	 30.0;
	1357	 8062	 0.022569	 0.074449	 0.0	 488	 488	 488	 0.0	 0.0	 1	 -30.0	 30.0;
	8062	 7803	 5.8e-05	 0.000222	 0.0	 137665	 137665	 137665	 0.0	 0.0	 1	 -30.0	 30.0;
	9780	 13508	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	2161	 13508	 0.009542	 0.031471	 0.0	 961	 961	 961	 0.0	 0.0	 1	 -30.0	 30.0;
	10857	 13508	 0.021671	 0.09856	 0.0	 314	 314	 314	 0.0	 0.0	 1	 -30.0	 30.0;
	4459	 3333	 0.005609	 0.013978	 0.0	 2098	 2098	 2098	 0.0	 0.0	 1	 -30.0	 30.0;
	6186	 3333	 0.003751	 0.01016	 0.0	 2917	 2917	 2917	 0.0	 0.0	 1	 -30.0	 30.0;
	13360	 5398	 0.000529	 0.00208	 0.0	 14718	 14718	 14718	 0.0	 0.0	 1	 -30.0	 30.0;
	13360	 5991	 0.008862	 0.029231	 0.0	 1035	 1035	 1035	 0.0	 0.0	 1	 -30.0	 30.0;
	1341	 8940	 0.000538	 0.00204	 0.0	 14973	 14973	 14973	 0.0	 0.0	 1	 -30.0	 30.0;
	1341	 13579	 0.009569	 0.026289	 0.0	 1130	 1130	 1130	 0.0	 0.0	 1	 -30.0	 30.0;
	5398	 4990	 0.00028	 0.001209	 0.0	 25454	 25454	 25454	 0.0	 0.0	 1	 -30.0	 30.0;
	1713	 4990	 0.005489	 0.014249	 0.0	 2069	 2069	 2069	 0.0	 0.0	 1	 -30.0	 30.0;
	8940	 4459	 0.000271	 0.001231	 0.0	 25060	 25060	 25060	 0.0	 0.0	 1	 -30.0	 30.0;
	5398	 8382	 0.000338	 0.001311	 0.0	 23332	 23332	 23332	 0.0	 0.0	 1	 -30.0	 30.0;
	8382	 8368	 0.005791	 0.02716	 0.0	 1138	 1138	 1138	 0.0	 0.0	 1	 -30.0	 30.0;
	6381	 10587	 0.00288	 0.03132	 0.0	 1196	 1196	 1196	 0.0	 0.0	 1	 -30.0	 30.0;
	6381	 10587	 0.00282	 0.03191	 0.0	 1174	 1174	 1174	 0.0	 0.0	 1	 -30.0	 30.0;
	10587	 8575	 0.00111	 0.01111	 0.0	 3367	 3367	 3367	 0.0	 0.0	 1	 -30.0	 30.0;
	10587	 9846	 0.00108	 0.01133	 0.0	 3303	 3303	 3303	 0.0	 0.0	 1	 -30.0	 30.0;
	8940	 1704	 0.008751	 0.033911	 0.0	 902	 902	 902	 0.0	 0.0	 1	 -30.0	 30.0;
	8940	 440	 0.002418	 0.00936	 0.0	 3268	 3268	 3268	 0.0	 0.0	 1	 -30.0	 30.0;
	6095	 6950	 0.0	 0.000222	 0.0	 169332	 169332	 169332	 0.0	 0.0	 1	 -30.0	 30.0;
	6095	 413	 0.00944	 0.044271	 0.0	 839	 839	 839	 0.0	 0.0	 1	 -30.0	 30.0;
	6950	 11798	 0.006542	 0.0272	 0.0	 1344	 1344	 1344	 0.0	 0.0	 1	 -30.0	 30.0;
	5255	 3483	 0.001591	 0.005658	 0.0	 5375	 5375	 5375	 0.0	 0.0	 1	 -30.0	 30.0;
	3703	 1595	 0.000711	 0.001822	 0.0	 16151	 16151	 16151	 0.0	 0.0	 1	 -30.0	 30.0;
	1595	 6728	 0.010369	 0.021511	 0.0	 1323	 1323	 1323	 0.0	 0.0	 1	 -30.0	 30.0;
	3703	 11613	 0.001978	 0.0068	 0.0	 4461	 4461	 4461	 0.0	 0.0	 1	 -30.0	 30.0;
	790	 8757	 0.009062	 0.023902	 0.0	 1236	 1236	 1236	 0.0	 0.0	 1	 -30.0	 30.0;
	8757	 7635	 0.0092	 0.025249	 0.0	 1176	 1176	 1176	 0.0	 0.0	 1	 -30.0	 30.0;
	12443	 1270	 0.0022	 0.005942	 0.0	 4986	 4986	 4986	 0.0	 0.0	 1	 -30.0	 30.0;
	7225	 12443	 0.016169	 0.03352	 0.0	 849	 849	 849	 0.0	 0.0	 1	 -30.0	 30.0;
	794	 7635	 0.006902	 0.014898	 0.0	 1924	 1924	 1924	 0.0	 0.0	 1	 -30.0	 30.0;
	11291	 794	 0.018609	 0.041849	 0.0	 690	 690	 690	 0.0	 0.0	 1	 -30.0	 30.0;
	5218	 7202	 0.00156	 0.00696	 0.0	 4429	 4429	 4429	 0.0	 0.0	 1	 -30.0	 30.0;
	7746	 5218	 0.01592	 0.07532	 0.0	 411	 411	 411	 0.0	 0.0	 1	 -30.0	 30.0;
	3544	 7202	 0.00176	 0.006822	 0.0	 4484	 4484	 4484	 0.0	 0.0	 1	 -30.0	 30.0;
	3544	 12677	 0.015542	 0.069582	 0.0	 444	 444	 444	 0.0	 0.0	 1	 -30.0	 30.0;
	10732	 2326	 0.00176	 0.004631	 0.0	 6376	 6376	 6376	 0.0	 0.0	 1	 -30.0	 30.0;
	3117	 2326	 0.02272	 0.061458	 0.0	 483	 483	 483	 0.0	 0.0	 1	 -30.0	 30.0;
	9132	 4036	 0.00348	 0.015809	 0.0	 1952	 1952	 1952	 0.0	 0.0	 1	 -30.0	 30.0;
	12950	 4036	 0.013449	 0.056431	 0.0	 545	 545	 545	 0.0	 0.0	 1	 -30.0	 30.0;
	7923	 1802	 0.002911	 0.01272	 0.0	 2421	 2421	 2421	 0.0	 0.0	 1	 -30.0	 30.0;
	9132	 1802	 0.0034	 0.016102	 0.0	 1920	 1920	 1920	 0.0	 0.0	 1	 -30.0	 30.0;
	9635	 7923	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	7923	 11258	 0.030151	 0.079538	 0.0	 372	 372	 372	 0.0	 0.0	 1	 -30.0	 30.0;
	7746	 7923	 0.017769	 0.063511	 0.0	 479	 479	 479	 0.0	 0.0	 1	 -30.0	 30.0;
	7923	 6022	 0.031249	 0.084538	 0.0	 351	 351	 351	 0.0	 0.0	 1	 -30.0	 30.0;
	12842	 9132	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	9132	 6648	 0.013698	 0.047049	 0.0	 645	 645	 645	 0.0	 0.0	 1	 -30.0	 30.0;
	9132	 6648	 0.01396	 0.046031	 0.0	 657	 657	 657	 0.0	 0.0	 1	 -30.0	 30.0;
	12007	 9132	 0.007938	 0.037569	 0.0	 823	 823	 823	 0.0	 0.0	 1	 -30.0	 30.0;
	12950	 9132	 0.016751	 0.070271	 0.0	 438	 438	 438	 0.0	 0.0	 1	 -30.0	 30.0;
	10732	 9014	 0.00172	 0.00472	 0.0	 6288	 6288	 6288	 0.0	 0.0	 1	 -30.0	 30.0;
	9014	 2947	 0.007271	 0.015689	 0.0	 1827	 1827	 1827	 0.0	 0.0	 1	 -30.0	 30.0;
	764	 3719	 0.001471	 0.004	 0.0	 7412	 7412	 7412	 0.0	 0.0	 1	 -30.0	 30.0;
	764	 4236	 0.001991	 0.007729	 0.0	 3958	 3958	 3958	 0.0	 0.0	 1	 -30.0	 30.0;
	12284	 764	 0.003151	 0.047689	 0.0	 661	 661	 661	 0.0	 0.0	 1	 -30.0	 30.0;
	764	 529	 0.000809	 0.002769	 0.0	 10950	 10950	 10950	 0.0	 0.0	 1	 -30.0	 30.0;
	6198	 764	 0.002009	 0.020209	 0.0	 1556	 1556	 1556	 0.0	 0.0	 1	 -30.0	 30.0;
	6176	 9325	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	9325	 12936	 0.001	 0.002831	 0.0	 10521	 10521	 10521	 0.0	 0.0	 1	 -30.0	 30.0;
	9325	 11865	 0.001502	 0.005169	 0.0	 5869	 5869	 5869	 0.0	 0.0	 1	 -30.0	 30.0;
	8670	 9325	 0.001969	 0.0206	 0.0	 1527	 1527	 1527	 0.0	 0.0	 1	 -30.0	 30.0;
	11178	 5290	 0.000151	 0.000649	 0.0	 47405	 47405	 47405	 0.0	 0.0	 1	 -30.0	 30.0;
	11178	 10185	 0.000142	 0.000662	 0.0	 46654	 46654	 46654	 0.0	 0.0	 1	 -30.0	 30.0;
	3402	 10185	 0.004409	 0.01628	 0.0	 1873	 1873	 1873	 0.0	 0.0	 1	 -30.0	 30.0;
	9786	 9817	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	13518	 11035	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	9817	 13076	 0.00028	 0.000791	 0.0	 37645	 37645	 37645	 0.0	 0.0	 1	 -30.0	 30.0;
	8225	 11035	 0.000622	 0.001671	 0.0	 17716	 17716	 17716	 0.0	 0.0	 1	 -30.0	 30.0;
	6411	 6633	 0.000471	 0.0016	 0.0	 18939	 18939	 18939	 0.0	 0.0	 1	 -30.0	 30.0;
	6323	 6633	 0.013889	 0.065751	 0.0	 471	 471	 471	 0.0	 0.0	 1	 -30.0	 30.0;
	6411	 4659	 0.000471	 0.00156	 0.0	 19385	 19385	 19385	 0.0	 0.0	 1	 -30.0	 30.0;
	6648	 4659	 0.018262	 0.082978	 0.0	 372	 372	 372	 0.0	 0.0	 1	 -30.0	 30.0;
	1719	 3818	 0.02168	 0.077489	 0.0	 393	 393	 393	 0.0	 0.0	 1	 -30.0	 30.0;
	11708	 8049	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	8049	 13542	 0.000538	 0.001902	 0.0	 15981	 15981	 15981	 0.0	 0.0	 1	 -30.0	 30.0;
	4579	 8049	 0.004578	 0.017031	 0.0	 1792	 1792	 1792	 0.0	 0.0	 1	 -30.0	 30.0;
	4579	 8049	 0.004662	 0.016671	 0.0	 1825	 1825	 1825	 0.0	 0.0	 1	 -30.0	 30.0;
	6423	 6648	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	6648	 4588	 0.0242	 0.093769	 0.0	 327	 327	 327	 0.0	 0.0	 1	 -30.0	 30.0;
	12473	 2908	 0.002289	 0.008129	 0.0	 3741	 3741	 3741	 0.0	 0.0	 1	 -30.0	 30.0;
	7076	 8795	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	8795	 5410	 0.00668	 0.02588	 0.0	 1182	 1182	 1182	 0.0	 0.0	 1	 -30.0	 30.0;
	1671	 5410	 0.00308	 0.013778	 0.0	 2238	 2238	 2238	 0.0	 0.0	 1	 -30.0	 30.0;
	5040	 8795	 0.032169	 0.124618	 0.0	 246	 246	 246	 0.0	 0.0	 1	 -30.0	 30.0;
	1891	 12284	 0.006778	 0.02236	 0.0	 1352	 1352	 1352	 0.0	 0.0	 1	 -30.0	 30.0;
	11958	 1891	 0.00308	 0.011929	 0.0	 2564	 2564	 2564	 0.0	 0.0	 1	 -30.0	 30.0;
	8525	 10380	 0.016911	 0.070391	 0.0	 437	 437	 437	 0.0	 0.0	 1	 -30.0	 30.0;
	3703	 8525	 0.03196	 0.149969	 0.0	 206	 206	 206	 0.0	 0.0	 1	 -30.0	 30.0;
	8775	 11701	 0.00016	 0.00049	 0.0	 72929	 72929	 72929	 0.0	 0.0	 1	 -30.0	 30.0;
	4404	 8775	 7e-05	 0.00049	 0.0	 75947	 75947	 75947	 0.0	 0.0	 1	 -30.0	 30.0;
	11957	 9164	 0.0022	 0.00852	 0.0	 3590	 3590	 3590	 0.0	 0.0	 1	 -30.0	 30.0;
	9361	 9164	 0.000431	 0.000951	 0.0	 30253	 30253	 30253	 0.0	 0.0	 1	 -30.0	 30.0;
	11957	 8491	 0.002249	 0.008351	 0.0	 3653	 3653	 3653	 0.0	 0.0	 1	 -30.0	 30.0;
	11338	 8491	 0.019431	 0.053351	 0.0	 557	 557	 557	 0.0	 0.0	 1	 -30.0	 30.0;
	7279	 11957	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	8431	 7685	 0.001929	 0.008111	 0.0	 3789	 3789	 3789	 0.0	 0.0	 1	 -30.0	 30.0;
	6198	 8431	 0.00652	 0.021511	 0.0	 1406	 1406	 1406	 0.0	 0.0	 1	 -30.0	 30.0;
	9405	 7685	 0.001889	 0.008271	 0.0	 3724	 3724	 3724	 0.0	 0.0	 1	 -30.0	 30.0;
	9405	 12284	 0.012289	 0.051551	 0.0	 597	 597	 597	 0.0	 0.0	 1	 -30.0	 30.0;
	4300	 7685	 0.001431	 0.005071	 0.0	 5995	 5995	 5995	 0.0	 0.0	 1	 -30.0	 30.0;
	1672	 7685	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	12950	 7419	 0.007271	 0.0344	 0.0	 899	 899	 899	 0.0	 0.0	 1	 -30.0	 30.0;
	10600	 7419	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	2830	 12473	 0.003289	 0.011329	 0.0	 2678	 2678	 2678	 0.0	 0.0	 1	 -30.0	 30.0;
	12473	 1941	 0.012129	 0.032831	 0.0	 903	 903	 903	 0.0	 0.0	 1	 -30.0	 30.0;
	12473	 252	 0.006031	 0.025289	 0.0	 1215	 1215	 1215	 0.0	 0.0	 1	 -30.0	 30.0;
	12473	 252	 0.005911	 0.025778	 0.0	 1195	 1195	 1195	 0.0	 0.0	 1	 -30.0	 30.0;
	685	 12473	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	3091	 12128	 0.000529	 0.001969	 0.0	 15493	 15493	 15493	 0.0	 0.0	 1	 -30.0	 30.0;
	12425	 12128	 0.000538	 0.001929	 0.0	 15774	 15774	 15774	 0.0	 0.0	 1	 -30.0	 30.0;
	2451	 10540	 0.001151	 0.004222	 0.0	 7219	 7219	 7219	 0.0	 0.0	 1	 -30.0	 30.0;
	1718	 2451	 0.003818	 0.017222	 0.0	 1791	 1791	 1791	 0.0	 0.0	 1	 -30.0	 30.0;
	3629	 2639	 0.00416	 0.019502	 0.0	 1585	 1585	 1585	 0.0	 0.0	 1	 -30.0	 30.0;
	7802	 9931	 0.001991	 0.00372	 0.0	 7487	 7487	 7487	 0.0	 0.0	 1	 -30.0	 30.0;
	7802	 4600	 0.009889	 0.026751	 0.0	 1108	 1108	 1108	 0.0	 0.0	 1	 -30.0	 30.0;
	5621	 9931	 0.002018	 0.00364	 0.0	 7590	 7590	 7590	 0.0	 0.0	 1	 -30.0	 30.0;
	10590	 5621	 0.01644	 0.036942	 0.0	 782	 782	 782	 0.0	 0.0	 1	 -30.0	 30.0;
	12895	 9931	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	3703	 8527	 0.019071	 0.07388	 0.0	 414	 414	 414	 0.0	 0.0	 1	 -30.0	 30.0;
	758	 8527	 0.02804	 0.1256	 0.0	 246	 246	 246	 0.0	 0.0	 1	 -30.0	 30.0;
	8532	 8527	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	8527	 8362	 0.001911	 0.000751	 0.0	 15384	 15384	 15384	 0.0	 0.0	 1	 -30.0	 30.0;
	10252	 6239	 0.008098	 0.028689	 0.0	 1060	 1060	 1060	 0.0	 0.0	 1	 -30.0	 30.0;
	10926	 10252	 0.017609	 0.068191	 0.0	 449	 449	 449	 0.0	 0.0	 1	 -30.0	 30.0;
	10252	 3263	 0.015018	 0.058191	 0.0	 526	 526	 526	 0.0	 0.0	 1	 -30.0	 30.0;
	9796	 9610	 0.007031	 0.014578	 0.0	 1952	 1952	 1952	 0.0	 0.0	 1	 -30.0	 30.0;
	9796	 6054	 0.003791	 0.012529	 0.0	 2414	 2414	 2414	 0.0	 0.0	 1	 -30.0	 30.0;
	9796	 6748	 0.010249	 0.035209	 0.0	 862	 862	 862	 0.0	 0.0	 1	 -30.0	 30.0;
	11343	 1319	 0.002489	 0.005818	 0.0	 4992	 4992	 4992	 0.0	 0.0	 1	 -30.0	 30.0;
	4961	 11343	 0.002071	 0.009751	 0.0	 3169	 3169	 3169	 0.0	 0.0	 1	 -30.0	 30.0;
	4961	 4744	 0.001871	 0.006902	 0.0	 4418	 4418	 4418	 0.0	 0.0	 1	 -30.0	 30.0;
	4961	 6902	 0.003658	 0.014062	 0.0	 2174	 2174	 2174	 0.0	 0.0	 1	 -30.0	 30.0;
	11339	 11765	 0.002289	 0.008178	 0.0	 3720	 3720	 3720	 0.0	 0.0	 1	 -30.0	 30.0;
	1724	 11765	 0.002329	 0.008	 0.0	 3792	 3792	 3792	 0.0	 0.0	 1	 -30.0	 30.0;
	1724	 3629	 0.002071	 0.009249	 0.0	 3333	 3333	 3333	 0.0	 0.0	 1	 -30.0	 30.0;
	2161	 8850	 0.005951	 0.021249	 0.0	 1432	 1432	 1432	 0.0	 0.0	 1	 -30.0	 30.0;
	542	 8850	 0.006058	 0.0208	 0.0	 1459	 1459	 1459	 0.0	 0.0	 1	 -30.0	 30.0;
	6932	 1570	 0.000942	 0.003129	 0.0	 9667	 9667	 9667	 0.0	 0.0	 1	 -30.0	 30.0;
	6932	 6054	 0.030849	 0.10176	 0.0	 298	 298	 298	 0.0	 0.0	 1	 -30.0	 30.0;
	3202	 1570	 0.00084	 0.003551	 0.0	 8657	 8657	 8657	 0.0	 0.0	 1	 -30.0	 30.0;
	3629	 3202	 0.002378	 0.007831	 0.0	 3860	 3860	 3860	 0.0	 0.0	 1	 -30.0	 30.0;
	5636	 1943	 0.007231	 0.01624	 0.0	 1777	 1777	 1777	 0.0	 0.0	 1	 -30.0	 30.0;
	2169	 5636	 0.001311	 0.005111	 0.0	 5987	 5987	 5987	 0.0	 0.0	 1	 -30.0	 30.0;
	5636	 8528	 0.001338	 0.005009	 0.0	 6093	 6093	 6093	 0.0	 0.0	 1	 -30.0	 30.0;
	5340	 5636	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	1943	 830	 0.000338	 0.00116	 0.0	 26144	 26144	 26144	 0.0	 0.0	 1	 -30.0	 30.0;
	830	 1824	 0.025778	 0.069751	 0.0	 425	 425	 425	 0.0	 0.0	 1	 -30.0	 30.0;
	3155	 830	 0.004009	 0.01376	 0.0	 2204	 2204	 2204	 0.0	 0.0	 1	 -30.0	 30.0;
	7204	 830	 0.00408	 0.013462	 0.0	 2246	 2246	 2246	 0.0	 0.0	 1	 -30.0	 30.0;
	5491	 830	 0.000329	 0.001262	 0.0	 24221	 24221	 24221	 0.0	 0.0	 1	 -30.0	 30.0;
	7015	 830	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	12793	 2076	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	3849	 1843	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	2378	 2076	 0.000711	 0.002018	 0.0	 14764	 14764	 14764	 0.0	 0.0	 1	 -30.0	 30.0;
	1843	 7413	 0.00068	 0.001502	 0.0	 19159	 19159	 19159	 0.0	 0.0	 1	 -30.0	 30.0;
	5527	 1318	 0.00012	 0.00056	 0.0	 55154	 55154	 55154	 0.0	 0.0	 1	 -30.0	 30.0;
	5239	 1318	 0.02516	 0.086418	 0.0	 351	 351	 351	 0.0	 0.0	 1	 -30.0	 30.0;
	5527	 9073	 0.00012	 0.00052	 0.0	 59190	 59190	 59190	 0.0	 0.0	 1	 -30.0	 30.0;
	9073	 10857	 0.032591	 0.116511	 0.0	 262	 262	 262	 0.0	 0.0	 1	 -30.0	 30.0;
	12037	 5527	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	3269	 3091	 0.01752	 0.062098	 0.0	 490	 490	 490	 0.0	 0.0	 1	 -30.0	 30.0;
	12425	 3859	 0.00076	 0.003551	 0.0	 8699	 8699	 8699	 0.0	 0.0	 1	 -30.0	 30.0;
	13657	 3483	 4e-05	 0.00028	 0.0	 111679	 111679	 111679	 0.0	 0.0	 1	 -30.0	 30.0;
	13657	 8214	 0.000858	 0.004458	 0.0	 6958	 6958	 6958	 0.0	 0.0	 1	 -30.0	 30.0;
	8214	 1933	 8e-05	 0.000338	 0.0	 90942	 90942	 90942	 0.0	 0.0	 1	 -30.0	 30.0;
	8330	 9918	 4e-05	 0.00028	 0.0	 111679	 111679	 111679	 0.0	 0.0	 1	 -30.0	 30.0;
	9918	 11992	 0.000982	 0.004369	 0.0	 7054	 7054	 7054	 0.0	 0.0	 1	 -30.0	 30.0;
	3977	 8330	 0.01704	 0.083271	 0.0	 372	 372	 372	 0.0	 0.0	 1	 -30.0	 30.0;
	11992	 4374	 7.1e-05	 0.000351	 0.0	 88206	 88206	 88206	 0.0	 0.0	 1	 -30.0	 30.0;
	7160	 8831	 0.000271	 0.00068	 0.0	 43152	 43152	 43152	 0.0	 0.0	 1	 -30.0	 30.0;
	9985	 7160	 0.012809	 0.05376	 0.0	 572	 572	 572	 0.0	 0.0	 1	 -30.0	 30.0;
	7160	 10822	 0.00364	 0.015262	 0.0	 2014	 2014	 2014	 0.0	 0.0	 1	 -30.0	 30.0;
	1669	 7266	 0.00012	 0.000431	 0.0	 70604	 70604	 70604	 0.0	 0.0	 1	 -30.0	 30.0;
	12370	 7266	 0.003982	 0.015271	 0.0	 2002	 2002	 2002	 0.0	 0.0	 1	 -30.0	 30.0;
	1669	 5392	 0.00012	 0.000418	 0.0	 72634	 72634	 72634	 0.0	 0.0	 1	 -30.0	 30.0;
	11150	 5392	 0.000431	 0.00172	 0.0	 17814	 17814	 17814	 0.0	 0.0	 1	 -30.0	 30.0;
	171	 4812	 0.00024	 0.00032	 0.0	 78969	 78969	 78969	 0.0	 0.0	 1	 -30.0	 30.0;
	636	 171	 0.002418	 0.011462	 0.0	 2697	 2697	 2697	 0.0	 0.0	 1	 -30.0	 30.0;
	10097	 6536	 0.00028	 0.000311	 0.0	 75483	 75483	 75483	 0.0	 0.0	 1	 -30.0	 30.0;
	10097	 12370	 0.003658	 0.01664	 0.0	 1855	 1855	 1855	 0.0	 0.0	 1	 -30.0	 30.0;
	12370	 4812	 0.003582	 0.016951	 0.0	 1824	 1824	 1824	 0.0	 0.0	 1	 -30.0	 30.0;
	2675	 1175	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	1175	 3358	 0.006231	 0.029249	 0.0	 1057	 1057	 1057	 0.0	 0.0	 1	 -30.0	 30.0;
	1175	 11150	 0.00144	 0.005529	 0.0	 5529	 5529	 5529	 0.0	 0.0	 1	 -30.0	 30.0;
	1175	 5954	 0.011111	 0.023978	 0.0	 1196	 1196	 1196	 0.0	 0.0	 1	 -30.0	 30.0;
	12932	 1669	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	3438	 8136	 0.001182	 0.002409	 0.0	 11772	 11772	 11772	 0.0	 0.0	 1	 -30.0	 30.0;
	9201	 4395	 0.006098	 0.029822	 0.0	 1038	 1038	 1038	 0.0	 0.0	 1	 -30.0	 30.0;
	4395	 13445	 0.00096	 0.003378	 0.0	 8995	 8995	 8995	 0.0	 0.0	 1	 -30.0	 30.0;
	6153	 9717	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	9717	 2277	 0.01044	 0.03444	 0.0	 878	 878	 878	 0.0	 0.0	 1	 -30.0	 30.0;
	9717	 2277	 0.009298	 0.03904	 0.0	 788	 788	 788	 0.0	 0.0	 1	 -30.0	 30.0;
	9717	 7682	 0.017311	 0.078738	 0.0	 392	 392	 392	 0.0	 0.0	 1	 -30.0	 30.0;
	9210	 11258	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	11258	 790	 0.012449	 0.029129	 0.0	 998	 998	 998	 0.0	 0.0	 1	 -30.0	 30.0;
	1052	 1711	 0.00015	 0.00045	 0.0	 79250	 79250	 79250	 0.0	 0.0	 1	 -30.0	 30.0;
	679	 1711	 0.00107	 0.01215	 0.0	 3083	 3083	 3083	 0.0	 0.0	 1	 -30.0	 30.0;
	4404	 1052	 6e-05	 0.00056	 0.0	 66746	 66746	 66746	 0.0	 0.0	 1	 -30.0	 30.0;
	6112	 12028	 0.00035	 0.00284	 0.0	 13138	 13138	 13138	 0.0	 0.0	 1	 -30.0	 30.0;
	11185	 12028	 0.00163	 0.01512	 0.0	 2472	 2472	 2472	 0.0	 0.0	 1	 -30.0	 30.0;
	7298	 12028	 0.00115	 0.00913	 0.0	 4086	 4086	 4086	 0.0	 0.0	 1	 -30.0	 30.0;
	4111	 12028	 0.00133	 0.01513	 0.0	 2476	 2476	 2476	 0.0	 0.0	 1	 -30.0	 30.0;
	4111	 12028	 0.00131	 0.01401	 0.0	 2672	 2672	 2672	 0.0	 0.0	 1	 -30.0	 30.0;
	679	 12028	 0.00013	 0.00129	 0.0	 28994	 28994	 28994	 0.0	 0.0	 1	 -30.0	 30.0;
	10415	 12028	 0.00077	 0.00664	 0.0	 5624	 5624	 5624	 0.0	 0.0	 1	 -30.0	 30.0;
	3629	 6054	 0.028391	 0.12908	 0.0	 239	 239	 239	 0.0	 0.0	 1	 -30.0	 30.0;
	12725	 3629	 0.01216	 0.05532	 0.0	 558	 558	 558	 0.0	 0.0	 1	 -30.0	 30.0;
	11778	 8989	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	3436	 8989	 0.023609	 0.053071	 0.0	 544	 544	 544	 0.0	 0.0	 1	 -30.0	 30.0;
	7269	 2521	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	2521	 10009	 0.020471	 0.051871	 0.0	 567	 567	 567	 0.0	 0.0	 1	 -30.0	 30.0;
	5040	 2521	 0.01744	 0.049862	 0.0	 598	 598	 598	 0.0	 0.0	 1	 -30.0	 30.0;
	12677	 3818	 0.009111	 0.039809	 0.0	 774	 774	 774	 0.0	 0.0	 1	 -30.0	 30.0;
	7746	 10319	 0.033022	 0.13856	 0.0	 222	 222	 222	 0.0	 0.0	 1	 -30.0	 30.0;
	10319	 3818	 0.009529	 0.045089	 0.0	 686	 686	 686	 0.0	 0.0	 1	 -30.0	 30.0;
	11266	 2378	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	2378	 1223	 0.001889	 0.003462	 0.0	 8010	 8010	 8010	 0.0	 0.0	 1	 -30.0	 30.0;
	2378	 1216	 0.006569	 0.0142	 0.0	 2425	 2425	 2425	 0.0	 0.0	 1	 -30.0	 30.0;
	10297	 2378	 0.003982	 0.018102	 0.0	 1705	 1705	 1705	 0.0	 0.0	 1	 -30.0	 30.0;
	2378	 923	 0.00232	 0.007969	 0.0	 3806	 3806	 3806	 0.0	 0.0	 1	 -30.0	 30.0;
	2026	 3231	 0.002502	 0.011698	 0.0	 2641	 2641	 2641	 0.0	 0.0	 1	 -30.0	 30.0;
	8073	 3231	 0.009351	 0.039209	 0.0	 784	 784	 784	 0.0	 0.0	 1	 -30.0	 30.0;
	3231	 13543	 0.008622	 0.0296	 0.0	 1025	 1025	 1025	 0.0	 0.0	 1	 -30.0	 30.0;
	2905	 3709	 0.008951	 0.037289	 0.0	 824	 824	 824	 0.0	 0.0	 1	 -30.0	 30.0;
	3709	 6645	 0.005369	 0.02144	 0.0	 1430	 1430	 1430	 0.0	 0.0	 1	 -30.0	 30.0;
	9832	 12087	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	8073	 12087	 0.00608	 0.025551	 0.0	 1203	 1203	 1203	 0.0	 0.0	 1	 -30.0	 30.0;
	8073	 12087	 0.00596	 0.026049	 0.0	 1183	 1183	 1183	 0.0	 0.0	 1	 -30.0	 30.0;
	12087	 2905	 0.001369	 0.004898	 0.0	 6211	 6211	 6211	 0.0	 0.0	 1	 -30.0	 30.0;
	12087	 3438	 0.00144	 0.006031	 0.0	 5095	 5095	 5095	 0.0	 0.0	 1	 -30.0	 30.0;
	7060	 4801	 0.0012	 0.00328	 0.0	 9045	 9045	 9045	 0.0	 0.0	 1	 -30.0	 30.0;
	12370	 7060	 0.00132	 0.006271	 0.0	 4930	 4930	 4930	 0.0	 0.0	 1	 -30.0	 30.0;
	7060	 12766	 0.009089	 0.040711	 0.0	 758	 758	 758	 0.0	 0.0	 1	 -30.0	 30.0;
	12922	 1825	 5.8e-05	 0.00028	 0.0	 110467	 110467	 110467	 0.0	 0.0	 1	 -30.0	 30.0;
	4579	 1825	 0.000302	 0.00132	 0.0	 23328	 23328	 23328	 0.0	 0.0	 1	 -30.0	 30.0;
	12117	 4442	 0.00368	 0.016502	 0.0	 1869	 1869	 1869	 0.0	 0.0	 1	 -30.0	 30.0;
	2805	 12117	 0.000329	 0.00124	 0.0	 24622	 24622	 24622	 0.0	 0.0	 1	 -30.0	 30.0;
	7405	 2761	 0.0012	 0.002689	 0.0	 10728	 10728	 10728	 0.0	 0.0	 1	 -30.0	 30.0;
	4579	 2761	 0.000338	 0.001289	 0.0	 23704	 23704	 23704	 0.0	 0.0	 1	 -30.0	 30.0;
	607	 12922	 0.000942	 0.002151	 0.0	 13452	 13452	 13452	 0.0	 0.0	 1	 -30.0	 30.0;
	7728	 3048	 0.00316	 0.010862	 0.0	 2793	 2793	 2793	 0.0	 0.0	 1	 -30.0	 30.0;
	7728	 10104	 0.003222	 0.010618	 0.0	 2847	 2847	 2847	 0.0	 0.0	 1	 -30.0	 30.0;
	5355	 3048	 0.010169	 0.037858	 0.0	 806	 806	 806	 0.0	 0.0	 1	 -30.0	 30.0;
	2604	 10104	 0.00552	 0.024129	 0.0	 1277	 1277	 1277	 0.0	 0.0	 1	 -30.0	 30.0;
	3040	 6222	 0.000449	 0.001889	 0.0	 16269	 16269	 16269	 0.0	 0.0	 1	 -30.0	 30.0;
	6714	 8783	 0.00044	 0.001929	 0.0	 15965	 15965	 15965	 0.0	 0.0	 1	 -30.0	 30.0;
	5615	 7265	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	7265	 10893	 0.000418	 0.00192	 0.0	 16076	 16076	 16076	 0.0	 0.0	 1	 -30.0	 30.0;
	7265	 10540	 0.000409	 0.00196	 0.0	 15777	 15777	 15777	 0.0	 0.0	 1	 -30.0	 30.0;
	12370	 10893	 0.00608	 0.022431	 0.0	 1360	 1360	 1360	 0.0	 0.0	 1	 -30.0	 30.0;
	9171	 7894	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	6302	 7894	 0.00016	 0.000751	 0.0	 41138	 41138	 41138	 0.0	 0.0	 1	 -30.0	 30.0;
	6302	 12680	 0.046622	 0.173511	 0.0	 176	 176	 176	 0.0	 0.0	 1	 -30.0	 30.0;
	2151	 7894	 0.000151	 0.000698	 0.0	 44231	 44231	 44231	 0.0	 0.0	 1	 -30.0	 30.0;
	5239	 2151	 0.01464	 0.052329	 0.0	 582	 582	 582	 0.0	 0.0	 1	 -30.0	 30.0;
	9977	 9399	 0.006129	 0.023751	 0.0	 1288	 1288	 1288	 0.0	 0.0	 1	 -30.0	 30.0;
	7234	 9399	 0.001049	 0.003311	 0.0	 9095	 9095	 9095	 0.0	 0.0	 1	 -30.0	 30.0;
	12602	 7809	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	7809	 4442	 0.003271	 0.012089	 0.0	 2523	 2523	 2523	 0.0	 0.0	 1	 -30.0	 30.0;
	7809	 2680	 0.002951	 0.013311	 0.0	 2317	 2317	 2317	 0.0	 0.0	 1	 -30.0	 30.0;
	7809	 7522	 0.017489	 0.082769	 0.0	 374	 374	 374	 0.0	 0.0	 1	 -30.0	 30.0;
	7809	 3433	 0.006231	 0.029498	 0.0	 1048	 1048	 1048	 0.0	 0.0	 1	 -30.0	 30.0;
	3987	 7657	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	9316	 12813	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	2911	 7657	 0.00124	 0.004458	 0.0	 6827	 6827	 6827	 0.0	 0.0	 1	 -30.0	 30.0;
	8551	 12813	 0.001169	 0.001969	 0.0	 13795	 13795	 13795	 0.0	 0.0	 1	 -30.0	 30.0;
	3266	 13076	 0.000791	 0.002929	 0.0	 10412	 10412	 10412	 0.0	 0.0	 1	 -30.0	 30.0;
	1540	 13076	 0.000911	 0.003138	 0.0	 9667	 9667	 9667	 0.0	 0.0	 1	 -30.0	 30.0;
	2805	 2680	 0.004671	 0.01672	 0.0	 1820	 1820	 1820	 0.0	 0.0	 1	 -30.0	 30.0;
	2081	 3719	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	3719	 4300	 0.00064	 0.00188	 0.0	 15906	 15906	 15906	 0.0	 0.0	 1	 -30.0	 30.0;
	884	 11210	 0.00014	 0.00061	 0.0	 60064	 60064	 60064	 0.0	 0.0	 1	 -30.0	 30.0;
	7007	 8597	 0.000698	 0.0024	 0.0	 12638	 12638	 12638	 0.0	 0.0	 1	 -30.0	 30.0;
	7007	 3542	 0.000711	 0.002351	 0.0	 12861	 12861	 12861	 0.0	 0.0	 1	 -30.0	 30.0;
	12370	 8597	 0.001858	 0.006391	 0.0	 4746	 4746	 4746	 0.0	 0.0	 1	 -30.0	 30.0;
	7199	 3542	 0.014129	 0.06328	 0.0	 488	 488	 488	 0.0	 0.0	 1	 -30.0	 30.0;
	3263	 7199	 0.0002	 0.00092	 0.0	 33551	 33551	 33551	 0.0	 0.0	 1	 -30.0	 30.0;
	12488	 1023	 4e-05	 0.0004	 0.0	 93513	 93513	 93513	 0.0	 0.0	 1	 -30.0	 30.0;
	12488	 6112	 4e-05	 0.00039	 0.0	 95886	 95886	 95886	 0.0	 0.0	 1	 -30.0	 30.0;
	7298	 1023	 0.00066	 0.00705	 0.0	 5309	 5309	 5309	 0.0	 0.0	 1	 -30.0	 30.0;
	6837	 431	 0.003622	 0.016209	 0.0	 1902	 1902	 1902	 0.0	 0.0	 1	 -30.0	 30.0;
	13355	 6837	 5.8e-05	 0.00028	 0.0	 110467	 110467	 110467	 0.0	 0.0	 1	 -30.0	 30.0;
	3716	 6837	 3.1e-05	 0.00028	 0.0	 112127	 112127	 112127	 0.0	 0.0	 1	 -30.0	 30.0;
	11771	 491	 0.00084	 0.002031	 0.0	 14372	 14372	 14372	 0.0	 0.0	 1	 -30.0	 30.0;
	10460	 9398	 0.004511	 0.01972	 0.0	 1562	 1562	 1562	 0.0	 0.0	 1	 -30.0	 30.0;
	10460	 12676	 0.00064	 0.0028	 0.0	 10998	 10998	 10998	 0.0	 0.0	 1	 -30.0	 30.0;
	7176	 11771	 0.004422	 0.020102	 0.0	 1535	 1535	 1535	 0.0	 0.0	 1	 -30.0	 30.0;
	11771	 7002	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	10036	 1069	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	1069	 4681	 0.000822	 0.003622	 0.0	 8505	 8505	 8505	 0.0	 0.0	 1	 -30.0	 30.0;
	1069	 3358	 0.000809	 0.003689	 0.0	 8364	 8364	 8364	 0.0	 0.0	 1	 -30.0	 30.0;
	5176	 9806	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	3755	 9806	 0.001471	 0.00528	 0.0	 5763	 5763	 5763	 0.0	 0.0	 1	 -30.0	 30.0;
	3755	 9806	 0.001502	 0.005169	 0.0	 5869	 5869	 5869	 0.0	 0.0	 1	 -30.0	 30.0;
	3064	 9806	 0.000769	 0.002858	 0.0	 10673	 10673	 10673	 0.0	 0.0	 1	 -30.0	 30.0;
	9806	 3271	 0.003698	 0.013209	 0.0	 2303	 2303	 2303	 0.0	 0.0	 1	 -30.0	 30.0;
	9806	 3040	 0.00116	 0.005271	 0.0	 5853	 5853	 5853	 0.0	 0.0	 1	 -30.0	 30.0;
	9806	 7399	 0.003378	 0.006178	 0.0	 4487	 4487	 4487	 0.0	 0.0	 1	 -30.0	 30.0;
	9806	 1105	 0.000849	 0.004009	 0.0	 7709	 7709	 7709	 0.0	 0.0	 1	 -30.0	 30.0;
	9806	 242	 0.000431	 0.00112	 0.0	 26322	 26322	 26322	 0.0	 0.0	 1	 -30.0	 30.0;
	3883	 8131	 0.006778	 0.002631	 0.0	 4345	 4345	 4345	 0.0	 0.0	 1	 -30.0	 30.0;
	2189	 150	 0.003569	 0.00468	 0.0	 5367	 5367	 5367	 0.0	 0.0	 1	 -30.0	 30.0;
	2189	 150	 0.003178	 0.005298	 0.0	 5113	 5113	 5113	 0.0	 0.0	 1	 -30.0	 30.0;
	8492	 6249	 0.00388	 0.0174	 0.0	 1772	 1772	 1772	 0.0	 0.0	 1	 -30.0	 30.0;
	1078	 6249	 0.003138	 0.011689	 0.0	 2610	 2610	 2610	 0.0	 0.0	 1	 -30.0	 30.0;
	8492	 2426	 0.0044	 0.017049	 0.0	 1794	 1794	 1794	 0.0	 0.0	 1	 -30.0	 30.0;
	2426	 11261	 0.000791	 0.002631	 0.0	 11498	 11498	 11498	 0.0	 0.0	 1	 -30.0	 30.0;
	7836	 4236	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	678	 10009	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	3269	 10009	 0.017698	 0.0584	 0.0	 518	 518	 518	 0.0	 0.0	 1	 -30.0	 30.0;
	3269	 10009	 0.015769	 0.066191	 0.0	 465	 465	 465	 0.0	 0.0	 1	 -30.0	 30.0;
	6381	 12293	 0.00225	 0.02425	 0.0	 1544	 1544	 1544	 0.0	 0.0	 1	 -30.0	 30.0;
	6381	 12293	 0.00161	 0.02118	 0.0	 1770	 1770	 1770	 0.0	 0.0	 1	 -30.0	 30.0;
	1624	 12293	 0.00312	 0.03268	 0.0	 1146	 1146	 1146	 0.0	 0.0	 1	 -30.0	 30.0;
	1624	 12293	 0.00305	 0.0333	 0.0	 1125	 1125	 1125	 0.0	 0.0	 1	 -30.0	 30.0;
	9094	 8073	 0.000182	 0.000831	 0.0	 37132	 37132	 37132	 0.0	 0.0	 1	 -30.0	 30.0;
	11486	 9094	 0.013649	 0.054609	 0.0	 562	 562	 562	 0.0	 0.0	 1	 -30.0	 30.0;
	13277	 11485	 0.007209	 0.03252	 0.0	 949	 949	 949	 0.0	 0.0	 1	 -30.0	 30.0;
	13063	 13277	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	11485	 8073	 0.000169	 0.000769	 0.0	 40119	 40119	 40119	 0.0	 0.0	 1	 -30.0	 30.0;
	3927	 8073	 0.011649	 0.026778	 0.0	 1082	 1082	 1082	 0.0	 0.0	 1	 -30.0	 30.0;
	9398	 3927	 0.004049	 0.01112	 0.0	 2670	 2670	 2670	 0.0	 0.0	 1	 -30.0	 30.0;
	9398	 8073	 0.007898	 0.037338	 0.0	 828	 828	 828	 0.0	 0.0	 1	 -30.0	 30.0;
	9398	 8073	 0.00772	 0.034578	 0.0	 892	 892	 892	 0.0	 0.0	 1	 -30.0	 30.0;
	8073	 6891	 0.042582	 0.193609	 0.0	 160	 160	 160	 0.0	 0.0	 1	 -30.0	 30.0;
	8073	 12351	 0.027591	 0.130569	 0.0	 237	 237	 237	 0.0	 0.0	 1	 -30.0	 30.0;
	8073	 13088	 0.018431	 0.065898	 0.0	 462	 462	 462	 0.0	 0.0	 1	 -30.0	 30.0;
	8073	 38	 0.02836	 0.1134	 0.0	 271	 271	 271	 0.0	 0.0	 1	 -30.0	 30.0;
	8073	 1357	 0.046142	 0.15844	 0.0	 230	 230	 230	 0.0	 0.0	 1	 -30.0	 30.0;
	11024	 8073	 0.011409	 0.027311	 0.0	 1068	 1068	 1068	 0.0	 0.0	 1	 -30.0	 30.0;
	8073	 13543	 0.019271	 0.063569	 0.0	 476	 476	 476	 0.0	 0.0	 1	 -30.0	 30.0;
	8073	 13543	 0.02212	 0.082329	 0.0	 371	 371	 371	 0.0	 0.0	 1	 -30.0	 30.0;
	4270	 7017	 0.018249	 0.04624	 0.0	 636	 636	 636	 0.0	 0.0	 1	 -30.0	 30.0;
	973	 7017	 0.008929	 0.01872	 0.0	 1523	 1523	 1523	 0.0	 0.0	 1	 -30.0	 30.0;
	973	 7017	 0.008742	 0.017329	 0.0	 1628	 1628	 1628	 0.0	 0.0	 1	 -30.0	 30.0;
	2250	 8662	 0.001569	 0.00412	 0.0	 7165	 7165	 7165	 0.0	 0.0	 1	 -30.0	 30.0;
	8662	 11489	 0.037409	 0.106911	 0.0	 279	 279	 279	 0.0	 0.0	 1	 -30.0	 30.0;
	2250	 6186	 0.01836	 0.049671	 0.0	 597	 597	 597	 0.0	 0.0	 1	 -30.0	 30.0;
	5976	 7608	 0.007791	 0.037502	 0.0	 825	 825	 825	 0.0	 0.0	 1	 -30.0	 30.0;
	5976	 13318	 0.014911	 0.051218	 0.0	 593	 593	 593	 0.0	 0.0	 1	 -30.0	 30.0;
	3512	 7177	 0.007071	 0.0294	 0.0	 1045	 1045	 1045	 0.0	 0.0	 1	 -30.0	 30.0;
	3512	 10876	 0.010169	 0.039378	 0.0	 777	 777	 777	 0.0	 0.0	 1	 -30.0	 30.0;
	9398	 7176	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	9398	 9501	 0.004449	 0.00924	 0.0	 3081	 3081	 3081	 0.0	 0.0	 1	 -30.0	 30.0;
	5442	 7774	 0.002191	 0.011142	 0.0	 2782	 2782	 2782	 0.0	 0.0	 1	 -30.0	 30.0;
	7774	 11730	 0.00244	 0.011951	 0.0	 2590	 2590	 2590	 0.0	 0.0	 1	 -30.0	 30.0;
	9040	 10529	 0.004662	 0.020871	 0.0	 1478	 1478	 1478	 0.0	 0.0	 1	 -30.0	 30.0;
	5442	 10529	 0.00528	 0.020449	 0.0	 1496	 1496	 1496	 0.0	 0.0	 1	 -30.0	 30.0;
	8796	 10529	 0.0036	 0.0144	 0.0	 2129	 2129	 2129	 0.0	 0.0	 1	 -30.0	 30.0;
	4091	 5673	 0.00212	 0.008871	 0.0	 3464	 3464	 3464	 0.0	 0.0	 1	 -30.0	 30.0;
	8988	 4091	 0.001991	 0.008271	 0.0	 3713	 3713	 3713	 0.0	 0.0	 1	 -30.0	 30.0;
	569	 5673	 0.002071	 0.009049	 0.0	 3403	 3403	 3403	 0.0	 0.0	 1	 -30.0	 30.0;
	569	 5790	 0.002031	 0.008098	 0.0	 3784	 3784	 3784	 0.0	 0.0	 1	 -30.0	 30.0;
	3188	 3858	 0.002631	 0.00868	 0.0	 3483	 3483	 3483	 0.0	 0.0	 1	 -30.0	 30.0;
	4213	 3858	 0.00048	 0.001769	 0.0	 17233	 17233	 17233	 0.0	 0.0	 1	 -30.0	 30.0;
	3188	 8564	 0.002338	 0.009831	 0.0	 3126	 3126	 3126	 0.0	 0.0	 1	 -30.0	 30.0;
	10166	 8564	 0.006911	 0.025742	 0.0	 1424	 1424	 1424	 0.0	 0.0	 1	 -30.0	 30.0;
	8190	 3188	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	3436	 4989	 0.005649	 0.020209	 0.0	 1506	 1506	 1506	 0.0	 0.0	 1	 -30.0	 30.0;
	6728	 4989	 0.037822	 0.075338	 0.0	 375	 375	 375	 0.0	 0.0	 1	 -30.0	 30.0;
	913	 3436	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	3436	 10380	 0.005609	 0.020871	 0.0	 1462	 1462	 1462	 0.0	 0.0	 1	 -30.0	 30.0;
	3436	 11139	 0.042569	 0.11516	 0.0	 258	 258	 258	 0.0	 0.0	 1	 -30.0	 30.0;
	2200	 10380	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	12480	 8339	 0.00396	 0.010458	 0.0	 2825	 2825	 2825	 0.0	 0.0	 1	 -30.0	 30.0;
	10857	 8339	 0.019671	 0.088151	 0.0	 350	 350	 350	 0.0	 0.0	 1	 -30.0	 30.0;
	11575	 12674	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	2568	 7937	 0.00912	 0.03364	 0.0	 907	 907	 907	 0.0	 0.0	 1	 -30.0	 30.0;
	7937	 10729	 0.010942	 0.051369	 0.0	 602	 602	 602	 0.0	 0.0	 1	 -30.0	 30.0;
	2826	 12674	 0.000182	 0.000822	 0.0	 37519	 37519	 37519	 0.0	 0.0	 1	 -30.0	 30.0;
	2826	 12680	 0.023209	 0.118049	 0.0	 263	 263	 263	 0.0	 0.0	 1	 -30.0	 30.0;
	2568	 12674	 0.0002	 0.000809	 0.0	 37904	 37904	 37904	 0.0	 0.0	 1	 -30.0	 30.0;
	3014	 9100	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	2194	 11185	 0.00076	 0.00811	 0.0	 4658	 4658	 4658	 0.0	 0.0	 1	 -30.0	 30.0;
	11993	 4073	 5.8e-05	 0.000231	 0.0	 132626	 132626	 132626	 0.0	 0.0	 1	 -30.0	 30.0;
	11139	 11993	 0.013471	 0.053849	 0.0	 570	 570	 570	 0.0	 0.0	 1	 -30.0	 30.0;
	10708	 11139	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	2338	 2658	 0.007489	 0.03376	 0.0	 914	 914	 914	 0.0	 0.0	 1	 -30.0	 30.0;
	16	 2338	 0.004271	 0.016431	 0.0	 1861	 1861	 1861	 0.0	 0.0	 1	 -30.0	 30.0;
	8080	 7465	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	12933	 7465	 0.013289	 0.04384	 0.0	 690	 690	 690	 0.0	 0.0	 1	 -30.0	 30.0;
	12933	 7465	 0.01184	 0.049689	 0.0	 619	 619	 619	 0.0	 0.0	 1	 -30.0	 30.0;
	12933	 7465	 0.011338	 0.0508	 0.0	 607	 607	 607	 0.0	 0.0	 1	 -30.0	 30.0;
	6618	 7465	 0.008502	 0.035671	 0.0	 862	 862	 862	 0.0	 0.0	 1	 -30.0	 30.0;
	7465	 5264	 0.02216	 0.088622	 0.0	 346	 346	 346	 0.0	 0.0	 1	 -30.0	 30.0;
	7465	 7862	 0.019911	 0.101262	 0.0	 307	 307	 307	 0.0	 0.0	 1	 -30.0	 30.0;
	7465	 653	 0.014551	 0.068258	 0.0	 453	 453	 453	 0.0	 0.0	 1	 -30.0	 30.0;
	7465	 6493	 0.014129	 0.050529	 0.0	 603	 603	 603	 0.0	 0.0	 1	 -30.0	 30.0;
	7465	 10830	 0.018022	 0.08072	 0.0	 382	 382	 382	 0.0	 0.0	 1	 -30.0	 30.0;
	758	 11139	 0.005382	 0.02004	 0.0	 1523	 1523	 1523	 0.0	 0.0	 1	 -30.0	 30.0;
	13429	 943	 0.007769	 0.034791	 0.0	 887	 887	 887	 0.0	 0.0	 1	 -30.0	 30.0;
	943	 10857	 0.068351	 0.30616	 0.0	 101	 101	 101	 0.0	 0.0	 1	 -30.0	 30.0;
	2549	 6902	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	1979	 9985	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	356	 3269	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	105	 642	 0.00163	 0.01819	 0.0	 2059	 2059	 2059	 0.0	 0.0	 1	 -30.0	 30.0;
	8575	 105	 0.00241	 0.02622	 0.0	 1428	 1428	 1428	 0.0	 0.0	 1	 -30.0	 30.0;
	9846	 105	 0.00236	 0.02672	 0.0	 1402	 1402	 1402	 0.0	 0.0	 1	 -30.0	 30.0;
	105	 4111	 0.00188	 0.02029	 0.0	 1845	 1845	 1845	 0.0	 0.0	 1	 -30.0	 30.0;
	105	 4111	 0.00213	 0.01988	 0.0	 1881	 1881	 1881	 0.0	 0.0	 1	 -30.0	 30.0;
	2110	 5239	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	1429	 5239	 0.009822	 0.046449	 0.0	 666	 666	 666	 0.0	 0.0	 1	 -30.0	 30.0;
	10848	 5239	 0.00344	 0.01628	 0.0	 1899	 1899	 1899	 0.0	 0.0	 1	 -30.0	 30.0;
	5239	 2466	 0.00648	 0.025102	 0.0	 1219	 1219	 1219	 0.0	 0.0	 1	 -30.0	 30.0;
	6907	 1610	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	1610	 1588	 0.02368	 0.099338	 0.0	 310	 310	 310	 0.0	 0.0	 1	 -30.0	 30.0;
	5040	 1610	 0.017169	 0.061382	 0.0	 496	 496	 496	 0.0	 0.0	 1	 -30.0	 30.0;
	2194	 10290	 0.00209	 0.01796	 0.0	 2099	 2099	 2099	 0.0	 0.0	 1	 -30.0	 30.0;
	2194	 10290	 0.00213	 0.01758	 0.0	 2143	 2143	 2143	 0.0	 0.0	 1	 -30.0	 30.0;
	7872	 10290	 0.0013	 0.01389	 0.0	 2695	 2695	 2695	 0.0	 0.0	 1	 -30.0	 30.0;
	6546	 10290	 0.00147	 0.01361	 0.0	 2747	 2747	 2747	 0.0	 0.0	 1	 -30.0	 30.0;
	884	 6381	 0.00052	 0.00446	 0.0	 8372	 8372	 8372	 0.0	 0.0	 1	 -30.0	 30.0;
	884	 6381	 0.00053	 0.00436	 0.0	 8559	 8559	 8559	 0.0	 0.0	 1	 -30.0	 30.0;
	4100	 11338	 0.014889	 0.05544	 0.0	 551	 551	 551	 0.0	 0.0	 1	 -30.0	 30.0;
	4100	 11338	 0.015178	 0.054289	 0.0	 561	 561	 561	 0.0	 0.0	 1	 -30.0	 30.0;
	3161	 4100	 0.003111	 0.013569	 0.0	 2270	 2270	 2270	 0.0	 0.0	 1	 -30.0	 30.0;
	9248	 4100	 0.000791	 0.00376	 0.0	 8221	 8221	 8221	 0.0	 0.0	 1	 -30.0	 30.0;
	4100	 10950	 0.002751	 0.009809	 0.0	 3101	 3101	 3101	 0.0	 0.0	 1	 -30.0	 30.0;
	4100	 13418	 0.007129	 0.024471	 0.0	 1240	 1240	 1240	 0.0	 0.0	 1	 -30.0	 30.0;
	4100	 13038	 0.017951	 0.0668	 0.0	 457	 457	 457	 0.0	 0.0	 1	 -30.0	 30.0;
	4100	 7546	 0.006178	 0.02812	 0.0	 1098	 1098	 1098	 0.0	 0.0	 1	 -30.0	 30.0;
	4100	 2406	 0.006049	 0.028649	 0.0	 1079	 1079	 1079	 0.0	 0.0	 1	 -30.0	 30.0;
	8853	 7298	 0.00396	 0.03136	 0.0	 1190	 1190	 1190	 0.0	 0.0	 1	 -30.0	 30.0;
	8853	 7298	 0.00353	 0.03554	 0.0	 1053	 1053	 1053	 0.0	 0.0	 1	 -30.0	 30.0;
	8853	 7298	 0.00387	 0.0331	 0.0	 1129	 1129	 1129	 0.0	 0.0	 1	 -30.0	 30.0;
	8853	 7298	 0.00394	 0.03239	 0.0	 1153	 1153	 1153	 0.0	 0.0	 1	 -30.0	 30.0;
	2812	 1780	 0.00225	 0.01786	 0.0	 2089	 2089	 2089	 0.0	 0.0	 1	 -30.0	 30.0;
	1780	 4404	 0.00124	 0.01101	 0.0	 3393	 3393	 3393	 0.0	 0.0	 1	 -30.0	 30.0;
	2812	 6546	 0.00201	 0.02024	 0.0	 1849	 1849	 1849	 0.0	 0.0	 1	 -30.0	 30.0;
	2812	 9129	 0.00197	 0.02063	 0.0	 1814	 1814	 1814	 0.0	 0.0	 1	 -30.0	 30.0;
	9129	 4404	 0.00126	 0.01078	 0.0	 3464	 3464	 3464	 0.0	 0.0	 1	 -30.0	 30.0;
	2812	 7872	 0.00193	 0.02103	 0.0	 1781	 1781	 1781	 0.0	 0.0	 1	 -30.0	 30.0;
	7208	 3755	 0.001209	 0.004551	 0.0	 6709	 6709	 6709	 0.0	 0.0	 1	 -30.0	 30.0;
	3755	 1866	 0.000449	 0.002018	 0.0	 15280	 15280	 15280	 0.0	 0.0	 1	 -30.0	 30.0;
	1515	 3755	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	10166	 5552	 0.007049	 0.0252	 0.0	 1450	 1450	 1450	 0.0	 0.0	 1	 -30.0	 30.0;
	11202	 10166	 0.001191	 0.003222	 0.0	 11045	 11045	 11045	 0.0	 0.0	 1	 -30.0	 30.0;
	10166	 1216	 0.000511	 0.001978	 0.0	 18401	 18401	 18401	 0.0	 0.0	 1	 -30.0	 30.0;
	10166	 10297	 0.001009	 0.004782	 0.0	 7763	 7763	 7763	 0.0	 0.0	 1	 -30.0	 30.0;
	10166	 4760	 0.000991	 0.004422	 0.0	 8372	 8372	 8372	 0.0	 0.0	 1	 -30.0	 30.0;
	13435	 3708	 0.000929	 0.003098	 0.0	 9767	 9767	 9767	 0.0	 0.0	 1	 -30.0	 30.0;
	5544	 13435	 0.005858	 0.0246	 0.0	 1250	 1250	 1250	 0.0	 0.0	 1	 -30.0	 30.0;
	2189	 5564	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	3883	 5564	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	7532	 12942	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	12942	 2788	 0.002031	 0.009222	 0.0	 3346	 3346	 3346	 0.0	 0.0	 1	 -30.0	 30.0;
	8689	 12942	 0.01036	 0.045231	 0.0	 681	 681	 681	 0.0	 0.0	 1	 -30.0	 30.0;
	12942	 3626	 0.026858	 0.062822	 0.0	 463	 463	 463	 0.0	 0.0	 1	 -30.0	 30.0;
	1159	 2788	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	2788	 3818	 0.021569	 0.098089	 0.0	 315	 315	 315	 0.0	 0.0	 1	 -30.0	 30.0;
	12471	 5564	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	6116	 7702	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	7702	 13161	 0.000418	 0.001769	 0.0	 17378	 17378	 17378	 0.0	 0.0	 1	 -30.0	 30.0;
	7702	 10729	 0.000409	 0.001809	 0.0	 17032	 17032	 17032	 0.0	 0.0	 1	 -30.0	 30.0;
	4334	 3266	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	8398	 9903	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	5953	 6748	 0.000569	 0.00168	 0.0	 17809	 17809	 17809	 0.0	 0.0	 1	 -30.0	 30.0;
	5953	 12924	 0.000582	 0.001649	 0.0	 18064	 18064	 18064	 0.0	 0.0	 1	 -30.0	 30.0;
	12924	 3263	 0.001858	 0.006911	 0.0	 4414	 4414	 4414	 0.0	 0.0	 1	 -30.0	 30.0;
	13637	 5953	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	7380	 413	 0.0154	 0.006022	 0.0	 2295	 2295	 2295	 0.0	 0.0	 1	 -30.0	 30.0;
	5083	 8627	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	8627	 13452	 8e-05	 0.0004	 0.0	 77435	 77435	 77435	 0.0	 0.0	 1	 -30.0	 30.0;
	8627	 8977	 9.8e-05	 0.000329	 0.0	 92015	 92015	 92015	 0.0	 0.0	 1	 -30.0	 30.0;
	3703	 13452	 0.023129	 0.076289	 0.0	 397	 397	 397	 0.0	 0.0	 1	 -30.0	 30.0;
	758	 8977	 0.011258	 0.047249	 0.0	 651	 651	 651	 0.0	 0.0	 1	 -30.0	 30.0;
	3703	 9201	 0.018822	 0.072271	 0.0	 423	 423	 423	 0.0	 0.0	 1	 -30.0	 30.0;
	3703	 11383	 0.002009	 0.006649	 0.0	 4548	 4548	 4548	 0.0	 0.0	 1	 -30.0	 30.0;
	3703	 6551	 0.000942	 0.00424	 0.0	 7273	 7273	 7273	 0.0	 0.0	 1	 -30.0	 30.0;
	3703	 13445	 0.017711	 0.060809	 0.0	 499	 499	 499	 0.0	 0.0	 1	 -30.0	 30.0;
	3703	 13445	 0.01804	 0.059489	 0.0	 509	 509	 509	 0.0	 0.0	 1	 -30.0	 30.0;
	8575	 8853	 0.0028	 0.03055	 0.0	 1226	 1226	 1226	 0.0	 0.0	 1	 -30.0	 30.0;
	8575	 8853	 0.00274	 0.03113	 0.0	 1203	 1203	 1203	 0.0	 0.0	 1	 -30.0	 30.0;
	12619	 5104	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	12680	 431	 0.0002	 0.000942	 0.0	 32802	 32802	 32802	 0.0	 0.0	 1	 -30.0	 30.0;
	5752	 1704	 0.004351	 0.014929	 0.0	 2032	 2032	 2032	 0.0	 0.0	 1	 -30.0	 30.0;
	5752	 12680	 0.004831	 0.017289	 0.0	 1760	 1760	 1760	 0.0	 0.0	 1	 -30.0	 30.0;
	7023	 11094	 0.014289	 0.067609	 0.0	 550	 550	 550	 0.0	 0.0	 1	 -30.0	 30.0;
	7023	 11094	 0.013978	 0.0626	 0.0	 592	 592	 592	 0.0	 0.0	 1	 -30.0	 30.0;
	5355	 5991	 0.004431	 0.014609	 0.0	 2070	 2070	 2070	 0.0	 0.0	 1	 -30.0	 30.0;
	5355	 6001	 0.00664	 0.025711	 0.0	 1190	 1190	 1190	 0.0	 0.0	 1	 -30.0	 30.0;
	5355	 10389	 0.001289	 0.004422	 0.0	 6858	 6858	 6858	 0.0	 0.0	 1	 -30.0	 30.0;
	5355	 2604	 0.01448	 0.065822	 0.0	 469	 469	 469	 0.0	 0.0	 1	 -30.0	 30.0;
	5355	 4813	 0.004631	 0.017938	 0.0	 1706	 1706	 1706	 0.0	 0.0	 1	 -30.0	 30.0;
	5355	 4813	 0.00492	 0.01692	 0.0	 1793	 1793	 1793	 0.0	 0.0	 1	 -30.0	 30.0;
	10857	 5104	 0.027511	 0.120182	 0.0	 257	 257	 257	 0.0	 0.0	 1	 -30.0	 30.0;
	1904	 5104	 0.004	 0.014898	 0.0	 2048	 2048	 2048	 0.0	 0.0	 1	 -30.0	 30.0;
	11261	 1240	 0.000351	 0.001591	 0.0	 19388	 19388	 19388	 0.0	 0.0	 1	 -30.0	 30.0;
	10857	 1240	 0.018929	 0.084791	 0.0	 364	 364	 364	 0.0	 0.0	 1	 -30.0	 30.0;
	2678	 1078	 0.013502	 0.063889	 0.0	 484	 484	 484	 0.0	 0.0	 1	 -30.0	 30.0;
	2658	 7823	 0.01632	 0.057871	 0.0	 631	 631	 631	 0.0	 0.0	 1	 -30.0	 30.0;
	11476	 3054	 0.0	 0.000222	 0.0	 169332	 169332	 169332	 0.0	 0.0	 1	 -30.0	 30.0;
	3778	 3054	 0.01176	 0.04704	 0.0	 776	 776	 776	 0.0	 0.0	 1	 -30.0	 30.0;
	9767	 11489	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	13355	 11489	 0.02892	 0.057622	 0.0	 490	 490	 490	 0.0	 0.0	 1	 -30.0	 30.0;
	3945	 6853	 0.001711	 0.0078	 0.0	 3956	 3956	 3956	 0.0	 0.0	 1	 -30.0	 30.0;
	3977	 6853	 0.01224	 0.042022	 0.0	 722	 722	 722	 0.0	 0.0	 1	 -30.0	 30.0;
	9485	 3117	 0.007769	 0.061249	 0.0	 512	 512	 512	 0.0	 0.0	 1	 -30.0	 30.0;
	13248	 9173	 0.001391	 0.0048	 0.0	 6321	 6321	 6321	 0.0	 0.0	 1	 -30.0	 30.0;
	6676	 13248	 0.004071	 0.01988	 0.0	 1557	 1557	 1557	 0.0	 0.0	 1	 -30.0	 30.0;
	11511	 9173	 0.001418	 0.004702	 0.0	 6432	 6432	 6432	 0.0	 0.0	 1	 -30.0	 30.0;
	11511	 4465	 0.012711	 0.048809	 0.0	 627	 627	 627	 0.0	 0.0	 1	 -30.0	 30.0;
	6556	 4531	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	11981	 9173	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	4531	 9173	 0.00448	 0.016698	 0.0	 1828	 1828	 1828	 0.0	 0.0	 1	 -30.0	 30.0;
	10144	 6676	 0.014689	 0.052049	 0.0	 585	 585	 585	 0.0	 0.0	 1	 -30.0	 30.0;
	4531	 252	 0.025631	 0.084538	 0.0	 358	 358	 358	 0.0	 0.0	 1	 -30.0	 30.0;
	13063	 3769	 0.005431	 0.026551	 0.0	 1166	 1166	 1166	 0.0	 0.0	 1	 -30.0	 30.0;
	3769	 6493	 0.013151	 0.058898	 0.0	 524	 524	 524	 0.0	 0.0	 1	 -30.0	 30.0;
	7410	 9398	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	5345	 1588	 0.00036	 0.001329	 0.0	 22941	 22941	 22941	 0.0	 0.0	 1	 -30.0	 30.0;
	8645	 12391	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	12515	 8645	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	12391	 8405	 0.00612	 0.014671	 0.0	 2387	 2387	 2387	 0.0	 0.0	 1	 -30.0	 30.0;
	10596	 12515	 0.006942	 0.014378	 0.0	 1979	 1979	 1979	 0.0	 0.0	 1	 -30.0	 30.0;
	12885	 1564	 4.9e-05	 0.00028	 0.0	 111124	 111124	 111124	 0.0	 0.0	 1	 -30.0	 30.0;
	6041	 12885	 0.002071	 0.008289	 0.0	 3698	 3698	 3698	 0.0	 0.0	 1	 -30.0	 30.0;
	7651	 1564	 4.9e-05	 0.00028	 0.0	 111124	 111124	 111124	 0.0	 0.0	 1	 -30.0	 30.0;
	7651	 10129	 0.000729	 0.003049	 0.0	 10076	 10076	 10076	 0.0	 0.0	 1	 -30.0	 30.0;
	3552	 1564	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	2947	 13578	 0.000409	 0.00184	 0.0	 16759	 16759	 16759	 0.0	 0.0	 1	 -30.0	 30.0;
	4270	 13578	 0.0004	 0.00188	 0.0	 16434	 16434	 16434	 0.0	 0.0	 1	 -30.0	 30.0;
	659	 10054	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	10054	 9962	 0.003982	 0.020249	 0.0	 1531	 1531	 1531	 0.0	 0.0	 1	 -30.0	 30.0;
	10054	 12676	 0.006498	 0.031791	 0.0	 974	 974	 974	 0.0	 0.0	 1	 -30.0	 30.0;
	13084	 9371	 0.000129	 0.000609	 0.0	 50742	 50742	 50742	 0.0	 0.0	 1	 -30.0	 30.0;
	13084	 895	 0.00036	 0.000729	 0.0	 38851	 38851	 38851	 0.0	 0.0	 1	 -30.0	 30.0;
	13084	 8847	 0.000129	 0.000569	 0.0	 54140	 54140	 54140	 0.0	 0.0	 1	 -30.0	 30.0;
	1547	 13084	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	8847	 791	 0.006862	 0.030942	 0.0	 997	 997	 997	 0.0	 0.0	 1	 -30.0	 30.0;
	4032	 6469	 0.0016	 0.00716	 0.0	 4306	 4306	 4306	 0.0	 0.0	 1	 -30.0	 30.0;
	4032	 11899	 0.001849	 0.006542	 0.0	 4647	 4647	 4647	 0.0	 0.0	 1	 -30.0	 30.0;
	1111	 6469	 0.001809	 0.007018	 0.0	 4359	 4359	 4359	 0.0	 0.0	 1	 -30.0	 30.0;
	1111	 2851	 0.004302	 0.01588	 0.0	 1920	 1920	 1920	 0.0	 0.0	 1	 -30.0	 30.0;
	4737	 6469	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	11338	 10013	 0.008831	 0.036751	 0.0	 836	 836	 836	 0.0	 0.0	 1	 -30.0	 30.0;
	11338	 93	 0.011031	 0.045942	 0.0	 669	 669	 669	 0.0	 0.0	 1	 -30.0	 30.0;
	9600	 11338	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	38	 11338	 0.043418	 0.124111	 0.0	 241	 241	 241	 0.0	 0.0	 1	 -30.0	 30.0;
	5787	 13161	 0.011698	 0.048702	 0.0	 631	 631	 631	 0.0	 0.0	 1	 -30.0	 30.0;
	12933	 6618	 0.005058	 0.02572	 0.0	 1206	 1206	 1206	 0.0	 0.0	 1	 -30.0	 30.0;
	5563	 6618	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	1938	 8769	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	12950	 12007	 0.008969	 0.032062	 0.0	 949	 949	 949	 0.0	 0.0	 1	 -30.0	 30.0;
	5780	 10263	 0.000489	 0.002369	 0.0	 13059	 13059	 13059	 0.0	 0.0	 1	 -30.0	 30.0;
	4579	 10263	 0.0028	 0.0096	 0.0	 3159	 3159	 3159	 0.0	 0.0	 1	 -30.0	 30.0;
	5780	 10495	 0.00048	 0.002191	 0.0	 14083	 14083	 14083	 0.0	 0.0	 1	 -30.0	 30.0;
	4579	 10495	 0.002849	 0.0094	 0.0	 3216	 3216	 3216	 0.0	 0.0	 1	 -30.0	 30.0;
	6923	 5780	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	6110	 12950	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	12022	 12950	 0.005138	 0.023391	 0.0	 1319	 1319	 1319	 0.0	 0.0	 1	 -30.0	 30.0;
	9821	 12950	 0.005031	 0.023831	 0.0	 1297	 1297	 1297	 0.0	 0.0	 1	 -30.0	 30.0;
	8781	 12950	 0.00492	 0.022062	 0.0	 1398	 1398	 1398	 0.0	 0.0	 1	 -30.0	 30.0;
	12950	 7225	 0.012449	 0.03368	 0.0	 880	 880	 880	 0.0	 0.0	 1	 -30.0	 30.0;
	6289	 7746	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	7109	 7746	 0.005582	 0.021622	 0.0	 1415	 1415	 1415	 0.0	 0.0	 1	 -30.0	 30.0;
	7746	 3645	 0.011769	 0.052729	 0.0	 585	 585	 585	 0.0	 0.0	 1	 -30.0	 30.0;
	2555	 12898	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	12725	 12898	 0.005489	 0.019618	 0.0	 1551	 1551	 1551	 0.0	 0.0	 1	 -30.0	 30.0;
	10926	 12898	 0.005591	 0.0192	 0.0	 1580	 1580	 1580	 0.0	 0.0	 1	 -30.0	 30.0;
	10279	 2173	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	10701	 12022	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	9821	 1446	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	2173	 1446	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	3924	 1525	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	551	 3924	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	1525	 625	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	625	 8781	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	4562	 10042	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	7522	 726	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	4562	 551	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	5876	 1742	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	472	 5876	 0.012969	 0.046369	 0.0	 657	 657	 657	 0.0	 0.0	 1	 -30.0	 30.0;
	1742	 5432	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	5432	 7109	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	726	 10701	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	11798	 10939	 0.003151	 0.00128	 0.0	 11053	 11053	 11053	 0.0	 0.0	 1	 -30.0	 30.0;
	2194	 463	 0.00154	 0.01649	 0.0	 2291	 2291	 2291	 0.0	 0.0	 1	 -30.0	 30.0;
	4579	 8523	 0.001298	 0.00568	 0.0	 5422	 5422	 5422	 0.0	 0.0	 1	 -30.0	 30.0;
	4579	 2613	 0.0002	 0.000871	 0.0	 35346	 35346	 35346	 0.0	 0.0	 1	 -30.0	 30.0;
	12972	 11637	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	13429	 11637	 4e-05	 0.00028	 0.0	 111679	 111679	 111679	 0.0	 0.0	 1	 -30.0	 30.0;
	4327	 11637	 4e-05	 0.00028	 0.0	 111679	 111679	 111679	 0.0	 0.0	 1	 -30.0	 30.0;
	4327	 12680	 0.010071	 0.039	 0.0	 785	 785	 785	 0.0	 0.0	 1	 -30.0	 30.0;
	6345	 7520	 0.000218	 0.000849	 0.0	 36037	 36037	 36037	 0.0	 0.0	 1	 -30.0	 30.0;
	2622	 7520	 0.000231	 0.00084	 0.0	 36258	 36258	 36258	 0.0	 0.0	 1	 -30.0	 30.0;
	8120	 7520	 0.000231	 0.000822	 0.0	 36995	 36995	 36995	 0.0	 0.0	 1	 -30.0	 30.0;
	9021	 7520	 0.00024	 0.0008	 0.0	 37819	 37819	 37819	 0.0	 0.0	 1	 -30.0	 30.0;
	13102	 7520	 0.00024	 0.000782	 0.0	 38616	 38616	 38616	 0.0	 0.0	 1	 -30.0	 30.0;
	7520	 9943	 0.000209	 0.000889	 0.0	 34589	 34589	 34589	 0.0	 0.0	 1	 -30.0	 30.0;
	15	 7520	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	4912	 7520	 0.000209	 0.000911	 0.0	 33796	 33796	 33796	 0.0	 0.0	 1	 -30.0	 30.0;
	7006	 2622	 0.00784	 0.025862	 0.0	 1169	 1169	 1169	 0.0	 0.0	 1	 -30.0	 30.0;
	8120	 8542	 0.001991	 0.009391	 0.0	 3291	 3291	 3291	 0.0	 0.0	 1	 -30.0	 30.0;
	9021	 7335	 0.003591	 0.01184	 0.0	 2554	 2554	 2554	 0.0	 0.0	 1	 -30.0	 30.0;
	11303	 790	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	2194	 2850	 0.00013	 0.00077	 0.0	 40451	 40451	 40451	 0.0	 0.0	 1	 -30.0	 30.0;
	1523	 2850	 0.00013	 0.00076	 0.0	 40968	 40968	 40968	 0.0	 0.0	 1	 -30.0	 30.0;
	1283	 2850	 0.0002	 0.00127	 0.0	 24570	 24570	 24570	 0.0	 0.0	 1	 -30.0	 30.0;
	6010	 1991	 0.002449	 0.006871	 0.0	 4331	 4331	 4331	 0.0	 0.0	 1	 -30.0	 30.0;
	3652	 10760	 0.00132	 0.004929	 0.0	 6191	 6191	 6191	 0.0	 0.0	 1	 -30.0	 30.0;
	8628	 3426	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	3426	 3626	 0.036111	 0.084471	 0.0	 344	 344	 344	 0.0	 0.0	 1	 -30.0	 30.0;
	3426	 5199	 0.043129	 0.093129	 0.0	 308	 308	 308	 0.0	 0.0	 1	 -30.0	 30.0;
	8769	 12458	 0.001071	 0.004129	 0.0	 7406	 7406	 7406	 0.0	 0.0	 1	 -30.0	 30.0;
	1671	 12458	 0.01016	 0.036298	 0.0	 839	 839	 839	 0.0	 0.0	 1	 -30.0	 30.0;
	1718	 8769	 0.010951	 0.055689	 0.0	 557	 557	 557	 0.0	 0.0	 1	 -30.0	 30.0;
	5736	 10359	 0.005831	 0.022591	 0.0	 1354	 1354	 1354	 0.0	 0.0	 1	 -30.0	 30.0;
	139	 10359	 0.016542	 0.075222	 0.0	 411	 411	 411	 0.0	 0.0	 1	 -30.0	 30.0;
	10359	 7759	 0.015938	 0.00716	 0.0	 1808	 1808	 1808	 0.0	 0.0	 1	 -30.0	 30.0;
	7909	 3749	 0.0	 0.000222	 0.0	 169332	 169332	 169332	 0.0	 0.0	 1	 -30.0	 30.0;
	3749	 803	 0.009591	 0.02332	 0.0	 1491	 1491	 1491	 0.0	 0.0	 1	 -30.0	 30.0;
	7909	 8405	 0.0	 0.000222	 0.0	 169332	 169332	 169332	 0.0	 0.0	 1	 -30.0	 30.0;
	3818	 3027	 0.03828	 0.10096	 0.0	 293	 293	 293	 0.0	 0.0	 1	 -30.0	 30.0;
	139	 3027	 0.03036	 0.086778	 0.0	 344	 344	 344	 0.0	 0.0	 1	 -30.0	 30.0;
	4838	 1824	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	11552	 3161	 0.002182	 0.010329	 0.0	 2993	 2993	 2993	 0.0	 0.0	 1	 -30.0	 30.0;
	11552	 6891	 0.002129	 0.009569	 0.0	 3223	 3223	 3223	 0.0	 0.0	 1	 -30.0	 30.0;
	8244	 13340	 0.0018	 0.00668	 0.0	 4566	 4566	 4566	 0.0	 0.0	 1	 -30.0	 30.0;
	3727	 13340	 0.004569	 0.01636	 0.0	 1860	 1860	 1860	 0.0	 0.0	 1	 -30.0	 30.0;
	8244	 4588	 0.001831	 0.006542	 0.0	 4650	 4650	 4650	 0.0	 0.0	 1	 -30.0	 30.0;
	3727	 6323	 0.006338	 0.026609	 0.0	 1155	 1155	 1155	 0.0	 0.0	 1	 -30.0	 30.0;
	9136	 10857	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	10857	 8862	 0.016231	 0.070902	 0.0	 435	 435	 435	 0.0	 0.0	 1	 -30.0	 30.0;
	10857	 12228	 0.010138	 0.046102	 0.0	 670	 670	 670	 0.0	 0.0	 1	 -30.0	 30.0;
	8599	 5040	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	5040	 13459	 0.006431	 0.028991	 0.0	 1064	 1064	 1064	 0.0	 0.0	 1	 -30.0	 30.0;
	3945	 9086	 0.01184	 0.053022	 0.0	 582	 582	 582	 0.0	 0.0	 1	 -30.0	 30.0;
	3945	 3977	 0.012529	 0.044422	 0.0	 685	 685	 685	 0.0	 0.0	 1	 -30.0	 30.0;
	11089	 8210	 0.00436	 0.010689	 0.0	 2737	 2737	 2737	 0.0	 0.0	 1	 -30.0	 30.0;
	7359	 11089	 0.019529	 0.055831	 0.0	 535	 535	 535	 0.0	 0.0	 1	 -30.0	 30.0;
	4600	 8210	 0.004942	 0.01048	 0.0	 2727	 2727	 2727	 0.0	 0.0	 1	 -30.0	 30.0;
	3157	 8210	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	1795	 7852	 0.006431	 0.01764	 0.0	 1683	 1683	 1683	 0.0	 0.0	 1	 -30.0	 30.0;
	6775	 1795	 4e-05	 0.00028	 0.0	 111679	 111679	 111679	 0.0	 0.0	 1	 -30.0	 30.0;
	13173	 7852	 0.003431	 0.013218	 0.0	 2314	 2314	 2314	 0.0	 0.0	 1	 -30.0	 30.0;
	8014	 7852	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	7852	 8667	 0.00708	 0.014702	 0.0	 1936	 1936	 1936	 0.0	 0.0	 1	 -30.0	 30.0;
	4854	 7852	 0.065422	 0.130311	 0.0	 217	 217	 217	 0.0	 0.0	 1	 -30.0	 30.0;
	13173	 2992	 0.003049	 0.013831	 0.0	 2231	 2231	 2231	 0.0	 0.0	 1	 -30.0	 30.0;
	9985	 13173	 0.011209	 0.051009	 0.0	 605	 605	 605	 0.0	 0.0	 1	 -30.0	 30.0;
	4591	 13173	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	11769	 13173	 0.00504	 0.024622	 0.0	 1257	 1257	 1257	 0.0	 0.0	 1	 -30.0	 30.0;
	3269	 2992	 0.009049	 0.033671	 0.0	 906	 906	 906	 0.0	 0.0	 1	 -30.0	 30.0;
	9011	 2992	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	6775	 9716	 4e-05	 0.00028	 0.0	 111679	 111679	 111679	 0.0	 0.0	 1	 -30.0	 30.0;
	7025	 6775	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	9985	 8667	 0.007631	 0.015569	 0.0	 1822	 1822	 1822	 0.0	 0.0	 1	 -30.0	 30.0;
	9985	 3516	 0.000822	 0.00316	 0.0	 9675	 9675	 9675	 0.0	 0.0	 1	 -30.0	 30.0;
	9985	 9672	 0.017751	 0.060929	 0.0	 498	 498	 498	 0.0	 0.0	 1	 -30.0	 30.0;
	3269	 9716	 0.007418	 0.016022	 0.0	 1790	 1790	 1790	 0.0	 0.0	 1	 -30.0	 30.0;
	3269	 13358	 0.007542	 0.035689	 0.0	 866	 866	 866	 0.0	 0.0	 1	 -30.0	 30.0;
	13216	 689	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	689	 1837	 0.000338	 0.001218	 0.0	 24990	 24990	 24990	 0.0	 0.0	 1	 -30.0	 30.0;
	7603	 255	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	255	 11434	 0.000351	 0.001191	 0.0	 25440	 25440	 25440	 0.0	 0.0	 1	 -30.0	 30.0;
	10145	 1671	 0.004662	 0.016009	 0.0	 1895	 1895	 1895	 0.0	 0.0	 1	 -30.0	 30.0;
	10145	 12370	 0.017489	 0.084191	 0.0	 368	 368	 368	 0.0	 0.0	 1	 -30.0	 30.0;
	1671	 37	 0.003809	 0.013111	 0.0	 2314	 2314	 2314	 0.0	 0.0	 1	 -30.0	 30.0;
	1671	 8886	 0.003489	 0.013502	 0.0	 2266	 2266	 2266	 0.0	 0.0	 1	 -30.0	 30.0;
	5345	 1671	 0.004738	 0.015658	 0.0	 1931	 1931	 1931	 0.0	 0.0	 1	 -30.0	 30.0;
	11548	 1671	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	1671	 3692	 0.010351	 0.035529	 0.0	 854	 854	 854	 0.0	 0.0	 1	 -30.0	 30.0;
	1671	 4098	 0.00388	 0.012822	 0.0	 2358	 2358	 2358	 0.0	 0.0	 1	 -30.0	 30.0;
	1837	 37	 0.003729	 0.013218	 0.0	 2300	 2300	 2300	 0.0	 0.0	 1	 -30.0	 30.0;
	8886	 10370	 0.002418	 0.008298	 0.0	 3655	 3655	 3655	 0.0	 0.0	 1	 -30.0	 30.0;
	11434	 10370	 0.001538	 0.007822	 0.0	 3963	 3963	 3963	 0.0	 0.0	 1	 -30.0	 30.0;
	1824	 1480	 0.005369	 0.010702	 0.0	 2639	 2639	 2639	 0.0	 0.0	 1	 -30.0	 30.0;
	4835	 4568	 0.00088	 0.0075	 0.0	 4183	 4183	 4183	 0.0	 0.0	 1	 -30.0	 30.0;
	4835	 4568	 0.0009	 0.00734	 0.0	 4272	 4272	 4272	 0.0	 0.0	 1	 -30.0	 30.0;
	11826	 10596	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	2239	 12284	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	11826	 12284	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	8670	 12284	 0.018831	 0.072951	 0.0	 420	 420	 420	 0.0	 0.0	 1	 -30.0	 30.0;
	9111	 12284	 0.012351	 0.042409	 0.0	 716	 716	 716	 0.0	 0.0	 1	 -30.0	 30.0;
	7359	 5736	 0.001938	 0.008698	 0.0	 3545	 3545	 3545	 0.0	 0.0	 1	 -30.0	 30.0;
	2915	 7359	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	9423	 12804	 0.017871	 0.047151	 0.0	 627	 627	 627	 0.0	 0.0	 1	 -30.0	 30.0;
	12804	 973	 0.00076	 0.002098	 0.0	 14156	 14156	 14156	 0.0	 0.0	 1	 -30.0	 30.0;
	7823	 7380	 0.0	 0.000222	 0.0	 169332	 169332	 169332	 0.0	 0.0	 1	 -30.0	 30.0;
	11730	 3692	 0.005249	 0.024631	 0.0	 1255	 1255	 1255	 0.0	 0.0	 1	 -30.0	 30.0;
	13364	 11730	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	2463	 5869	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	12546	 5869	 0.00016	 0.000502	 0.0	 59952	 59952	 59952	 0.0	 0.0	 1	 -30.0	 30.0;
	5570	 12546	 0.008658	 0.037809	 0.0	 815	 815	 815	 0.0	 0.0	 1	 -30.0	 30.0;
	8862	 5869	 0.000142	 0.00056	 0.0	 54676	 54676	 54676	 0.0	 0.0	 1	 -30.0	 30.0;
	9877	 9423	 4e-05	 0.00028	 0.0	 111679	 111679	 111679	 0.0	 0.0	 1	 -30.0	 30.0;
	9877	 8171	 4e-05	 0.00028	 0.0	 111679	 111679	 111679	 0.0	 0.0	 1	 -30.0	 30.0;
	10950	 4561	 0.0002	 0.00092	 0.0	 33551	 33551	 33551	 0.0	 0.0	 1	 -30.0	 30.0;
	4561	 1858	 0.002542	 0.010649	 0.0	 2886	 2886	 2886	 0.0	 0.0	 1	 -30.0	 30.0;
	9248	 38	 0.054	 0.121351	 0.0	 238	 238	 238	 0.0	 0.0	 1	 -30.0	 30.0;
	9645	 10950	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	5045	 6287	 0.001969	 0.004271	 0.0	 6717	 6717	 6717	 0.0	 0.0	 1	 -30.0	 30.0;
	5045	 4854	 0.009111	 0.025009	 0.0	 1187	 1187	 1187	 0.0	 0.0	 1	 -30.0	 30.0;
	2472	 5045	 0.027502	 0.074369	 0.0	 399	 399	 399	 0.0	 0.0	 1	 -30.0	 30.0;
	11562	 9894	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	9894	 5264	 0.0002	 0.000942	 0.0	 32802	 32802	 32802	 0.0	 0.0	 1	 -30.0	 30.0;
	9894	 9962	 0.0002	 0.000871	 0.0	 35346	 35346	 35346	 0.0	 0.0	 1	 -30.0	 30.0;
	2830	 13105	 0.00052	 0.00136	 0.0	 21695	 21695	 21695	 0.0	 0.0	 1	 -30.0	 30.0;
	4592	 2830	 0.020471	 0.07928	 0.0	 386	 386	 386	 0.0	 0.0	 1	 -30.0	 30.0;
	7097	 1198	 3.1e-05	 0.00028	 0.0	 112127	 112127	 112127	 0.0	 0.0	 1	 -30.0	 30.0;
	9090	 1198	 0.015609	 0.076289	 0.0	 406	 406	 406	 0.0	 0.0	 1	 -30.0	 30.0;
	7097	 11769	 3.1e-05	 0.00028	 0.0	 112127	 112127	 112127	 0.0	 0.0	 1	 -30.0	 30.0;
	3398	 7097	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	12426	 10685	 0.008809	 0.041342	 0.0	 748	 748	 748	 0.0	 0.0	 1	 -30.0	 30.0;
	12867	 10685	 0.011698	 0.017782	 0.0	 1485	 1485	 1485	 0.0	 0.0	 1	 -30.0	 30.0;
	5954	 12426	 0.029769	 0.069649	 0.0	 418	 418	 418	 0.0	 0.0	 1	 -30.0	 30.0;
	13642	 8302	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	8670	 8302	 0.006738	 0.024089	 0.0	 1263	 1263	 1263	 0.0	 0.0	 1	 -30.0	 30.0;
	13642	 11958	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	1947	 13642	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	12710	 2	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	9010	 3652	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	2	 3652	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	1244	 2	 0.001062	 0.003649	 0.0	 8312	 8312	 8312	 0.0	 0.0	 1	 -30.0	 30.0;
	3818	 2545	 0.00204	 0.009129	 0.0	 3377	 3377	 3377	 0.0	 0.0	 1	 -30.0	 30.0;
	3818	 2545	 0.00232	 0.008951	 0.0	 3417	 3417	 3417	 0.0	 0.0	 1	 -30.0	 30.0;
	3818	 11951	 0.00152	 0.006911	 0.0	 4464	 4464	 4464	 0.0	 0.0	 1	 -30.0	 30.0;
	3818	 11951	 0.001489	 0.00704	 0.0	 4390	 4390	 4390	 0.0	 0.0	 1	 -30.0	 30.0;
	3818	 11951	 0.001462	 0.00652	 0.0	 4728	 4728	 4728	 0.0	 0.0	 1	 -30.0	 30.0;
	3818	 12944	 0.001391	 0.003609	 0.0	 8167	 8167	 8167	 0.0	 0.0	 1	 -30.0	 30.0;
	3818	 12233	 0.001658	 0.003311	 0.0	 8531	 8531	 8531	 0.0	 0.0	 1	 -30.0	 30.0;
	3818	 11995	 0.000991	 0.004329	 0.0	 7113	 7113	 7113	 0.0	 0.0	 1	 -30.0	 30.0;
	3818	 3851	 0.010369	 0.038569	 0.0	 791	 791	 791	 0.0	 0.0	 1	 -30.0	 30.0;
	318	 2545	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	318	 8789	 0.026809	 0.126889	 0.0	 244	 244	 244	 0.0	 0.0	 1	 -30.0	 30.0;
	12755	 2545	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	12755	 12479	 0.026218	 0.117489	 0.0	 263	 263	 263	 0.0	 0.0	 1	 -30.0	 30.0;
	11951	 2545	 0.00064	 0.002662	 0.0	 11538	 11538	 11538	 0.0	 0.0	 1	 -30.0	 30.0;
	11951	 2545	 0.000622	 0.002711	 0.0	 11357	 11357	 11357	 0.0	 0.0	 1	 -30.0	 30.0;
	11951	 126	 0.000609	 0.002271	 0.0	 13435	 13435	 13435	 0.0	 0.0	 1	 -30.0	 30.0;
	6818	 12944	 0.002098	 0.005702	 0.0	 5199	 5199	 5199	 0.0	 0.0	 1	 -30.0	 30.0;
	5791	 12233	 0.002582	 0.006031	 0.0	 4815	 4815	 4815	 0.0	 0.0	 1	 -30.0	 30.0;
	6022	 5791	 0.019458	 0.055618	 0.0	 537	 537	 537	 0.0	 0.0	 1	 -30.0	 30.0;
	12956	 11995	 0.00092	 0.003289	 0.0	 9249	 9249	 9249	 0.0	 0.0	 1	 -30.0	 30.0;
	12956	 126	 0.000942	 0.003222	 0.0	 9410	 9410	 9410	 0.0	 0.0	 1	 -30.0	 30.0;
	12120	 12956	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	6818	 8949	 0.03868	 0.1062	 0.0	 280	 280	 280	 0.0	 0.0	 1	 -30.0	 30.0;
	8465	 13561	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	3433	 13561	 0.000689	 0.00312	 0.0	 9886	 9886	 9886	 0.0	 0.0	 1	 -30.0	 30.0;
	472	 13561	 0.0008	 0.002991	 0.0	 10203	 10203	 10203	 0.0	 0.0	 1	 -30.0	 30.0;
	8794	 12379	 0.000511	 0.001191	 0.0	 24374	 24374	 24374	 0.0	 0.0	 1	 -30.0	 30.0;
	13094	 7635	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	3626	 3979	 0.01216	 0.048609	 0.0	 631	 631	 631	 0.0	 0.0	 1	 -30.0	 30.0;
	5665	 3851	 0.000769	 0.00348	 0.0	 8864	 8864	 8864	 0.0	 0.0	 1	 -30.0	 30.0;
	5665	 8689	 0.000871	 0.003409	 0.0	 8978	 8978	 8978	 0.0	 0.0	 1	 -30.0	 30.0;
	9201	 13445	 0.007071	 0.03316	 0.0	 932	 932	 932	 0.0	 0.0	 1	 -30.0	 30.0;
	791	 12740	 0.009609	 0.038418	 0.0	 798	 798	 798	 0.0	 0.0	 1	 -30.0	 30.0;
	1101	 791	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	12836	 12740	 0.00724	 0.014951	 0.0	 1902	 1902	 1902	 0.0	 0.0	 1	 -30.0	 30.0;
	4720	 6323	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	11747	 6323	 0.016071	 0.067418	 0.0	 456	 456	 456	 0.0	 0.0	 1	 -30.0	 30.0;
	11747	 6323	 0.015738	 0.068751	 0.0	 448	 448	 448	 0.0	 0.0	 1	 -30.0	 30.0;
	6323	 10133	 0.017431	 0.037622	 0.0	 762	 762	 762	 0.0	 0.0	 1	 -30.0	 30.0;
	5269	 2185	 0.001031	 0.003378	 0.0	 8944	 8944	 8944	 0.0	 0.0	 1	 -30.0	 30.0;
	2185	 11780	 0.000169	 0.00068	 0.0	 45081	 45081	 45081	 0.0	 0.0	 1	 -30.0	 30.0;
	2406	 5269	 0.006249	 0.023262	 0.0	 1312	 1312	 1312	 0.0	 0.0	 1	 -30.0	 30.0;
	13418	 9977	 8.9e-05	 0.000471	 0.0	 65899	 65899	 65899	 0.0	 0.0	 1	 -30.0	 30.0;
	4308	 3778	 0.0	 0.000222	 0.0	 169332	 169332	 169332	 0.0	 0.0	 1	 -30.0	 30.0;
	6236	 3778	 0.01564	 0.065089	 0.0	 562	 562	 562	 0.0	 0.0	 1	 -30.0	 30.0;
	3778	 7102	 0.018938	 0.085391	 0.0	 434	 434	 434	 0.0	 0.0	 1	 -30.0	 30.0;
	3778	 2100	 0.016511	 0.044662	 0.0	 790	 790	 790	 0.0	 0.0	 1	 -30.0	 30.0;
	415	 758	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	758	 12836	 0.002689	 0.012938	 0.0	 2391	 2391	 2391	 0.0	 0.0	 1	 -30.0	 30.0;
	7420	 4115	 0.0	 0.000222	 0.0	 169332	 169332	 169332	 0.0	 0.0	 1	 -30.0	 30.0;
	1171	 7420	 0.007649	 0.019631	 0.0	 1785	 1785	 1785	 0.0	 0.0	 1	 -30.0	 30.0;
	9127	 540	 0.008849	 0.02096	 0.0	 1653	 1653	 1653	 0.0	 0.0	 1	 -30.0	 30.0;
	4115	 9127	 0.0	 0.000222	 0.0	 169332	 169332	 169332	 0.0	 0.0	 1	 -30.0	 30.0;
	540	 7091	 0.0	 0.00028	 0.0	 134256	 134256	 134256	 0.0	 0.0	 1	 -30.0	 30.0;
	16	 3402	 0.00232	 0.00928	 0.0	 3303	 3303	 3303	 0.0	 0.0	 1	 -30.0	 30.0;
	3859	 2169	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	9672	 8528	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	4957	 3155	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	8568	 4957	 0.0088	 0.034102	 0.0	 897	 897	 897	 0.0	 0.0	 1	 -30.0	 30.0;
	10822	 7204	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	7445	 4731	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	12005	 6010	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	7882	 2295	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	11531	 11277	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	11293	 7684	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	9940	 12239	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	12239	 3590	 0.002542	 0.00392	 0.0	 6761	 6761	 6761	 0.0	 0.0	 1	 -30.0	 30.0;
	2911	 6701	 0.00296	 0.013462	 0.0	 2292	 2292	 2292	 0.0	 0.0	 1	 -30.0	 30.0;
	11664	 2911	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	2911	 4489	 0.002489	 0.003991	 0.0	 6716	 6716	 6716	 0.0	 0.0	 1	 -30.0	 30.0;
	1110	 7413	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	11728	 7413	 0.000289	 0.000742	 0.0	 39668	 39668	 39668	 0.0	 0.0	 1	 -30.0	 30.0;
	11038	 7469	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	3708	 7469	 0.000302	 0.000729	 0.0	 40031	 40031	 40031	 0.0	 0.0	 1	 -30.0	 30.0;
	7469	 10191	 0.000662	 0.002111	 0.0	 14278	 14278	 14278	 0.0	 0.0	 1	 -30.0	 30.0;
	6468	 1715	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	9560	 2295	 0.000822	 0.002871	 0.0	 10578	 10578	 10578	 0.0	 0.0	 1	 -30.0	 30.0;
	2295	 12853	 0.006391	 0.028809	 0.0	 1071	 1071	 1071	 0.0	 0.0	 1	 -30.0	 30.0;
	4046	 11277	 0.000831	 0.002809	 0.0	 10784	 10784	 10784	 0.0	 0.0	 1	 -30.0	 30.0;
	9952	 9560	 0.014791	 0.005969	 0.0	 1981	 1981	 1981	 0.0	 0.0	 1	 -30.0	 30.0;
	6334	 4046	 0.01508	 0.005849	 0.0	 1953	 1953	 1953	 0.0	 0.0	 1	 -30.0	 30.0;
	6256	 7684	 0.011302	 0.050578	 0.0	 610	 610	 610	 0.0	 0.0	 1	 -30.0	 30.0;
	8794	 7684	 0.01704	 0.033938	 0.0	 832	 832	 832	 0.0	 0.0	 1	 -30.0	 30.0;
	12444	 7862	 0.001262	 0.00532	 0.0	 5778	 5778	 5778	 0.0	 0.0	 1	 -30.0	 30.0;
	12444	 2851	 0.00124	 0.005431	 0.0	 5671	 5671	 5671	 0.0	 0.0	 1	 -30.0	 30.0;
	9212	 529	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	529	 7366	 0.001538	 0.004609	 0.0	 6502	 6502	 6502	 0.0	 0.0	 1	 -30.0	 30.0;
	1841	 12936	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	3863	 8761	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	12214	 8761	 0.00244	 0.004071	 0.0	 6656	 6656	 6656	 0.0	 0.0	 1	 -30.0	 30.0;
	3150	 7500	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	8100	 7500	 0.002649	 0.003631	 0.0	 7028	 7028	 7028	 0.0	 0.0	 1	 -30.0	 30.0;
	7277	 13318	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	3630	 1941	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	12190	 8523	 0.000849	 0.001769	 0.0	 16099	 16099	 16099	 0.0	 0.0	 1	 -30.0	 30.0;
	8523	 11559	 0.000951	 0.003991	 0.0	 7700	 7700	 7700	 0.0	 0.0	 1	 -30.0	 30.0;
	6881	 7091	 0.0	 0.000222	 0.0	 169332	 169332	 169332	 0.0	 0.0	 1	 -30.0	 30.0;
	6881	 11618	 0.0034	 0.00872	 0.0	 4017	 4017	 4017	 0.0	 0.0	 1	 -30.0	 30.0;
	10016	 11747	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	1715	 11291	 0.001978	 0.007671	 0.0	 3988	 3988	 3988	 0.0	 0.0	 1	 -30.0	 30.0;
	1715	 1270	 0.002018	 0.00752	 0.0	 4057	 4057	 4057	 0.0	 0.0	 1	 -30.0	 30.0;
	7130	 6236	 0.0	 0.000222	 0.0	 169332	 169332	 169332	 0.0	 0.0	 1	 -30.0	 30.0;
	6236	 1357	 0.018351	 0.070502	 0.0	 517	 517	 517	 0.0	 0.0	 1	 -30.0	 30.0;
	12370	 6902	 0.0028	 0.014209	 0.0	 2182	 2182	 2182	 0.0	 0.0	 1	 -30.0	 30.0;
	10801	 13319	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	10823	 2277	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	10129	 2277	 0.02624	 0.096858	 0.0	 315	 315	 315	 0.0	 0.0	 1	 -30.0	 30.0;
	662	 8650	 5.8e-05	 0.00024	 0.0	 127932	 127932	 127932	 0.0	 0.0	 1	 -30.0	 30.0;
	662	 10389	 5.8e-05	 0.000231	 0.0	 132626	 132626	 132626	 0.0	 0.0	 1	 -30.0	 30.0;
	9555	 6001	 0.0012	 0.005809	 0.0	 5326	 5326	 5326	 0.0	 0.0	 1	 -30.0	 30.0;
	9555	 11034	 8.9e-05	 0.00028	 0.0	 107512	 107512	 107512	 0.0	 0.0	 1	 -30.0	 30.0;
	9555	 9329	 8e-05	 0.00032	 0.0	 95764	 95764	 95764	 0.0	 0.0	 1	 -30.0	 30.0;
	11034	 4813	 0.006889	 0.032631	 0.0	 948	 948	 948	 0.0	 0.0	 1	 -30.0	 30.0;
	9329	 4813	 0.006738	 0.030209	 0.0	 1021	 1021	 1021	 0.0	 0.0	 1	 -30.0	 30.0;
	5529	 4213	 0.001218	 0.004031	 0.0	 7502	 7502	 7502	 0.0	 0.0	 1	 -30.0	 30.0;
	4213	 8794	 0.005751	 0.012929	 0.0	 2233	 2233	 2233	 0.0	 0.0	 1	 -30.0	 30.0;
	232	 5552	 0.000462	 0.001791	 0.0	 17078	 17078	 17078	 0.0	 0.0	 1	 -30.0	 30.0;
	232	 9100	 0.00352	 0.007302	 0.0	 3897	 3897	 3897	 0.0	 0.0	 1	 -30.0	 30.0;
	6800	 7208	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	6576	 3064	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	1871	 8225	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	8225	 1402	 0.001289	 0.005022	 0.0	 6093	 6093	 6093	 0.0	 0.0	 1	 -30.0	 30.0;
	4192	 11865	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	6198	 12853	 0.00036	 0.0016	 0.0	 19261	 19261	 19261	 0.0	 0.0	 1	 -30.0	 30.0;
	6198	 7427	 0.000409	 0.001569	 0.0	 19482	 19482	 19482	 0.0	 0.0	 1	 -30.0	 30.0;
	10477	 6198	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	12026	 6198	 0.001658	 0.004511	 0.0	 6573	 6573	 6573	 0.0	 0.0	 1	 -30.0	 30.0;
	8670	 3741	 0.00176	 0.007911	 0.0	 3898	 3898	 3898	 0.0	 0.0	 1	 -30.0	 30.0;
	1402	 8670	 0.00172	 0.008058	 0.0	 3834	 3834	 3834	 0.0	 0.0	 1	 -30.0	 30.0;
	9095	 8670	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	2051	 12853	 0.0022	 0.00852	 0.0	 3590	 3590	 3590	 0.0	 0.0	 1	 -30.0	 30.0;
	11044	 7427	 0.000111	 0.000489	 0.0	 62994	 62994	 62994	 0.0	 0.0	 1	 -30.0	 30.0;
	11044	 12876	 0.00396	 0.013058	 0.0	 2315	 2315	 2315	 0.0	 0.0	 1	 -30.0	 30.0;
	3741	 13013	 0.001138	 0.002529	 0.0	 11391	 11391	 11391	 0.0	 0.0	 1	 -30.0	 30.0;
	12767	 1347	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	13284	 12767	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	12767	 3829	 0.001329	 0.005978	 0.0	 5159	 5159	 5159	 0.0	 0.0	 1	 -30.0	 30.0;
	7837	 11486	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	7980	 9562	 0.0	 0.000222	 0.0	 169332	 169332	 169332	 0.0	 0.0	 1	 -30.0	 30.0;
	9562	 11618	 0.0	 0.000222	 0.0	 169332	 169332	 169332	 0.0	 0.0	 1	 -30.0	 30.0;
	7980	 4807	 0.010191	 0.028329	 0.0	 1249	 1249	 1249	 0.0	 0.0	 1	 -30.0	 30.0;
	2614	 13102	 0.002391	 0.00788	 0.0	 3836	 3836	 3836	 0.0	 0.0	 1	 -30.0	 30.0;
	1513	 2614	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	8542	 2614	 0.002249	 0.008351	 0.0	 3653	 3653	 3653	 0.0	 0.0	 1	 -30.0	 30.0;
	8927	 4374	 0.000302	 0.000969	 0.0	 31122	 31122	 31122	 0.0	 0.0	 1	 -30.0	 30.0;
	3505	 1933	 0.000271	 0.001102	 0.0	 27835	 27835	 27835	 0.0	 0.0	 1	 -30.0	 30.0;
	9943	 8927	 0.000391	 0.001738	 0.0	 17732	 17732	 17732	 0.0	 0.0	 1	 -30.0	 30.0;
	3505	 4912	 0.002289	 0.008178	 0.0	 3720	 3720	 3720	 0.0	 0.0	 1	 -30.0	 30.0;
	10262	 8542	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	8542	 7006	 0.00112	 0.00504	 0.0	 6119	 6119	 6119	 0.0	 0.0	 1	 -30.0	 30.0;
	8542	 7006	 0.001271	 0.004942	 0.0	 6191	 6191	 6191	 0.0	 0.0	 1	 -30.0	 30.0;
	4758	 7006	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	7006	 10590	 0.000418	 0.00192	 0.0	 16076	 16076	 16076	 0.0	 0.0	 1	 -30.0	 30.0;
	7006	 6571	 0.000409	 0.001951	 0.0	 15846	 15846	 15846	 0.0	 0.0	 1	 -30.0	 30.0;
	7006	 139	 0.03228	 0.106458	 0.0	 284	 284	 284	 0.0	 0.0	 1	 -30.0	 30.0;
	7006	 139	 0.02876	 0.120649	 0.0	 255	 255	 255	 0.0	 0.0	 1	 -30.0	 30.0;
	6571	 139	 0.05888	 0.117289	 0.0	 241	 241	 241	 0.0	 0.0	 1	 -30.0	 30.0;
	10129	 11862	 0.00324	 0.01584	 0.0	 1954	 1954	 1954	 0.0	 0.0	 1	 -30.0	 30.0;
	1811	 11862	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	5491	 11301	 0.00176	 0.004449	 0.0	 6603	 6603	 6603	 0.0	 0.0	 1	 -30.0	 30.0;
	12113	 1429	 0.009929	 0.046969	 0.0	 658	 658	 658	 0.0	 0.0	 1	 -30.0	 30.0;
	12113	 3053	 0.009711	 0.043489	 0.0	 709	 709	 709	 0.0	 0.0	 1	 -30.0	 30.0;
	1904	 3053	 0.005031	 0.02252	 0.0	 1369	 1369	 1369	 0.0	 0.0	 1	 -30.0	 30.0;
	1888	 7366	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	8443	 9410	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	10832	 9410	 0.000462	 0.00108	 0.0	 26891	 26891	 26891	 0.0	 0.0	 1	 -30.0	 30.0;
	11929	 7366	 0.000471	 0.001049	 0.0	 27470	 27470	 27470	 0.0	 0.0	 1	 -30.0	 30.0;
	12026	 2051	 0.00104	 0.003729	 0.0	 8160	 8160	 8160	 0.0	 0.0	 1	 -30.0	 30.0;
	12351	 7620	 0.002329	 0.008	 0.0	 3792	 3792	 3792	 0.0	 0.0	 1	 -30.0	 30.0;
	13038	 7620	 0.002378	 0.007831	 0.0	 3860	 3860	 3860	 0.0	 0.0	 1	 -30.0	 30.0;
	2864	 7620	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	878	 1904	 0.006711	 0.026018	 0.0	 1176	 1176	 1176	 0.0	 0.0	 1	 -30.0	 30.0;
	1904	 2466	 0.009298	 0.04232	 0.0	 730	 730	 730	 0.0	 0.0	 1	 -30.0	 30.0;
	13543	 13088	 0.004751	 0.01632	 0.0	 1859	 1859	 1859	 0.0	 0.0	 1	 -30.0	 30.0;
	3976	 2701	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	2701	 4465	 0.000338	 0.001151	 0.0	 26332	 26332	 26332	 0.0	 0.0	 1	 -30.0	 30.0;
	2701	 9090	 0.000338	 0.00112	 0.0	 27001	 27001	 27001	 0.0	 0.0	 1	 -30.0	 30.0;
	8899	 11202	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	11094	 690	 0.00484	 0.023329	 0.0	 1326	 1326	 1326	 0.0	 0.0	 1	 -30.0	 30.0;
	7525	 9952	 0.004222	 0.017751	 0.0	 1732	 1732	 1732	 0.0	 0.0	 1	 -30.0	 30.0;
	1650	 6334	 0.004138	 0.018102	 0.0	 1702	 1702	 1702	 0.0	 0.0	 1	 -30.0	 30.0;
	12224	 4834	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	12224	 1737	 0.000622	 0.002418	 0.0	 12652	 12652	 12652	 0.0	 0.0	 1	 -30.0	 30.0;
	4834	 923	 0.000631	 0.002369	 0.0	 12885	 12885	 12885	 0.0	 0.0	 1	 -30.0	 30.0;
	11383	 13114	 0.00012	 0.00032	 0.0	 92426	 92426	 92426	 0.0	 0.0	 1	 -30.0	 30.0;
	11844	 7682	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	1581	 5954	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	3218	 4489	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	12263	 3590	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	8591	 914	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	4976	 10890	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	3241	 12680	 0.001409	 0.00464	 0.0	 6514	 6514	 6514	 0.0	 0.0	 1	 -30.0	 30.0;
	2472	 3241	 0.003098	 0.014911	 0.0	 2075	 2075	 2075	 0.0	 0.0	 1	 -30.0	 30.0;
	12680	 3716	 0.004662	 0.015369	 0.0	 1967	 1967	 1967	 0.0	 0.0	 1	 -30.0	 30.0;
	173	 13579	 9.8e-05	 0.000369	 0.0	 82735	 82735	 82735	 0.0	 0.0	 1	 -30.0	 30.0;
	12680	 173	 0.001031	 0.003658	 0.0	 8312	 8312	 8312	 0.0	 0.0	 1	 -30.0	 30.0;
	4813	 8368	 0.001049	 0.003591	 0.0	 8444	 8444	 8444	 0.0	 0.0	 1	 -30.0	 30.0;
	8988	 5436	 0.003209	 0.012338	 0.0	 2478	 2478	 2478	 0.0	 0.0	 1	 -30.0	 30.0;
	4098	 8988	 0.003311	 0.012689	 0.0	 2409	 2409	 2409	 0.0	 0.0	 1	 -30.0	 30.0;
	11744	 3626	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	139	 554	 0.003871	 0.010458	 0.0	 2833	 2833	 2833	 0.0	 0.0	 1	 -30.0	 30.0;
	12479	 139	 0.000218	 0.000849	 0.0	 36037	 36037	 36037	 0.0	 0.0	 1	 -30.0	 30.0;
	8789	 139	 0.000231	 0.00084	 0.0	 36258	 36258	 36258	 0.0	 0.0	 1	 -30.0	 30.0;
	13553	 139	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	554	 4079	 0.000231	 0.000822	 0.0	 36995	 36995	 36995	 0.0	 0.0	 1	 -30.0	 30.0;
	5199	 4079	 0.00024	 0.0008	 0.0	 37819	 37819	 37819	 0.0	 0.0	 1	 -30.0	 30.0;
	3373	 4079	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	8235	 1718	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	3660	 8551	 0.000151	 0.00036	 0.0	 80914	 80914	 80914	 0.0	 0.0	 1	 -30.0	 30.0;
	3660	 12214	 8e-05	 0.00028	 0.0	 108472	 108472	 108472	 0.0	 0.0	 1	 -30.0	 30.0;
	1540	 8100	 8e-05	 0.00028	 0.0	 108472	 108472	 108472	 0.0	 0.0	 1	 -30.0	 30.0;
	1971	 3660	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	3660	 1540	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	3175	 1540	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	2722	 12881	 0.001711	 0.003058	 0.0	 9015	 9015	 9015	 0.0	 0.0	 1	 -30.0	 30.0;
	11559	 2722	 0.003369	 0.008889	 0.0	 3323	 3323	 3323	 0.0	 0.0	 1	 -30.0	 30.0;
	2495	 12881	 0.002009	 0.005311	 0.0	 5563	 5563	 5563	 0.0	 0.0	 1	 -30.0	 30.0;
	4250	 2495	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	11899	 1213	 0.002551	 0.011578	 0.0	 2665	 2665	 2665	 0.0	 0.0	 1	 -30.0	 30.0;
	6041	 1213	 0.002489	 0.0118	 0.0	 2620	 2620	 2620	 0.0	 0.0	 1	 -30.0	 30.0;
	10623	 12370	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	12370	 5790	 0.010009	 0.04892	 0.0	 633	 633	 633	 0.0	 0.0	 1	 -30.0	 30.0;
	7234	 5426	 0.000182	 0.000671	 0.0	 45434	 45434	 45434	 0.0	 0.0	 1	 -30.0	 30.0;
	11318	 10860	 0.006169	 0.02036	 0.0	 1768	 1768	 1768	 0.0	 0.0	 1	 -30.0	 30.0;
	10860	 2100	 0.007369	 0.0322	 0.0	 1139	 1139	 1139	 0.0	 0.0	 1	 -30.0	 30.0;
	9581	 11318	 0.005498	 0.023071	 0.0	 1600	 1600	 1600	 0.0	 0.0	 1	 -30.0	 30.0;
	11780	 9581	 0.004809	 0.021671	 0.0	 1423	 1423	 1423	 0.0	 0.0	 1	 -30.0	 30.0;
	10111	 11318	 0.0	 0.00028	 0.0	 134256	 134256	 134256	 0.0	 0.0	 1	 -30.0	 30.0;
	11318	 1357	 0.016169	 0.06784	 0.0	 540	 540	 540	 0.0	 0.0	 1	 -30.0	 30.0;
	8889	 4854	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	13104	 38	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	7615	 38	 0.01124	 0.039822	 0.0	 764	 764	 764	 0.0	 0.0	 1	 -30.0	 30.0;
	10144	 252	 0.001169	 0.00532	 0.0	 5800	 5800	 5800	 0.0	 0.0	 1	 -30.0	 30.0;
	690	 252	 0.001138	 0.005418	 0.0	 5706	 5706	 5706	 0.0	 0.0	 1	 -30.0	 30.0;
	12628	 5098	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	9715	 7615	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	3271	 11882	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	7027	 8674	 0.00212	 0.008871	 0.0	 3464	 3464	 3464	 0.0	 0.0	 1	 -30.0	 30.0;
	3040	 7027	 0.002289	 0.008902	 0.0	 3437	 3437	 3437	 0.0	 0.0	 1	 -30.0	 30.0;
	8674	 12510	 0.00024	 0.000782	 0.0	 38616	 38616	 38616	 0.0	 0.0	 1	 -30.0	 30.0;
	4592	 12510	 0.000209	 0.000889	 0.0	 34589	 34589	 34589	 0.0	 0.0	 1	 -30.0	 30.0;
	8248	 11882	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	143	 11882	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	2930	 12510	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	2491	 6668	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	6668	 7855	 0.001209	 0.005529	 0.0	 5582	 5582	 5582	 0.0	 0.0	 1	 -30.0	 30.0;
	6668	 10133	 0.001191	 0.00564	 0.0	 5480	 5480	 5480	 0.0	 0.0	 1	 -30.0	 30.0;
	4096	 7855	 0.014982	 0.0428	 0.0	 697	 697	 697	 0.0	 0.0	 1	 -30.0	 30.0;
	1480	 5759	 0.012849	 0.022929	 0.0	 1202	 1202	 1202	 0.0	 0.0	 1	 -30.0	 30.0;
	5759	 12964	 0.000431	 0.000929	 0.0	 30844	 30844	 30844	 0.0	 0.0	 1	 -30.0	 30.0;
	12867	 12964	 0.000849	 0.003831	 0.0	 8050	 8050	 8050	 0.0	 0.0	 1	 -30.0	 30.0;
	11061	 12964	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	7617	 4496	 0.000231	 0.000769	 0.0	 39340	 39340	 39340	 0.0	 0.0	 1	 -30.0	 30.0;
	7617	 6256	 0.0002	 0.000871	 0.0	 35346	 35346	 35346	 0.0	 0.0	 1	 -30.0	 30.0;
	10851	 7617	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	5983	 878	 0.004049	 0.01844	 0.0	 1674	 1674	 1674	 0.0	 0.0	 1	 -30.0	 30.0;
	5983	 5570	 0.003969	 0.018791	 0.0	 1645	 1645	 1645	 0.0	 0.0	 1	 -30.0	 30.0;
	7224	 5983	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	8949	 578	 0.002271	 0.004258	 0.0	 6546	 6546	 6546	 0.0	 0.0	 1	 -30.0	 30.0;
	4096	 5244	 0.012449	 0.0248	 0.0	 1139	 1139	 1139	 0.0	 0.0	 1	 -30.0	 30.0;
	5244	 578	 0.002311	 0.004169	 0.0	 6627	 6627	 6627	 0.0	 0.0	 1	 -30.0	 30.0;
	5907	 4096	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	10543	 578	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	6961	 4407	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	12876	 4407	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	9111	 4407	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	3347	 12228	 0.002071	 0.009049	 0.0	 3403	 3403	 3403	 0.0	 0.0	 1	 -30.0	 30.0;
	3347	 347	 0.002031	 0.009222	 0.0	 3346	 3346	 3346	 0.0	 0.0	 1	 -30.0	 30.0;
	13519	 3347	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	13368	 1357	 0.0	 0.000222	 0.0	 169332	 169332	 169332	 0.0	 0.0	 1	 -30.0	 30.0;
	2100	 1357	 0.015511	 0.06772	 0.0	 542	 542	 542	 0.0	 0.0	 1	 -30.0	 30.0;
	5582	 13358	 4e-05	 0.00028	 0.0	 111679	 111679	 111679	 0.0	 0.0	 1	 -30.0	 30.0;
	5582	 8568	 4e-05	 0.00028	 0.0	 111679	 111679	 111679	 0.0	 0.0	 1	 -30.0	 30.0;
	35	 5582	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	10939	 2398	 0.0052	 0.013898	 0.0	 2534	 2534	 2534	 0.0	 0.0	 1	 -30.0	 30.0;
	13459	 6126	 0.009071	 0.032151	 0.0	 946	 946	 946	 0.0	 0.0	 1	 -30.0	 30.0;
	9678	 13459	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	803	 11883	 0.0	 0.000222	 0.0	 169332	 169332	 169332	 0.0	 0.0	 1	 -30.0	 30.0;
	2398	 10163	 0.0	 0.000222	 0.0	 169332	 169332	 169332	 0.0	 0.0	 1	 -30.0	 30.0;
	11883	 1171	 0.0	 0.000222	 0.0	 169332	 169332	 169332	 0.0	 0.0	 1	 -30.0	 30.0;
	11883	 4807	 0.0	 0.000222	 0.0	 169332	 169332	 169332	 0.0	 0.0	 1	 -30.0	 30.0;
	11883	 10163	 0.0	 0.000222	 0.0	 169332	 169332	 169332	 0.0	 0.0	 1	 -30.0	 30.0;
	7803	 11024	 0.042889	 0.088942	 0.0	 320	 320	 320	 0.0	 0.0	 1	 -30.0	 30.0;
	1105	 8783	 0.000609	 0.001618	 0.0	 18272	 18272	 18272	 0.0	 0.0	 1	 -30.0	 30.0;
	653	 11486	 0.011289	 0.057409	 0.0	 540	 540	 540	 0.0	 0.0	 1	 -30.0	 30.0;
	5920	 1223	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	7546	 5544	 8.9e-05	 0.000449	 0.0	 69008	 69008	 69008	 0.0	 0.0	 1	 -30.0	 30.0;
	12111	 7002	 0.000169	 0.000662	 0.0	 46233	 46233	 46233	 0.0	 0.0	 1	 -30.0	 30.0;
	3295	 7399	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	1858	 10152	 9.8e-05	 0.000511	 0.0	 60709	 60709	 60709	 0.0	 0.0	 1	 -30.0	 30.0;
	12753	 10152	 0.006338	 0.022662	 0.0	 1343	 1343	 1343	 0.0	 0.0	 1	 -30.0	 30.0;
	1281	 10297	 0.000809	 0.001729	 0.0	 16548	 16548	 16548	 0.0	 0.0	 1	 -30.0	 30.0;
	4760	 1737	 0.00204	 0.007898	 0.0	 3873	 3873	 3873	 0.0	 0.0	 1	 -30.0	 30.0;
	7335	 13283	 0.00188	 0.00516	 0.0	 5752	 5752	 5752	 0.0	 0.0	 1	 -30.0	 30.0;
	12753	 11728	 0.000831	 0.003511	 0.0	 8755	 8755	 8755	 0.0	 0.0	 1	 -30.0	 30.0;
	1866	 242	 0.00064	 0.002871	 0.0	 10739	 10739	 10739	 0.0	 0.0	 1	 -30.0	 30.0;
	10191	 5426	 0.000182	 0.00064	 0.0	 47473	 47473	 47473	 0.0	 0.0	 1	 -30.0	 30.0;
	10191	 7102	 0.000191	 0.000631	 0.0	 47913	 47913	 47913	 0.0	 0.0	 1	 -30.0	 30.0;
	5182	 10191	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	2993	 463	 0.00043	 0.00337	 0.0	 11066	 11066	 11066	 0.0	 0.0	 1	 -30.0	 30.0;
	2993	 10415	 0.00038	 0.00383	 0.0	 9768	 9768	 9768	 0.0	 0.0	 1	 -30.0	 30.0;
	12766	 7839	 0.000431	 0.00112	 0.0	 26322	 26322	 26322	 0.0	 0.0	 1	 -30.0	 30.0;
	2613	 12766	 0.006458	 0.021302	 0.0	 1420	 1420	 1420	 0.0	 0.0	 1	 -30.0	 30.0;
	11620	 3977	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	10848	 5787	 0.000249	 0.001138	 0.0	 27116	 27116	 27116	 0.0	 0.0	 1	 -30.0	 30.0;
	6489	 10848	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	10848	 2466	 0.002449	 0.011169	 0.0	 2763	 2763	 2763	 0.0	 0.0	 1	 -30.0	 30.0;
	6251	 2466	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	7661	 6022	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	11150	 12955	 0.000271	 0.001089	 0.0	 28148	 28148	 28148	 0.0	 0.0	 1	 -30.0	 30.0;
	4766	 5790	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	461	 2100	 0.0	 0.000222	 0.0	 169332	 169332	 169332	 0.0	 0.0	 1	 -30.0	 30.0;
	1968	 1244	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	4890	 12026	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	10038	 6493	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	1132	 3645	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	5954	 636	 0.006729	 0.031862	 0.0	 970	 970	 970	 0.0	 0.0	 1	 -30.0	 30.0;
	5954	 8083	 0.006591	 0.029498	 0.0	 1046	 1046	 1046	 0.0	 0.0	 1	 -30.0	 30.0;
	10890	 13013	 0.000258	 0.000711	 0.0	 41763	 41763	 41763	 0.0	 0.0	 1	 -30.0	 30.0;
	7759	 9485	 0.020311	 0.045649	 0.0	 633	 633	 633	 0.0	 0.0	 1	 -30.0	 30.0;
	12111	 10830	 0.004102	 0.014089	 0.0	 2153	 2153	 2153	 0.0	 0.0	 1	 -30.0	 30.0;
	10830	 2457	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	11985	 4283	 0.038777	 0.100653	 0.0	 293	 293	 293	 0.0	 0.0	 1	 -30.0	 30.0;
	12107	 11985	 0.026711	 0.08357	 0.0	 361	 361	 361	 0.0	 0.0	 1	 -30.0	 30.0;
	691	 12130	 0.062719	 0.144537	 0.0	 201	 201	 201	 0.0	 0.0	 1	 -30.0	 30.0;
	7433	 691	 0.045033	 0.112364	 0.0	 261	 261	 261	 0.0	 0.0	 1	 -30.0	 30.0;
	6583	 11209	 0.011659	 0.070599	 0.0	 442	 442	 442	 0.0	 0.0	 1	 -30.0	 30.0;
	6583	 7347	 0.00968	 0.04149	 0.0	 742	 742	 742	 0.0	 0.0	 1	 -30.0	 30.0;
	6583	 7347	 0.00862	 0.047021	 0.0	 661	 661	 661	 0.0	 0.0	 1	 -30.0	 30.0;
	11907	 12130	 0.077471	 0.185529	 0.0	 158	 158	 158	 0.0	 0.0	 1	 -30.0	 30.0;
	5481	 12130	 0.045157	 0.126248	 0.0	 236	 236	 236	 0.0	 0.0	 1	 -30.0	 30.0;
	4863	 12130	 0.01119	 0.043099	 0.0	 710	 710	 710	 0.0	 0.0	 1	 -30.0	 30.0;
	4863	 12130	 0.01095	 0.043909	 0.0	 699	 699	 699	 0.0	 0.0	 1	 -30.0	 30.0;
	4016	 11907	 0.03681	 0.090496	 0.0	 324	 324	 324	 0.0	 0.0	 1	 -30.0	 30.0;
	4586	 9093	 0.056174	 0.129223	 0.0	 225	 225	 225	 0.0	 0.0	 1	 -30.0	 30.0;
	5635	 4586	 0.029256	 0.116322	 0.0	 264	 264	 264	 0.0	 0.0	 1	 -30.0	 30.0;
	8013	 12639	 0.061347	 0.097917	 0.0	 274	 274	 274	 0.0	 0.0	 1	 -30.0	 30.0;
	12639	 13176	 0.088719	 0.24762	 0.0	 121	 121	 121	 0.0	 0.0	 1	 -30.0	 30.0;
	11885	 410	 0.0	 0.000413	 0.0	 76483	 76483	 76483	 0.0	 0.0	 1	 -30.0	 30.0;
	11885	 8262	 0.004612	 0.01738	 0.0	 1757	 1757	 1757	 0.0	 0.0	 1	 -30.0	 30.0;
	11885	 8355	 0.008364	 0.02695	 0.0	 1120	 1120	 1120	 0.0	 0.0	 1	 -30.0	 30.0;
	11885	 8355	 0.014992	 0.043636	 0.0	 685	 685	 685	 0.0	 0.0	 1	 -30.0	 30.0;
	12257	 410	 0.003033	 0.012851	 0.0	 2393	 2393	 2393	 0.0	 0.0	 1	 -30.0	 30.0;
	12257	 410	 0.002967	 0.011901	 0.0	 2576	 2576	 2576	 0.0	 0.0	 1	 -30.0	 30.0;
	410	 9385	 0.015256	 0.042686	 0.0	 697	 697	 697	 0.0	 0.0	 1	 -30.0	 30.0;
	2751	 410	 0.004397	 0.025653	 0.0	 1214	 1214	 1214	 0.0	 0.0	 1	 -30.0	 30.0;
	4915	 5800	 0.0027	 0.012961	 0.0	 2386	 2386	 2386	 0.0	 0.0	 1	 -30.0	 30.0;
	7347	 5800	 0.038169	 0.16812	 0.0	 184	 184	 184	 0.0	 0.0	 1	 -30.0	 30.0;
	5800	 8006	 0.015479	 0.073409	 0.0	 422	 422	 422	 0.0	 0.0	 1	 -30.0	 30.0;
	9650	 5066	 0.027868	 0.087843	 0.0	 343	 343	 343	 0.0	 0.0	 1	 -30.0	 30.0;
	7363	 9650	 0.013934	 0.040479	 0.0	 738	 738	 738	 0.0	 0.0	 1	 -30.0	 30.0;
	2546	 5066	 0.019231	 0.076471	 0.0	 401	 401	 401	 0.0	 0.0	 1	 -30.0	 30.0;
	3274	 13278	 0.013421	 0.037256	 0.0	 798	 798	 798	 0.0	 0.0	 1	 -30.0	 30.0;
	8064	 3274	 0.022438	 0.046851	 0.0	 609	 609	 609	 0.0	 0.0	 1	 -30.0	 30.0;
	12188	 723	 0.014562	 0.045314	 0.0	 664	 664	 664	 0.0	 0.0	 1	 -30.0	 30.0;
	723	 4016	 0.000826	 0.002207	 0.0	 13405	 13405	 13405	 0.0	 0.0	 1	 -30.0	 30.0;
	2720	 13255	 0.040628	 0.113562	 0.0	 262	 262	 262	 0.0	 0.0	 1	 -30.0	 30.0;
	8009	 2720	 0.008058	 0.024438	 0.0	 1228	 1228	 1228	 0.0	 0.0	 1	 -30.0	 30.0;
	2720	 8553	 0.022471	 0.041083	 0.0	 675	 675	 675	 0.0	 0.0	 1	 -30.0	 30.0;
	6439	 12663	 0.047322	 0.096669	 0.0	 294	 294	 294	 0.0	 0.0	 1	 -30.0	 30.0;
	12663	 12107	 0.01914	 0.07614	 0.0	 403	 403	 403	 0.0	 0.0	 1	 -30.0	 30.0;
	1067	 8828	 0.007802	 0.01924	 0.0	 1522	 1522	 1522	 0.0	 0.0	 1	 -30.0	 30.0;
	1067	 8828	 0.005397	 0.015554	 0.0	 1919	 1919	 1919	 0.0	 0.0	 1	 -30.0	 30.0;
	8828	 84	 0.024719	 0.040702	 0.0	 664	 664	 664	 0.0	 0.0	 1	 -30.0	 30.0;
	8828	 84	 0.02419	 0.041471	 0.0	 658	 658	 658	 0.0	 0.0	 1	 -30.0	 30.0;
	6235	 3825	 0.039603	 0.109529	 0.0	 272	 272	 272	 0.0	 0.0	 1	 -30.0	 30.0;
	5042	 6235	 0.013826	 0.039826	 0.0	 750	 750	 750	 0.0	 0.0	 1	 -30.0	 30.0;
	10014	 6235	 0.015174	 0.04981	 0.0	 607	 607	 607	 0.0	 0.0	 1	 -30.0	 30.0;
	11855	 6732	 0.003669	 0.009008	 0.0	 3248	 3248	 3248	 0.0	 0.0	 1	 -30.0	 30.0;
	6732	 2855	 0.03276	 0.106603	 0.0	 284	 284	 284	 0.0	 0.0	 1	 -30.0	 30.0;
	6732	 2855	 0.03019	 0.107612	 0.0	 283	 283	 283	 0.0	 0.0	 1	 -30.0	 30.0;
	5422	 6732	 0.019033	 0.051653	 0.0	 574	 574	 574	 0.0	 0.0	 1	 -30.0	 30.0;
	265	 6732	 0.037603	 0.124017	 0.0	 244	 244	 244	 0.0	 0.0	 1	 -30.0	 30.0;
	6732	 9134	 0.034868	 0.097471	 0.0	 306	 306	 306	 0.0	 0.0	 1	 -30.0	 30.0;
	6732	 9420	 0.043099	 0.130603	 0.0	 230	 230	 230	 0.0	 0.0	 1	 -30.0	 30.0;
	6439	 11855	 0.06105	 0.110339	 0.0	 251	 251	 251	 0.0	 0.0	 1	 -30.0	 30.0;
	4035	 9154	 0.041446	 0.108843	 0.0	 272	 272	 272	 0.0	 0.0	 1	 -30.0	 30.0;
	9154	 350	 0.063471	 0.123207	 0.0	 228	 228	 228	 0.0	 0.0	 1	 -30.0	 30.0;
	4475	 8009	 0.02343	 0.073603	 0.0	 409	 409	 409	 0.0	 0.0	 1	 -30.0	 30.0;
	4475	 2689	 0.022537	 0.091587	 0.0	 335	 335	 335	 0.0	 0.0	 1	 -30.0	 30.0;
	30	 13610	 0.036744	 0.106934	 0.0	 280	 280	 280	 0.0	 0.0	 1	 -30.0	 30.0;
	30	 1176	 0.006207	 0.023959	 0.0	 1277	 1277	 1277	 0.0	 0.0	 1	 -30.0	 30.0;
	5042	 4984	 0.003157	 0.011008	 0.0	 2759	 2759	 2759	 0.0	 0.0	 1	 -30.0	 30.0;
	5042	 4984	 0.003223	 0.010793	 0.0	 2805	 2805	 2805	 0.0	 0.0	 1	 -30.0	 30.0;
	10014	 4984	 0.005	 0.035653	 0.0	 878	 878	 878	 0.0	 0.0	 1	 -30.0	 30.0;
	10014	 4984	 0.004901	 0.036347	 0.0	 862	 862	 862	 0.0	 0.0	 1	 -30.0	 30.0;
	11857	 2244	 0.007917	 0.029603	 0.0	 1031	 1031	 1031	 0.0	 0.0	 1	 -30.0	 30.0;
	1051	 2244	 0.004876	 0.01476	 0.0	 2033	 2033	 2033	 0.0	 0.0	 1	 -30.0	 30.0;
	7959	 13610	 0.007182	 0.023579	 0.0	 1282	 1282	 1282	 0.0	 0.0	 1	 -30.0	 30.0;
	7959	 6720	 0.007322	 0.023099	 0.0	 1304	 1304	 1304	 0.0	 0.0	 1	 -30.0	 30.0;
	8553	 560	 0.010942	 0.040562	 0.0	 752	 752	 752	 0.0	 0.0	 1	 -30.0	 30.0;
	560	 1279	 0.030603	 0.103702	 0.0	 293	 293	 293	 0.0	 0.0	 1	 -30.0	 30.0;
	13278	 3681	 0.01176	 0.041421	 0.0	 734	 734	 734	 0.0	 0.0	 1	 -30.0	 30.0;
	13278	 9344	 0.011868	 0.03581	 0.0	 838	 838	 838	 0.0	 0.0	 1	 -30.0	 30.0;
	1130	 13278	 0.01757	 0.064579	 0.0	 472	 472	 472	 0.0	 0.0	 1	 -30.0	 30.0;
	10395	 10745	 0.017099	 0.064281	 0.0	 475	 475	 475	 0.0	 0.0	 1	 -30.0	 30.0;
	1146	 5635	 0.015207	 0.057397	 0.0	 532	 532	 532	 0.0	 0.0	 1	 -30.0	 30.0;
	9344	 1146	 0.009198	 0.036512	 0.0	 839	 839	 839	 0.0	 0.0	 1	 -30.0	 30.0;
	1146	 10014	 0.024281	 0.239446	 0.0	 132	 132	 132	 0.0	 0.0	 1	 -30.0	 30.0;
	13537	 1861	 0.052471	 0.157347	 0.0	 191	 191	 191	 0.0	 0.0	 1	 -30.0	 30.0;
	604	 1861	 0.009314	 0.035909	 0.0	 852	 852	 852	 0.0	 0.0	 1	 -30.0	 30.0;
	11857	 1861	 0.039314	 0.122777	 0.0	 246	 246	 246	 0.0	 0.0	 1	 -30.0	 30.0;
	12257	 664	 0.001223	 0.003711	 0.0	 8085	 8085	 8085	 0.0	 0.0	 1	 -30.0	 30.0;
	7347	 10824	 0.00518	 0.023091	 0.0	 1335	 1335	 1335	 0.0	 0.0	 1	 -30.0	 30.0;
	7347	 10824	 0.005281	 0.022591	 0.0	 1362	 1362	 1362	 0.0	 0.0	 1	 -30.0	 30.0;
	3780	 11841	 0.018198	 0.037149	 0.0	 764	 764	 764	 0.0	 0.0	 1	 -30.0	 30.0;
	11628	 8625	 0.012893	 0.040033	 0.0	 752	 752	 752	 0.0	 0.0	 1	 -30.0	 30.0;
	5638	 8625	 0.007132	 0.020331	 0.0	 1467	 1467	 1467	 0.0	 0.0	 1	 -30.0	 30.0;
	4642	 2024	 0.00479	 0.05497	 0.0	 688	 688	 688	 0.0	 0.0	 1	 -30.0	 30.0;
	6439	 2855	 0.047322	 0.139868	 0.0	 214	 214	 214	 0.0	 0.0	 1	 -30.0	 30.0;
	5080	 2855	 0.005471	 0.017471	 0.0	 1726	 1726	 1726	 0.0	 0.0	 1	 -30.0	 30.0;
	5080	 2855	 0.013826	 0.040207	 0.0	 743	 743	 743	 0.0	 0.0	 1	 -30.0	 30.0;
	4283	 2855	 0.010678	 0.03814	 0.0	 798	 798	 798	 0.0	 0.0	 1	 -30.0	 30.0;
	4283	 2855	 0.010603	 0.034793	 0.0	 869	 869	 869	 0.0	 0.0	 1	 -30.0	 30.0;
	6826	 2855	 0.014579	 0.043331	 0.0	 691	 691	 691	 0.0	 0.0	 1	 -30.0	 30.0;
	2855	 9134	 0.021413	 0.079248	 0.0	 385	 385	 385	 0.0	 0.0	 1	 -30.0	 30.0;
	2855	 10334	 0.031198	 0.098298	 0.0	 307	 307	 307	 0.0	 0.0	 1	 -30.0	 30.0;
	8015	 4915	 0.009651	 0.045031	 0.0	 686	 686	 686	 0.0	 0.0	 1	 -30.0	 30.0;
	13255	 8028	 0.050207	 0.124066	 0.0	 237	 237	 237	 0.0	 0.0	 1	 -30.0	 30.0;
	13603	 6659	 0.034314	 0.070521	 0.0	 403	 403	 403	 0.0	 0.0	 1	 -30.0	 30.0;
	9712	 8064	 0.007463	 0.022612	 0.0	 1327	 1327	 1327	 0.0	 0.0	 1	 -30.0	 30.0;
	9712	 8064	 0.007603	 0.022132	 0.0	 1350	 1350	 1350	 0.0	 0.0	 1	 -30.0	 30.0;
	8009	 5701	 0.01081	 0.033603	 0.0	 895	 895	 895	 0.0	 0.0	 1	 -30.0	 30.0;
	13537	 8009	 0.011223	 0.036446	 0.0	 829	 829	 829	 0.0	 0.0	 1	 -30.0	 30.0;
	8009	 11628	 0.014182	 0.045669	 0.0	 661	 661	 661	 0.0	 0.0	 1	 -30.0	 30.0;
	11628	 8009	 0.014463	 0.044744	 0.0	 672	 672	 672	 0.0	 0.0	 1	 -30.0	 30.0;
	265	 5422	 0.02124	 0.069099	 0.0	 437	 437	 437	 0.0	 0.0	 1	 -30.0	 30.0;
	13571	 11706	 0.008041	 0.030504	 0.0	 1002	 1002	 1002	 0.0	 0.0	 1	 -30.0	 30.0;
	13571	 3318	 0.009107	 0.029893	 0.0	 1011	 1011	 1011	 0.0	 0.0	 1	 -30.0	 30.0;
	12796	 11224	 0.024802	 0.074537	 0.0	 403	 403	 403	 0.0	 0.0	 1	 -30.0	 30.0;
	187	 12796	 0.038711	 0.136876	 0.0	 223	 223	 223	 0.0	 0.0	 1	 -30.0	 30.0;
	1051	 2689	 0.069413	 0.194223	 0.0	 154	 154	 154	 0.0	 0.0	 1	 -30.0	 30.0;
	13537	 5701	 0.01276	 0.035281	 0.0	 842	 842	 842	 0.0	 0.0	 1	 -30.0	 30.0;
	6174	 10974	 0.008744	 0.025802	 0.0	 1160	 1160	 1160	 0.0	 0.0	 1	 -30.0	 30.0;
	10974	 3318	 0.008909	 0.025248	 0.0	 1180	 1180	 1180	 0.0	 0.0	 1	 -30.0	 30.0;
	4863	 11706	 0.009289	 0.029281	 0.0	 1029	 1029	 1029	 0.0	 0.0	 1	 -30.0	 30.0;
	2387	 5481	 0.021421	 0.081298	 0.0	 376	 376	 376	 0.0	 0.0	 1	 -30.0	 30.0;
	2387	 10395	 0.044479	 0.139058	 0.0	 217	 217	 217	 0.0	 0.0	 1	 -30.0	 30.0;
	13362	 11209	 0.008479	 0.049461	 0.0	 630	 630	 630	 0.0	 0.0	 1	 -30.0	 30.0;
	7347	 11209	 0.00394	 0.02236	 0.0	 1392	 1392	 1392	 0.0	 0.0	 1	 -30.0	 30.0;
	1067	 8238	 0.016174	 0.044463	 0.0	 668	 668	 668	 0.0	 0.0	 1	 -30.0	 30.0;
	1067	 8238	 0.014413	 0.05038	 0.0	 603	 603	 603	 0.0	 0.0	 1	 -30.0	 30.0;
	1115	 1067	 0.020198	 0.064678	 0.0	 467	 467	 467	 0.0	 0.0	 1	 -30.0	 30.0;
	1115	 1067	 0.020587	 0.063364	 0.0	 475	 475	 475	 0.0	 0.0	 1	 -30.0	 30.0;
	1115	 1067	 0.031711	 0.059223	 0.0	 471	 471	 471	 0.0	 0.0	 1	 -30.0	 30.0;
	13603	 3002	 0.056678	 0.178372	 0.0	 169	 169	 169	 0.0	 0.0	 1	 -30.0	 30.0;
	3002	 7433	 0.019496	 0.078083	 0.0	 393	 393	 393	 0.0	 0.0	 1	 -30.0	 30.0;
	8238	 455	 0.045198	 0.111479	 0.0	 263	 263	 263	 0.0	 0.0	 1	 -30.0	 30.0;
	7832	 8064	 0.015041	 0.057983	 0.0	 528	 528	 528	 0.0	 0.0	 1	 -30.0	 30.0;
	1495	 7832	 0.03519	 0.105653	 0.0	 284	 284	 284	 0.0	 0.0	 1	 -30.0	 30.0;
	187	 9093	 0.044	 0.099339	 0.0	 291	 291	 291	 0.0	 0.0	 1	 -30.0	 30.0;
	9385	 12257	 0.013636	 0.039512	 0.0	 756	 756	 756	 0.0	 0.0	 1	 -30.0	 30.0;
	9385	 12257	 0.012149	 0.044777	 0.0	 681	 681	 681	 0.0	 0.0	 1	 -30.0	 30.0;
	8064	 13595	 0.035281	 0.122702	 0.0	 248	 248	 248	 0.0	 0.0	 1	 -30.0	 30.0;
	5783	 13595	 0.031967	 0.090248	 0.0	 330	 330	 330	 0.0	 0.0	 1	 -30.0	 30.0;
	10014	 13595	 0.023983	 0.066421	 0.0	 448	 448	 448	 0.0	 0.0	 1	 -30.0	 30.0;
	13603	 7753	 0.032901	 0.126777	 0.0	 242	 242	 242	 0.0	 0.0	 1	 -30.0	 30.0;
	7753	 12990	 0.015372	 0.059083	 0.0	 518	 518	 518	 0.0	 0.0	 1	 -30.0	 30.0;
	6174	 10395	 0.012636	 0.024496	 0.0	 1147	 1147	 1147	 0.0	 0.0	 1	 -30.0	 30.0;
	6174	 10395	 0.012893	 0.024	 0.0	 1160	 1160	 1160	 0.0	 0.0	 1	 -30.0	 30.0;
	6174	 10915	 0.001917	 0.006091	 0.0	 4947	 4947	 4947	 0.0	 0.0	 1	 -30.0	 30.0;
	6174	 3318	 0.018149	 0.049413	 0.0	 601	 601	 601	 0.0	 0.0	 1	 -30.0	 30.0;
	3084	 1219	 0.01276	 0.037083	 0.0	 806	 806	 806	 0.0	 0.0	 1	 -30.0	 30.0;
	13176	 3084	 0.069636	 0.146636	 0.0	 195	 195	 195	 0.0	 0.0	 1	 -30.0	 30.0;
	3795	 13272	 0.00219	 0.02213	 0.0	 1707	 1707	 1707	 0.0	 0.0	 1	 -30.0	 30.0;
	8344	 7347	 0.00194	 0.0087	 0.0	 3544	 3544	 3544	 0.0	 0.0	 1	 -30.0	 30.0;
	8344	 7347	 0.001979	 0.00851	 0.0	 3616	 3616	 3616	 0.0	 0.0	 1	 -30.0	 30.0;
	5635	 3825	 0.028893	 0.108496	 0.0	 282	 282	 282	 0.0	 0.0	 1	 -30.0	 30.0;
	3681	 5635	 0.021008	 0.05814	 0.0	 511	 511	 511	 0.0	 0.0	 1	 -30.0	 30.0;
	8238	 5726	 0.018661	 0.056488	 0.0	 531	 531	 531	 0.0	 0.0	 1	 -30.0	 30.0;
	963	 1495	 0.01381	 0.03776	 0.0	 786	 786	 786	 0.0	 0.0	 1	 -30.0	 30.0;
	963	 5783	 0.012298	 0.042793	 0.0	 710	 710	 710	 0.0	 0.0	 1	 -30.0	 30.0;
	8536	 8553	 0.009281	 0.03038	 0.0	 995	 995	 995	 0.0	 0.0	 1	 -30.0	 30.0;
	11224	 4035	 0.011438	 0.035711	 0.0	 843	 843	 843	 0.0	 0.0	 1	 -30.0	 30.0;
	9949	 11224	 0.05095	 0.124661	 0.0	 235	 235	 235	 0.0	 0.0	 1	 -30.0	 30.0;
	8028	 13603	 0.058207	 0.110223	 0.0	 254	 254	 254	 0.0	 0.0	 1	 -30.0	 30.0;
	604	 1051	 0.061876	 0.195174	 0.0	 155	 155	 155	 0.0	 0.0	 1	 -30.0	 30.0;
	3833	 2929	 0.013438	 0.032033	 0.0	 910	 910	 910	 0.0	 0.0	 1	 -30.0	 30.0;
	6720	 3833	 0.03619	 0.085066	 0.0	 342	 342	 342	 0.0	 0.0	 1	 -30.0	 30.0;
	5726	 3828	 0.05324	 0.154826	 0.0	 193	 193	 193	 0.0	 0.0	 1	 -30.0	 30.0;
	5638	 2929	 0.004579	 0.026017	 0.0	 1196	 1196	 1196	 0.0	 0.0	 1	 -30.0	 30.0;
	2132	 13415	 0.00795	 0.03657	 0.0	 845	 845	 845	 0.0	 0.0	 1	 -30.0	 30.0;
	4035	 1787	 0.055967	 0.167983	 0.0	 179	 179	 179	 0.0	 0.0	 1	 -30.0	 30.0;
	9949	 4035	 0.070942	 0.168066	 0.0	 174	 174	 174	 0.0	 0.0	 1	 -30.0	 30.0;
	3592	 3795	 0.00389	 0.04149	 0.0	 911	 911	 911	 0.0	 0.0	 1	 -30.0	 30.0;
	10347	 3592	 0.003	 0.02776	 0.0	 1132	 1132	 1132	 0.0	 0.0	 1	 -30.0	 30.0;
	8002	 8015	 0.002159	 0.01261	 0.0	 2470	 2470	 2470	 0.0	 0.0	 1	 -30.0	 30.0;
	8002	 8015	 0.002021	 0.016849	 0.0	 1862	 1862	 1862	 0.0	 0.0	 1	 -30.0	 30.0;
	10240	 8015	 0.007151	 0.046719	 0.0	 669	 669	 669	 0.0	 0.0	 1	 -30.0	 30.0;
	8015	 10118	 0.000539	 0.00368	 0.0	 8493	 8493	 8493	 0.0	 0.0	 1	 -30.0	 30.0;
	8015	 10118	 0.000539	 0.003591	 0.0	 8699	 8699	 8699	 0.0	 0.0	 1	 -30.0	 30.0;
	11628	 8536	 0.007446	 0.010579	 0.0	 2442	 2442	 2442	 0.0	 0.0	 1	 -30.0	 30.0;
	11628	 3653	 0.011992	 0.03276	 0.0	 906	 906	 906	 0.0	 0.0	 1	 -30.0	 30.0;
	1115	 3780	 0.034207	 0.085124	 0.0	 345	 345	 345	 0.0	 0.0	 1	 -30.0	 30.0;
	7098	 1115	 0.001248	 0.004471	 0.0	 6805	 6805	 6805	 0.0	 0.0	 1	 -30.0	 30.0;
	7098	 1115	 0.001223	 0.004562	 0.0	 6688	 6688	 6688	 0.0	 0.0	 1	 -30.0	 30.0;
	8006	 2132	 0.006961	 0.04039	 0.0	 771	 771	 771	 0.0	 0.0	 1	 -30.0	 30.0;
	8006	 2132	 0.004521	 0.02305	 0.0	 1345	 1345	 1345	 0.0	 0.0	 1	 -30.0	 30.0;
	8006	 6485	 0.00395	 0.022789	 0.0	 1366	 1366	 1366	 0.0	 0.0	 1	 -30.0	 30.0;
	187	 11321	 0.031934	 0.123661	 0.0	 248	 248	 248	 0.0	 0.0	 1	 -30.0	 30.0;
	187	 5042	 0.019802	 0.070901	 0.0	 430	 430	 430	 0.0	 0.0	 1	 -30.0	 30.0;
	187	 5042	 0.022438	 0.069479	 0.0	 433	 433	 433	 0.0	 0.0	 1	 -30.0	 30.0;
	187	 9340	 0.014727	 0.04305	 0.0	 695	 695	 695	 0.0	 0.0	 1	 -30.0	 30.0;
	8355	 187	 0.01343	 0.06824	 0.0	 455	 455	 455	 0.0	 0.0	 1	 -30.0	 30.0;
	2751	 187	 0.022	 0.060388	 0.0	 492	 492	 492	 0.0	 0.0	 1	 -30.0	 30.0;
	2751	 187	 0.019603	 0.068438	 0.0	 444	 444	 444	 0.0	 0.0	 1	 -30.0	 30.0;
	1787	 1727	 0.048769	 0.114711	 0.0	 254	 254	 254	 0.0	 0.0	 1	 -30.0	 30.0;
	5080	 6439	 0.046901	 0.148033	 0.0	 204	 204	 204	 0.0	 0.0	 1	 -30.0	 30.0;
	10095	 6439	 0.055744	 0.139066	 0.0	 211	 211	 211	 0.0	 0.0	 1	 -30.0	 30.0;
	1130	 8064	 0.010917	 0.032901	 0.0	 912	 912	 912	 0.0	 0.0	 1	 -30.0	 30.0;
	84	 8013	 0.026322	 0.044388	 0.0	 613	 613	 613	 0.0	 0.0	 1	 -30.0	 30.0;
	7433	 12188	 0.047438	 0.143727	 0.0	 209	 209	 209	 0.0	 0.0	 1	 -30.0	 30.0;
	11126	 12188	 0.026876	 0.09776	 0.0	 312	 312	 312	 0.0	 0.0	 1	 -30.0	 30.0;
	12990	 11126	 0.01705	 0.060802	 0.0	 501	 501	 501	 0.0	 0.0	 1	 -30.0	 30.0;
	1279	 12990	 0.028727	 0.075289	 0.0	 392	 392	 392	 0.0	 0.0	 1	 -30.0	 30.0;
	7433	 8133	 0.002388	 0.015942	 0.0	 1960	 1960	 1960	 0.0	 0.0	 1	 -30.0	 30.0;
	7433	 4016	 0.088471	 0.217198	 0.0	 135	 135	 135	 0.0	 0.0	 1	 -30.0	 30.0;
	3828	 9733	 0.01714	 0.056248	 0.0	 538	 538	 538	 0.0	 0.0	 1	 -30.0	 30.0;
	9435	 5080	 0.004479	 0.014008	 0.0	 2148	 2148	 2148	 0.0	 0.0	 1	 -30.0	 30.0;
	4283	 9435	 0.009851	 0.032314	 0.0	 936	 936	 936	 0.0	 0.0	 1	 -30.0	 30.0;
	6826	 9435	 0.001636	 0.005587	 0.0	 5426	 5426	 5426	 0.0	 0.0	 1	 -30.0	 30.0;
	6826	 12107	 0.021603	 0.084	 0.0	 365	 365	 365	 0.0	 0.0	 1	 -30.0	 30.0;
	2546	 6890	 0.021727	 0.065893	 0.0	 456	 456	 456	 0.0	 0.0	 1	 -30.0	 30.0;
	2546	 6720	 0.025686	 0.080256	 0.0	 375	 375	 375	 0.0	 0.0	 1	 -30.0	 30.0;
	6720	 2546	 0.026182	 0.078587	 0.0	 382	 382	 382	 0.0	 0.0	 1	 -30.0	 30.0;
	10240	 8002	 0.00536	 0.040919	 0.0	 766	 766	 766	 0.0	 0.0	 1	 -30.0	 30.0;
	3653	 5638	 0.007388	 0.026628	 0.0	 1144	 1144	 1144	 0.0	 0.0	 1	 -30.0	 30.0;
	9385	 12404	 0.005826	 0.017488	 0.0	 1714	 1714	 1714	 0.0	 0.0	 1	 -30.0	 30.0;
	9385	 12404	 0.005826	 0.016653	 0.0	 1791	 1791	 1791	 0.0	 0.0	 1	 -30.0	 30.0;
	5783	 12404	 0.026826	 0.082273	 0.0	 366	 366	 366	 0.0	 0.0	 1	 -30.0	 30.0;
	13202	 9385	 0.003256	 0.010587	 0.0	 2852	 2852	 2852	 0.0	 0.0	 1	 -30.0	 30.0;
	13202	 1362	 0.003331	 0.010372	 0.0	 2900	 2900	 2900	 0.0	 0.0	 1	 -30.0	 30.0;
	13400	 11857	 0.025174	 0.077661	 0.0	 387	 387	 387	 0.0	 0.0	 1	 -30.0	 30.0;
	2795	 6890	 0.030248	 0.085413	 0.0	 349	 349	 349	 0.0	 0.0	 1	 -30.0	 30.0;
	7363	 6890	 0.029471	 0.109198	 0.0	 280	 280	 280	 0.0	 0.0	 1	 -30.0	 30.0;
	1727	 265	 0.058942	 0.115529	 0.0	 244	 244	 244	 0.0	 0.0	 1	 -30.0	 30.0;
	9340	 11321	 0.028413	 0.083	 0.0	 361	 361	 361	 0.0	 0.0	 1	 -30.0	 30.0;
	9949	 11321	 0.005826	 0.016	 0.0	 1856	 1856	 1856	 0.0	 0.0	 1	 -30.0	 30.0;
	12624	 11321	 0.005512	 0.016612	 0.0	 1805	 1805	 1805	 0.0	 0.0	 1	 -30.0	 30.0;
	8293	 9385	 0.014256	 0.033909	 0.0	 859	 859	 859	 0.0	 0.0	 1	 -30.0	 30.0;
	1051	 9385	 0.052826	 0.200702	 0.0	 153	 153	 153	 0.0	 0.0	 1	 -30.0	 30.0;
	2751	 9385	 0.01976	 0.061058	 0.0	 493	 493	 493	 0.0	 0.0	 1	 -30.0	 30.0;
	2751	 9385	 0.014008	 0.053207	 0.0	 575	 575	 575	 0.0	 0.0	 1	 -30.0	 30.0;
	2751	 9385	 0.013711	 0.054207	 0.0	 565	 565	 565	 0.0	 0.0	 1	 -30.0	 30.0;
	8355	 5042	 0.009132	 0.024843	 0.0	 1194	 1194	 1194	 0.0	 0.0	 1	 -30.0	 30.0;
	10014	 5042	 0.010711	 0.040256	 0.0	 759	 759	 759	 0.0	 0.0	 1	 -30.0	 30.0;
	9559	 5042	 0.004562	 0.012421	 0.0	 2388	 2388	 2388	 0.0	 0.0	 1	 -30.0	 30.0;
	11770	 2795	 0.025273	 0.079777	 0.0	 378	 378	 378	 0.0	 0.0	 1	 -30.0	 30.0;
	1362	 8293	 0.009149	 0.028992	 0.0	 1040	 1040	 1040	 0.0	 0.0	 1	 -30.0	 30.0;
	4863	 3318	 0.027149	 0.096802	 0.0	 315	 315	 315	 0.0	 0.0	 1	 -30.0	 30.0;
	1176	 6720	 0.063033	 0.157099	 0.0	 187	 187	 187	 0.0	 0.0	 1	 -30.0	 30.0;
	1176	 11770	 0.009702	 0.035397	 0.0	 861	 861	 861	 0.0	 0.0	 1	 -30.0	 30.0;
	1176	 11770	 0.009504	 0.036091	 0.0	 847	 847	 847	 0.0	 0.0	 1	 -30.0	 30.0;
	350	 10095	 0.029893	 0.105364	 0.0	 289	 289	 289	 0.0	 0.0	 1	 -30.0	 30.0;
	8355	 8262	 0.005397	 0.020298	 0.0	 1504	 1504	 1504	 0.0	 0.0	 1	 -30.0	 30.0;
	10915	 4117	 0.001124	 0.002942	 0.0	 10030	 10030	 10030	 0.0	 0.0	 1	 -30.0	 30.0;
	7098	 4117	 0.001207	 0.003174	 0.0	 9303	 9303	 9303	 0.0	 0.0	 1	 -30.0	 30.0;
	7098	 4117	 0.00124	 0.003099	 0.0	 9464	 9464	 9464	 0.0	 0.0	 1	 -30.0	 30.0;
	9559	 8355	 0.004066	 0.014083	 0.0	 2155	 2155	 2155	 0.0	 0.0	 1	 -30.0	 30.0;
	3423	 10240	 0.005099	 0.025479	 0.0	 1216	 1216	 1216	 0.0	 0.0	 1	 -30.0	 30.0;
	3423	 10240	 0.0052	 0.024961	 0.0	 1239	 1239	 1239	 0.0	 0.0	 1	 -30.0	 30.0;
	12624	 9949	 0.003868	 0.013901	 0.0	 2190	 2190	 2190	 0.0	 0.0	 1	 -30.0	 30.0;
	10347	 2024	 0.00126	 0.01433	 0.0	 2196	 2196	 2196	 0.0	 0.0	 1	 -30.0	 30.0;
	13400	 2751	 0.011752	 0.044314	 0.0	 689	 689	 689	 0.0	 0.0	 1	 -30.0	 30.0;
	9134	 10334	 0.021719	 0.046248	 0.0	 619	 619	 619	 0.0	 0.0	 1	 -30.0	 30.0;
	9134	 9420	 0.05324	 0.100281	 0.0	 279	 279	 279	 0.0	 0.0	 1	 -30.0	 30.0;
	6459	 9848	 0.00109	 0.01155	 0.0	 3241	 3241	 3241	 0.0	 0.0	 1	 -30.0	 30.0;
	6459	 9848	 0.0011	 0.01158	 0.0	 3232	 3232	 3232	 0.0	 0.0	 1	 -30.0	 30.0;
	6459	 4348	 0.00096	 0.01293	 0.0	 2900	 2900	 2900	 0.0	 0.0	 1	 -30.0	 30.0;
	6459	 4348	 0.00098	 0.01264	 0.0	 2966	 2966	 2966	 0.0	 0.0	 1	 -30.0	 30.0;
	6459	 829	 0.00101	 0.01059	 0.0	 3534	 3534	 3534	 0.0	 0.0	 1	 -30.0	 30.0;
	11848	 9066	 0.00112	 0.010969	 0.0	 2865	 2865	 2865	 0.0	 0.0	 1	 -30.0	 30.0;
	435	 9066	 0.00126	 0.01075	 0.0	 2919	 2919	 2919	 0.0	 0.0	 1	 -30.0	 30.0;
	5430	 12666	 0.00197	 0.0207	 0.0	 1808	 1808	 1808	 0.0	 0.0	 1	 -30.0	 30.0;
	5430	 829	 0.00303	 0.0273	 0.0	 1369	 1369	 1369	 0.0	 0.0	 1	 -30.0	 30.0;
	6869	 12432	 0.00194	 0.02339	 0.0	 1617	 1617	 1617	 0.0	 0.0	 1	 -30.0	 30.0;
	4348	 6869	 0.00057	 0.00492	 0.0	 7590	 7590	 7590	 0.0	 0.0	 1	 -30.0	 30.0;
	9779	 4099	 0.01105	 0.056599	 0.0	 548	 548	 548	 0.0	 0.0	 1	 -30.0	 30.0;
	7590	 4099	 0.00482	 0.046521	 0.0	 676	 676	 676	 0.0	 0.0	 1	 -30.0	 30.0;
	9848	 12573	 0.00194	 0.01645	 0.0	 2291	 2291	 2291	 0.0	 0.0	 1	 -30.0	 30.0;
	12573	 10686	 0.00134	 0.01459	 0.0	 2156	 2156	 2156	 0.0	 0.0	 1	 -30.0	 30.0;
	7706	 12584	 0.000401	 0.00318	 0.0	 9856	 9856	 9856	 0.0	 0.0	 1	 -30.0	 30.0;
	7706	 10323	 0.000349	 0.00293	 0.0	 10705	 10705	 10705	 0.0	 0.0	 1	 -30.0	 30.0;
	7706	 1986	 0.000401	 0.00324	 0.0	 9676	 9676	 9676	 0.0	 0.0	 1	 -30.0	 30.0;
	7706	 4099	 0.01214	 0.058401	 0.0	 530	 530	 530	 0.0	 0.0	 1	 -30.0	 30.0;
	7706	 4099	 0.012979	 0.053281	 0.0	 577	 577	 577	 0.0	 0.0	 1	 -30.0	 30.0;
	7706	 1313	 0.007919	 0.053729	 0.0	 582	 582	 582	 0.0	 0.0	 1	 -30.0	 30.0;
	7706	 9934	 0.014771	 0.06813	 0.0	 454	 454	 454	 0.0	 0.0	 1	 -30.0	 30.0;
	7706	 9934	 0.013789	 0.067711	 0.0	 458	 458	 458	 0.0	 0.0	 1	 -30.0	 30.0;
	2356	 9066	 0.005349	 0.044469	 0.0	 706	 706	 706	 0.0	 0.0	 1	 -30.0	 30.0;
	13314	 9066	 0.005229	 0.04118	 0.0	 761	 761	 761	 0.0	 0.0	 1	 -30.0	 30.0;
	9066	 7201	 0.0008	 0.00676	 0.0	 4641	 4641	 4641	 0.0	 0.0	 1	 -30.0	 30.0;
	9066	 3036	 0.000781	 0.00626	 0.0	 5008	 5008	 5008	 0.0	 0.0	 1	 -30.0	 30.0;
	9066	 11556	 0.00363	 0.017409	 0.0	 1777	 1777	 1777	 0.0	 0.0	 1	 -30.0	 30.0;
	9066	 11556	 0.0037	 0.01705	 0.0	 1811	 1811	 1811	 0.0	 0.0	 1	 -30.0	 30.0;
	9066	 3430	 0.00449	 0.046469	 0.0	 677	 677	 677	 0.0	 0.0	 1	 -30.0	 30.0;
	7196	 5295	 0.00052	 0.00727	 0.0	 4334	 4334	 4334	 0.0	 0.0	 1	 -30.0	 30.0;
	7196	 10686	 0.00047	 0.0062	 0.0	 5081	 5081	 5081	 0.0	 0.0	 1	 -30.0	 30.0;
	7196	 10686	 0.00046	 0.00631	 0.0	 4993	 4993	 4993	 0.0	 0.0	 1	 -30.0	 30.0;
	7957	 9934	 0.003531	 0.013669	 0.0	 2238	 2238	 2238	 0.0	 0.0	 1	 -30.0	 30.0;
	10922	 12432	 0.00032	 0.00322	 0.0	 9762	 9762	 9762	 0.0	 0.0	 1	 -30.0	 30.0;
	10922	 7049	 0.00156	 0.01603	 0.0	 1962	 1962	 1962	 0.0	 0.0	 1	 -30.0	 30.0;
	10922	 3389	 0.0022	 0.02389	 0.0	 1317	 1317	 1317	 0.0	 0.0	 1	 -30.0	 30.0;
	13262	 3430	 0.00337	 0.032669	 0.0	 962	 962	 962	 0.0	 0.0	 1	 -30.0	 30.0;
	13575	 7049	 0.00199	 0.0195	 0.0	 1612	 1612	 1612	 0.0	 0.0	 1	 -30.0	 30.0;
	13575	 3389	 0.00144	 0.01354	 0.0	 2320	 2320	 2320	 0.0	 0.0	 1	 -30.0	 30.0;
	13575	 3389	 0.00147	 0.01325	 0.0	 2370	 2370	 2370	 0.0	 0.0	 1	 -30.0	 30.0;
	13575	 7409	 0.00211	 0.02433	 0.0	 1294	 1294	 1294	 0.0	 0.0	 1	 -30.0	 30.0;
	10019	 4099	 0.013901	 0.088849	 0.0	 352	 352	 352	 0.0	 0.0	 1	 -30.0	 30.0;
	7049	 4348	 0.00149	 0.01564	 0.0	 2415	 2415	 2415	 0.0	 0.0	 1	 -30.0	 30.0;
	7049	 11735	 0.00294	 0.02278	 0.0	 1652	 1652	 1652	 0.0	 0.0	 1	 -30.0	 30.0;
	4348	 11735	 0.00133	 0.01873	 0.0	 2002	 2002	 2002	 0.0	 0.0	 1	 -30.0	 30.0;
	11556	 9934	 0.00581	 0.034229	 0.0	 910	 910	 910	 0.0	 0.0	 1	 -30.0	 30.0;
	11735	 9919	 0.00145	 0.02024	 0.0	 1853	 1853	 1853	 0.0	 0.0	 1	 -30.0	 30.0;
	11735	 9919	 0.00142	 0.01874	 0.0	 2001	 2001	 2001	 0.0	 0.0	 1	 -30.0	 30.0;
	11735	 12666	 0.00245	 0.02367	 0.0	 1580	 1580	 1580	 0.0	 0.0	 1	 -30.0	 30.0;
	11735	 7409	 0.00178	 0.02175	 0.0	 1739	 1739	 1739	 0.0	 0.0	 1	 -30.0	 30.0;
	8194	 10478	 0.000701	 0.009299	 0.0	 4032	 4032	 4032	 0.0	 0.0	 1	 -30.0	 30.0;
	8194	 10478	 0.001042	 0.007833	 0.0	 4758	 4758	 4758	 0.0	 0.0	 1	 -30.0	 30.0;
	8194	 10478	 0.001403	 0.00534	 0.0	 6809	 6809	 6809	 0.0	 0.0	 1	 -30.0	 30.0;
	10686	 4523	 0.00022	 0.00258	 0.0	 12199	 12199	 12199	 0.0	 0.0	 1	 -30.0	 30.0;
	4099	 1313	 0.02024	 0.099349	 0.0	 312	 312	 312	 0.0	 0.0	 1	 -30.0	 30.0;
	4099	 13107	 0.00044	 0.003081	 0.0	 10150	 10150	 10150	 0.0	 0.0	 1	 -30.0	 30.0;
	4099	 6922	 0.00043	 0.00314	 0.0	 9967	 9967	 9967	 0.0	 0.0	 1	 -30.0	 30.0;
	4099	 12919	 0.00461	 0.027531	 0.0	 1132	 1132	 1132	 0.0	 0.0	 1	 -30.0	 30.0;
	13229	 1313	 0.01212	 0.09901	 0.0	 317	 317	 317	 0.0	 0.0	 1	 -30.0	 30.0;
	541	 3196	 0.000289	 0.00261	 0.0	 12029	 12029	 12029	 0.0	 0.0	 1	 -30.0	 30.0;
	6705	 541	 0.00043	 0.002831	 0.0	 11032	 11032	 11032	 0.0	 0.0	 1	 -30.0	 30.0;
	5139	 541	 0.000289	 0.000599	 0.0	 47495	 47495	 47495	 0.0	 0.0	 1	 -30.0	 30.0;
	10964	 1637	 0.000289	 0.00224	 0.0	 13986	 13986	 13986	 0.0	 0.0	 1	 -30.0	 30.0;
	6071	 10964	 0.000219	 0.001591	 0.0	 19669	 19669	 19669	 0.0	 0.0	 1	 -30.0	 30.0;
	3856	 13018	 0.00045	 0.00786	 0.0	 4013	 4013	 4013	 0.0	 0.0	 1	 -30.0	 30.0;
	3856	 13018	 0.00044	 0.00728	 0.0	 4332	 4332	 4332	 0.0	 0.0	 1	 -30.0	 30.0;
	13018	 12148	 0.00049	 0.00466	 0.0	 6742	 6742	 6742	 0.0	 0.0	 1	 -30.0	 30.0;
	13018	 11938	 0.00125	 0.01973	 0.0	 1598	 1598	 1598	 0.0	 0.0	 1	 -30.0	 30.0;
	9947	 9945	 0.001461	 0.00714	 0.0	 4335	 4335	 4335	 0.0	 0.0	 1	 -30.0	 30.0;
	13472	 9947	 0.00037	 0.00094	 0.0	 31269	 31269	 31269	 0.0	 0.0	 1	 -30.0	 30.0;
	9947	 2575	 0.001039	 0.00737	 0.0	 4244	 4244	 4244	 0.0	 0.0	 1	 -30.0	 30.0;
	7737	 1430	 8.1e-05	 0.00061	 0.0	 51332	 51332	 51332	 0.0	 0.0	 1	 -30.0	 30.0;
	10714	 11870	 0.00053	 0.00852	 0.0	 3701	 3701	 3701	 0.0	 0.0	 1	 -30.0	 30.0;
	7968	 11870	 0.00053	 0.00704	 0.0	 4475	 4475	 4475	 0.0	 0.0	 1	 -30.0	 30.0;
	7461	 4899	 0.0001	 0.00128	 0.0	 24603	 24603	 24603	 0.0	 0.0	 1	 -30.0	 30.0;
	6384	 13417	 0.0015	 0.00705	 0.0	 4383	 4383	 4383	 0.0	 0.0	 1	 -30.0	 30.0;
	13417	 10325	 0.009771	 0.05363	 0.0	 580	 580	 580	 0.0	 0.0	 1	 -30.0	 30.0;
	6384	 13417	 0.00088	 0.007771	 0.0	 4039	 4039	 4039	 0.0	 0.0	 1	 -30.0	 30.0;
	9406	 12442	 0.00539	 0.032979	 0.0	 946	 946	 946	 0.0	 0.0	 1	 -30.0	 30.0;
	2092	 9406	 0.00482	 0.03086	 0.0	 1012	 1012	 1012	 0.0	 0.0	 1	 -30.0	 30.0;
	5423	 9406	 0.010539	 0.065479	 0.0	 477	 477	 477	 0.0	 0.0	 1	 -30.0	 30.0;
	9406	 11593	 0.01074	 0.06405	 0.0	 487	 487	 487	 0.0	 0.0	 1	 -30.0	 30.0;
	7554	 9406	 0.0063	 0.048909	 0.0	 641	 641	 641	 0.0	 0.0	 1	 -30.0	 30.0;
	2597	 1260	 0.0002	 0.00022	 0.0	 106240	 106240	 106240	 0.0	 0.0	 1	 -30.0	 30.0;
	7288	 1260	 0.0002	 0.00022	 0.0	 106240	 106240	 106240	 0.0	 0.0	 1	 -30.0	 30.0;
	9966	 1260	 0.00019	 0.00023	 0.0	 105881	 105881	 105881	 0.0	 0.0	 1	 -30.0	 30.0;
	1295	 1809	 0.000289	 0.0017	 0.0	 18318	 18318	 18318	 0.0	 0.0	 1	 -30.0	 30.0;
	1260	 1700	 0.00145	 0.01937	 0.0	 1627	 1627	 1627	 0.0	 0.0	 1	 -30.0	 30.0;
	4515	 1260	 0.00048	 0.00814	 0.0	 3874	 3874	 3874	 0.0	 0.0	 1	 -30.0	 30.0;
	4515	 1260	 0.00057	 0.00758	 0.0	 4156	 4156	 4156	 0.0	 0.0	 1	 -30.0	 30.0;
	12355	 11550	 0.0002	 0.00187	 0.0	 16796	 16796	 16796	 0.0	 0.0	 1	 -30.0	 30.0;
	12355	 11550	 0.000169	 0.00193	 0.0	 16305	 16305	 16305	 0.0	 0.0	 1	 -30.0	 30.0;
	8875	 10160	 0.00216	 0.03591	 0.0	 879	 879	 879	 0.0	 0.0	 1	 -30.0	 30.0;
	8875	 2196	 0.00092	 0.01287	 0.0	 2449	 2449	 2449	 0.0	 0.0	 1	 -30.0	 30.0;
	1782	 5296	 0.02412	 0.10443	 0.0	 295	 295	 295	 0.0	 0.0	 1	 -30.0	 30.0;
	1809	 12442	 0.00063	 0.00401	 0.0	 7782	 7782	 7782	 0.0	 0.0	 1	 -30.0	 30.0;
	1809	 5240	 0.00038	 0.002409	 0.0	 12953	 12953	 12953	 0.0	 0.0	 1	 -30.0	 30.0;
	7147	 6024	 0.010091	 0.05524	 0.0	 563	 563	 563	 0.0	 0.0	 1	 -30.0	 30.0;
	7994	 7147	 0.00668	 0.04457	 0.0	 701	 701	 701	 0.0	 0.0	 1	 -30.0	 30.0;
	7398	 8255	 0.00057	 0.004961	 0.0	 6326	 6326	 6326	 0.0	 0.0	 1	 -30.0	 30.0;
	8255	 7977	 0.00025	 0.002159	 0.0	 14534	 14534	 14534	 0.0	 0.0	 1	 -30.0	 30.0;
	4765	 6626	 0.00443	 0.01807	 0.0	 1698	 1698	 1698	 0.0	 0.0	 1	 -30.0	 30.0;
	4765	 8500	 0.00037	 0.001659	 0.0	 18584	 18584	 18584	 0.0	 0.0	 1	 -30.0	 30.0;
	7398	 11495	 0.00037	 0.003599	 0.0	 8731	 8731	 8731	 0.0	 0.0	 1	 -30.0	 30.0;
	7398	 10969	 0.000659	 0.00836	 0.0	 3767	 3767	 3767	 0.0	 0.0	 1	 -30.0	 30.0;
	7398	 10969	 0.00151	 0.012289	 0.0	 2552	 2552	 2552	 0.0	 0.0	 1	 -30.0	 30.0;
	7398	 3422	 0.000539	 0.003711	 0.0	 8424	 8424	 8424	 0.0	 0.0	 1	 -30.0	 30.0;
	12378	 1885	 0.00036	 0.00606	 0.0	 5204	 5204	 5204	 0.0	 0.0	 1	 -30.0	 30.0;
	12378	 1885	 0.00035	 0.00618	 0.0	 5104	 5104	 5104	 0.0	 0.0	 1	 -30.0	 30.0;
	1885	 11460	 0.00101	 0.01675	 0.0	 1883	 1883	 1883	 0.0	 0.0	 1	 -30.0	 30.0;
	1885	 7797	 4e-05	 0.00071	 0.0	 44419	 44419	 44419	 0.0	 0.0	 1	 -30.0	 30.0;
	1885	 7797	 4e-05	 0.00081	 0.0	 38950	 38950	 38950	 0.0	 0.0	 1	 -30.0	 30.0;
	1885	 1395	 0.00013	 0.00152	 0.0	 20706	 20706	 20706	 0.0	 0.0	 1	 -30.0	 30.0;
	1885	 1395	 0.00014	 0.00149	 0.0	 21107	 21107	 21107	 0.0	 0.0	 1	 -30.0	 30.0;
	1885	 6133	 0.00013	 0.00164	 0.0	 19201	 19201	 19201	 0.0	 0.0	 1	 -30.0	 30.0;
	1885	 6133	 0.00013	 0.00168	 0.0	 18746	 18746	 18746	 0.0	 0.0	 1	 -30.0	 30.0;
	8766	 7554	 0.000669	 0.00511	 0.0	 6130	 6130	 6130	 0.0	 0.0	 1	 -30.0	 30.0;
	13251	 9007	 3.9e-05	 0.000341	 0.0	 92032	 92032	 92032	 0.0	 0.0	 1	 -30.0	 30.0;
	8579	 8264	 0.004219	 0.02145	 0.0	 1445	 1445	 1445	 0.0	 0.0	 1	 -30.0	 30.0;
	8579	 5926	 0.000229	 0.002849	 0.0	 11052	 11052	 11052	 0.0	 0.0	 1	 -30.0	 30.0;
	1782	 70	 0.0137	 0.10436	 0.0	 301	 301	 301	 0.0	 0.0	 1	 -30.0	 30.0;
	3830	 1782	 0.001521	 0.01449	 0.0	 2169	 2169	 2169	 0.0	 0.0	 1	 -30.0	 30.0;
	1108	 643	 8.1e-05	 0.00057	 0.0	 54866	 54866	 54866	 0.0	 0.0	 1	 -30.0	 30.0;
	9945	 643	 0.001461	 0.00813	 0.0	 3825	 3825	 3825	 0.0	 0.0	 1	 -30.0	 30.0;
	2017	 643	 0.00049	 0.00381	 0.0	 8223	 8223	 8223	 0.0	 0.0	 1	 -30.0	 30.0;
	13225	 3705	 0.000401	 0.00287	 0.0	 10901	 10901	 10901	 0.0	 0.0	 1	 -30.0	 30.0;
	8298	 7058	 8.3e-05	 0.000347	 0.0	 105361	 105361	 105361	 0.0	 0.0	 1	 -30.0	 30.0;
	3518	 10740	 0.00023	 0.00285	 0.0	 11048	 11048	 11048	 0.0	 0.0	 1	 -30.0	 30.0;
	10740	 4628	 0.00016	 0.00218	 0.0	 14451	 14451	 14451	 0.0	 0.0	 1	 -30.0	 30.0;
	4302	 10740	 0.00057	 0.00736	 0.0	 4279	 4279	 4279	 0.0	 0.0	 1	 -30.0	 30.0;
	6332	 11542	 0.000591	 0.005789	 0.0	 5429	 5429	 5429	 0.0	 0.0	 1	 -30.0	 30.0;
	6332	 4868	 0.002729	 0.011461	 0.0	 2682	 2682	 2682	 0.0	 0.0	 1	 -30.0	 30.0;
	6332	 8920	 0.00051	 0.00205	 0.0	 14953	 14953	 14953	 0.0	 0.0	 1	 -30.0	 30.0;
	12176	 9859	 0.00031	 0.00374	 0.0	 8417	 8417	 8417	 0.0	 0.0	 1	 -30.0	 30.0;
	3876	 12176	 0.00032	 0.00518	 0.0	 6087	 6087	 6087	 0.0	 0.0	 1	 -30.0	 30.0;
	2835	 10707	 0.00136	 0.01038	 0.0	 3018	 3018	 3018	 0.0	 0.0	 1	 -30.0	 30.0;
	12587	 8306	 0.00151	 0.02083	 0.0	 1513	 1513	 1513	 0.0	 0.0	 1	 -30.0	 30.0;
	11223	 8306	 0.00015	 0.00232	 0.0	 13587	 13587	 13587	 0.0	 0.0	 1	 -30.0	 30.0;
	7434	 11942	 1e-05	 0.00025	 0.0	 126249	 126249	 126249	 0.0	 0.0	 1	 -30.0	 30.0;
	8840	 11942	 1e-05	 0.00023	 0.0	 137207	 137207	 137207	 0.0	 0.0	 1	 -30.0	 30.0;
	3470	 11942	 0.00047	 0.00683	 0.0	 4614	 4614	 4614	 0.0	 0.0	 1	 -30.0	 30.0;
	1241	 11942	 0.00067	 0.00858	 0.0	 3671	 3671	 3671	 0.0	 0.0	 1	 -30.0	 30.0;
	3648	 1487	 0.003669	 0.025331	 0.0	 1235	 1235	 1235	 0.0	 0.0	 1	 -30.0	 30.0;
	546	 3648	 0.00525	 0.02994	 0.0	 1040	 1040	 1040	 0.0	 0.0	 1	 -30.0	 30.0;
	6852	 10025	 0.00595	 0.03625	 0.0	 860	 860	 860	 0.0	 0.0	 1	 -30.0	 30.0;
	6852	 1272	 0.004969	 0.03411	 0.0	 917	 917	 917	 0.0	 0.0	 1	 -30.0	 30.0;
	9133	 2643	 0.005669	 0.04293	 0.0	 730	 730	 730	 0.0	 0.0	 1	 -30.0	 30.0;
	9133	 2643	 0.00555	 0.043771	 0.0	 716	 716	 716	 0.0	 0.0	 1	 -30.0	 30.0;
	2643	 5625	 0.002831	 0.022401	 0.0	 1399	 1399	 1399	 0.0	 0.0	 1	 -30.0	 30.0;
	2643	 5625	 0.00325	 0.01938	 0.0	 1608	 1608	 1608	 0.0	 0.0	 1	 -30.0	 30.0;
	11845	 233	 0.00068	 0.00082	 0.0	 29652	 29652	 29652	 0.0	 0.0	 1	 -30.0	 30.0;
	11845	 2898	 0.00054	 0.00868	 0.0	 3633	 3633	 3633	 0.0	 0.0	 1	 -30.0	 30.0;
	2519	 5509	 0.00061	 0.002909	 0.0	 10628	 10628	 10628	 0.0	 0.0	 1	 -30.0	 30.0;
	2519	 2089	 0.002271	 0.01014	 0.0	 3040	 3040	 3040	 0.0	 0.0	 1	 -30.0	 30.0;
	5725	 1785	 0.00083	 0.00986	 0.0	 3193	 3193	 3193	 0.0	 0.0	 1	 -30.0	 30.0;
	1785	 11966	 0.00031	 0.00511	 0.0	 6171	 6171	 6171	 0.0	 0.0	 1	 -30.0	 30.0;
	1785	 11966	 0.0003	 0.00521	 0.0	 6053	 6053	 6053	 0.0	 0.0	 1	 -30.0	 30.0;
	12715	 1785	 0.00081	 0.01288	 0.0	 2448	 2448	 2448	 0.0	 0.0	 1	 -30.0	 30.0;
	1785	 13320	 0.00039	 0.00645	 0.0	 4889	 4889	 4889	 0.0	 0.0	 1	 -30.0	 30.0;
	5538	 6984	 0.00243	 0.012211	 0.0	 2538	 2538	 2538	 0.0	 0.0	 1	 -30.0	 30.0;
	5232	 7735	 0.00018	 0.00226	 0.0	 13933	 13933	 13933	 0.0	 0.0	 1	 -30.0	 30.0;
	6957	 7735	 0.0002	 0.00347	 0.0	 9088	 9088	 9088	 0.0	 0.0	 1	 -30.0	 30.0;
	4628	 7735	 0.00018	 0.0029	 0.0	 10872	 10872	 10872	 0.0	 0.0	 1	 -30.0	 30.0;
	8003	 9859	 0.00045	 0.00494	 0.0	 6368	 6368	 6368	 0.0	 0.0	 1	 -30.0	 30.0;
	9859	 3843	 0.00042	 0.00497	 0.0	 6334	 6334	 6334	 0.0	 0.0	 1	 -30.0	 30.0;
	4689	 12587	 0.00019	 0.00234	 0.0	 13455	 13455	 13455	 0.0	 0.0	 1	 -30.0	 30.0;
	10160	 12587	 8e-05	 0.00105	 0.0	 29997	 29997	 29997	 0.0	 0.0	 1	 -30.0	 30.0;
	10160	 12587	 8e-05	 0.00107	 0.0	 29439	 29439	 29439	 0.0	 0.0	 1	 -30.0	 30.0;
	12587	 11639	 8e-05	 0.001	 0.0	 31487	 31487	 31487	 0.0	 0.0	 1	 -30.0	 30.0;
	12587	 7796	 0.00063	 0.01015	 0.0	 3107	 3107	 3107	 0.0	 0.0	 1	 -30.0	 30.0;
	1239	 10646	 0.00064	 0.005651	 0.0	 5555	 5555	 5555	 0.0	 0.0	 1	 -30.0	 30.0;
	1239	 10646	 0.000581	 0.006531	 0.0	 4818	 4818	 4818	 0.0	 0.0	 1	 -30.0	 30.0;
	7467	 9197	 0.007099	 0.04432	 0.0	 704	 704	 704	 0.0	 0.0	 1	 -30.0	 30.0;
	3196	 2575	 0.00144	 0.01157	 0.0	 2710	 2710	 2710	 0.0	 0.0	 1	 -30.0	 30.0;
	3196	 860	 0.00114	 0.00695	 0.0	 4486	 4486	 4486	 0.0	 0.0	 1	 -30.0	 30.0;
	5232	 2403	 0.00044	 0.0053	 0.0	 5940	 5940	 5940	 0.0	 0.0	 1	 -30.0	 30.0;
	10333	 9683	 0.00162	 0.009039	 0.0	 3440	 3440	 3440	 0.0	 0.0	 1	 -30.0	 30.0;
	10333	 9683	 0.00187	 0.0072	 0.0	 4247	 4247	 4247	 0.0	 0.0	 1	 -30.0	 30.0;
	11772	 9683	 0.00101	 0.00564	 0.0	 5513	 5513	 5513	 0.0	 0.0	 1	 -30.0	 30.0;
	5453	 9683	 0.0007	 0.00445	 0.0	 7013	 7013	 7013	 0.0	 0.0	 1	 -30.0	 30.0;
	4177	 9683	 0.001081	 0.00619	 0.0	 5027	 5027	 5027	 0.0	 0.0	 1	 -30.0	 30.0;
	10160	 12229	 0.00022	 0.00228	 0.0	 13791	 13791	 13791	 0.0	 0.0	 1	 -30.0	 30.0;
	10160	 9069	 0.00023	 0.00223	 0.0	 14090	 14090	 14090	 0.0	 0.0	 1	 -30.0	 30.0;
	10160	 11671	 0.0002	 0.00262	 0.0	 12022	 12022	 12022	 0.0	 0.0	 1	 -30.0	 30.0;
	10160	 2742	 0.00021	 0.00261	 0.0	 12064	 12064	 12064	 0.0	 0.0	 1	 -30.0	 30.0;
	60	 10216	 0.00663	 0.04181	 0.0	 747	 747	 747	 0.0	 0.0	 1	 -30.0	 30.0;
	10160	 3519	 0.00059	 0.00921	 0.0	 3423	 3423	 3423	 0.0	 0.0	 1	 -30.0	 30.0;
	10160	 6109	 0.0014	 0.02227	 0.0	 1416	 1416	 1416	 0.0	 0.0	 1	 -30.0	 30.0;
	5685	 4037	 0.000401	 0.002469	 0.0	 12629	 12629	 12629	 0.0	 0.0	 1	 -30.0	 30.0;
	8229	 4037	 0.00212	 0.01218	 0.0	 2555	 2555	 2555	 0.0	 0.0	 1	 -30.0	 30.0;
	4037	 2882	 0.004169	 0.02439	 0.0	 1277	 1277	 1277	 0.0	 0.0	 1	 -30.0	 30.0;
	12442	 13406	 0.02336	 0.122419	 0.0	 254	 254	 254	 0.0	 0.0	 1	 -30.0	 30.0;
	12442	 997	 0.002729	 0.0137	 0.0	 2262	 2262	 2262	 0.0	 0.0	 1	 -30.0	 30.0;
	4123	 12442	 0.000919	 0.003831	 0.0	 8018	 8018	 8018	 0.0	 0.0	 1	 -30.0	 30.0;
	4123	 12442	 0.00082	 0.004349	 0.0	 7138	 7138	 7138	 0.0	 0.0	 1	 -30.0	 30.0;
	6626	 12442	 0.01325	 0.055159	 0.0	 557	 557	 557	 0.0	 0.0	 1	 -30.0	 30.0;
	6626	 12442	 0.0108	 0.06074	 0.0	 513	 513	 513	 0.0	 0.0	 1	 -30.0	 30.0;
	12442	 7044	 0.001099	 0.00631	 0.0	 4932	 4932	 4932	 0.0	 0.0	 1	 -30.0	 30.0;
	11420	 1430	 0.00495	 0.029151	 0.0	 1069	 1069	 1069	 0.0	 0.0	 1	 -30.0	 30.0;
	1430	 13217	 0.003909	 0.0227	 0.0	 1372	 1372	 1372	 0.0	 0.0	 1	 -30.0	 30.0;
	5423	 5219	 0.00061	 0.00424	 0.0	 7374	 7374	 7374	 0.0	 0.0	 1	 -30.0	 30.0;
	4113	 1637	 0.00068	 0.003919	 0.0	 7942	 7942	 7942	 0.0	 0.0	 1	 -30.0	 30.0;
	6707	 1637	 0.00368	 0.019901	 0.0	 1561	 1561	 1561	 0.0	 0.0	 1	 -30.0	 30.0;
	10873	 6957	 0.00025	 0.00388	 0.0	 8125	 8125	 8125	 0.0	 0.0	 1	 -30.0	 30.0;
	10873	 557	 0.00038	 0.00623	 0.0	 5061	 5061	 5061	 0.0	 0.0	 1	 -30.0	 30.0;
	9945	 1247	 0.000909	 0.006031	 0.0	 5180	 5180	 5180	 0.0	 0.0	 1	 -30.0	 30.0;
	1247	 2575	 0.001211	 0.0062	 0.0	 5001	 5001	 5001	 0.0	 0.0	 1	 -30.0	 30.0;
	3470	 597	 0.00022	 0.00322	 0.0	 9787	 9787	 9787	 0.0	 0.0	 1	 -30.0	 30.0;
	3470	 6619	 0.00018	 0.00307	 0.0	 10272	 10272	 10272	 0.0	 0.0	 1	 -30.0	 30.0;
	3470	 7220	 0.00068	 0.00873	 0.0	 3608	 3608	 3608	 0.0	 0.0	 1	 -30.0	 30.0;
	3470	 12006	 0.00124	 0.02016	 0.0	 1564	 1564	 1564	 0.0	 0.0	 1	 -30.0	 30.0;
	13516	 10714	 0.00025	 0.00332	 0.0	 9488	 9488	 9488	 0.0	 0.0	 1	 -30.0	 30.0;
	13516	 10714	 0.00025	 0.00335	 0.0	 9403	 9403	 9403	 0.0	 0.0	 1	 -30.0	 30.0;
	13516	 10714	 0.00025	 0.00325	 0.0	 9691	 9691	 9691	 0.0	 0.0	 1	 -30.0	 30.0;
	4421	 13516	 0.00076	 0.01075	 0.0	 2932	 2932	 2932	 0.0	 0.0	 1	 -30.0	 30.0;
	10206	 13516	 3e-05	 0.00044	 0.0	 71624	 71624	 71624	 0.0	 0.0	 1	 -30.0	 30.0;
	9007	 11027	 0.001651	 0.010849	 0.0	 2879	 2879	 2879	 0.0	 0.0	 1	 -30.0	 30.0;
	12256	 9007	 0.00288	 0.018469	 0.0	 1690	 1690	 1690	 0.0	 0.0	 1	 -30.0	 30.0;
	10069	 2159	 0.00072	 0.00923	 0.0	 3412	 3412	 3412	 0.0	 0.0	 1	 -30.0	 30.0;
	10069	 12112	 0.00069	 0.00855	 0.0	 3683	 3683	 3683	 0.0	 0.0	 1	 -30.0	 30.0;
	4599	 6710	 0.00124	 0.01667	 0.0	 1890	 1890	 1890	 0.0	 0.0	 1	 -30.0	 30.0;
	4599	 7383	 0.00034	 0.00571	 0.0	 5523	 5523	 5523	 0.0	 0.0	 1	 -30.0	 30.0;
	6767	 4599	 0.0004	 0.00638	 0.0	 4942	 4942	 4942	 0.0	 0.0	 1	 -30.0	 30.0;
	6767	 4599	 0.00039	 0.0065	 0.0	 4851	 4851	 4851	 0.0	 0.0	 1	 -30.0	 30.0;
	11591	 4599	 0.00027	 0.00451	 0.0	 6992	 6992	 6992	 0.0	 0.0	 1	 -30.0	 30.0;
	13479	 5720	 0.012409	 0.074961	 0.0	 416	 416	 416	 0.0	 0.0	 1	 -30.0	 30.0;
	13479	 12694	 0.002419	 0.01761	 0.0	 1778	 1778	 1778	 0.0	 0.0	 1	 -30.0	 30.0;
	13479	 2017	 0.006901	 0.053409	 0.0	 587	 587	 587	 0.0	 0.0	 1	 -30.0	 30.0;
	4113	 17	 0.000599	 0.00356	 0.0	 8750	 8750	 8750	 0.0	 0.0	 1	 -30.0	 30.0;
	4113	 6626	 0.011841	 0.049341	 0.0	 623	 623	 623	 0.0	 0.0	 1	 -30.0	 30.0;
	6705	 1267	 0.000521	 0.004831	 0.0	 6501	 6501	 6501	 0.0	 0.0	 1	 -30.0	 30.0;
	128	 1267	 0.00055	 0.00143	 0.0	 20617	 20617	 20617	 0.0	 0.0	 1	 -30.0	 30.0;
	11316	 1267	 0.0005	 0.00364	 0.0	 8598	 8598	 8598	 0.0	 0.0	 1	 -30.0	 30.0;
	11316	 1267	 0.00056	 0.003469	 0.0	 8990	 8990	 8990	 0.0	 0.0	 1	 -30.0	 30.0;
	1267	 7570	 0.00082	 0.00257	 0.0	 11710	 11710	 11710	 0.0	 0.0	 1	 -30.0	 30.0;
	6643	 7934	 0.00249	 0.01536	 0.0	 2030	 2030	 2030	 0.0	 0.0	 1	 -30.0	 30.0;
	6643	 3563	 0.00113	 0.00651	 0.0	 4781	 4781	 4781	 0.0	 0.0	 1	 -30.0	 30.0;
	11910	 12598	 0.00643	 0.045031	 0.0	 695	 695	 695	 0.0	 0.0	 1	 -30.0	 30.0;
	12549	 11910	 0.003581	 0.02706	 0.0	 1158	 1158	 1158	 0.0	 0.0	 1	 -30.0	 30.0;
	2591	 2196	 0.00046	 0.00774	 0.0	 4074	 4074	 4074	 0.0	 0.0	 1	 -30.0	 30.0;
	2591	 9458	 0.00031	 0.00483	 0.0	 6527	 6527	 6527	 0.0	 0.0	 1	 -30.0	 30.0;
	13153	 5535	 0.001099	 0.00345	 0.0	 8724	 8724	 8724	 0.0	 0.0	 1	 -30.0	 30.0;
	1778	 1396	 0.00913	 0.053211	 0.0	 586	 586	 586	 0.0	 0.0	 1	 -30.0	 30.0;
	1396	 2476	 0.021151	 0.095401	 0.0	 324	 324	 324	 0.0	 0.0	 1	 -30.0	 30.0;
	9008	 6710	 0.00034	 0.0055	 0.0	 5733	 5733	 5733	 0.0	 0.0	 1	 -30.0	 30.0;
	3949	 5200	 0.00064	 0.01945	 0.0	 1624	 1624	 1624	 0.0	 0.0	 1	 -30.0	 30.0;
	3949	 12823	 0.0004	 0.01026	 0.0	 3077	 3077	 3077	 0.0	 0.0	 1	 -30.0	 30.0;
	9752	 3949	 0.00071	 0.01087	 0.0	 2900	 2900	 2900	 0.0	 0.0	 1	 -30.0	 30.0;
	12996	 2083	 0.00968	 0.088169	 0.0	 357	 357	 357	 0.0	 0.0	 1	 -30.0	 30.0;
	12996	 2083	 0.012349	 0.086409	 0.0	 362	 362	 362	 0.0	 0.0	 1	 -30.0	 30.0;
	2083	 6018	 0.00288	 0.017211	 0.0	 1811	 1811	 1811	 0.0	 0.0	 1	 -30.0	 30.0;
	6018	 2083	 0.00257	 0.0195	 0.0	 1606	 1606	 1606	 0.0	 0.0	 1	 -30.0	 30.0;
	4450	 1487	 0.00051	 0.00407	 0.0	 7701	 7701	 7701	 0.0	 0.0	 1	 -30.0	 30.0;
	157	 9558	 0.00019	 0.00309	 0.0	 10204	 10204	 10204	 0.0	 0.0	 1	 -30.0	 30.0;
	157	 10392	 0.00023	 0.00357	 0.0	 8830	 8830	 8830	 0.0	 0.0	 1	 -30.0	 30.0;
	4795	 10467	 0.00088	 0.0092	 0.0	 3418	 3418	 3418	 0.0	 0.0	 1	 -30.0	 30.0;
	4795	 437	 0.00023	 0.00179	 0.0	 17503	 17503	 17503	 0.0	 0.0	 1	 -30.0	 30.0;
	8849	 1321	 0.00145	 0.007919	 0.0	 3924	 3924	 3924	 0.0	 0.0	 1	 -30.0	 30.0;
	692	 1321	 0.00143	 0.00812	 0.0	 3832	 3832	 3832	 0.0	 0.0	 1	 -30.0	 30.0;
	1321	 8264	 0.00524	 0.02181	 0.0	 1409	 1409	 1409	 0.0	 0.0	 1	 -30.0	 30.0;
	2899	 5538	 0.00261	 0.01913	 0.0	 1637	 1637	 1637	 0.0	 0.0	 1	 -30.0	 30.0;
	6626	 5538	 0.00164	 0.016591	 0.0	 1895	 1895	 1895	 0.0	 0.0	 1	 -30.0	 30.0;
	6574	 7660	 0.00087	 0.012719	 0.0	 2478	 2478	 2478	 0.0	 0.0	 1	 -30.0	 30.0;
	3	 11181	 0.00775	 0.03501	 0.0	 881	 881	 881	 0.0	 0.0	 1	 -30.0	 30.0;
	3	 11505	 0.01944	 0.093479	 0.0	 331	 331	 331	 0.0	 0.0	 1	 -30.0	 30.0;
	3	 11505	 0.01981	 0.091539	 0.0	 338	 338	 338	 0.0	 0.0	 1	 -30.0	 30.0;
	9382	 8209	 0.003771	 0.020599	 0.0	 1509	 1509	 1509	 0.0	 0.0	 1	 -30.0	 30.0;
	12846	 9382	 0.001271	 0.00811	 0.0	 3848	 3848	 3848	 0.0	 0.0	 1	 -30.0	 30.0;
	9207	 1541	 0.00048	 0.01459	 0.0	 2164	 2164	 2164	 0.0	 0.0	 1	 -30.0	 30.0;
	5200	 9207	 0.00047	 0.01351	 0.0	 2337	 2337	 2337	 0.0	 0.0	 1	 -30.0	 30.0;
	3386	 2092	 0.021729	 0.088281	 0.0	 348	 348	 348	 0.0	 0.0	 1	 -30.0	 30.0;
	2092	 4123	 0.00038	 0.001771	 0.0	 17439	 17439	 17439	 0.0	 0.0	 1	 -30.0	 30.0;
	2092	 1778	 0.022901	 0.101401	 0.0	 304	 304	 304	 0.0	 0.0	 1	 -30.0	 30.0;
	7	 7944	 0.002909	 0.01432	 0.0	 2162	 2162	 2162	 0.0	 0.0	 1	 -30.0	 30.0;
	7	 3830	 0.015729	 0.08824	 0.0	 353	 353	 353	 0.0	 0.0	 1	 -30.0	 30.0;
	4170	 10167	 0.00038	 0.002169	 0.0	 14345	 14345	 14345	 0.0	 0.0	 1	 -30.0	 30.0;
	2575	 4170	 0.000479	 0.00212	 0.0	 14534	 14534	 14534	 0.0	 0.0	 1	 -30.0	 30.0;
	4170	 590	 0.00019	 0.00086	 0.0	 35865	 35865	 35865	 0.0	 0.0	 1	 -30.0	 30.0;
	1106	 201	 0.00089	 0.004901	 0.0	 6342	 6342	 6342	 0.0	 0.0	 1	 -30.0	 30.0;
	5689	 1541	 0.00109	 0.03151	 0.0	 1002	 1002	 1002	 0.0	 0.0	 1	 -30.0	 30.0;
	9133	 9070	 0.003409	 0.020271	 0.0	 1537	 1537	 1537	 0.0	 0.0	 1	 -30.0	 30.0;
	9133	 9070	 0.002909	 0.02388	 0.0	 1314	 1314	 1314	 0.0	 0.0	 1	 -30.0	 30.0;
	9070	 5625	 0.00545	 0.042969	 0.0	 730	 730	 730	 0.0	 0.0	 1	 -30.0	 30.0;
	9070	 5625	 0.005341	 0.0438	 0.0	 716	 716	 716	 0.0	 0.0	 1	 -30.0	 30.0;
	7977	 10969	 0.001521	 0.00863	 0.0	 3605	 3605	 3605	 0.0	 0.0	 1	 -30.0	 30.0;
	4625	 7977	 0.00057	 0.005979	 0.0	 5260	 5260	 5260	 0.0	 0.0	 1	 -30.0	 30.0;
	1117	 8349	 0.00085	 0.01449	 0.0	 2177	 2177	 2177	 0.0	 0.0	 1	 -30.0	 30.0;
	1241	 8349	 0.0006	 0.00777	 0.0	 4054	 4054	 4054	 0.0	 0.0	 1	 -30.0	 30.0;
	7220	 8349	 0.0003	 0.00492	 0.0	 6409	 6409	 6409	 0.0	 0.0	 1	 -30.0	 30.0;
	3844	 3779	 0.003349	 0.02686	 0.0	 1167	 1167	 1167	 0.0	 0.0	 1	 -30.0	 30.0;
	3172	 3779	 0.00213	 0.016849	 0.0	 1860	 1860	 1860	 0.0	 0.0	 1	 -30.0	 30.0;
	5591	 13652	 0.00077	 0.0106	 0.0	 2973	 2973	 2973	 0.0	 0.0	 1	 -30.0	 30.0;
	12119	 13652	 0.00155	 0.0148	 0.0	 2123	 2123	 2123	 0.0	 0.0	 1	 -30.0	 30.0;
	2300	 9133	 0.016651	 0.10632	 0.0	 294	 294	 294	 0.0	 0.0	 1	 -30.0	 30.0;
	2300	 9133	 0.014841	 0.12049	 0.0	 261	 261	 261	 0.0	 0.0	 1	 -30.0	 30.0;
	6845	 9133	 9.9e-05	 0.001229	 0.0	 25619	 25619	 25619	 0.0	 0.0	 1	 -30.0	 30.0;
	11349	 9133	 9.9e-05	 0.00114	 0.0	 27605	 27605	 27605	 0.0	 0.0	 1	 -30.0	 30.0;
	12162	 3126	 0.00048	 0.00781	 0.0	 4037	 4037	 4037	 0.0	 0.0	 1	 -30.0	 30.0;
	12162	 4877	 0.00076	 0.01058	 0.0	 2978	 2978	 2978	 0.0	 0.0	 1	 -30.0	 30.0;
	12675	 12162	 0.00073	 0.01181	 0.0	 2670	 2670	 2670	 0.0	 0.0	 1	 -30.0	 30.0;
	10597	 7383	 0.00059	 0.00929	 0.0	 3394	 3394	 3394	 0.0	 0.0	 1	 -30.0	 30.0;
	212	 7383	 8e-05	 0.00092	 0.0	 34205	 34205	 34205	 0.0	 0.0	 1	 -30.0	 30.0;
	443	 1487	 0.00019	 0.000849	 0.0	 36308	 36308	 36308	 0.0	 0.0	 1	 -30.0	 30.0;
	3413	 5807	 0.003479	 0.01538	 0.0	 2004	 2004	 2004	 0.0	 0.0	 1	 -30.0	 30.0;
	3413	 5807	 0.003539	 0.01505	 0.0	 2044	 2044	 2044	 0.0	 0.0	 1	 -30.0	 30.0;
	3413	 2089	 0.01387	 0.084099	 0.0	 371	 371	 371	 0.0	 0.0	 1	 -30.0	 30.0;
	1573	 3413	 0.00375	 0.021341	 0.0	 1458	 1458	 1458	 0.0	 0.0	 1	 -30.0	 30.0;
	12345	 7830	 0.00023	 0.00345	 0.0	 9136	 9136	 9136	 0.0	 0.0	 1	 -30.0	 30.0;
	7830	 2403	 0.00054	 0.00662	 0.0	 4756	 4756	 4756	 0.0	 0.0	 1	 -30.0	 30.0;
	597	 12655	 7e-05	 0.00099	 0.0	 31827	 31827	 31827	 0.0	 0.0	 1	 -30.0	 30.0;
	8016	 597	 0.00012	 0.002	 0.0	 15766	 15766	 15766	 0.0	 0.0	 1	 -30.0	 30.0;
	343	 10467	 0.00075	 0.00888	 0.0	 3545	 3545	 3545	 0.0	 0.0	 1	 -30.0	 30.0;
	4486	 10467	 0.00054	 0.00705	 0.0	 4468	 4468	 4468	 0.0	 0.0	 1	 -30.0	 30.0;
	10025	 6078	 0.00574	 0.0287	 0.0	 1080	 1080	 1080	 0.0	 0.0	 1	 -30.0	 30.0;
	10025	 10632	 0.001331	 0.009479	 0.0	 3300	 3300	 3300	 0.0	 0.0	 1	 -30.0	 30.0;
	10632	 10025	 0.00539	 0.024159	 0.0	 1277	 1277	 1277	 0.0	 0.0	 1	 -30.0	 30.0;
	7316	 10025	 0.000539	 0.0028	 0.0	 11078	 11078	 11078	 0.0	 0.0	 1	 -30.0	 30.0;
	11316	 11785	 0.000969	 0.00724	 0.0	 4325	 4325	 4325	 0.0	 0.0	 1	 -30.0	 30.0;
	9723	 11785	 0.000349	 0.00339	 0.0	 9269	 9269	 9269	 0.0	 0.0	 1	 -30.0	 30.0;
	3843	 12345	 0.00021	 0.00349	 0.0	 9035	 9035	 9035	 0.0	 0.0	 1	 -30.0	 30.0;
	11772	 60	 0.00318	 0.020669	 0.0	 1511	 1511	 1511	 0.0	 0.0	 1	 -30.0	 30.0;
	11772	 60	 0.003599	 0.02026	 0.0	 1536	 1536	 1536	 0.0	 0.0	 1	 -30.0	 30.0;
	60	 9311	 0.0053	 0.035521	 0.0	 880	 880	 880	 0.0	 0.0	 1	 -30.0	 30.0;
	60	 4007	 0.00486	 0.024331	 0.0	 1274	 1274	 1274	 0.0	 0.0	 1	 -30.0	 30.0;
	9945	 6705	 0.000659	 0.00645	 0.0	 4872	 4872	 4872	 0.0	 0.0	 1	 -30.0	 30.0;
	7944	 5240	 0.00239	 0.01531	 0.0	 2039	 2039	 2039	 0.0	 0.0	 1	 -30.0	 30.0;
	11901	 2241	 0.00119	 0.01215	 0.0	 2588	 2588	 2588	 0.0	 0.0	 1	 -30.0	 30.0;
	2241	 10536	 0.00012	 0.0015	 0.0	 20992	 20992	 20992	 0.0	 0.0	 1	 -30.0	 30.0;
	2241	 2550	 0.00047	 0.00738	 0.0	 4272	 4272	 4272	 0.0	 0.0	 1	 -30.0	 30.0;
	11542	 8678	 0.00068	 0.00189	 0.0	 15726	 15726	 15726	 0.0	 0.0	 1	 -30.0	 30.0;
	7309	 12574	 0.003669	 0.022099	 0.0	 1411	 1411	 1411	 0.0	 0.0	 1	 -30.0	 30.0;
	12846	 12574	 0.004771	 0.0218	 0.0	 1416	 1416	 1416	 0.0	 0.0	 1	 -30.0	 30.0;
	4177	 11181	 0.001469	 0.006591	 0.0	 4678	 4678	 4678	 0.0	 0.0	 1	 -30.0	 30.0;
	4881	 747	 8.1e-05	 0.00045	 0.0	 69084	 69084	 69084	 0.0	 0.0	 1	 -30.0	 30.0;
	747	 692	 0.001021	 0.00782	 0.0	 4006	 4006	 4006	 0.0	 0.0	 1	 -30.0	 30.0;
	5926	 747	 0.0015	 0.009591	 0.0	 3254	 3254	 3254	 0.0	 0.0	 1	 -30.0	 30.0;
	8998	 11495	 0.00019	 0.001581	 0.0	 19837	 19837	 19837	 0.0	 0.0	 1	 -30.0	 30.0;
	8998	 11316	 3.9e-05	 0.000479	 0.0	 65727	 65727	 65727	 0.0	 0.0	 1	 -30.0	 30.0;
	10714	 12703	 0.00027	 0.00281	 0.0	 11190	 11190	 11190	 0.0	 0.0	 1	 -30.0	 30.0;
	7968	 10714	 0.00096	 0.01609	 0.0	 1960	 1960	 1960	 0.0	 0.0	 1	 -30.0	 30.0;
	10714	 12675	 0.00027	 0.00339	 0.0	 9289	 9289	 9289	 0.0	 0.0	 1	 -30.0	 30.0;
	10714	 12675	 0.00023	 0.00398	 0.0	 7924	 7924	 7924	 0.0	 0.0	 1	 -30.0	 30.0;
	1867	 11027	 0.000901	 0.00937	 0.0	 3356	 3356	 3356	 0.0	 0.0	 1	 -30.0	 30.0;
	13225	 11027	 0.001901	 0.01549	 0.0	 2025	 2025	 2025	 0.0	 0.0	 1	 -30.0	 30.0;
	12256	 11027	 0.003591	 0.02205	 0.0	 1414	 1414	 1414	 0.0	 0.0	 1	 -30.0	 30.0;
	11027	 8297	 0.0013	 0.009901	 0.0	 3164	 3164	 3164	 0.0	 0.0	 1	 -30.0	 30.0;
	3824	 4421	 0.00022	 0.00299	 0.0	 10536	 10536	 10536	 0.0	 0.0	 1	 -30.0	 30.0;
	4421	 12762	 0.00047	 0.00564	 0.0	 5582	 5582	 5582	 0.0	 0.0	 1	 -30.0	 30.0;
	8	 4421	 0.00046	 0.0075	 0.0	 4204	 4204	 4204	 0.0	 0.0	 1	 -30.0	 30.0;
	9203	 1028	 0.00214	 0.020979	 0.0	 1498	 1498	 1498	 0.0	 0.0	 1	 -30.0	 30.0;
	4123	 1028	 0.004651	 0.03332	 0.0	 939	 939	 939	 0.0	 0.0	 1	 -30.0	 30.0;
	1028	 7554	 0.00468	 0.021281	 0.0	 1450	 1450	 1450	 0.0	 0.0	 1	 -30.0	 30.0;
	1028	 7044	 0.00581	 0.028331	 0.0	 1093	 1093	 1093	 0.0	 0.0	 1	 -30.0	 30.0;
	2520	 10548	 7e-05	 0.00086	 0.0	 36609	 36609	 36609	 0.0	 0.0	 1	 -30.0	 30.0;
	3777	 6523	 0.0002	 0.00279	 0.0	 11293	 11293	 11293	 0.0	 0.0	 1	 -30.0	 30.0;
	3777	 6523	 0.00017	 0.00333	 0.0	 9474	 9474	 9474	 0.0	 0.0	 1	 -30.0	 30.0;
	8283	 11901	 1e-05	 0.00036	 0.0	 87709	 87709	 87709	 0.0	 0.0	 1	 -30.0	 30.0;
	7570	 12746	 0.000401	 0.004081	 0.0	 7704	 7704	 7704	 0.0	 0.0	 1	 -30.0	 30.0;
	12746	 10499	 0.001581	 0.015719	 0.0	 2000	 2000	 2000	 0.0	 0.0	 1	 -30.0	 30.0;
	11326	 1272	 0.00012	 0.000229	 0.0	 122178	 122178	 122178	 0.0	 0.0	 1	 -30.0	 30.0;
	11326	 1272	 0.00012	 0.00024	 0.0	 117720	 117720	 117720	 0.0	 0.0	 1	 -30.0	 30.0;
	1272	 7315	 0.00132	 0.005729	 0.0	 5373	 5373	 5373	 0.0	 0.0	 1	 -30.0	 30.0;
	12979	 1272	 0.00438	 0.024901	 0.0	 1250	 1250	 1250	 0.0	 0.0	 1	 -30.0	 30.0;
	8209	 152	 0.005521	 0.023711	 0.0	 1298	 1298	 1298	 0.0	 0.0	 1	 -30.0	 30.0;
	343	 10793	 0.0008	 0.01014	 0.0	 3106	 3106	 3106	 0.0	 0.0	 1	 -30.0	 30.0;
	343	 10793	 0.00068	 0.01229	 0.0	 2567	 2567	 2567	 0.0	 0.0	 1	 -30.0	 30.0;
	3844	 9307	 0.001901	 0.01163	 0.0	 2681	 2681	 2681	 0.0	 0.0	 1	 -30.0	 30.0;
	2575	 804	 0.00101	 0.00824	 0.0	 3805	 3805	 3805	 0.0	 0.0	 1	 -30.0	 30.0;
	12996	 8376	 0.00787	 0.068219	 0.0	 460	 460	 460	 0.0	 0.0	 1	 -30.0	 30.0;
	12996	 8376	 0.007711	 0.069539	 0.0	 452	 452	 452	 0.0	 0.0	 1	 -30.0	 30.0;
	2300	 8730	 0.00032	 0.002091	 0.0	 14933	 14933	 14933	 0.0	 0.0	 1	 -30.0	 30.0;
	4010	 6756	 0.00012	 0.00182	 0.0	 17319	 17319	 17319	 0.0	 0.0	 1	 -30.0	 30.0;
	6756	 8	 0.00058	 0.00736	 0.0	 4279	 4279	 4279	 0.0	 0.0	 1	 -30.0	 30.0;
	4010	 2520	 0.00074	 0.01143	 0.0	 2758	 2758	 2758	 0.0	 0.0	 1	 -30.0	 30.0;
	10597	 8107	 0.00084	 0.01378	 0.0	 2289	 2289	 2289	 0.0	 0.0	 1	 -30.0	 30.0;
	10597	 10525	 0.00037	 0.00356	 0.0	 8826	 8826	 8826	 0.0	 0.0	 1	 -30.0	 30.0;
	10392	 10597	 0.00012	 0.00206	 0.0	 15308	 15308	 15308	 0.0	 0.0	 1	 -30.0	 30.0;
	9718	 10565	 0.00036	 0.00151	 0.0	 20349	 20349	 20349	 0.0	 0.0	 1	 -30.0	 30.0;
	1117	 2159	 0.0012	 0.01835	 0.0	 1718	 1718	 1718	 0.0	 0.0	 1	 -30.0	 30.0;
	2159	 12112	 0.00088	 0.01503	 0.0	 2099	 2099	 2099	 0.0	 0.0	 1	 -30.0	 30.0;
	3055	 2159	 0.00057	 0.00939	 0.0	 3358	 3358	 3358	 0.0	 0.0	 1	 -30.0	 30.0;
	2196	 5443	 0.00157	 0.02006	 0.0	 1570	 1570	 1570	 0.0	 0.0	 1	 -30.0	 30.0;
	2196	 8242	 0.00027	 0.00349	 0.0	 9024	 9024	 9024	 0.0	 0.0	 1	 -30.0	 30.0;
	11223	 2196	 0.00136	 0.02325	 0.0	 1357	 1357	 1357	 0.0	 0.0	 1	 -30.0	 30.0;
	2196	 5725	 0.00038	 0.00478	 0.0	 6588	 6588	 6588	 0.0	 0.0	 1	 -30.0	 30.0;
	2196	 9432	 0.00077	 0.01171	 0.0	 2692	 2692	 2692	 0.0	 0.0	 1	 -30.0	 30.0;
	1117	 7968	 0.00129	 0.02076	 0.0	 1519	 1519	 1519	 0.0	 0.0	 1	 -30.0	 30.0;
	1117	 2520	 0.00037	 0.0046	 0.0	 6845	 6845	 6845	 0.0	 0.0	 1	 -30.0	 30.0;
	2520	 1117	 0.00021	 0.00375	 0.0	 8411	 8411	 8411	 0.0	 0.0	 1	 -30.0	 30.0;
	1117	 3055	 0.00055	 0.00885	 0.0	 3563	 3563	 3563	 0.0	 0.0	 1	 -30.0	 30.0;
	9945	 2575	 0.001659	 0.01138	 0.0	 2747	 2747	 2747	 0.0	 0.0	 1	 -30.0	 30.0;
	9945	 7190	 0.001169	 0.010021	 0.0	 3131	 3131	 3131	 0.0	 0.0	 1	 -30.0	 30.0;
	9945	 2017	 0.002229	 0.00975	 0.0	 3159	 3159	 3159	 0.0	 0.0	 1	 -30.0	 30.0;
	9945	 8384	 0.00049	 0.004521	 0.0	 6947	 6947	 6947	 0.0	 0.0	 1	 -30.0	 30.0;
	9945	 9723	 0.0002	 0.001969	 0.0	 15961	 15961	 15961	 0.0	 0.0	 1	 -30.0	 30.0;
	4302	 7092	 0.0001	 0.00158	 0.0	 19953	 19953	 19953	 0.0	 0.0	 1	 -30.0	 30.0;
	4302	 7092	 0.00011	 0.00151	 0.0	 20864	 20864	 20864	 0.0	 0.0	 1	 -30.0	 30.0;
	1700	 7238	 3e-05	 0.00043	 0.0	 73281	 73281	 73281	 0.0	 0.0	 1	 -30.0	 30.0;
	1700	 998	 0.00037	 0.00589	 0.0	 5353	 5353	 5353	 0.0	 0.0	 1	 -30.0	 30.0;
	2898	 1700	 0.00087	 0.01218	 0.0	 2587	 2587	 2587	 0.0	 0.0	 1	 -30.0	 30.0;
	11430	 8376	 0.00362	 0.024409	 0.0	 1281	 1281	 1281	 0.0	 0.0	 1	 -30.0	 30.0;
	11430	 5625	 0.00488	 0.03119	 0.0	 1001	 1001	 1001	 0.0	 0.0	 1	 -30.0	 30.0;
	11772	 6940	 0.00055	 0.00264	 0.0	 11714	 11714	 11714	 0.0	 0.0	 1	 -30.0	 30.0;
	8920	 6940	 0.00031	 0.001341	 0.0	 22950	 22950	 22950	 0.0	 0.0	 1	 -30.0	 30.0;
	8678	 6940	 0.00012	 0.000669	 0.0	 46475	 46475	 46475	 0.0	 0.0	 1	 -30.0	 30.0;
	1188	 2407	 3.1e-05	 0.000469	 0.0	 67204	 67204	 67204	 0.0	 0.0	 1	 -30.0	 30.0;
	2837	 2407	 3.1e-05	 0.000461	 0.0	 68365	 68365	 68365	 0.0	 0.0	 1	 -30.0	 30.0;
	2899	 6600	 0.00607	 0.03457	 0.0	 900	 900	 900	 0.0	 0.0	 1	 -30.0	 30.0;
	6600	 6626	 0.0087	 0.047719	 0.0	 652	 652	 652	 0.0	 0.0	 1	 -30.0	 30.0;
	5591	 12119	 0.00129	 0.02159	 0.0	 1461	 1461	 1461	 0.0	 0.0	 1	 -30.0	 30.0;
	5591	 10874	 0.00091	 0.00903	 0.0	 3481	 3481	 3481	 0.0	 0.0	 1	 -30.0	 30.0;
	12715	 5591	 0.0004	 0.00518	 0.0	 6080	 6080	 6080	 0.0	 0.0	 1	 -30.0	 30.0;
	5591	 9841	 0.00032	 0.00557	 0.0	 5662	 5662	 5662	 0.0	 0.0	 1	 -30.0	 30.0;
	10969	 6917	 3.1e-05	 0.0002	 0.0	 156073	 156073	 156073	 0.0	 0.0	 1	 -30.0	 30.0;
	10969	 9046	 3.1e-05	 0.000211	 0.0	 148114	 148114	 148114	 0.0	 0.0	 1	 -30.0	 30.0;
	7934	 3691	 0.00199	 0.011591	 0.0	 2686	 2686	 2686	 0.0	 0.0	 1	 -30.0	 30.0;
	5447	 7934	 0.000211	 0.000919	 0.0	 33500	 33500	 33500	 0.0	 0.0	 1	 -30.0	 30.0;
	7796	 3519	 0.00109	 0.01525	 0.0	 2067	 2067	 2067	 0.0	 0.0	 1	 -30.0	 30.0;
	1084	 3691	 0.005789	 0.02826	 0.0	 1096	 1096	 1096	 0.0	 0.0	 1	 -30.0	 30.0;
	9558	 4128	 0.00041	 0.0064	 0.0	 4926	 4926	 4926	 0.0	 0.0	 1	 -30.0	 30.0;
	9558	 3843	 0.00051	 0.00603	 0.0	 5220	 5220	 5220	 0.0	 0.0	 1	 -30.0	 30.0;
	13023	 6282	 0.00245	 0.02726	 0.0	 1155	 1155	 1155	 0.0	 0.0	 1	 -30.0	 30.0;
	13023	 10499	 0.000271	 0.00337	 0.0	 9343	 9343	 9343	 0.0	 0.0	 1	 -30.0	 30.0;
	9332	 10063	 0.000151	 0.00064	 0.0	 48037	 48037	 48037	 0.0	 0.0	 1	 -30.0	 30.0;
	2769	 9332	 0.003341	 0.022091	 0.0	 1414	 1414	 1414	 0.0	 0.0	 1	 -30.0	 30.0;
	9332	 9311	 0.022	 0.125771	 0.0	 248	 248	 248	 0.0	 0.0	 1	 -30.0	 30.0;
	9332	 13428	 0.0153	 0.08863	 0.0	 352	 352	 352	 0.0	 0.0	 1	 -30.0	 30.0;
	9332	 13428	 0.015599	 0.08682	 0.0	 359	 359	 359	 0.0	 0.0	 1	 -30.0	 30.0;
	198	 2891	 0.001169	 0.00844	 0.0	 3708	 3708	 3708	 0.0	 0.0	 1	 -30.0	 30.0;
	10565	 198	 0.00081	 0.004271	 0.0	 7267	 7267	 7267	 0.0	 0.0	 1	 -30.0	 30.0;
	198	 8615	 0.000349	 0.0015	 0.0	 20511	 20511	 20511	 0.0	 0.0	 1	 -30.0	 30.0;
	5443	 9432	 0.00058	 0.00717	 0.0	 4392	 4392	 4392	 0.0	 0.0	 1	 -30.0	 30.0;
	5443	 8192	 0.0007	 0.01203	 0.0	 2622	 2622	 2622	 0.0	 0.0	 1	 -30.0	 30.0;
	8192	 5443	 0.00061	 0.00957	 0.0	 3294	 3294	 3294	 0.0	 0.0	 1	 -30.0	 30.0;
	12823	 3722	 2e-05	 0.00075	 0.0	 42102	 42102	 42102	 0.0	 0.0	 1	 -30.0	 30.0;
	9752	 12823	 0.00041	 0.01221	 0.0	 2586	 2586	 2586	 0.0	 0.0	 1	 -30.0	 30.0;
	1487	 12879	 0.00157	 0.007969	 0.0	 3890	 3890	 3890	 0.0	 0.0	 1	 -30.0	 30.0;
	6232	 12879	 0.00151	 0.00625	 0.0	 4913	 4913	 4913	 0.0	 0.0	 1	 -30.0	 30.0;
	6509	 6513	 2e-05	 0.00023	 0.0	 136820	 136820	 136820	 0.0	 0.0	 1	 -30.0	 30.0;
	6509	 6513	 2e-05	 0.00022	 0.0	 142990	 142990	 142990	 0.0	 0.0	 1	 -30.0	 30.0;
	5689	 6509	 0.00026	 0.00395	 0.0	 7980	 7980	 7980	 0.0	 0.0	 1	 -30.0	 30.0;
	5689	 6509	 0.00025	 0.00403	 0.0	 7824	 7824	 7824	 0.0	 0.0	 1	 -30.0	 30.0;
	13153	 2112	 0.00111	 0.005099	 0.0	 6054	 6054	 6054	 0.0	 0.0	 1	 -30.0	 30.0;
	2112	 6913	 0.000729	 0.0023	 0.0	 13092	 13092	 13092	 0.0	 0.0	 1	 -30.0	 30.0;
	6913	 11830	 0.003831	 0.016271	 0.0	 1890	 1890	 1890	 0.0	 0.0	 1	 -30.0	 30.0;
	6554	 13509	 0.001849	 0.014719	 0.0	 2130	 2130	 2130	 0.0	 0.0	 1	 -30.0	 30.0;
	10853	 6554	 0.00157	 0.010169	 0.0	 3070	 3070	 3070	 0.0	 0.0	 1	 -30.0	 30.0;
	11428	 9203	 0.00149	 0.01513	 0.0	 2078	 2078	 2078	 0.0	 0.0	 1	 -30.0	 30.0;
	9453	 11428	 0.003229	 0.02918	 0.0	 1076	 1076	 1076	 0.0	 0.0	 1	 -30.0	 30.0;
	12119	 9524	 1e-05	 0.00021	 0.0	 150246	 150246	 150246	 0.0	 0.0	 1	 -30.0	 30.0;
	3281	 3126	 0.00054	 0.00765	 0.0	 4119	 4119	 4119	 0.0	 0.0	 1	 -30.0	 30.0;
	5927	 8242	 1e-05	 0.0002	 0.0	 157740	 157740	 157740	 0.0	 0.0	 1	 -30.0	 30.0;
	8242	 9432	 0.00053	 0.00746	 0.0	 4224	 4224	 4224	 0.0	 0.0	 1	 -30.0	 30.0;
	4713	 5720	 0.010469	 0.057979	 0.0	 537	 537	 537	 0.0	 0.0	 1	 -30.0	 30.0;
	4713	 3796	 0.00014	 0.000781	 0.0	 39811	 39811	 39811	 0.0	 0.0	 1	 -30.0	 30.0;
	4713	 1253	 0.00181	 0.013039	 0.0	 2400	 2400	 2400	 0.0	 0.0	 1	 -30.0	 30.0;
	6078	 12979	 0.01107	 0.04905	 0.0	 629	 629	 629	 0.0	 0.0	 1	 -30.0	 30.0;
	3752	 2297	 0.00038	 0.00468	 0.0	 6728	 6728	 6728	 0.0	 0.0	 1	 -30.0	 30.0;
	3752	 2297	 0.00034	 0.0053	 0.0	 5948	 5948	 5948	 0.0	 0.0	 1	 -30.0	 30.0;
	4877	 3752	 0.00012	 0.00185	 0.0	 17039	 17039	 17039	 0.0	 0.0	 1	 -30.0	 30.0;
	4877	 3752	 0.00013	 0.00181	 0.0	 17407	 17407	 17407	 0.0	 0.0	 1	 -30.0	 30.0;
	7718	 11372	 0.000211	 0.0018	 0.0	 17430	 17430	 17430	 0.0	 0.0	 1	 -30.0	 30.0;
	2108	 2942	 0.00037	 0.00225	 0.0	 13853	 13853	 13853	 0.0	 0.0	 1	 -30.0	 30.0;
	7394	 11591	 0.00025	 0.00317	 0.0	 9934	 9934	 9934	 0.0	 0.0	 1	 -30.0	 30.0;
	2403	 7394	 0.00029	 0.00484	 0.0	 6515	 6515	 6515	 0.0	 0.0	 1	 -30.0	 30.0;
	142	 10618	 0.00057	 0.00858	 0.0	 3674	 3674	 3674	 0.0	 0.0	 1	 -30.0	 30.0;
	142	 13320	 0.0005	 0.00665	 0.0	 4737	 4737	 4737	 0.0	 0.0	 1	 -30.0	 30.0;
	860	 4356	 0.00239	 0.012289	 0.0	 2524	 2524	 2524	 0.0	 0.0	 1	 -30.0	 30.0;
	9607	 4356	 0.0008	 0.005211	 0.0	 5992	 5992	 5992	 0.0	 0.0	 1	 -30.0	 30.0;
	12112	 5908	 0.00067	 0.01081	 0.0	 2917	 2917	 2917	 0.0	 0.0	 1	 -30.0	 30.0;
	3837	 12112	 0.00105	 0.01455	 0.0	 2166	 2166	 2166	 0.0	 0.0	 1	 -30.0	 30.0;
	11421	 10618	 0.0002	 0.00261	 0.0	 12068	 12068	 12068	 0.0	 0.0	 1	 -30.0	 30.0;
	8708	 12890	 1e-05	 0.0002	 0.0	 157740	 157740	 157740	 0.0	 0.0	 1	 -30.0	 30.0;
	10874	 12890	 0.00036	 0.00601	 0.0	 5247	 5247	 5247	 0.0	 0.0	 1	 -30.0	 30.0;
	13320	 12890	 0.0001	 0.00151	 0.0	 20874	 20874	 20874	 0.0	 0.0	 1	 -30.0	 30.0;
	6580	 10148	 2e-05	 0.00021	 0.0	 149739	 149739	 149739	 0.0	 0.0	 1	 -30.0	 30.0;
	12119	 10148	 0.00046	 0.00568	 0.0	 5544	 5544	 5544	 0.0	 0.0	 1	 -30.0	 30.0;
	11460	 10148	 0.00041	 0.00531	 0.0	 5931	 5931	 5931	 0.0	 0.0	 1	 -30.0	 30.0;
	3824	 3281	 0.0003	 0.00482	 0.0	 6541	 6541	 6541	 0.0	 0.0	 1	 -30.0	 30.0;
	2898	 1934	 1e-05	 0.0002	 0.0	 157740	 157740	 157740	 0.0	 0.0	 1	 -30.0	 30.0;
	11223	 1623	 1e-05	 0.00022	 0.0	 143431	 143431	 143431	 0.0	 0.0	 1	 -30.0	 30.0;
	3875	 12655	 2e-05	 0.00025	 0.0	 125947	 125947	 125947	 0.0	 0.0	 1	 -30.0	 30.0;
	3875	 12655	 2e-05	 0.00026	 0.0	 121132	 121132	 121132	 0.0	 0.0	 1	 -30.0	 30.0;
	1241	 7518	 0.00032	 0.00528	 0.0	 5972	 5972	 5972	 0.0	 0.0	 1	 -30.0	 30.0;
	4204	 7518	 0.0006	 0.0084	 0.0	 3751	 3751	 3751	 0.0	 0.0	 1	 -30.0	 30.0;
	9458	 11966	 0.00105	 0.01735	 0.0	 1818	 1818	 1818	 0.0	 0.0	 1	 -30.0	 30.0;
	6109	 9458	 0.00135	 0.01758	 0.0	 1792	 1792	 1792	 0.0	 0.0	 1	 -30.0	 30.0;
	10618	 11966	 0.0004	 0.0068	 0.0	 4638	 4638	 4638	 0.0	 0.0	 1	 -30.0	 30.0;
	10618	 11966	 0.00039	 0.0063	 0.0	 5005	 5005	 5005	 0.0	 0.0	 1	 -30.0	 30.0;
	11966	 13320	 0.00067	 0.00834	 0.0	 3776	 3776	 3776	 0.0	 0.0	 1	 -30.0	 30.0;
	11247	 998	 0.00084	 0.01114	 0.0	 2828	 2828	 2828	 0.0	 0.0	 1	 -30.0	 30.0;
	2898	 998	 0.00081	 0.011	 0.0	 2864	 2864	 2864	 0.0	 0.0	 1	 -30.0	 30.0;
	4515	 4569	 0.00059	 0.00726	 0.0	 4337	 4337	 4337	 0.0	 0.0	 1	 -30.0	 30.0;
	6109	 4569	 0.001	 0.01178	 0.0	 2672	 2672	 2672	 0.0	 0.0	 1	 -30.0	 30.0;
	6513	 3355	 0.00031	 0.00197	 0.0	 15840	 15840	 15840	 0.0	 0.0	 1	 -30.0	 30.0;
	6513	 3355	 0.00035	 0.00193	 0.0	 16104	 16104	 16104	 0.0	 0.0	 1	 -30.0	 30.0;
	9380	 3355	 2e-05	 0.0004	 0.0	 78870	 78870	 78870	 0.0	 0.0	 1	 -30.0	 30.0;
	9380	 3355	 2e-05	 0.00041	 0.0	 76951	 76951	 76951	 0.0	 0.0	 1	 -30.0	 30.0;
	7136	 6695	 3.1e-05	 0.000271	 0.0	 115804	 115804	 115804	 0.0	 0.0	 1	 -30.0	 30.0;
	6695	 7136	 3.1e-05	 0.000281	 0.0	 111733	 111733	 111733	 0.0	 0.0	 1	 -30.0	 30.0;
	6695	 4688	 0.000229	 0.000271	 0.0	 89029	 89029	 89029	 0.0	 0.0	 1	 -30.0	 30.0;
	6338	 8518	 0.000289	 0.001229	 0.0	 25020	 25020	 25020	 0.0	 0.0	 1	 -30.0	 30.0;
	6338	 12979	 0.002479	 0.01106	 0.0	 2787	 2787	 2787	 0.0	 0.0	 1	 -30.0	 30.0;
	2476	 1084	 0.00738	 0.04069	 0.0	 764	 764	 764	 0.0	 0.0	 1	 -30.0	 30.0;
	6767	 3518	 0.00058	 0.00872	 0.0	 3615	 3615	 3615	 0.0	 0.0	 1	 -30.0	 30.0;
	3518	 11901	 0.00116	 0.01483	 0.0	 2124	 2124	 2124	 0.0	 0.0	 1	 -30.0	 30.0;
	3518	 11901	 0.00118	 0.01452	 0.0	 2169	 2169	 2169	 0.0	 0.0	 1	 -30.0	 30.0;
	10618	 4515	 0.00139	 0.02265	 0.0	 1392	 1392	 1392	 0.0	 0.0	 1	 -30.0	 30.0;
	10618	 4515	 0.00149	 0.02349	 0.0	 1343	 1343	 1343	 0.0	 0.0	 1	 -30.0	 30.0;
	5938	 4515	 0.00086	 0.01488	 0.0	 2120	 2120	 2120	 0.0	 0.0	 1	 -30.0	 30.0;
	5938	 4515	 0.00095	 0.01554	 0.0	 2029	 2029	 2029	 0.0	 0.0	 1	 -30.0	 30.0;
	505	 1102	 0.019651	 0.09944	 0.0	 312	 312	 312	 0.0	 0.0	 1	 -30.0	 30.0;
	10333	 1790	 0.0002	 0.001831	 0.0	 17150	 17150	 17150	 0.0	 0.0	 1	 -30.0	 30.0;
	13115	 4038	 7e-05	 0.00062	 0.0	 50626	 50626	 50626	 0.0	 0.0	 1	 -30.0	 30.0;
	4038	 17	 0.004039	 0.023081	 0.0	 1349	 1349	 1349	 0.0	 0.0	 1	 -30.0	 30.0;
	6626	 4038	 0.0132	 0.064331	 0.0	 481	 481	 481	 0.0	 0.0	 1	 -30.0	 30.0;
	4038	 13325	 0.001401	 0.008729	 0.0	 3573	 3573	 3573	 0.0	 0.0	 1	 -30.0	 30.0;
	9432	 13503	 0.00021	 0.00247	 0.0	 12743	 12743	 12743	 0.0	 0.0	 1	 -30.0	 30.0;
	9432	 8192	 0.00138	 0.01791	 0.0	 1759	 1759	 1759	 0.0	 0.0	 1	 -30.0	 30.0;
	12119	 11460	 0.00056	 0.00795	 0.0	 3964	 3964	 3964	 0.0	 0.0	 1	 -30.0	 30.0;
	12119	 7772	 0.00081	 0.00788	 0.0	 3988	 3988	 3988	 0.0	 0.0	 1	 -30.0	 30.0;
	11153	 6767	 3e-05	 0.00042	 0.0	 75017	 75017	 75017	 0.0	 0.0	 1	 -30.0	 30.0;
	2494	 6767	 3e-05	 0.00042	 0.0	 75017	 75017	 75017	 0.0	 0.0	 1	 -30.0	 30.0;
	12643	 6767	 3e-05	 0.00035	 0.0	 89920	 89920	 89920	 0.0	 0.0	 1	 -30.0	 30.0;
	9899	 6767	 3e-05	 0.00036	 0.0	 87440	 87440	 87440	 0.0	 0.0	 1	 -30.0	 30.0;
	11591	 6767	 0.00035	 0.00423	 0.0	 7443	 7443	 7443	 0.0	 0.0	 1	 -30.0	 30.0;
	4486	 7461	 0.00076	 0.00904	 0.0	 3482	 3482	 3482	 0.0	 0.0	 1	 -30.0	 30.0;
	7461	 437	 0.00029	 0.00361	 0.0	 8722	 8722	 8722	 0.0	 0.0	 1	 -30.0	 30.0;
	10383	 8849	 0.010349	 0.056729	 0.0	 548	 548	 548	 0.0	 0.0	 1	 -30.0	 30.0;
	10383	 2891	 0.001581	 0.012771	 0.0	 2455	 2455	 2455	 0.0	 0.0	 1	 -30.0	 30.0;
	10383	 1487	 0.001081	 0.01136	 0.0	 2769	 2769	 2769	 0.0	 0.0	 1	 -30.0	 30.0;
	10383	 6232	 0.001669	 0.00914	 0.0	 3400	 3400	 3400	 0.0	 0.0	 1	 -30.0	 30.0;
	10383	 8264	 0.01757	 0.07575	 0.0	 407	 407	 407	 0.0	 0.0	 1	 -30.0	 30.0;
	1166	 10525	 0.00037	 0.00558	 0.0	 5649	 5649	 5649	 0.0	 0.0	 1	 -30.0	 30.0;
	1166	 12762	 0.00041	 0.0072	 0.0	 4381	 4381	 4381	 0.0	 0.0	 1	 -30.0	 30.0;
	11420	 6707	 0.002479	 0.017961	 0.0	 1743	 1743	 1743	 0.0	 0.0	 1	 -30.0	 30.0;
	7061	 11420	 0.00155	 0.0127	 0.0	 2469	 2469	 2469	 0.0	 0.0	 1	 -30.0	 30.0;
	201	 11505	 0.001961	 0.010419	 0.0	 2980	 2980	 2980	 0.0	 0.0	 1	 -30.0	 30.0;
	3023	 2891	 0.00138	 0.007521	 0.0	 4131	 4131	 4131	 0.0	 0.0	 1	 -30.0	 30.0;
	11939	 3023	 0.00281	 0.02543	 0.0	 1235	 1235	 1235	 0.0	 0.0	 1	 -30.0	 30.0;
	3023	 12757	 0.000211	 0.000901	 0.0	 34135	 34135	 34135	 0.0	 0.0	 1	 -30.0	 30.0;
	13225	 5599	 0.000789	 0.00519	 0.0	 6018	 6018	 6018	 0.0	 0.0	 1	 -30.0	 30.0;
	13225	 149	 0.00056	 0.004281	 0.0	 7317	 7317	 7317	 0.0	 0.0	 1	 -30.0	 30.0;
	13225	 12256	 0.00163	 0.012031	 0.0	 2602	 2602	 2602	 0.0	 0.0	 1	 -30.0	 30.0;
	9453	 13225	 0.000211	 0.00161	 0.0	 19454	 19454	 19454	 0.0	 0.0	 1	 -30.0	 30.0;
	13225	 8297	 0.00018	 0.00144	 0.0	 21767	 21767	 21767	 0.0	 0.0	 1	 -30.0	 30.0;
	10730	 2575	 9.1e-05	 0.00081	 0.0	 38753	 38753	 38753	 0.0	 0.0	 1	 -30.0	 30.0;
	12508	 2575	 9.1e-05	 0.00099	 0.0	 31773	 31773	 31773	 0.0	 0.0	 1	 -30.0	 30.0;
	4868	 7438	 0.001219	 0.01461	 0.0	 2155	 2155	 2155	 0.0	 0.0	 1	 -30.0	 30.0;
	4868	 3129	 0.00769	 0.035169	 0.0	 878	 878	 878	 0.0	 0.0	 1	 -30.0	 30.0;
	11152	 4933	 5e-05	 0.000219	 0.0	 140617	 140617	 140617	 0.0	 0.0	 1	 -30.0	 30.0;
	4933	 8615	 0.000281	 0.00112	 0.0	 27356	 27356	 27356	 0.0	 0.0	 1	 -30.0	 30.0;
	8348	 6282	 0.003591	 0.01825	 0.0	 1699	 1699	 1699	 0.0	 0.0	 1	 -30.0	 30.0;
	8348	 6282	 0.00125	 0.01386	 0.0	 2270	 2270	 2270	 0.0	 0.0	 1	 -30.0	 30.0;
	505	 6282	 0.000961	 0.00513	 0.0	 6053	 6053	 6053	 0.0	 0.0	 1	 -30.0	 30.0;
	2297	 6438	 0.00022	 0.00295	 0.0	 10678	 10678	 10678	 0.0	 0.0	 1	 -30.0	 30.0;
	8254	 640	 0.00326	 0.02562	 0.0	 1224	 1224	 1224	 0.0	 0.0	 1	 -30.0	 30.0;
	8254	 11100	 0.00164	 0.013219	 0.0	 2372	 2372	 2372	 0.0	 0.0	 1	 -30.0	 30.0;
	6118	 1181	 8.1e-05	 0.00019	 0.0	 152932	 152932	 152932	 0.0	 0.0	 1	 -30.0	 30.0;
	6118	 1181	 3.9e-05	 0.00032	 0.0	 97986	 97986	 97986	 0.0	 0.0	 1	 -30.0	 30.0;
	6118	 1181	 0.00011	 0.0002	 0.0	 138387	 138387	 138387	 0.0	 0.0	 1	 -30.0	 30.0;
	6118	 1181	 0.000103	 0.000171	 0.0	 158234	 158234	 158234	 0.0	 0.0	 1	 -30.0	 30.0;
	6118	 1181	 0.00011	 0.00019	 0.0	 143877	 143877	 143877	 0.0	 0.0	 1	 -30.0	 30.0;
	6118	 5599	 8.1e-05	 0.001	 0.0	 31485	 31485	 31485	 0.0	 0.0	 1	 -30.0	 30.0;
	6118	 149	 0.000281	 0.00213	 0.0	 14703	 14703	 14703	 0.0	 0.0	 1	 -30.0	 30.0;
	9453	 6118	 0.00025	 0.000831	 0.0	 36400	 36400	 36400	 0.0	 0.0	 1	 -30.0	 30.0;
	12181	 6118	 0.00013	 0.000469	 0.0	 64904	 64904	 64904	 0.0	 0.0	 1	 -30.0	 30.0;
	4486	 343	 0.00088	 0.01144	 0.0	 2753	 2753	 2753	 0.0	 0.0	 1	 -30.0	 30.0;
	3187	 343	 0.00076	 0.01445	 0.0	 2183	 2183	 2183	 0.0	 0.0	 1	 -30.0	 30.0;
	3102	 11247	 0.00048	 0.0076	 0.0	 4148	 4148	 4148	 0.0	 0.0	 1	 -30.0	 30.0;
	11247	 3380	 0.00017	 0.00273	 0.0	 11549	 11549	 11549	 0.0	 0.0	 1	 -30.0	 30.0;
	13217	 12414	 0.00014	 0.000849	 0.0	 36710	 36710	 36710	 0.0	 0.0	 1	 -30.0	 30.0;
	7309	 13217	 0.0022	 0.01289	 0.0	 2416	 2416	 2416	 0.0	 0.0	 1	 -30.0	 30.0;
	5217	 11550	 0.00582	 0.03749	 0.0	 833	 833	 833	 0.0	 0.0	 1	 -30.0	 30.0;
	5217	 11550	 0.00593	 0.03669	 0.0	 850	 850	 850	 0.0	 0.0	 1	 -30.0	 30.0;
	11550	 8448	 0.000281	 0.003419	 0.0	 9208	 9208	 9208	 0.0	 0.0	 1	 -30.0	 30.0;
	11550	 6018	 0.00645	 0.03995	 0.0	 781	 781	 781	 0.0	 0.0	 1	 -30.0	 30.0;
	11550	 6018	 0.00657	 0.039081	 0.0	 798	 798	 798	 0.0	 0.0	 1	 -30.0	 30.0;
	12378	 13132	 8e-05	 0.00125	 0.0	 25219	 25219	 25219	 0.0	 0.0	 1	 -30.0	 30.0;
	12378	 12938	 8e-05	 0.00127	 0.0	 24823	 24823	 24823	 0.0	 0.0	 1	 -30.0	 30.0;
	12378	 6751	 7e-05	 0.0013	 0.0	 24263	 24263	 24263	 0.0	 0.0	 1	 -30.0	 30.0;
	12378	 9366	 7e-05	 0.0012	 0.0	 26279	 26279	 26279	 0.0	 0.0	 1	 -30.0	 30.0;
	10553	 8107	 5e-05	 0.0006	 0.0	 52464	 52464	 52464	 0.0	 0.0	 1	 -30.0	 30.0;
	8107	 8	 0.00034	 0.00466	 0.0	 6761	 6761	 6761	 0.0	 0.0	 1	 -30.0	 30.0;
	10632	 10565	 0.000591	 0.00588	 0.0	 5346	 5346	 5346	 0.0	 0.0	 1	 -30.0	 30.0;
	10565	 10632	 0.00139	 0.00818	 0.0	 3807	 3807	 3807	 0.0	 0.0	 1	 -30.0	 30.0;
	6232	 10632	 0.00169	 0.013969	 0.0	 2245	 2245	 2245	 0.0	 0.0	 1	 -30.0	 30.0;
	5819	 502	 0.000229	 0.00163	 0.0	 19191	 19191	 19191	 0.0	 0.0	 1	 -30.0	 30.0;
	6388	 7315	 0.00275	 0.02836	 0.0	 1109	 1109	 1109	 0.0	 0.0	 1	 -30.0	 30.0;
	70	 7315	 0.004909	 0.02468	 0.0	 1256	 1256	 1256	 0.0	 0.0	 1	 -30.0	 30.0;
	7315	 12979	 0.001419	 0.02212	 0.0	 1426	 1426	 1426	 0.0	 0.0	 1	 -30.0	 30.0;
	6688	 12378	 0.0016	 0.02118	 0.0	 1488	 1488	 1488	 0.0	 0.0	 1	 -30.0	 30.0;
	12378	 1309	 0.00116	 0.01869	 0.0	 1687	 1687	 1687	 0.0	 0.0	 1	 -30.0	 30.0;
	12006	 12378	 0.00169	 0.02149	 0.0	 1466	 1466	 1466	 0.0	 0.0	 1	 -30.0	 30.0;
	12378	 7772	 0.00171	 0.02913	 0.0	 1083	 1083	 1083	 0.0	 0.0	 1	 -30.0	 30.0;
	12378	 9199	 0.00138	 0.0212	 0.0	 1487	 1487	 1487	 0.0	 0.0	 1	 -30.0	 30.0;
	3563	 5423	 0.00511	 0.02775	 0.0	 1120	 1120	 1120	 0.0	 0.0	 1	 -30.0	 30.0;
	7796	 6109	 0.0008	 0.01262	 0.0	 2498	 2498	 2498	 0.0	 0.0	 1	 -30.0	 30.0;
	7492	 557	 0.0005	 0.00851	 0.0	 3706	 3706	 3706	 0.0	 0.0	 1	 -30.0	 30.0;
	7492	 3876	 0.00032	 0.00558	 0.0	 5652	 5652	 5652	 0.0	 0.0	 1	 -30.0	 30.0;
	3856	 8016	 0.00039	 0.00601	 0.0	 5245	 5245	 5245	 0.0	 0.0	 1	 -30.0	 30.0;
	3856	 6619	 0.00036	 0.00575	 0.0	 5483	 5483	 5483	 0.0	 0.0	 1	 -30.0	 30.0;
	3856	 11938	 0.00117	 0.01616	 0.0	 1950	 1950	 1950	 0.0	 0.0	 1	 -30.0	 30.0;
	1241	 9008	 0.0003	 0.00471	 0.0	 6693	 6693	 6693	 0.0	 0.0	 1	 -30.0	 30.0;
	5217	 1080	 0.00011	 0.00081	 0.0	 38643	 38643	 38643	 0.0	 0.0	 1	 -30.0	 30.0;
	5217	 2300	 0.01087	 0.06457	 0.0	 483	 483	 483	 0.0	 0.0	 1	 -30.0	 30.0;
	5217	 2300	 0.00968	 0.073169	 0.0	 428	 428	 428	 0.0	 0.0	 1	 -30.0	 30.0;
	2891	 11152	 0.00105	 0.005781	 0.0	 5377	 5377	 5377	 0.0	 0.0	 1	 -30.0	 30.0;
	3080	 4123	 0.002961	 0.029021	 0.0	 1083	 1083	 1083	 0.0	 0.0	 1	 -30.0	 30.0;
	9642	 557	 4e-05	 0.00033	 0.0	 95024	 95024	 95024	 0.0	 0.0	 1	 -30.0	 30.0;
	3331	 557	 4e-05	 0.00035	 0.0	 89666	 89666	 89666	 0.0	 0.0	 1	 -30.0	 30.0;
	7482	 557	 4e-05	 0.0003	 0.0	 104368	 104368	 104368	 0.0	 0.0	 1	 -30.0	 30.0;
	4882	 557	 4e-05	 0.00028	 0.0	 111679	 111679	 111679	 0.0	 0.0	 1	 -30.0	 30.0;
	7190	 128	 0.000211	 0.00045	 0.0	 63555	 63555	 63555	 0.0	 0.0	 1	 -30.0	 30.0;
	13596	 5475	 0.00024	 0.001099	 0.0	 28081	 28081	 28081	 0.0	 0.0	 1	 -30.0	 30.0;
	6071	 13596	 0.00544	 0.029831	 0.0	 1042	 1042	 1042	 0.0	 0.0	 1	 -30.0	 30.0;
	3777	 10525	 0.00076	 0.0101	 0.0	 3119	 3119	 3119	 0.0	 0.0	 1	 -30.0	 30.0;
	2899	 8500	 0.01106	 0.06313	 0.0	 493	 493	 493	 0.0	 0.0	 1	 -30.0	 30.0;
	8286	 8348	 0.001909	 0.011401	 0.0	 2733	 2733	 2733	 0.0	 0.0	 1	 -30.0	 30.0;
	9607	 8286	 0.00113	 0.005479	 0.0	 5647	 5647	 5647	 0.0	 0.0	 1	 -30.0	 30.0;
	11772	 5453	 0.000151	 0.000961	 0.0	 32471	 32471	 32471	 0.0	 0.0	 1	 -30.0	 30.0;
	11772	 13428	 0.00156	 0.01125	 0.0	 2782	 2782	 2782	 0.0	 0.0	 1	 -30.0	 30.0;
	11772	 13428	 0.00344	 0.021599	 0.0	 1445	 1445	 1445	 0.0	 0.0	 1	 -30.0	 30.0;
	1855	 7438	 0.00106	 0.01276	 0.0	 2467	 2467	 2467	 0.0	 0.0	 1	 -30.0	 30.0;
	6384	 8541	 0.001349	 0.008831	 0.0	 3536	 3536	 3536	 0.0	 0.0	 1	 -30.0	 30.0;
	5475	 13115	 0.001901	 0.010031	 0.0	 3094	 3094	 3094	 0.0	 0.0	 1	 -30.0	 30.0;
	3172	 10853	 0.001719	 0.012159	 0.0	 2573	 2573	 2573	 0.0	 0.0	 1	 -30.0	 30.0;
	4628	 155	 4e-05	 0.00061	 0.0	 51672	 51672	 51672	 0.0	 0.0	 1	 -30.0	 30.0;
	11452	 1658	 0.00126	 0.00595	 0.0	 5194	 5194	 5194	 0.0	 0.0	 1	 -30.0	 30.0;
	4204	 8	 0.00018	 0.00224	 0.0	 14057	 14057	 14057	 0.0	 0.0	 1	 -30.0	 30.0;
	8920	 9311	 0.000521	 0.002039	 0.0	 15010	 15010	 15010	 0.0	 0.0	 1	 -30.0	 30.0;
	11593	 13115	 0.002169	 0.016479	 0.0	 1901	 1901	 1901	 0.0	 0.0	 1	 -30.0	 30.0;
	6688	 8016	 0.00073	 0.01168	 0.0	 2700	 2700	 2700	 0.0	 0.0	 1	 -30.0	 30.0;
	12006	 8016	 0.00131	 0.0162	 0.0	 1944	 1944	 1944	 0.0	 0.0	 1	 -30.0	 30.0;
	10969	 3422	 0.00112	 0.007591	 0.0	 4117	 4117	 4117	 0.0	 0.0	 1	 -30.0	 30.0;
	8384	 10969	 0.00162	 0.01332	 0.0	 2355	 2355	 2355	 0.0	 0.0	 1	 -30.0	 30.0;
	9079	 12006	 0.00027	 0.00344	 0.0	 9155	 9155	 9155	 0.0	 0.0	 1	 -30.0	 30.0;
	2758	 12006	 0.0003	 0.00313	 0.0	 10046	 10046	 10046	 0.0	 0.0	 1	 -30.0	 30.0;
	2601	 2520	 0.00014	 0.00243	 0.0	 12978	 12978	 12978	 0.0	 0.0	 1	 -30.0	 30.0;
	2608	 7086	 0.00019	 0.001781	 0.0	 17636	 17636	 17636	 0.0	 0.0	 1	 -30.0	 30.0;
	4613	 7086	 0.000151	 0.001969	 0.0	 15996	 15996	 15996	 0.0	 0.0	 1	 -30.0	 30.0;
	2769	 9311	 0.025461	 0.14561	 0.0	 214	 214	 214	 0.0	 0.0	 1	 -30.0	 30.0;
	11100	 640	 0.004599	 0.028581	 0.0	 1092	 1092	 1092	 0.0	 0.0	 1	 -30.0	 30.0;
	6024	 2407	 0.00987	 0.05706	 0.0	 546	 546	 546	 0.0	 0.0	 1	 -30.0	 30.0;
	155	 3704	 9e-05	 0.00103	 0.0	 30551	 30551	 30551	 0.0	 0.0	 1	 -30.0	 30.0;
	155	 3704	 0.0001	 0.00101	 0.0	 31123	 31123	 31123	 0.0	 0.0	 1	 -30.0	 30.0;
	3876	 3704	 0.00023	 0.00381	 0.0	 8276	 8276	 8276	 0.0	 0.0	 1	 -30.0	 30.0;
	183	 2891	 0.002219	 0.01374	 0.0	 2270	 2270	 2270	 0.0	 0.0	 1	 -30.0	 30.0;
	12737	 4486	 0.00092	 0.00895	 0.0	 3511	 3511	 3511	 0.0	 0.0	 1	 -30.0	 30.0;
	183	 10565	 0.001151	 0.009479	 0.0	 3309	 3309	 3309	 0.0	 0.0	 1	 -30.0	 30.0;
	1404	 3129	 0.00188	 0.012151	 0.0	 2570	 2570	 2570	 0.0	 0.0	 1	 -30.0	 30.0;
	6559	 2297	 0.00036	 0.00471	 0.0	 6687	 6687	 6687	 0.0	 0.0	 1	 -30.0	 30.0;
	6559	 1332	 0.00085	 0.01337	 0.0	 2358	 2358	 2358	 0.0	 0.0	 1	 -30.0	 30.0;
	4368	 6559	 9e-05	 0.00105	 0.0	 29974	 29974	 29974	 0.0	 0.0	 1	 -30.0	 30.0;
	4877	 6559	 0.00037	 0.00634	 0.0	 4974	 4974	 4974	 0.0	 0.0	 1	 -30.0	 30.0;
	6018	 4296	 0.00056	 0.004979	 0.0	 6305	 6305	 6305	 0.0	 0.0	 1	 -30.0	 30.0;
	5625	 8376	 0.00488	 0.029039	 0.0	 1073	 1073	 1073	 0.0	 0.0	 1	 -30.0	 30.0;
	5625	 8376	 0.004349	 0.032919	 0.0	 952	 952	 952	 0.0	 0.0	 1	 -30.0	 30.0;
	3777	 4128	 0.00046	 0.00571	 0.0	 5515	 5515	 5515	 0.0	 0.0	 1	 -30.0	 30.0;
	13509	 8229	 0.010841	 0.04989	 0.0	 619	 619	 619	 0.0	 0.0	 1	 -30.0	 30.0;
	4706	 1404	 0.00282	 0.01436	 0.0	 2159	 2159	 2159	 0.0	 0.0	 1	 -30.0	 30.0;
	4706	 1404	 0.00282	 0.014789	 0.0	 2099	 2099	 2099	 0.0	 0.0	 1	 -30.0	 30.0;
	389	 3796	 0.00012	 0.000841	 0.0	 37183	 37183	 37183	 0.0	 0.0	 1	 -30.0	 30.0;
	389	 1253	 0.00175	 0.01189	 0.0	 2629	 2629	 2629	 0.0	 0.0	 1	 -30.0	 30.0;
	389	 2407	 0.00851	 0.04389	 0.0	 707	 707	 707	 0.0	 0.0	 1	 -30.0	 30.0;
	12889	 280	 0.00063	 0.00374	 0.0	 8329	 8329	 8329	 0.0	 0.0	 1	 -30.0	 30.0;
	5689	 233	 0.00037	 0.00484	 0.0	 6508	 6508	 6508	 0.0	 0.0	 1	 -30.0	 30.0;
	12715	 7772	 0.00161	 0.02178	 0.0	 1447	 1447	 1447	 0.0	 0.0	 1	 -30.0	 30.0;
	12694	 2017	 0.00745	 0.03588	 0.0	 862	 862	 862	 0.0	 0.0	 1	 -30.0	 30.0;
	2987	 7305	 0.00051	 0.00829	 0.0	 3804	 3804	 3804	 0.0	 0.0	 1	 -30.0	 30.0;
	2987	 11938	 0.00124	 0.01751	 0.0	 1800	 1800	 1800	 0.0	 0.0	 1	 -30.0	 30.0;
	2987	 11591	 0.0008	 0.01242	 0.0	 2539	 2539	 2539	 0.0	 0.0	 1	 -30.0	 30.0;
	2520	 7968	 0.00118	 0.01502	 0.0	 2097	 2097	 2097	 0.0	 0.0	 1	 -30.0	 30.0;
	5689	 9752	 0.00131	 0.01723	 0.0	 1828	 1828	 1828	 0.0	 0.0	 1	 -30.0	 30.0;
	1790	 8678	 0.000271	 0.001081	 0.0	 28344	 28344	 28344	 0.0	 0.0	 1	 -30.0	 30.0;
	10536	 4302	 0.00014	 0.00178	 0.0	 17692	 17692	 17692	 0.0	 0.0	 1	 -30.0	 30.0;
	1790	 9311	 0.00051	 0.00201	 0.0	 15233	 15233	 15233	 0.0	 0.0	 1	 -30.0	 30.0;
	11591	 12029	 9e-05	 0.00091	 0.0	 34543	 34543	 34543	 0.0	 0.0	 1	 -30.0	 30.0;
	2766	 692	 9.1e-05	 0.000591	 0.0	 52825	 52825	 52825	 0.0	 0.0	 1	 -30.0	 30.0;
	4688	 7336	 2.1e-05	 0.00025	 0.0	 125906	 125906	 125906	 0.0	 0.0	 1	 -30.0	 30.0;
	2898	 9380	 0.00035	 0.00556	 0.0	 5670	 5670	 5670	 0.0	 0.0	 1	 -30.0	 30.0;
	2898	 9380	 0.0004	 0.00545	 0.0	 5781	 5781	 5781	 0.0	 0.0	 1	 -30.0	 30.0;
	1309	 6636	 0.0004	 0.00517	 0.0	 6092	 6092	 6092	 0.0	 0.0	 1	 -30.0	 30.0;
	6636	 7772	 0.00037	 0.00456	 0.0	 6905	 6905	 6905	 0.0	 0.0	 1	 -30.0	 30.0;
	7797	 1309	 0.00133	 0.01413	 0.0	 2226	 2226	 2226	 0.0	 0.0	 1	 -30.0	 30.0;
	10325	 6384	 0.01187	 0.05524	 0.0	 560	 560	 560	 0.0	 0.0	 1	 -30.0	 30.0;
	6384	 4613	 0.00063	 0.0065	 0.0	 4837	 4837	 4837	 0.0	 0.0	 1	 -30.0	 30.0;
	2407	 6384	 0.011841	 0.052289	 0.0	 590	 590	 590	 0.0	 0.0	 1	 -30.0	 30.0;
	11460	 1921	 0.00055	 0.00517	 0.0	 6076	 6076	 6076	 0.0	 0.0	 1	 -30.0	 30.0;
	1921	 7797	 0.00097	 0.01163	 0.0	 2707	 2707	 2707	 0.0	 0.0	 1	 -30.0	 30.0;
	2608	 6574	 0.000969	 0.01039	 0.0	 3028	 3028	 3028	 0.0	 0.0	 1	 -30.0	 30.0;
	11939	 9747	 0.00326	 0.015581	 0.0	 1985	 1985	 1985	 0.0	 0.0	 1	 -30.0	 30.0;
	3876	 437	 0.00099	 0.01348	 0.0	 2337	 2337	 2337	 0.0	 0.0	 1	 -30.0	 30.0;
	11901	 437	 0.00045	 0.00368	 0.0	 8521	 8521	 8521	 0.0	 0.0	 1	 -30.0	 30.0;
	1487	 6232	 0.002021	 0.011331	 0.0	 2745	 2745	 2745	 0.0	 0.0	 1	 -30.0	 30.0;
	13475	 1487	 0.00076	 0.0073	 0.0	 4304	 4304	 4304	 0.0	 0.0	 1	 -30.0	 30.0;
	3102	 5938	 0.00101	 0.01505	 0.0	 2095	 2095	 2095	 0.0	 0.0	 1	 -30.0	 30.0;
	9303	 1008	 0.0	 0.000347	 0.0	 91030	 91030	 91030	 0.0	 0.0	 1	 -30.0	 30.0;
	3837	 5908	 0.00065	 0.00768	 0.0	 4099	 4099	 4099	 0.0	 0.0	 1	 -30.0	 30.0;
	7305	 9008	 0.00025	 0.0035	 0.0	 9003	 9003	 9003	 0.0	 0.0	 1	 -30.0	 30.0;
	5599	 9170	 0.00013	 0.000331	 0.0	 88825	 88825	 88825	 0.0	 0.0	 1	 -30.0	 30.0;
	149	 9170	 3.9e-05	 0.00036	 0.0	 87233	 87233	 87233	 0.0	 0.0	 1	 -30.0	 30.0;
	6626	 4123	 0.011021	 0.061901	 0.0	 503	 503	 503	 0.0	 0.0	 1	 -30.0	 30.0;
	4123	 8500	 0.007901	 0.04495	 0.0	 693	 693	 693	 0.0	 0.0	 1	 -30.0	 30.0;
	7316	 10565	 0.00369	 0.02186	 0.0	 1425	 1425	 1425	 0.0	 0.0	 1	 -30.0	 30.0;
	10565	 9608	 0.000281	 0.001091	 0.0	 28038	 28038	 28038	 0.0	 0.0	 1	 -30.0	 30.0;
	10565	 8615	 0.000461	 0.001841	 0.0	 16644	 16644	 16644	 0.0	 0.0	 1	 -30.0	 30.0;
	1778	 5296	 0.006271	 0.02999	 0.0	 1031	 1031	 1031	 0.0	 0.0	 1	 -30.0	 30.0;
	6626	 17	 0.011219	 0.05245	 0.0	 589	 589	 589	 0.0	 0.0	 1	 -30.0	 30.0;
	12549	 6388	 0.000281	 0.004091	 0.0	 7704	 7704	 7704	 0.0	 0.0	 1	 -30.0	 30.0;
	3875	 5827	 0.00041	 0.00534	 0.0	 5898	 5898	 5898	 0.0	 0.0	 1	 -30.0	 30.0;
	10563	 12256	 0.002659	 0.01557	 0.0	 2000	 2000	 2000	 0.0	 0.0	 1	 -30.0	 30.0;
	12979	 70	 0.00795	 0.0483	 0.0	 646	 646	 646	 0.0	 0.0	 1	 -30.0	 30.0;
	9723	 4625	 0.00037	 0.00361	 0.0	 8705	 8705	 8705	 0.0	 0.0	 1	 -30.0	 30.0;
	2882	 7718	 0.001211	 0.0082	 0.0	 3811	 3811	 3811	 0.0	 0.0	 1	 -30.0	 30.0;
	2300	 13003	 9.9e-05	 0.00101	 0.0	 31126	 31126	 31126	 0.0	 0.0	 1	 -30.0	 30.0;
	2300	 5096	 9.9e-05	 0.00099	 0.0	 31749	 31749	 31749	 0.0	 0.0	 1	 -30.0	 30.0;
	2300	 7583	 0.000169	 0.001539	 0.0	 20402	 20402	 20402	 0.0	 0.0	 1	 -30.0	 30.0;
	2300	 5643	 0.000169	 0.00157	 0.0	 20004	 20004	 20004	 0.0	 0.0	 1	 -30.0	 30.0;
	1253	 2661	 0.00011	 0.000349	 0.0	 86322	 86322	 86322	 0.0	 0.0	 1	 -30.0	 30.0;
	1253	 2661	 0.00012	 0.000341	 0.0	 87379	 87379	 87379	 0.0	 0.0	 1	 -30.0	 30.0;
	3837	 1233	 0.00017	 0.00314	 0.0	 10045	 10045	 10045	 0.0	 0.0	 1	 -30.0	 30.0;
	590	 5191	 0.00012	 0.00056	 0.0	 55154	 55154	 55154	 0.0	 0.0	 1	 -30.0	 30.0;
	2407	 2229	 0.000219	 0.001469	 0.0	 21268	 21268	 21268	 0.0	 0.0	 1	 -30.0	 30.0;
	2407	 2229	 0.0002	 0.001781	 0.0	 17625	 17625	 17625	 0.0	 0.0	 1	 -30.0	 30.0;
	12675	 1332	 0.00038	 0.00623	 0.0	 5061	 5061	 5061	 0.0	 0.0	 1	 -30.0	 30.0;
	10563	 10853	 0.003669	 0.01631	 0.0	 1890	 1890	 1890	 0.0	 0.0	 1	 -30.0	 30.0;
	1015	 7797	 0.00013	 0.00117	 0.0	 26833	 26833	 26833	 0.0	 0.0	 1	 -30.0	 30.0;
	12395	 7797	 0.00012	 0.0013	 0.0	 24196	 24196	 24196	 0.0	 0.0	 1	 -30.0	 30.0;
	10325	 4351	 0.00082	 0.004969	 0.0	 6273	 6273	 6273	 0.0	 0.0	 1	 -30.0	 30.0;
	10325	 4351	 0.0008	 0.004599	 0.0	 6767	 6767	 6767	 0.0	 0.0	 1	 -30.0	 30.0;
	2407	 10325	 0.00914	 0.060289	 0.0	 519	 519	 519	 0.0	 0.0	 1	 -30.0	 30.0;
	6626	 11830	 0.005219	 0.02681	 0.0	 1157	 1157	 1157	 0.0	 0.0	 1	 -30.0	 30.0;
	6626	 11830	 0.005919	 0.026271	 0.0	 1173	 1173	 1173	 0.0	 0.0	 1	 -30.0	 30.0;
	6626	 8500	 0.00381	 0.02086	 0.0	 1490	 1490	 1490	 0.0	 0.0	 1	 -30.0	 30.0;
	9311	 11071	 0.004539	 0.01957	 0.0	 1573	 1573	 1573	 0.0	 0.0	 1	 -30.0	 30.0;
	4007	 9311	 0.00112	 0.00632	 0.0	 4922	 4922	 4922	 0.0	 0.0	 1	 -30.0	 30.0;
	9841	 6482	 0.00027	 0.00426	 0.0	 7401	 7401	 7401	 0.0	 0.0	 1	 -30.0	 30.0;
	13320	 6482	 0.0002	 0.00238	 0.0	 13226	 13226	 13226	 0.0	 0.0	 1	 -30.0	 30.0;
	1555	 6482	 8e-05	 0.00077	 0.0	 40803	 40803	 40803	 0.0	 0.0	 1	 -30.0	 30.0;
	6626	 7061	 0.00149	 0.012091	 0.0	 2593	 2593	 2593	 0.0	 0.0	 1	 -30.0	 30.0;
	13645	 6232	 0.00064	 0.00356	 0.0	 8733	 8733	 8733	 0.0	 0.0	 1	 -30.0	 30.0;
	7309	 9307	 0.005729	 0.033	 0.0	 944	 944	 944	 0.0	 0.0	 1	 -30.0	 30.0;
	13325	 12889	 0.0017	 0.007599	 0.0	 4057	 4057	 4057	 0.0	 0.0	 1	 -30.0	 30.0;
	11938	 2550	 0.00221	 0.02589	 0.0	 1216	 1216	 1216	 0.0	 0.0	 1	 -30.0	 30.0;
	5453	 1658	 0.000331	 0.000831	 0.0	 35314	 35314	 35314	 0.0	 0.0	 1	 -30.0	 30.0;
	9453	 12181	 9.9e-05	 0.00045	 0.0	 68555	 68555	 68555	 0.0	 0.0	 1	 -30.0	 30.0;
	12757	 6232	 0.00039	 0.00163	 0.0	 18847	 18847	 18847	 0.0	 0.0	 1	 -30.0	 30.0;
	12006	 7772	 0.00383	 0.04628	 0.0	 681	 681	 681	 0.0	 0.0	 1	 -30.0	 30.0;
	9607	 10499	 0.00106	 0.01101	 0.0	 2856	 2856	 2856	 0.0	 0.0	 1	 -30.0	 30.0;
	13475	 10707	 0.00131	 0.012659	 0.0	 2482	 2482	 2482	 0.0	 0.0	 1	 -30.0	 30.0;
	3837	 8192	 0.00052	 0.00735	 0.0	 4287	 4287	 4287	 0.0	 0.0	 1	 -30.0	 30.0;
	8192	 3837	 0.00058	 0.0074	 0.0	 4256	 4256	 4256	 0.0	 0.0	 1	 -30.0	 30.0;
	9199	 3837	 0.0013	 0.01837	 0.0	 1716	 1716	 1716	 0.0	 0.0	 1	 -30.0	 30.0;
	6845	 11349	 3.9e-05	 0.000599	 0.0	 52623	 52623	 52623	 0.0	 0.0	 1	 -30.0	 30.0;
	1778	 11071	 0.00031	 0.001461	 0.0	 21150	 21150	 21150	 0.0	 0.0	 1	 -30.0	 30.0;
	4688	 10175	 0.001151	 0.008771	 0.0	 3571	 3571	 3571	 0.0	 0.0	 1	 -30.0	 30.0;
	7136	 6062	 0.00095	 0.00457	 0.0	 6768	 6768	 6768	 0.0	 0.0	 1	 -30.0	 30.0;
	7136	 1847	 0.001419	 0.00982	 0.0	 3184	 3184	 3184	 0.0	 0.0	 1	 -30.0	 30.0;
	12757	 9608	 0.00037	 0.00144	 0.0	 21246	 21246	 21246	 0.0	 0.0	 1	 -30.0	 30.0;
	10707	 1855	 0.00143	 0.01225	 0.0	 2562	 2562	 2562	 0.0	 0.0	 1	 -30.0	 30.0;
	1573	 11071	 0.00044	 0.00207	 0.0	 14927	 14927	 14927	 0.0	 0.0	 1	 -30.0	 30.0;
	3187	 2550	 0.00076	 0.01509	 0.0	 2091	 2091	 2091	 0.0	 0.0	 1	 -30.0	 30.0;
	13428	 4177	 0.0007	 0.004039	 0.0	 7706	 7706	 7706	 0.0	 0.0	 1	 -30.0	 30.0;
	7554	 12846	 0.004419	 0.01918	 0.0	 1605	 1605	 1605	 0.0	 0.0	 1	 -30.0	 30.0;
	9747	 5926	 0.006099	 0.029539	 0.0	 1048	 1048	 1048	 0.0	 0.0	 1	 -30.0	 30.0;
	11159	 10796	 0.00106	 0.00513	 0.0	 6030	 6030	 6030	 0.0	 0.0	 1	 -30.0	 30.0;
	12995	 13647	 0.001021	 0.004711	 0.0	 6553	 6553	 6553	 0.0	 0.0	 1	 -30.0	 30.0;
	2360	 12894	 0.000211	 0.00106	 0.0	 29226	 29226	 29226	 0.0	 0.0	 1	 -30.0	 30.0;
	10887	 12295	 7e-05	 0.00087	 0.0	 36191	 36191	 36191	 0.0	 0.0	 1	 -30.0	 30.0;
	10887	 12894	 3.9e-05	 0.000651	 0.0	 48435	 48435	 48435	 0.0	 0.0	 1	 -30.0	 30.0;
	13647	 13352	 0.002039	 0.008271	 0.0	 3709	 3709	 3709	 0.0	 0.0	 1	 -30.0	 30.0;
	13647	 13352	 0.002	 0.00843	 0.0	 3646	 3646	 3646	 0.0	 0.0	 1	 -30.0	 30.0;
	5972	 10796	 0.001219	 0.00725	 0.0	 4297	 4297	 4297	 0.0	 0.0	 1	 -30.0	 30.0;
	10796	 13647	 0.001151	 0.006789	 0.0	 4588	 4588	 4588	 0.0	 0.0	 1	 -30.0	 30.0;
	5972	 10796	 0.0012	 0.006711	 0.0	 4634	 4634	 4634	 0.0	 0.0	 1	 -30.0	 30.0;
	10796	 13647	 0.00112	 0.006289	 0.0	 4945	 4945	 4945	 0.0	 0.0	 1	 -30.0	 30.0;
	11232	 10481	 0.002021	 0.01101	 0.0	 2822	 2822	 2822	 0.0	 0.0	 1	 -30.0	 30.0;
	10481	 5972	 0.0015	 0.008521	 0.0	 3651	 3651	 3651	 0.0	 0.0	 1	 -30.0	 30.0;
	10481	 5972	 0.001469	 0.00868	 0.0	 3589	 3589	 3589	 0.0	 0.0	 1	 -30.0	 30.0;
	13647	 12295	 0.000719	 0.00443	 0.0	 7039	 7039	 7039	 0.0	 0.0	 1	 -30.0	 30.0;
	13647	 12894	 0.0005	 0.00268	 0.0	 11587	 11587	 11587	 0.0	 0.0	 1	 -30.0	 30.0;
	9076	 2755	 0.029149	 0.051802	 0.0	 532	 532	 532	 0.0	 0.0	 1	 -30.0	 30.0;
	8291	 2755	 0.035777	 0.063587	 0.0	 433	 433	 433	 0.0	 0.0	 1	 -30.0	 30.0;
	9076	 4471	 0.025967	 0.058702	 0.0	 493	 493	 493	 0.0	 0.0	 1	 -30.0	 30.0;
	4471	 10817	 0.01943	 0.043942	 0.0	 658	 658	 658	 0.0	 0.0	 1	 -30.0	 30.0;
	4471	 2674	 0.05776	 0.115802	 0.0	 245	 245	 245	 0.0	 0.0	 1	 -30.0	 30.0;
	316	 4471	 0.027388	 0.054917	 0.0	 515	 515	 515	 0.0	 0.0	 1	 -30.0	 30.0;
	10817	 2674	 0.028438	 0.104719	 0.0	 292	 292	 292	 0.0	 0.0	 1	 -30.0	 30.0;
	7591	 7344	 0.008091	 0.03755	 0.0	 823	 823	 823	 0.0	 0.0	 1	 -30.0	 30.0;
	12534	 7344	 0.00556	 0.02913	 0.0	 1066	 1066	 1066	 0.0	 0.0	 1	 -30.0	 30.0;
	174	 316	 0.033512	 0.069909	 0.0	 408	 408	 408	 0.0	 0.0	 1	 -30.0	 30.0;
	12534	 11008	 0.00587	 0.02949	 0.0	 1051	 1051	 1051	 0.0	 0.0	 1	 -30.0	 30.0;
	3901	 8358	 0.013314	 0.040719	 0.0	 738	 738	 738	 0.0	 0.0	 1	 -30.0	 30.0;
	3901	 8358	 0.01357	 0.039876	 0.0	 750	 750	 750	 0.0	 0.0	 1	 -30.0	 30.0;
	3901	 8358	 0.014579	 0.041157	 0.0	 724	 724	 724	 0.0	 0.0	 1	 -30.0	 30.0;
	3901	 3174	 0.031298	 0.112364	 0.0	 271	 271	 271	 0.0	 0.0	 1	 -30.0	 30.0;
	3901	 3174	 0.030653	 0.114521	 0.0	 267	 267	 267	 0.0	 0.0	 1	 -30.0	 30.0;
	372	 12265	 0.00537	 0.04394	 0.0	 714	 714	 714	 0.0	 0.0	 1	 -30.0	 30.0;
	372	 12265	 0.005461	 0.04726	 0.0	 664	 664	 664	 0.0	 0.0	 1	 -30.0	 30.0;
	7591	 372	 0.01312	 0.074419	 0.0	 419	 419	 419	 0.0	 0.0	 1	 -30.0	 30.0;
	8358	 6142	 0.0	 0.000413	 0.0	 76483	 76483	 76483	 0.0	 0.0	 1	 -30.0	 30.0;
	6142	 9503	 0.052702	 0.121281	 0.0	 239	 239	 239	 0.0	 0.0	 1	 -30.0	 30.0;
	8452	 4750	 0.00103	 0.01397	 0.0	 2684	 2684	 2684	 0.0	 0.0	 1	 -30.0	 30.0;
	3174	 2674	 0.002959	 0.014851	 0.0	 2086	 2086	 2086	 0.0	 0.0	 1	 -30.0	 30.0;
	3174	 2674	 0.002769	 0.016339	 0.0	 1907	 1907	 1907	 0.0	 0.0	 1	 -30.0	 30.0;
	8452	 11249	 0.00167	 0.02105	 0.0	 1781	 1781	 1781	 0.0	 0.0	 1	 -30.0	 30.0;
	8291	 2674	 0.067826	 0.163702	 0.0	 179	 179	 179	 0.0	 0.0	 1	 -30.0	 30.0;
	5329	 3458	 0.009463	 0.038388	 0.0	 799	 799	 799	 0.0	 0.0	 1	 -30.0	 30.0;
	5577	 3458	 0.021289	 0.124008	 0.0	 252	 252	 252	 0.0	 0.0	 1	 -30.0	 30.0;
	8596	 8059	 0.035587	 0.104182	 0.0	 287	 287	 287	 0.0	 0.0	 1	 -30.0	 30.0;
	10532	 8059	 0.040678	 0.119107	 0.0	 251	 251	 251	 0.0	 0.0	 1	 -30.0	 30.0;
	10744	 5821	 0.00156	 0.01963	 0.0	 1909	 1909	 1909	 0.0	 0.0	 1	 -30.0	 30.0;
	10744	 4747	 0.00255	 0.02314	 0.0	 1615	 1615	 1615	 0.0	 0.0	 1	 -30.0	 30.0;
	10278	 550	 0.01305	 0.035686	 0.0	 999	 999	 999	 0.0	 0.0	 1	 -30.0	 30.0;
	10278	 550	 0.013314	 0.034959	 0.0	 1015	 1015	 1015	 0.0	 0.0	 1	 -30.0	 30.0;
	2909	 550	 0.005612	 0.022636	 0.0	 1355	 1355	 1355	 0.0	 0.0	 1	 -30.0	 30.0;
	92	 550	 0.029826	 0.113909	 0.0	 269	 269	 269	 0.0	 0.0	 1	 -30.0	 30.0;
	9861	 550	 0.04824	 0.109727	 0.0	 264	 264	 264	 0.0	 0.0	 1	 -30.0	 30.0;
	10278	 11021	 0.010802	 0.04124	 0.0	 890	 890	 890	 0.0	 0.0	 1	 -30.0	 30.0;
	2909	 10278	 0.021851	 0.050934	 0.0	 685	 685	 685	 0.0	 0.0	 1	 -30.0	 30.0;
	5156	 10278	 0.070223	 0.192198	 0.0	 186	 186	 186	 0.0	 0.0	 1	 -30.0	 30.0;
	5156	 10278	 0.071603	 0.188281	 0.0	 189	 189	 189	 0.0	 0.0	 1	 -30.0	 30.0;
	2909	 11021	 0.008339	 0.021066	 0.0	 1395	 1395	 1395	 0.0	 0.0	 1	 -30.0	 30.0;
	3057	 2909	 0.024744	 0.092099	 0.0	 332	 332	 332	 0.0	 0.0	 1	 -30.0	 30.0;
	4247	 5690	 0.029579	 0.114661	 0.0	 267	 267	 267	 0.0	 0.0	 1	 -30.0	 30.0;
	10532	 5690	 0.009298	 0.035488	 0.0	 862	 862	 862	 0.0	 0.0	 1	 -30.0	 30.0;
	6908	 5690	 0.020149	 0.078107	 0.0	 392	 392	 392	 0.0	 0.0	 1	 -30.0	 30.0;
	9743	 8596	 0.017826	 0.063777	 0.0	 477	 477	 477	 0.0	 0.0	 1	 -30.0	 30.0;
	4747	 5821	 0.00158	 0.02095	 0.0	 1790	 1790	 1790	 0.0	 0.0	 1	 -30.0	 30.0;
	494	 5821	 0.00076	 0.00957	 0.0	 3916	 3916	 3916	 0.0	 0.0	 1	 -30.0	 30.0;
	6974	 4247	 0.005678	 0.044198	 0.0	 709	 709	 709	 0.0	 0.0	 1	 -30.0	 30.0;
	6974	 4247	 0.006438	 0.043314	 0.0	 722	 722	 722	 0.0	 0.0	 1	 -30.0	 30.0;
	9510	 4247	 0.013612	 0.043157	 0.0	 699	 699	 699	 0.0	 0.0	 1	 -30.0	 30.0;
	1276	 4247	 0.056248	 0.147934	 0.0	 200	 200	 200	 0.0	 0.0	 1	 -30.0	 30.0;
	1276	 4247	 0.057339	 0.144851	 0.0	 203	 203	 203	 0.0	 0.0	 1	 -30.0	 30.0;
	12482	 4247	 0.000463	 0.003603	 0.0	 8696	 8696	 8696	 0.0	 0.0	 1	 -30.0	 30.0;
	4247	 11050	 0.037107	 0.138157	 0.0	 221	 221	 221	 0.0	 0.0	 1	 -30.0	 30.0;
	6974	 11941	 0.004058	 0.015107	 0.0	 2020	 2020	 2020	 0.0	 0.0	 1	 -30.0	 30.0;
	9615	 1817	 0.011793	 0.034521	 0.0	 866	 866	 866	 0.0	 0.0	 1	 -30.0	 30.0;
	2939	 1817	 0.019636	 0.073132	 0.0	 418	 418	 418	 0.0	 0.0	 1	 -30.0	 30.0;
	6315	 2474	 0.0	 0.000413	 0.0	 76483	 76483	 76483	 0.0	 0.0	 1	 -30.0	 30.0;
	5329	 1286	 0.014339	 0.041983	 0.0	 713	 713	 713	 0.0	 0.0	 1	 -30.0	 30.0;
	7588	 1286	 0.029314	 0.118281	 0.0	 260	 260	 260	 0.0	 0.0	 1	 -30.0	 30.0;
	12533	 3898	 0.016636	 0.064488	 0.0	 475	 475	 475	 0.0	 0.0	 1	 -30.0	 30.0;
	9355	 3898	 0.034273	 0.127612	 0.0	 240	 240	 240	 0.0	 0.0	 1	 -30.0	 30.0;
	3898	 5577	 0.00886	 0.02495	 0.0	 1194	 1194	 1194	 0.0	 0.0	 1	 -30.0	 30.0;
	12533	 9490	 0.026587	 0.084364	 0.0	 358	 358	 358	 0.0	 0.0	 1	 -30.0	 30.0;
	9355	 12446	 0.039298	 0.115058	 0.0	 260	 260	 260	 0.0	 0.0	 1	 -30.0	 30.0;
	9355	 9615	 0.036066	 0.134289	 0.0	 228	 228	 228	 0.0	 0.0	 1	 -30.0	 30.0;
	9355	 2417	 0.000529	 0.001554	 0.0	 19243	 19243	 19243	 0.0	 0.0	 1	 -30.0	 30.0;
	92	 9510	 0.03981	 0.160628	 0.0	 191	 191	 191	 0.0	 0.0	 1	 -30.0	 30.0;
	11941	 9510	 0.008438	 0.025744	 0.0	 1166	 1166	 1166	 0.0	 0.0	 1	 -30.0	 30.0;
	9510	 5571	 0.024223	 0.093876	 0.0	 326	 326	 326	 0.0	 0.0	 1	 -30.0	 30.0;
	9490	 6899	 0.019868	 0.054017	 0.0	 549	 549	 549	 0.0	 0.0	 1	 -30.0	 30.0;
	9861	 6899	 0.051248	 0.121347	 0.0	 240	 240	 240	 0.0	 0.0	 1	 -30.0	 30.0;
	8150	 8084	 0.042793	 0.101314	 0.0	 288	 288	 288	 0.0	 0.0	 1	 -30.0	 30.0;
	8150	 8084	 0.030091	 0.099372	 0.0	 305	 305	 305	 0.0	 0.0	 1	 -30.0	 30.0;
	3256	 8084	 0.005488	 0.020959	 0.0	 1458	 1458	 1458	 0.0	 0.0	 1	 -30.0	 30.0;
	2925	 7368	 0.009198	 0.025851	 0.0	 1152	 1152	 1152	 0.0	 0.0	 1	 -30.0	 30.0;
	7368	 8946	 0.019752	 0.057843	 0.0	 517	 517	 517	 0.0	 0.0	 1	 -30.0	 30.0;
	2939	 7368	 0.032934	 0.096413	 0.0	 311	 311	 311	 0.0	 0.0	 1	 -30.0	 30.0;
	9826	 12554	 0.05586	 0.112686	 0.0	 252	 252	 252	 0.0	 0.0	 1	 -30.0	 30.0;
	8606	 12554	 0.029744	 0.057636	 0.0	 488	 488	 488	 0.0	 0.0	 1	 -30.0	 30.0;
	5247	 9826	 0.004868	 0.013686	 0.0	 2175	 2175	 2175	 0.0	 0.0	 1	 -30.0	 30.0;
	612	 9826	 0.005413	 0.015207	 0.0	 1957	 1957	 1957	 0.0	 0.0	 1	 -30.0	 30.0;
	9615	 9826	 0.043669	 0.084653	 0.0	 332	 332	 332	 0.0	 0.0	 1	 -30.0	 30.0;
	612	 5247	 0.004818	 0.01724	 0.0	 1765	 1765	 1765	 0.0	 0.0	 1	 -30.0	 30.0;
	59	 5247	 0.017719	 0.054017	 0.0	 556	 556	 556	 0.0	 0.0	 1	 -30.0	 30.0;
	9615	 5727	 0.004364	 0.017719	 0.0	 1731	 1731	 1731	 0.0	 0.0	 1	 -30.0	 30.0;
	5727	 1776	 0.007463	 0.041727	 0.0	 746	 746	 746	 0.0	 0.0	 1	 -30.0	 30.0;
	2925	 12446	 0.016289	 0.065711	 0.0	 467	 467	 467	 0.0	 0.0	 1	 -30.0	 30.0;
	3256	 9743	 0.02014	 0.072066	 0.0	 423	 423	 423	 0.0	 0.0	 1	 -30.0	 30.0;
	4341	 12460	 0.003091	 0.011826	 0.0	 2585	 2585	 2585	 0.0	 0.0	 1	 -30.0	 30.0;
	5156	 12460	 0.00386	 0.013793	 0.0	 2206	 2206	 2206	 0.0	 0.0	 1	 -30.0	 30.0;
	3057	 4341	 0.036	 0.114223	 0.0	 264	 264	 264	 0.0	 0.0	 1	 -30.0	 30.0;
	7588	 5156	 0.027942	 0.081793	 0.0	 366	 366	 366	 0.0	 0.0	 1	 -30.0	 30.0;
	8150	 6884	 0.027008	 0.061041	 0.0	 474	 474	 474	 0.0	 0.0	 1	 -30.0	 30.0;
	10655	 6884	 0.025504	 0.072198	 0.0	 413	 413	 413	 0.0	 0.0	 1	 -30.0	 30.0;
	8946	 9490	 0.01686	 0.060331	 0.0	 505	 505	 505	 0.0	 0.0	 1	 -30.0	 30.0;
	3774	 1776	 0.010091	 0.038529	 0.0	 794	 794	 794	 0.0	 0.0	 1	 -30.0	 30.0;
	10655	 3774	 0.027099	 0.082603	 0.0	 364	 364	 364	 0.0	 0.0	 1	 -30.0	 30.0;
	6897	 8036	 0.014463	 0.051719	 0.0	 589	 589	 589	 0.0	 0.0	 1	 -30.0	 30.0;
	8036	 5577	 0.014612	 0.041066	 0.0	 725	 725	 725	 0.0	 0.0	 1	 -30.0	 30.0;
	2612	 92	 0.001661	 0.006446	 0.0	 4746	 4746	 4746	 0.0	 0.0	 1	 -30.0	 30.0;
	10679	 92	 0.005198	 0.019331	 0.0	 1578	 1578	 1578	 0.0	 0.0	 1	 -30.0	 30.0;
	9910	 2612	 0.003512	 0.011587	 0.0	 2609	 2609	 2609	 0.0	 0.0	 1	 -30.0	 30.0;
	9910	 10679	 0.004339	 0.015512	 0.0	 1962	 1962	 1962	 0.0	 0.0	 1	 -30.0	 30.0;
	8150	 8606	 0.043628	 0.081231	 0.0	 343	 343	 343	 0.0	 0.0	 1	 -30.0	 30.0;
	3887	 10532	 0.031661	 0.092669	 0.0	 323	 323	 323	 0.0	 0.0	 1	 -30.0	 30.0;
	1776	 59	 0.017562	 0.070818	 0.0	 433	 433	 433	 0.0	 0.0	 1	 -30.0	 30.0;
	2939	 12446	 0.008843	 0.033802	 0.0	 905	 905	 905	 0.0	 0.0	 1	 -30.0	 30.0;
	10542	 13118	 0.01164	 0.05205	 0.0	 593	 593	 593	 0.0	 0.0	 1	 -30.0	 30.0;
	1776	 9615	 0.007934	 0.042653	 0.0	 729	 729	 729	 0.0	 0.0	 1	 -30.0	 30.0;
	13257	 9615	 0.00343	 0.014488	 0.0	 2122	 2122	 2122	 0.0	 0.0	 1	 -30.0	 30.0;
	175	 9615	 0.004339	 0.022421	 0.0	 1384	 1384	 1384	 0.0	 0.0	 1	 -30.0	 30.0;
	9615	 6315	 0.00143	 0.007149	 0.0	 4333	 4333	 4333	 0.0	 0.0	 1	 -30.0	 30.0;
	9615	 6315	 0.001446	 0.007	 0.0	 4420	 4420	 4420	 0.0	 0.0	 1	 -30.0	 30.0;
	9615	 6315	 0.001504	 0.007256	 0.0	 4263	 4263	 4263	 0.0	 0.0	 1	 -30.0	 30.0;
	9615	 6315	 0.001529	 0.007099	 0.0	 4350	 4350	 4350	 0.0	 0.0	 1	 -30.0	 30.0;
	1776	 2939	 0.015653	 0.051669	 0.0	 586	 586	 586	 0.0	 0.0	 1	 -30.0	 30.0;
	6182	 4747	 0.00046	 0.00424	 0.0	 8815	 8815	 8815	 0.0	 0.0	 1	 -30.0	 30.0;
	5329	 5577	 0.049339	 0.138727	 0.0	 215	 215	 215	 0.0	 0.0	 1	 -30.0	 30.0;
	6908	 8150	 0.005421	 0.017876	 0.0	 1691	 1691	 1691	 0.0	 0.0	 1	 -30.0	 30.0;
	1276	 3887	 0.001678	 0.006421	 0.0	 4760	 4760	 4760	 0.0	 0.0	 1	 -30.0	 30.0;
	1276	 11050	 0.024512	 0.055752	 0.0	 519	 519	 519	 0.0	 0.0	 1	 -30.0	 30.0;
	5700	 2417	 0.019347	 0.072058	 0.0	 424	 424	 424	 0.0	 0.0	 1	 -30.0	 30.0;
	6897	 5700	 0.002364	 0.008777	 0.0	 3476	 3476	 3476	 0.0	 0.0	 1	 -30.0	 30.0;
	5700	 5577	 0.032331	 0.102537	 0.0	 294	 294	 294	 0.0	 0.0	 1	 -30.0	 30.0;
	175	 13257	 0.00305	 0.017711	 0.0	 1758	 1758	 1758	 0.0	 0.0	 1	 -30.0	 30.0;
	8004	 10655	 0.005289	 0.009463	 0.0	 2914	 2914	 2914	 0.0	 0.0	 1	 -30.0	 30.0;
	8004	 6502	 0.00181	 0.007298	 0.0	 4201	 4201	 4201	 0.0	 0.0	 1	 -30.0	 30.0;
	6502	 10655	 0.000893	 0.00338	 0.0	 9036	 9036	 9036	 0.0	 0.0	 1	 -30.0	 30.0;
	5571	 6502	 0.012033	 0.046579	 0.0	 657	 657	 657	 0.0	 0.0	 1	 -30.0	 30.0;
	8737	 2409	 0.00017	 0.01734	 0.0	 1822	 1822	 1822	 0.0	 0.0	 1	 -30.0	 30.0;
	6151	 1593	 0.00017	 0.01767	 0.0	 1788	 1788	 1788	 0.0	 0.0	 1	 -30.0	 30.0;
	13039	 2887	 0.0006	 0.040218	 0.0	 786	 786	 786	 0.0	 0.0	 1	 -30.0	 30.0;
	13074	 5030	 0.00076	 0.002409	 0.0	 12505	 12505	 12505	 0.0	 0.0	 1	 -30.0	 30.0;
	13074	 5539	 0.0	 0.000538	 0.0	 58713	 58713	 58713	 0.0	 0.0	 1	 -30.0	 30.0;
	9360	 2232	 0.00528	 0.027569	 0.0	 1126	 1126	 1126	 0.0	 0.0	 1	 -30.0	 30.0;
	9360	 2232	 0.005382	 0.026978	 0.0	 1149	 1149	 1149	 0.0	 0.0	 1	 -30.0	 30.0;
	7663	 9360	 0.00104	 0.009649	 0.0	 3255	 3255	 3255	 0.0	 0.0	 1	 -30.0	 30.0;
	7663	 9360	 0.001062	 0.009449	 0.0	 3323	 3323	 3323	 0.0	 0.0	 1	 -30.0	 30.0;
	12145	 7653	 0.000289	 0.000889	 0.0	 33791	 33791	 33791	 0.0	 0.0	 1	 -30.0	 30.0;
	1716	 7653	 0.003502	 0.01524	 0.0	 2021	 2021	 2021	 0.0	 0.0	 1	 -30.0	 30.0;
	12145	 11700	 0.000289	 0.00088	 0.0	 34103	 34103	 34103	 0.0	 0.0	 1	 -30.0	 30.0;
	1716	 11700	 0.003431	 0.014111	 0.0	 2176	 2176	 2176	 0.0	 0.0	 1	 -30.0	 30.0;
	6233	 209	 0.001502	 0.1272	 0.0	 249	 249	 249	 0.0	 0.0	 1	 -30.0	 30.0;
	12901	 1047	 8e-05	 0.000729	 0.0	 43072	 43072	 43072	 0.0	 0.0	 1	 -30.0	 30.0;
	1716	 1047	 0.003818	 0.012911	 0.0	 2347	 2347	 2347	 0.0	 0.0	 1	 -30.0	 30.0;
	13431	 1047	 0.001618	 0.013711	 0.0	 2288	 2288	 2288	 0.0	 0.0	 1	 -30.0	 30.0;
	4906	 2668	 0.001062	 0.007791	 0.0	 4018	 4018	 4018	 0.0	 0.0	 1	 -30.0	 30.0;
	9568	 2668	 0.001809	 0.008951	 0.0	 3459	 3459	 3459	 0.0	 0.0	 1	 -30.0	 30.0;
	8418	 2668	 0.007142	 0.020311	 0.0	 1468	 1468	 1468	 0.0	 0.0	 1	 -30.0	 30.0;
	4906	 12311	 0.000942	 0.008831	 0.0	 3557	 3557	 3557	 0.0	 0.0	 1	 -30.0	 30.0;
	9568	 12311	 0.001769	 0.008289	 0.0	 3727	 3727	 3727	 0.0	 0.0	 1	 -30.0	 30.0;
	8418	 12311	 0.00728	 0.019898	 0.0	 1491	 1491	 1491	 0.0	 0.0	 1	 -30.0	 30.0;
	13070	 8340	 0.003569	 0.017951	 0.0	 1726	 1726	 1726	 0.0	 0.0	 1	 -30.0	 30.0;
	5022	 13070	 0.001991	 0.007271	 0.0	 4191	 4191	 4191	 0.0	 0.0	 1	 -30.0	 30.0;
	11290	 13070	 0.000391	 0.001462	 0.0	 20873	 20873	 20873	 0.0	 0.0	 1	 -30.0	 30.0;
	3758	 12017	 0.003502	 0.018289	 0.0	 1697	 1697	 1697	 0.0	 0.0	 1	 -30.0	 30.0;
	370	 3758	 0.001769	 0.00824	 0.0	 3749	 3749	 3749	 0.0	 0.0	 1	 -30.0	 30.0;
	11290	 3758	 0.0004	 0.001431	 0.0	 21259	 21259	 21259	 0.0	 0.0	 1	 -30.0	 30.0;
	2585	 6946	 0.0	 0.000413	 0.0	 76483	 76483	 76483	 0.0	 0.0	 1	 -30.0	 30.0;
	5910	 11011	 0.001471	 0.1296	 0.0	 244	 244	 244	 0.0	 0.0	 1	 -30.0	 30.0;
	5030	 10815	 0.00056	 0.015018	 0.0	 2102	 2102	 2102	 0.0	 0.0	 1	 -30.0	 30.0;
	236	 12520	 0.000631	 0.01472	 0.0	 2144	 2144	 2144	 0.0	 0.0	 1	 -30.0	 30.0;
	236	 5030	 0.0	 0.001169	 0.0	 27021	 27021	 27021	 0.0	 0.0	 1	 -30.0	 30.0;
	236	 12436	 0.000942	 0.003342	 0.0	 9098	 9098	 9098	 0.0	 0.0	 1	 -30.0	 30.0;
	236	 3874	 0.001582	 0.002831	 0.0	 9741	 9741	 9741	 0.0	 0.0	 1	 -30.0	 30.0;
	4508	 7794	 0.0008	 0.003422	 0.0	 8989	 8989	 8989	 0.0	 0.0	 1	 -30.0	 30.0;
	4508	 7794	 0.000822	 0.003351	 0.0	 9155	 9155	 9155	 0.0	 0.0	 1	 -30.0	 30.0;
	12436	 3874	 0.002631	 0.004889	 0.0	 5690	 5690	 5690	 0.0	 0.0	 1	 -30.0	 30.0;
	12436	 3287	 0.005418	 0.022489	 0.0	 1366	 1366	 1366	 0.0	 0.0	 1	 -30.0	 30.0;
	12436	 3287	 0.00552	 0.022018	 0.0	 1392	 1392	 1392	 0.0	 0.0	 1	 -30.0	 30.0;
	10839	 11072	 0.004091	 0.020893	 0.0	 1484	 1484	 1484	 0.0	 0.0	 1	 -30.0	 30.0;
	10839	 11072	 0.004	 0.019339	 0.0	 1600	 1600	 1600	 0.0	 0.0	 1	 -30.0	 30.0;
	10839	 6483	 0.016479	 0.037058	 0.0	 779	 779	 779	 0.0	 0.0	 1	 -30.0	 30.0;
	10839	 6872	 0.016347	 0.05124	 0.0	 588	 588	 588	 0.0	 0.0	 1	 -30.0	 30.0;
	8406	 11072	 0.007058	 0.030587	 0.0	 1007	 1007	 1007	 0.0	 0.0	 1	 -30.0	 30.0;
	8406	 11072	 0.007149	 0.029934	 0.0	 1027	 1027	 1027	 0.0	 0.0	 1	 -30.0	 30.0;
	9967	 9063	 0.002089	 0.003449	 0.0	 7834	 7834	 7834	 0.0	 0.0	 1	 -30.0	 30.0;
	9967	 9063	 0.002129	 0.003378	 0.0	 7911	 7911	 7911	 0.0	 0.0	 1	 -30.0	 30.0;
	3324	 1033	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	1033	 6264	 0.007489	 0.0516	 0.0	 606	 606	 606	 0.0	 0.0	 1	 -30.0	 30.0;
	1033	 6264	 0.008489	 0.050569	 0.0	 617	 617	 617	 0.0	 0.0	 1	 -30.0	 30.0;
	1236	 4640	 0.0	 0.047951	 0.0	 659	 659	 659	 0.0	 0.0	 1	 -30.0	 30.0;
	8098	 4640	 0.001649	 0.016591	 0.0	 1895	 1895	 1895	 0.0	 0.0	 1	 -30.0	 30.0;
	11519	 4640	 0.001618	 0.016898	 0.0	 1861	 1861	 1861	 0.0	 0.0	 1	 -30.0	 30.0;
	5119	 9063	 0.006871	 0.039911	 0.0	 780	 780	 780	 0.0	 0.0	 1	 -30.0	 30.0;
	5119	 9063	 0.007009	 0.039089	 0.0	 796	 796	 796	 0.0	 0.0	 1	 -30.0	 30.0;
	5119	 4601	 0.001658	 0.011871	 0.0	 2636	 2636	 2636	 0.0	 0.0	 1	 -30.0	 30.0;
	5119	 4601	 0.001631	 0.010991	 0.0	 2843	 2843	 2843	 0.0	 0.0	 1	 -30.0	 30.0;
	7898	 13483	 0.00092	 0.004689	 0.0	 6611	 6611	 6611	 0.0	 0.0	 1	 -30.0	 30.0;
	190	 13483	 0.002049	 0.0038	 0.0	 7317	 7317	 7317	 0.0	 0.0	 1	 -30.0	 30.0;
	9249	 13483	 0.005649	 0.026	 0.0	 1188	 1188	 1188	 0.0	 0.0	 1	 -30.0	 30.0;
	7898	 4391	 0.000902	 0.004782	 0.0	 6492	 6492	 6492	 0.0	 0.0	 1	 -30.0	 30.0;
	417	 4391	 0.003471	 0.014471	 0.0	 2123	 2123	 2123	 0.0	 0.0	 1	 -30.0	 30.0;
	190	 4391	 0.002089	 0.00372	 0.0	 7404	 7404	 7404	 0.0	 0.0	 1	 -30.0	 30.0;
	6147	 2682	 0.003569	 0.010671	 0.0	 2808	 2808	 2808	 0.0	 0.0	 1	 -30.0	 30.0;
	5733	 6147	 0.019782	 0.061658	 0.0	 488	 488	 488	 0.0	 0.0	 1	 -30.0	 30.0;
	714	 8340	 0.000409	 0.0014	 0.0	 21658	 21658	 21658	 0.0	 0.0	 1	 -30.0	 30.0;
	8340	 792	 0.003302	 0.017311	 0.0	 1793	 1793	 1793	 0.0	 0.0	 1	 -30.0	 30.0;
	714	 12017	 0.000409	 0.001369	 0.0	 22108	 22108	 22108	 0.0	 0.0	 1	 -30.0	 30.0;
	12017	 792	 0.003231	 0.016031	 0.0	 1932	 1932	 1932	 0.0	 0.0	 1	 -30.0	 30.0;
	13626	 12481	 0.000751	 0.005711	 0.0	 5484	 5484	 5484	 0.0	 0.0	 1	 -30.0	 30.0;
	13626	 13296	 0.0018	 0.00716	 0.0	 4279	 4279	 4279	 0.0	 0.0	 1	 -30.0	 30.0;
	1667	 13626	 0.001978	 0.013462	 0.0	 2322	 2322	 2322	 0.0	 0.0	 1	 -30.0	 30.0;
	13626	 2763	 0.001502	 0.0056	 0.0	 5449	 5449	 5449	 0.0	 0.0	 1	 -30.0	 30.0;
	4785	 9403	 0.005991	 0.0284	 0.0	 1089	 1089	 1089	 0.0	 0.0	 1	 -30.0	 30.0;
	2918	 9403	 0.000302	 0.000858	 0.0	 34727	 34727	 34727	 0.0	 0.0	 1	 -30.0	 30.0;
	9157	 9403	 0.002622	 0.013231	 0.0	 2342	 2342	 2342	 0.0	 0.0	 1	 -30.0	 30.0;
	10451	 8621	 0.004271	 0.019502	 0.0	 1583	 1583	 1583	 0.0	 0.0	 1	 -30.0	 30.0;
	2918	 8621	 0.000271	 0.000969	 0.0	 31394	 31394	 31394	 0.0	 0.0	 1	 -30.0	 30.0;
	9157	 8621	 0.00356	 0.014378	 0.0	 2133	 2133	 2133	 0.0	 0.0	 1	 -30.0	 30.0;
	10562	 9850	 0.0022	 0.009569	 0.0	 3218	 3218	 3218	 0.0	 0.0	 1	 -30.0	 30.0;
	3935	 9850	 0.000311	 0.001169	 0.0	 26113	 26113	 26113	 0.0	 0.0	 1	 -30.0	 30.0;
	4817	 9850	 0.001889	 0.006311	 0.0	 4795	 4795	 4795	 0.0	 0.0	 1	 -30.0	 30.0;
	3935	 4785	 0.000271	 0.00132	 0.0	 23441	 23441	 23441	 0.0	 0.0	 1	 -30.0	 30.0;
	4817	 4785	 0.001929	 0.006178	 0.0	 4881	 4881	 4881	 0.0	 0.0	 1	 -30.0	 30.0;
	6977	 9653	 0.000339	 0.001149	 0.0	 26368	 26368	 26368	 0.0	 0.0	 1	 -30.0	 30.0;
	694	 10631	 0.002591	 0.014418	 0.0	 2157	 2157	 2157	 0.0	 0.0	 1	 -30.0	 30.0;
	694	 1120	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	9295	 5022	 0.0014	 0.00652	 0.0	 4737	 4737	 4737	 0.0	 0.0	 1	 -30.0	 30.0;
	7696	 5022	 0.000418	 0.001338	 0.0	 22534	 22534	 22534	 0.0	 0.0	 1	 -30.0	 30.0;
	9295	 370	 0.001369	 0.006649	 0.0	 4654	 4654	 4654	 0.0	 0.0	 1	 -30.0	 30.0;
	7696	 370	 0.000369	 0.00152	 0.0	 20195	 20195	 20195	 0.0	 0.0	 1	 -30.0	 30.0;
	13039	 10305	 0.004689	 0.018151	 0.0	 1685	 1685	 1685	 0.0	 0.0	 1	 -30.0	 30.0;
	13039	 10305	 0.004591	 0.018498	 0.0	 1658	 1658	 1658	 0.0	 0.0	 1	 -30.0	 30.0;
	1775	 202	 9.8e-05	 0.00028	 0.0	 106479	 106479	 106479	 0.0	 0.0	 1	 -30.0	 30.0;
	1775	 5843	 0.003698	 0.0198	 0.0	 1569	 1569	 1569	 0.0	 0.0	 1	 -30.0	 30.0;
	2815	 1775	 0.005471	 0.0206	 0.0	 1482	 1482	 1482	 0.0	 0.0	 1	 -30.0	 30.0;
	2815	 1775	 0.0062	 0.020191	 0.0	 1496	 1496	 1496	 0.0	 0.0	 1	 -30.0	 30.0;
	1775	 5048	 0.006098	 0.030551	 0.0	 1014	 1014	 1014	 0.0	 0.0	 1	 -30.0	 30.0;
	1337	 8418	 0.004809	 0.019751	 0.0	 1554	 1554	 1554	 0.0	 0.0	 1	 -30.0	 30.0;
	1337	 8418	 0.004711	 0.018289	 0.0	 1673	 1673	 1673	 0.0	 0.0	 1	 -30.0	 30.0;
	12145	 8811	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	10562	 10451	 0.007929	 0.044022	 0.0	 707	 707	 707	 0.0	 0.0	 1	 -30.0	 30.0;
	8826	 1917	 0.009782	 0.033938	 0.0	 895	 895	 895	 0.0	 0.0	 1	 -30.0	 30.0;
	8826	 9596	 0.003609	 0.016889	 0.0	 1829	 1829	 1829	 0.0	 0.0	 1	 -30.0	 30.0;
	952	 1974	 0.00044	 0.027591	 0.0	 1145	 1145	 1145	 0.0	 0.0	 1	 -30.0	 30.0;
	9983	 5189	 0.000419	 0.027979	 0.0	 1129	 1129	 1129	 0.0	 0.0	 1	 -30.0	 30.0;
	522	 5189	 0.000409	 0.02851	 0.0	 1108	 1108	 1108	 0.0	 0.0	 1	 -30.0	 30.0;
	1974	 5189	 0.0	 0.000461	 0.0	 68520	 68520	 68520	 0.0	 0.0	 1	 -30.0	 30.0;
	1974	 11313	 0.000531	 0.005581	 0.0	 5635	 5635	 5635	 0.0	 0.0	 1	 -30.0	 30.0;
	1508	 1974	 0.003841	 0.022461	 0.0	 1387	 1387	 1387	 0.0	 0.0	 1	 -30.0	 30.0;
	5189	 199	 0.000539	 0.005461	 0.0	 5757	 5757	 5757	 0.0	 0.0	 1	 -30.0	 30.0;
	5693	 5189	 0.00376	 0.022901	 0.0	 1362	 1362	 1362	 0.0	 0.0	 1	 -30.0	 30.0;
	7318	 13121	 0.028843	 0.060992	 0.0	 469	 469	 469	 0.0	 0.0	 1	 -30.0	 30.0;
	7318	 13121	 0.029397	 0.059744	 0.0	 475	 475	 475	 0.0	 0.0	 1	 -30.0	 30.0;
	2585	 9277	 0.001727	 0.00924	 0.0	 3361	 3361	 3361	 0.0	 0.0	 1	 -30.0	 30.0;
	11741	 2585	 0.004851	 0.02724	 0.0	 1142	 1142	 1142	 0.0	 0.0	 1	 -30.0	 30.0;
	1917	 9596	 0.0138	 0.040249	 0.0	 743	 743	 743	 0.0	 0.0	 1	 -30.0	 30.0;
	1917	 939	 0.007098	 0.022329	 0.0	 1349	 1349	 1349	 0.0	 0.0	 1	 -30.0	 30.0;
	1917	 2618	 0.001902	 0.008391	 0.0	 3672	 3672	 3672	 0.0	 0.0	 1	 -30.0	 30.0;
	1917	 2618	 0.001929	 0.008209	 0.0	 3746	 3746	 3746	 0.0	 0.0	 1	 -30.0	 30.0;
	2386	 1917	 0.001649	 0.01228	 0.0	 2550	 2550	 2550	 0.0	 0.0	 1	 -30.0	 30.0;
	2386	 1917	 0.001471	 0.01392	 0.0	 2257	 2257	 2257	 0.0	 0.0	 1	 -30.0	 30.0;
	1917	 11165	 0.000582	 0.040991	 0.0	 771	 771	 771	 0.0	 0.0	 1	 -30.0	 30.0;
	1917	 464	 0.01116	 0.033671	 0.0	 891	 891	 891	 0.0	 0.0	 1	 -30.0	 30.0;
	10226	 3561	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	7325	 10030	 0.00031	 0.00312	 0.0	 10075	 10075	 10075	 0.0	 0.0	 1	 -30.0	 30.0;
	8845	 10030	 0.00069	 0.00769	 0.0	 4092	 4092	 4092	 0.0	 0.0	 1	 -30.0	 30.0;
	8979	 7210	 0.010471	 0.029289	 0.0	 1016	 1016	 1016	 0.0	 0.0	 1	 -30.0	 30.0;
	8979	 7210	 0.010671	 0.028671	 0.0	 1033	 1033	 1033	 0.0	 0.0	 1	 -30.0	 30.0;
	507	 8979	 0.00624	 0.021871	 0.0	 1389	 1389	 1389	 0.0	 0.0	 1	 -30.0	 30.0;
	507	 8979	 0.007071	 0.021431	 0.0	 1400	 1400	 1400	 0.0	 0.0	 1	 -30.0	 30.0;
	10591	 11365	 9.8e-05	 0.00028	 0.0	 106479	 106479	 106479	 0.0	 0.0	 1	 -30.0	 30.0;
	10591	 9596	 0.001062	 0.003351	 0.0	 8986	 8986	 8986	 0.0	 0.0	 1	 -30.0	 30.0;
	10591	 10306	 0.002111	 0.02008	 0.0	 1565	 1565	 1565	 0.0	 0.0	 1	 -30.0	 30.0;
	10591	 9365	 0.001009	 0.010929	 0.0	 2878	 2878	 2878	 0.0	 0.0	 1	 -30.0	 30.0;
	2386	 10591	 0.004711	 0.050609	 0.0	 622	 622	 622	 0.0	 0.0	 1	 -30.0	 30.0;
	10591	 13431	 0.011462	 0.02396	 0.0	 1190	 1190	 1190	 0.0	 0.0	 1	 -30.0	 30.0;
	5910	 3363	 0.0	 0.0444	 0.0	 712	 712	 712	 0.0	 0.0	 1	 -30.0	 30.0;
	5910	 1614	 0.001698	 0.1128	 0.0	 280	 280	 280	 0.0	 0.0	 1	 -30.0	 30.0;
	5910	 8589	 8.9e-05	 0.000742	 0.0	 42268	 42268	 42268	 0.0	 0.0	 1	 -30.0	 30.0;
	5910	 8589	 8.9e-05	 0.000729	 0.0	 43011	 43011	 43011	 0.0	 0.0	 1	 -30.0	 30.0;
	5910	 4019	 0.000302	 0.000809	 0.0	 36580	 36580	 36580	 0.0	 0.0	 1	 -30.0	 30.0;
	5910	 11783	 0.001502	 0.002182	 0.0	 11925	 11925	 11925	 0.0	 0.0	 1	 -30.0	 30.0;
	5910	 8990	 0.001311	 0.001871	 0.0	 13827	 13827	 13827	 0.0	 0.0	 1	 -30.0	 30.0;
	5910	 8990	 0.001369	 0.00204	 0.0	 12858	 12858	 12858	 0.0	 0.0	 1	 -30.0	 30.0;
	5910	 10137	 0.001049	 0.00308	 0.0	 9709	 9709	 9709	 0.0	 0.0	 1	 -30.0	 30.0;
	11741	 8587	 0.014967	 0.09105	 0.0	 343	 343	 343	 0.0	 0.0	 1	 -30.0	 30.0;
	7725	 8587	 0.028959	 0.12905	 0.0	 239	 239	 239	 0.0	 0.0	 1	 -30.0	 30.0;
	3555	 8587	 0.006438	 0.041256	 0.0	 757	 757	 757	 0.0	 0.0	 1	 -30.0	 30.0;
	3555	 8587	 0.006554	 0.040364	 0.0	 773	 773	 773	 0.0	 0.0	 1	 -30.0	 30.0;
	3363	 1781	 0.0	 0.012742	 0.0	 2479	 2479	 2479	 0.0	 0.0	 1	 -30.0	 30.0;
	1667	 12481	 0.001018	 0.00868	 0.0	 3615	 3615	 3615	 0.0	 0.0	 1	 -30.0	 30.0;
	1667	 13296	 0.001871	 0.00548	 0.0	 5455	 5455	 5455	 0.0	 0.0	 1	 -30.0	 30.0;
	13296	 10948	 0.00228	 0.004338	 0.0	 6446	 6446	 6446	 0.0	 0.0	 1	 -30.0	 30.0;
	13296	 10948	 0.00224	 0.004431	 0.0	 6362	 6362	 6362	 0.0	 0.0	 1	 -30.0	 30.0;
	4355	 1155	 0.00076	 0.00747	 0.0	 4207	 4207	 4207	 0.0	 0.0	 1	 -30.0	 30.0;
	8261	 1155	 0.00103	 0.01061	 0.0	 2964	 2964	 2964	 0.0	 0.0	 1	 -30.0	 30.0;
	3197	 13291	 0.002689	 0.013818	 0.0	 2244	 2244	 2244	 0.0	 0.0	 1	 -30.0	 30.0;
	792	 3197	 0.002111	 0.003769	 0.0	 7313	 7313	 7313	 0.0	 0.0	 1	 -30.0	 30.0;
	792	 3197	 0.002151	 0.003689	 0.0	 7397	 7397	 7397	 0.0	 0.0	 1	 -30.0	 30.0;
	13039	 7898	 0.00176	 0.012702	 0.0	 2464	 2464	 2464	 0.0	 0.0	 1	 -30.0	 30.0;
	13039	 7898	 0.001729	 0.012951	 0.0	 2418	 2418	 2418	 0.0	 0.0	 1	 -30.0	 30.0;
	8351	 1501	 0.000151	 0.000511	 0.0	 59281	 59281	 59281	 0.0	 0.0	 1	 -30.0	 30.0;
	8351	 1501	 0.000151	 0.000502	 0.0	 60257	 60257	 60257	 0.0	 0.0	 1	 -30.0	 30.0;
	8351	 2618	 0.01076	 0.05508	 0.0	 563	 563	 563	 0.0	 0.0	 1	 -30.0	 30.0;
	8351	 2618	 0.010542	 0.05616	 0.0	 553	 553	 553	 0.0	 0.0	 1	 -30.0	 30.0;
	8351	 9968	 0.003089	 0.009	 0.0	 3320	 3320	 3320	 0.0	 0.0	 1	 -30.0	 30.0;
	8351	 9968	 0.003031	 0.009169	 0.0	 3271	 3271	 3271	 0.0	 0.0	 1	 -30.0	 30.0;
	8351	 9157	 0.001849	 0.00872	 0.0	 3544	 3544	 3544	 0.0	 0.0	 1	 -30.0	 30.0;
	8351	 9157	 0.00188	 0.008538	 0.0	 3614	 3614	 3614	 0.0	 0.0	 1	 -30.0	 30.0;
	4281	 4817	 0.004151	 0.01556	 0.0	 1962	 1962	 1962	 0.0	 0.0	 1	 -30.0	 30.0;
	2386	 4281	 0.006591	 0.026778	 0.0	 1146	 1146	 1146	 0.0	 0.0	 1	 -30.0	 30.0;
	10226	 13140	 0.00056	 0.038671	 0.0	 817	 817	 817	 0.0	 0.0	 1	 -30.0	 30.0;
	2493	 871	 0.0	 0.00045	 0.0	 70195	 70195	 70195	 0.0	 0.0	 1	 -30.0	 30.0;
	871	 1593	 0.00162	 0.01968	 0.0	 1600	 1600	 1600	 0.0	 0.0	 1	 -30.0	 30.0;
	10226	 6671	 9.8e-05	 0.00028	 0.0	 106479	 106479	 106479	 0.0	 0.0	 1	 -30.0	 30.0;
	10226	 9295	 0.002649	 0.015111	 0.0	 2059	 2059	 2059	 0.0	 0.0	 1	 -30.0	 30.0;
	10226	 9295	 0.002702	 0.014809	 0.0	 2099	 2099	 2099	 0.0	 0.0	 1	 -30.0	 30.0;
	10226	 7362	 0.0008	 0.005711	 0.0	 5478	 5478	 5478	 0.0	 0.0	 1	 -30.0	 30.0;
	10226	 7362	 0.000782	 0.005809	 0.0	 5390	 5390	 5390	 0.0	 0.0	 1	 -30.0	 30.0;
	10226	 4815	 0.001049	 0.007738	 0.0	 4046	 4046	 4046	 0.0	 0.0	 1	 -30.0	 30.0;
	10226	 4815	 0.001071	 0.007569	 0.0	 4133	 4133	 4133	 0.0	 0.0	 1	 -30.0	 30.0;
	10226	 4508	 0.005138	 0.025338	 0.0	 1222	 1222	 1222	 0.0	 0.0	 1	 -30.0	 30.0;
	10226	 4508	 0.005031	 0.025831	 0.0	 1201	 1201	 1201	 0.0	 0.0	 1	 -30.0	 30.0;
	10226	 2074	 0.003658	 0.029071	 0.0	 1079	 1079	 1079	 0.0	 0.0	 1	 -30.0	 30.0;
	10226	 2074	 0.004151	 0.028489	 0.0	 1098	 1098	 1098	 0.0	 0.0	 1	 -30.0	 30.0;
	1730	 1915	 0.001471	 0.011471	 0.0	 2732	 2732	 2732	 0.0	 0.0	 1	 -30.0	 30.0;
	1730	 1915	 0.001502	 0.011218	 0.0	 2791	 2791	 2791	 0.0	 0.0	 1	 -30.0	 30.0;
	3287	 1915	 0.001871	 0.014511	 0.0	 2159	 2159	 2159	 0.0	 0.0	 1	 -30.0	 30.0;
	3287	 1915	 0.001902	 0.0142	 0.0	 2205	 2205	 2205	 0.0	 0.0	 1	 -30.0	 30.0;
	287	 10546	 0.000351	 0.004662	 0.0	 6757	 6757	 6757	 0.0	 0.0	 1	 -30.0	 30.0;
	65	 287	 0.00772	 0.033818	 0.0	 911	 911	 911	 0.0	 0.0	 1	 -30.0	 30.0;
	7268	 12422	 0.0	 0.00051	 0.0	 61936	 61936	 61936	 0.0	 0.0	 1	 -30.0	 30.0;
	12422	 2719	 0.00076	 0.0119	 0.0	 2650	 2650	 2650	 0.0	 0.0	 1	 -30.0	 30.0;
	12422	 4886	 0.00025	 0.00316	 0.0	 9965	 9965	 9965	 0.0	 0.0	 1	 -30.0	 30.0;
	7268	 5101	 0.00077	 0.01164	 0.0	 2708	 2708	 2708	 0.0	 0.0	 1	 -30.0	 30.0;
	7268	 9879	 0.00025	 0.00322	 0.0	 9781	 9781	 9781	 0.0	 0.0	 1	 -30.0	 30.0;
	6959	 10224	 0.001369	 0.021182	 0.0	 1489	 1489	 1489	 0.0	 0.0	 1	 -30.0	 30.0;
	2719	 5101	 0.0	 0.00052	 0.0	 60745	 60745	 60745	 0.0	 0.0	 1	 -30.0	 30.0;
	2719	 11660	 0.00015	 0.00328	 0.0	 9621	 9621	 9621	 0.0	 0.0	 1	 -30.0	 30.0;
	583	 2719	 0.00016	 0.00314	 0.0	 10047	 10047	 10047	 0.0	 0.0	 1	 -30.0	 30.0;
	5101	 8845	 0.00017	 0.00321	 0.0	 9827	 9827	 9827	 0.0	 0.0	 1	 -30.0	 30.0;
	8504	 5101	 0.00018	 0.00308	 0.0	 10239	 10239	 10239	 0.0	 0.0	 1	 -30.0	 30.0;
	4653	 8478	 0.00024	 0.01948	 0.0	 1622	 1622	 1622	 0.0	 0.0	 1	 -30.0	 30.0;
	2386	 11098	 0.000631	 0.037902	 0.0	 834	 834	 834	 0.0	 0.0	 1	 -30.0	 30.0;
	3408	 10416	 0.00244	 0.01532	 0.0	 2037	 2037	 2037	 0.0	 0.0	 1	 -30.0	 30.0;
	424	 11893	 0.0	 0.00053	 0.0	 59599	 59599	 59599	 0.0	 0.0	 1	 -30.0	 30.0;
	424	 8845	 0.00013	 0.00282	 0.0	 11190	 11190	 11190	 0.0	 0.0	 1	 -30.0	 30.0;
	5998	 424	 0.00038	 0.00708	 0.0	 4456	 4456	 4456	 0.0	 0.0	 1	 -30.0	 30.0;
	11893	 11660	 0.00013	 0.00261	 0.0	 12088	 12088	 12088	 0.0	 0.0	 1	 -30.0	 30.0;
	8583	 11893	 0.00038	 0.00722	 0.0	 4369	 4369	 4369	 0.0	 0.0	 1	 -30.0	 30.0;
	2101	 7663	 0.00016	 0.002769	 0.0	 11389	 11389	 11389	 0.0	 0.0	 1	 -30.0	 30.0;
	5822	 7663	 0.00016	 0.00272	 0.0	 11593	 11593	 11593	 0.0	 0.0	 1	 -30.0	 30.0;
	11831	 7663	 0.00016	 0.002662	 0.0	 11845	 11845	 11845	 0.0	 0.0	 1	 -30.0	 30.0;
	2834	 2276	 0.024479	 0.081727	 0.0	 371	 371	 371	 0.0	 0.0	 1	 -30.0	 30.0;
	10113	 2276	 0.024248	 0.064893	 0.0	 456	 456	 456	 0.0	 0.0	 1	 -30.0	 30.0;
	988	 12888	 0.0084	 0.04056	 0.0	 763	 763	 763	 0.0	 0.0	 1	 -30.0	 30.0;
	12888	 295	 0.003809	 0.0248	 0.0	 1259	 1259	 1259	 0.0	 0.0	 1	 -30.0	 30.0;
	12888	 5048	 0.002542	 0.014569	 0.0	 2136	 2136	 2136	 0.0	 0.0	 1	 -30.0	 30.0;
	12888	 5048	 0.002591	 0.01428	 0.0	 2177	 2177	 2177	 0.0	 0.0	 1	 -30.0	 30.0;
	11082	 11340	 9.8e-05	 0.00028	 0.0	 106479	 106479	 106479	 0.0	 0.0	 1	 -30.0	 30.0;
	11082	 8139	 0.003071	 0.01636	 0.0	 1898	 1898	 1898	 0.0	 0.0	 1	 -30.0	 30.0;
	11082	 7810	 0.003889	 0.027022	 0.0	 1158	 1158	 1158	 0.0	 0.0	 1	 -30.0	 30.0;
	6997	 11082	 0.00624	 0.036009	 0.0	 865	 865	 865	 0.0	 0.0	 1	 -30.0	 30.0;
	6997	 11082	 0.00636	 0.035258	 0.0	 882	 882	 882	 0.0	 0.0	 1	 -30.0	 30.0;
	7663	 3996	 0.000982	 0.001529	 0.0	 17383	 17383	 17383	 0.0	 0.0	 1	 -30.0	 30.0;
	7663	 3996	 0.000991	 0.001502	 0.0	 17554	 17554	 17554	 0.0	 0.0	 1	 -30.0	 30.0;
	12773	 7663	 0.00052	 0.004991	 0.0	 6295	 6295	 6295	 0.0	 0.0	 1	 -30.0	 30.0;
	7663	 3868	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	947	 6035	 0.012182	 0.034826	 0.0	 857	 857	 857	 0.0	 0.0	 1	 -30.0	 30.0;
	2834	 947	 0.025744	 0.059	 0.0	 491	 491	 491	 0.0	 0.0	 1	 -30.0	 30.0;
	6067	 2336	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	9017	 6067	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	9017	 8554	 0.003129	 0.015031	 0.0	 2058	 2058	 2058	 0.0	 0.0	 1	 -30.0	 30.0;
	6067	 728	 0.00228	 0.019871	 0.0	 1580	 1580	 1580	 0.0	 0.0	 1	 -30.0	 30.0;
	6067	 8554	 0.002791	 0.017031	 0.0	 1831	 1831	 1831	 0.0	 0.0	 1	 -30.0	 30.0;
	9634	 5049	 0.001431	 0.01252	 0.0	 2507	 2507	 2507	 0.0	 0.0	 1	 -30.0	 30.0;
	9634	 8829	 0.001649	 0.007631	 0.0	 4046	 4046	 4046	 0.0	 0.0	 1	 -30.0	 30.0;
	9634	 7652	 0.001471	 0.008649	 0.0	 3601	 3601	 3601	 0.0	 0.0	 1	 -30.0	 30.0;
	728	 8554	 0.00656	 0.009071	 0.0	 2822	 2822	 2822	 0.0	 0.0	 1	 -30.0	 30.0;
	8813	 11724	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	7246	 13401	 0.0	 0.00028	 0.0	 112812	 112812	 112812	 0.0	 0.0	 1	 -30.0	 30.0;
	1145	 11839	 0.000521	 0.001529	 0.0	 19555	 19555	 19555	 0.0	 0.0	 1	 -30.0	 30.0;
	113	 12513	 0.000219	 0.00095	 0.0	 32401	 32401	 32401	 0.0	 0.0	 1	 -30.0	 30.0;
	48	 12513	 0.000219	 0.00088	 0.0	 34833	 34833	 34833	 0.0	 0.0	 1	 -30.0	 30.0;
	13039	 13175	 0.002391	 0.015618	 0.0	 2000	 2000	 2000	 0.0	 0.0	 1	 -30.0	 30.0;
	7325	 1289	 0.0	 0.00054	 0.0	 58496	 58496	 58496	 0.0	 0.0	 1	 -30.0	 30.0;
	2553	 7325	 0.00079	 0.01037	 0.0	 3038	 3038	 3038	 0.0	 0.0	 1	 -30.0	 30.0;
	11462	 7325	 0.00022	 0.00296	 0.0	 10643	 10643	 10643	 0.0	 0.0	 1	 -30.0	 30.0;
	7960	 1289	 0.00077	 0.01056	 0.0	 2984	 2984	 2984	 0.0	 0.0	 1	 -30.0	 30.0;
	1667	 6295	 0.000649	 0.03712	 0.0	 851	 851	 851	 0.0	 0.0	 1	 -30.0	 30.0;
	1667	 12627	 0.003302	 0.019138	 0.0	 1627	 1627	 1627	 0.0	 0.0	 1	 -30.0	 30.0;
	1667	 12627	 0.003369	 0.018742	 0.0	 1659	 1659	 1659	 0.0	 0.0	 1	 -30.0	 30.0;
	1667	 694	 0.001769	 0.018222	 0.0	 1726	 1726	 1726	 0.0	 0.0	 1	 -30.0	 30.0;
	1667	 10948	 0.000858	 0.006809	 0.0	 4603	 4603	 4603	 0.0	 0.0	 1	 -30.0	 30.0;
	1667	 10948	 0.000969	 0.006671	 0.0	 4686	 4686	 4686	 0.0	 0.0	 1	 -30.0	 30.0;
	1667	 12180	 0.005551	 0.03908	 0.0	 801	 801	 801	 0.0	 0.0	 1	 -30.0	 30.0;
	1667	 12180	 0.005431	 0.039822	 0.0	 786	 786	 786	 0.0	 0.0	 1	 -30.0	 30.0;
	1667	 12180	 0.005311	 0.036871	 0.0	 848	 848	 848	 0.0	 0.0	 1	 -30.0	 30.0;
	1456	 1575	 0.002169	 0.016271	 0.0	 1925	 1925	 1925	 0.0	 0.0	 1	 -30.0	 30.0;
	4601	 1575	 0.007418	 0.07832	 0.0	 402	 402	 402	 0.0	 0.0	 1	 -30.0	 30.0;
	7067	 4355	 0.0	 0.0005	 0.0	 63175	 63175	 63175	 0.0	 0.0	 1	 -30.0	 30.0;
	7067	 1592	 0.0	 0.00049	 0.0	 64464	 64464	 64464	 0.0	 0.0	 1	 -30.0	 30.0;
	7067	 11934	 0.00079	 0.00848	 0.0	 3709	 3709	 3709	 0.0	 0.0	 1	 -30.0	 30.0;
	7067	 4653	 0.00183	 0.0174	 0.0	 1806	 1806	 1806	 0.0	 0.0	 1	 -30.0	 30.0;
	4355	 1592	 0.0	 0.00048	 0.0	 65807	 65807	 65807	 0.0	 0.0	 1	 -30.0	 30.0;
	4355	 12977	 0.0008	 0.0083	 0.0	 3789	 3789	 3789	 0.0	 0.0	 1	 -30.0	 30.0;
	6275	 106	 0.004449	 0.02404	 0.0	 1293	 1293	 1293	 0.0	 0.0	 1	 -30.0	 30.0;
	6275	 106	 0.004529	 0.023551	 0.0	 1318	 1318	 1318	 0.0	 0.0	 1	 -30.0	 30.0;
	6275	 9063	 0.006791	 0.013271	 0.0	 2119	 2119	 2119	 0.0	 0.0	 1	 -30.0	 30.0;
	6275	 1589	 0.00424	 0.030378	 0.0	 1030	 1030	 1030	 0.0	 0.0	 1	 -30.0	 30.0;
	6275	 1589	 0.004151	 0.028129	 0.0	 1111	 1111	 1111	 0.0	 0.0	 1	 -30.0	 30.0;
	6275	 10706	 0.002311	 0.003622	 0.0	 7352	 7352	 7352	 0.0	 0.0	 1	 -30.0	 30.0;
	6275	 10706	 0.002062	 0.004102	 0.0	 6881	 6881	 6881	 0.0	 0.0	 1	 -30.0	 30.0;
	6275	 10209	 0.00452	 0.029609	 0.0	 1055	 1055	 1055	 0.0	 0.0	 1	 -30.0	 30.0;
	6275	 10209	 0.004422	 0.030169	 0.0	 1036	 1036	 1036	 0.0	 0.0	 1	 -30.0	 30.0;
	6275	 6997	 0.00416	 0.023058	 0.0	 1349	 1349	 1349	 0.0	 0.0	 1	 -30.0	 30.0;
	6275	 5334	 0.002831	 0.020742	 0.0	 1509	 1509	 1509	 0.0	 0.0	 1	 -30.0	 30.0;
	4508	 2455	 0.002338	 0.01592	 0.0	 1964	 1964	 1964	 0.0	 0.0	 1	 -30.0	 30.0;
	5337	 4555	 9.8e-05	 0.00028	 0.0	 106479	 106479	 106479	 0.0	 0.0	 1	 -30.0	 30.0;
	1589	 5337	 0.004969	 0.03636	 0.0	 861	 861	 861	 0.0	 0.0	 1	 -30.0	 30.0;
	10209	 5337	 0.003431	 0.015698	 0.0	 1966	 1966	 1966	 0.0	 0.0	 1	 -30.0	 30.0;
	10661	 5337	 0.00456	 0.027582	 0.0	 1130	 1130	 1130	 0.0	 0.0	 1	 -30.0	 30.0;
	11934	 12977	 0.0	 0.00047	 0.0	 67208	 67208	 67208	 0.0	 0.0	 1	 -30.0	 30.0;
	12369	 11934	 0.00093	 0.01185	 0.0	 2658	 2658	 2658	 0.0	 0.0	 1	 -30.0	 30.0;
	1112	 12977	 0.00091	 0.01207	 0.0	 2610	 2610	 2610	 0.0	 0.0	 1	 -30.0	 30.0;
	988	 9425	 9.8e-05	 0.00028	 0.0	 106479	 106479	 106479	 0.0	 0.0	 1	 -30.0	 30.0;
	9064	 988	 0.000529	 0.003151	 0.0	 9887	 9887	 9887	 0.0	 0.0	 1	 -30.0	 30.0;
	9064	 988	 0.00052	 0.003209	 0.0	 9717	 9717	 9717	 0.0	 0.0	 1	 -30.0	 30.0;
	988	 295	 0.00352	 0.020578	 0.0	 1514	 1514	 1514	 0.0	 0.0	 1	 -30.0	 30.0;
	13121	 10103	 0.039182	 0.089413	 0.0	 324	 324	 324	 0.0	 0.0	 1	 -30.0	 30.0;
	13121	 13608	 0.033686	 0.067124	 0.0	 421	 421	 421	 0.0	 0.0	 1	 -30.0	 30.0;
	4955	 5962	 0.044992	 0.093174	 0.0	 306	 306	 306	 0.0	 0.0	 1	 -30.0	 30.0;
	8785	 4955	 0.013678	 0.052479	 0.0	 583	 583	 583	 0.0	 0.0	 1	 -30.0	 30.0;
	7145	 4955	 0.005686	 0.022893	 0.0	 1340	 1340	 1340	 0.0	 0.0	 1	 -30.0	 30.0;
	4955	 10449	 0.034281	 0.094653	 0.0	 314	 314	 314	 0.0	 0.0	 1	 -30.0	 30.0;
	3965	 8934	 0.0	 0.00045	 0.0	 70195	 70195	 70195	 0.0	 0.0	 1	 -30.0	 30.0;
	113	 3965	 0.00032	 0.001469	 0.0	 21010	 21010	 21010	 0.0	 0.0	 1	 -30.0	 30.0;
	48	 8934	 0.000289	 0.001039	 0.0	 29290	 29290	 29290	 0.0	 0.0	 1	 -30.0	 30.0;
	1145	 11392	 0.00324	 0.017628	 0.0	 1763	 1763	 1763	 0.0	 0.0	 1	 -30.0	 30.0;
	1145	 12571	 0.002678	 0.019298	 0.0	 1622	 1622	 1622	 0.0	 0.0	 1	 -30.0	 30.0;
	1145	 7789	 0.000529	 0.001504	 0.0	 19813	 19813	 19813	 0.0	 0.0	 1	 -30.0	 30.0;
	7307	 2067	 0.00042	 0.0261	 0.0	 1441	 1441	 1441	 0.0	 0.0	 1	 -30.0	 30.0;
	9980	 7024	 0.00043	 0.02555	 0.0	 1472	 1472	 1472	 0.0	 0.0	 1	 -30.0	 30.0;
	9496	 7024	 0.00044	 0.02499	 0.0	 1505	 1505	 1505	 0.0	 0.0	 1	 -30.0	 30.0;
	12198	 7024	 0.00039	 0.02833	 0.0	 1327	 1327	 1327	 0.0	 0.0	 1	 -30.0	 30.0;
	842	 1927	 0.00019	 0.01594	 0.0	 1982	 1982	 1982	 0.0	 0.0	 1	 -30.0	 30.0;
	409	 9452	 0.000419	 0.026099	 0.0	 1211	 1211	 1211	 0.0	 0.0	 1	 -30.0	 30.0;
	3900	 11947	 0.00043	 0.02555	 0.0	 1237	 1237	 1237	 0.0	 0.0	 1	 -30.0	 30.0;
	12821	 12218	 0.00038	 0.02888	 0.0	 1302	 1302	 1302	 0.0	 0.0	 1	 -30.0	 30.0;
	10053	 5967	 0.00038	 0.02944	 0.0	 1277	 1277	 1277	 0.0	 0.0	 1	 -30.0	 30.0;
	5478	 2067	 0.00037	 0.02999	 0.0	 1265	 1265	 1265	 0.0	 0.0	 1	 -30.0	 30.0;
	2699	 2067	 0.00036	 0.02777	 0.0	 1367	 1367	 1367	 0.0	 0.0	 1	 -30.0	 30.0;
	106	 11969	 9.8e-05	 0.00028	 0.0	 106479	 106479	 106479	 0.0	 0.0	 1	 -30.0	 30.0;
	10694	 106	 0.003951	 0.02048	 0.0	 1515	 1515	 1515	 0.0	 0.0	 1	 -30.0	 30.0;
	106	 11965	 0.003858	 0.020871	 0.0	 1489	 1489	 1489	 0.0	 0.0	 1	 -30.0	 30.0;
	7024	 12218	 0.0	 0.00046	 0.0	 81721	 81721	 81721	 0.0	 0.0	 1	 -30.0	 30.0;
	7024	 5967	 0.0	 0.00045	 0.0	 83537	 83537	 83537	 0.0	 0.0	 1	 -30.0	 30.0;
	7024	 10831	 0.0	 0.00051	 0.0	 73709	 73709	 73709	 0.0	 0.0	 1	 -30.0	 30.0;
	7024	 2853	 0.0	 0.00052	 0.0	 72292	 72292	 72292	 0.0	 0.0	 1	 -30.0	 30.0;
	3509	 11947	 0.0	 0.00051	 0.0	 61936	 61936	 61936	 0.0	 0.0	 1	 -30.0	 30.0;
	3509	 9452	 0.0	 0.000521	 0.0	 60629	 60629	 60629	 0.0	 0.0	 1	 -30.0	 30.0;
	3509	 9165	 0.0	 0.000531	 0.0	 59487	 59487	 59487	 0.0	 0.0	 1	 -30.0	 30.0;
	3509	 6373	 0.0	 0.000539	 0.0	 58604	 58604	 58604	 0.0	 0.0	 1	 -30.0	 30.0;
	2067	 12218	 0.0	 0.00053	 0.0	 70928	 70928	 70928	 0.0	 0.0	 1	 -30.0	 30.0;
	2067	 5967	 0.0	 0.00054	 0.0	 69614	 69614	 69614	 0.0	 0.0	 1	 -30.0	 30.0;
	2067	 10831	 0.0	 0.0005	 0.0	 75184	 75184	 75184	 0.0	 0.0	 1	 -30.0	 30.0;
	2067	 2853	 0.0	 0.00049	 0.0	 76718	 76718	 76718	 0.0	 0.0	 1	 -30.0	 30.0;
	486	 11947	 0.0	 0.0005	 0.0	 63175	 63175	 63175	 0.0	 0.0	 1	 -30.0	 30.0;
	486	 9452	 0.0	 0.00049	 0.0	 64464	 64464	 64464	 0.0	 0.0	 1	 -30.0	 30.0;
	486	 9165	 0.0	 0.000479	 0.0	 65945	 65945	 65945	 0.0	 0.0	 1	 -30.0	 30.0;
	486	 6373	 0.0	 0.000469	 0.0	 67351	 67351	 67351	 0.0	 0.0	 1	 -30.0	 30.0;
	10205	 12218	 0.00043	 0.00544	 0.0	 6889	 6889	 6889	 0.0	 0.0	 1	 -30.0	 30.0;
	5125	 11947	 0.0	 0.000461	 0.0	 68520	 68520	 68520	 0.0	 0.0	 1	 -30.0	 30.0;
	9452	 1927	 0.0	 0.00045	 0.0	 70195	 70195	 70195	 0.0	 0.0	 1	 -30.0	 30.0;
	2792	 10831	 0.00038	 0.00616	 0.0	 6148	 6148	 6148	 0.0	 0.0	 1	 -30.0	 30.0;
	7729	 2853	 0.00041	 0.02721	 0.0	 1382	 1382	 1382	 0.0	 0.0	 1	 -30.0	 30.0;
	6373	 1508	 0.002081	 0.023	 0.0	 1368	 1368	 1368	 0.0	 0.0	 1	 -30.0	 30.0;
	9737	 6959	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	7545	 3892	 0.0	 0.00048	 0.0	 65807	 65807	 65807	 0.0	 0.0	 1	 -30.0	 30.0;
	7545	 2409	 0.0011	 0.01189	 0.0	 2646	 2646	 2646	 0.0	 0.0	 1	 -30.0	 30.0;
	7545	 4653	 0.00084	 0.00906	 0.0	 3472	 3472	 3472	 0.0	 0.0	 1	 -30.0	 30.0;
	3892	 2409	 0.00112	 0.01165	 0.0	 2699	 2699	 2699	 0.0	 0.0	 1	 -30.0	 30.0;
	3892	 1593	 0.00115	 0.0114	 0.0	 2757	 2757	 2757	 0.0	 0.0	 1	 -30.0	 30.0;
	3892	 8261	 0.00086	 0.00887	 0.0	 3545	 3545	 3545	 0.0	 0.0	 1	 -30.0	 30.0;
	4906	 10546	 0.00116	 0.00912	 0.0	 3436	 3436	 3436	 0.0	 0.0	 1	 -30.0	 30.0;
	4906	 10546	 0.001129	 0.009298	 0.0	 3373	 3373	 3373	 0.0	 0.0	 1	 -30.0	 30.0;
	10546	 13275	 0.000609	 0.005058	 0.0	 6201	 6201	 6201	 0.0	 0.0	 1	 -30.0	 30.0;
	65	 10546	 0.008009	 0.04	 0.0	 775	 775	 775	 0.0	 0.0	 1	 -30.0	 30.0;
	10546	 5680	 0.002289	 0.016218	 0.0	 1929	 1929	 1929	 0.0	 0.0	 1	 -30.0	 30.0;
	4906	 579	 0.003098	 0.032729	 0.0	 961	 961	 961	 0.0	 0.0	 1	 -30.0	 30.0;
	4906	 5180	 0.002982	 0.013058	 0.0	 2359	 2359	 2359	 0.0	 0.0	 1	 -30.0	 30.0;
	4906	 5180	 0.00304	 0.0128	 0.0	 2401	 2401	 2401	 0.0	 0.0	 1	 -30.0	 30.0;
	4906	 8486	 0.008791	 0.059622	 0.0	 525	 525	 525	 0.0	 0.0	 1	 -30.0	 30.0;
	13275	 9568	 0.000511	 0.004409	 0.0	 7117	 7117	 7117	 0.0	 0.0	 1	 -30.0	 30.0;
	11253	 9568	 0.009391	 0.030809	 0.0	 981	 981	 981	 0.0	 0.0	 1	 -30.0	 30.0;
	11253	 9568	 0.009191	 0.031391	 0.0	 966	 966	 966	 0.0	 0.0	 1	 -30.0	 30.0;
	2423	 4153	 9.8e-05	 0.000222	 0.0	 130167	 130167	 130167	 0.0	 0.0	 1	 -30.0	 30.0;
	9063	 2423	 0.00276	 0.014782	 0.0	 2101	 2101	 2101	 0.0	 0.0	 1	 -30.0	 30.0;
	9063	 2423	 0.002809	 0.014458	 0.0	 2145	 2145	 2145	 0.0	 0.0	 1	 -30.0	 30.0;
	1589	 2423	 0.003138	 0.017502	 0.0	 1777	 1777	 1777	 0.0	 0.0	 1	 -30.0	 30.0;
	1589	 2423	 0.0032	 0.017138	 0.0	 1812	 1812	 1812	 0.0	 0.0	 1	 -30.0	 30.0;
	8618	 9277	 0.002033	 0.005273	 0.0	 5590	 5590	 5590	 0.0	 0.0	 1	 -30.0	 30.0;
	6307	 9277	 0.036066	 0.160107	 0.0	 193	 193	 193	 0.0	 0.0	 1	 -30.0	 30.0;
	1062	 13197	 0.027686	 0.04614	 0.0	 588	 588	 588	 0.0	 0.0	 1	 -30.0	 30.0;
	5855	 13197	 0.025107	 0.051372	 0.0	 553	 553	 553	 0.0	 0.0	 1	 -30.0	 30.0;
	11741	 805	 0.002479	 0.01086	 0.0	 2836	 2836	 2836	 0.0	 0.0	 1	 -30.0	 30.0;
	805	 10113	 0.013603	 0.051876	 0.0	 589	 589	 589	 0.0	 0.0	 1	 -30.0	 30.0;
	11783	 12548	 0.00176	 0.108	 0.0	 293	 293	 293	 0.0	 0.0	 1	 -30.0	 30.0;
	2269	 8081	 0.0	 0.00047	 0.0	 67208	 67208	 67208	 0.0	 0.0	 1	 -30.0	 30.0;
	2269	 7960	 0.00038	 0.00366	 0.0	 8585	 8585	 8585	 0.0	 0.0	 1	 -30.0	 30.0;
	2269	 12160	 0.00052	 0.00633	 0.0	 4974	 4974	 4974	 0.0	 0.0	 1	 -30.0	 30.0;
	11567	 12550	 0.0	 0.00051	 0.0	 61936	 61936	 61936	 0.0	 0.0	 1	 -30.0	 30.0;
	11567	 4743	 0.001599	 0.015599	 0.0	 2015	 2015	 2015	 0.0	 0.0	 1	 -30.0	 30.0;
	7752	 11567	 0.00212	 0.022349	 0.0	 1408	 1408	 1408	 0.0	 0.0	 1	 -30.0	 30.0;
	8081	 2553	 0.00034	 0.00415	 0.0	 7586	 7586	 7586	 0.0	 0.0	 1	 -30.0	 30.0;
	12080	 8081	 0.00051	 0.00646	 0.0	 4875	 4875	 4875	 0.0	 0.0	 1	 -30.0	 30.0;
	12550	 547	 0.00163	 0.015271	 0.0	 2057	 2057	 2057	 0.0	 0.0	 1	 -30.0	 30.0;
	13242	 12550	 0.002159	 0.021901	 0.0	 1436	 1436	 1436	 0.0	 0.0	 1	 -30.0	 30.0;
	8669	 1133	 0.00224	 0.015018	 0.0	 2081	 2081	 2081	 0.0	 0.0	 1	 -30.0	 30.0;
	8669	 4601	 0.004111	 0.00652	 0.0	 4099	 4099	 4099	 0.0	 0.0	 1	 -30.0	 30.0;
	8669	 4601	 0.004191	 0.006391	 0.0	 4134	 4134	 4134	 0.0	 0.0	 1	 -30.0	 30.0;
	10113	 7460	 0.00238	 0.006744	 0.0	 4417	 4417	 4417	 0.0	 0.0	 1	 -30.0	 30.0;
	8486	 579	 0.003329	 0.033129	 0.0	 949	 949	 949	 0.0	 0.0	 1	 -30.0	 30.0;
	8589	 6233	 0.005809	 0.021182	 0.0	 1439	 1439	 1439	 0.0	 0.0	 1	 -30.0	 30.0;
	8589	 6233	 0.005689	 0.021591	 0.0	 1415	 1415	 1415	 0.0	 0.0	 1	 -30.0	 30.0;
	6233	 3890	 0.00132	 0.01052	 0.0	 2980	 2980	 2980	 0.0	 0.0	 1	 -30.0	 30.0;
	6233	 367	 0.001129	 0.012329	 0.0	 2552	 2552	 2552	 0.0	 0.0	 1	 -30.0	 30.0;
	6233	 3209	 0.001569	 0.1224	 0.0	 259	 259	 259	 0.0	 0.0	 1	 -30.0	 30.0;
	4508	 3693	 0.000662	 0.036351	 0.0	 869	 869	 869	 0.0	 0.0	 1	 -30.0	 30.0;
	6330	 10854	 0.001777	 0.009107	 0.0	 3405	 3405	 3405	 0.0	 0.0	 1	 -30.0	 30.0;
	6330	 1899	 0.002967	 0.002901	 0.0	 7613	 7613	 7613	 0.0	 0.0	 1	 -30.0	 30.0;
	6330	 12203	 0.017893	 0.057479	 0.0	 525	 525	 525	 0.0	 0.0	 1	 -30.0	 30.0;
	10854	 13148	 0.000554	 0.001091	 0.0	 25816	 25816	 25816	 0.0	 0.0	 1	 -30.0	 30.0;
	10854	 11060	 0.006339	 0.022603	 0.0	 1346	 1346	 1346	 0.0	 0.0	 1	 -30.0	 30.0;
	1899	 536	 0.004174	 0.006702	 0.0	 4001	 4001	 4001	 0.0	 0.0	 1	 -30.0	 30.0;
	536	 11060	 0.009818	 0.040099	 0.0	 766	 766	 766	 0.0	 0.0	 1	 -30.0	 30.0;
	417	 9249	 0.003729	 0.01876	 0.0	 1652	 1652	 1652	 0.0	 0.0	 1	 -30.0	 30.0;
	8554	 10592	 0.000782	 0.059938	 0.0	 527	 527	 527	 0.0	 0.0	 1	 -30.0	 30.0;
	12059	 8554	 0.000769	 0.061111	 0.0	 517	 517	 517	 0.0	 0.0	 1	 -30.0	 30.0;
	1456	 9536	 0.000382	 0.019378	 0.0	 1630	 1630	 1630	 0.0	 0.0	 1	 -30.0	 30.0;
	1456	 9518	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	1589	 9988	 1.8e-05	 0.00188	 0.0	 16802	 16802	 16802	 0.0	 0.0	 1	 -30.0	 30.0;
	12501	 8782	 0.000372	 0.001223	 0.0	 24710	 24710	 24710	 0.0	 0.0	 1	 -30.0	 30.0;
	11783	 8495	 0.000809	 0.001751	 0.0	 16377	 16377	 16377	 0.0	 0.0	 1	 -30.0	 30.0;
	4920	 1236	 0.0	 0.043511	 0.0	 726	 726	 726	 0.0	 0.0	 1	 -30.0	 30.0;
	10912	 4920	 0.003529	 0.022178	 0.0	 1407	 1407	 1407	 0.0	 0.0	 1	 -30.0	 30.0;
	10912	 4920	 0.0036	 0.021711	 0.0	 1436	 1436	 1436	 0.0	 0.0	 1	 -30.0	 30.0;
	9333	 4265	 0.0	 0.000413	 0.0	 76483	 76483	 76483	 0.0	 0.0	 1	 -30.0	 30.0;
	3177	 9333	 0.047479	 0.102603	 0.0	 280	 280	 280	 0.0	 0.0	 1	 -30.0	 30.0;
	3177	 9333	 0.053727	 0.091281	 0.0	 299	 299	 299	 0.0	 0.0	 1	 -30.0	 30.0;
	8948	 9333	 0.021678	 0.045669	 0.0	 625	 625	 625	 0.0	 0.0	 1	 -30.0	 30.0;
	3177	 12372	 0.004397	 0.030678	 0.0	 1020	 1020	 1020	 0.0	 0.0	 1	 -30.0	 30.0;
	3177	 12372	 0.004314	 0.031256	 0.0	 1002	 1002	 1002	 0.0	 0.0	 1	 -30.0	 30.0;
	3177	 11392	 0.008347	 0.055512	 0.0	 563	 563	 563	 0.0	 0.0	 1	 -30.0	 30.0;
	3177	 3860	 0.006223	 0.039744	 0.0	 786	 786	 786	 0.0	 0.0	 1	 -30.0	 30.0;
	12184	 3177	 0.006124	 0.041686	 0.0	 750	 750	 750	 0.0	 0.0	 1	 -30.0	 30.0;
	12184	 3177	 0.006942	 0.040851	 0.0	 763	 763	 763	 0.0	 0.0	 1	 -30.0	 30.0;
	5962	 8406	 0.019248	 0.039041	 0.0	 726	 726	 726	 0.0	 0.0	 1	 -30.0	 30.0;
	10449	 5962	 0.015719	 0.04943	 0.0	 609	 609	 609	 0.0	 0.0	 1	 -30.0	 30.0;
	8068	 1716	 0.00296	 0.011871	 0.0	 2582	 2582	 2582	 0.0	 0.0	 1	 -30.0	 30.0;
	8068	 13431	 0.01328	 0.04144	 0.0	 726	 726	 726	 0.0	 0.0	 1	 -30.0	 30.0;
	3935	 10451	 0.00736	 0.033222	 0.0	 929	 929	 929	 0.0	 0.0	 1	 -30.0	 30.0;
	3935	 10451	 0.007502	 0.032529	 0.0	 947	 947	 947	 0.0	 0.0	 1	 -30.0	 30.0;
	2386	 3935	 0.00192	 0.02576	 0.0	 1223	 1223	 1223	 0.0	 0.0	 1	 -30.0	 30.0;
	2386	 3935	 0.002169	 0.02524	 0.0	 1247	 1247	 1247	 0.0	 0.0	 1	 -30.0	 30.0;
	3935	 12527	 0.00656	 0.017071	 0.0	 1728	 1728	 1728	 0.0	 0.0	 1	 -30.0	 30.0;
	3935	 3938	 0.002662	 0.007471	 0.0	 3983	 3983	 3983	 0.0	 0.0	 1	 -30.0	 30.0;
	3935	 4660	 0.003191	 0.009062	 0.0	 3288	 3288	 3288	 0.0	 0.0	 1	 -30.0	 30.0;
	10103	 12831	 0.00981	 0.057298	 0.0	 544	 544	 544	 0.0	 0.0	 1	 -30.0	 30.0;
	4595	 9295	 0.008342	 0.037031	 0.0	 833	 833	 833	 0.0	 0.0	 1	 -30.0	 30.0;
	2074	 9295	 0.0086	 0.039791	 0.0	 776	 776	 776	 0.0	 0.0	 1	 -30.0	 30.0;
	2409	 1593	 0.0	 0.00046	 0.0	 68669	 68669	 68669	 0.0	 0.0	 1	 -30.0	 30.0;
	8845	 2409	 0.00055	 0.00685	 0.0	 4597	 4597	 4597	 0.0	 0.0	 1	 -30.0	 30.0;
	11660	 1593	 0.00054	 0.00699	 0.0	 4506	 4506	 4506	 0.0	 0.0	 1	 -30.0	 30.0;
	13039	 103	 0.0056	 0.052889	 0.0	 594	 594	 594	 0.0	 0.0	 1	 -30.0	 30.0;
	13039	 8664	 0.006058	 0.023591	 0.0	 1297	 1297	 1297	 0.0	 0.0	 1	 -30.0	 30.0;
	13039	 8664	 0.0054	 0.026729	 0.0	 1159	 1159	 1159	 0.0	 0.0	 1	 -30.0	 30.0;
	13039	 12722	 0.00168	 0.01188	 0.0	 2633	 2633	 2633	 0.0	 0.0	 1	 -30.0	 30.0;
	13039	 13317	 0.003178	 0.028658	 0.0	 1096	 1096	 1096	 0.0	 0.0	 1	 -30.0	 30.0;
	13039	 7579	 0.003178	 0.028542	 0.0	 1100	 1100	 1100	 0.0	 0.0	 1	 -30.0	 30.0;
	7246	 9430	 0.00068	 0.004449	 0.0	 7019	 7019	 7019	 0.0	 0.0	 1	 -30.0	 30.0;
	7246	 5049	 0.00076	 0.004818	 0.0	 6477	 6477	 6477	 0.0	 0.0	 1	 -30.0	 30.0;
	4019	 2542	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	4019	 8589	 9e-06	 0.000222	 0.0	 142169	 142169	 142169	 0.0	 0.0	 1	 -30.0	 30.0;
	7891	 8589	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	10902	 8589	 1.8e-05	 0.004329	 0.0	 7297	 7297	 7297	 0.0	 0.0	 1	 -30.0	 30.0;
	8813	 7688	 0.001831	 0.001698	 0.0	 12650	 12650	 12650	 0.0	 0.0	 1	 -30.0	 30.0;
	8813	 7688	 0.002209	 0.001471	 0.0	 11902	 11902	 11902	 0.0	 0.0	 1	 -30.0	 30.0;
	1848	 11394	 0.017653	 0.070289	 0.0	 436	 436	 436	 0.0	 0.0	 1	 -30.0	 30.0;
	6070	 11394	 0.013231	 0.042207	 0.0	 715	 715	 715	 0.0	 0.0	 1	 -30.0	 30.0;
	6070	 11394	 0.013479	 0.041331	 0.0	 727	 727	 727	 0.0	 0.0	 1	 -30.0	 30.0;
	4008	 11394	 0.013934	 0.055702	 0.0	 551	 551	 551	 0.0	 0.0	 1	 -30.0	 30.0;
	6190	 8785	 0.000537	 0.001471	 0.0	 20172	 20172	 20172	 0.0	 0.0	 1	 -30.0	 30.0;
	8785	 7145	 0.009967	 0.048959	 0.0	 633	 633	 633	 0.0	 0.0	 1	 -30.0	 30.0;
	8785	 13524	 0.030612	 0.055058	 0.0	 502	 502	 502	 0.0	 0.0	 1	 -30.0	 30.0;
	8785	 13524	 0.031207	 0.053934	 0.0	 507	 507	 507	 0.0	 0.0	 1	 -30.0	 30.0;
	8827	 8785	 0.01314	 0.040579	 0.0	 741	 741	 741	 0.0	 0.0	 1	 -30.0	 30.0;
	8827	 8785	 0.012851	 0.03757	 0.0	 796	 796	 796	 0.0	 0.0	 1	 -30.0	 30.0;
	8785	 10245	 0.006901	 0.021174	 0.0	 1419	 1419	 1419	 0.0	 0.0	 1	 -30.0	 30.0;
	8785	 10245	 0.007653	 0.01924	 0.0	 1526	 1526	 1526	 0.0	 0.0	 1	 -30.0	 30.0;
	10694	 8155	 0.008982	 0.038462	 0.0	 800	 800	 800	 0.0	 0.0	 1	 -30.0	 30.0;
	8155	 11965	 0.009151	 0.037649	 0.0	 816	 816	 816	 0.0	 0.0	 1	 -30.0	 30.0;
	8155	 1456	 0.004258	 0.03952	 0.0	 795	 795	 795	 0.0	 0.0	 1	 -30.0	 30.0;
	3753	 8155	 0.003489	 0.0264	 0.0	 1187	 1187	 1187	 0.0	 0.0	 1	 -30.0	 30.0;
	8155	 3287	 0.003849	 0.05232	 0.0	 603	 603	 603	 0.0	 0.0	 1	 -30.0	 30.0;
	2834	 6035	 0.032669	 0.080273	 0.0	 365	 365	 365	 0.0	 0.0	 1	 -30.0	 30.0;
	2697	 6035	 0.004901	 0.014967	 0.0	 2006	 2006	 2006	 0.0	 0.0	 1	 -30.0	 30.0;
	465	 8406	 0.000562	 0.001058	 0.0	 26367	 26367	 26367	 0.0	 0.0	 1	 -30.0	 30.0;
	12369	 1112	 0.0	 0.00045	 0.0	 70195	 70195	 70195	 0.0	 0.0	 1	 -30.0	 30.0;
	12369	 12160	 0.001	 0.01169	 0.0	 2693	 2693	 2693	 0.0	 0.0	 1	 -30.0	 30.0;
	1112	 12080	 0.00098	 0.01192	 0.0	 2642	 2642	 2642	 0.0	 0.0	 1	 -30.0	 30.0;
	9653	 11060	 0.002339	 0.006223	 0.0	 4752	 4752	 4752	 0.0	 0.0	 1	 -30.0	 30.0;
	9653	 11060	 0.002388	 0.006091	 0.0	 4829	 4829	 4829	 0.0	 0.0	 1	 -30.0	 30.0;
	600	 9653	 0.000504	 0.001207	 0.0	 24150	 24150	 24150	 0.0	 0.0	 1	 -30.0	 30.0;
	8406	 11060	 0.00105	 0.007959	 0.0	 3935	 3935	 3935	 0.0	 0.0	 1	 -30.0	 30.0;
	8406	 11060	 0.001033	 0.007372	 0.0	 4244	 4244	 4244	 0.0	 0.0	 1	 -30.0	 30.0;
	8406	 3794	 0.018752	 0.042339	 0.0	 683	 683	 683	 0.0	 0.0	 1	 -30.0	 30.0;
	8406	 3794	 0.018339	 0.039231	 0.0	 730	 730	 730	 0.0	 0.0	 1	 -30.0	 30.0;
	2834	 10113	 0.036793	 0.081719	 0.0	 353	 353	 353	 0.0	 0.0	 1	 -30.0	 30.0;
	2834	 12501	 0.003702	 0.015132	 0.0	 2028	 2028	 2028	 0.0	 0.0	 1	 -30.0	 30.0;
	3555	 2834	 0.00124	 0.007314	 0.0	 4258	 4258	 4258	 0.0	 0.0	 1	 -30.0	 30.0;
	766	 9851	 0.002329	 0.00356	 0.0	 7426	 7426	 7426	 0.0	 0.0	 1	 -30.0	 30.0;
	766	 9851	 0.002378	 0.00348	 0.0	 7495	 7495	 7495	 0.0	 0.0	 1	 -30.0	 30.0;
	766	 9851	 0.00212	 0.003951	 0.0	 7045	 7045	 7045	 0.0	 0.0	 1	 -30.0	 30.0;
	766	 10948	 0.001951	 0.003791	 0.0	 7409	 7409	 7409	 0.0	 0.0	 1	 -30.0	 30.0;
	103	 11538	 0.002542	 0.01472	 0.0	 2115	 2115	 2115	 0.0	 0.0	 1	 -30.0	 30.0;
	2386	 10306	 0.003262	 0.024151	 0.0	 1297	 1297	 1297	 0.0	 0.0	 1	 -30.0	 30.0;
	13611	 7881	 0.0036	 0.01548	 0.0	 1988	 1988	 1988	 0.0	 0.0	 1	 -30.0	 30.0;
	13611	 7881	 0.00352	 0.014329	 0.0	 2141	 2141	 2141	 0.0	 0.0	 1	 -30.0	 30.0;
	2682	 6437	 0.002591	 0.014418	 0.0	 2157	 2157	 2157	 0.0	 0.0	 1	 -30.0	 30.0;
	5180	 2682	 0.001071	 0.003058	 0.0	 9749	 9749	 9749	 0.0	 0.0	 1	 -30.0	 30.0;
	5180	 525	 9.8e-05	 0.000222	 0.0	 130167	 130167	 130167	 0.0	 0.0	 1	 -30.0	 30.0;
	5180	 1887	 0.017458	 0.052129	 0.0	 575	 575	 575	 0.0	 0.0	 1	 -30.0	 30.0;
	10694	 12439	 0.00136	 0.00216	 0.0	 12376	 12376	 12376	 0.0	 0.0	 1	 -30.0	 30.0;
	11965	 12439	 0.001391	 0.00212	 0.0	 12458	 12458	 12458	 0.0	 0.0	 1	 -30.0	 30.0;
	9365	 13431	 0.005858	 0.016591	 0.0	 1796	 1796	 1796	 0.0	 0.0	 1	 -30.0	 30.0;
	1259	 12831	 0.004562	 0.011653	 0.0	 2525	 2525	 2525	 0.0	 0.0	 1	 -30.0	 30.0;
	1259	 6983	 0.030868	 0.064174	 0.0	 444	 444	 444	 0.0	 0.0	 1	 -30.0	 30.0;
	4743	 547	 0.0	 0.000521	 0.0	 60629	 60629	 60629	 0.0	 0.0	 1	 -30.0	 30.0;
	3408	 1456	 0.005929	 0.053271	 0.0	 590	 590	 590	 0.0	 0.0	 1	 -30.0	 30.0;
	3408	 445	 0.00664	 0.040849	 0.0	 764	 764	 764	 0.0	 0.0	 1	 -30.0	 30.0;
	3408	 4601	 0.00968	 0.049382	 0.0	 628	 628	 628	 0.0	 0.0	 1	 -30.0	 30.0;
	8486	 6882	 9.8e-05	 0.000222	 0.0	 130167	 130167	 130167	 0.0	 0.0	 1	 -30.0	 30.0;
	8486	 103	 0.00044	 0.004489	 0.0	 7004	 7004	 7004	 0.0	 0.0	 1	 -30.0	 30.0;
	8486	 5733	 0.01064	 0.043751	 0.0	 702	 702	 702	 0.0	 0.0	 1	 -30.0	 30.0;
	8486	 5733	 0.0104	 0.040511	 0.0	 756	 756	 756	 0.0	 0.0	 1	 -30.0	 30.0;
	7579	 8486	 0.0024	 0.025498	 0.0	 1234	 1234	 1234	 0.0	 0.0	 1	 -30.0	 30.0;
	6264	 1714	 0.00264	 0.01412	 0.0	 2199	 2199	 2199	 0.0	 0.0	 1	 -30.0	 30.0;
	694	 8968	 0.000609	 0.03944	 0.0	 962	 962	 962	 0.0	 0.0	 1	 -30.0	 30.0;
	5815	 694	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	694	 9851	 0.001182	 0.003018	 0.0	 9746	 9746	 9746	 0.0	 0.0	 1	 -30.0	 30.0;
	694	 9851	 0.0012	 0.002951	 0.0	 9916	 9916	 9916	 0.0	 0.0	 1	 -30.0	 30.0;
	694	 9851	 0.001071	 0.003351	 0.0	 8979	 8979	 8979	 0.0	 0.0	 1	 -30.0	 30.0;
	694	 10336	 0.001031	 0.01544	 0.0	 2042	 2042	 2042	 0.0	 0.0	 1	 -30.0	 30.0;
	694	 520	 0.001009	 0.015738	 0.0	 2003	 2003	 2003	 0.0	 0.0	 1	 -30.0	 30.0;
	694	 2388	 0.000991	 0.01604	 0.0	 1966	 1966	 1966	 0.0	 0.0	 1	 -30.0	 30.0;
	9063	 10706	 0.003898	 0.008862	 0.0	 3263	 3263	 3263	 0.0	 0.0	 1	 -30.0	 30.0;
	9063	 10706	 0.003818	 0.009031	 0.0	 3222	 3222	 3222	 0.0	 0.0	 1	 -30.0	 30.0;
	939	 464	 0.003831	 0.012502	 0.0	 2416	 2416	 2416	 0.0	 0.0	 1	 -30.0	 30.0;
	8845	 11660	 0.0	 0.00051	 0.0	 61936	 61936	 61936	 0.0	 0.0	 1	 -30.0	 30.0;
	8768	 11660	 0.00127	 0.0132	 0.0	 2382	 2382	 2382	 0.0	 0.0	 1	 -30.0	 30.0;
	10912	 9802	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	10912	 11228	 0.001338	 0.011209	 0.0	 2799	 2799	 2799	 0.0	 0.0	 1	 -30.0	 30.0;
	10912	 7432	 0.004222	 0.030062	 0.0	 1041	 1041	 1041	 0.0	 0.0	 1	 -30.0	 30.0;
	13558	 10912	 0.001182	 0.0104	 0.0	 3018	 3018	 3018	 0.0	 0.0	 1	 -30.0	 30.0;
	9802	 5649	 9e-06	 0.000222	 0.0	 142169	 142169	 142169	 0.0	 0.0	 1	 -30.0	 30.0;
	9802	 7432	 0.004138	 0.03064	 0.0	 1022	 1022	 1022	 0.0	 0.0	 1	 -30.0	 30.0;
	5649	 7432	 0.004049	 0.031209	 0.0	 1004	 1004	 1004	 0.0	 0.0	 1	 -30.0	 30.0;
	1062	 5855	 0.022603	 0.051959	 0.0	 558	 558	 558	 0.0	 0.0	 1	 -30.0	 30.0;
	12289	 1062	 0.013636	 0.032041	 0.0	 908	 908	 908	 0.0	 0.0	 1	 -30.0	 30.0;
	12527	 4661	 0.00228	 0.009222	 0.0	 3326	 3326	 3326	 0.0	 0.0	 1	 -30.0	 30.0;
	3938	 4661	 0.002471	 0.010302	 0.0	 2982	 2982	 2982	 0.0	 0.0	 1	 -30.0	 30.0;
	4660	 4661	 0.001831	 0.007378	 0.0	 4156	 4156	 4156	 0.0	 0.0	 1	 -30.0	 30.0;
	12372	 6307	 0.006843	 0.049248	 0.0	 636	 636	 636	 0.0	 0.0	 1	 -30.0	 30.0;
	12372	 6307	 0.006686	 0.045603	 0.0	 686	 686	 686	 0.0	 0.0	 1	 -30.0	 30.0;
	3954	 2815	 0.004102	 0.011529	 0.0	 2582	 2582	 2582	 0.0	 0.0	 1	 -30.0	 30.0;
	3954	 2815	 0.004182	 0.01128	 0.0	 2626	 2626	 2626	 0.0	 0.0	 1	 -30.0	 30.0;
	2733	 3001	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	11997	 2733	 0.003649	 0.0122	 0.0	 2481	 2481	 2481	 0.0	 0.0	 1	 -30.0	 30.0;
	11997	 2733	 0.00372	 0.011938	 0.0	 2527	 2527	 2527	 0.0	 0.0	 1	 -30.0	 30.0;
	2733	 8098	 0.005031	 0.028102	 0.0	 1107	 1107	 1107	 0.0	 0.0	 1	 -30.0	 30.0;
	2733	 8098	 0.005129	 0.02752	 0.0	 1129	 1129	 1129	 0.0	 0.0	 1	 -30.0	 30.0;
	2733	 11519	 0.005218	 0.026951	 0.0	 1151	 1151	 1151	 0.0	 0.0	 1	 -30.0	 30.0;
	6480	 5049	 0.00288	 0.01992	 0.0	 1570	 1570	 1570	 0.0	 0.0	 1	 -30.0	 30.0;
	6480	 5049	 0.003262	 0.01952	 0.0	 1597	 1597	 1597	 0.0	 0.0	 1	 -30.0	 30.0;
	9064	 1589	 0.00956	 0.061022	 0.0	 512	 512	 512	 0.0	 0.0	 1	 -30.0	 30.0;
	9064	 3954	 0.005382	 0.033911	 0.0	 920	 920	 920	 0.0	 0.0	 1	 -30.0	 30.0;
	9064	 3954	 0.005271	 0.034569	 0.0	 904	 904	 904	 0.0	 0.0	 1	 -30.0	 30.0;
	9064	 9080	 0.004102	 0.023018	 0.0	 1352	 1352	 1352	 0.0	 0.0	 1	 -30.0	 30.0;
	2553	 7960	 0.0	 0.00052	 0.0	 60745	 60745	 60745	 0.0	 0.0	 1	 -30.0	 30.0;
	1456	 7099	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	1456	 4601	 0.011631	 0.094591	 0.0	 332	 332	 332	 0.0	 0.0	 1	 -30.0	 30.0;
	3753	 1456	 0.0012	 0.008769	 0.0	 3569	 3569	 3569	 0.0	 0.0	 1	 -30.0	 30.0;
	1456	 13414	 0.001218	 0.008582	 0.0	 3645	 3645	 3645	 0.0	 0.0	 1	 -30.0	 30.0;
	10451	 12642	 0.002689	 0.013818	 0.0	 2244	 2244	 2244	 0.0	 0.0	 1	 -30.0	 30.0;
	3794	 12203	 0.005	 0.008934	 0.0	 3086	 3086	 3086	 0.0	 0.0	 1	 -30.0	 30.0;
	11313	 199	 0.0	 0.000531	 0.0	 59487	 59487	 59487	 0.0	 0.0	 1	 -30.0	 30.0;
	11313	 7752	 0.001281	 0.0158	 0.0	 1993	 1993	 1993	 0.0	 0.0	 1	 -30.0	 30.0;
	199	 13242	 0.00125	 0.016099	 0.0	 1957	 1957	 1957	 0.0	 0.0	 1	 -30.0	 30.0;
	1848	 6983	 0.010058	 0.048	 0.0	 645	 645	 645	 0.0	 0.0	 1	 -30.0	 30.0;
	1848	 6983	 0.010248	 0.047	 0.0	 657	 657	 657	 0.0	 0.0	 1	 -30.0	 30.0;
	1848	 4008	 0.004314	 0.024537	 0.0	 1268	 1268	 1268	 0.0	 0.0	 1	 -30.0	 30.0;
	2386	 4817	 0.010791	 0.042151	 0.0	 726	 726	 726	 0.0	 0.0	 1	 -30.0	 30.0;
	507	 8951	 0.0006	 0.040218	 0.0	 786	 786	 786	 0.0	 0.0	 1	 -30.0	 30.0;
	367	 12734	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	4653	 8261	 0.0	 0.00053	 0.0	 59599	 59599	 59599	 0.0	 0.0	 1	 -30.0	 30.0;
	4653	 6366	 0.0	 0.00054	 0.0	 58496	 58496	 58496	 0.0	 0.0	 1	 -30.0	 30.0;
	2386	 13252	 0.00196	 0.010249	 0.0	 3028	 3028	 3028	 0.0	 0.0	 1	 -30.0	 30.0;
	2386	 2165	 0.002182	 0.010498	 0.0	 2946	 2946	 2946	 0.0	 0.0	 1	 -30.0	 30.0;
	8664	 12958	 0.000582	 0.040991	 0.0	 771	 771	 771	 0.0	 0.0	 1	 -30.0	 30.0;
	8664	 8239	 0.000569	 0.04176	 0.0	 757	 757	 757	 0.0	 0.0	 1	 -30.0	 30.0;
	2074	 4595	 0.003818	 0.013209	 0.0	 2298	 2298	 2298	 0.0	 0.0	 1	 -30.0	 30.0;
	8664	 9249	 0.00428	 0.023511	 0.0	 1322	 1322	 1322	 0.0	 0.0	 1	 -30.0	 30.0;
	8664	 9249	 0.004182	 0.021769	 0.0	 1425	 1425	 1425	 0.0	 0.0	 1	 -30.0	 30.0;
	2792	 10205	 0.0	 0.0005	 0.0	 75878	 75878	 75878	 0.0	 0.0	 1	 -30.0	 30.0;
	2792	 12160	 0.00114	 0.01661	 0.0	 1898	 1898	 1898	 0.0	 0.0	 1	 -30.0	 30.0;
	6333	 6237	 0.0	 0.000539	 0.0	 58604	 58604	 58604	 0.0	 0.0	 1	 -30.0	 30.0;
	6333	 113	 0.00119	 0.014081	 0.0	 2236	 2236	 2236	 0.0	 0.0	 1	 -30.0	 30.0;
	10205	 12080	 0.00117	 0.01626	 0.0	 2328	 2328	 2328	 0.0	 0.0	 1	 -30.0	 30.0;
	6237	 48	 0.00106	 0.01595	 0.0	 1977	 1977	 1977	 0.0	 0.0	 1	 -30.0	 30.0;
	6307	 8804	 0.018058	 0.065719	 0.0	 464	 464	 464	 0.0	 0.0	 1	 -30.0	 30.0;
	6307	 8948	 0.012826	 0.025058	 0.0	 1123	 1123	 1123	 0.0	 0.0	 1	 -30.0	 30.0;
	6307	 8948	 0.013331	 0.024	 0.0	 1151	 1151	 1151	 0.0	 0.0	 1	 -30.0	 30.0;
	13252	 2165	 0.001089	 0.003151	 0.0	 9475	 9475	 9475	 0.0	 0.0	 1	 -30.0	 30.0;
	8418	 3479	 9.8e-05	 0.000222	 0.0	 130167	 130167	 130167	 0.0	 0.0	 1	 -30.0	 30.0;
	507	 1804	 0.000631	 0.054471	 0.0	 580	 580	 580	 0.0	 0.0	 1	 -30.0	 30.0;
	507	 2998	 0.000622	 0.055489	 0.0	 570	 570	 570	 0.0	 0.0	 1	 -30.0	 30.0;
	507	 13166	 0.0006	 0.051382	 0.0	 615	 615	 615	 0.0	 0.0	 1	 -30.0	 30.0;
	6070	 6983	 0.017702	 0.064331	 0.0	 474	 474	 474	 0.0	 0.0	 1	 -30.0	 30.0;
	6070	 2552	 0.012314	 0.04924	 0.0	 623	 623	 623	 0.0	 0.0	 1	 -30.0	 30.0;
	7059	 12352	 0.001223	 0.001248	 0.0	 18078	 18078	 18078	 0.0	 0.0	 1	 -30.0	 30.0;
	7725	 12352	 0.001471	 0.00481	 0.0	 6280	 6280	 6280	 0.0	 0.0	 1	 -30.0	 30.0;
	8804	 12352	 0.011521	 0.03138	 0.0	 945	 945	 945	 0.0	 0.0	 1	 -30.0	 30.0;
	11783	 11627	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	11783	 8990	 0.000289	 0.00056	 0.0	 50125	 50125	 50125	 0.0	 0.0	 1	 -30.0	 30.0;
	5835	 4914	 0.00034	 0.01805	 0.0	 1750	 1750	 1750	 0.0	 0.0	 1	 -30.0	 30.0;
	10953	 3890	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	3044	 9782	 0.00035	 0.01766	 0.0	 1789	 1789	 1789	 0.0	 0.0	 1	 -30.0	 30.0;
	13244	 6183	 0.00035	 0.01728	 0.0	 1828	 1828	 1828	 0.0	 0.0	 1	 -30.0	 30.0;
	7412	 12253	 0.00031	 0.01958	 0.0	 1938	 1938	 1938	 0.0	 0.0	 1	 -30.0	 30.0;
	10651	 4914	 0.00031	 0.01997	 0.0	 1582	 1582	 1582	 0.0	 0.0	 1	 -30.0	 30.0;
	9404	 4914	 0.0003	 0.02035	 0.0	 1553	 1553	 1553	 0.0	 0.0	 1	 -30.0	 30.0;
	8583	 8758	 0.00016	 0.0025	 0.0	 12610	 12610	 12610	 0.0	 0.0	 1	 -30.0	 30.0;
	7000	 4914	 0.00029	 0.02074	 0.0	 1523	 1523	 1523	 0.0	 0.0	 1	 -30.0	 30.0;
	11827	 12253	 0.00029	 0.0192	 0.0	 1645	 1645	 1645	 0.0	 0.0	 1	 -30.0	 30.0;
	12504	 12253	 0.00033	 0.01882	 0.0	 1679	 1679	 1679	 0.0	 0.0	 1	 -30.0	 30.0;
	9782	 6183	 0.0	 0.00049	 0.0	 64464	 64464	 64464	 0.0	 0.0	 1	 -30.0	 30.0;
	6934	 9782	 0.0	 0.00048	 0.0	 65807	 65807	 65807	 0.0	 0.0	 1	 -30.0	 30.0;
	11543	 6183	 0.0	 0.00047	 0.0	 67208	 67208	 67208	 0.0	 0.0	 1	 -30.0	 30.0;
	4914	 8593	 0.0	 0.00046	 0.0	 68669	 68669	 68669	 0.0	 0.0	 1	 -30.0	 30.0;
	4914	 616	 0.0	 0.00045	 0.0	 70195	 70195	 70195	 0.0	 0.0	 1	 -30.0	 30.0;
	4914	 13170	 0.0	 0.00051	 0.0	 61936	 61936	 61936	 0.0	 0.0	 1	 -30.0	 30.0;
	12253	 11543	 0.0	 0.00052	 0.0	 60745	 60745	 60745	 0.0	 0.0	 1	 -30.0	 30.0;
	12253	 6934	 0.0	 0.00053	 0.0	 59599	 59599	 59599	 0.0	 0.0	 1	 -30.0	 30.0;
	12253	 13170	 0.0	 0.00054	 0.0	 58496	 58496	 58496	 0.0	 0.0	 1	 -30.0	 30.0;
	8593	 8872	 0.0	 0.0005	 0.0	 63175	 63175	 63175	 0.0	 0.0	 1	 -30.0	 30.0;
	8872	 11543	 0.0	 0.00049	 0.0	 64464	 64464	 64464	 0.0	 0.0	 1	 -30.0	 30.0;
	8872	 5998	 0.00028	 0.00403	 0.0	 7820	 7820	 7820	 0.0	 0.0	 1	 -30.0	 30.0;
	9167	 8872	 0.00021	 0.00396	 0.0	 7966	 7966	 7966	 0.0	 0.0	 1	 -30.0	 30.0;
	616	 4211	 0.0	 0.00048	 0.0	 65807	 65807	 65807	 0.0	 0.0	 1	 -30.0	 30.0;
	4211	 6934	 0.0	 0.00047	 0.0	 67208	 67208	 67208	 0.0	 0.0	 1	 -30.0	 30.0;
	4211	 8583	 0.00029	 0.00394	 0.0	 7996	 7996	 7996	 0.0	 0.0	 1	 -30.0	 30.0;
	6578	 4211	 0.0002	 0.00404	 0.0	 7810	 7810	 7810	 0.0	 0.0	 1	 -30.0	 30.0;
	3890	 367	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	367	 818	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	12527	 3938	 0.004471	 0.020791	 0.0	 1486	 1486	 1486	 0.0	 0.0	 1	 -30.0	 30.0;
	12527	 4660	 0.002791	 0.01132	 0.0	 2710	 2710	 2710	 0.0	 0.0	 1	 -30.0	 30.0;
	9851	 12368	 0.000822	 0.001649	 0.0	 17144	 17144	 17144	 0.0	 0.0	 1	 -30.0	 30.0;
	9851	 12368	 0.0008	 0.00168	 0.0	 16976	 16976	 16976	 0.0	 0.0	 1	 -30.0	 30.0;
	9851	 12368	 0.000782	 0.00156	 0.0	 18102	 18102	 18102	 0.0	 0.0	 1	 -30.0	 30.0;
	548	 464	 0.00432	 0.012662	 0.0	 2362	 2362	 2362	 0.0	 0.0	 1	 -30.0	 30.0;
	548	 464	 0.003849	 0.014351	 0.0	 2126	 2126	 2126	 0.0	 0.0	 1	 -30.0	 30.0;
	1589	 3666	 0.001418	 0.004618	 0.0	 6539	 6539	 6539	 0.0	 0.0	 1	 -30.0	 30.0;
	1589	 10661	 0.001689	 0.011631	 0.0	 2688	 2688	 2688	 0.0	 0.0	 1	 -30.0	 30.0;
	1589	 9080	 0.005991	 0.03832	 0.0	 815	 815	 815	 0.0	 0.0	 1	 -30.0	 30.0;
	13611	 2763	 0.001169	 0.007098	 0.0	 4392	 4392	 4392	 0.0	 0.0	 1	 -30.0	 30.0;
	10948	 2763	 0.0012	 0.00696	 0.0	 4473	 4473	 4473	 0.0	 0.0	 1	 -30.0	 30.0;
	6483	 13524	 0.030066	 0.046289	 0.0	 573	 573	 573	 0.0	 0.0	 1	 -30.0	 30.0;
	6483	 13524	 0.026793	 0.052463	 0.0	 537	 537	 537	 0.0	 0.0	 1	 -30.0	 30.0;
	11331	 6483	 0.023413	 0.057397	 0.0	 510	 510	 510	 0.0	 0.0	 1	 -30.0	 30.0;
	8139	 7810	 0.001631	 0.00832	 0.0	 3726	 3726	 3726	 0.0	 0.0	 1	 -30.0	 30.0;
	8813	 6506	 0.012569	 0.04732	 0.0	 646	 646	 646	 0.0	 0.0	 1	 -30.0	 30.0;
	8813	 6506	 0.012311	 0.048231	 0.0	 635	 635	 635	 0.0	 0.0	 1	 -30.0	 30.0;
	11790	 9541	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	7432	 11790	 0.000982	 0.004751	 0.0	 6511	 6511	 6511	 0.0	 0.0	 1	 -30.0	 30.0;
	7442	 1781	 0.00144	 0.12	 0.0	 264	 264	 264	 0.0	 0.0	 1	 -30.0	 30.0;
	507	 7810	 0.001249	 0.0064	 0.0	 4845	 4845	 4845	 0.0	 0.0	 1	 -30.0	 30.0;
	507	 7810	 0.00112	 0.007249	 0.0	 4307	 4307	 4307	 0.0	 0.0	 1	 -30.0	 30.0;
	7752	 13242	 0.0	 0.0005	 0.0	 63175	 63175	 63175	 0.0	 0.0	 1	 -30.0	 30.0;
	13608	 12831	 0.022843	 0.098893	 0.0	 312	 312	 312	 0.0	 0.0	 1	 -30.0	 30.0;
	12831	 6983	 0.034909	 0.072893	 0.0	 391	 391	 391	 0.0	 0.0	 1	 -30.0	 30.0;
	11228	 558	 0.00188	 0.092222	 0.0	 343	 343	 343	 0.0	 0.0	 1	 -30.0	 30.0;
	11228	 1738	 0.00184	 0.093991	 0.0	 337	 337	 337	 0.0	 0.0	 1	 -30.0	 30.0;
	11228	 5890	 0.0018	 0.09576	 0.0	 330	 330	 330	 0.0	 0.0	 1	 -30.0	 30.0;
	8554	 11228	 0.00132	 0.01088	 0.0	 2883	 2883	 2883	 0.0	 0.0	 1	 -30.0	 30.0;
	8827	 2697	 0.01924	 0.056603	 0.0	 529	 529	 529	 0.0	 0.0	 1	 -30.0	 30.0;
	8827	 2697	 0.017124	 0.064149	 0.0	 476	 476	 476	 0.0	 0.0	 1	 -30.0	 30.0;
	6264	 5106	 9.8e-05	 0.000222	 0.0	 130167	 130167	 130167	 0.0	 0.0	 1	 -30.0	 30.0;
	6264	 6959	 0.006889	 0.03404	 0.0	 910	 910	 910	 0.0	 0.0	 1	 -30.0	 30.0;
	6264	 6959	 0.007018	 0.033329	 0.0	 928	 928	 928	 0.0	 0.0	 1	 -30.0	 30.0;
	6264	 11685	 0.006169	 0.035689	 0.0	 873	 873	 873	 0.0	 0.0	 1	 -30.0	 30.0;
	6264	 11685	 0.00628	 0.034929	 0.0	 891	 891	 891	 0.0	 0.0	 1	 -30.0	 30.0;
	6264	 12180	 0.004271	 0.026418	 0.0	 1181	 1181	 1181	 0.0	 0.0	 1	 -30.0	 30.0;
	6264	 12180	 0.00436	 0.02588	 0.0	 1204	 1204	 1204	 0.0	 0.0	 1	 -30.0	 30.0;
	6264	 12180	 0.00444	 0.025338	 0.0	 1228	 1228	 1228	 0.0	 0.0	 1	 -30.0	 30.0;
	5733	 1887	 0.00852	 0.02444	 0.0	 1221	 1221	 1221	 0.0	 0.0	 1	 -30.0	 30.0;
	12722	 65	 0.002671	 0.018929	 0.0	 1653	 1653	 1653	 0.0	 0.0	 1	 -30.0	 30.0;
	11462	 4886	 0.0	 0.00046	 0.0	 68669	 68669	 68669	 0.0	 0.0	 1	 -30.0	 30.0;
	11462	 9879	 0.0	 0.00045	 0.0	 70195	 70195	 70195	 0.0	 0.0	 1	 -30.0	 30.0;
	8768	 4886	 0.0	 0.00051	 0.0	 61936	 61936	 61936	 0.0	 0.0	 1	 -30.0	 30.0;
	8768	 9879	 0.0	 0.00052	 0.0	 60745	 60745	 60745	 0.0	 0.0	 1	 -30.0	 30.0;
	3666	 10661	 0.000329	 0.000902	 0.0	 32900	 32900	 32900	 0.0	 0.0	 1	 -30.0	 30.0;
	12180	 5462	 0.00068	 0.050351	 0.0	 628	 628	 628	 0.0	 0.0	 1	 -30.0	 30.0;
	4950	 6959	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	1927	 5125	 0.0	 0.00049	 0.0	 64464	 64464	 64464	 0.0	 0.0	 1	 -30.0	 30.0;
	1927	 1508	 0.00212	 0.022531	 0.0	 1396	 1396	 1396	 0.0	 0.0	 1	 -30.0	 30.0;
	1927	 113	 0.000919	 0.012789	 0.0	 2464	 2464	 2464	 0.0	 0.0	 1	 -30.0	 30.0;
	5125	 5693	 0.002159	 0.02206	 0.0	 1426	 1426	 1426	 0.0	 0.0	 1	 -30.0	 30.0;
	5125	 48	 0.00094	 0.012531	 0.0	 2514	 2514	 2514	 0.0	 0.0	 1	 -30.0	 30.0;
	279	 7432	 0.00032	 0.014102	 0.0	 2240	 2240	 2240	 0.0	 0.0	 1	 -30.0	 30.0;
	7103	 7432	 0.000329	 0.0138	 0.0	 2289	 2289	 2289	 0.0	 0.0	 1	 -30.0	 30.0;
	5437	 7432	 0.000329	 0.013502	 0.0	 2339	 2339	 2339	 0.0	 0.0	 1	 -30.0	 30.0;
	9249	 792	 0.005818	 0.02396	 0.0	 1282	 1282	 1282	 0.0	 0.0	 1	 -30.0	 30.0;
	9249	 792	 0.005942	 0.023462	 0.0	 1306	 1306	 1306	 0.0	 0.0	 1	 -30.0	 30.0;
	8554	 9810	 0.000671	 0.001871	 0.0	 15892	 15892	 15892	 0.0	 0.0	 1	 -30.0	 30.0;
	7128	 9810	 0.0	 0.001791	 0.0	 17637	 17637	 17637	 0.0	 0.0	 1	 -30.0	 30.0;
	8554	 5141	 0.002249	 0.003471	 0.0	 7638	 7638	 7638	 0.0	 0.0	 1	 -30.0	 30.0;
	8554	 5141	 0.001631	 0.0042	 0.0	 7011	 7011	 7011	 0.0	 0.0	 1	 -30.0	 30.0;
	8554	 5549	 0.00092	 0.002582	 0.0	 11524	 11524	 11524	 0.0	 0.0	 1	 -30.0	 30.0;
	7432	 5141	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	7432	 8696	 9.8e-05	 0.000222	 0.0	 130167	 130167	 130167	 0.0	 0.0	 1	 -30.0	 30.0;
	13558	 7432	 0.000822	 0.00572	 0.0	 5467	 5467	 5467	 0.0	 0.0	 1	 -30.0	 30.0;
	7432	 6696	 0.001338	 0.013622	 0.0	 2308	 2308	 2308	 0.0	 0.0	 1	 -30.0	 30.0;
	3192	 7432	 0.00136	 0.004649	 0.0	 6522	 6522	 6522	 0.0	 0.0	 1	 -30.0	 30.0;
	5141	 7128	 0.0	 0.001751	 0.0	 18040	 18040	 18040	 0.0	 0.0	 1	 -30.0	 30.0;
	5549	 5141	 0.0	 0.001711	 0.0	 18462	 18462	 18462	 0.0	 0.0	 1	 -30.0	 30.0;
	8829	 9430	 0.000662	 0.004529	 0.0	 6902	 6902	 6902	 0.0	 0.0	 1	 -30.0	 30.0;
	7652	 9430	 0.000649	 0.004618	 0.0	 6774	 6774	 6774	 0.0	 0.0	 1	 -30.0	 30.0;
	6983	 2552	 0.005669	 0.028992	 0.0	 1070	 1070	 1070	 0.0	 0.0	 1	 -30.0	 30.0;
	10137	 10637	 0.001631	 0.1176	 0.0	 269	 269	 269	 0.0	 0.0	 1	 -30.0	 30.0;
	1730	 7801	 9.8e-05	 0.000222	 0.0	 130167	 130167	 130167	 0.0	 0.0	 1	 -30.0	 30.0;
	507	 1730	 0.006942	 0.04516	 0.0	 692	 692	 692	 0.0	 0.0	 1	 -30.0	 30.0;
	507	 1730	 0.0068	 0.04604	 0.0	 679	 679	 679	 0.0	 0.0	 1	 -30.0	 30.0;
	12571	 3860	 0.003289	 0.017909	 0.0	 1735	 1735	 1735	 0.0	 0.0	 1	 -30.0	 30.0;
	4660	 12053	 0.00056	 0.038671	 0.0	 817	 817	 817	 0.0	 0.0	 1	 -30.0	 30.0;
	6872	 11331	 0.02162	 0.062612	 0.0	 477	 477	 477	 0.0	 0.0	 1	 -30.0	 30.0;
	65	 3578	 9.8e-05	 0.000222	 0.0	 130167	 130167	 130167	 0.0	 0.0	 1	 -30.0	 30.0;
	65	 13317	 0.000822	 0.00656	 0.0	 4778	 4778	 4778	 0.0	 0.0	 1	 -30.0	 30.0;
	65	 1300	 0.003009	 0.004649	 0.0	 5704	 5704	 5704	 0.0	 0.0	 1	 -30.0	 30.0;
	65	 1300	 0.003071	 0.004551	 0.0	 5754	 5754	 5754	 0.0	 0.0	 1	 -30.0	 30.0;
	10209	 599	 0.00464	 0.029431	 0.0	 1061	 1061	 1061	 0.0	 0.0	 1	 -30.0	 30.0;
	10209	 599	 0.005249	 0.02884	 0.0	 1078	 1078	 1078	 0.0	 0.0	 1	 -30.0	 30.0;
	4508	 8813	 0.001902	 0.012702	 0.0	 2460	 2460	 2460	 0.0	 0.0	 1	 -30.0	 30.0;
	4508	 8813	 0.001858	 0.012938	 0.0	 2417	 2417	 2417	 0.0	 0.0	 1	 -30.0	 30.0;
	4508	 11218	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	8990	 7919	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	9157	 5602	 9.8e-05	 0.000222	 0.0	 130167	 130167	 130167	 0.0	 0.0	 1	 -30.0	 30.0;
	507	 10492	 9.8e-05	 0.000222	 0.0	 130167	 130167	 130167	 0.0	 0.0	 1	 -30.0	 30.0;
	13431	 1406	 9.8e-05	 0.000222	 0.0	 130167	 130167	 130167	 0.0	 0.0	 1	 -30.0	 30.0;
	13611	 4584	 9.8e-05	 0.000222	 0.0	 130167	 130167	 130167	 0.0	 0.0	 1	 -30.0	 30.0;
	13611	 6959	 0.004738	 0.012529	 0.0	 2359	 2359	 2359	 0.0	 0.0	 1	 -30.0	 30.0;
	13611	 6959	 0.004831	 0.012262	 0.0	 2397	 2397	 2397	 0.0	 0.0	 1	 -30.0	 30.0;
	13611	 6959	 0.002711	 0.018431	 0.0	 1696	 1696	 1696	 0.0	 0.0	 1	 -30.0	 30.0;
	5855	 13410	 0.01205	 0.03281	 0.0	 904	 904	 904	 0.0	 0.0	 1	 -30.0	 30.0;
	4832	 6959	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	6959	 1531	 0.000649	 0.03712	 0.0	 851	 851	 851	 0.0	 0.0	 1	 -30.0	 30.0;
	6959	 6569	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	9242	 6959	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	6997	 5334	 0.00076	 0.005329	 0.0	 5869	 5869	 5869	 0.0	 0.0	 1	 -30.0	 30.0;
	4601	 445	 0.005769	 0.03528	 0.0	 884	 884	 884	 0.0	 0.0	 1	 -30.0	 30.0;
	10948	 2072	 0.002258	 0.004849	 0.0	 5906	 5906	 5906	 0.0	 0.0	 1	 -30.0	 30.0;
	10948	 2072	 0.002209	 0.004489	 0.0	 6314	 6314	 6314	 0.0	 0.0	 1	 -30.0	 30.0;
	1508	 5693	 0.0	 0.000479	 0.0	 65945	 65945	 65945	 0.0	 0.0	 1	 -30.0	 30.0;
	1508	 9483	 0.00256	 0.01561	 0.0	 1997	 1997	 1997	 0.0	 0.0	 1	 -30.0	 30.0;
	5693	 7724	 0.00269	 0.01451	 0.0	 2141	 2141	 2141	 0.0	 0.0	 1	 -30.0	 30.0;
	12184	 11881	 0.003372	 0.028231	 0.0	 1111	 1111	 1111	 0.0	 0.0	 1	 -30.0	 30.0;
	12184	 13495	 0.007033	 0.047083	 0.0	 664	 664	 664	 0.0	 0.0	 1	 -30.0	 30.0;
	113	 48	 0.0	 0.000469	 0.0	 67351	 67351	 67351	 0.0	 0.0	 1	 -30.0	 30.0;
	4601	 2827	 9.8e-05	 0.000222	 0.0	 130167	 130167	 130167	 0.0	 0.0	 1	 -30.0	 30.0;
	3954	 4601	 0.00392	 0.025191	 0.0	 1240	 1240	 1240	 0.0	 0.0	 1	 -30.0	 30.0;
	3954	 4601	 0.00444	 0.024689	 0.0	 1260	 1260	 1260	 0.0	 0.0	 1	 -30.0	 30.0;
	13495	 11881	 0.003529	 0.021223	 0.0	 1469	 1469	 1469	 0.0	 0.0	 1	 -30.0	 30.0;
	8829	 7652	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	6578	 583	 0.00069	 0.00134	 0.0	 20958	 20958	 20958	 0.0	 0.0	 1	 -30.0	 30.0;
	8504	 9167	 0.00067	 0.00136	 0.0	 20835	 20835	 20835	 0.0	 0.0	 1	 -30.0	 30.0;
	3555	 12501	 0.012992	 0.070207	 0.0	 443	 443	 443	 0.0	 0.0	 1	 -30.0	 30.0;
	583	 8504	 0.0	 0.00053	 0.0	 59599	 59599	 59599	 0.0	 0.0	 1	 -30.0	 30.0;
	9483	 7724	 0.0	 0.000461	 0.0	 68520	 68520	 68520	 0.0	 0.0	 1	 -30.0	 30.0;
	12160	 12080	 0.0	 0.00054	 0.0	 58496	 58496	 58496	 0.0	 0.0	 1	 -30.0	 30.0;
	10245	 12289	 0.002314	 0.005661	 0.0	 5165	 5165	 5165	 0.0	 0.0	 1	 -30.0	 30.0;
	12289	 10245	 0.002512	 0.005909	 0.0	 4920	 4920	 4920	 0.0	 0.0	 1	 -30.0	 30.0;
	8827	 10245	 0.006364	 0.018488	 0.0	 1616	 1616	 1616	 0.0	 0.0	 1	 -30.0	 30.0;
	8827	 10245	 0.005959	 0.017752	 0.0	 1687	 1687	 1687	 0.0	 0.0	 1	 -30.0	 30.0;
	8827	 13410	 0.018397	 0.04176	 0.0	 693	 693	 693	 0.0	 0.0	 1	 -30.0	 30.0;
	8827	 13410	 0.018058	 0.042653	 0.0	 682	 682	 682	 0.0	 0.0	 1	 -30.0	 30.0;
	8098	 11519	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	3753	 12784	 0.0	 0.000529	 0.0	 59712	 59712	 59712	 0.0	 0.0	 1	 -30.0	 30.0;
	13414	 12784	 0.0	 0.00052	 0.0	 60745	 60745	 60745	 0.0	 0.0	 1	 -30.0	 30.0;
	3287	 13414	 0.003369	 0.031329	 0.0	 1003	 1003	 1003	 0.0	 0.0	 1	 -30.0	 30.0;
	3601	 9145	 0.07449	 0.527603	 0.0	 60	 60	 60	 0.0	 0.0	 1	 -30.0	 30.0;
	4373	 9145	 0.01093	 0.074531	 0.0	 420	 420	 420	 0.0	 0.0	 1	 -30.0	 30.0;
	7999	 9145	 0.00887	 0.04576	 0.0	 678	 678	 678	 0.0	 0.0	 1	 -30.0	 30.0;
	5745	 9145	 0.01099	 0.06689	 0.0	 466	 466	 466	 0.0	 0.0	 1	 -30.0	 30.0;
	8031	 1506	 0.04732	 0.42186	 0.0	 75	 75	 75	 0.0	 0.0	 1	 -30.0	 30.0;
	8031	 1506	 0.004469	 0.03124	 0.0	 1001	 1001	 1001	 0.0	 0.0	 1	 -30.0	 30.0;
	1506	 633	 0.500289	 1.586157	 0.0	 19	 19	 19	 0.0	 0.0	 1	 -30.0	 30.0;
	1506	 7690	 0.01089	 0.060719	 0.0	 513	 513	 513	 0.0	 0.0	 1	 -30.0	 30.0;
	1506	 12514	 0.133469	 0.882645	 0.0	 36	 36	 36	 0.0	 0.0	 1	 -30.0	 30.0;
	8031	 1506	 0.005531	 0.032521	 0.0	 958	 958	 958	 0.0	 0.0	 1	 -30.0	 30.0;
	1506	 12514	 0.005219	 0.025659	 0.0	 1207	 1207	 1207	 0.0	 0.0	 1	 -30.0	 30.0;
	12798	 5651	 0.00186	 0.012789	 0.0	 2445	 2445	 2445	 0.0	 0.0	 1	 -30.0	 30.0;
	5867	 5651	 0.001	 0.234938	 0.0	 135	 135	 135	 0.0	 0.0	 1	 -30.0	 30.0;
	7423	 9801	 0.00081	 0.004781	 0.0	 6515	 6515	 6515	 0.0	 0.0	 1	 -30.0	 30.0;
	4104	 12032	 0.00082	 0.00468	 0.0	 6649	 6649	 6649	 0.0	 0.0	 1	 -30.0	 30.0;
	6716	 6737	 0.03374	 0.614711	 0.0	 52	 52	 52	 0.0	 0.0	 1	 -30.0	 30.0;
	12597	 6737	 0.04612	 0.366777	 0.0	 86	 86	 86	 0.0	 0.0	 1	 -30.0	 30.0;
	7534	 6737	 0.001461	 0.01239	 0.0	 2532	 2532	 2532	 0.0	 0.0	 1	 -30.0	 30.0;
	12597	 6716	 0.078599	 0.394649	 0.0	 79	 79	 79	 0.0	 0.0	 1	 -30.0	 30.0;
	1998	 6716	 0.00143	 0.01263	 0.0	 2486	 2486	 2486	 0.0	 0.0	 1	 -30.0	 30.0;
	10689	 1379	 0.007841	 0.05613	 0.0	 558	 558	 558	 0.0	 0.0	 1	 -30.0	 30.0;
	7749	 3514	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	7749	 3514	 0.001	 0.328946	 0.0	 97	 97	 97	 0.0	 0.0	 1	 -30.0	 30.0;
	5321	 3514	 0.224855	 1.532376	 0.0	 21	 21	 21	 0.0	 0.0	 1	 -30.0	 30.0;
	1063	 3514	 0.136781	 1.457355	 0.0	 22	 22	 22	 0.0	 0.0	 1	 -30.0	 30.0;
	1063	 3514	 0.01055	 0.074979	 0.0	 418	 418	 418	 0.0	 0.0	 1	 -30.0	 30.0;
	2109	 3514	 0.014909	 0.523802	 0.0	 61	 61	 61	 0.0	 0.0	 1	 -30.0	 30.0;
	2619	 3514	 0.001	 0.71781	 0.0	 45	 45	 45	 0.0	 0.0	 1	 -30.0	 30.0;
	11043	 3514	 0.134271	 1.687004	 0.0	 19	 19	 19	 0.0	 0.0	 1	 -30.0	 30.0;
	6113	 7749	 0.002341	 0.01263	 0.0	 2460	 2460	 2460	 0.0	 0.0	 1	 -30.0	 30.0;
	5321	 7749	 0.235227	 1.541777	 0.0	 21	 21	 21	 0.0	 0.0	 1	 -30.0	 30.0;
	1063	 7749	 0.16344	 1.266136	 0.0	 25	 25	 25	 0.0	 0.0	 1	 -30.0	 30.0;
	2109	 7749	 0.015479	 0.562376	 0.0	 57	 57	 57	 0.0	 0.0	 1	 -30.0	 30.0;
	2619	 7749	 0.001	 0.767789	 0.0	 42	 42	 42	 0.0	 0.0	 1	 -30.0	 30.0;
	11043	 7749	 0.158281	 1.596364	 0.0	 20	 20	 20	 0.0	 0.0	 1	 -30.0	 30.0;
	10849	 5015	 0.006169	 0.039289	 0.0	 795	 795	 795	 0.0	 0.0	 1	 -30.0	 30.0;
	12209	 5015	 0.08256	 0.638182	 0.0	 50	 50	 50	 0.0	 0.0	 1	 -30.0	 30.0;
	3967	 5015	 0.221653	 1.097397	 0.0	 29	 29	 29	 0.0	 0.0	 1	 -30.0	 30.0;
	5015	 9811	 0.0118	 0.05445	 0.0	 567	 567	 567	 0.0	 0.0	 1	 -30.0	 30.0;
	4325	 5015	 0.08986	 0.756921	 0.0	 42	 42	 42	 0.0	 0.0	 1	 -30.0	 30.0;
	8076	 933	 0.03887	 0.335083	 0.0	 94	 94	 94	 0.0	 0.0	 1	 -30.0	 30.0;
	933	 8076	 0.00455	 0.036539	 0.0	 858	 858	 858	 0.0	 0.0	 1	 -30.0	 30.0;
	246	 933	 0.002169	 0.01688	 0.0	 1857	 1857	 1857	 0.0	 0.0	 1	 -30.0	 30.0;
	246	 933	 0.01045	 0.244731	 0.0	 129	 129	 129	 0.0	 0.0	 1	 -30.0	 30.0;
	9654	 933	 0.001	 0.259525	 0.0	 122	 122	 122	 0.0	 0.0	 1	 -30.0	 30.0;
	5298	 933	 0.036651	 0.378657	 0.0	 84	 84	 84	 0.0	 0.0	 1	 -30.0	 30.0;
	9643	 9177	 0.004669	 0.03839	 0.0	 817	 817	 817	 0.0	 0.0	 1	 -30.0	 30.0;
	857	 9177	 0.000781	 0.00674	 0.0	 4656	 4656	 4656	 0.0	 0.0	 1	 -30.0	 30.0;
	5321	 9177	 0.001461	 0.01201	 0.0	 2611	 2611	 2611	 0.0	 0.0	 1	 -30.0	 30.0;
	13650	 9177	 0.00087	 0.00614	 0.0	 5094	 5094	 5094	 0.0	 0.0	 1	 -30.0	 30.0;
	13263	 6113	 0.00464	 0.02919	 0.0	 1069	 1069	 1069	 0.0	 0.0	 1	 -30.0	 30.0;
	2619	 6113	 0.004719	 0.02719	 0.0	 1145	 1145	 1145	 0.0	 0.0	 1	 -30.0	 30.0;
	8240	 6113	 0.00169	 0.01361	 0.0	 2304	 2304	 2304	 0.0	 0.0	 1	 -30.0	 30.0;
	3037	 6113	 0.00751	 0.04581	 0.0	 681	 681	 681	 0.0	 0.0	 1	 -30.0	 30.0;
	9335	 9643	 0.00368	 0.022469	 0.0	 1388	 1388	 1388	 0.0	 0.0	 1	 -30.0	 30.0;
	8240	 9643	 0.001659	 0.012599	 0.0	 2486	 2486	 2486	 0.0	 0.0	 1	 -30.0	 30.0;
	11043	 9643	 0.007341	 0.042419	 0.0	 734	 734	 734	 0.0	 0.0	 1	 -30.0	 30.0;
	9643	 10993	 0.00186	 0.01456	 0.0	 2152	 2152	 2152	 0.0	 0.0	 1	 -30.0	 30.0;
	9104	 4911	 0.00312	 0.03151	 0.0	 998	 998	 998	 0.0	 0.0	 1	 -30.0	 30.0;
	13061	 9104	 0.00073	 0.00808	 0.0	 3894	 3894	 3894	 0.0	 0.0	 1	 -30.0	 30.0;
	10513	 4322	 0.013479	 0.27064	 0.0	 117	 117	 117	 0.0	 0.0	 1	 -30.0	 30.0;
	10513	 4322	 0.00187	 0.020289	 0.0	 1551	 1551	 1551	 0.0	 0.0	 1	 -30.0	 30.0;
	13357	 4322	 0.012169	 0.298636	 0.0	 106	 106	 106	 0.0	 0.0	 1	 -30.0	 30.0;
	10689	 10131	 0.00337	 0.027831	 0.0	 1127	 1127	 1127	 0.0	 0.0	 1	 -30.0	 30.0;
	5745	 10689	 0.00461	 0.03301	 0.0	 948	 948	 948	 0.0	 0.0	 1	 -30.0	 30.0;
	10131	 10689	 0.005781	 0.039789	 0.0	 786	 786	 786	 0.0	 0.0	 1	 -30.0	 30.0;
	10131	 10689	 0.035151	 0.987397	 0.0	 32	 32	 32	 0.0	 0.0	 1	 -30.0	 30.0;
	6712	 10689	 0.013099	 0.631736	 0.0	 50	 50	 50	 0.0	 0.0	 1	 -30.0	 30.0;
	4373	 3601	 0.118409	 1.072417	 0.0	 30	 30	 30	 0.0	 0.0	 1	 -30.0	 30.0;
	4373	 3601	 0.006281	 0.051961	 0.0	 604	 604	 604	 0.0	 0.0	 1	 -30.0	 30.0;
	2926	 3601	 0.284979	 1.491054	 0.0	 21	 21	 21	 0.0	 0.0	 1	 -30.0	 30.0;
	8076	 4736	 0.006409	 0.038081	 0.0	 818	 818	 818	 0.0	 0.0	 1	 -30.0	 30.0;
	246	 8076	 0.225806	 1.262624	 0.0	 25	 25	 25	 0.0	 0.0	 1	 -30.0	 30.0;
	9654	 8076	 0.282252	 1.121529	 0.0	 28	 28	 28	 0.0	 0.0	 1	 -30.0	 30.0;
	5298	 8076	 0.561921	 1.55469	 0.0	 20	 20	 20	 0.0	 0.0	 1	 -30.0	 30.0;
	10338	 5572	 0.00322	 0.02808	 0.0	 1118	 1118	 1118	 0.0	 0.0	 1	 -30.0	 30.0;
	317	 5572	 0.00196	 0.01843	 0.0	 1705	 1705	 1705	 0.0	 0.0	 1	 -30.0	 30.0;
	10265	 12450	 0.552066	 1.574607	 0.0	 19	 19	 19	 0.0	 0.0	 1	 -30.0	 30.0;
	4850	 12450	 0.010151	 0.087021	 0.0	 361	 361	 361	 0.0	 0.0	 1	 -30.0	 30.0;
	10697	 12450	 0.16999	 0.991054	 0.0	 32	 32	 32	 0.0	 0.0	 1	 -30.0	 30.0;
	399	 12450	 0.003831	 0.02386	 0.0	 1308	 1308	 1308	 0.0	 0.0	 1	 -30.0	 30.0;
	399	 12450	 0.00863	 0.535785	 0.0	 59	 59	 59	 0.0	 0.0	 1	 -30.0	 30.0;
	9019	 12450	 0.04357	 0.617335	 0.0	 52	 52	 52	 0.0	 0.0	 1	 -30.0	 30.0;
	8333	 4051	 0.008081	 0.03963	 0.0	 781	 781	 781	 0.0	 0.0	 1	 -30.0	 30.0;
	4051	 2619	 0.00213	 0.01488	 0.0	 2102	 2102	 2102	 0.0	 0.0	 1	 -30.0	 30.0;
	317	 6653	 0.00219	 0.02232	 0.0	 1409	 1409	 1409	 0.0	 0.0	 1	 -30.0	 30.0;
	6653	 9356	 0.00352	 0.03947	 0.0	 798	 798	 798	 0.0	 0.0	 1	 -30.0	 30.0;
	6653	 9162	 0.00222	 0.02857	 0.0	 1103	 1103	 1103	 0.0	 0.0	 1	 -30.0	 30.0;
	537	 8472	 0.00104	 0.00901	 0.0	 3483	 3483	 3483	 0.0	 0.0	 1	 -30.0	 30.0;
	3952	 537	 0.00106	 0.00881	 0.0	 3560	 3560	 3560	 0.0	 0.0	 1	 -30.0	 30.0;
	9705	 5950	 0.00301	 0.031271	 0.0	 1006	 1006	 1006	 0.0	 0.0	 1	 -30.0	 30.0;
	8472	 530	 0.00133	 0.01852	 0.0	 1702	 1702	 1702	 0.0	 0.0	 1	 -30.0	 30.0;
	530	 7328	 0.00253	 0.0287	 0.0	 1097	 1097	 1097	 0.0	 0.0	 1	 -30.0	 30.0;
	8472	 530	 0.06395	 0.413802	 0.0	 76	 76	 76	 0.0	 0.0	 1	 -30.0	 30.0;
	9356	 13654	 0.00075	 0.00981	 0.0	 3857	 3857	 3857	 0.0	 0.0	 1	 -30.0	 30.0;
	11590	 6644	 0.234814	 1.148326	 0.0	 27	 27	 27	 0.0	 0.0	 1	 -30.0	 30.0;
	13563	 6644	 0.222417	 1.185971	 0.0	 27	 27	 27	 0.0	 0.0	 1	 -30.0	 30.0;
	12963	 6644	 0.08124	 0.548574	 0.0	 57	 57	 57	 0.0	 0.0	 1	 -30.0	 30.0;
	12963	 6644	 0.01132	 0.074211	 0.0	 421	 421	 421	 0.0	 0.0	 1	 -30.0	 30.0;
	1107	 6644	 0.115849	 0.953099	 0.0	 33	 33	 33	 0.0	 0.0	 1	 -30.0	 30.0;
	12187	 6246	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	12187	 6246	 0.001	 0.517348	 0.0	 62	 62	 62	 0.0	 0.0	 1	 -30.0	 30.0;
	6246	 11045	 0.00051	 0.00504	 0.0	 6236	 6236	 6236	 0.0	 0.0	 1	 -30.0	 30.0;
	6246	 7601	 0.00258	 0.02748	 0.0	 1145	 1145	 1145	 0.0	 0.0	 1	 -30.0	 30.0;
	1405	 12187	 0.00224	 0.02852	 0.0	 1105	 1105	 1105	 0.0	 0.0	 1	 -30.0	 30.0;
	12187	 3952	 0.00144	 0.01774	 0.0	 1775	 1775	 1775	 0.0	 0.0	 1	 -30.0	 30.0;
	8216	 12361	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	8216	 12361	 0.06794	 0.65593	 0.0	 48	 48	 48	 0.0	 0.0	 1	 -30.0	 30.0;
	12361	 10513	 0.028479	 0.136841	 0.0	 226	 226	 226	 0.0	 0.0	 1	 -30.0	 30.0;
	8216	 5950	 0.02019	 0.10464	 0.0	 297	 297	 297	 0.0	 0.0	 1	 -30.0	 30.0;
	11045	 3952	 0.00128	 0.01333	 0.0	 2359	 2359	 2359	 0.0	 0.0	 1	 -30.0	 30.0;
	488	 9973	 0.667066	 1.759628	 0.0	 17	 17	 17	 0.0	 0.0	 1	 -30.0	 30.0;
	7101	 9973	 0.0232	 0.385289	 0.0	 82	 82	 82	 0.0	 0.0	 1	 -30.0	 30.0;
	7101	 9973	 0.00686	 0.03882	 0.0	 802	 802	 802	 0.0	 0.0	 1	 -30.0	 30.0;
	11541	 9973	 0.04143	 0.328037	 0.0	 96	 96	 96	 0.0	 0.0	 1	 -30.0	 30.0;
	13004	 9973	 0.00107	 0.00707	 0.0	 4418	 4418	 4418	 0.0	 0.0	 1	 -30.0	 30.0;
	7101	 488	 0.173021	 1.092025	 0.0	 29	 29	 29	 0.0	 0.0	 1	 -30.0	 30.0;
	7101	 488	 0.010849	 0.074771	 0.0	 419	 419	 419	 0.0	 0.0	 1	 -30.0	 30.0;
	843	 488	 0.18632	 0.723574	 0.0	 43	 43	 43	 0.0	 0.0	 1	 -30.0	 30.0;
	11297	 488	 0.077651	 0.853368	 0.0	 37	 37	 37	 0.0	 0.0	 1	 -30.0	 30.0;
	11297	 488	 0.011169	 0.07225	 0.0	 433	 433	 433	 0.0	 0.0	 1	 -30.0	 30.0;
	11541	 488	 0.14268	 0.506488	 0.0	 61	 61	 61	 0.0	 0.0	 1	 -30.0	 30.0;
	10697	 488	 0.352417	 1.255207	 0.0	 25	 25	 25	 0.0	 0.0	 1	 -30.0	 30.0;
	399	 488	 0.391322	 1.63	 0.0	 19	 19	 19	 0.0	 0.0	 1	 -30.0	 30.0;
	4669	 3967	 0.006271	 0.037341	 0.0	 835	 835	 835	 0.0	 0.0	 1	 -30.0	 30.0;
	5298	 4669	 0.005961	 0.054719	 0.0	 574	 574	 574	 0.0	 0.0	 1	 -30.0	 30.0;
	5153	 6887	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	5153	 6887	 0.001	 0.333822	 0.0	 95	 95	 95	 0.0	 0.0	 1	 -30.0	 30.0;
	6887	 5474	 0.00587	 0.040281	 0.0	 776	 776	 776	 0.0	 0.0	 1	 -30.0	 30.0;
	5153	 13357	 0.003599	 0.046841	 0.0	 673	 673	 673	 0.0	 0.0	 1	 -30.0	 30.0;
	4243	 7601	 0.00224	 0.02796	 0.0	 1127	 1127	 1127	 0.0	 0.0	 1	 -30.0	 30.0;
	3967	 12209	 0.08693	 0.670269	 0.0	 47	 47	 47	 0.0	 0.0	 1	 -30.0	 30.0;
	5321	 12209	 0.301839	 1.820372	 0.0	 18	 18	 18	 0.0	 0.0	 1	 -30.0	 30.0;
	2109	 12209	 0.00136	 0.01051	 0.0	 2981	 2981	 2981	 0.0	 0.0	 1	 -30.0	 30.0;
	2109	 12209	 0.00445	 0.344835	 0.0	 92	 92	 92	 0.0	 0.0	 1	 -30.0	 30.0;
	12267	 12209	 0.197159	 1.014752	 0.0	 31	 31	 31	 0.0	 0.0	 1	 -30.0	 30.0;
	8333	 12209	 0.097341	 0.78186	 0.0	 41	 41	 41	 0.0	 0.0	 1	 -30.0	 30.0;
	4325	 12209	 0.013039	 0.297211	 0.0	 107	 107	 107	 0.0	 0.0	 1	 -30.0	 30.0;
	10849	 12209	 0.035521	 0.685351	 0.0	 47	 47	 47	 0.0	 0.0	 1	 -30.0	 30.0;
	5867	 12209	 0.367335	 1.746467	 0.0	 18	 18	 18	 0.0	 0.0	 1	 -30.0	 30.0;
	4463	 12209	 0.04186	 0.505517	 0.0	 63	 63	 63	 0.0	 0.0	 1	 -30.0	 30.0;
	2109	 12209	 0.001021	 0.284401	 0.0	 112	 112	 112	 0.0	 0.0	 1	 -30.0	 30.0;
	9811	 12209	 0.02575	 0.548884	 0.0	 58	 58	 58	 0.0	 0.0	 1	 -30.0	 30.0;
	10993	 12209	 0.002211	 0.016599	 0.0	 1887	 1887	 1887	 0.0	 0.0	 1	 -30.0	 30.0;
	10273	 12798	 0.0015	 0.00876	 0.0	 3555	 3555	 3555	 0.0	 0.0	 1	 -30.0	 30.0;
	5867	 10273	 0.00062	 0.00386	 0.0	 8080	 8080	 8080	 0.0	 0.0	 1	 -30.0	 30.0;
	9811	 13263	 0.00188	 0.008651	 0.0	 3569	 3569	 3569	 0.0	 0.0	 1	 -30.0	 30.0;
	4463	 13263	 0.00651	 0.278678	 0.0	 114	 114	 114	 0.0	 0.0	 1	 -30.0	 30.0;
	8240	 13263	 0.080781	 0.659587	 0.0	 48	 48	 48	 0.0	 0.0	 1	 -30.0	 30.0;
	7817	 10020	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	7817	 10020	 0.001	 0.232851	 0.0	 136	 136	 136	 0.0	 0.0	 1	 -30.0	 30.0;
	10020	 12998	 0.01614	 0.08307	 0.0	 374	 374	 374	 0.0	 0.0	 1	 -30.0	 30.0;
	633	 10020	 0.190479	 0.901095	 0.0	 35	 35	 35	 0.0	 0.0	 1	 -30.0	 30.0;
	633	 10020	 0.00281	 0.01663	 0.0	 1873	 1873	 1873	 0.0	 0.0	 1	 -30.0	 30.0;
	7690	 10020	 0.032841	 0.593161	 0.0	 54	 54	 54	 0.0	 0.0	 1	 -30.0	 30.0;
	12597	 10020	 0.004599	 0.03094	 0.0	 1010	 1010	 1010	 0.0	 0.0	 1	 -30.0	 30.0;
	12514	 10020	 0.100021	 0.542231	 0.0	 58	 58	 58	 0.0	 0.0	 1	 -30.0	 30.0;
	633	 7817	 0.1945	 0.883884	 0.0	 35	 35	 35	 0.0	 0.0	 1	 -30.0	 30.0;
	7690	 7817	 0.028409	 0.617727	 0.0	 52	 52	 52	 0.0	 0.0	 1	 -30.0	 30.0;
	7817	 7534	 0.003281	 0.04162	 0.0	 757	 757	 757	 0.0	 0.0	 1	 -30.0	 30.0;
	12514	 7817	 0.09636	 0.566219	 0.0	 55	 55	 55	 0.0	 0.0	 1	 -30.0	 30.0;
	12514	 7817	 0.007521	 0.044719	 0.0	 697	 697	 697	 0.0	 0.0	 1	 -30.0	 30.0;
	13357	 10513	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	13357	 10513	 0.001	 0.19056	 0.0	 166	 166	 166	 0.0	 0.0	 1	 -30.0	 30.0;
	10513	 4850	 0.01356	 0.08876	 0.0	 352	 352	 352	 0.0	 0.0	 1	 -30.0	 30.0;
	13357	 4850	 0.005271	 0.068591	 0.0	 460	 460	 460	 0.0	 0.0	 1	 -30.0	 30.0;
	4972	 12798	 0.003591	 0.03075	 0.0	 1021	 1021	 1021	 0.0	 0.0	 1	 -30.0	 30.0;
	7534	 12798	 0.01	 0.056159	 0.0	 554	 554	 554	 0.0	 0.0	 1	 -30.0	 30.0;
	2867	 12798	 0.011831	 0.067969	 0.0	 458	 458	 458	 0.0	 0.0	 1	 -30.0	 30.0;
	1998	 12798	 0.00937	 0.05893	 0.0	 530	 530	 530	 0.0	 0.0	 1	 -30.0	 30.0;
	12798	 10968	 0.000909	 0.004719	 0.0	 6573	 6573	 6573	 0.0	 0.0	 1	 -30.0	 30.0;
	3159	 9356	 0.00176	 0.01759	 0.0	 1787	 1787	 1787	 0.0	 0.0	 1	 -30.0	 30.0;
	4318	 3159	 0.00137	 0.01801	 0.0	 1749	 1749	 1749	 0.0	 0.0	 1	 -30.0	 30.0;
	3159	 11162	 0.00184	 0.01756	 0.0	 1790	 1790	 1790	 0.0	 0.0	 1	 -30.0	 30.0;
	9811	 4463	 0.00213	 0.012539	 0.0	 2484	 2484	 2484	 0.0	 0.0	 1	 -30.0	 30.0;
	8240	 4463	 0.07664	 0.597665	 0.0	 53	 53	 53	 0.0	 0.0	 1	 -30.0	 30.0;
	2109	 4463	 0.07132	 0.544959	 0.0	 58	 58	 58	 0.0	 0.0	 1	 -30.0	 30.0;
	2109	 4463	 0.00405	 0.02507	 0.0	 1244	 1244	 1244	 0.0	 0.0	 1	 -30.0	 30.0;
	9811	 4463	 0.001	 0.348058	 0.0	 91	 91	 91	 0.0	 0.0	 1	 -30.0	 30.0;
	4325	 3967	 0.06064	 0.52688	 0.0	 60	 60	 60	 0.0	 0.0	 1	 -30.0	 30.0;
	3967	 4325	 0.005271	 0.03093	 0.0	 1007	 1007	 1007	 0.0	 0.0	 1	 -30.0	 30.0;
	4972	 9335	 0.002841	 0.023409	 0.0	 1340	 1340	 1340	 0.0	 0.0	 1	 -30.0	 30.0;
	10187	 2867	 0.00226	 0.015841	 0.0	 1975	 1975	 1975	 0.0	 0.0	 1	 -30.0	 30.0;
	9015	 2867	 0.01237	 0.060909	 0.0	 509	 509	 509	 0.0	 0.0	 1	 -30.0	 30.0;
	2867	 4972	 0.01637	 0.07345	 0.0	 420	 420	 420	 0.0	 0.0	 1	 -30.0	 30.0;
	5874	 2867	 0.00243	 0.018341	 0.0	 1708	 1708	 1708	 0.0	 0.0	 1	 -30.0	 30.0;
	5039	 1141	 0.0026	 0.02813	 0.0	 1119	 1119	 1119	 0.0	 0.0	 1	 -30.0	 30.0;
	7423	 4104	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	7423	 4104	 0.02631	 0.515517	 0.0	 62	 62	 62	 0.0	 0.0	 1	 -30.0	 30.0;
	4104	 10131	 0.00394	 0.041169	 0.0	 764	 764	 764	 0.0	 0.0	 1	 -30.0	 30.0;
	4104	 10131	 0.343719	 1.744855	 0.0	 18	 18	 18	 0.0	 0.0	 1	 -30.0	 30.0;
	4104	 3037	 0.017159	 0.080591	 0.0	 384	 384	 384	 0.0	 0.0	 1	 -30.0	 30.0;
	7423	 8020	 0.005	 0.066591	 0.0	 474	 474	 474	 0.0	 0.0	 1	 -30.0	 30.0;
	7423	 10131	 0.065229	 1.288988	 0.0	 25	 25	 25	 0.0	 0.0	 1	 -30.0	 30.0;
	1063	 5321	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	1063	 5321	 0.001	 0.56	 0.0	 57	 57	 57	 0.0	 0.0	 1	 -30.0	 30.0;
	2109	 5321	 0.063599	 0.651508	 0.0	 49	 49	 49	 0.0	 0.0	 1	 -30.0	 30.0;
	12267	 5321	 0.075159	 1.271095	 0.0	 25	 25	 25	 0.0	 0.0	 1	 -30.0	 30.0;
	8333	 5321	 0.360475	 1.617479	 0.0	 20	 20	 20	 0.0	 0.0	 1	 -30.0	 30.0;
	2619	 5321	 0.001	 0.740702	 0.0	 43	 43	 43	 0.0	 0.0	 1	 -30.0	 30.0;
	4325	 5321	 0.363884	 2.00314	 0.0	 16	 16	 16	 0.0	 0.0	 1	 -30.0	 30.0;
	10849	 5321	 0.3925	 1.858533	 0.0	 17	 17	 17	 0.0	 0.0	 1	 -30.0	 30.0;
	2109	 1063	 0.04769	 0.602128	 0.0	 53	 53	 53	 0.0	 0.0	 1	 -30.0	 30.0;
	12267	 1063	 0.050341	 1.259855	 0.0	 26	 26	 26	 0.0	 0.0	 1	 -30.0	 30.0;
	2619	 1063	 0.001	 0.829566	 0.0	 39	 39	 39	 0.0	 0.0	 1	 -30.0	 30.0;
	4850	 8031	 0.00049	 0.00324	 0.0	 9640	 9640	 9640	 0.0	 0.0	 1	 -30.0	 30.0;
	8031	 5555	 0.018659	 0.111289	 0.0	 280	 280	 280	 0.0	 0.0	 1	 -30.0	 30.0;
	8031	 12514	 0.509835	 1.831384	 0.0	 17	 17	 17	 0.0	 0.0	 1	 -30.0	 30.0;
	4850	 8031	 0.0005	 0.00318	 0.0	 9813	 9813	 9813	 0.0	 0.0	 1	 -30.0	 30.0;
	9811	 2109	 0.05936	 0.582149	 0.0	 54	 54	 54	 0.0	 0.0	 1	 -30.0	 30.0;
	4325	 2109	 0.003331	 0.0203	 0.0	 1536	 1536	 1536	 0.0	 0.0	 1	 -30.0	 30.0;
	12267	 2109	 0.12286	 0.888244	 0.0	 36	 36	 36	 0.0	 0.0	 1	 -30.0	 30.0;
	8333	 2109	 0.033599	 0.599959	 0.0	 53	 53	 53	 0.0	 0.0	 1	 -30.0	 30.0;
	2619	 2109	 0.100539	 0.767066	 0.0	 41	 41	 41	 0.0	 0.0	 1	 -30.0	 30.0;
	4325	 2109	 0.0822	 0.730331	 0.0	 43	 43	 43	 0.0	 0.0	 1	 -30.0	 30.0;
	10849	 2109	 0.15512	 0.82874	 0.0	 38	 38	 38	 0.0	 0.0	 1	 -30.0	 30.0;
	7741	 2121	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	7741	 2121	 0.001	 0.194781	 0.0	 163	 163	 163	 0.0	 0.0	 1	 -30.0	 30.0;
	2121	 2754	 0.0132	 0.071979	 0.0	 432	 432	 432	 0.0	 0.0	 1	 -30.0	 30.0;
	2121	 561	 0.0148	 0.073031	 0.0	 424	 424	 424	 0.0	 0.0	 1	 -30.0	 30.0;
	7999	 2121	 0.005781	 0.0378	 0.0	 827	 827	 827	 0.0	 0.0	 1	 -30.0	 30.0;
	9015	 2121	 0.153961	 1.590021	 0.0	 20	 20	 20	 0.0	 0.0	 1	 -30.0	 30.0;
	9015	 2121	 0.00631	 0.03855	 0.0	 809	 809	 809	 0.0	 0.0	 1	 -30.0	 30.0;
	13206	 2121	 0.14124	 1.705702	 0.0	 19	 19	 19	 0.0	 0.0	 1	 -30.0	 30.0;
	7999	 7741	 0.00589	 0.03699	 0.0	 844	 844	 844	 0.0	 0.0	 1	 -30.0	 30.0;
	9015	 7741	 0.18032	 1.449298	 0.0	 22	 22	 22	 0.0	 0.0	 1	 -30.0	 30.0;
	13206	 7741	 0.150651	 1.729298	 0.0	 19	 19	 19	 0.0	 0.0	 1	 -30.0	 30.0;
	13206	 7741	 0.00636	 0.045409	 0.0	 689	 689	 689	 0.0	 0.0	 1	 -30.0	 30.0;
	4071	 5525	 0.00173	 0.01602	 0.0	 1961	 1961	 1961	 0.0	 0.0	 1	 -30.0	 30.0;
	6805	 4071	 0.00207	 0.02233	 0.0	 1409	 1409	 1409	 0.0	 0.0	 1	 -30.0	 30.0;
	2040	 4071	 0.00178	 0.02178	 0.0	 1446	 1446	 1446	 0.0	 0.0	 1	 -30.0	 30.0;
	5874	 10187	 0.00589	 0.214174	 0.0	 148	 148	 148	 0.0	 0.0	 1	 -30.0	 30.0;
	9015	 10187	 0.105789	 1.66719	 0.0	 19	 19	 19	 0.0	 0.0	 1	 -30.0	 30.0;
	13206	 10187	 0.108969	 1.629731	 0.0	 20	 20	 20	 0.0	 0.0	 1	 -30.0	 30.0;
	11541	 7101	 0.024581	 0.231446	 0.0	 136	 136	 136	 0.0	 0.0	 1	 -30.0	 30.0;
	11541	 7101	 0.004599	 0.035341	 0.0	 887	 887	 887	 0.0	 0.0	 1	 -30.0	 30.0;
	7328	 1585	 0.00106	 0.01023	 0.0	 3072	 3072	 3072	 0.0	 0.0	 1	 -30.0	 30.0;
	1597	 1585	 0.00403	 0.04889	 0.0	 644	 644	 644	 0.0	 0.0	 1	 -30.0	 30.0;
	13169	 8011	 0.00123	 0.01589	 0.0	 1982	 1982	 1982	 0.0	 0.0	 1	 -30.0	 30.0;
	13169	 4911	 0.00158	 0.01592	 0.0	 1975	 1975	 1975	 0.0	 0.0	 1	 -30.0	 30.0;
	374	 10360	 0.00219	 0.02123	 0.0	 1481	 1481	 1481	 0.0	 0.0	 1	 -30.0	 30.0;
	374	 12364	 0.00171	 0.01708	 0.0	 1841	 1841	 1841	 0.0	 0.0	 1	 -30.0	 30.0;
	374	 12364	 0.00174	 0.0167	 0.0	 1882	 1882	 1882	 0.0	 0.0	 1	 -30.0	 30.0;
	1597	 374	 0.00515	 0.285942	 0.0	 111	 111	 111	 0.0	 0.0	 1	 -30.0	 30.0;
	1597	 374	 0.00058	 0.00775	 0.0	 4065	 4065	 4065	 0.0	 0.0	 1	 -30.0	 30.0;
	1597	 374	 0.00057	 0.0079	 0.0	 3989	 3989	 3989	 0.0	 0.0	 1	 -30.0	 30.0;
	4972	 9811	 0.009341	 0.6725	 0.0	 47	 47	 47	 0.0	 0.0	 1	 -30.0	 30.0;
	5867	 9811	 0.171229	 1.013678	 0.0	 31	 31	 31	 0.0	 0.0	 1	 -30.0	 30.0;
	10993	 9811	 0.00251	 0.02049	 0.0	 1531	 1531	 1531	 0.0	 0.0	 1	 -30.0	 30.0;
	9811	 10968	 0.005909	 0.036349	 0.0	 858	 858	 858	 0.0	 0.0	 1	 -30.0	 30.0;
	11767	 11162	 0.00091	 0.00886	 0.0	 3547	 3547	 3547	 0.0	 0.0	 1	 -30.0	 30.0;
	13061	 11767	 0.00054	 0.00532	 0.0	 5908	 5908	 5908	 0.0	 0.0	 1	 -30.0	 30.0;
	399	 10265	 0.009531	 0.051211	 0.0	 607	 607	 607	 0.0	 0.0	 1	 -30.0	 30.0;
	399	 10265	 0.785124	 1.943678	 0.0	 16	 16	 16	 0.0	 0.0	 1	 -30.0	 30.0;
	10265	 5560	 0.010789	 0.05194	 0.0	 596	 596	 596	 0.0	 0.0	 1	 -30.0	 30.0;
	9019	 10265	 0.173281	 0.62781	 0.0	 49	 49	 49	 0.0	 0.0	 1	 -30.0	 30.0;
	8240	 4972	 0.00613	 0.033659	 0.0	 924	 924	 924	 0.0	 0.0	 1	 -30.0	 30.0;
	5867	 4972	 0.11576	 0.840434	 0.0	 38	 38	 38	 0.0	 0.0	 1	 -30.0	 30.0;
	11297	 843	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	11297	 843	 0.05964	 0.314938	 0.0	 99	 99	 99	 0.0	 0.0	 1	 -30.0	 30.0;
	843	 9320	 0.002169	 0.017341	 0.0	 1808	 1808	 1808	 0.0	 0.0	 1	 -30.0	 30.0;
	611	 843	 0.454215	 1.265475	 0.0	 24	 24	 24	 0.0	 0.0	 1	 -30.0	 30.0;
	843	 611	 0.007091	 0.061521	 0.0	 511	 511	 511	 0.0	 0.0	 1	 -30.0	 30.0;
	11297	 2452	 0.013021	 0.087711	 0.0	 357	 357	 357	 0.0	 0.0	 1	 -30.0	 30.0;
	1363	 11297	 0.35781	 1.954277	 0.0	 16	 16	 16	 0.0	 0.0	 1	 -30.0	 30.0;
	611	 11297	 0.0485	 0.815537	 0.0	 39	 39	 39	 0.0	 0.0	 1	 -30.0	 30.0;
	2619	 8020	 0.415537	 1.939483	 0.0	 16	 16	 16	 0.0	 0.0	 1	 -30.0	 30.0;
	8240	 8020	 0.097031	 0.677913	 0.0	 47	 47	 47	 0.0	 0.0	 1	 -30.0	 30.0;
	8020	 8240	 0.003031	 0.033021	 0.0	 953	 953	 953	 0.0	 0.0	 1	 -30.0	 30.0;
	8020	 8240	 0.00637	 0.038979	 0.0	 800	 800	 800	 0.0	 0.0	 1	 -30.0	 30.0;
	11043	 8020	 0.024271	 0.588967	 0.0	 54	 54	 54	 0.0	 0.0	 1	 -30.0	 30.0;
	3037	 8020	 0.00439	 0.372438	 0.0	 85	 85	 85	 0.0	 0.0	 1	 -30.0	 30.0;
	314	 8020	 0.001	 0.198331	 0.0	 160	 160	 160	 0.0	 0.0	 1	 -30.0	 30.0;
	314	 8020	 0.00232	 0.01226	 0.0	 2532	 2532	 2532	 0.0	 0.0	 1	 -30.0	 30.0;
	5560	 2452	 0.014211	 0.079219	 0.0	 393	 393	 393	 0.0	 0.0	 1	 -30.0	 30.0;
	246	 2452	 0.015151	 0.07637	 0.0	 406	 406	 406	 0.0	 0.0	 1	 -30.0	 30.0;
	4736	 2452	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	4736	 2452	 0.001	 0.258698	 0.0	 123	 123	 123	 0.0	 0.0	 1	 -30.0	 30.0;
	9654	 2452	 0.01544	 0.074781	 0.0	 414	 414	 414	 0.0	 0.0	 1	 -30.0	 30.0;
	1363	 4736	 0.013909	 0.073349	 0.0	 424	 424	 424	 0.0	 0.0	 1	 -30.0	 30.0;
	7843	 7483	 0.006919	 0.04764	 0.0	 657	 657	 657	 0.0	 0.0	 1	 -30.0	 30.0;
	3208	 7483	 0.224318	 1.85469	 0.0	 17	 17	 17	 0.0	 0.0	 1	 -30.0	 30.0;
	12963	 7483	 0.015169	 0.1077	 0.0	 291	 291	 291	 0.0	 0.0	 1	 -30.0	 30.0;
	561	 7483	 0.130771	 1.06564	 0.0	 30	 30	 30	 0.0	 0.0	 1	 -30.0	 30.0;
	7843	 7483	 0.249669	 1.169917	 0.0	 27	 27	 27	 0.0	 0.0	 1	 -30.0	 30.0;
	5525	 733	 0.00127	 0.01444	 0.0	 2180	 2180	 2180	 0.0	 0.0	 1	 -30.0	 30.0;
	5525	 8923	 0.00318	 0.04235	 0.0	 744	 744	 744	 0.0	 0.0	 1	 -30.0	 30.0;
	5525	 12852	 0.00131	 0.01758	 0.0	 1792	 1792	 1792	 0.0	 0.0	 1	 -30.0	 30.0;
	6712	 4373	 0.469607	 1.302025	 0.0	 23	 23	 23	 0.0	 0.0	 1	 -30.0	 30.0;
	2926	 4373	 0.001	 0.205711	 0.0	 154	 154	 154	 0.0	 0.0	 1	 -30.0	 30.0;
	2926	 4373	 0.002969	 0.02201	 0.0	 1423	 1423	 1423	 0.0	 0.0	 1	 -30.0	 30.0;
	13004	 11541	 0.00549	 0.044831	 0.0	 700	 700	 700	 0.0	 0.0	 1	 -30.0	 30.0;
	2802	 3208	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	2802	 3208	 0.08343	 1.583099	 0.0	 20	 20	 20	 0.0	 0.0	 1	 -30.0	 30.0;
	2754	 3208	 0.094651	 1.363719	 0.0	 24	 24	 24	 0.0	 0.0	 1	 -30.0	 30.0;
	3208	 12998	 0.00112	 0.00895	 0.0	 3502	 3502	 3502	 0.0	 0.0	 1	 -30.0	 30.0;
	12998	 3208	 0.00151	 0.00944	 0.0	 3305	 3305	 3305	 0.0	 0.0	 1	 -30.0	 30.0;
	561	 3208	 0.018669	 0.563368	 0.0	 57	 57	 57	 0.0	 0.0	 1	 -30.0	 30.0;
	7843	 3208	 0.00538	 0.652851	 0.0	 49	 49	 49	 0.0	 0.0	 1	 -30.0	 30.0;
	2754	 2802	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	2754	 2802	 0.001	 0.495455	 0.0	 64	 64	 64	 0.0	 0.0	 1	 -30.0	 30.0;
	561	 2802	 0.036849	 0.734215	 0.0	 43	 43	 43	 0.0	 0.0	 1	 -30.0	 30.0;
	7843	 2802	 0.001	 0.459566	 0.0	 69	 69	 69	 0.0	 0.0	 1	 -30.0	 30.0;
	7843	 2802	 0.00095	 0.00638	 0.0	 4898	 4898	 4898	 0.0	 0.0	 1	 -30.0	 30.0;
	12998	 2754	 0.00105	 0.00818	 0.0	 3831	 3831	 3831	 0.0	 0.0	 1	 -30.0	 30.0;
	561	 2754	 0.040151	 0.657893	 0.0	 48	 48	 48	 0.0	 0.0	 1	 -30.0	 30.0;
	561	 2754	 0.00193	 0.01406	 0.0	 2226	 2226	 2226	 0.0	 0.0	 1	 -30.0	 30.0;
	7843	 2754	 0.001	 0.49438	 0.0	 64	 64	 64	 0.0	 0.0	 1	 -30.0	 30.0;
	8333	 12267	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	8333	 12267	 0.08057	 0.906178	 0.0	 35	 35	 35	 0.0	 0.0	 1	 -30.0	 30.0;
	4325	 12267	 0.0347	 0.658202	 0.0	 48	 48	 48	 0.0	 0.0	 1	 -30.0	 30.0;
	10849	 12267	 0.032719	 0.534318	 0.0	 60	 60	 60	 0.0	 0.0	 1	 -30.0	 30.0;
	10849	 12267	 0.004281	 0.033461	 0.0	 937	 937	 937	 0.0	 0.0	 1	 -30.0	 30.0;
	4325	 8333	 0.001	 0.395785	 0.0	 80	 80	 80	 0.0	 0.0	 1	 -30.0	 30.0;
	10849	 8333	 0.14007	 0.838595	 0.0	 38	 38	 38	 0.0	 0.0	 1	 -30.0	 30.0;
	12852	 733	 0.04194	 0.384211	 0.0	 82	 82	 82	 0.0	 0.0	 1	 -30.0	 30.0;
	733	 12852	 0.00034	 0.00341	 0.0	 9218	 9218	 9218	 0.0	 0.0	 1	 -30.0	 30.0;
	1114	 11590	 0.001969	 0.014021	 0.0	 2231	 2231	 2231	 0.0	 0.0	 1	 -30.0	 30.0;
	13563	 11590	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	13563	 11590	 0.001	 0.26219	 0.0	 121	 121	 121	 0.0	 0.0	 1	 -30.0	 30.0;
	11590	 4316	 0.03032	 0.14413	 0.0	 215	 215	 215	 0.0	 0.0	 1	 -30.0	 30.0;
	13563	 1107	 0.01325	 0.11038	 0.0	 285	 285	 285	 0.0	 0.0	 1	 -30.0	 30.0;
	3694	 12998	 0.011901	 0.07319	 0.0	 426	 426	 426	 0.0	 0.0	 1	 -30.0	 30.0;
	12998	 5555	 0.00401	 0.03175	 0.0	 988	 988	 988	 0.0	 0.0	 1	 -30.0	 30.0;
	12852	 4318	 0.00368	 0.03712	 0.0	 847	 847	 847	 0.0	 0.0	 1	 -30.0	 30.0;
	12852	 4243	 0.00169	 0.02158	 0.0	 1460	 1460	 1460	 0.0	 0.0	 1	 -30.0	 30.0;
	1141	 6805	 0.00116	 0.01472	 0.0	 2140	 2140	 2140	 0.0	 0.0	 1	 -30.0	 30.0;
	317	 10360	 0.05575	 0.602438	 0.0	 53	 53	 53	 0.0	 0.0	 1	 -30.0	 30.0;
	10360	 317	 0.00163	 0.01604	 0.0	 1960	 1960	 1960	 0.0	 0.0	 1	 -30.0	 30.0;
	10360	 4318	 0.00269	 0.02759	 0.0	 1140	 1140	 1140	 0.0	 0.0	 1	 -30.0	 30.0;
	10360	 9356	 0.00256	 0.02877	 0.0	 1094	 1094	 1094	 0.0	 0.0	 1	 -30.0	 30.0;
	1107	 12963	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	1107	 12963	 0.09549	 0.768967	 0.0	 41	 41	 41	 0.0	 0.0	 1	 -30.0	 30.0;
	7690	 633	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	7690	 633	 0.05899	 0.428306	 0.0	 74	 74	 74	 0.0	 0.0	 1	 -30.0	 30.0;
	7534	 633	 0.005591	 0.04031	 0.0	 777	 777	 777	 0.0	 0.0	 1	 -30.0	 30.0;
	12514	 633	 0.00714	 0.15039	 0.0	 210	 210	 210	 0.0	 0.0	 1	 -30.0	 30.0;
	1998	 7690	 0.005469	 0.041099	 0.0	 762	 762	 762	 0.0	 0.0	 1	 -30.0	 30.0;
	12514	 7690	 0.036711	 0.380269	 0.0	 83	 83	 83	 0.0	 0.0	 1	 -30.0	 30.0;
	7104	 317	 0.00056	 0.124578	 0.0	 254	 254	 254	 0.0	 0.0	 1	 -30.0	 30.0;
	7104	 317	 0.0007	 0.00889	 0.0	 3543	 3543	 3543	 0.0	 0.0	 1	 -30.0	 30.0;
	4850	 3694	 0.013479	 0.11436	 0.0	 275	 275	 275	 0.0	 0.0	 1	 -30.0	 30.0;
	4316	 4850	 0.012	 0.066919	 0.0	 465	 465	 465	 0.0	 0.0	 1	 -30.0	 30.0;
	5555	 3694	 0.3925	 1.654463	 0.0	 19	 19	 19	 0.0	 0.0	 1	 -30.0	 30.0;
	5874	 10131	 0.301178	 1.948719	 0.0	 17	 17	 17	 0.0	 0.0	 1	 -30.0	 30.0;
	5874	 10131	 0.009169	 0.06301	 0.0	 497	 497	 497	 0.0	 0.0	 1	 -30.0	 30.0;
	4911	 1141	 0.00176	 0.02342	 0.0	 1345	 1345	 1345	 0.0	 0.0	 1	 -30.0	 30.0;
	5421	 1141	 0.00108	 0.01167	 0.0	 2696	 2696	 2696	 0.0	 0.0	 1	 -30.0	 30.0;
	5555	 561	 0.191961	 1.234649	 0.0	 26	 26	 26	 0.0	 0.0	 1	 -30.0	 30.0;
	7843	 561	 0.03699	 0.374917	 0.0	 84	 84	 84	 0.0	 0.0	 1	 -30.0	 30.0;
	1998	 12597	 0.00361	 0.03024	 0.0	 1038	 1038	 1038	 0.0	 0.0	 1	 -30.0	 30.0;
	399	 10697	 0.350806	 1.554649	 0.0	 20	 20	 20	 0.0	 0.0	 1	 -30.0	 30.0;
	10697	 399	 0.004831	 0.06375	 0.0	 495	 495	 495	 0.0	 0.0	 1	 -30.0	 30.0;
	10697	 3667	 0.007099	 0.07076	 0.0	 445	 445	 445	 0.0	 0.0	 1	 -30.0	 30.0;
	9019	 399	 0.0022	 0.01318	 0.0	 2364	 2364	 2364	 0.0	 0.0	 1	 -30.0	 30.0;
	399	 1363	 0.01775	 0.099419	 0.0	 313	 313	 313	 0.0	 0.0	 1	 -30.0	 30.0;
	9019	 399	 0.186581	 1.067335	 0.0	 30	 30	 30	 0.0	 0.0	 1	 -30.0	 30.0;
	4318	 4243	 0.00373	 0.05005	 0.0	 630	 630	 630	 0.0	 0.0	 1	 -30.0	 30.0;
	5560	 1363	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	5560	 1363	 0.001	 0.16038	 0.0	 197	 197	 197	 0.0	 0.0	 1	 -30.0	 30.0;
	611	 1363	 0.010531	 0.17819	 0.0	 177	 177	 177	 0.0	 0.0	 1	 -30.0	 30.0;
	611	 1363	 0.0025	 0.017081	 0.0	 1830	 1830	 1830	 0.0	 0.0	 1	 -30.0	 30.0;
	611	 5560	 0.0777	 0.498492	 0.0	 63	 63	 63	 0.0	 0.0	 1	 -30.0	 30.0;
	11043	 2619	 0.01907	 1.485992	 0.0	 22	 22	 22	 0.0	 0.0	 1	 -30.0	 30.0;
	3037	 2619	 0.120669	 1.890888	 0.0	 17	 17	 17	 0.0	 0.0	 1	 -30.0	 30.0;
	13206	 7999	 0.010271	 0.06219	 0.0	 502	 502	 502	 0.0	 0.0	 1	 -30.0	 30.0;
	9015	 5874	 0.298079	 1.623781	 0.0	 20	 20	 20	 0.0	 0.0	 1	 -30.0	 30.0;
	13206	 5874	 0.273223	 1.612107	 0.0	 20	 20	 20	 0.0	 0.0	 1	 -30.0	 30.0;
	4318	 13061	 0.00277	 0.02823	 0.0	 1114	 1114	 1114	 0.0	 0.0	 1	 -30.0	 30.0;
	9356	 4318	 0.00077	 0.00747	 0.0	 4207	 4207	 4207	 0.0	 0.0	 1	 -30.0	 30.0;
	11162	 9162	 0.00102	 0.01145	 0.0	 2748	 2748	 2748	 0.0	 0.0	 1	 -30.0	 30.0;
	11162	 9162	 0.00112	 0.01049	 0.0	 2995	 2995	 2995	 0.0	 0.0	 1	 -30.0	 30.0;
	13206	 9015	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	13206	 9015	 0.001	 0.22343	 0.0	 142	 142	 142	 0.0	 0.0	 1	 -30.0	 30.0;
	8011	 5421	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	8011	 5421	 0.001	 0.26178	 0.0	 121	 121	 121	 0.0	 0.0	 1	 -30.0	 30.0;
	4911	 5421	 0.00153	 0.0214	 0.0	 1473	 1473	 1473	 0.0	 0.0	 1	 -30.0	 30.0;
	13061	 5421	 0.00468	 0.06143	 0.0	 513	 513	 513	 0.0	 0.0	 1	 -30.0	 30.0;
	314	 8240	 0.271756	 1.50345	 0.0	 21	 21	 21	 0.0	 0.0	 1	 -30.0	 30.0;
	3037	 11043	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	3037	 11043	 0.015271	 0.796736	 0.0	 40	 40	 40	 0.0	 0.0	 1	 -30.0	 30.0;
	314	 11043	 0.02776	 0.935537	 0.0	 34	 34	 34	 0.0	 0.0	 1	 -30.0	 30.0;
	314	 11043	 0.004219	 0.026599	 0.0	 1173	 1173	 1173	 0.0	 0.0	 1	 -30.0	 30.0;
	314	 3037	 0.001	 0.620888	 0.0	 51	 51	 51	 0.0	 0.0	 1	 -30.0	 30.0;
	7843	 5555	 0.361364	 1.973368	 0.0	 16	 16	 16	 0.0	 0.0	 1	 -30.0	 30.0;
	5745	 6712	 0.001599	 0.00825	 0.0	 3759	 3759	 3759	 0.0	 0.0	 1	 -30.0	 30.0;
	2926	 6712	 0.659194	 1.990062	 0.0	 16	 16	 16	 0.0	 0.0	 1	 -30.0	 30.0;
	9654	 246	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	9654	 246	 0.11788	 0.822417	 0.0	 39	 39	 39	 0.0	 0.0	 1	 -30.0	 30.0;
	5298	 246	 0.086341	 0.745145	 0.0	 43	 43	 43	 0.0	 0.0	 1	 -30.0	 30.0;
	5298	 9654	 0.00569	 0.033281	 0.0	 936	 936	 936	 0.0	 0.0	 1	 -30.0	 30.0;
	5298	 9654	 0.03618	 0.609897	 0.0	 52	 52	 52	 0.0	 0.0	 1	 -30.0	 30.0;
	34	 7104	 0.00087	 0.00898	 0.0	 3502	 3502	 3502	 0.0	 0.0	 1	 -30.0	 30.0;
	200	 5474	 0.001	 0.211322	 0.0	 150	 150	 150	 0.0	 0.0	 1	 -30.0	 30.0;
	200	 5474	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	4316	 5474	 0.13407	 1.029876	 0.0	 31	 31	 31	 0.0	 0.0	 1	 -30.0	 30.0;
	2617	 5474	 0.141419	 0.956033	 0.0	 33	 33	 33	 0.0	 0.0	 1	 -30.0	 30.0;
	4316	 200	 0.12913	 1.151054	 0.0	 28	 28	 28	 0.0	 0.0	 1	 -30.0	 30.0;
	2617	 200	 0.14487	 1.008244	 0.0	 32	 32	 32	 0.0	 0.0	 1	 -30.0	 30.0;
	200	 2617	 0.007599	 0.05356	 0.0	 584	 584	 584	 0.0	 0.0	 1	 -30.0	 30.0;
	10849	 4325	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	10849	 4325	 0.024219	 0.488657	 0.0	 65	 65	 65	 0.0	 0.0	 1	 -30.0	 30.0;
	2617	 4316	 0.001	 0.226901	 0.0	 140	 140	 140	 0.0	 0.0	 1	 -30.0	 30.0;
	2617	 4316	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	10968	 5867	 0.00063	 0.005159	 0.0	 6078	 6078	 6078	 0.0	 0.0	 1	 -30.0	 30.0;
	5950	 3667	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	5950	 3667	 0.001	 0.214277	 0.0	 148	 148	 148	 0.0	 0.0	 1	 -30.0	 30.0;
	4873	 6248	 0.019671	 0.07004	 0.0	 435	 435	 435	 0.0	 0.0	 1	 -30.0	 30.0;
	4873	 6248	 0.01812	 0.06872	 0.0	 445	 445	 445	 0.0	 0.0	 1	 -30.0	 30.0;
	8437	 6920	 0.001582	 0.00724	 0.0	 4263	 4263	 4263	 0.0	 0.0	 1	 -30.0	 30.0;
	8437	 6920	 0.001551	 0.007231	 0.0	 4272	 4272	 4272	 0.0	 0.0	 1	 -30.0	 30.0;
	8437	 6920	 0.001262	 0.00796	 0.0	 3920	 3920	 3920	 0.0	 0.0	 1	 -30.0	 30.0;
	7935	 3919	 0.0264	 0.075129	 0.0	 397	 397	 397	 0.0	 0.0	 1	 -30.0	 30.0;
	7935	 7693	 0.00824	 0.044751	 0.0	 695	 695	 695	 0.0	 0.0	 1	 -30.0	 30.0;
	11572	 6920	 0.018271	 0.070191	 0.0	 436	 436	 436	 0.0	 0.0	 1	 -30.0	 30.0;
	11572	 6920	 0.021711	 0.063129	 0.0	 474	 474	 474	 0.0	 0.0	 1	 -30.0	 30.0;
	11572	 11064	 0.013191	 0.0428	 0.0	 706	 706	 706	 0.0	 0.0	 1	 -30.0	 30.0;
	13366	 3919	 0.027631	 0.102502	 0.0	 298	 298	 298	 0.0	 0.0	 1	 -30.0	 30.0;
	13366	 10792	 0.005369	 0.052622	 0.0	 598	 598	 598	 0.0	 0.0	 1	 -30.0	 30.0;
	13366	 10792	 0.013938	 0.0534	 0.0	 573	 573	 573	 0.0	 0.0	 1	 -30.0	 30.0;
	13366	 10792	 0.01364	 0.049449	 0.0	 616	 616	 616	 0.0	 0.0	 1	 -30.0	 30.0;
	13366	 1993	 0.007991	 0.037738	 0.0	 819	 819	 819	 0.0	 0.0	 1	 -30.0	 30.0;
	6349	 6920	 0.007671	 0.04096	 0.0	 758	 758	 758	 0.0	 0.0	 1	 -30.0	 30.0;
	6349	 6920	 0.007511	 0.041769	 0.0	 745	 745	 745	 0.0	 0.0	 1	 -30.0	 30.0;
	6349	 7566	 0.004089	 0.010978	 0.0	 2697	 2697	 2697	 0.0	 0.0	 1	 -30.0	 30.0;
	6349	 7566	 0.003	 0.014769	 0.0	 2096	 2096	 2096	 0.0	 0.0	 1	 -30.0	 30.0;
	6349	 891	 0.001351	 0.00784	 0.0	 3971	 3971	 3971	 0.0	 0.0	 1	 -30.0	 30.0;
	6349	 8438	 0.003671	 0.022089	 0.0	 1411	 1411	 1411	 0.0	 0.0	 1	 -30.0	 30.0;
	6349	 4251	 0.002378	 0.00772	 0.0	 3911	 3911	 3911	 0.0	 0.0	 1	 -30.0	 30.0;
	6920	 891	 0.006911	 0.03268	 0.0	 946	 946	 946	 0.0	 0.0	 1	 -30.0	 30.0;
	6920	 3030	 0.00944	 0.03284	 0.0	 925	 925	 925	 0.0	 0.0	 1	 -30.0	 30.0;
	6920	 6378	 0.009831	 0.02848	 0.0	 1049	 1049	 1049	 0.0	 0.0	 1	 -30.0	 30.0;
	6920	 8438	 0.003671	 0.02092	 0.0	 1488	 1488	 1488	 0.0	 0.0	 1	 -30.0	 30.0;
	12999	 3919	 0.019378	 0.10932	 0.0	 285	 285	 285	 0.0	 0.0	 1	 -30.0	 30.0;
	12999	 3919	 0.021969	 0.107129	 0.0	 289	 289	 289	 0.0	 0.0	 1	 -30.0	 30.0;
	12999	 7693	 0.009151	 0.063249	 0.0	 495	 495	 495	 0.0	 0.0	 1	 -30.0	 30.0;
	12999	 6050	 0.029169	 0.088102	 0.0	 341	 341	 341	 0.0	 0.0	 1	 -30.0	 30.0;
	12999	 7135	 0.031351	 0.115698	 0.0	 264	 264	 264	 0.0	 0.0	 1	 -30.0	 30.0;
	12999	 10792	 0.04936	 0.182018	 0.0	 168	 168	 168	 0.0	 0.0	 1	 -30.0	 30.0;
	12999	 9259	 0.001609	 0.016889	 0.0	 1862	 1862	 1862	 0.0	 0.0	 1	 -30.0	 30.0;
	12999	 4033	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	1022	 13210	 0.008698	 0.033591	 0.0	 911	 911	 911	 0.0	 0.0	 1	 -30.0	 30.0;
	8027	 2649	 0.01792	 0.070169	 0.0	 437	 437	 437	 0.0	 0.0	 1	 -30.0	 30.0;
	8027	 12751	 0.00308	 0.008422	 0.0	 3523	 3523	 3523	 0.0	 0.0	 1	 -30.0	 30.0;
	8027	 810	 0.002031	 0.012102	 0.0	 2575	 2575	 2575	 0.0	 0.0	 1	 -30.0	 30.0;
	8027	 810	 0.0068	 0.03452	 0.0	 898	 898	 898	 0.0	 0.0	 1	 -30.0	 30.0;
	8027	 5565	 0.01176	 0.055871	 0.0	 554	 554	 554	 0.0	 0.0	 1	 -30.0	 30.0;
	6379	 6378	 0.04856	 0.135111	 0.0	 221	 221	 221	 0.0	 0.0	 1	 -30.0	 30.0;
	3919	 9044	 0.039289	 0.146129	 0.0	 209	 209	 209	 0.0	 0.0	 1	 -30.0	 30.0;
	3919	 9044	 0.038471	 0.148938	 0.0	 206	 206	 206	 0.0	 0.0	 1	 -30.0	 30.0;
	3919	 4981	 0.010911	 0.04116	 0.0	 742	 742	 742	 0.0	 0.0	 1	 -30.0	 30.0;
	9044	 1993	 0.002898	 0.017409	 0.0	 1790	 1790	 1790	 0.0	 0.0	 1	 -30.0	 30.0;
	7323	 1767	 0.00544	 0.051431	 0.0	 611	 611	 611	 0.0	 0.0	 1	 -30.0	 30.0;
	7323	 7775	 0.003791	 0.014342	 0.0	 2130	 2130	 2130	 0.0	 0.0	 1	 -30.0	 30.0;
	7323	 8630	 0.005969	 0.026302	 0.0	 1172	 1172	 1172	 0.0	 0.0	 1	 -30.0	 30.0;
	7323	 1254	 0.00608	 0.02572	 0.0	 1196	 1196	 1196	 0.0	 0.0	 1	 -30.0	 30.0;
	7323	 3809	 0.010818	 0.066769	 0.0	 467	 467	 467	 0.0	 0.0	 1	 -30.0	 30.0;
	2649	 3445	 0.006649	 0.024138	 0.0	 1262	 1262	 1262	 0.0	 0.0	 1	 -30.0	 30.0;
	2649	 3445	 0.007542	 0.023662	 0.0	 1272	 1272	 1272	 0.0	 0.0	 1	 -30.0	 30.0;
	2649	 3445	 0.007991	 0.036622	 0.0	 843	 843	 843	 0.0	 0.0	 1	 -30.0	 30.0;
	2649	 3445	 0.0116	 0.046018	 0.0	 666	 666	 666	 0.0	 0.0	 1	 -30.0	 30.0;
	6050	 3030	 0.011631	 0.047049	 0.0	 652	 652	 652	 0.0	 0.0	 1	 -30.0	 30.0;
	7135	 10792	 0.018822	 0.064009	 0.0	 474	 474	 474	 0.0	 0.0	 1	 -30.0	 30.0;
	1767	 8630	 0.008071	 0.049138	 0.0	 635	 635	 635	 0.0	 0.0	 1	 -30.0	 30.0;
	1767	 1254	 0.007889	 0.045502	 0.0	 684	 684	 684	 0.0	 0.0	 1	 -30.0	 30.0;
	1767	 12185	 0.009822	 0.057222	 0.0	 545	 545	 545	 0.0	 0.0	 1	 -30.0	 30.0;
	3445	 5461	 0.00656	 0.023831	 0.0	 1278	 1278	 1278	 0.0	 0.0	 1	 -30.0	 30.0;
	3445	 5461	 0.007431	 0.023351	 0.0	 1290	 1290	 1290	 0.0	 0.0	 1	 -30.0	 30.0;
	3445	 10863	 0.007391	 0.026978	 0.0	 1130	 1130	 1130	 0.0	 0.0	 1	 -30.0	 30.0;
	3445	 6269	 0.001871	 0.012142	 0.0	 2572	 2572	 2572	 0.0	 0.0	 1	 -30.0	 30.0;
	3445	 1398	 0.003969	 0.026169	 0.0	 1194	 1194	 1194	 0.0	 0.0	 1	 -30.0	 30.0;
	3445	 3140	 0.008151	 0.04664	 0.0	 668	 668	 668	 0.0	 0.0	 1	 -30.0	 30.0;
	12062	 49	 0.00076	 0.005622	 0.0	 5568	 5568	 5568	 0.0	 0.0	 1	 -30.0	 30.0;
	12062	 5461	 0.0094	 0.035791	 0.0	 854	 854	 854	 0.0	 0.0	 1	 -30.0	 30.0;
	12062	 11425	 0.00844	 0.031031	 0.0	 983	 983	 983	 0.0	 0.0	 1	 -30.0	 30.0;
	12062	 2404	 0.00028	 0.002062	 0.0	 15180	 15180	 15180	 0.0	 0.0	 1	 -30.0	 30.0;
	12062	 4146	 0.004849	 0.030031	 0.0	 1039	 1039	 1039	 0.0	 0.0	 1	 -30.0	 30.0;
	12062	 6269	 0.00268	 0.022391	 0.0	 1401	 1401	 1401	 0.0	 0.0	 1	 -30.0	 30.0;
	12062	 1398	 0.002391	 0.025382	 0.0	 1239	 1239	 1239	 0.0	 0.0	 1	 -30.0	 30.0;
	810	 5461	 0.017551	 0.078191	 0.0	 395	 395	 395	 0.0	 0.0	 1	 -30.0	 30.0;
	9519	 2208	 0.003849	 0.02475	 0.0	 1262	 1262	 1262	 0.0	 0.0	 1	 -30.0	 30.0;
	9519	 10291	 0.0042	 0.02005	 0.0	 1542	 1542	 1542	 0.0	 0.0	 1	 -30.0	 30.0;
	9519	 5259	 0.00011	 0.000581	 0.0	 53419	 53419	 53419	 0.0	 0.0	 1	 -30.0	 30.0;
	9519	 1129	 0.000169	 0.000651	 0.0	 46965	 46965	 46965	 0.0	 0.0	 1	 -30.0	 30.0;
	9519	 3089	 0.000169	 0.000659	 0.0	 46430	 46430	 46430	 0.0	 0.0	 1	 -30.0	 30.0;
	11655	 9126	 0.00219	 0.01125	 0.0	 2757	 2757	 2757	 0.0	 0.0	 1	 -30.0	 30.0;
	11655	 13245	 0.00018	 0.000599	 0.0	 50503	 50503	 50503	 0.0	 0.0	 1	 -30.0	 30.0;
	11655	 13120	 0.00018	 0.000591	 0.0	 51129	 51129	 51129	 0.0	 0.0	 1	 -30.0	 30.0;
	11655	 2471	 0.00019	 0.000581	 0.0	 51675	 51675	 51675	 0.0	 0.0	 1	 -30.0	 30.0;
	11655	 4759	 0.000169	 0.000651	 0.0	 46965	 46965	 46965	 0.0	 0.0	 1	 -30.0	 30.0;
	3827	 2814	 0.00231	 0.0138	 0.0	 2258	 2258	 2258	 0.0	 0.0	 1	 -30.0	 30.0;
	3827	 2814	 0.00082	 0.003841	 0.0	 8043	 8043	 8043	 0.0	 0.0	 1	 -30.0	 30.0;
	3827	 254	 0.00305	 0.01762	 0.0	 1767	 1767	 1767	 0.0	 0.0	 1	 -30.0	 30.0;
	8247	 7778	 0.01101	 0.055469	 0.0	 559	 559	 559	 0.0	 0.0	 1	 -30.0	 30.0;
	8247	 1849	 0.009169	 0.0462	 0.0	 671	 671	 671	 0.0	 0.0	 1	 -30.0	 30.0;
	8247	 10291	 0.00201	 0.00905	 0.0	 3408	 3408	 3408	 0.0	 0.0	 1	 -30.0	 30.0;
	8247	 2859	 0.005969	 0.038841	 0.0	 804	 804	 804	 0.0	 0.0	 1	 -30.0	 30.0;
	8247	 11381	 0.00474	 0.02687	 0.0	 1158	 1158	 1158	 0.0	 0.0	 1	 -30.0	 30.0;
	8247	 8082	 0.005409	 0.03438	 0.0	 908	 908	 908	 0.0	 0.0	 1	 -30.0	 30.0;
	8247	 4654	 0.005401	 0.03264	 0.0	 955	 955	 955	 0.0	 0.0	 1	 -30.0	 30.0;
	8247	 13253	 0.00311	 0.015919	 0.0	 1948	 1948	 1948	 0.0	 0.0	 1	 -30.0	 30.0;
	8247	 2531	 0.00462	 0.02613	 0.0	 1191	 1191	 1191	 0.0	 0.0	 1	 -30.0	 30.0;
	4609	 1596	 0.01044	 0.05187	 0.0	 597	 597	 597	 0.0	 0.0	 1	 -30.0	 30.0;
	4609	 1596	 0.01001	 0.05113	 0.0	 607	 607	 607	 0.0	 0.0	 1	 -30.0	 30.0;
	4609	 12530	 0.008331	 0.051729	 0.0	 603	 603	 603	 0.0	 0.0	 1	 -30.0	 30.0;
	4609	 960	 0.000169	 0.00089	 0.0	 34869	 34869	 34869	 0.0	 0.0	 1	 -30.0	 30.0;
	4609	 5860	 0.00214	 0.01099	 0.0	 2822	 2822	 2822	 0.0	 0.0	 1	 -30.0	 30.0;
	2814	 8480	 0.004669	 0.042349	 0.0	 742	 742	 742	 0.0	 0.0	 1	 -30.0	 30.0;
	2814	 10624	 0.00139	 0.008789	 0.0	 3550	 3550	 3550	 0.0	 0.0	 1	 -30.0	 30.0;
	2814	 10624	 0.000219	 0.001669	 0.0	 18766	 18766	 18766	 0.0	 0.0	 1	 -30.0	 30.0;
	2814	 254	 0.00119	 0.01063	 0.0	 2954	 2954	 2954	 0.0	 0.0	 1	 -30.0	 30.0;
	5100	 2859	 0.004169	 0.02724	 0.0	 1147	 1147	 1147	 0.0	 0.0	 1	 -30.0	 30.0;
	5100	 2859	 0.004081	 0.025219	 0.0	 1237	 1237	 1237	 0.0	 0.0	 1	 -30.0	 30.0;
	5100	 468	 0.00168	 0.01039	 0.0	 3002	 3002	 3002	 0.0	 0.0	 1	 -30.0	 30.0;
	5100	 2118	 0.0017	 0.01055	 0.0	 2956	 2956	 2956	 0.0	 0.0	 1	 -30.0	 30.0;
	10949	 10161	 0.00139	 0.008771	 0.0	 3557	 3557	 3557	 0.0	 0.0	 1	 -30.0	 30.0;
	10949	 9330	 0.000651	 0.00261	 0.0	 11743	 11743	 11743	 0.0	 0.0	 1	 -30.0	 30.0;
	10949	 9330	 0.000729	 0.00256	 0.0	 11868	 11868	 11868	 0.0	 0.0	 1	 -30.0	 30.0;
	10949	 1754	 0.0	 0.008169	 0.0	 3867	 3867	 3867	 0.0	 0.0	 1	 -30.0	 30.0;
	10949	 8227	 5e-05	 0.00025	 0.0	 123896	 123896	 123896	 0.0	 0.0	 1	 -30.0	 30.0;
	8259	 1849	 0.003719	 0.022669	 0.0	 1376	 1376	 1376	 0.0	 0.0	 1	 -30.0	 30.0;
	8259	 9390	 0.00732	 0.042711	 0.0	 729	 729	 729	 0.0	 0.0	 1	 -30.0	 30.0;
	8259	 9390	 0.003599	 0.025331	 0.0	 1235	 1235	 1235	 0.0	 0.0	 1	 -30.0	 30.0;
	8259	 13301	 0.00494	 0.027401	 0.0	 1135	 1135	 1135	 0.0	 0.0	 1	 -30.0	 30.0;
	7778	 9925	 0.0062	 0.03519	 0.0	 885	 885	 885	 0.0	 0.0	 1	 -30.0	 30.0;
	7778	 9925	 0.00739	 0.04574	 0.0	 682	 682	 682	 0.0	 0.0	 1	 -30.0	 30.0;
	7778	 4654	 0.006781	 0.034289	 0.0	 904	 904	 904	 0.0	 0.0	 1	 -30.0	 30.0;
	9925	 4401	 0.003669	 0.03205	 0.0	 980	 980	 980	 0.0	 0.0	 1	 -30.0	 30.0;
	9925	 4401	 0.002789	 0.026289	 0.0	 1195	 1195	 1195	 0.0	 0.0	 1	 -30.0	 30.0;
	9925	 3679	 0.005979	 0.031979	 0.0	 971	 971	 971	 0.0	 0.0	 1	 -30.0	 30.0;
	4401	 9126	 0.00425	 0.02132	 0.0	 1453	 1453	 1453	 0.0	 0.0	 1	 -30.0	 30.0;
	4401	 2208	 0.002469	 0.015099	 0.0	 2065	 2065	 2065	 0.0	 0.0	 1	 -30.0	 30.0;
	4401	 13245	 0.004341	 0.02662	 0.0	 1172	 1172	 1172	 0.0	 0.0	 1	 -30.0	 30.0;
	4401	 4759	 0.005219	 0.02287	 0.0	 1347	 1347	 1347	 0.0	 0.0	 1	 -30.0	 30.0;
	4401	 11149	 0.0095	 0.04693	 0.0	 660	 660	 660	 0.0	 0.0	 1	 -30.0	 30.0;
	8480	 254	 0.01099	 0.052909	 0.0	 585	 585	 585	 0.0	 0.0	 1	 -30.0	 30.0;
	8480	 9390	 0.004901	 0.02949	 0.0	 1057	 1057	 1057	 0.0	 0.0	 1	 -30.0	 30.0;
	8480	 6951	 0.00832	 0.038531	 0.0	 802	 802	 802	 0.0	 0.0	 1	 -30.0	 30.0;
	8480	 9050	 0.003909	 0.018091	 0.0	 1707	 1707	 1707	 0.0	 0.0	 1	 -30.0	 30.0;
	8480	 2846	 0.000331	 0.00189	 0.0	 16463	 16463	 16463	 0.0	 0.0	 1	 -30.0	 30.0;
	1849	 9390	 0.01101	 0.05514	 0.0	 562	 562	 562	 0.0	 0.0	 1	 -30.0	 30.0;
	1849	 10982	 0.00345	 0.01925	 0.0	 1616	 1616	 1616	 0.0	 0.0	 1	 -30.0	 30.0;
	13464	 254	 0.00162	 0.00889	 0.0	 3496	 3496	 3496	 0.0	 0.0	 1	 -30.0	 30.0;
	13464	 13301	 0.00039	 0.00464	 0.0	 6784	 6784	 6784	 0.0	 0.0	 1	 -30.0	 30.0;
	13464	 7806	 0.00064	 0.010099	 0.0	 3122	 3122	 3122	 0.0	 0.0	 1	 -30.0	 30.0;
	9126	 10161	 0.003151	 0.01613	 0.0	 1922	 1922	 1922	 0.0	 0.0	 1	 -30.0	 30.0;
	9126	 10161	 0.002091	 0.012409	 0.0	 2511	 2511	 2511	 0.0	 0.0	 1	 -30.0	 30.0;
	9126	 13513	 0.0	 0.00799	 0.0	 3954	 3954	 3954	 0.0	 0.0	 1	 -30.0	 30.0;
	9126	 9305	 0.0	 0.00906	 0.0	 3487	 3487	 3487	 0.0	 0.0	 1	 -30.0	 30.0;
	9126	 10284	 0.000909	 0.010401	 0.0	 3026	 3026	 3026	 0.0	 0.0	 1	 -30.0	 30.0;
	9126	 3584	 0.003211	 0.016081	 0.0	 1927	 1927	 1927	 0.0	 0.0	 1	 -30.0	 30.0;
	9126	 13120	 0.00314	 0.017711	 0.0	 1757	 1757	 1757	 0.0	 0.0	 1	 -30.0	 30.0;
	9126	 2471	 0.00214	 0.010591	 0.0	 2924	 2924	 2924	 0.0	 0.0	 1	 -30.0	 30.0;
	5094	 4654	 0.00056	 0.003169	 0.0	 9816	 9816	 9816	 0.0	 0.0	 1	 -30.0	 30.0;
	10624	 10599	 0.001719	 0.0108	 0.0	 2889	 2889	 2889	 0.0	 0.0	 1	 -30.0	 30.0;
	10161	 5813	 0.0005	 0.00174	 0.0	 17448	 17448	 17448	 0.0	 0.0	 1	 -30.0	 30.0;
	10161	 8227	 0.00126	 0.00587	 0.0	 5262	 5262	 5262	 0.0	 0.0	 1	 -30.0	 30.0;
	10169	 3679	 0.007909	 0.03607	 0.0	 856	 856	 856	 0.0	 0.0	 1	 -30.0	 30.0;
	10169	 10284	 0.00057	 0.00457	 0.0	 6859	 6859	 6859	 0.0	 0.0	 1	 -30.0	 30.0;
	10169	 8227	 0.00132	 0.008409	 0.0	 3711	 3711	 3711	 0.0	 0.0	 1	 -30.0	 30.0;
	254	 3532	 0.003581	 0.017289	 0.0	 1790	 1790	 1790	 0.0	 0.0	 1	 -30.0	 30.0;
	254	 6951	 0.002711	 0.01526	 0.0	 2039	 2039	 2039	 0.0	 0.0	 1	 -30.0	 30.0;
	254	 9217	 0.00039	 0.006081	 0.0	 5184	 5184	 5184	 0.0	 0.0	 1	 -30.0	 30.0;
	254	 7806	 0.00037	 0.005409	 0.0	 5827	 5827	 5827	 0.0	 0.0	 1	 -30.0	 30.0;
	254	 10599	 0.00244	 0.013789	 0.0	 2256	 2256	 2256	 0.0	 0.0	 1	 -30.0	 30.0;
	5813	 3584	 0.000349	 0.00149	 0.0	 20641	 20641	 20641	 0.0	 0.0	 1	 -30.0	 30.0;
	3532	 9390	 0.00212	 0.010531	 0.0	 2941	 2941	 2941	 0.0	 0.0	 1	 -30.0	 30.0;
	563	 7785	 0.003039	 0.031151	 0.0	 1010	 1010	 1010	 0.0	 0.0	 1	 -30.0	 30.0;
	563	 9050	 0.001831	 0.0187	 0.0	 1682	 1682	 1682	 0.0	 0.0	 1	 -30.0	 30.0;
	2631	 7491	 0.006599	 0.043169	 0.0	 724	 724	 724	 0.0	 0.0	 1	 -30.0	 30.0;
	2631	 7443	 0.006729	 0.046599	 0.0	 671	 671	 671	 0.0	 0.0	 1	 -30.0	 30.0;
	2631	 5339	 0.002159	 0.010789	 0.0	 2871	 2871	 2871	 0.0	 0.0	 1	 -30.0	 30.0;
	2631	 1134	 0.0022	 0.01057	 0.0	 2926	 2926	 2926	 0.0	 0.0	 1	 -30.0	 30.0;
	2631	 1490	 0.003461	 0.02049	 0.0	 1521	 1521	 1521	 0.0	 0.0	 1	 -30.0	 30.0;
	11795	 1016	 0.00311	 0.019469	 0.0	 1603	 1603	 1603	 0.0	 0.0	 1	 -30.0	 30.0;
	11795	 915	 0.01064	 0.065969	 0.0	 473	 473	 473	 0.0	 0.0	 1	 -30.0	 30.0;
	1596	 468	 0.003539	 0.020479	 0.0	 1520	 1520	 1520	 0.0	 0.0	 1	 -30.0	 30.0;
	1596	 2118	 0.00357	 0.020719	 0.0	 1503	 1503	 1503	 0.0	 0.0	 1	 -30.0	 30.0;
	1596	 7491	 0.00275	 0.013831	 0.0	 2240	 2240	 2240	 0.0	 0.0	 1	 -30.0	 30.0;
	1596	 7443	 0.0028	 0.013531	 0.0	 2287	 2287	 2287	 0.0	 0.0	 1	 -30.0	 30.0;
	9390	 9050	 0.005151	 0.04851	 0.0	 648	 648	 648	 0.0	 0.0	 1	 -30.0	 30.0;
	9390	 12530	 0.005401	 0.025281	 0.0	 1222	 1222	 1222	 0.0	 0.0	 1	 -30.0	 30.0;
	9390	 12530	 0.0055	 0.02475	 0.0	 1246	 1246	 1246	 0.0	 0.0	 1	 -30.0	 30.0;
	10982	 8082	 0.00093	 0.00538	 0.0	 5786	 5786	 5786	 0.0	 0.0	 1	 -30.0	 30.0;
	10291	 2859	 0.010331	 0.061849	 0.0	 504	 504	 504	 0.0	 0.0	 1	 -30.0	 30.0;
	12487	 5339	 0.00686	 0.032771	 0.0	 944	 944	 944	 0.0	 0.0	 1	 -30.0	 30.0;
	12487	 1134	 0.007	 0.032081	 0.0	 962	 962	 962	 0.0	 0.0	 1	 -30.0	 30.0;
	7785	 6120	 0.007729	 0.038099	 0.0	 813	 813	 813	 0.0	 0.0	 1	 -30.0	 30.0;
	6120	 1016	 0.006581	 0.035281	 0.0	 881	 881	 881	 0.0	 0.0	 1	 -30.0	 30.0;
	6120	 1016	 0.003711	 0.02651	 0.0	 1181	 1181	 1181	 0.0	 0.0	 1	 -30.0	 30.0;
	6120	 6356	 0.00482	 0.021979	 0.0	 1404	 1404	 1404	 0.0	 0.0	 1	 -30.0	 30.0;
	6120	 6356	 0.003979	 0.026099	 0.0	 1197	 1197	 1197	 0.0	 0.0	 1	 -30.0	 30.0;
	2859	 13253	 0.0038	 0.017271	 0.0	 1787	 1787	 1787	 0.0	 0.0	 1	 -30.0	 30.0;
	2859	 11216	 0.00626	 0.03626	 0.0	 859	 859	 859	 0.0	 0.0	 1	 -30.0	 30.0;
	12530	 915	 0.00538	 0.02588	 0.0	 1195	 1195	 1195	 0.0	 0.0	 1	 -30.0	 30.0;
	12530	 915	 0.005479	 0.025341	 0.0	 1219	 1219	 1219	 0.0	 0.0	 1	 -30.0	 30.0;
	186	 13247	 0.00134	 0.01235	 0.0	 2543	 2543	 2543	 0.0	 0.0	 1	 -30.0	 30.0;
	186	 789	 0.00127	 0.01399	 0.0	 2249	 2249	 2249	 0.0	 0.0	 1	 -30.0	 30.0;
	186	 11488	 0.00142	 0.01374	 0.0	 2287	 2287	 2287	 0.0	 0.0	 1	 -30.0	 30.0;
	11490	 11719	 0.00039	 0.00365	 0.0	 8606	 8606	 8606	 0.0	 0.0	 1	 -30.0	 30.0;
	11490	 5201	 0.00058	 0.00507	 0.0	 6190	 6190	 6190	 0.0	 0.0	 1	 -30.0	 30.0;
	1463	 9196	 0.00129	 0.01577	 0.0	 1997	 1997	 1997	 0.0	 0.0	 1	 -30.0	 30.0;
	1463	 4330	 0.00033	 0.00373	 0.0	 8436	 8436	 8436	 0.0	 0.0	 1	 -30.0	 30.0;
	1463	 5331	 0.00086	 0.00799	 0.0	 3931	 3931	 3931	 0.0	 0.0	 1	 -30.0	 30.0;
	1900	 5331	 0.00189	 0.02135	 0.0	 1474	 1474	 1474	 0.0	 0.0	 1	 -30.0	 30.0;
	1900	 5483	 0.00106	 0.01219	 0.0	 2582	 2582	 2582	 0.0	 0.0	 1	 -30.0	 30.0;
	1900	 11869	 0.00147	 0.01622	 0.0	 1940	 1940	 1940	 0.0	 0.0	 1	 -30.0	 30.0;
	1900	 9534	 0.00215	 0.02108	 0.0	 1491	 1491	 1491	 0.0	 0.0	 1	 -30.0	 30.0;
	647	 3465	 0.00063	 0.0052	 0.0	 6031	 6031	 6031	 0.0	 0.0	 1	 -30.0	 30.0;
	647	 5331	 0.00159	 0.01792	 0.0	 1756	 1756	 1756	 0.0	 0.0	 1	 -30.0	 30.0;
	9196	 5483	 0.00157	 0.01981	 0.0	 1590	 1590	 1590	 0.0	 0.0	 1	 -30.0	 30.0;
	9196	 11869	 0.00158	 0.02014	 0.0	 1564	 1564	 1564	 0.0	 0.0	 1	 -30.0	 30.0;
	3465	 13247	 0.0018	 0.02388	 0.0	 1320	 1320	 1320	 0.0	 0.0	 1	 -30.0	 30.0;
	3465	 801	 0.00034	 0.00318	 0.0	 9877	 9877	 9877	 0.0	 0.0	 1	 -30.0	 30.0;
	3465	 10345	 0.00015	 0.00132	 0.0	 23777	 23777	 23777	 0.0	 0.0	 1	 -30.0	 30.0;
	3465	 12695	 0.00014	 0.0015	 0.0	 20968	 20968	 20968	 0.0	 0.0	 1	 -30.0	 30.0;
	3465	 1655	 0.00013	 0.00153	 0.0	 20572	 20572	 20572	 0.0	 0.0	 1	 -30.0	 30.0;
	3465	 4742	 0.00013	 0.00156	 0.0	 20179	 20179	 20179	 0.0	 0.0	 1	 -30.0	 30.0;
	3465	 8461	 0.0004	 0.00449	 0.0	 7008	 7008	 7008	 0.0	 0.0	 1	 -30.0	 30.0;
	3465	 8461	 0.00045	 0.0044	 0.0	 7142	 7142	 7142	 0.0	 0.0	 1	 -30.0	 30.0;
	13247	 2715	 0.0023	 0.01984	 0.0	 1582	 1582	 1582	 0.0	 0.0	 1	 -30.0	 30.0;
	13247	 13348	 0.0002	 0.00235	 0.0	 13394	 13394	 13394	 0.0	 0.0	 1	 -30.0	 30.0;
	13247	 8743	 0.00019	 0.00239	 0.0	 13175	 13175	 13175	 0.0	 0.0	 1	 -30.0	 30.0;
	13247	 11445	 0.00169	 0.01602	 0.0	 1961	 1961	 1961	 0.0	 0.0	 1	 -30.0	 30.0;
	13247	 12752	 0.00024	 0.00253	 0.0	 12430	 12430	 12430	 0.0	 0.0	 1	 -30.0	 30.0;
	13247	 12044	 0.00022	 0.00244	 0.0	 12894	 12894	 12894	 0.0	 0.0	 1	 -30.0	 30.0;
	13247	 1977	 0.00025	 0.00239	 0.0	 13145	 13145	 13145	 0.0	 0.0	 1	 -30.0	 30.0;
	12100	 11719	 0.00066	 0.0061	 0.0	 5149	 5149	 5149	 0.0	 0.0	 1	 -30.0	 30.0;
	12100	 11719	 0.00062	 0.00844	 0.0	 3733	 3733	 3733	 0.0	 0.0	 1	 -30.0	 30.0;
	12100	 11547	 0.00124	 0.01353	 0.0	 2325	 2325	 2325	 0.0	 0.0	 1	 -30.0	 30.0;
	12100	 9043	 0.00046	 0.00452	 0.0	 6953	 6953	 6953	 0.0	 0.0	 1	 -30.0	 30.0;
	4330	 5331	 0.00045	 0.00531	 0.0	 5928	 5928	 5928	 0.0	 0.0	 1	 -30.0	 30.0;
	4330	 801	 0.00123	 0.01433	 0.0	 2197	 2197	 2197	 0.0	 0.0	 1	 -30.0	 30.0;
	4330	 11445	 0.00174	 0.01696	 0.0	 1853	 1853	 1853	 0.0	 0.0	 1	 -30.0	 30.0;
	7038	 9043	 0.00086	 0.00877	 0.0	 3585	 3585	 3585	 0.0	 0.0	 1	 -30.0	 30.0;
	7038	 5201	 0.00096	 0.00999	 0.0	 3148	 3148	 3148	 0.0	 0.0	 1	 -30.0	 30.0;
	7038	 7217	 0.00082	 0.00761	 0.0	 4127	 4127	 4127	 0.0	 0.0	 1	 -30.0	 30.0;
	11719	 9534	 0.00185	 0.01803	 0.0	 1743	 1743	 1743	 0.0	 0.0	 1	 -30.0	 30.0;
	11719	 9511	 0.00138	 0.01246	 0.0	 2520	 2520	 2520	 0.0	 0.0	 1	 -30.0	 30.0;
	11719	 11737	 0.00062	 0.00605	 0.0	 5194	 5194	 5194	 0.0	 0.0	 1	 -30.0	 30.0;
	11719	 5201	 0.00073	 0.00817	 0.0	 3851	 3851	 3851	 0.0	 0.0	 1	 -30.0	 30.0;
	789	 13219	 0.00094	 0.00999	 0.0	 3148	 3148	 3148	 0.0	 0.0	 1	 -30.0	 30.0;
	789	 5866	 0.00058	 0.00671	 0.0	 4691	 4691	 4691	 0.0	 0.0	 1	 -30.0	 30.0;
	5483	 9534	 0.00108	 0.01279	 0.0	 2461	 2461	 2461	 0.0	 0.0	 1	 -30.0	 30.0;
	5483	 11737	 0.00225	 0.02472	 0.0	 1273	 1273	 1273	 0.0	 0.0	 1	 -30.0	 30.0;
	5483	 6664	 0.00019	 0.00244	 0.0	 12907	 12907	 12907	 0.0	 0.0	 1	 -30.0	 30.0;
	5483	 9272	 0.00018	 0.00248	 0.0	 12704	 12704	 12704	 0.0	 0.0	 1	 -30.0	 30.0;
	5483	 397	 0.0001	 0.0011	 0.0	 28598	 28598	 28598	 0.0	 0.0	 1	 -30.0	 30.0;
	5483	 2921	 0.00011	 0.00108	 0.0	 29098	 29098	 29098	 0.0	 0.0	 1	 -30.0	 30.0;
	11547	 9043	 0.00089	 0.00815	 0.0	 3853	 3853	 3853	 0.0	 0.0	 1	 -30.0	 30.0;
	8865	 11869	 0.0009	 0.00859	 0.0	 3658	 3658	 3658	 0.0	 0.0	 1	 -30.0	 30.0;
	8865	 13219	 0.00167	 0.02239	 0.0	 1407	 1407	 1407	 0.0	 0.0	 1	 -30.0	 30.0;
	11869	 7679	 2e-05	 0.00024	 0.0	 131160	 131160	 131160	 0.0	 0.0	 1	 -30.0	 30.0;
	9534	 195	 0.00157	 0.01326	 0.0	 2366	 2366	 2366	 0.0	 0.0	 1	 -30.0	 30.0;
	2715	 8085	 0.00155	 0.0139	 0.0	 2259	 2259	 2259	 0.0	 0.0	 1	 -30.0	 30.0;
	195	 9511	 0.00142	 0.01472	 0.0	 2136	 2136	 2136	 0.0	 0.0	 1	 -30.0	 30.0;
	6592	 9511	 0.00187	 0.02232	 0.0	 1411	 1411	 1411	 0.0	 0.0	 1	 -30.0	 30.0;
	6592	 2240	 0.00049	 0.00572	 0.0	 5503	 5503	 5503	 0.0	 0.0	 1	 -30.0	 30.0;
	9511	 2848	 0.0	 0.00021	 0.0	 150416	 150416	 150416	 0.0	 0.0	 1	 -30.0	 30.0;
	13219	 5866	 0.00104	 0.00939	 0.0	 3344	 3344	 3344	 0.0	 0.0	 1	 -30.0	 30.0;
	13219	 10952	 0.00043	 0.0049	 0.0	 6422	 6422	 6422	 0.0	 0.0	 1	 -30.0	 30.0;
	13219	 10952	 0.00049	 0.0048	 0.0	 6547	 6547	 6547	 0.0	 0.0	 1	 -30.0	 30.0;
	49	 1681	 0.002009	 0.01464	 0.0	 2138	 2138	 2138	 0.0	 0.0	 1	 -30.0	 30.0;
	1681	 5461	 0.003302	 0.026	 0.0	 1206	 1206	 1206	 0.0	 0.0	 1	 -30.0	 30.0;
	574	 6248	 0.006222	 0.018089	 0.0	 1652	 1652	 1652	 0.0	 0.0	 1	 -30.0	 30.0;
	5461	 10863	 0.0	 0.000222	 0.0	 142286	 142286	 142286	 0.0	 0.0	 1	 -30.0	 30.0;
	5461	 4146	 8.9e-05	 0.000911	 0.0	 34509	 34509	 34509	 0.0	 0.0	 1	 -30.0	 30.0;
	12976	 11425	 1.8e-05	 0.000222	 0.0	 141820	 141820	 141820	 0.0	 0.0	 1	 -30.0	 30.0;
	9451	 10863	 0.00388	 0.014289	 0.0	 2134	 2134	 2134	 0.0	 0.0	 1	 -30.0	 30.0;
	8168	 891	 0.001329	 0.007898	 0.0	 3944	 3944	 3944	 0.0	 0.0	 1	 -30.0	 30.0;
	8168	 6711	 0.00048	 0.002951	 0.0	 10566	 10566	 10566	 0.0	 0.0	 1	 -30.0	 30.0;
	8168	 13344	 8e-05	 0.00032	 0.0	 95764	 95764	 95764	 0.0	 0.0	 1	 -30.0	 30.0;
	4093	 7775	 0.000302	 0.001102	 0.0	 27645	 27645	 27645	 0.0	 0.0	 1	 -30.0	 30.0;
	6378	 11374	 0.003742	 0.013098	 0.0	 2319	 2319	 2319	 0.0	 0.0	 1	 -30.0	 30.0;
	11064	 8973	 0.008911	 0.032298	 0.0	 943	 943	 943	 0.0	 0.0	 1	 -30.0	 30.0;
	8630	 9569	 0.00124	 0.005409	 0.0	 5693	 5693	 5693	 0.0	 0.0	 1	 -30.0	 30.0;
	1016	 8230	 0.0025	 0.0123	 0.0	 2517	 2517	 2517	 0.0	 0.0	 1	 -30.0	 30.0;
	1016	 8230	 0.001781	 0.013729	 0.0	 2282	 2282	 2282	 0.0	 0.0	 1	 -30.0	 30.0;
	1016	 6356	 0.00324	 0.016039	 0.0	 1931	 1931	 1931	 0.0	 0.0	 1	 -30.0	 30.0;
	13301	 9217	 0.00037	 0.00474	 0.0	 6644	 6644	 6644	 0.0	 0.0	 1	 -30.0	 30.0;
	11381	 2531	 9.1e-05	 0.000521	 0.0	 59725	 59725	 59725	 0.0	 0.0	 1	 -30.0	 30.0;
	9217	 7806	 3.1e-05	 0.00043	 0.0	 73269	 73269	 73269	 0.0	 0.0	 1	 -30.0	 30.0;
	2531	 11300	 0.001281	 0.005909	 0.0	 5225	 5225	 5225	 0.0	 0.0	 1	 -30.0	 30.0;
	2118	 8414	 0.000909	 0.00476	 0.0	 6519	 6519	 6519	 0.0	 0.0	 1	 -30.0	 30.0;
	7443	 7683	 0.00011	 0.000599	 0.0	 51867	 51867	 51867	 0.0	 0.0	 1	 -30.0	 30.0;
	5339	 13451	 0.000289	 0.001719	 0.0	 18122	 18122	 18122	 0.0	 0.0	 1	 -30.0	 30.0;
	10599	 6029	 0.00026	 0.001591	 0.0	 19594	 19594	 19594	 0.0	 0.0	 1	 -30.0	 30.0;
	8461	 5866	 0.00108	 0.01382	 0.0	 2279	 2279	 2279	 0.0	 0.0	 1	 -30.0	 30.0;
	10741	 11216	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	6972	 11516	 0.014281	 0.033446	 0.0	 869	 869	 869	 0.0	 0.0	 1	 -30.0	 30.0;
	12931	 11516	 0.038273	 0.11138	 0.0	 269	 269	 269	 0.0	 0.0	 1	 -30.0	 30.0;
	3999	 1890	 0.039504	 0.11795	 0.0	 254	 254	 254	 0.0	 0.0	 1	 -30.0	 30.0;
	4188	 3999	 0.039893	 0.095083	 0.0	 307	 307	 307	 0.0	 0.0	 1	 -30.0	 30.0;
	6752	 13155	 0.025107	 0.052256	 0.0	 545	 545	 545	 0.0	 0.0	 1	 -30.0	 30.0;
	2522	 6752	 0.010124	 0.017818	 0.0	 1542	 1542	 1542	 0.0	 0.0	 1	 -30.0	 30.0;
	13564	 9982	 0.035198	 0.083893	 0.0	 348	 348	 348	 0.0	 0.0	 1	 -30.0	 30.0;
	9982	 9539	 0.026149	 0.064851	 0.0	 452	 452	 452	 0.0	 0.0	 1	 -30.0	 30.0;
	13141	 10872	 0.0	 0.000793	 0.0	 39833	 39833	 39833	 0.0	 0.0	 1	 -30.0	 30.0;
	5513	 13141	 0.02086	 0.051744	 0.0	 567	 567	 567	 0.0	 0.0	 1	 -30.0	 30.0;
	736	 10872	 0.041992	 0.117446	 0.0	 254	 254	 254	 0.0	 0.0	 1	 -30.0	 30.0;
	8186	 7395	 0.014031	 0.079591	 0.0	 391	 391	 391	 0.0	 0.0	 1	 -30.0	 30.0;
	7395	 12413	 0.0075	 0.054099	 0.0	 579	 579	 579	 0.0	 0.0	 1	 -30.0	 30.0;
	5020	 7395	 0.013841	 0.0733	 0.0	 509	 509	 509	 0.0	 0.0	 1	 -30.0	 30.0;
	7395	 2954	 0.006469	 0.041401	 0.0	 754	 754	 754	 0.0	 0.0	 1	 -30.0	 30.0;
	677	 3726	 0.005628	 0.015826	 0.0	 1881	 1881	 1881	 0.0	 0.0	 1	 -30.0	 30.0;
	12776	 677	 0.026364	 0.056017	 0.0	 511	 511	 511	 0.0	 0.0	 1	 -30.0	 30.0;
	677	 5513	 0.026099	 0.062182	 0.0	 469	 469	 469	 0.0	 0.0	 1	 -30.0	 30.0;
	677	 7623	 0.04481	 0.131231	 0.0	 228	 228	 228	 0.0	 0.0	 1	 -30.0	 30.0;
	736	 3726	 0.005512	 0.01614	 0.0	 1853	 1853	 1853	 0.0	 0.0	 1	 -30.0	 30.0;
	12776	 736	 0.023488	 0.063479	 0.0	 467	 467	 467	 0.0	 0.0	 1	 -30.0	 30.0;
	736	 9121	 0.044198	 0.129446	 0.0	 231	 231	 231	 0.0	 0.0	 1	 -30.0	 30.0;
	9211	 2018	 0.006612	 0.01657	 0.0	 1771	 1771	 1771	 0.0	 0.0	 1	 -30.0	 30.0;
	3933	 9211	 0.003967	 0.007521	 0.0	 3715	 3715	 3715	 0.0	 0.0	 1	 -30.0	 30.0;
	8450	 9270	 0.027496	 0.067438	 0.0	 434	 434	 434	 0.0	 0.0	 1	 -30.0	 30.0;
	7040	 8450	 0.044587	 0.102702	 0.0	 283	 283	 283	 0.0	 0.0	 1	 -30.0	 30.0;
	8450	 6579	 0.051438	 0.143868	 0.0	 207	 207	 207	 0.0	 0.0	 1	 -30.0	 30.0;
	8450	 11697	 0.029256	 0.072579	 0.0	 404	 404	 404	 0.0	 0.0	 1	 -30.0	 30.0;
	1316	 8450	 0.049149	 0.122653	 0.0	 240	 240	 240	 0.0	 0.0	 1	 -30.0	 30.0;
	1316	 8450	 0.043372	 0.125157	 0.0	 239	 239	 239	 0.0	 0.0	 1	 -30.0	 30.0;
	12851	 8450	 0.016471	 0.042529	 0.0	 693	 693	 693	 0.0	 0.0	 1	 -30.0	 30.0;
	10960	 90	 0.0	 0.00076	 0.0	 41563	 41563	 41563	 0.0	 0.0	 1	 -30.0	 30.0;
	90	 3016	 0.038017	 0.110653	 0.0	 270	 270	 270	 0.0	 0.0	 1	 -30.0	 30.0;
	7497	 90	 0.025174	 0.07938	 0.0	 380	 380	 380	 0.0	 0.0	 1	 -30.0	 30.0;
	7964	 90	 0.043017	 0.128446	 0.0	 234	 234	 234	 0.0	 0.0	 1	 -30.0	 30.0;
	6175	 10960	 0.051636	 0.189413	 0.0	 161	 161	 161	 0.0	 0.0	 1	 -30.0	 30.0;
	10960	 5175	 0.04714	 0.113008	 0.0	 258	 258	 258	 0.0	 0.0	 1	 -30.0	 30.0;
	4064	 10960	 0.008149	 0.025711	 0.0	 1172	 1172	 1172	 0.0	 0.0	 1	 -30.0	 30.0;
	6652	 12237	 0.039686	 0.102843	 0.0	 287	 287	 287	 0.0	 0.0	 1	 -30.0	 30.0;
	10393	 12237	 0.006372	 0.01857	 0.0	 1609	 1609	 1609	 0.0	 0.0	 1	 -30.0	 30.0;
	12237	 6830	 0.045711	 0.108901	 0.0	 268	 268	 268	 0.0	 0.0	 1	 -30.0	 30.0;
	1699	 2094	 0.04119	 0.106331	 0.0	 278	 278	 278	 0.0	 0.0	 1	 -30.0	 30.0;
	4913	 1699	 0.013752	 0.03024	 0.0	 951	 951	 951	 0.0	 0.0	 1	 -30.0	 30.0;
	8512	 6888	 0.00595	 0.019008	 0.0	 1586	 1586	 1586	 0.0	 0.0	 1	 -30.0	 30.0;
	6888	 11651	 0.00576	 0.020331	 0.0	 1495	 1495	 1495	 0.0	 0.0	 1	 -30.0	 30.0;
	4097	 11791	 0.03586	 0.082107	 0.0	 353	 353	 353	 0.0	 0.0	 1	 -30.0	 30.0;
	630	 4097	 0.022223	 0.055099	 0.0	 532	 532	 532	 0.0	 0.0	 1	 -30.0	 30.0;
	12083	 9714	 0.008802	 0.02862	 0.0	 1055	 1055	 1055	 0.0	 0.0	 1	 -30.0	 30.0;
	9714	 11041	 0.032719	 0.124942	 0.0	 245	 245	 245	 0.0	 0.0	 1	 -30.0	 30.0;
	1103	 12115	 0.019793	 0.055331	 0.0	 538	 538	 538	 0.0	 0.0	 1	 -30.0	 30.0;
	12115	 12125	 0.01395	 0.034612	 0.0	 847	 847	 847	 0.0	 0.0	 1	 -30.0	 30.0;
	5427	 3149	 0.004727	 0.010107	 0.0	 2831	 2831	 2831	 0.0	 0.0	 1	 -30.0	 30.0;
	12909	 5427	 0.007289	 0.014364	 0.0	 1962	 1962	 1962	 0.0	 0.0	 1	 -30.0	 30.0;
	8012	 5944	 0.004818	 0.009901	 0.0	 2869	 2869	 2869	 0.0	 0.0	 1	 -30.0	 30.0;
	688	 8012	 0.012223	 0.031554	 0.0	 934	 934	 934	 0.0	 0.0	 1	 -30.0	 30.0;
	1925	 763	 0.00108	 0.01189	 0.0	 3149	 3149	 3149	 0.0	 0.0	 1	 -30.0	 30.0;
	1371	 1925	 0.0032	 0.03265	 0.0	 1146	 1146	 1146	 0.0	 0.0	 1	 -30.0	 30.0;
	9813	 1925	 0.0007	 0.00731	 0.0	 5120	 5120	 5120	 0.0	 0.0	 1	 -30.0	 30.0;
	3640	 8341	 0.0	 0.000744	 0.0	 42457	 42457	 42457	 0.0	 0.0	 1	 -30.0	 30.0;
	3640	 2706	 0.009248	 0.022041	 0.0	 1322	 1322	 1322	 0.0	 0.0	 1	 -30.0	 30.0;
	8341	 12672	 0.008124	 0.02286	 0.0	 1302	 1302	 1302	 0.0	 0.0	 1	 -30.0	 30.0;
	6947	 11002	 0.007702	 0.019893	 0.0	 1481	 1481	 1481	 0.0	 0.0	 1	 -30.0	 30.0;
	11002	 10088	 0.015579	 0.04914	 0.0	 613	 613	 613	 0.0	 0.0	 1	 -30.0	 30.0;
	13051	 4510	 0.00981	 0.068021	 0.0	 547	 547	 547	 0.0	 0.0	 1	 -30.0	 30.0;
	13051	 2416	 0.006341	 0.042211	 0.0	 889	 889	 889	 0.0	 0.0	 1	 -30.0	 30.0;
	1403	 10539	 0.060281	 0.144512	 0.0	 202	 202	 202	 0.0	 0.0	 1	 -30.0	 30.0;
	1403	 10539	 0.061438	 0.141504	 0.0	 205	 205	 205	 0.0	 0.0	 1	 -30.0	 30.0;
	10539	 3933	 0.016579	 0.039917	 0.0	 731	 731	 731	 0.0	 0.0	 1	 -30.0	 30.0;
	2258	 5488	 0.0	 0.000843	 0.0	 37471	 37471	 37471	 0.0	 0.0	 1	 -30.0	 30.0;
	9557	 2258	 0.010256	 0.022711	 0.0	 1268	 1268	 1268	 0.0	 0.0	 1	 -30.0	 30.0;
	2258	 7127	 0.024983	 0.073149	 0.0	 409	 409	 409	 0.0	 0.0	 1	 -30.0	 30.0;
	5488	 6253	 0.008388	 0.02557	 0.0	 1174	 1174	 1174	 0.0	 0.0	 1	 -30.0	 30.0;
	3685	 12183	 0.063512	 0.200339	 0.0	 151	 151	 151	 0.0	 0.0	 1	 -30.0	 30.0;
	6652	 3685	 0.037562	 0.085967	 0.0	 337	 337	 337	 0.0	 0.0	 1	 -30.0	 30.0;
	4362	 1081	 0.002579	 0.007752	 0.0	 3867	 3867	 3867	 0.0	 0.0	 1	 -30.0	 30.0;
	1945	 1081	 0.001777	 0.00495	 0.0	 6006	 6006	 6006	 0.0	 0.0	 1	 -30.0	 30.0;
	9671	 10682	 0.030248	 0.084612	 0.0	 352	 352	 352	 0.0	 0.0	 1	 -30.0	 30.0;
	10682	 12827	 0.013281	 0.037124	 0.0	 802	 802	 802	 0.0	 0.0	 1	 -30.0	 30.0;
	7961	 5590	 0.009488	 0.023521	 0.0	 1246	 1246	 1246	 0.0	 0.0	 1	 -30.0	 30.0;
	953	 5590	 0.022579	 0.058314	 0.0	 506	 506	 506	 0.0	 0.0	 1	 -30.0	 30.0;
	6687	 7089	 0.02743	 0.062793	 0.0	 461	 461	 461	 0.0	 0.0	 1	 -30.0	 30.0;
	10577	 6687	 0.001719	 0.003777	 0.0	 7612	 7612	 7612	 0.0	 0.0	 1	 -30.0	 30.0;
	3972	 2833	 0.035992	 0.085876	 0.0	 340	 340	 340	 0.0	 0.0	 1	 -30.0	 30.0;
	3501	 3972	 0.008777	 0.01962	 0.0	 1470	 1470	 1470	 0.0	 0.0	 1	 -30.0	 30.0;
	4361	 3249	 0.001793	 0.001521	 0.0	 13435	 13435	 13435	 0.0	 0.0	 1	 -30.0	 30.0;
	3249	 3250	 0.004917	 0.007702	 0.0	 3457	 3457	 3457	 0.0	 0.0	 1	 -30.0	 30.0;
	10421	 4175	 0.001521	 0.004554	 0.0	 6579	 6579	 6579	 0.0	 0.0	 1	 -30.0	 30.0;
	744	 4175	 0.011198	 0.041099	 0.0	 742	 742	 742	 0.0	 0.0	 1	 -30.0	 30.0;
	2469	 12012	 0.00144	 0.01155	 0.0	 3230	 3230	 3230	 0.0	 0.0	 1	 -30.0	 30.0;
	2469	 10698	 0.00123	 0.01345	 0.0	 2784	 2784	 2784	 0.0	 0.0	 1	 -30.0	 30.0;
	9101	 9118	 0.007669	 0.02419	 0.0	 1245	 1245	 1245	 0.0	 0.0	 1	 -30.0	 30.0;
	9101	 268	 0.003661	 0.008769	 0.0	 3325	 3325	 3325	 0.0	 0.0	 1	 -30.0	 30.0;
	12774	 9101	 0.00943	 0.036008	 0.0	 849	 849	 849	 0.0	 0.0	 1	 -30.0	 30.0;
	848	 9101	 0.012661	 0.037802	 0.0	 793	 793	 793	 0.0	 0.0	 1	 -30.0	 30.0;
	11800	 12242	 0.006083	 0.024099	 0.0	 1271	 1271	 1271	 0.0	 0.0	 1	 -30.0	 30.0;
	11800	 1660	 0.002248	 0.004248	 0.0	 6573	 6573	 6573	 0.0	 0.0	 1	 -30.0	 30.0;
	2511	 6954	 0.019651	 0.141771	 0.0	 221	 221	 221	 0.0	 0.0	 1	 -30.0	 30.0;
	6954	 5372	 0.004841	 0.02718	 0.0	 1145	 1145	 1145	 0.0	 0.0	 1	 -30.0	 30.0;
	6954	 5372	 0.00493	 0.02661	 0.0	 1168	 1168	 1168	 0.0	 0.0	 1	 -30.0	 30.0;
	6343	 6954	 0.008729	 0.04569	 0.0	 680	 680	 680	 0.0	 0.0	 1	 -30.0	 30.0;
	13098	 10326	 0.002529	 0.005793	 0.0	 4998	 4998	 4998	 0.0	 0.0	 1	 -30.0	 30.0;
	10326	 8918	 0.003579	 0.007876	 0.0	 3652	 3652	 3652	 0.0	 0.0	 1	 -30.0	 30.0;
	12077	 1205	 0.014182	 0.03119	 0.0	 922	 922	 922	 0.0	 0.0	 1	 -30.0	 30.0;
	12077	 9941	 0.061124	 0.192777	 0.0	 157	 157	 157	 0.0	 0.0	 1	 -30.0	 30.0;
	7422	 1091	 0.114603	 0.284256	 0.0	 104	 104	 104	 0.0	 0.0	 1	 -30.0	 30.0;
	1091	 11147	 0.00786	 0.019488	 0.0	 1504	 1504	 1504	 0.0	 0.0	 1	 -30.0	 30.0;
	13098	 12685	 0.002669	 0.006124	 0.0	 4729	 4729	 4729	 0.0	 0.0	 1	 -30.0	 30.0;
	5351	 7373	 0.00895	 0.022182	 0.0	 1321	 1321	 1321	 0.0	 0.0	 1	 -30.0	 30.0;
	7373	 348	 0.002281	 0.008033	 0.0	 3783	 3783	 3783	 0.0	 0.0	 1	 -30.0	 30.0;
	5351	 1205	 0.005314	 0.013719	 0.0	 2148	 2148	 2148	 0.0	 0.0	 1	 -30.0	 30.0;
	9131	 7927	 0.031521	 0.069298	 0.0	 415	 415	 415	 0.0	 0.0	 1	 -30.0	 30.0;
	7927	 12685	 0.003719	 0.013223	 0.0	 2300	 2300	 2300	 0.0	 0.0	 1	 -30.0	 30.0;
	7927	 348	 0.009719	 0.027818	 0.0	 1072	 1072	 1072	 0.0	 0.0	 1	 -30.0	 30.0;
	7927	 5811	 0.042669	 0.127397	 0.0	 236	 236	 236	 0.0	 0.0	 1	 -30.0	 30.0;
	7927	 9816	 0.031157	 0.077281	 0.0	 380	 380	 380	 0.0	 0.0	 1	 -30.0	 30.0;
	8918	 1205	 0.00319	 0.008934	 0.0	 3330	 3330	 3330	 0.0	 0.0	 1	 -30.0	 30.0;
	1205	 9644	 0.01462	 0.046124	 0.0	 653	 653	 653	 0.0	 0.0	 1	 -30.0	 30.0;
	12147	 6492	 0.007587	 0.018628	 0.0	 1571	 1571	 1571	 0.0	 0.0	 1	 -30.0	 30.0;
	10843	 12147	 0.024529	 0.052826	 0.0	 543	 543	 543	 0.0	 0.0	 1	 -30.0	 30.0;
	7455	 12596	 0.041223	 0.115314	 0.0	 258	 258	 258	 0.0	 0.0	 1	 -30.0	 30.0;
	7455	 10412	 0.022512	 0.051521	 0.0	 562	 562	 562	 0.0	 0.0	 1	 -30.0	 30.0;
	10393	 7455	 0.063537	 0.189702	 0.0	 158	 158	 158	 0.0	 0.0	 1	 -30.0	 30.0;
	6304	 8124	 0.01524	 0.045496	 0.0	 659	 659	 659	 0.0	 0.0	 1	 -30.0	 30.0;
	703	 8124	 0.035876	 0.092612	 0.0	 319	 319	 319	 0.0	 0.0	 1	 -30.0	 30.0;
	9118	 7744	 0.015471	 0.046198	 0.0	 649	 649	 649	 0.0	 0.0	 1	 -30.0	 30.0;
	12410	 10385	 0.043364	 0.152818	 0.0	 199	 199	 199	 0.0	 0.0	 1	 -30.0	 30.0;
	1799	 10385	 0.03095	 0.100686	 0.0	 300	 300	 300	 0.0	 0.0	 1	 -30.0	 30.0;
	2995	 10385	 0.035628	 0.107959	 0.0	 278	 278	 278	 0.0	 0.0	 1	 -30.0	 30.0;
	10634	 9671	 0.010901	 0.034397	 0.0	 876	 876	 876	 0.0	 0.0	 1	 -30.0	 30.0;
	5024	 3991	 0.026099	 0.060099	 0.0	 483	 483	 483	 0.0	 0.0	 1	 -30.0	 30.0;
	3944	 5024	 0.025942	 0.057008	 0.0	 505	 505	 505	 0.0	 0.0	 1	 -30.0	 30.0;
	13150	 2309	 0.001901	 0.004636	 0.0	 6305	 6305	 6305	 0.0	 0.0	 1	 -30.0	 30.0;
	2309	 12953	 0.00176	 0.003124	 0.0	 8810	 8810	 8810	 0.0	 0.0	 1	 -30.0	 30.0;
	10024	 12183	 0.003876	 0.010909	 0.0	 2729	 2729	 2729	 0.0	 0.0	 1	 -30.0	 30.0;
	12183	 1034	 0.003802	 0.011124	 0.0	 2687	 2687	 2687	 0.0	 0.0	 1	 -30.0	 30.0;
	6725	 12183	 0.013339	 0.029298	 0.0	 982	 982	 982	 0.0	 0.0	 1	 -30.0	 30.0;
	2632	 12183	 0.031719	 0.11181	 0.0	 272	 272	 272	 0.0	 0.0	 1	 -30.0	 30.0;
	4919	 5454	 0.021521	 0.05557	 0.0	 531	 531	 531	 0.0	 0.0	 1	 -30.0	 30.0;
	6205	 4919	 0.037008	 0.107752	 0.0	 278	 278	 278	 0.0	 0.0	 1	 -30.0	 30.0;
	9535	 2800	 0.05743	 0.142463	 0.0	 206	 206	 206	 0.0	 0.0	 1	 -30.0	 30.0;
	9535	 2213	 0.036091	 0.074041	 0.0	 384	 384	 384	 0.0	 0.0	 1	 -30.0	 30.0;
	11589	 6146	 0.001211	 0.00545	 0.0	 5658	 5658	 5658	 0.0	 0.0	 1	 -30.0	 30.0;
	2986	 6146	 0.013711	 0.078669	 0.0	 396	 396	 396	 0.0	 0.0	 1	 -30.0	 30.0;
	1761	 6669	 0.050521	 0.125331	 0.0	 234	 234	 234	 0.0	 0.0	 1	 -30.0	 30.0;
	6669	 7629	 0.085818	 0.221579	 0.0	 133	 133	 133	 0.0	 0.0	 1	 -30.0	 30.0;
	6669	 8180	 0.014909	 0.034132	 0.0	 849	 849	 849	 0.0	 0.0	 1	 -30.0	 30.0;
	6669	 6979	 0.035826	 0.113033	 0.0	 267	 267	 267	 0.0	 0.0	 1	 -30.0	 30.0;
	9139	 9276	 0.008289	 0.026017	 0.0	 1157	 1157	 1157	 0.0	 0.0	 1	 -30.0	 30.0;
	5859	 9276	 0.023339	 0.089587	 0.0	 342	 342	 342	 0.0	 0.0	 1	 -30.0	 30.0;
	5486	 3411	 0.00661	 0.039521	 0.0	 789	 789	 789	 0.0	 0.0	 1	 -30.0	 30.0;
	12516	 5486	 0.00349	 0.01574	 0.0	 1960	 1960	 1960	 0.0	 0.0	 1	 -30.0	 30.0;
	1103	 9632	 0.03714	 0.088496	 0.0	 330	 330	 330	 0.0	 0.0	 1	 -30.0	 30.0;
	1103	 12268	 0.037256	 0.087669	 0.0	 332	 332	 332	 0.0	 0.0	 1	 -30.0	 30.0;
	1103	 6722	 0.03081	 0.07957	 0.0	 445	 445	 445	 0.0	 0.0	 1	 -30.0	 30.0;
	7358	 7781	 0.033248	 0.096818	 0.0	 309	 309	 309	 0.0	 0.0	 1	 -30.0	 30.0;
	13446	 7781	 0.011479	 0.034298	 0.0	 874	 874	 874	 0.0	 0.0	 1	 -30.0	 30.0;
	7093	 1572	 0.0	 0.000893	 0.0	 35373	 35373	 35373	 0.0	 0.0	 1	 -30.0	 30.0;
	7093	 2671	 0.019273	 0.042628	 0.0	 676	 676	 676	 0.0	 0.0	 1	 -30.0	 30.0;
	7093	 5487	 0.019628	 0.041702	 0.0	 686	 686	 686	 0.0	 0.0	 1	 -30.0	 30.0;
	8673	 7093	 0.029512	 0.062719	 0.0	 456	 456	 456	 0.0	 0.0	 1	 -30.0	 30.0;
	9939	 1572	 0.034901	 0.105744	 0.0	 284	 284	 284	 0.0	 0.0	 1	 -30.0	 30.0;
	10346	 1572	 0.026289	 0.071083	 0.0	 417	 417	 417	 0.0	 0.0	 1	 -30.0	 30.0;
	5068	 1572	 0.041893	 0.121942	 0.0	 245	 245	 245	 0.0	 0.0	 1	 -30.0	 30.0;
	3051	 12596	 0.024851	 0.071711	 0.0	 417	 417	 417	 0.0	 0.0	 1	 -30.0	 30.0;
	10799	 2415	 0.006512	 0.01681	 0.0	 1753	 1753	 1753	 0.0	 0.0	 1	 -30.0	 30.0;
	5699	 10799	 0.00305	 0.009099	 0.0	 3292	 3292	 3292	 0.0	 0.0	 1	 -30.0	 30.0;
	2046	 10571	 0.014678	 0.04105	 0.0	 725	 725	 725	 0.0	 0.0	 1	 -30.0	 30.0;
	9208	 2046	 0.054149	 0.119066	 0.0	 242	 242	 242	 0.0	 0.0	 1	 -30.0	 30.0;
	12226	 7040	 0.08557	 0.197909	 0.0	 147	 147	 147	 0.0	 0.0	 1	 -30.0	 30.0;
	13089	 12226	 0.038314	 0.075496	 0.0	 374	 374	 374	 0.0	 0.0	 1	 -30.0	 30.0;
	9537	 12174	 0.036554	 0.115289	 0.0	 262	 262	 262	 0.0	 0.0	 1	 -30.0	 30.0;
	3537	 9537	 0.047636	 0.11019	 0.0	 264	 264	 264	 0.0	 0.0	 1	 -30.0	 30.0;
	3195	 3970	 0.0	 0.000826	 0.0	 38242	 38242	 38242	 0.0	 0.0	 1	 -30.0	 30.0;
	12496	 3970	 0.013397	 0.037488	 0.0	 794	 794	 794	 0.0	 0.0	 1	 -30.0	 30.0;
	3195	 1296	 0.03095	 0.079917	 0.0	 369	 369	 369	 0.0	 0.0	 1	 -30.0	 30.0;
	8101	 3195	 0.014058	 0.032198	 0.0	 900	 900	 900	 0.0	 0.0	 1	 -30.0	 30.0;
	6968	 13599	 0.03086	 0.093488	 0.0	 321	 321	 321	 0.0	 0.0	 1	 -30.0	 30.0;
	9208	 6968	 0.023669	 0.071066	 0.0	 422	 422	 422	 0.0	 0.0	 1	 -30.0	 30.0;
	9208	 6968	 0.028083	 0.078537	 0.0	 379	 379	 379	 0.0	 0.0	 1	 -30.0	 30.0;
	1137	 9575	 0.016661	 0.052554	 0.0	 573	 573	 573	 0.0	 0.0	 1	 -30.0	 30.0;
	9575	 11954	 0.022223	 0.050868	 0.0	 570	 570	 570	 0.0	 0.0	 1	 -30.0	 30.0;
	499	 1539	 0.017	 0.043909	 0.0	 671	 671	 671	 0.0	 0.0	 1	 -30.0	 30.0;
	1539	 11984	 0.017727	 0.05595	 0.0	 539	 539	 539	 0.0	 0.0	 1	 -30.0	 30.0;
	903	 2199	 0.022223	 0.052967	 0.0	 550	 550	 550	 0.0	 0.0	 1	 -30.0	 30.0;
	5374	 2199	 0.027628	 0.071347	 0.0	 413	 413	 413	 0.0	 0.0	 1	 -30.0	 30.0;
	8833	 6723	 0.0	 0.00081	 0.0	 38997	 38997	 38997	 0.0	 0.0	 1	 -30.0	 30.0;
	8833	 13236	 0.002983	 0.010149	 0.0	 2987	 2987	 2987	 0.0	 0.0	 1	 -30.0	 30.0;
	3688	 8833	 0.008678	 0.023463	 0.0	 1263	 1263	 1263	 0.0	 0.0	 1	 -30.0	 30.0;
	6723	 1890	 0.002917	 0.010347	 0.0	 2939	 2939	 2939	 0.0	 0.0	 1	 -30.0	 30.0;
	3688	 6723	 0.008512	 0.023917	 0.0	 1245	 1245	 1245	 0.0	 0.0	 1	 -30.0	 30.0;
	8325	 5829	 0.003603	 0.011339	 0.0	 2655	 2655	 2655	 0.0	 0.0	 1	 -30.0	 30.0;
	8325	 6972	 0.006347	 0.015132	 0.0	 1925	 1925	 1925	 0.0	 0.0	 1	 -30.0	 30.0;
	8329	 8325	 0.027777	 0.08295	 0.0	 362	 362	 362	 0.0	 0.0	 1	 -30.0	 30.0;
	703	 5283	 0.045438	 0.105124	 0.0	 276	 276	 276	 0.0	 0.0	 1	 -30.0	 30.0;
	5283	 11357	 0.07486	 0.187603	 0.0	 157	 157	 157	 0.0	 0.0	 1	 -30.0	 30.0;
	2548	 7247	 0.01919	 0.053198	 0.0	 559	 559	 559	 0.0	 0.0	 1	 -30.0	 30.0;
	12205	 7247	 0.008488	 0.032421	 0.0	 943	 943	 943	 0.0	 0.0	 1	 -30.0	 30.0;
	3476	 10871	 0.00365	 0.03434	 0.0	 1089	 1089	 1089	 0.0	 0.0	 1	 -30.0	 30.0;
	2517	 10871	 0.0049	 0.04432	 0.0	 844	 844	 844	 0.0	 0.0	 1	 -30.0	 30.0;
	4510	 4908	 0.000901	 0.005539	 0.0	 6761	 6761	 6761	 0.0	 0.0	 1	 -30.0	 30.0;
	3047	 4510	 0.00894	 0.06106	 0.0	 615	 615	 615	 0.0	 0.0	 1	 -30.0	 30.0;
	4510	 2524	 0.006919	 0.049419	 0.0	 754	 754	 754	 0.0	 0.0	 1	 -30.0	 30.0;
	4510	 6474	 0.006771	 0.04576	 0.0	 821	 821	 821	 0.0	 0.0	 1	 -30.0	 30.0;
	922	 4852	 0.0	 0.000793	 0.0	 39833	 39833	 39833	 0.0	 0.0	 1	 -30.0	 30.0;
	922	 12297	 0.019628	 0.061364	 0.0	 491	 491	 491	 0.0	 0.0	 1	 -30.0	 30.0;
	922	 9291	 0.011727	 0.033826	 0.0	 883	 883	 883	 0.0	 0.0	 1	 -30.0	 30.0;
	4852	 8684	 0.006438	 0.01943	 0.0	 1544	 1544	 1544	 0.0	 0.0	 1	 -30.0	 30.0;
	4852	 8684	 0.006562	 0.019033	 0.0	 1569	 1569	 1569	 0.0	 0.0	 1	 -30.0	 30.0;
	6521	 4852	 0.006421	 0.020893	 0.0	 1446	 1446	 1446	 0.0	 0.0	 1	 -30.0	 30.0;
	8366	 6941	 0.00031	 0.00355	 0.0	 10550	 10550	 10550	 0.0	 0.0	 1	 -30.0	 30.0;
	6281	 2989	 0.016752	 0.046397	 0.0	 641	 641	 641	 0.0	 0.0	 1	 -30.0	 30.0;
	12104	 6281	 0.009347	 0.035702	 0.0	 856	 856	 856	 0.0	 0.0	 1	 -30.0	 30.0;
	2989	 12301	 0.011298	 0.040033	 0.0	 760	 760	 760	 0.0	 0.0	 1	 -30.0	 30.0;
	12952	 1838	 0.001298	 0.004322	 0.0	 7000	 7000	 7000	 0.0	 0.0	 1	 -30.0	 30.0;
	11292	 1838	 0.000347	 0.000876	 0.0	 33525	 33525	 33525	 0.0	 0.0	 1	 -30.0	 30.0;
	3476	 1193	 0.00028	 0.00301	 0.0	 12436	 12436	 12436	 0.0	 0.0	 1	 -30.0	 30.0;
	12012	 3476	 0.00297	 0.02796	 0.0	 1337	 1337	 1337	 0.0	 0.0	 1	 -30.0	 30.0;
	3476	 883	 0.00274	 0.03157	 0.0	 1187	 1187	 1187	 0.0	 0.0	 1	 -30.0	 30.0;
	9139	 11164	 0.00286	 0.010554	 0.0	 2889	 2889	 2889	 0.0	 0.0	 1	 -30.0	 30.0;
	9139	 13615	 0.025818	 0.091446	 0.0	 333	 333	 333	 0.0	 0.0	 1	 -30.0	 30.0;
	2833	 9139	 0.027066	 0.065554	 0.0	 446	 446	 446	 0.0	 0.0	 1	 -30.0	 30.0;
	9139	 4081	 0.086198	 0.151504	 0.0	 182	 182	 182	 0.0	 0.0	 1	 -30.0	 30.0;
	1095	 9139	 0.010893	 0.02719	 0.0	 1079	 1079	 1079	 0.0	 0.0	 1	 -30.0	 30.0;
	8703	 9139	 0.03162	 0.072818	 0.0	 398	 398	 398	 0.0	 0.0	 1	 -30.0	 30.0;
	9888	 11164	 0.002802	 0.010752	 0.0	 2843	 2843	 2843	 0.0	 0.0	 1	 -30.0	 30.0;
	9888	 12886	 0.054802	 0.152636	 0.0	 195	 195	 195	 0.0	 0.0	 1	 -30.0	 30.0;
	9888	 10190	 0.014223	 0.048397	 0.0	 627	 627	 627	 0.0	 0.0	 1	 -30.0	 30.0;
	10551	 9888	 0.01814	 0.043521	 0.0	 670	 670	 670	 0.0	 0.0	 1	 -30.0	 30.0;
	9888	 5828	 0.038248	 0.07586	 0.0	 372	 372	 372	 0.0	 0.0	 1	 -30.0	 30.0;
	5952	 10002	 0.017331	 0.061314	 0.0	 496	 496	 496	 0.0	 0.0	 1	 -30.0	 30.0;
	13015	 10002	 0.009182	 0.032339	 0.0	 940	 940	 940	 0.0	 0.0	 1	 -30.0	 30.0;
	1193	 11513	 0.00281	 0.02539	 0.0	 1472	 1472	 1472	 0.0	 0.0	 1	 -30.0	 30.0;
	9834	 11513	 0.00158	 0.01426	 0.0	 2621	 2621	 2621	 0.0	 0.0	 1	 -30.0	 30.0;
	9234	 6415	 0.0	 0.000211	 0.0	 178159	 178159	 178159	 0.0	 0.0	 1	 -30.0	 30.0;
	13627	 9234	 0.00888	 0.061021	 0.0	 616	 616	 616	 0.0	 0.0	 1	 -30.0	 30.0;
	9234	 2524	 0.006961	 0.04406	 0.0	 843	 843	 843	 0.0	 0.0	 1	 -30.0	 30.0;
	6415	 13315	 0.00869	 0.06218	 0.0	 605	 605	 605	 0.0	 0.0	 1	 -30.0	 30.0;
	6415	 10654	 0.002401	 0.027581	 0.0	 1371	 1371	 1371	 0.0	 0.0	 1	 -30.0	 30.0;
	6415	 6474	 0.00682	 0.04493	 0.0	 835	 835	 835	 0.0	 0.0	 1	 -30.0	 30.0;
	13293	 2861	 0.00238	 0.009446	 0.0	 3243	 3243	 3243	 0.0	 0.0	 1	 -30.0	 30.0;
	10843	 13293	 0.017653	 0.060008	 0.0	 505	 505	 505	 0.0	 0.0	 1	 -30.0	 30.0;
	10770	 4363	 0.01838	 0.051397	 0.0	 579	 579	 579	 0.0	 0.0	 1	 -30.0	 30.0;
	4363	 989	 0.02995	 0.071388	 0.0	 409	 409	 409	 0.0	 0.0	 1	 -30.0	 30.0;
	5035	 5734	 0.023223	 0.042223	 0.0	 656	 656	 656	 0.0	 0.0	 1	 -30.0	 30.0;
	5734	 172	 0.018636	 0.052124	 0.0	 571	 571	 571	 0.0	 0.0	 1	 -30.0	 30.0;
	9834	 10593	 0.00096	 0.01102	 0.0	 3399	 3399	 3399	 0.0	 0.0	 1	 -30.0	 30.0;
	10593	 7326	 0.00364	 0.02923	 0.0	 1277	 1277	 1277	 0.0	 0.0	 1	 -30.0	 30.0;
	10593	 6261	 0.00248	 0.02649	 0.0	 1413	 1413	 1413	 0.0	 0.0	 1	 -30.0	 30.0;
	10256	 10593	 0.00384	 0.04229	 0.0	 894	 894	 894	 0.0	 0.0	 1	 -30.0	 30.0;
	8281	 3637	 0.0	 0.000219	 0.0	 171651	 171651	 171651	 0.0	 0.0	 1	 -30.0	 30.0;
	13627	 3637	 0.00344	 0.02181	 0.0	 1719	 1719	 1719	 0.0	 0.0	 1	 -30.0	 30.0;
	3637	 13315	 0.00337	 0.02224	 0.0	 1687	 1687	 1687	 0.0	 0.0	 1	 -30.0	 30.0;
	3637	 293	 0.010521	 0.05913	 0.0	 632	 632	 632	 0.0	 0.0	 1	 -30.0	 30.0;
	3637	 802	 0.00081	 0.005341	 0.0	 6959	 6959	 6959	 0.0	 0.0	 1	 -30.0	 30.0;
	4361	 3250	 0.002579	 0.00476	 0.0	 5835	 5835	 5835	 0.0	 0.0	 1	 -30.0	 30.0;
	8928	 4361	 0.004388	 0.01595	 0.0	 1910	 1910	 1910	 0.0	 0.0	 1	 -30.0	 30.0;
	4361	 10300	 0.004752	 0.017868	 0.0	 1709	 1709	 1709	 0.0	 0.0	 1	 -30.0	 30.0;
	1683	 6849	 0.00338	 0.012959	 0.0	 2359	 2359	 2359	 0.0	 0.0	 1	 -30.0	 30.0;
	11615	 1683	 0.007008	 0.02338	 0.0	 1295	 1295	 1295	 0.0	 0.0	 1	 -30.0	 30.0;
	8700	 6520	 0.025347	 0.057942	 0.0	 500	 500	 500	 0.0	 0.0	 1	 -30.0	 30.0;
	5650	 8700	 0.06314	 0.162959	 0.0	 181	 181	 181	 0.0	 0.0	 1	 -30.0	 30.0;
	5626	 4383	 0.007967	 0.023802	 0.0	 1259	 1259	 1259	 0.0	 0.0	 1	 -30.0	 30.0;
	12981	 5626	 0.006636	 0.016463	 0.0	 1780	 1780	 1780	 0.0	 0.0	 1	 -30.0	 30.0;
	7302	 11091	 0.012091	 0.022893	 0.0	 1221	 1221	 1221	 0.0	 0.0	 1	 -30.0	 30.0;
	7302	 5448	 0.012322	 0.022388	 0.0	 1237	 1237	 1237	 0.0	 0.0	 1	 -30.0	 30.0;
	8985	 5584	 0.016529	 0.049347	 0.0	 607	 607	 607	 0.0	 0.0	 1	 -30.0	 30.0;
	12349	 12952	 0.00119	 0.007017	 0.0	 4439	 4439	 4439	 0.0	 0.0	 1	 -30.0	 30.0;
	12349	 13622	 0.002331	 0.009636	 0.0	 3187	 3187	 3187	 0.0	 0.0	 1	 -30.0	 30.0;
	4365	 2563	 0.008091	 0.02681	 0.0	 1128	 1128	 1128	 0.0	 0.0	 1	 -30.0	 30.0;
	2002	 2563	 0.001347	 0.006876	 0.0	 4509	 4509	 4509	 0.0	 0.0	 1	 -30.0	 30.0;
	11292	 2563	 0.002281	 0.009818	 0.0	 3134	 3134	 3134	 0.0	 0.0	 1	 -30.0	 30.0;
	591	 11799	 0.001149	 0.00243	 0.0	 11752	 11752	 11752	 0.0	 0.0	 1	 -30.0	 30.0;
	5224	 591	 0.002909	 0.006909	 0.0	 4214	 4214	 4214	 0.0	 0.0	 1	 -30.0	 30.0;
	989	 3144	 0.000413	 0.000959	 0.0	 30252	 30252	 30252	 0.0	 0.0	 1	 -30.0	 30.0;
	989	 3144	 0.000421	 0.000942	 0.0	 30614	 30614	 30614	 0.0	 0.0	 1	 -30.0	 30.0;
	10571	 11113	 0.024628	 0.073504	 0.0	 408	 408	 408	 0.0	 0.0	 1	 -30.0	 30.0;
	11113	 9271	 0.041496	 0.094992	 0.0	 305	 305	 305	 0.0	 0.0	 1	 -30.0	 30.0;
	4827	 658	 0.01	 0.021273	 0.0	 1344	 1344	 1344	 0.0	 0.0	 1	 -30.0	 30.0;
	658	 2632	 0.030479	 0.08795	 0.0	 340	 340	 340	 0.0	 0.0	 1	 -30.0	 30.0;
	658	 2632	 0.031157	 0.094992	 0.0	 316	 316	 316	 0.0	 0.0	 1	 -30.0	 30.0;
	7704	 9029	 0.00962	 0.023298	 0.0	 1254	 1254	 1254	 0.0	 0.0	 1	 -30.0	 30.0;
	2679	 7704	 0.018248	 0.040397	 0.0	 713	 713	 713	 0.0	 0.0	 1	 -30.0	 30.0;
	9921	 8188	 0.005868	 0.01781	 0.0	 1685	 1685	 1685	 0.0	 0.0	 1	 -30.0	 30.0;
	9921	 13335	 0.01	 0.02814	 0.0	 1058	 1058	 1058	 0.0	 0.0	 1	 -30.0	 30.0;
	9921	 47	 0.016562	 0.052033	 0.0	 579	 579	 579	 0.0	 0.0	 1	 -30.0	 30.0;
	9921	 47	 0.016893	 0.050967	 0.0	 589	 589	 589	 0.0	 0.0	 1	 -30.0	 30.0;
	8188	 5425	 0.013281	 0.033149	 0.0	 885	 885	 885	 0.0	 0.0	 1	 -30.0	 30.0;
	7424	 1852	 0.005463	 0.020008	 0.0	 1523	 1523	 1523	 0.0	 0.0	 1	 -30.0	 30.0;
	7424	 7656	 0.02695	 0.066868	 0.0	 439	 439	 439	 0.0	 0.0	 1	 -30.0	 30.0;
	5425	 7424	 0.002752	 0.008397	 0.0	 3575	 3575	 3575	 0.0	 0.0	 1	 -30.0	 30.0;
	8455	 7424	 0.002686	 0.007777	 0.0	 3840	 3840	 3840	 0.0	 0.0	 1	 -30.0	 30.0;
	7424	 47	 0.019099	 0.057876	 0.0	 519	 519	 519	 0.0	 0.0	 1	 -30.0	 30.0;
	7424	 5744	 0.017339	 0.043008	 0.0	 682	 682	 682	 0.0	 0.0	 1	 -30.0	 30.0;
	1852	 47	 0.017843	 0.068107	 0.0	 449	 449	 449	 0.0	 0.0	 1	 -30.0	 30.0;
	5381	 9302	 0.022289	 0.070314	 0.0	 429	 429	 429	 0.0	 0.0	 1	 -30.0	 30.0;
	9302	 3293	 0.035008	 0.101917	 0.0	 294	 294	 294	 0.0	 0.0	 1	 -30.0	 30.0;
	12524	 1403	 0.045231	 0.147174	 0.0	 206	 206	 206	 0.0	 0.0	 1	 -30.0	 30.0;
	12649	 1403	 0.011413	 0.03424	 0.0	 876	 876	 876	 0.0	 0.0	 1	 -30.0	 30.0;
	10459	 6553	 0.001124	 0.002579	 0.0	 11228	 11228	 11228	 0.0	 0.0	 1	 -30.0	 30.0;
	10459	 8917	 0.046909	 0.135298	 0.0	 221	 221	 221	 0.0	 0.0	 1	 -30.0	 30.0;
	10459	 7295	 0.035446	 0.075124	 0.0	 381	 381	 381	 0.0	 0.0	 1	 -30.0	 30.0;
	12324	 10459	 0.011107	 0.025793	 0.0	 1125	 1125	 1125	 0.0	 0.0	 1	 -30.0	 30.0;
	10459	 13422	 0.005983	 0.023752	 0.0	 1290	 1290	 1290	 0.0	 0.0	 1	 -30.0	 30.0;
	7873	 3160	 0.016132	 0.04695	 0.0	 637	 637	 637	 0.0	 0.0	 1	 -30.0	 30.0;
	4606	 3160	 0.008008	 0.019083	 0.0	 1527	 1527	 1527	 0.0	 0.0	 1	 -30.0	 30.0;
	6318	 682	 0.034281	 0.088488	 0.0	 333	 333	 333	 0.0	 0.0	 1	 -30.0	 30.0;
	682	 7385	 0.009149	 0.036372	 0.0	 843	 843	 843	 0.0	 0.0	 1	 -30.0	 30.0;
	682	 1121	 0.008711	 0.024124	 0.0	 1232	 1232	 1232	 0.0	 0.0	 1	 -30.0	 30.0;
	682	 2193	 0.03624	 0.109818	 0.0	 274	 274	 274	 0.0	 0.0	 1	 -30.0	 30.0;
	8917	 6553	 0.036777	 0.116041	 0.0	 260	 260	 260	 0.0	 0.0	 1	 -30.0	 30.0;
	11791	 12588	 0.003851	 0.00995	 0.0	 2961	 2961	 2961	 0.0	 0.0	 1	 -30.0	 30.0;
	11791	 12503	 0.025793	 0.056702	 0.0	 508	 508	 508	 0.0	 0.0	 1	 -30.0	 30.0;
	5102	 11791	 0.027942	 0.061421	 0.0	 469	 469	 469	 0.0	 0.0	 1	 -30.0	 30.0;
	12588	 13204	 0.021488	 0.047248	 0.0	 609	 609	 609	 0.0	 0.0	 1	 -30.0	 30.0;
	6364	 763	 0.00015	 0.00136	 0.0	 27475	 27475	 27475	 0.0	 0.0	 1	 -30.0	 30.0;
	10634	 12371	 0.016909	 0.037174	 0.0	 774	 774	 774	 0.0	 0.0	 1	 -30.0	 30.0;
	6449	 10634	 0.040496	 0.088512	 0.0	 325	 325	 325	 0.0	 0.0	 1	 -30.0	 30.0;
	7263	 6925	 0.035231	 0.111132	 0.0	 271	 271	 271	 0.0	 0.0	 1	 -30.0	 30.0;
	3125	 7263	 0.031017	 0.086752	 0.0	 343	 343	 343	 0.0	 0.0	 1	 -30.0	 30.0;
	5829	 6972	 0.003983	 0.014017	 0.0	 2168	 2168	 2168	 0.0	 0.0	 1	 -30.0	 30.0;
	9807	 11836	 0.003521	 0.010496	 0.0	 2854	 2854	 2854	 0.0	 0.0	 1	 -30.0	 30.0;
	12496	 11836	 0.002686	 0.00805	 0.0	 3723	 3723	 3723	 0.0	 0.0	 1	 -30.0	 30.0;
	10049	 9131	 0.05195	 0.145298	 0.0	 205	 205	 205	 0.0	 0.0	 1	 -30.0	 30.0;
	13636	 10937	 0.023207	 0.053132	 0.0	 545	 545	 545	 0.0	 0.0	 1	 -30.0	 30.0;
	2996	 13636	 0.049587	 0.150256	 0.0	 200	 200	 200	 0.0	 0.0	 1	 -30.0	 30.0;
	3677	 2094	 0.036719	 0.111298	 0.0	 270	 270	 270	 0.0	 0.0	 1	 -30.0	 30.0;
	744	 3677	 0.008364	 0.023207	 0.0	 1281	 1281	 1281	 0.0	 0.0	 1	 -30.0	 30.0;
	2002	 8798	 0.005256	 0.024653	 0.0	 1254	 1254	 1254	 0.0	 0.0	 1	 -30.0	 30.0;
	5737	 8798	 0.001347	 0.004397	 0.0	 6869	 6869	 6869	 0.0	 0.0	 1	 -30.0	 30.0;
	12952	 10108	 0.005149	 0.022826	 0.0	 1350	 1350	 1350	 0.0	 0.0	 1	 -30.0	 30.0;
	8324	 10108	 0.001207	 0.004992	 0.0	 6151	 6151	 6151	 0.0	 0.0	 1	 -30.0	 30.0;
	9941	 7422	 0.003934	 0.009744	 0.0	 3006	 3006	 3006	 0.0	 0.0	 1	 -30.0	 30.0;
	8115	 10571	 0.01438	 0.04186	 0.0	 714	 714	 714	 0.0	 0.0	 1	 -30.0	 30.0;
	2018	 2616	 0.005744	 0.014967	 0.0	 1971	 1971	 1971	 0.0	 0.0	 1	 -30.0	 30.0;
	9116	 425	 0.00176	 0.01659	 0.0	 2254	 2254	 2254	 0.0	 0.0	 1	 -30.0	 30.0;
	7326	 425	 0.00151	 0.01378	 0.0	 2712	 2712	 2712	 0.0	 0.0	 1	 -30.0	 30.0;
	7326	 425	 0.00128	 0.01392	 0.0	 2690	 2690	 2690	 0.0	 0.0	 1	 -30.0	 30.0;
	425	 5789	 0.00052	 0.00397	 0.0	 9389	 9389	 9389	 0.0	 0.0	 1	 -30.0	 30.0;
	6261	 425	 0.00221	 0.02248	 0.0	 1665	 1665	 1665	 0.0	 0.0	 1	 -30.0	 30.0;
	10393	 9936	 0.007182	 0.017107	 0.0	 1703	 1703	 1703	 0.0	 0.0	 1	 -30.0	 30.0;
	9936	 6033	 0.005149	 0.011339	 0.0	 2537	 2537	 2537	 0.0	 0.0	 1	 -30.0	 30.0;
	12672	 2706	 0.00943	 0.02157	 0.0	 1342	 1342	 1342	 0.0	 0.0	 1	 -30.0	 30.0;
	10498	 6492	 0.040636	 0.11257	 0.0	 264	 264	 264	 0.0	 0.0	 1	 -30.0	 30.0;
	13239	 10498	 0.014496	 0.042231	 0.0	 708	 708	 708	 0.0	 0.0	 1	 -30.0	 30.0;
	2833	 11164	 0.002744	 0.00995	 0.0	 3061	 3061	 3061	 0.0	 0.0	 1	 -30.0	 30.0;
	11164	 9631	 0.003099	 0.009752	 0.0	 3087	 3087	 3087	 0.0	 0.0	 1	 -30.0	 30.0;
	5424	 13040	 0.007322	 0.016744	 0.0	 1729	 1729	 1729	 0.0	 0.0	 1	 -30.0	 30.0;
	12090	 13040	 0.03024	 0.069231	 0.0	 419	 419	 419	 0.0	 0.0	 1	 -30.0	 30.0;
	9838	 1926	 0.008438	 0.018669	 0.0	 1542	 1542	 1542	 0.0	 0.0	 1	 -30.0	 30.0;
	1926	 744	 0.006727	 0.027942	 0.0	 1100	 1100	 1100	 0.0	 0.0	 1	 -30.0	 30.0;
	1926	 744	 0.006587	 0.028488	 0.0	 1081	 1081	 1081	 0.0	 0.0	 1	 -30.0	 30.0;
	6175	 3612	 0.014579	 0.040463	 0.0	 735	 735	 735	 0.0	 0.0	 1	 -30.0	 30.0;
	1800	 3612	 0.012826	 0.036992	 0.0	 807	 807	 807	 0.0	 0.0	 1	 -30.0	 30.0;
	3612	 7222	 0.006909	 0.019917	 0.0	 1499	 1499	 1499	 0.0	 0.0	 1	 -30.0	 30.0;
	9112	 11615	 0.003421	 0.011041	 0.0	 2733	 2733	 2733	 0.0	 0.0	 1	 -30.0	 30.0;
	9112	 8928	 0.005364	 0.016289	 0.0	 1842	 1842	 1842	 0.0	 0.0	 1	 -30.0	 30.0;
	6520	 6134	 0.012463	 0.030909	 0.0	 948	 948	 948	 0.0	 0.0	 1	 -30.0	 30.0;
	6520	 6134	 0.012702	 0.030273	 0.0	 963	 963	 963	 0.0	 0.0	 1	 -30.0	 30.0;
	10289	 6134	 0.008331	 0.02438	 0.0	 1227	 1227	 1227	 0.0	 0.0	 1	 -30.0	 30.0;
	12177	 6134	 0.008149	 0.024843	 0.0	 1209	 1209	 1209	 0.0	 0.0	 1	 -30.0	 30.0;
	2385	 2599	 0.010789	 0.071169	 0.0	 523	 523	 523	 0.0	 0.0	 1	 -30.0	 30.0;
	5659	 2599	 0.011901	 0.08499	 0.0	 439	 439	 439	 0.0	 0.0	 1	 -30.0	 30.0;
	3051	 6397	 0.035942	 0.113397	 0.0	 266	 266	 266	 0.0	 0.0	 1	 -30.0	 30.0;
	10412	 3051	 0.035818	 0.078752	 0.0	 366	 366	 366	 0.0	 0.0	 1	 -30.0	 30.0;
	3051	 6518	 0.052587	 0.147083	 0.0	 203	 203	 203	 0.0	 0.0	 1	 -30.0	 30.0;
	12981	 10684	 0.007273	 0.016661	 0.0	 1738	 1738	 1738	 0.0	 0.0	 1	 -30.0	 30.0;
	4571	 10684	 0.023488	 0.072488	 0.0	 415	 415	 415	 0.0	 0.0	 1	 -30.0	 30.0;
	13204	 4527	 0.004207	 0.011777	 0.0	 2526	 2526	 2526	 0.0	 0.0	 1	 -30.0	 30.0;
	12503	 4527	 0.005339	 0.020388	 0.0	 1499	 1499	 1499	 0.0	 0.0	 1	 -30.0	 30.0;
	11751	 1846	 0.007446	 0.01638	 0.0	 1756	 1756	 1756	 0.0	 0.0	 1	 -30.0	 30.0;
	4409	 1846	 0.023033	 0.057124	 0.0	 513	 513	 513	 0.0	 0.0	 1	 -30.0	 30.0;
	268	 3852	 0.030198	 0.095248	 0.0	 317	 317	 317	 0.0	 0.0	 1	 -30.0	 30.0;
	9174	 7484	 0.0	 0.000744	 0.0	 42457	 42457	 42457	 0.0	 0.0	 1	 -30.0	 30.0;
	4365	 9174	 0.003628	 0.012	 0.0	 2520	 2520	 2520	 0.0	 0.0	 1	 -30.0	 30.0;
	9174	 5737	 0.00681	 0.028273	 0.0	 1087	 1087	 1087	 0.0	 0.0	 1	 -30.0	 30.0;
	7484	 8324	 0.006669	 0.028826	 0.0	 1068	 1068	 1068	 0.0	 0.0	 1	 -30.0	 30.0;
	4297	 4885	 0.04543	 0.100521	 0.0	 287	 287	 287	 0.0	 0.0	 1	 -30.0	 30.0;
	4297	 4885	 0.046273	 0.098331	 0.0	 291	 291	 291	 0.0	 0.0	 1	 -30.0	 30.0;
	3332	 4885	 0.005041	 0.014554	 0.0	 2051	 2051	 2051	 0.0	 0.0	 1	 -30.0	 30.0;
	7094	 7004	 0.007818	 0.021653	 0.0	 1373	 1373	 1373	 0.0	 0.0	 1	 -30.0	 30.0;
	7004	 12667	 0.041992	 0.154033	 0.0	 198	 198	 198	 0.0	 0.0	 1	 -30.0	 30.0;
	10403	 9053	 0.003711	 0.009612	 0.0	 3066	 3066	 3066	 0.0	 0.0	 1	 -30.0	 30.0;
	6449	 10403	 0.009959	 0.025719	 0.0	 1146	 1146	 1146	 0.0	 0.0	 1	 -30.0	 30.0;
	11041	 9053	 0.006744	 0.014314	 0.0	 1997	 1997	 1997	 0.0	 0.0	 1	 -30.0	 30.0;
	1630	 9814	 0.023909	 0.052901	 0.0	 545	 545	 545	 0.0	 0.0	 1	 -30.0	 30.0;
	9814	 9750	 0.024347	 0.051752	 0.0	 553	 553	 553	 0.0	 0.0	 1	 -30.0	 30.0;
	5035	 1336	 0.04324	 0.088702	 0.0	 321	 321	 321	 0.0	 0.0	 1	 -30.0	 30.0;
	5035	 785	 0.045223	 0.125488	 0.0	 237	 237	 237	 0.0	 0.0	 1	 -30.0	 30.0;
	7656	 1863	 0.00305	 0.007893	 0.0	 3733	 3733	 3733	 0.0	 0.0	 1	 -30.0	 30.0;
	6410	 12380	 0.01905	 0.060107	 0.0	 501	 501	 501	 0.0	 0.0	 1	 -30.0	 30.0;
	12380	 9954	 0.023471	 0.055934	 0.0	 521	 521	 521	 0.0	 0.0	 1	 -30.0	 30.0;
	11607	 6540	 0.004893	 0.014339	 0.0	 2085	 2085	 2085	 0.0	 0.0	 1	 -30.0	 30.0;
	7961	 9915	 0.022934	 0.050397	 0.0	 571	 571	 571	 0.0	 0.0	 1	 -30.0	 30.0;
	85	 10644	 0.037248	 0.081901	 0.0	 352	 352	 352	 0.0	 0.0	 1	 -30.0	 30.0;
	1870	 10644	 0.013347	 0.039083	 0.0	 765	 765	 765	 0.0	 0.0	 1	 -30.0	 30.0;
	7301	 10644	 0.013058	 0.039818	 0.0	 754	 754	 754	 0.0	 0.0	 1	 -30.0	 30.0;
	10566	 12988	 0.04038	 0.11757	 0.0	 255	 255	 255	 0.0	 0.0	 1	 -30.0	 30.0;
	12988	 11041	 0.037397	 0.111653	 0.0	 269	 269	 269	 0.0	 0.0	 1	 -30.0	 30.0;
	58	 6216	 0.029273	 0.069752	 0.0	 418	 418	 418	 0.0	 0.0	 1	 -30.0	 30.0;
	58	 3747	 0.023678	 0.070702	 0.0	 424	 424	 424	 0.0	 0.0	 1	 -30.0	 30.0;
	1819	 9632	 0.001868	 0.005463	 0.0	 5472	 5472	 5472	 0.0	 0.0	 1	 -30.0	 30.0;
	5142	 6935	 0.00048	 0.00423	 0.0	 8831	 8831	 8831	 0.0	 0.0	 1	 -30.0	 30.0;
	8512	 12982	 0.003992	 0.010289	 0.0	 2863	 2863	 2863	 0.0	 0.0	 1	 -30.0	 30.0;
	8512	 4884	 0.003777	 0.009413	 0.0	 3115	 3115	 3115	 0.0	 0.0	 1	 -30.0	 30.0;
	9271	 8512	 0.015091	 0.047174	 0.0	 638	 638	 638	 0.0	 0.0	 1	 -30.0	 30.0;
	11651	 5583	 0.013826	 0.039917	 0.0	 748	 748	 748	 0.0	 0.0	 1	 -30.0	 30.0;
	11651	 899	 0.015678	 0.039124	 0.0	 750	 750	 750	 0.0	 0.0	 1	 -30.0	 30.0;
	11651	 8917	 0.066851	 0.192818	 0.0	 155	 155	 155	 0.0	 0.0	 1	 -30.0	 30.0;
	11651	 13422	 0.039653	 0.128983	 0.0	 235	 235	 235	 0.0	 0.0	 1	 -30.0	 30.0;
	12982	 10233	 0.005091	 0.009702	 0.0	 2883	 2883	 2883	 0.0	 0.0	 1	 -30.0	 30.0;
	10233	 1503	 0.004066	 0.010083	 0.0	 2906	 2906	 2906	 0.0	 0.0	 1	 -30.0	 30.0;
	1503	 5583	 0.007661	 0.024058	 0.0	 1252	 1252	 1252	 0.0	 0.0	 1	 -30.0	 30.0;
	11512	 5583	 0.045636	 0.13286	 0.0	 225	 225	 225	 0.0	 0.0	 1	 -30.0	 30.0;
	4884	 1503	 0.018421	 0.042868	 0.0	 677	 677	 677	 0.0	 0.0	 1	 -30.0	 30.0;
	2659	 8186	 0.00805	 0.04211	 0.0	 737	 737	 737	 0.0	 0.0	 1	 -30.0	 30.0;
	8186	 6424	 0.003211	 0.02194	 0.0	 1425	 1425	 1425	 0.0	 0.0	 1	 -30.0	 30.0;
	8186	 6343	 0.00974	 0.05531	 0.0	 563	 563	 563	 0.0	 0.0	 1	 -30.0	 30.0;
	13615	 2562	 0.019719	 0.05495	 0.0	 542	 542	 542	 0.0	 0.0	 1	 -30.0	 30.0;
	8115	 3442	 0.03495	 0.086686	 0.0	 338	 338	 338	 0.0	 0.0	 1	 -30.0	 30.0;
	9208	 3442	 0.041149	 0.122851	 0.0	 244	 244	 244	 0.0	 0.0	 1	 -30.0	 30.0;
	10611	 5424	 0.01124	 0.027893	 0.0	 1051	 1051	 1051	 0.0	 0.0	 1	 -30.0	 30.0;
	825	 2060	 0.02219	 0.057281	 0.0	 515	 515	 515	 0.0	 0.0	 1	 -30.0	 30.0;
	2060	 1214	 0.011843	 0.030529	 0.0	 965	 965	 965	 0.0	 0.0	 1	 -30.0	 30.0;
	1336	 172	 0.014298	 0.039983	 0.0	 744	 744	 744	 0.0	 0.0	 1	 -30.0	 30.0;
	13591	 6520	 0.008083	 0.028636	 0.0	 1062	 1062	 1062	 0.0	 0.0	 1	 -30.0	 30.0;
	10289	 6520	 0.012942	 0.02962	 0.0	 978	 978	 978	 0.0	 0.0	 1	 -30.0	 30.0;
	3798	 8463	 0.01657	 0.050017	 0.0	 600	 600	 600	 0.0	 0.0	 1	 -30.0	 30.0;
	2562	 3798	 0.006331	 0.019107	 0.0	 1570	 1570	 1570	 0.0	 0.0	 1	 -30.0	 30.0;
	12886	 5859	 0.003983	 0.013537	 0.0	 2239	 2239	 2239	 0.0	 0.0	 1	 -30.0	 30.0;
	2216	 9116	 0.00136	 0.01515	 0.0	 2472	 2472	 2472	 0.0	 0.0	 1	 -30.0	 30.0;
	8455	 13335	 0.007876	 0.01743	 0.0	 1652	 1652	 1652	 0.0	 0.0	 1	 -30.0	 30.0;
	10583	 1890	 0.018636	 0.055653	 0.0	 539	 539	 539	 0.0	 0.0	 1	 -30.0	 30.0;
	3852	 10583	 0.010554	 0.031504	 0.0	 951	 951	 951	 0.0	 0.0	 1	 -30.0	 30.0;
	8310	 2479	 0.013488	 0.039686	 0.0	 754	 754	 754	 0.0	 0.0	 1	 -30.0	 30.0;
	2479	 7415	 0.021934	 0.048198	 0.0	 597	 597	 597	 0.0	 0.0	 1	 -30.0	 30.0;
	7205	 11872	 0.0	 0.00086	 0.0	 36730	 36730	 36730	 0.0	 0.0	 1	 -30.0	 30.0;
	7205	 12538	 0.026463	 0.075669	 0.0	 395	 395	 395	 0.0	 0.0	 1	 -30.0	 30.0;
	7205	 1364	 0.029446	 0.081364	 0.0	 366	 366	 366	 0.0	 0.0	 1	 -30.0	 30.0;
	7926	 7205	 0.055851	 0.127826	 0.0	 227	 227	 227	 0.0	 0.0	 1	 -30.0	 30.0;
	5102	 11872	 0.047818	 0.124744	 0.0	 237	 237	 237	 0.0	 0.0	 1	 -30.0	 30.0;
	7158	 5837	 0.02562	 0.063256	 0.0	 463	 463	 463	 0.0	 0.0	 1	 -30.0	 30.0;
	5837	 4312	 0.006372	 0.012298	 0.0	 2281	 2281	 2281	 0.0	 0.0	 1	 -30.0	 30.0;
	9449	 3937	 0.009603	 0.021099	 0.0	 1363	 1363	 1363	 0.0	 0.0	 1	 -30.0	 30.0;
	13204	 10189	 0.014917	 0.052579	 0.0	 578	 578	 578	 0.0	 0.0	 1	 -30.0	 30.0;
	6739	 10189	 0.03014	 0.083512	 0.0	 356	 356	 356	 0.0	 0.0	 1	 -30.0	 30.0;
	10691	 8869	 0.03319	 0.092818	 0.0	 321	 321	 321	 0.0	 0.0	 1	 -30.0	 30.0;
	8869	 11437	 0.024248	 0.067826	 0.0	 439	 439	 439	 0.0	 0.0	 1	 -30.0	 30.0;
	4388	 12247	 0.048529	 0.153091	 0.0	 197	 197	 197	 0.0	 0.0	 1	 -30.0	 30.0;
	5033	 4388	 0.055397	 0.137421	 0.0	 214	 214	 214	 0.0	 0.0	 1	 -30.0	 30.0;
	13638	 5480	 0.0	 0.000219	 0.0	 144235	 144235	 144235	 0.0	 0.0	 1	 -30.0	 30.0;
	13638	 7984	 0.0013	 0.008539	 0.0	 3658	 3658	 3658	 0.0	 0.0	 1	 -30.0	 30.0;
	6914	 13638	 0.007169	 0.04463	 0.0	 699	 699	 699	 0.0	 0.0	 1	 -30.0	 30.0;
	13638	 10584	 0.01787	 0.097419	 0.0	 319	 319	 319	 0.0	 0.0	 1	 -30.0	 30.0;
	5480	 7984	 0.00164	 0.007409	 0.0	 4163	 4163	 4163	 0.0	 0.0	 1	 -30.0	 30.0;
	5480	 12756	 0.0097	 0.06274	 0.0	 498	 498	 498	 0.0	 0.0	 1	 -30.0	 30.0;
	6914	 5480	 0.007021	 0.045469	 0.0	 687	 687	 687	 0.0	 0.0	 1	 -30.0	 30.0;
	4070	 11936	 0.007496	 0.022397	 0.0	 1338	 1338	 1338	 0.0	 0.0	 1	 -30.0	 30.0;
	6033	 11936	 0.007959	 0.024124	 0.0	 1244	 1244	 1244	 0.0	 0.0	 1	 -30.0	 30.0;
	11199	 4317	 0.00405	 0.011686	 0.0	 2554	 2554	 2554	 0.0	 0.0	 1	 -30.0	 30.0;
	11199	 9454	 0.005471	 0.01581	 0.0	 1889	 1889	 1889	 0.0	 0.0	 1	 -30.0	 30.0;
	6953	 10393	 0.012727	 0.031579	 0.0	 928	 928	 928	 0.0	 0.0	 1	 -30.0	 30.0;
	6904	 6953	 0.009529	 0.027496	 0.0	 1086	 1086	 1086	 0.0	 0.0	 1	 -30.0	 30.0;
	1293	 2924	 0.0	 0.000876	 0.0	 36059	 36059	 36059	 0.0	 0.0	 1	 -30.0	 30.0;
	11439	 2924	 0.01243	 0.040413	 0.0	 748	 748	 748	 0.0	 0.0	 1	 -30.0	 30.0;
	6904	 2924	 0.002636	 0.007967	 0.0	 3765	 3765	 3765	 0.0	 0.0	 1	 -30.0	 30.0;
	6904	 2924	 0.002686	 0.007802	 0.0	 3829	 3829	 3829	 0.0	 0.0	 1	 -30.0	 30.0;
	1293	 6652	 0.049421	 0.127587	 0.0	 231	 231	 231	 0.0	 0.0	 1	 -30.0	 30.0;
	7986	 1293	 0.006587	 0.018248	 0.0	 1629	 1629	 1629	 0.0	 0.0	 1	 -30.0	 30.0;
	1293	 2800	 0.064438	 0.166364	 0.0	 178	 178	 178	 0.0	 0.0	 1	 -30.0	 30.0;
	10812	 6304	 0.085322	 0.155132	 0.0	 179	 179	 179	 0.0	 0.0	 1	 -30.0	 30.0;
	534	 7158	 0.050488	 0.130339	 0.0	 226	 226	 226	 0.0	 0.0	 1	 -30.0	 30.0;
	13073	 534	 0.035471	 0.111893	 0.0	 270	 270	 270	 0.0	 0.0	 1	 -30.0	 30.0;
	10566	 8057	 0.013876	 0.045132	 0.0	 669	 669	 669	 0.0	 0.0	 1	 -30.0	 30.0;
	8057	 6449	 0.042744	 0.16319	 0.0	 188	 188	 188	 0.0	 0.0	 1	 -30.0	 30.0;
	7331	 6838	 0.027512	 0.080083	 0.0	 374	 374	 374	 0.0	 0.0	 1	 -30.0	 30.0;
	5918	 7331	 0.013132	 0.038223	 0.0	 782	 782	 782	 0.0	 0.0	 1	 -30.0	 30.0;
	12827	 11000	 0.017347	 0.051802	 0.0	 579	 579	 579	 0.0	 0.0	 1	 -30.0	 30.0;
	5033	 11000	 0.036446	 0.086851	 0.0	 336	 336	 336	 0.0	 0.0	 1	 -30.0	 30.0;
	5692	 127	 0.0	 0.000893	 0.0	 35373	 35373	 35373	 0.0	 0.0	 1	 -30.0	 30.0;
	669	 127	 0.013223	 0.056876	 0.0	 541	 541	 541	 0.0	 0.0	 1	 -30.0	 30.0;
	127	 8673	 0.01662	 0.035322	 0.0	 810	 810	 810	 0.0	 0.0	 1	 -30.0	 30.0;
	9939	 5692	 0.023752	 0.069157	 0.0	 432	 432	 432	 0.0	 0.0	 1	 -30.0	 30.0;
	5692	 7584	 0.029851	 0.100967	 0.0	 301	 301	 301	 0.0	 0.0	 1	 -30.0	 30.0;
	5692	 6094	 0.014322	 0.031504	 0.0	 913	 913	 913	 0.0	 0.0	 1	 -30.0	 30.0;
	5692	 11431	 0.01481	 0.040017	 0.0	 741	 741	 741	 0.0	 0.0	 1	 -30.0	 30.0;
	6397	 6518	 0.038066	 0.094413	 0.0	 311	 311	 311	 0.0	 0.0	 1	 -30.0	 30.0;
	8215	 12637	 0.018702	 0.058967	 0.0	 511	 511	 511	 0.0	 0.0	 1	 -30.0	 30.0;
	11431	 8215	 0.008554	 0.023917	 0.0	 1244	 1244	 1244	 0.0	 0.0	 1	 -30.0	 30.0;
	2511	 2659	 0.009849	 0.05651	 0.0	 551	 551	 551	 0.0	 0.0	 1	 -30.0	 30.0;
	6947	 6739	 0.013554	 0.032066	 0.0	 908	 908	 908	 0.0	 0.0	 1	 -30.0	 30.0;
	6947	 3598	 0.013719	 0.042876	 0.0	 702	 702	 702	 0.0	 0.0	 1	 -30.0	 30.0;
	10882	 12635	 0.032512	 0.094636	 0.0	 316	 316	 316	 0.0	 0.0	 1	 -30.0	 30.0;
	12635	 6205	 0.040008	 0.116479	 0.0	 257	 257	 257	 0.0	 0.0	 1	 -30.0	 30.0;
	11380	 630	 0.02319	 0.055273	 0.0	 527	 527	 527	 0.0	 0.0	 1	 -30.0	 30.0;
	1364	 11380	 0.013248	 0.046413	 0.0	 655	 655	 655	 0.0	 0.0	 1	 -30.0	 30.0;
	7926	 11380	 0.073289	 0.23843	 0.0	 127	 127	 127	 0.0	 0.0	 1	 -30.0	 30.0;
	2578	 451	 0.008083	 0.029661	 0.0	 1028	 1028	 1028	 0.0	 0.0	 1	 -30.0	 30.0;
	10531	 451	 0.014661	 0.058273	 0.0	 526	 526	 526	 0.0	 0.0	 1	 -30.0	 30.0;
	7089	 5231	 0.017273	 0.044587	 0.0	 661	 661	 661	 0.0	 0.0	 1	 -30.0	 30.0;
	5231	 4923	 0.016413	 0.049	 0.0	 612	 612	 612	 0.0	 0.0	 1	 -30.0	 30.0;
	2443	 11280	 0.054587	 0.120008	 0.0	 240	 240	 240	 0.0	 0.0	 1	 -30.0	 30.0;
	12931	 2443	 0.049521	 0.144149	 0.0	 208	 208	 208	 0.0	 0.0	 1	 -30.0	 30.0;
	12776	 3726	 0.02757	 0.063124	 0.0	 459	 459	 459	 0.0	 0.0	 1	 -30.0	 30.0;
	10791	 825	 0.037686	 0.089818	 0.0	 325	 325	 325	 0.0	 0.0	 1	 -30.0	 30.0;
	8115	 899	 0.106033	 0.321289	 0.0	 94	 94	 94	 0.0	 0.0	 1	 -30.0	 30.0;
	13599	 8115	 0.066959	 0.153273	 0.0	 189	 189	 189	 0.0	 0.0	 1	 -30.0	 30.0;
	8115	 9816	 0.074421	 0.208132	 0.0	 143	 143	 143	 0.0	 0.0	 1	 -30.0	 30.0;
	8115	 13623	 0.054157	 0.123967	 0.0	 234	 234	 234	 0.0	 0.0	 1	 -30.0	 30.0;
	989	 5553	 0.086802	 0.24276	 0.0	 123	 123	 123	 0.0	 0.0	 1	 -30.0	 30.0;
	5553	 3467	 0.007628	 0.018826	 0.0	 1556	 1556	 1556	 0.0	 0.0	 1	 -30.0	 30.0;
	3963	 5381	 0.021256	 0.050669	 0.0	 575	 575	 575	 0.0	 0.0	 1	 -30.0	 30.0;
	9577	 159	 0.015893	 0.046223	 0.0	 647	 647	 647	 0.0	 0.0	 1	 -30.0	 30.0;
	159	 4447	 0.01562	 0.034331	 0.0	 838	 838	 838	 0.0	 0.0	 1	 -30.0	 30.0;
	11449	 8756	 0.011174	 0.023008	 0.0	 1235	 1235	 1235	 0.0	 0.0	 1	 -30.0	 30.0;
	703	 11449	 0.014438	 0.036174	 0.0	 811	 811	 811	 0.0	 0.0	 1	 -30.0	 30.0;
	8756	 4447	 0.012636	 0.029752	 0.0	 978	 978	 978	 0.0	 0.0	 1	 -30.0	 30.0;
	4317	 11439	 0.0	 0.000826	 0.0	 38242	 38242	 38242	 0.0	 0.0	 1	 -30.0	 30.0;
	4317	 4070	 0.00086	 0.003157	 0.0	 9654	 9654	 9654	 0.0	 0.0	 1	 -30.0	 30.0;
	4317	 9454	 0.01005	 0.027843	 0.0	 1068	 1068	 1068	 0.0	 0.0	 1	 -30.0	 30.0;
	11439	 1459	 0.000843	 0.003223	 0.0	 9482	 9482	 9482	 0.0	 0.0	 1	 -30.0	 30.0;
	9029	 2833	 0.022983	 0.064256	 0.0	 463	 463	 463	 0.0	 0.0	 1	 -30.0	 30.0;
	2833	 8832	 0.008603	 0.018273	 0.0	 1564	 1564	 1564	 0.0	 0.0	 1	 -30.0	 30.0;
	2833	 8832	 0.007661	 0.020702	 0.0	 1431	 1431	 1431	 0.0	 0.0	 1	 -30.0	 30.0;
	2833	 9631	 0.002678	 0.007174	 0.0	 4125	 4125	 4125	 0.0	 0.0	 1	 -30.0	 30.0;
	2833	 9631	 0.002388	 0.008132	 0.0	 3727	 3727	 3727	 0.0	 0.0	 1	 -30.0	 30.0;
	2524	 1040	 0.00237	 0.011781	 0.0	 3129	 3129	 3129	 0.0	 0.0	 1	 -30.0	 30.0;
	6474	 5186	 0.001901	 0.012831	 0.0	 2436	 2436	 2436	 0.0	 0.0	 1	 -30.0	 30.0;
	3149	 5944	 0.0	 0.00081	 0.0	 38997	 38997	 38997	 0.0	 0.0	 1	 -30.0	 30.0;
	3149	 8198	 0.017273	 0.025289	 0.0	 1032	 1032	 1032	 0.0	 0.0	 1	 -30.0	 30.0;
	5944	 7332	 0.030909	 0.042397	 0.0	 603	 603	 603	 0.0	 0.0	 1	 -30.0	 30.0;
	5944	 11554	 0.020967	 0.066149	 0.0	 456	 456	 456	 0.0	 0.0	 1	 -30.0	 30.0;
	7032	 8304	 0.049719	 0.109298	 0.0	 264	 264	 264	 0.0	 0.0	 1	 -30.0	 30.0;
	8304	 6972	 0.065909	 0.144901	 0.0	 199	 199	 199	 0.0	 0.0	 1	 -30.0	 30.0;
	1720	 9834	 0.00614	 0.05775	 0.0	 648	 648	 648	 0.0	 0.0	 1	 -30.0	 30.0;
	8310	 12952	 0.020678	 0.079256	 0.0	 386	 386	 386	 0.0	 0.0	 1	 -30.0	 30.0;
	6216	 12952	 0.020529	 0.051702	 0.0	 568	 568	 568	 0.0	 0.0	 1	 -30.0	 30.0;
	2002	 13404	 0.015066	 0.050711	 0.0	 598	 598	 598	 0.0	 0.0	 1	 -30.0	 30.0;
	373	 12960	 0.032364	 0.074058	 0.0	 391	 391	 391	 0.0	 0.0	 1	 -30.0	 30.0;
	3634	 373	 0.024893	 0.069612	 0.0	 428	 428	 428	 0.0	 0.0	 1	 -30.0	 30.0;
	5650	 11280	 0.051289	 0.112769	 0.0	 255	 255	 255	 0.0	 0.0	 1	 -30.0	 30.0;
	11508	 13204	 0.024124	 0.069562	 0.0	 430	 430	 430	 0.0	 0.0	 1	 -30.0	 30.0;
	13204	 1799	 0.026769	 0.10219	 0.0	 300	 300	 300	 0.0	 0.0	 1	 -30.0	 30.0;
	11658	 13204	 0.025909	 0.077347	 0.0	 388	 388	 388	 0.0	 0.0	 1	 -30.0	 30.0;
	13204	 1118	 0.01324	 0.046628	 0.0	 652	 652	 652	 0.0	 0.0	 1	 -30.0	 30.0;
	12410	 11450	 0.01676	 0.03686	 0.0	 781	 781	 781	 0.0	 0.0	 1	 -30.0	 30.0;
	3598	 12410	 0.017612	 0.043678	 0.0	 671	 671	 671	 0.0	 0.0	 1	 -30.0	 30.0;
	11751	 6694	 0.02043	 0.057124	 0.0	 521	 521	 521	 0.0	 0.0	 1	 -30.0	 30.0;
	9238	 10256	 0.00084	 0.00669	 0.0	 4685	 4685	 4685	 0.0	 0.0	 1	 -30.0	 30.0;
	2636	 6318	 0.019893	 0.062752	 0.0	 480	 480	 480	 0.0	 0.0	 1	 -30.0	 30.0;
	9373	 117	 0.058719	 0.164223	 0.0	 182	 182	 182	 0.0	 0.0	 1	 -30.0	 30.0;
	9373	 3634	 0.021661	 0.049587	 0.0	 584	 584	 584	 0.0	 0.0	 1	 -30.0	 30.0;
	876	 2874	 0.008	 0.030686	 0.0	 997	 997	 997	 0.0	 0.0	 1	 -30.0	 30.0;
	5454	 6655	 0.024017	 0.057248	 0.0	 509	 509	 509	 0.0	 0.0	 1	 -30.0	 30.0;
	6849	 1038	 0.005636	 0.020727	 0.0	 1471	 1471	 1471	 0.0	 0.0	 1	 -30.0	 30.0;
	7533	 10300	 0.004769	 0.016826	 0.0	 1807	 1807	 1807	 0.0	 0.0	 1	 -30.0	 30.0;
	11994	 7533	 0.00895	 0.031554	 0.0	 964	 964	 964	 0.0	 0.0	 1	 -30.0	 30.0;
	11679	 5579	 0.010919	 0.07275	 0.0	 511	 511	 511	 0.0	 0.0	 1	 -30.0	 30.0;
	5579	 12015	 0.004841	 0.02861	 0.0	 1296	 1296	 1296	 0.0	 0.0	 1	 -30.0	 30.0;
	13155	 4260	 0.044909	 0.092107	 0.0	 309	 309	 309	 0.0	 0.0	 1	 -30.0	 30.0;
	4571	 4383	 0.011901	 0.039537	 0.0	 766	 766	 766	 0.0	 0.0	 1	 -30.0	 30.0;
	596	 13378	 0.008421	 0.020066	 0.0	 1452	 1452	 1452	 0.0	 0.0	 1	 -30.0	 30.0;
	13378	 2142	 0.07076	 0.184612	 0.0	 160	 160	 160	 0.0	 0.0	 1	 -30.0	 30.0;
	13378	 7300	 0.00624	 0.018917	 0.0	 1586	 1586	 1586	 0.0	 0.0	 1	 -30.0	 30.0;
	13378	 2865	 0.055157	 0.127587	 0.0	 228	 228	 228	 0.0	 0.0	 1	 -30.0	 30.0;
	12637	 1099	 0.03562	 0.084876	 0.0	 344	 344	 344	 0.0	 0.0	 1	 -30.0	 30.0;
	1459	 12463	 0.024248	 0.073463	 0.0	 409	 409	 409	 0.0	 0.0	 1	 -30.0	 30.0;
	2616	 9557	 0.006372	 0.012686	 0.0	 2226	 2226	 2226	 0.0	 0.0	 1	 -30.0	 30.0;
	5996	 674	 0.003397	 0.009802	 0.0	 3045	 3045	 3045	 0.0	 0.0	 1	 -30.0	 30.0;
	5996	 7222	 0.002793	 0.008397	 0.0	 3570	 3570	 3570	 0.0	 0.0	 1	 -30.0	 30.0;
	953	 10900	 0.035636	 0.100248	 0.0	 297	 297	 297	 0.0	 0.0	 1	 -30.0	 30.0;
	4708	 10900	 0.034901	 0.102182	 0.0	 293	 293	 293	 0.0	 0.0	 1	 -30.0	 30.0;
	1706	 8231	 0.032388	 0.094281	 0.0	 317	 317	 317	 0.0	 0.0	 1	 -30.0	 30.0;
	7094	 8231	 0.031421	 0.093802	 0.0	 320	 320	 320	 0.0	 0.0	 1	 -30.0	 30.0;
	11679	 7281	 0.02455	 0.175521	 0.0	 213	 213	 213	 0.0	 0.0	 1	 -30.0	 30.0;
	11491	 7281	 0.011281	 0.058469	 0.0	 632	 632	 632	 0.0	 0.0	 1	 -30.0	 30.0;
	7281	 595	 0.015979	 0.102281	 0.0	 364	 364	 364	 0.0	 0.0	 1	 -30.0	 30.0;
	10770	 9459	 0.0	 0.000777	 0.0	 40653	 40653	 40653	 0.0	 0.0	 1	 -30.0	 30.0;
	10770	 12382	 0.010868	 0.037488	 0.0	 810	 810	 810	 0.0	 0.0	 1	 -30.0	 30.0;
	10770	 11553	 0.011967	 0.024562	 0.0	 1157	 1157	 1157	 0.0	 0.0	 1	 -30.0	 30.0;
	9459	 12382	 0.010636	 0.034711	 0.0	 871	 871	 871	 0.0	 0.0	 1	 -30.0	 30.0;
	9459	 13116	 0.055091	 0.164496	 0.0	 183	 183	 183	 0.0	 0.0	 1	 -30.0	 30.0;
	9459	 11557	 0.073091	 0.221488	 0.0	 136	 136	 136	 0.0	 0.0	 1	 -30.0	 30.0;
	12174	 5267	 0.01938	 0.056421	 0.0	 530	 530	 530	 0.0	 0.0	 1	 -30.0	 30.0;
	4524	 5267	 0.018983	 0.057496	 0.0	 522	 522	 522	 0.0	 0.0	 1	 -30.0	 30.0;
	7032	 10289	 0.031413	 0.07795	 0.0	 376	 376	 376	 0.0	 0.0	 1	 -30.0	 30.0;
	7032	 10705	 0.046231	 0.119372	 0.0	 247	 247	 247	 0.0	 0.0	 1	 -30.0	 30.0;
	7744	 4188	 0.012066	 0.029901	 0.0	 980	 980	 980	 0.0	 0.0	 1	 -30.0	 30.0;
	1492	 499	 0.022529	 0.071066	 0.0	 424	 424	 424	 0.0	 0.0	 1	 -30.0	 30.0;
	6655	 1492	 0.027471	 0.065471	 0.0	 445	 445	 445	 0.0	 0.0	 1	 -30.0	 30.0;
	1038	 6319	 0.0	 0.00076	 0.0	 41563	 41563	 41563	 0.0	 0.0	 1	 -30.0	 30.0;
	11994	 6319	 0.005868	 0.020678	 0.0	 1470	 1470	 1470	 0.0	 0.0	 1	 -30.0	 30.0;
	2193	 903	 0.022636	 0.049769	 0.0	 578	 578	 578	 0.0	 0.0	 1	 -30.0	 30.0;
	9784	 7332	 0.033909	 0.047901	 0.0	 539	 539	 539	 0.0	 0.0	 1	 -30.0	 30.0;
	9784	 7332	 0.034537	 0.04686	 0.0	 543	 543	 543	 0.0	 0.0	 1	 -30.0	 30.0;
	7332	 8198	 0.012959	 0.028661	 0.0	 1005	 1005	 1005	 0.0	 0.0	 1	 -30.0	 30.0;
	4396	 11589	 0.003919	 0.02719	 0.0	 1382	 1382	 1382	 0.0	 0.0	 1	 -30.0	 30.0;
	7659	 4560	 0.0	 0.000744	 0.0	 42457	 42457	 42457	 0.0	 0.0	 1	 -30.0	 30.0;
	5768	 7659	 0.013909	 0.038909	 0.0	 765	 765	 765	 0.0	 0.0	 1	 -30.0	 30.0;
	1697	 4560	 0.007579	 0.023	 0.0	 1305	 1305	 1305	 0.0	 0.0	 1	 -30.0	 30.0;
	2334	 6652	 0.032587	 0.077653	 0.0	 376	 376	 376	 0.0	 0.0	 1	 -30.0	 30.0;
	6652	 2213	 0.035744	 0.085851	 0.0	 340	 340	 340	 0.0	 0.0	 1	 -30.0	 30.0;
	1705	 5719	 0.011969	 0.0687	 0.0	 453	 453	 453	 0.0	 0.0	 1	 -30.0	 30.0;
	5719	 1383	 0.00431	 0.024719	 0.0	 1259	 1259	 1259	 0.0	 0.0	 1	 -30.0	 30.0;
	498	 7158	 0.107463	 0.250107	 0.0	 117	 117	 117	 0.0	 0.0	 1	 -30.0	 30.0;
	7158	 1222	 0.043099	 0.099678	 0.0	 291	 291	 291	 0.0	 0.0	 1	 -30.0	 30.0;
	7158	 4923	 0.033058	 0.075669	 0.0	 383	 383	 383	 0.0	 0.0	 1	 -30.0	 30.0;
	12540	 7158	 0.045273	 0.099537	 0.0	 289	 289	 289	 0.0	 0.0	 1	 -30.0	 30.0;
	7158	 3539	 0.071182	 0.141157	 0.0	 200	 200	 200	 0.0	 0.0	 1	 -30.0	 30.0;
	7158	 3539	 0.072554	 0.138223	 0.0	 203	 203	 203	 0.0	 0.0	 1	 -30.0	 30.0;
	1503	 899	 0.00781	 0.02357	 0.0	 1273	 1273	 1273	 0.0	 0.0	 1	 -30.0	 30.0;
	899	 9539	 0.014298	 0.042702	 0.0	 702	 702	 702	 0.0	 0.0	 1	 -30.0	 30.0;
	3992	 11846	 0.016793	 0.041661	 0.0	 704	 704	 704	 0.0	 0.0	 1	 -30.0	 30.0;
	11846	 11091	 0.011017	 0.021711	 0.0	 1298	 1298	 1298	 0.0	 0.0	 1	 -30.0	 30.0;
	2986	 11679	 0.01255	 0.08125	 0.0	 462	 462	 462	 0.0	 0.0	 1	 -30.0	 30.0;
	13328	 11540	 0.008041	 0.022488	 0.0	 1323	 1323	 1323	 0.0	 0.0	 1	 -30.0	 30.0;
	13328	 11540	 0.009149	 0.017438	 0.0	 1605	 1605	 1605	 0.0	 0.0	 1	 -30.0	 30.0;
	13328	 9721	 0.032876	 0.06481	 0.0	 435	 435	 435	 0.0	 0.0	 1	 -30.0	 30.0;
	11877	 13328	 0.022512	 0.056769	 0.0	 518	 518	 518	 0.0	 0.0	 1	 -30.0	 30.0;
	11540	 2442	 0.01276	 0.035702	 0.0	 834	 834	 834	 0.0	 0.0	 1	 -30.0	 30.0;
	2527	 8868	 0.007793	 0.02457	 0.0	 1226	 1226	 1226	 0.0	 0.0	 1	 -30.0	 30.0;
	5597	 8868	 0.00762	 0.022752	 0.0	 1317	 1317	 1317	 0.0	 0.0	 1	 -30.0	 30.0;
	3293	 9630	 0.010157	 0.025198	 0.0	 1163	 1163	 1163	 0.0	 0.0	 1	 -30.0	 30.0;
	3293	 7390	 0.018289	 0.054603	 0.0	 549	 549	 549	 0.0	 0.0	 1	 -30.0	 30.0;
	3293	 8180	 0.031876	 0.082322	 0.0	 358	 358	 358	 0.0	 0.0	 1	 -30.0	 30.0;
	13606	 2527	 0.011289	 0.033917	 0.0	 884	 884	 884	 0.0	 0.0	 1	 -30.0	 30.0;
	7926	 11508	 0.055537	 0.203711	 0.0	 150	 150	 150	 0.0	 0.0	 1	 -30.0	 30.0;
	9770	 12953	 0.001488	 0.003314	 0.0	 8696	 8696	 8696	 0.0	 0.0	 1	 -30.0	 30.0;
	11832	 9770	 0.009083	 0.012124	 0.0	 2086	 2086	 2086	 0.0	 0.0	 1	 -30.0	 30.0;
	5431	 4641	 0.0	 0.000876	 0.0	 36059	 36059	 36059	 0.0	 0.0	 1	 -30.0	 30.0;
	9128	 5142	 0.0011	 0.01267	 0.0	 2956	 2956	 2956	 0.0	 0.0	 1	 -30.0	 30.0;
	5142	 13221	 0.00252	 0.02751	 0.0	 1374	 1374	 1374	 0.0	 0.0	 1	 -30.0	 30.0;
	6838	 11554	 0.04314	 0.128802	 0.0	 233	 233	 233	 0.0	 0.0	 1	 -30.0	 30.0;
	5768	 1697	 0.011562	 0.029843	 0.0	 987	 987	 987	 0.0	 0.0	 1	 -30.0	 30.0;
	11433	 12242	 0.011256	 0.041174	 0.0	 741	 741	 741	 0.0	 0.0	 1	 -30.0	 30.0;
	11433	 12242	 0.011017	 0.04195	 0.0	 729	 729	 729	 0.0	 0.0	 1	 -30.0	 30.0;
	10937	 3594	 0.029496	 0.076149	 0.0	 387	 387	 387	 0.0	 0.0	 1	 -30.0	 30.0;
	12015	 1705	 0.009401	 0.05757	 0.0	 651	 651	 651	 0.0	 0.0	 1	 -30.0	 30.0;
	7094	 1706	 0.056934	 0.185223	 0.0	 164	 164	 164	 0.0	 0.0	 1	 -30.0	 30.0;
	12667	 1706	 0.005479	 0.016479	 0.0	 1819	 1819	 1819	 0.0	 0.0	 1	 -30.0	 30.0;
	12774	 9876	 0.011289	 0.029157	 0.0	 1011	 1011	 1011	 0.0	 0.0	 1	 -30.0	 30.0;
	12774	 848	 0.000504	 0.001446	 0.0	 20628	 20628	 20628	 0.0	 0.0	 1	 -30.0	 30.0;
	1250	 12774	 0.014347	 0.035802	 0.0	 819	 819	 819	 0.0	 0.0	 1	 -30.0	 30.0;
	1250	 12774	 0.014628	 0.035066	 0.0	 832	 832	 832	 0.0	 0.0	 1	 -30.0	 30.0;
	12774	 8985	 0.019537	 0.05462	 0.0	 545	 545	 545	 0.0	 0.0	 1	 -30.0	 30.0;
	9454	 7986	 0.003281	 0.009488	 0.0	 3147	 3147	 3147	 0.0	 0.0	 1	 -30.0	 30.0;
	9271	 3342	 0.033339	 0.086091	 0.0	 343	 343	 343	 0.0	 0.0	 1	 -30.0	 30.0;
	13623	 3342	 0.032628	 0.095	 0.0	 315	 315	 315	 0.0	 0.0	 1	 -30.0	 30.0;
	8463	 10190	 0.008281	 0.029331	 0.0	 1037	 1037	 1037	 0.0	 0.0	 1	 -30.0	 30.0;
	293	 802	 0.008711	 0.059841	 0.0	 628	 628	 628	 0.0	 0.0	 1	 -30.0	 30.0;
	293	 10584	 0.0127	 0.06389	 0.0	 485	 485	 485	 0.0	 0.0	 1	 -30.0	 30.0;
	6175	 8417	 0.0	 0.000826	 0.0	 38242	 38242	 38242	 0.0	 0.0	 1	 -30.0	 30.0;
	6175	 1800	 0.016992	 0.051281	 0.0	 585	 585	 585	 0.0	 0.0	 1	 -30.0	 30.0;
	6175	 674	 0.017322	 0.050223	 0.0	 595	 595	 595	 0.0	 0.0	 1	 -30.0	 30.0;
	6175	 5175	 0.016901	 0.06357	 0.0	 481	 481	 481	 0.0	 0.0	 1	 -30.0	 30.0;
	6175	 4909	 0.037231	 0.112777	 0.0	 266	 266	 266	 0.0	 0.0	 1	 -30.0	 30.0;
	7415	 6175	 0.039636	 0.115388	 0.0	 259	 259	 259	 0.0	 0.0	 1	 -30.0	 30.0;
	3747	 6175	 0.067339	 0.212438	 0.0	 142	 142	 142	 0.0	 0.0	 1	 -30.0	 30.0;
	1214	 9876	 0.061322	 0.134818	 0.0	 214	 214	 214	 0.0	 0.0	 1	 -30.0	 30.0;
	3400	 674	 0.04114	 0.119752	 0.0	 250	 250	 250	 0.0	 0.0	 1	 -30.0	 30.0;
	2010	 2364	 0.03657	 0.109198	 0.0	 275	 275	 275	 0.0	 0.0	 1	 -30.0	 30.0;
	1296	 2010	 0.042488	 0.097248	 0.0	 298	 298	 298	 0.0	 0.0	 1	 -30.0	 30.0;
	2010	 6945	 0.039099	 0.089512	 0.0	 324	 324	 324	 0.0	 0.0	 1	 -30.0	 30.0;
	2727	 2450	 0.013537	 0.032471	 0.0	 898	 898	 898	 0.0	 0.0	 1	 -30.0	 30.0;
	7326	 6941	 0.00158	 0.01747	 0.0	 2144	 2144	 2144	 0.0	 0.0	 1	 -30.0	 30.0;
	2884	 7984	 0.00894	 0.04824	 0.0	 644	 644	 644	 0.0	 0.0	 1	 -30.0	 30.0;
	6914	 2884	 0.003531	 0.018341	 0.0	 1692	 1692	 1692	 0.0	 0.0	 1	 -30.0	 30.0;
	12301	 10882	 0.029818	 0.068256	 0.0	 425	 425	 425	 0.0	 0.0	 1	 -30.0	 30.0;
	9161	 8337	 0.0	 0.00081	 0.0	 38997	 38997	 38997	 0.0	 0.0	 1	 -30.0	 30.0;
	9161	 11292	 0.003512	 0.004661	 0.0	 5413	 5413	 5413	 0.0	 0.0	 1	 -30.0	 30.0;
	6518	 4827	 0.010959	 0.027322	 0.0	 1074	 1074	 1074	 0.0	 0.0	 1	 -30.0	 30.0;
	13622	 8337	 0.003579	 0.004562	 0.0	 5448	 5448	 5448	 0.0	 0.0	 1	 -30.0	 30.0;
	5374	 2636	 0.045843	 0.136851	 0.0	 219	 219	 219	 0.0	 0.0	 1	 -30.0	 30.0;
	5374	 5971	 0.044678	 0.135421	 0.0	 222	 222	 222	 0.0	 0.0	 1	 -30.0	 30.0;
	5374	 2499	 0.015793	 0.04786	 0.0	 627	 627	 627	 0.0	 0.0	 1	 -30.0	 30.0;
	10296	 6205	 0.036248	 0.10138	 0.0	 294	 294	 294	 0.0	 0.0	 1	 -30.0	 30.0;
	2204	 12012	 0.00336	 0.02922	 0.0	 1279	 1279	 1279	 0.0	 0.0	 1	 -30.0	 30.0;
	8051	 11491	 0.01663	 0.097229	 0.0	 382	 382	 382	 0.0	 0.0	 1	 -30.0	 30.0;
	13236	 1890	 0.0	 0.000777	 0.0	 40653	 40653	 40653	 0.0	 0.0	 1	 -30.0	 30.0;
	1890	 9721	 0.09357	 0.184397	 0.0	 153	 153	 153	 0.0	 0.0	 1	 -30.0	 30.0;
	7924	 1890	 0.090248	 0.177719	 0.0	 159	 159	 159	 0.0	 0.0	 1	 -30.0	 30.0;
	7924	 1890	 0.091983	 0.174017	 0.0	 161	 161	 161	 0.0	 0.0	 1	 -30.0	 30.0;
	1890	 1773	 0.018256	 0.05314	 0.0	 563	 563	 563	 0.0	 0.0	 1	 -30.0	 30.0;
	1890	 11877	 0.112273	 0.205446	 0.0	 135	 135	 135	 0.0	 0.0	 1	 -30.0	 30.0;
	3411	 5020	 0.003401	 0.02362	 0.0	 1590	 1590	 1590	 0.0	 0.0	 1	 -30.0	 30.0;
	3411	 10999	 0.002719	 0.012781	 0.0	 2904	 2904	 2904	 0.0	 0.0	 1	 -30.0	 30.0;
	3411	 3092	 0.00205	 0.022719	 0.0	 1664	 1664	 1664	 0.0	 0.0	 1	 -30.0	 30.0;
	11779	 11354	 0.036579	 0.090719	 0.0	 323	 323	 323	 0.0	 0.0	 1	 -30.0	 30.0;
	11779	 11075	 0.038802	 0.092446	 0.0	 316	 316	 316	 0.0	 0.0	 1	 -30.0	 30.0;
	2744	 7358	 0.029397	 0.067298	 0.0	 431	 431	 431	 0.0	 0.0	 1	 -30.0	 30.0;
	2744	 13446	 0.054289	 0.124289	 0.0	 233	 233	 233	 0.0	 0.0	 1	 -30.0	 30.0;
	7358	 11607	 0.007421	 0.023438	 0.0	 1285	 1285	 1285	 0.0	 0.0	 1	 -30.0	 30.0;
	7358	 7669	 0.006124	 0.018554	 0.0	 1617	 1617	 1617	 0.0	 0.0	 1	 -30.0	 30.0;
	12104	 12301	 0.010446	 0.034017	 0.0	 888	 888	 888	 0.0	 0.0	 1	 -30.0	 30.0;
	1137	 4064	 0.045702	 0.127802	 0.0	 233	 233	 233	 0.0	 0.0	 1	 -30.0	 30.0;
	7584	 10293	 0.057438	 0.171496	 0.0	 175	 175	 175	 0.0	 0.0	 1	 -30.0	 30.0;
	2126	 10293	 0.025182	 0.057636	 0.0	 503	 503	 503	 0.0	 0.0	 1	 -30.0	 30.0;
	6817	 4081	 0.03224	 0.075033	 0.0	 387	 387	 387	 0.0	 0.0	 1	 -30.0	 30.0;
	498	 1222	 0.075653	 0.13295	 0.0	 207	 207	 207	 0.0	 0.0	 1	 -30.0	 30.0;
	989	 11433	 0.005058	 0.017017	 0.0	 1780	 1780	 1780	 0.0	 0.0	 1	 -30.0	 30.0;
	989	 11433	 0.005157	 0.016669	 0.0	 1811	 1811	 1811	 0.0	 0.0	 1	 -30.0	 30.0;
	6972	 5980	 0.046777	 0.101124	 0.0	 284	 284	 284	 0.0	 0.0	 1	 -30.0	 30.0;
	9270	 13564	 0.045364	 0.135446	 0.0	 222	 222	 222	 0.0	 0.0	 1	 -30.0	 30.0;
	10289	 9630	 0.037471	 0.113529	 0.0	 265	 265	 265	 0.0	 0.0	 1	 -30.0	 30.0;
	6657	 13199	 0.058372	 0.168446	 0.0	 178	 178	 178	 0.0	 0.0	 1	 -30.0	 30.0;
	6657	 13199	 0.066157	 0.165083	 0.0	 178	 178	 178	 0.0	 0.0	 1	 -30.0	 30.0;
	4524	 13199	 0.046628	 0.120388	 0.0	 245	 245	 245	 0.0	 0.0	 1	 -30.0	 30.0;
	8042	 6725	 0.029868	 0.087488	 0.0	 342	 342	 342	 0.0	 0.0	 1	 -30.0	 30.0;
	6979	 3963	 0.015562	 0.047107	 0.0	 637	 637	 637	 0.0	 0.0	 1	 -30.0	 30.0;
	11450	 2995	 0.045967	 0.109562	 0.0	 266	 266	 266	 0.0	 0.0	 1	 -30.0	 30.0;
	989	 11799	 0.00705	 0.016876	 0.0	 1728	 1728	 1728	 0.0	 0.0	 1	 -30.0	 30.0;
	989	 5224	 0.004	 0.009537	 0.0	 3055	 3055	 3055	 0.0	 0.0	 1	 -30.0	 30.0;
	989	 3564	 0.06243	 0.161207	 0.0	 183	 183	 183	 0.0	 0.0	 1	 -30.0	 30.0;
	1660	 11553	 0.005942	 0.014149	 0.0	 2059	 2059	 2059	 0.0	 0.0	 1	 -30.0	 30.0;
	13139	 9488	 0.004651	 0.024159	 0.0	 1284	 1284	 1284	 0.0	 0.0	 1	 -30.0	 30.0;
	13139	 11682	 0.00474	 0.02363	 0.0	 1311	 1311	 1311	 0.0	 0.0	 1	 -30.0	 30.0;
	11041	 12371	 0.036669	 0.115669	 0.0	 261	 261	 261	 0.0	 0.0	 1	 -30.0	 30.0;
	1496	 8416	 0.043273	 0.095132	 0.0	 303	 303	 303	 0.0	 0.0	 1	 -30.0	 30.0;
	1496	 8257	 0.004521	 0.011661	 0.0	 2526	 2526	 2526	 0.0	 0.0	 1	 -30.0	 30.0;
	883	 9128	 0.00207	 0.01871	 0.0	 1997	 1997	 1997	 0.0	 0.0	 1	 -30.0	 30.0;
	1383	 2511	 0.00419	 0.02712	 0.0	 1152	 1152	 1152	 0.0	 0.0	 1	 -30.0	 30.0;
	1383	 2511	 0.002349	 0.022039	 0.0	 1426	 1426	 1426	 0.0	 0.0	 1	 -30.0	 30.0;
	8917	 7295	 0.02	 0.04314	 0.0	 665	 665	 665	 0.0	 0.0	 1	 -30.0	 30.0;
	2231	 13404	 0.00676	 0.016124	 0.0	 1807	 1807	 1807	 0.0	 0.0	 1	 -30.0	 30.0;
	10868	 13649	 0.007876	 0.022529	 0.0	 1324	 1324	 1324	 0.0	 0.0	 1	 -30.0	 30.0;
	13649	 5597	 0.025793	 0.060298	 0.0	 482	 482	 482	 0.0	 0.0	 1	 -30.0	 30.0;
	3435	 10296	 0.067587	 0.204793	 0.0	 147	 147	 147	 0.0	 0.0	 1	 -30.0	 30.0;
	8832	 10691	 0.053008	 0.116554	 0.0	 247	 247	 247	 0.0	 0.0	 1	 -30.0	 30.0;
	9792	 9721	 0.01195	 0.030868	 0.0	 955	 955	 955	 0.0	 0.0	 1	 -30.0	 30.0;
	8257	 9792	 0.015463	 0.04876	 0.0	 618	 618	 618	 0.0	 0.0	 1	 -30.0	 30.0;
	744	 4409	 0.018702	 0.071413	 0.0	 428	 428	 428	 0.0	 0.0	 1	 -30.0	 30.0;
	256	 6941	 0.00142	 0.01555	 0.0	 2408	 2408	 2408	 0.0	 0.0	 1	 -30.0	 30.0;
	256	 2204	 0.00123	 0.01312	 0.0	 2853	 2853	 2853	 0.0	 0.0	 1	 -30.0	 30.0;
	256	 2204	 0.00121	 0.01337	 0.0	 2801	 2801	 2801	 0.0	 0.0	 1	 -30.0	 30.0;
	2216	 256	 0.00079	 0.01226	 0.0	 3060	 3060	 3060	 0.0	 0.0	 1	 -30.0	 30.0;
	4169	 256	 0.00062	 0.00673	 0.0	 5563	 5563	 5563	 0.0	 0.0	 1	 -30.0	 30.0;
	8931	 7984	 0.0	 0.000211	 0.0	 149704	 149704	 149704	 0.0	 0.0	 1	 -30.0	 30.0;
	6914	 7984	 0.00763	 0.05451	 0.0	 574	 574	 574	 0.0	 0.0	 1	 -30.0	 30.0;
	10393	 12463	 0.0	 0.00076	 0.0	 41563	 41563	 41563	 0.0	 0.0	 1	 -30.0	 30.0;
	13591	 8503	 0.00657	 0.019603	 0.0	 1528	 1528	 1528	 0.0	 0.0	 1	 -30.0	 30.0;
	9807	 9304	 0.011512	 0.028562	 0.0	 1026	 1026	 1026	 0.0	 0.0	 1	 -30.0	 30.0;
	11658	 12538	 0.014612	 0.05362	 0.0	 569	 569	 569	 0.0	 0.0	 1	 -30.0	 30.0;
	13557	 596	 0.00976	 0.02419	 0.0	 1211	 1211	 1211	 0.0	 0.0	 1	 -30.0	 30.0;
	2193	 4514	 0.007876	 0.022934	 0.0	 1303	 1303	 1303	 0.0	 0.0	 1	 -30.0	 30.0;
	4514	 5971	 0.01795	 0.042769	 0.0	 682	 682	 682	 0.0	 0.0	 1	 -30.0	 30.0;
	2578	 11105	 0.023488	 0.046364	 0.0	 608	 608	 608	 0.0	 0.0	 1	 -30.0	 30.0;
	2578	 2450	 0.013802	 0.031802	 0.0	 912	 912	 912	 0.0	 0.0	 1	 -30.0	 30.0;
	4362	 10897	 0.036678	 0.080636	 0.0	 357	 357	 357	 0.0	 0.0	 1	 -30.0	 30.0;
	10897	 6387	 0.005917	 0.017066	 0.0	 1749	 1749	 1749	 0.0	 0.0	 1	 -30.0	 30.0;
	2231	 2862	 0.003364	 0.012901	 0.0	 2370	 2370	 2370	 0.0	 0.0	 1	 -30.0	 30.0;
	3400	 2231	 0.038107	 0.120198	 0.0	 251	 251	 251	 0.0	 0.0	 1	 -30.0	 30.0;
	8310	 2862	 0.003289	 0.011942	 0.0	 2551	 2551	 2551	 0.0	 0.0	 1	 -30.0	 30.0;
	1296	 6263	 0.047818	 0.109479	 0.0	 265	 265	 265	 0.0	 0.0	 1	 -30.0	 30.0;
	6263	 6594	 0.023603	 0.060744	 0.0	 485	 485	 485	 0.0	 0.0	 1	 -30.0	 30.0;
	6263	 7306	 0.042851	 0.125488	 0.0	 239	 239	 239	 0.0	 0.0	 1	 -30.0	 30.0;
	6263	 7306	 0.04376	 0.123124	 0.0	 242	 242	 242	 0.0	 0.0	 1	 -30.0	 30.0;
	6941	 2204	 0.00089	 0.0071	 0.0	 5254	 5254	 5254	 0.0	 0.0	 1	 -30.0	 30.0;
	12301	 3435	 0.0	 0.000744	 0.0	 42457	 42457	 42457	 0.0	 0.0	 1	 -30.0	 30.0;
	12301	 11984	 0.039554	 0.086942	 0.0	 331	 331	 331	 0.0	 0.0	 1	 -30.0	 30.0;
	744	 4913	 0.046364	 0.078843	 0.0	 346	 346	 346	 0.0	 0.0	 1	 -30.0	 30.0;
	1901	 5417	 0.006248	 0.007702	 0.0	 3185	 3185	 3185	 0.0	 0.0	 1	 -30.0	 30.0;
	13150	 1901	 0.001273	 0.002661	 0.0	 10709	 10709	 10709	 0.0	 0.0	 1	 -30.0	 30.0;
	12960	 6410	 0.027711	 0.061314	 0.0	 470	 470	 470	 0.0	 0.0	 1	 -30.0	 30.0;
	12960	 6410	 0.028231	 0.059967	 0.0	 477	 477	 477	 0.0	 0.0	 1	 -30.0	 30.0;
	1502	 8416	 0.029702	 0.056231	 0.0	 497	 497	 497	 0.0	 0.0	 1	 -30.0	 30.0;
	4312	 9402	 0.006256	 0.011397	 0.0	 2430	 2430	 2430	 0.0	 0.0	 1	 -30.0	 30.0;
	6722	 7019	 0.010298	 0.032512	 0.0	 1103	 1103	 1103	 0.0	 0.0	 1	 -30.0	 30.0;
	7019	 13527	 0.01805	 0.039686	 0.0	 863	 863	 863	 0.0	 0.0	 1	 -30.0	 30.0;
	12860	 10413	 0.012849	 0.07226	 0.0	 517	 517	 517	 0.0	 0.0	 1	 -30.0	 30.0;
	12860	 12669	 0.013099	 0.07075	 0.0	 528	 528	 528	 0.0	 0.0	 1	 -30.0	 30.0;
	2548	 12205	 0.008314	 0.033033	 0.0	 928	 928	 928	 0.0	 0.0	 1	 -30.0	 30.0;
	9939	 13006	 0.031843	 0.096463	 0.0	 311	 311	 311	 0.0	 0.0	 1	 -30.0	 30.0;
	13019	 12268	 0.002207	 0.005273	 0.0	 5526	 5526	 5526	 0.0	 0.0	 1	 -30.0	 30.0;
	9517	 13019	 0.009124	 0.027669	 0.0	 1303	 1303	 1303	 0.0	 0.0	 1	 -30.0	 30.0;
	2364	 8042	 0.010777	 0.032653	 0.0	 919	 919	 919	 0.0	 0.0	 1	 -30.0	 30.0;
	1630	 11727	 0.00757	 0.018901	 0.0	 1552	 1552	 1552	 0.0	 0.0	 1	 -30.0	 30.0;
	4272	 9750	 0.007719	 0.018512	 0.0	 1575	 1575	 1575	 0.0	 0.0	 1	 -30.0	 30.0;
	5828	 6817	 0.016198	 0.040818	 0.0	 720	 720	 720	 0.0	 0.0	 1	 -30.0	 30.0;
	1066	 4125	 0.054512	 0.162752	 0.0	 185	 185	 185	 0.0	 0.0	 1	 -30.0	 30.0;
	4125	 3944	 0.030802	 0.067719	 0.0	 425	 425	 425	 0.0	 0.0	 1	 -30.0	 30.0;
	6694	 10421	 0.012298	 0.029281	 0.0	 995	 995	 995	 0.0	 0.0	 1	 -30.0	 30.0;
	420	 12206	 0.074322	 0.221901	 0.0	 135	 135	 135	 0.0	 0.0	 1	 -30.0	 30.0;
	1316	 12206	 0.009669	 0.023033	 0.0	 1265	 1265	 1265	 0.0	 0.0	 1	 -30.0	 30.0;
	1250	 7924	 0.0	 0.000843	 0.0	 37471	 37471	 37471	 0.0	 0.0	 1	 -30.0	 30.0;
	57	 11404	 0.073463	 0.189678	 0.0	 156	 156	 156	 0.0	 0.0	 1	 -30.0	 30.0;
	11404	 11554	 0.058653	 0.145488	 0.0	 202	 202	 202	 0.0	 0.0	 1	 -30.0	 30.0;
	2216	 5789	 0.00102	 0.01773	 0.0	 2117	 2117	 2117	 0.0	 0.0	 1	 -30.0	 30.0;
	7584	 6241	 0.00838	 0.02438	 0.0	 1226	 1226	 1226	 0.0	 0.0	 1	 -30.0	 30.0;
	7584	 10570	 0.01219	 0.03024	 0.0	 969	 969	 969	 0.0	 0.0	 1	 -30.0	 30.0;
	7584	 2126	 0.048744	 0.11614	 0.0	 251	 251	 251	 0.0	 0.0	 1	 -30.0	 30.0;
	10570	 2671	 0.012967	 0.030934	 0.0	 942	 942	 942	 0.0	 0.0	 1	 -30.0	 30.0;
	6241	 5487	 0.006983	 0.021149	 0.0	 1419	 1419	 1419	 0.0	 0.0	 1	 -30.0	 30.0;
	669	 6241	 0.017347	 0.058702	 0.0	 517	 517	 517	 0.0	 0.0	 1	 -30.0	 30.0;
	3539	 10577	 0.02457	 0.058562	 0.0	 498	 498	 498	 0.0	 0.0	 1	 -30.0	 30.0;
	9545	 7912	 0.016083	 0.044983	 0.0	 662	 662	 662	 0.0	 0.0	 1	 -30.0	 30.0;
	7127	 7912	 0.004843	 0.011512	 0.0	 2530	 2530	 2530	 0.0	 0.0	 1	 -30.0	 30.0;
	11512	 12324	 0.005058	 0.011339	 0.0	 2545	 2545	 2545	 0.0	 0.0	 1	 -30.0	 30.0;
	10231	 9000	 0.023727	 0.074843	 0.0	 403	 403	 403	 0.0	 0.0	 1	 -30.0	 30.0;
	13006	 9000	 0.031157	 0.098281	 0.0	 307	 307	 307	 0.0	 0.0	 1	 -30.0	 30.0;
	1118	 6739	 0.014372	 0.048661	 0.0	 623	 623	 623	 0.0	 0.0	 1	 -30.0	 30.0;
	1371	 883	 0.00331	 0.02754	 0.0	 1356	 1356	 1356	 0.0	 0.0	 1	 -30.0	 30.0;
	10999	 10664	 0.002669	 0.01732	 0.0	 2146	 2146	 2146	 0.0	 0.0	 1	 -30.0	 30.0;
	10664	 398	 0.019719	 0.103289	 0.0	 358	 358	 358	 0.0	 0.0	 1	 -30.0	 30.0;
	10999	 5020	 0.00261	 0.016039	 0.0	 2314	 2314	 2314	 0.0	 0.0	 1	 -30.0	 30.0;
	703	 9577	 0.008587	 0.017446	 0.0	 1625	 1625	 1625	 0.0	 0.0	 1	 -30.0	 30.0;
	3992	 12524	 0.0	 0.000876	 0.0	 36059	 36059	 36059	 0.0	 0.0	 1	 -30.0	 30.0;
	12297	 3992	 0.017413	 0.05443	 0.0	 553	 553	 553	 0.0	 0.0	 1	 -30.0	 30.0;
	3992	 9291	 0.024744	 0.074289	 0.0	 404	 404	 404	 0.0	 0.0	 1	 -30.0	 30.0;
	12524	 12649	 0.036421	 0.11381	 0.0	 265	 265	 265	 0.0	 0.0	 1	 -30.0	 30.0;
	7385	 1121	 0.004198	 0.012587	 0.0	 2381	 2381	 2381	 0.0	 0.0	 1	 -30.0	 30.0;
	11954	 12243	 0.014686	 0.044521	 0.0	 674	 674	 674	 0.0	 0.0	 1	 -30.0	 30.0;
	3747	 12243	 0.015231	 0.041256	 0.0	 719	 719	 719	 0.0	 0.0	 1	 -30.0	 30.0;
	85	 9915	 0.01438	 0.045364	 0.0	 664	 664	 664	 0.0	 0.0	 1	 -30.0	 30.0;
	10771	 9254	 0.025562	 0.076298	 0.0	 393	 393	 393	 0.0	 0.0	 1	 -30.0	 30.0;
	9254	 12931	 0.028083	 0.061744	 0.0	 466	 466	 466	 0.0	 0.0	 1	 -30.0	 30.0;
	47	 7495	 0.05019	 0.152107	 0.0	 198	 198	 198	 0.0	 0.0	 1	 -30.0	 30.0;
	1020	 7495	 0.027909	 0.072033	 0.0	 409	 409	 409	 0.0	 0.0	 1	 -30.0	 30.0;
	2800	 6830	 0.020512	 0.061248	 0.0	 490	 490	 490	 0.0	 0.0	 1	 -30.0	 30.0;
	1214	 8814	 0.025364	 0.053893	 0.0	 531	 531	 531	 0.0	 0.0	 1	 -30.0	 30.0;
	12247	 10566	 0.054479	 0.165099	 0.0	 182	 182	 182	 0.0	 0.0	 1	 -30.0	 30.0;
	12247	 10566	 0.055636	 0.161983	 0.0	 185	 185	 185	 0.0	 0.0	 1	 -30.0	 30.0;
	12247	 12083	 0.051579	 0.154	 0.0	 195	 195	 195	 0.0	 0.0	 1	 -30.0	 30.0;
	11554	 785	 0.035752	 0.106752	 0.0	 281	 281	 281	 0.0	 0.0	 1	 -30.0	 30.0;
	172	 9784	 0.021124	 0.054537	 0.0	 541	 541	 541	 0.0	 0.0	 1	 -30.0	 30.0;
	172	 9784	 0.021537	 0.05343	 0.0	 549	 549	 549	 0.0	 0.0	 1	 -30.0	 30.0;
	9741	 802	 0.0082	 0.04119	 0.0	 904	 904	 904	 0.0	 0.0	 1	 -30.0	 30.0;
	6410	 9954	 0.040281	 0.122058	 0.0	 246	 246	 246	 0.0	 0.0	 1	 -30.0	 30.0;
	8042	 6594	 0.031934	 0.10086	 0.0	 299	 299	 299	 0.0	 0.0	 1	 -30.0	 30.0;
	8042	 2334	 0.048347	 0.145008	 0.0	 207	 207	 207	 0.0	 0.0	 1	 -30.0	 30.0;
	8042	 6945	 0.056636	 0.164901	 0.0	 182	 182	 182	 0.0	 0.0	 1	 -30.0	 30.0;
	6657	 10595	 0.048091	 0.119281	 0.0	 246	 246	 246	 0.0	 0.0	 1	 -30.0	 30.0;
	6657	 7188	 0.00305	 0.008793	 0.0	 3394	 3394	 3394	 0.0	 0.0	 1	 -30.0	 30.0;
	6657	 7188	 0.003463	 0.00862	 0.0	 3401	 3401	 3401	 0.0	 0.0	 1	 -30.0	 30.0;
	3467	 6657	 0.004223	 0.009339	 0.0	 3082	 3082	 3082	 0.0	 0.0	 1	 -30.0	 30.0;
	3467	 6657	 0.005281	 0.009603	 0.0	 2883	 2883	 2883	 0.0	 0.0	 1	 -30.0	 30.0;
	9270	 6579	 0.028033	 0.066033	 0.0	 441	 441	 441	 0.0	 0.0	 1	 -30.0	 30.0;
	7138	 13606	 0.012983	 0.051587	 0.0	 594	 594	 594	 0.0	 0.0	 1	 -30.0	 30.0;
	9813	 6453	 0.00183	 0.01416	 0.0	 2633	 2633	 2633	 0.0	 0.0	 1	 -30.0	 30.0;
	6094	 10318	 0.012504	 0.036397	 0.0	 821	 821	 821	 0.0	 0.0	 1	 -30.0	 30.0;
	13006	 10318	 0.024488	 0.074198	 0.0	 405	 405	 405	 0.0	 0.0	 1	 -30.0	 30.0;
	5699	 2861	 0.010579	 0.045496	 0.0	 677	 677	 677	 0.0	 0.0	 1	 -30.0	 30.0;
	10595	 13116	 0.025372	 0.065512	 0.0	 450	 450	 450	 0.0	 0.0	 1	 -30.0	 30.0;
	12792	 9644	 0.015058	 0.042124	 0.0	 707	 707	 707	 0.0	 0.0	 1	 -30.0	 30.0;
	5235	 12792	 0.038248	 0.084099	 0.0	 342	 342	 342	 0.0	 0.0	 1	 -30.0	 30.0;
	12081	 1066	 0.045719	 0.113397	 0.0	 259	 259	 259	 0.0	 0.0	 1	 -30.0	 30.0;
	12081	 5744	 0.046603	 0.111041	 0.0	 263	 263	 263	 0.0	 0.0	 1	 -30.0	 30.0;
	1099	 12201	 0.013843	 0.041934	 0.0	 716	 716	 716	 0.0	 0.0	 1	 -30.0	 30.0;
	13073	 12540	 0.052083	 0.134446	 0.0	 220	 220	 220	 0.0	 0.0	 1	 -30.0	 30.0;
	7040	 420	 0.013579	 0.03981	 0.0	 751	 751	 751	 0.0	 0.0	 1	 -30.0	 30.0;
	7040	 420	 0.013868	 0.039058	 0.0	 763	 763	 763	 0.0	 0.0	 1	 -30.0	 30.0;
	7040	 12851	 0.035099	 0.077182	 0.0	 373	 373	 373	 0.0	 0.0	 1	 -30.0	 30.0;
	13089	 7040	 0.11376	 0.27386	 0.0	 107	 107	 107	 0.0	 0.0	 1	 -30.0	 30.0;
	420	 11871	 0.069628	 0.153091	 0.0	 188	 188	 188	 0.0	 0.0	 1	 -30.0	 30.0;
	13221	 6453	 0.00296	 0.03263	 0.0	 1158	 1158	 1158	 0.0	 0.0	 1	 -30.0	 30.0;
	5597	 7873	 0.048322	 0.115149	 0.0	 253	 253	 253	 0.0	 0.0	 1	 -30.0	 30.0;
	1819	 7436	 0.009802	 0.028678	 0.0	 1043	 1043	 1043	 0.0	 0.0	 1	 -30.0	 30.0;
	11832	 5417	 0.003132	 0.004347	 0.0	 5896	 5896	 5896	 0.0	 0.0	 1	 -30.0	 30.0;
	4894	 6889	 0.00284	 0.02937	 0.0	 1274	 1274	 1274	 0.0	 0.0	 1	 -30.0	 30.0;
	6889	 10256	 0.00353	 0.03885	 0.0	 973	 973	 973	 0.0	 0.0	 1	 -30.0	 30.0;
	1720	 6889	 0.00193	 0.02044	 0.0	 1831	 1831	 1831	 0.0	 0.0	 1	 -30.0	 30.0;
	5659	 2385	 0.00918	 0.065591	 0.0	 568	 568	 568	 0.0	 0.0	 1	 -30.0	 30.0;
	9703	 5659	 0.0	 0.000211	 0.0	 178159	 178159	 178159	 0.0	 0.0	 1	 -30.0	 30.0;
	5659	 13139	 0.01776	 0.09207	 0.0	 405	 405	 405	 0.0	 0.0	 1	 -30.0	 30.0;
	5659	 13139	 0.018081	 0.09007	 0.0	 413	 413	 413	 0.0	 0.0	 1	 -30.0	 30.0;
	5659	 5758	 0.0017	 0.0117	 0.0	 3180	 3180	 3180	 0.0	 0.0	 1	 -30.0	 30.0;
	5659	 1619	 0.001669	 0.011919	 0.0	 3124	 3124	 3124	 0.0	 0.0	 1	 -30.0	 30.0;
	6122	 13557	 0.009041	 0.023331	 0.0	 1263	 1263	 1263	 0.0	 0.0	 1	 -30.0	 30.0;
	3534	 4898	 0.075851	 0.15557	 0.0	 183	 183	 183	 0.0	 0.0	 1	 -30.0	 30.0;
	2893	 3534	 0.012471	 0.036587	 0.0	 818	 818	 818	 0.0	 0.0	 1	 -30.0	 30.0;
	7138	 10868	 0.003702	 0.011537	 0.0	 2607	 2607	 2607	 0.0	 0.0	 1	 -30.0	 30.0;
	8673	 10346	 0.003661	 0.009066	 0.0	 3231	 3231	 3231	 0.0	 0.0	 1	 -30.0	 30.0;
	8673	 11431	 0.0	 0.000893	 0.0	 35373	 35373	 35373	 0.0	 0.0	 1	 -30.0	 30.0;
	7575	 12516	 0.00537	 0.032901	 0.0	 948	 948	 948	 0.0	 0.0	 1	 -30.0	 30.0;
	13461	 9517	 0.016661	 0.041331	 0.0	 844	 844	 844	 0.0	 0.0	 1	 -30.0	 30.0;
	13461	 10779	 0.002628	 0.007587	 0.0	 4682	 4682	 4682	 0.0	 0.0	 1	 -30.0	 30.0;
	13461	 13527	 0.009446	 0.025388	 0.0	 1388	 1388	 1388	 0.0	 0.0	 1	 -30.0	 30.0;
	11597	 11354	 0.023248	 0.060017	 0.0	 491	 491	 491	 0.0	 0.0	 1	 -30.0	 30.0;
	1863	 1066	 0.053711	 0.127983	 0.0	 228	 228	 228	 0.0	 0.0	 1	 -30.0	 30.0;
	12201	 5068	 0.009851	 0.022537	 0.0	 1285	 1285	 1285	 0.0	 0.0	 1	 -30.0	 30.0;
	3975	 11376	 0.007256	 0.021702	 0.0	 1658	 1658	 1658	 0.0	 0.0	 1	 -30.0	 30.0;
	3975	 12125	 0.001058	 0.003149	 0.0	 9509	 9509	 9509	 0.0	 0.0	 1	 -30.0	 30.0;
	11376	 10779	 0.014744	 0.048893	 0.0	 737	 737	 737	 0.0	 0.0	 1	 -30.0	 30.0;
	4909	 3978	 0.040901	 0.119017	 0.0	 251	 251	 251	 0.0	 0.0	 1	 -30.0	 30.0;
	10049	 11147	 0.026653	 0.063504	 0.0	 459	 459	 459	 0.0	 0.0	 1	 -30.0	 30.0;
	6658	 2865	 0.005198	 0.011909	 0.0	 2431	 2431	 2431	 0.0	 0.0	 1	 -30.0	 30.0;
	6658	 1380	 0.006603	 0.020793	 0.0	 1448	 1448	 1448	 0.0	 0.0	 1	 -30.0	 30.0;
	1296	 1916	 0.023909	 0.054744	 0.0	 529	 529	 529	 0.0	 0.0	 1	 -30.0	 30.0;
	7306	 1916	 0.01286	 0.038959	 0.0	 770	 770	 770	 0.0	 0.0	 1	 -30.0	 30.0;
	9545	 526	 0.0	 0.000826	 0.0	 38242	 38242	 38242	 0.0	 0.0	 1	 -30.0	 30.0;
	11091	 526	 0.005488	 0.011256	 0.0	 2523	 2523	 2523	 0.0	 0.0	 1	 -30.0	 30.0;
	5448	 526	 0.018983	 0.055579	 0.0	 538	 538	 538	 0.0	 0.0	 1	 -30.0	 30.0;
	9545	 6521	 0.013479	 0.038876	 0.0	 768	 768	 768	 0.0	 0.0	 1	 -30.0	 30.0;
	10843	 9158	 0.010041	 0.02205	 0.0	 1304	 1304	 1304	 0.0	 0.0	 1	 -30.0	 30.0;
	9158	 13239	 0.01224	 0.037099	 0.0	 809	 809	 809	 0.0	 0.0	 1	 -30.0	 30.0;
	10843	 5952	 0.0	 0.00081	 0.0	 38997	 38997	 38997	 0.0	 0.0	 1	 -30.0	 30.0;
	8196	 10843	 0.011	 0.030959	 0.0	 962	 962	 962	 0.0	 0.0	 1	 -30.0	 30.0;
	4278	 5952	 0.010777	 0.031554	 0.0	 948	 948	 948	 0.0	 0.0	 1	 -30.0	 30.0;
	5952	 12090	 0.030521	 0.069868	 0.0	 415	 415	 415	 0.0	 0.0	 1	 -30.0	 30.0;
	5952	 10106	 0.016901	 0.051198	 0.0	 586	 586	 586	 0.0	 0.0	 1	 -30.0	 30.0;
	2415	 10611	 0.008868	 0.027967	 0.0	 1077	 1077	 1077	 0.0	 0.0	 1	 -30.0	 30.0;
	13239	 13015	 0.006322	 0.02319	 0.0	 1315	 1315	 1315	 0.0	 0.0	 1	 -30.0	 30.0;
	3991	 8196	 0.006488	 0.019008	 0.0	 1573	 1573	 1573	 0.0	 0.0	 1	 -30.0	 30.0;
	1584	 4278	 0.006347	 0.019372	 0.0	 1550	 1550	 1550	 0.0	 0.0	 1	 -30.0	 30.0;
	3944	 1584	 0.018339	 0.038967	 0.0	 734	 734	 734	 0.0	 0.0	 1	 -30.0	 30.0;
	1761	 7629	 0.037793	 0.093752	 0.0	 313	 313	 313	 0.0	 0.0	 1	 -30.0	 30.0;
	1818	 1095	 0.018603	 0.048017	 0.0	 614	 614	 614	 0.0	 0.0	 1	 -30.0	 30.0;
	6150	 9580	 0.04086	 0.128893	 0.0	 234	 234	 234	 0.0	 0.0	 1	 -30.0	 30.0;
	9580	 1945	 0.004587	 0.010083	 0.0	 2852	 2852	 2852	 0.0	 0.0	 1	 -30.0	 30.0;
	3978	 7964	 0.012529	 0.028661	 0.0	 1010	 1010	 1010	 0.0	 0.0	 1	 -30.0	 30.0;
	57	 5918	 0.016339	 0.035909	 0.0	 801	 801	 801	 0.0	 0.0	 1	 -30.0	 30.0;
	1818	 10551	 0.021702	 0.058653	 0.0	 506	 506	 506	 0.0	 0.0	 1	 -30.0	 30.0;
	9121	 11727	 0.037339	 0.109364	 0.0	 274	 274	 274	 0.0	 0.0	 1	 -30.0	 30.0;
	7623	 4272	 0.036554	 0.11143	 0.0	 270	 270	 270	 0.0	 0.0	 1	 -30.0	 30.0;
	8814	 8985	 0.027149	 0.062149	 0.0	 466	 466	 466	 0.0	 0.0	 1	 -30.0	 30.0;
	10039	 5650	 0.034281	 0.103876	 0.0	 289	 289	 289	 0.0	 0.0	 1	 -30.0	 30.0;
	10039	 7390	 0.023479	 0.06843	 0.0	 437	 437	 437	 0.0	 0.0	 1	 -30.0	 30.0;
	12177	 10039	 0.053149	 0.116868	 0.0	 247	 247	 247	 0.0	 0.0	 1	 -30.0	 30.0;
	11105	 9838	 0.004802	 0.013298	 0.0	 2235	 2235	 2235	 0.0	 0.0	 1	 -30.0	 30.0;
	9838	 744	 0.012669	 0.038231	 0.0	 785	 785	 785	 0.0	 0.0	 1	 -30.0	 30.0;
	7188	 3537	 0.040339	 0.079496	 0.0	 355	 355	 355	 0.0	 0.0	 1	 -30.0	 30.0;
	12540	 2414	 0.054521	 0.171992	 0.0	 176	 176	 176	 0.0	 0.0	 1	 -30.0	 30.0;
	8207	 2414	 0.05514	 0.122	 0.0	 236	 236	 236	 0.0	 0.0	 1	 -30.0	 30.0;
	3332	 2414	 0.056157	 0.119339	 0.0	 240	 240	 240	 0.0	 0.0	 1	 -30.0	 30.0;
	11697	 6579	 0.034248	 0.075289	 0.0	 382	 382	 382	 0.0	 0.0	 1	 -30.0	 30.0;
	4894	 6989	 0.0018	 0.01865	 0.0	 2007	 2007	 2007	 0.0	 0.0	 1	 -30.0	 30.0;
	11041	 6449	 0.0	 0.000793	 0.0	 39833	 39833	 39833	 0.0	 0.0	 1	 -30.0	 30.0;
	11514	 10771	 0.023231	 0.064983	 0.0	 458	 458	 458	 0.0	 0.0	 1	 -30.0	 30.0;
	2416	 3047	 0.00163	 0.01087	 0.0	 2874	 2874	 2874	 0.0	 0.0	 1	 -30.0	 30.0;
	9381	 47	 0.020727	 0.053512	 0.0	 551	 551	 551	 0.0	 0.0	 1	 -30.0	 30.0;
	744	 10531	 0.022364	 0.064488	 0.0	 463	 463	 463	 0.0	 0.0	 1	 -30.0	 30.0;
	1296	 6434	 0.014579	 0.04805	 0.0	 630	 630	 630	 0.0	 0.0	 1	 -30.0	 30.0;
	1296	 6434	 0.014281	 0.048992	 0.0	 619	 619	 619	 0.0	 0.0	 1	 -30.0	 30.0;
	10698	 13036	 0.00228	 0.02412	 0.0	 1552	 1552	 1552	 0.0	 0.0	 1	 -30.0	 30.0;
	11075	 2142	 0.004298	 0.009132	 0.0	 3130	 3130	 3130	 0.0	 0.0	 1	 -30.0	 30.0;
	4898	 11075	 0.003826	 0.010347	 0.0	 2864	 2864	 2864	 0.0	 0.0	 1	 -30.0	 30.0;
	4898	 2142	 0.0	 0.000777	 0.0	 40653	 40653	 40653	 0.0	 0.0	 1	 -30.0	 30.0;
	11597	 2142	 0.042256	 0.092917	 0.0	 310	 310	 310	 0.0	 0.0	 1	 -30.0	 30.0;
	5372	 7313	 0.005021	 0.029341	 0.0	 1062	 1062	 1062	 0.0	 0.0	 1	 -30.0	 30.0;
	708	 1857	 0.066248	 0.151661	 0.0	 191	 191	 191	 0.0	 0.0	 1	 -30.0	 30.0;
	1857	 3016	 0.007587	 0.016702	 0.0	 1722	 1722	 1722	 0.0	 0.0	 1	 -30.0	 30.0;
	3937	 7300	 0.008579	 0.019636	 0.0	 1475	 1475	 1475	 0.0	 0.0	 1	 -30.0	 30.0;
	12177	 8503	 0.008942	 0.024992	 0.0	 1191	 1191	 1191	 0.0	 0.0	 1	 -30.0	 30.0;
	9935	 5235	 0.049124	 0.154983	 0.0	 195	 195	 195	 0.0	 0.0	 1	 -30.0	 30.0;
	3125	 9935	 0.018289	 0.04186	 0.0	 692	 692	 692	 0.0	 0.0	 1	 -30.0	 30.0;
	6989	 6364	 0.00064	 0.00617	 0.0	 6061	 6061	 6061	 0.0	 0.0	 1	 -30.0	 30.0;
	5597	 4879	 0.0	 0.00076	 0.0	 41563	 41563	 41563	 0.0	 0.0	 1	 -30.0	 30.0;
	5597	 4606	 0.024421	 0.073331	 0.0	 409	 409	 409	 0.0	 0.0	 1	 -30.0	 30.0;
	4879	 12981	 0.0	 0.000744	 0.0	 42457	 42457	 42457	 0.0	 0.0	 1	 -30.0	 30.0;
	10231	 13006	 0.025653	 0.056388	 0.0	 510	 510	 510	 0.0	 0.0	 1	 -30.0	 30.0;
	6343	 7782	 0.003711	 0.02356	 0.0	 1325	 1325	 1325	 0.0	 0.0	 1	 -30.0	 30.0;
	4362	 6387	 0.015777	 0.089537	 0.0	 348	 348	 348	 0.0	 0.0	 1	 -30.0	 30.0;
	1945	 4362	 0.001587	 0.005612	 0.0	 5417	 5417	 5417	 0.0	 0.0	 1	 -30.0	 30.0;
	1380	 6122	 0.008934	 0.027091	 0.0	 1108	 1108	 1108	 0.0	 0.0	 1	 -30.0	 30.0;
	2893	 2865	 0.021298	 0.052603	 0.0	 557	 557	 557	 0.0	 0.0	 1	 -30.0	 30.0;
	11215	 12756	 0.01036	 0.05943	 0.0	 524	 524	 524	 0.0	 0.0	 1	 -30.0	 30.0;
	9400	 1316	 0.036438	 0.114909	 0.0	 263	 263	 263	 0.0	 0.0	 1	 -30.0	 30.0;
	6925	 9400	 0.038876	 0.113207	 0.0	 264	 264	 264	 0.0	 0.0	 1	 -30.0	 30.0;
	5811	 10665	 0.045058	 0.127901	 0.0	 233	 233	 233	 0.0	 0.0	 1	 -30.0	 30.0;
	10665	 3125	 0.014083	 0.042661	 0.0	 704	 704	 704	 0.0	 0.0	 1	 -30.0	 30.0;
	1325	 708	 0.016537	 0.052157	 0.0	 578	 578	 578	 0.0	 0.0	 1	 -30.0	 30.0;
	11437	 8703	 0.045711	 0.136504	 0.0	 220	 220	 220	 0.0	 0.0	 1	 -30.0	 30.0;
	2517	 883	 0.00579	 0.06394	 0.0	 586	 586	 586	 0.0	 0.0	 1	 -30.0	 30.0;
	2522	 1870	 0.012512	 0.03381	 0.0	 877	 877	 877	 0.0	 0.0	 1	 -30.0	 30.0;
	1870	 953	 0.053149	 0.149512	 0.0	 200	 200	 200	 0.0	 0.0	 1	 -30.0	 30.0;
	2522	 7301	 0.012248	 0.034471	 0.0	 864	 864	 864	 0.0	 0.0	 1	 -30.0	 30.0;
	7301	 4708	 0.052041	 0.152388	 0.0	 197	 197	 197	 0.0	 0.0	 1	 -30.0	 30.0;
	1316	 6150	 0.024471	 0.056033	 0.0	 517	 517	 517	 0.0	 0.0	 1	 -30.0	 30.0;
	2679	 3501	 0.008752	 0.016322	 0.0	 1706	 1706	 1706	 0.0	 0.0	 1	 -30.0	 30.0;
	2517	 10256	 0.00211	 0.01832	 0.0	 2058	 2058	 2058	 0.0	 0.0	 1	 -30.0	 30.0;
	5738	 10088	 0.0	 0.00086	 0.0	 36730	 36730	 36730	 0.0	 0.0	 1	 -30.0	 30.0;
	2636	 117	 0.0	 0.000876	 0.0	 36059	 36059	 36059	 0.0	 0.0	 1	 -30.0	 30.0;
	3594	 117	 0.007248	 0.021107	 0.0	 1416	 1416	 1416	 0.0	 0.0	 1	 -30.0	 30.0;
	2499	 2636	 0.036653	 0.106661	 0.0	 281	 281	 281	 0.0	 0.0	 1	 -30.0	 30.0;
	12496	 5986	 0.003107	 0.007727	 0.0	 3793	 3793	 3793	 0.0	 0.0	 1	 -30.0	 30.0;
	5986	 8101	 0.013612	 0.029917	 0.0	 962	 962	 962	 0.0	 0.0	 1	 -30.0	 30.0;
	10705	 7629	 0.064182	 0.141124	 0.0	 204	 204	 204	 0.0	 0.0	 1	 -30.0	 30.0;
	10154	 7629	 0.058331	 0.150579	 0.0	 196	 196	 196	 0.0	 0.0	 1	 -30.0	 30.0;
	10654	 7303	 0.00337	 0.03668	 0.0	 858	 858	 858	 0.0	 0.0	 1	 -30.0	 30.0;
	5980	 11514	 0.033959	 0.080934	 0.0	 360	 360	 360	 0.0	 0.0	 1	 -30.0	 30.0;
	10289	 12177	 0.0	 0.000826	 0.0	 38242	 38242	 38242	 0.0	 0.0	 1	 -30.0	 30.0;
	10154	 12177	 0.07314	 0.181438	 0.0	 162	 162	 162	 0.0	 0.0	 1	 -30.0	 30.0;
	12177	 8329	 0.01476	 0.04295	 0.0	 696	 696	 696	 0.0	 0.0	 1	 -30.0	 30.0;
	1316	 11871	 0.018488	 0.044091	 0.0	 661	 661	 661	 0.0	 0.0	 1	 -30.0	 30.0;
	4769	 2517	 0.00025	 0.00227	 0.0	 16461	 16461	 16461	 0.0	 0.0	 1	 -30.0	 30.0;
	4769	 2517	 0.00025	 0.00222	 0.0	 16827	 16827	 16827	 0.0	 0.0	 1	 -30.0	 30.0;
	2517	 1720	 0.00179	 0.01494	 0.0	 2499	 2499	 2499	 0.0	 0.0	 1	 -30.0	 30.0;
	2216	 4169	 0.00133	 0.01403	 0.0	 2668	 2668	 2668	 0.0	 0.0	 1	 -30.0	 30.0;
	1502	 2442	 0.027438	 0.076752	 0.0	 388	 388	 388	 0.0	 0.0	 1	 -30.0	 30.0;
	13239	 5699	 0.0	 0.00081	 0.0	 38997	 38997	 38997	 0.0	 0.0	 1	 -30.0	 30.0;
	5699	 10106	 0.014347	 0.03705	 0.0	 796	 796	 796	 0.0	 0.0	 1	 -30.0	 30.0;
	11215	 7575	 0.00286	 0.015591	 0.0	 1993	 1993	 1993	 0.0	 0.0	 1	 -30.0	 30.0;
	9304	 8101	 0.0	 0.000793	 0.0	 39833	 39833	 39833	 0.0	 0.0	 1	 -30.0	 30.0;
	8101	 6434	 0.008231	 0.021273	 0.0	 1385	 1385	 1385	 0.0	 0.0	 1	 -30.0	 30.0;
	1773	 10791	 0.013653	 0.031231	 0.0	 927	 927	 927	 0.0	 0.0	 1	 -30.0	 30.0;
	4571	 7138	 0.0	 0.000777	 0.0	 40653	 40653	 40653	 0.0	 0.0	 1	 -30.0	 30.0;
	12909	 11554	 0.028364	 0.063479	 0.0	 455	 455	 455	 0.0	 0.0	 1	 -30.0	 30.0;
	5918	 11554	 0.023636	 0.051983	 0.0	 554	 554	 554	 0.0	 0.0	 1	 -30.0	 30.0;
	688	 11554	 0.022752	 0.066248	 0.0	 451	 451	 451	 0.0	 0.0	 1	 -30.0	 30.0;
	9402	 8207	 0.004512	 0.013099	 0.0	 2280	 2280	 2280	 0.0	 0.0	 1	 -30.0	 30.0;
	9402	 3332	 0.006331	 0.015124	 0.0	 1927	 1927	 1927	 0.0	 0.0	 1	 -30.0	 30.0;
	7497	 1325	 0.048058	 0.143504	 0.0	 209	 209	 209	 0.0	 0.0	 1	 -30.0	 30.0;
	11557	 3564	 0.02676	 0.077901	 0.0	 384	 384	 384	 0.0	 0.0	 1	 -30.0	 30.0;
	3871	 838	 0.0	 0.000744	 0.0	 42457	 42457	 42457	 0.0	 0.0	 1	 -30.0	 30.0;
	6856	 1720	 0.00031	 0.00329	 0.0	 11376	 11376	 11376	 0.0	 0.0	 1	 -30.0	 30.0;
	6856	 1720	 0.00035	 0.00322	 0.0	 11607	 11607	 11607	 0.0	 0.0	 1	 -30.0	 30.0;
	12090	 1020	 0.01276	 0.028033	 0.0	 1026	 1026	 1026	 0.0	 0.0	 1	 -30.0	 30.0;
	10812	 11357	 0.049983	 0.088198	 0.0	 312	 312	 312	 0.0	 0.0	 1	 -30.0	 30.0;
	7127	 5448	 0.0	 0.000876	 0.0	 36059	 36059	 36059	 0.0	 0.0	 1	 -30.0	 30.0;
	6253	 5448	 0.020157	 0.04643	 0.0	 625	 625	 625	 0.0	 0.0	 1	 -30.0	 30.0;
	11784	 12056	 0.050554	 0.09781	 0.0	 287	 287	 287	 0.0	 0.0	 1	 -30.0	 30.0;
	10519	 11784	 0.050157	 0.093818	 0.0	 297	 297	 297	 0.0	 0.0	 1	 -30.0	 30.0;
	11127	 5756	 0.03338	 0.08238	 0.0	 356	 356	 356	 0.0	 0.0	 1	 -30.0	 30.0;
	180	 5756	 0.041554	 0.156107	 0.0	 196	 196	 196	 0.0	 0.0	 1	 -30.0	 30.0;
	5508	 12532	 0.04676	 0.124372	 0.0	 238	 238	 238	 0.0	 0.0	 1	 -30.0	 30.0;
	3041	 12532	 0.043868	 0.116678	 0.0	 254	 254	 254	 0.0	 0.0	 1	 -30.0	 30.0;
	10046	 8328	 0.015529	 0.049017	 0.0	 615	 615	 615	 0.0	 0.0	 1	 -30.0	 30.0;
	10046	 2022	 0.019471	 0.052802	 0.0	 562	 562	 562	 0.0	 0.0	 1	 -30.0	 30.0;
	6978	 8078	 0.030339	 0.062124	 0.0	 457	 457	 457	 0.0	 0.0	 1	 -30.0	 30.0;
	12604	 6978	 0.043488	 0.11219	 0.0	 263	 263	 263	 0.0	 0.0	 1	 -30.0	 30.0;
	6978	 8540	 0.025934	 0.052198	 0.0	 542	 542	 542	 0.0	 0.0	 1	 -30.0	 30.0;
	11385	 11022	 0.024372	 0.057347	 0.0	 507	 507	 507	 0.0	 0.0	 1	 -30.0	 30.0;
	11385	 9765	 0.023868	 0.058446	 0.0	 501	 501	 501	 0.0	 0.0	 1	 -30.0	 30.0;
	11320	 2022	 0.032636	 0.103934	 0.0	 290	 290	 290	 0.0	 0.0	 1	 -30.0	 30.0;
	13260	 11320	 0.02695	 0.081719	 0.0	 368	 368	 368	 0.0	 0.0	 1	 -30.0	 30.0;
	8334	 6514	 0.022521	 0.13874	 0.0	 225	 225	 225	 0.0	 0.0	 1	 -30.0	 30.0;
	8334	 4491	 0.0117	 0.053091	 0.0	 582	 582	 582	 0.0	 0.0	 1	 -30.0	 30.0;
	8334	 10454	 0.001401	 0.006789	 0.0	 4557	 4557	 4557	 0.0	 0.0	 1	 -30.0	 30.0;
	8334	 3439	 0.00139	 0.0113	 0.0	 2775	 2775	 2775	 0.0	 0.0	 1	 -30.0	 30.0;
	3902	 8334	 0.01818	 0.095349	 0.0	 326	 326	 326	 0.0	 0.0	 1	 -30.0	 30.0;
	11733	 8334	 0.005729	 0.043599	 0.0	 719	 719	 719	 0.0	 0.0	 1	 -30.0	 30.0;
	8334	 13559	 0.00095	 0.006409	 0.0	 4876	 4876	 4876	 0.0	 0.0	 1	 -30.0	 30.0;
	8334	 12405	 0.00093	 0.006531	 0.0	 4789	 4789	 4789	 0.0	 0.0	 1	 -30.0	 30.0;
	8334	 7184	 0.025659	 0.11894	 0.0	 260	 260	 260	 0.0	 0.0	 1	 -30.0	 30.0;
	8334	 1011	 0.01036	 0.04869	 0.0	 635	 635	 635	 0.0	 0.0	 1	 -30.0	 30.0;
	7529	 6060	 0.022231	 0.051521	 0.0	 563	 563	 563	 0.0	 0.0	 1	 -30.0	 30.0;
	1568	 6060	 0.038099	 0.092579	 0.0	 316	 316	 316	 0.0	 0.0	 1	 -30.0	 30.0;
	2988	 1826	 0.018041	 0.066793	 0.0	 457	 457	 457	 0.0	 0.0	 1	 -30.0	 30.0;
	7010	 1826	 0.019942	 0.075554	 0.0	 405	 405	 405	 0.0	 0.0	 1	 -30.0	 30.0;
	264	 12403	 0.028347	 0.064727	 0.0	 448	 448	 448	 0.0	 0.0	 1	 -30.0	 30.0;
	264	 371	 0.028124	 0.066826	 0.0	 436	 436	 436	 0.0	 0.0	 1	 -30.0	 30.0;
	9290	 1842	 0.017107	 0.031438	 0.0	 883	 883	 883	 0.0	 0.0	 1	 -30.0	 30.0;
	67	 1842	 0.028322	 0.109331	 0.0	 280	 280	 280	 0.0	 0.0	 1	 -30.0	 30.0;
	6552	 11093	 0.0	 0.000413	 0.0	 76483	 76483	 76483	 0.0	 0.0	 1	 -30.0	 30.0;
	6552	 2187	 0.002248	 0.008413	 0.0	 3628	 3628	 3628	 0.0	 0.0	 1	 -30.0	 30.0;
	11093	 5193	 0.003421	 0.010397	 0.0	 2886	 2886	 2886	 0.0	 0.0	 1	 -30.0	 30.0;
	4291	 11093	 0.039554	 0.071554	 0.0	 387	 387	 387	 0.0	 0.0	 1	 -30.0	 30.0;
	2079	 11093	 0.012612	 0.036818	 0.0	 812	 812	 812	 0.0	 0.0	 1	 -30.0	 30.0;
	8636	 219	 0.004471	 0.014041	 0.0	 2144	 2144	 2144	 0.0	 0.0	 1	 -30.0	 30.0;
	219	 5775	 0.013628	 0.050934	 0.0	 600	 600	 600	 0.0	 0.0	 1	 -30.0	 30.0;
	219	 4874	 0.002438	 0.007959	 0.0	 3795	 3795	 3795	 0.0	 0.0	 1	 -30.0	 30.0;
	219	 4960	 0.014579	 0.030132	 0.0	 944	 944	 944	 0.0	 0.0	 1	 -30.0	 30.0;
	219	 12402	 0.04186	 0.08719	 0.0	 327	 327	 327	 0.0	 0.0	 1	 -30.0	 30.0;
	219	 11847	 0.072653	 0.128339	 0.0	 215	 215	 215	 0.0	 0.0	 1	 -30.0	 30.0;
	8607	 1322	 0.013612	 0.049421	 0.0	 617	 617	 617	 0.0	 0.0	 1	 -30.0	 30.0;
	8607	 11720	 0.037256	 0.107727	 0.0	 278	 278	 278	 0.0	 0.0	 1	 -30.0	 30.0;
	3902	 4227	 0.003349	 0.0237	 0.0	 1320	 1320	 1320	 0.0	 0.0	 1	 -30.0	 30.0;
	3902	 4227	 0.003281	 0.024159	 0.0	 1296	 1296	 1296	 0.0	 0.0	 1	 -30.0	 30.0;
	3902	 4227	 0.003599	 0.023469	 0.0	 1331	 1331	 1331	 0.0	 0.0	 1	 -30.0	 30.0;
	3902	 4227	 0.003669	 0.02299	 0.0	 1357	 1357	 1357	 0.0	 0.0	 1	 -30.0	 30.0;
	504	 10789	 0.009124	 0.02781	 0.0	 1080	 1080	 1080	 0.0	 0.0	 1	 -30.0	 30.0;
	504	 10789	 0.008661	 0.026479	 0.0	 1134	 1134	 1134	 0.0	 0.0	 1	 -30.0	 30.0;
	504	 10789	 0.008488	 0.027033	 0.0	 1115	 1115	 1115	 0.0	 0.0	 1	 -30.0	 30.0;
	504	 2560	 0.002248	 0.006554	 0.0	 4559	 4559	 4559	 0.0	 0.0	 1	 -30.0	 30.0;
	504	 7403	 0.001612	 0.004636	 0.0	 6436	 6436	 6436	 0.0	 0.0	 1	 -30.0	 30.0;
	504	 2187	 0.012223	 0.027331	 0.0	 1056	 1056	 1056	 0.0	 0.0	 1	 -30.0	 30.0;
	504	 7863	 0.002099	 0.01181	 0.0	 2634	 2634	 2634	 0.0	 0.0	 1	 -30.0	 30.0;
	504	 7863	 0.002058	 0.012058	 0.0	 2583	 2583	 2583	 0.0	 0.0	 1	 -30.0	 30.0;
	10789	 1948	 0.019008	 0.055876	 0.0	 536	 536	 536	 0.0	 0.0	 1	 -30.0	 30.0;
	10789	 4106	 0.020727	 0.05795	 0.0	 514	 514	 514	 0.0	 0.0	 1	 -30.0	 30.0;
	4291	 11646	 0.004471	 0.010471	 0.0	 2775	 2775	 2775	 0.0	 0.0	 1	 -30.0	 30.0;
	12729	 11646	 0.010479	 0.025967	 0.0	 1129	 1129	 1129	 0.0	 0.0	 1	 -30.0	 30.0;
	2560	 7403	 0.001636	 0.004537	 0.0	 6550	 6550	 6550	 0.0	 0.0	 1	 -30.0	 30.0;
	5193	 8636	 0.001603	 0.005256	 0.0	 5749	 5749	 5749	 0.0	 0.0	 1	 -30.0	 30.0;
	12489	 453	 0.001039	 0.00812	 0.0	 3859	 3859	 3859	 0.0	 0.0	 1	 -30.0	 30.0;
	12489	 453	 0.001169	 0.007961	 0.0	 3926	 3926	 3926	 0.0	 0.0	 1	 -30.0	 30.0;
	1322	 5775	 0.001802	 0.006628	 0.0	 4599	 4599	 4599	 0.0	 0.0	 1	 -30.0	 30.0;
	7771	 13329	 0.00022	 0.00217	 0.0	 14483	 14483	 14483	 0.0	 0.0	 1	 -30.0	 30.0;
	2405	 13329	 0.00067	 0.0072	 0.0	 4369	 4369	 4369	 0.0	 0.0	 1	 -30.0	 30.0;
	3689	 4291	 0.019826	 0.06962	 0.0	 437	 437	 437	 0.0	 0.0	 1	 -30.0	 30.0;
	3902	 6514	 0.005919	 0.02874	 0.0	 1077	 1077	 1077	 0.0	 0.0	 1	 -30.0	 30.0;
	3356	 6514	 0.001271	 0.009651	 0.0	 3245	 3245	 3245	 0.0	 0.0	 1	 -30.0	 30.0;
	12489	 6514	 0.00126	 0.00955	 0.0	 3280	 3280	 3280	 0.0	 0.0	 1	 -30.0	 30.0;
	10798	 7771	 0.0009	 0.01149	 0.0	 3292	 3292	 3292	 0.0	 0.0	 1	 -30.0	 30.0;
	7771	 12313	 0.00115	 0.01172	 0.0	 3222	 3222	 3222	 0.0	 0.0	 1	 -30.0	 30.0;
	3356	 2505	 0.00431	 0.033729	 0.0	 929	 929	 929	 0.0	 0.0	 1	 -30.0	 30.0;
	12489	 12928	 0.001841	 0.0115	 0.0	 2713	 2713	 2713	 0.0	 0.0	 1	 -30.0	 30.0;
	4491	 11733	 0.008401	 0.053719	 0.0	 581	 581	 581	 0.0	 0.0	 1	 -30.0	 30.0;
	5735	 4491	 0.0013	 0.006021	 0.0	 5129	 5129	 5129	 0.0	 0.0	 1	 -30.0	 30.0;
	13353	 12490	 0.016083	 0.036347	 0.0	 795	 795	 795	 0.0	 0.0	 1	 -30.0	 30.0;
	12490	 12399	 0.01576	 0.037058	 0.0	 785	 785	 785	 0.0	 0.0	 1	 -30.0	 30.0;
	9135	 12490	 0.039661	 0.101099	 0.0	 291	 291	 291	 0.0	 0.0	 1	 -30.0	 30.0;
	5925	 562	 0.015777	 0.058099	 0.0	 525	 525	 525	 0.0	 0.0	 1	 -30.0	 30.0;
	7033	 562	 0.044901	 0.08681	 0.0	 324	 324	 324	 0.0	 0.0	 1	 -30.0	 30.0;
	7065	 4095	 0.00173	 0.01919	 0.0	 1952	 1952	 1952	 0.0	 0.0	 1	 -30.0	 30.0;
	4095	 12632	 0.00213	 0.02194	 0.0	 1722	 1722	 1722	 0.0	 0.0	 1	 -30.0	 30.0;
	329	 1946	 0.00395	 0.008331	 0.0	 3426	 3426	 3426	 0.0	 0.0	 1	 -30.0	 30.0;
	12235	 1946	 0.157273	 0.234413	 0.0	 112	 112	 112	 0.0	 0.0	 1	 -30.0	 30.0;
	329	 5675	 0.003421	 0.009099	 0.0	 3250	 3250	 3250	 0.0	 0.0	 1	 -30.0	 30.0;
	5675	 8991	 0.06795	 0.151058	 0.0	 191	 191	 191	 0.0	 0.0	 1	 -30.0	 30.0;
	329	 4574	 0.040099	 0.154554	 0.0	 198	 198	 198	 0.0	 0.0	 1	 -30.0	 30.0;
	329	 6858	 0.070769	 0.175471	 0.0	 167	 167	 167	 0.0	 0.0	 1	 -30.0	 30.0;
	329	 757	 0.008504	 0.028322	 0.0	 1069	 1069	 1069	 0.0	 0.0	 1	 -30.0	 30.0;
	329	 13632	 0.02738	 0.069876	 0.0	 421	 421	 421	 0.0	 0.0	 1	 -30.0	 30.0;
	1400	 12992	 0.010347	 0.023041	 0.0	 1251	 1251	 1251	 0.0	 0.0	 1	 -30.0	 30.0;
	13260	 12992	 0.044281	 0.083967	 0.0	 333	 333	 333	 0.0	 0.0	 1	 -30.0	 30.0;
	1568	 1400	 0.055744	 0.101992	 0.0	 272	 272	 272	 0.0	 0.0	 1	 -30.0	 30.0;
	2420	 12403	 0.015446	 0.026554	 0.0	 1029	 1029	 1029	 0.0	 0.0	 1	 -30.0	 30.0;
	12403	 4875	 0.035388	 0.067603	 0.0	 414	 414	 414	 0.0	 0.0	 1	 -30.0	 30.0;
	4358	 10702	 0.007273	 0.013752	 0.0	 2031	 2031	 2031	 0.0	 0.0	 1	 -30.0	 30.0;
	10702	 10212	 0.00362	 0.007033	 0.0	 3994	 3994	 3994	 0.0	 0.0	 1	 -30.0	 30.0;
	6119	 10212	 0.001182	 0.003727	 0.0	 8079	 8079	 8079	 0.0	 0.0	 1	 -30.0	 30.0;
	6119	 12418	 0.013314	 0.052752	 0.0	 581	 581	 581	 0.0	 0.0	 1	 -30.0	 30.0;
	4358	 5639	 0.028372	 0.075868	 0.0	 390	 390	 390	 0.0	 0.0	 1	 -30.0	 30.0;
	11712	 4358	 0.033917	 0.080413	 0.0	 362	 362	 362	 0.0	 0.0	 1	 -30.0	 30.0;
	12298	 7786	 0.004669	 0.03695	 0.0	 849	 849	 849	 0.0	 0.0	 1	 -30.0	 30.0;
	7786	 11733	 0.004229	 0.025271	 0.0	 1233	 1233	 1233	 0.0	 0.0	 1	 -30.0	 30.0;
	11127	 9719	 0.041909	 0.072157	 0.0	 379	 379	 379	 0.0	 0.0	 1	 -30.0	 30.0;
	6843	 9719	 0.031174	 0.078554	 0.0	 374	 374	 374	 0.0	 0.0	 1	 -30.0	 30.0;
	2941	 2988	 0.030777	 0.114017	 0.0	 268	 268	 268	 0.0	 0.0	 1	 -30.0	 30.0;
	2380	 9865	 0.021479	 0.05195	 0.0	 562	 562	 562	 0.0	 0.0	 1	 -30.0	 30.0;
	9865	 2022	 0.04881	 0.09786	 0.0	 289	 289	 289	 0.0	 0.0	 1	 -30.0	 30.0;
	10608	 10500	 0.043992	 0.107769	 0.0	 272	 272	 272	 0.0	 0.0	 1	 -30.0	 30.0;
	10608	 2022	 0.017347	 0.059826	 0.0	 508	 508	 508	 0.0	 0.0	 1	 -30.0	 30.0;
	4289	 10212	 0.006281	 0.014802	 0.0	 1965	 1965	 1965	 0.0	 0.0	 1	 -30.0	 30.0;
	5639	 4289	 0.045818	 0.086281	 0.0	 324	 324	 324	 0.0	 0.0	 1	 -30.0	 30.0;
	9765	 4289	 0.022521	 0.077653	 0.0	 391	 391	 391	 0.0	 0.0	 1	 -30.0	 30.0;
	3004	 8066	 0.014132	 0.053744	 0.0	 569	 569	 569	 0.0	 0.0	 1	 -30.0	 30.0;
	1151	 3004	 0.025901	 0.082504	 0.0	 366	 366	 366	 0.0	 0.0	 1	 -30.0	 30.0;
	3548	 3004	 0.05905	 0.233421	 0.0	 132	 132	 132	 0.0	 0.0	 1	 -30.0	 30.0;
	10	 6376	 0.035174	 0.062992	 0.0	 438	 438	 438	 0.0	 0.0	 1	 -30.0	 30.0;
	10	 9275	 0.015901	 0.059529	 0.0	 513	 513	 513	 0.0	 0.0	 1	 -30.0	 30.0;
	6376	 8602	 0.005174	 0.015322	 0.0	 1954	 1954	 1954	 0.0	 0.0	 1	 -30.0	 30.0;
	6376	 9572	 0.021471	 0.063207	 0.0	 474	 474	 474	 0.0	 0.0	 1	 -30.0	 30.0;
	8602	 2896	 0.030033	 0.114521	 0.0	 267	 267	 267	 0.0	 0.0	 1	 -30.0	 30.0;
	8602	 8201	 0.050537	 0.090521	 0.0	 305	 305	 305	 0.0	 0.0	 1	 -30.0	 30.0;
	8602	 8201	 0.026446	 0.070959	 0.0	 418	 418	 418	 0.0	 0.0	 1	 -30.0	 30.0;
	9308	 6832	 0.028157	 0.075636	 0.0	 392	 392	 392	 0.0	 0.0	 1	 -30.0	 30.0;
	9308	 12312	 0.021413	 0.212132	 0.0	 149	 149	 149	 0.0	 0.0	 1	 -30.0	 30.0;
	9308	 12312	 0.046446	 0.096702	 0.0	 295	 295	 295	 0.0	 0.0	 1	 -30.0	 30.0;
	12034	 6813	 0.042562	 0.102702	 0.0	 285	 285	 285	 0.0	 0.0	 1	 -30.0	 30.0;
	11014	 6813	 0.034314	 0.071603	 0.0	 398	 398	 398	 0.0	 0.0	 1	 -30.0	 30.0;
	6926	 12729	 0.034033	 0.077537	 0.0	 374	 374	 374	 0.0	 0.0	 1	 -30.0	 30.0;
	12604	 6926	 0.01919	 0.035669	 0.0	 780	 780	 780	 0.0	 0.0	 1	 -30.0	 30.0;
	11127	 12056	 0.046826	 0.094587	 0.0	 300	 300	 300	 0.0	 0.0	 1	 -30.0	 30.0;
	13290	 4241	 0.059909	 0.111868	 0.0	 249	 249	 249	 0.0	 0.0	 1	 -30.0	 30.0;
	11663	 13290	 0.020909	 0.037934	 0.0	 730	 730	 730	 0.0	 0.0	 1	 -30.0	 30.0;
	8558	 9994	 0.009727	 0.025347	 0.0	 1164	 1164	 1164	 0.0	 0.0	 1	 -30.0	 30.0;
	7046	 8558	 0.01981	 0.040331	 0.0	 703	 703	 703	 0.0	 0.0	 1	 -30.0	 30.0;
	3847	 8074	 1.7e-05	 0.000413	 0.0	 76418	 76418	 76418	 0.0	 0.0	 1	 -30.0	 30.0;
	868	 3847	 0.017091	 0.04114	 0.0	 710	 710	 710	 0.0	 0.0	 1	 -30.0	 30.0;
	3689	 4874	 0.03014	 0.111744	 0.0	 273	 273	 273	 0.0	 0.0	 1	 -30.0	 30.0;
	11435	 2420	 0.012628	 0.026339	 0.0	 1082	 1082	 1082	 0.0	 0.0	 1	 -30.0	 30.0;
	1762	 7686	 0.032934	 0.078298	 0.0	 372	 372	 372	 0.0	 0.0	 1	 -30.0	 30.0;
	2798	 1762	 0.025198	 0.050942	 0.0	 556	 556	 556	 0.0	 0.0	 1	 -30.0	 30.0;
	4006	 10733	 0.025529	 0.049421	 0.0	 568	 568	 568	 0.0	 0.0	 1	 -30.0	 30.0;
	9135	 10733	 0.026124	 0.06962	 0.0	 425	 425	 425	 0.0	 0.0	 1	 -30.0	 30.0;
	580	 9455	 0.00036	 0.00188	 0.0	 16502	 16502	 16502	 0.0	 0.0	 1	 -30.0	 30.0;
	580	 9455	 0.00043	 0.00174	 0.0	 17624	 17624	 17624	 0.0	 0.0	 1	 -30.0	 30.0;
	12354	 1220	 0.026091	 0.052298	 0.0	 541	 541	 541	 0.0	 0.0	 1	 -30.0	 30.0;
	12354	 1220	 0.015413	 0.048636	 0.0	 620	 620	 620	 0.0	 0.0	 1	 -30.0	 30.0;
	1220	 9691	 0.024463	 0.08705	 0.0	 350	 350	 350	 0.0	 0.0	 1	 -30.0	 30.0;
	9455	 5434	 0.00638	 0.04836	 0.0	 648	 648	 648	 0.0	 0.0	 1	 -30.0	 30.0;
	9455	 12567	 0.002081	 0.01214	 0.0	 2565	 2565	 2565	 0.0	 0.0	 1	 -30.0	 30.0;
	9455	 12567	 0.002081	 0.01257	 0.0	 2480	 2480	 2480	 0.0	 0.0	 1	 -30.0	 30.0;
	13228	 4103	 0.005314	 0.015017	 0.0	 1983	 1983	 1983	 0.0	 0.0	 1	 -30.0	 30.0;
	13228	 371	 0.004331	 0.011752	 0.0	 2523	 2523	 2523	 0.0	 0.0	 1	 -30.0	 30.0;
	4103	 371	 0.00386	 0.013322	 0.0	 2278	 2278	 2278	 0.0	 0.0	 1	 -30.0	 30.0;
	371	 6832	 0.02181	 0.080802	 0.0	 378	 378	 378	 0.0	 0.0	 1	 -30.0	 30.0;
	371	 2444	 0.036992	 0.107727	 0.0	 278	 278	 278	 0.0	 0.0	 1	 -30.0	 30.0;
	371	 7581	 0.029273	 0.105248	 0.0	 290	 290	 290	 0.0	 0.0	 1	 -30.0	 30.0;
	9765	 12418	 0.016909	 0.05057	 0.0	 593	 593	 593	 0.0	 0.0	 1	 -30.0	 30.0;
	12493	 7065	 0.00302	 0.03553	 0.0	 1055	 1055	 1055	 0.0	 0.0	 1	 -30.0	 30.0;
	6858	 11134	 0.005983	 0.023132	 0.0	 1323	 1323	 1323	 0.0	 0.0	 1	 -30.0	 30.0;
	10471	 11134	 0.003777	 0.011421	 0.0	 2626	 2626	 2626	 0.0	 0.0	 1	 -30.0	 30.0;
	757	 11134	 0.050041	 0.180397	 0.0	 169	 169	 169	 0.0	 0.0	 1	 -30.0	 30.0;
	11134	 13632	 0.056562	 0.179397	 0.0	 168	 168	 168	 0.0	 0.0	 1	 -30.0	 30.0;
	7607	 3118	 0.012818	 0.046769	 0.0	 652	 652	 652	 0.0	 0.0	 1	 -30.0	 30.0;
	12731	 12928	 0.00286	 0.017581	 0.0	 1774	 1774	 1774	 0.0	 0.0	 1	 -30.0	 30.0;
	856	 13353	 0.012554	 0.029083	 0.0	 998	 998	 998	 0.0	 0.0	 1	 -30.0	 30.0;
	4394	 4295	 0.000909	 0.002876	 0.0	 10473	 10473	 10473	 0.0	 0.0	 1	 -30.0	 30.0;
	9688	 856	 0.018719	 0.033769	 0.0	 819	 819	 819	 0.0	 0.0	 1	 -30.0	 30.0;
	4532	 9688	 0.032149	 0.059041	 0.0	 470	 470	 470	 0.0	 0.0	 1	 -30.0	 30.0;
	11906	 7299	 0.005198	 0.013488	 0.0	 2186	 2186	 2186	 0.0	 0.0	 1	 -30.0	 30.0;
	4241	 11906	 0.018636	 0.044149	 0.0	 660	 660	 660	 0.0	 0.0	 1	 -30.0	 30.0;
	4241	 7299	 0.014554	 0.028438	 0.0	 989	 989	 989	 0.0	 0.0	 1	 -30.0	 30.0;
	11663	 4241	 0.032934	 0.155826	 0.0	 199	 199	 199	 0.0	 0.0	 1	 -30.0	 30.0;
	4241	 9666	 0.015231	 0.035843	 0.0	 812	 812	 812	 0.0	 0.0	 1	 -30.0	 30.0;
	4241	 13588	 0.037248	 0.089901	 0.0	 325	 325	 325	 0.0	 0.0	 1	 -30.0	 30.0;
	4241	 632	 0.04643	 0.09338	 0.0	 303	 303	 303	 0.0	 0.0	 1	 -30.0	 30.0;
	6851	 12502	 0.075612	 0.155504	 0.0	 183	 183	 183	 0.0	 0.0	 1	 -30.0	 30.0;
	12502	 6377	 0.04057	 0.08876	 0.0	 324	 324	 324	 0.0	 0.0	 1	 -30.0	 30.0;
	12502	 489	 0.114628	 0.20105	 0.0	 137	 137	 137	 0.0	 0.0	 1	 -30.0	 30.0;
	6260	 13628	 0.018521	 0.090322	 0.0	 343	 343	 343	 0.0	 0.0	 1	 -30.0	 30.0;
	4106	 13628	 0.013702	 0.052983	 0.0	 578	 578	 578	 0.0	 0.0	 1	 -30.0	 30.0;
	2468	 11533	 0.006017	 0.019198	 0.0	 1571	 1571	 1571	 0.0	 0.0	 1	 -30.0	 30.0;
	2468	 9971	 0.052686	 0.090653	 0.0	 302	 302	 302	 0.0	 0.0	 1	 -30.0	 30.0;
	2468	 3118	 0.065826	 0.122818	 0.0	 227	 227	 227	 0.0	 0.0	 1	 -30.0	 30.0;
	9765	 11022	 0.04443	 0.105719	 0.0	 276	 276	 276	 0.0	 0.0	 1	 -30.0	 30.0;
	13273	 11787	 0.00838	 0.018942	 0.0	 1526	 1526	 1526	 0.0	 0.0	 1	 -30.0	 30.0;
	12231	 11787	 0.058017	 0.142983	 0.0	 205	 205	 205	 0.0	 0.0	 1	 -30.0	 30.0;
	2195	 11494	 0.00085	 0.01148	 0.0	 2744	 2744	 2744	 0.0	 0.0	 1	 -30.0	 30.0;
	12632	 11494	 0.00172	 0.0234	 0.0	 1347	 1347	 1347	 0.0	 0.0	 1	 -30.0	 30.0;
	11127	 13273	 0.04805	 0.152256	 0.0	 198	 198	 198	 0.0	 0.0	 1	 -30.0	 30.0;
	13273	 8487	 0.028372	 0.069471	 0.0	 421	 421	 421	 0.0	 0.0	 1	 -30.0	 30.0;
	9994	 13273	 0.038364	 0.12214	 0.0	 247	 247	 247	 0.0	 0.0	 1	 -30.0	 30.0;
	5508	 8066	 0.013463	 0.05405	 0.0	 568	 568	 568	 0.0	 0.0	 1	 -30.0	 30.0;
	4960	 12402	 0.025083	 0.060273	 0.0	 484	 484	 484	 0.0	 0.0	 1	 -30.0	 30.0;
	3776	 13208	 0.012438	 0.047124	 0.0	 649	 649	 649	 0.0	 0.0	 1	 -30.0	 30.0;
	13260	 3776	 0.022388	 0.084818	 0.0	 361	 361	 361	 0.0	 0.0	 1	 -30.0	 30.0;
	2941	 4336	 0.005471	 0.020281	 0.0	 1504	 1504	 1504	 0.0	 0.0	 1	 -30.0	 30.0;
	7010	 4336	 0.107174	 0.201248	 0.0	 139	 139	 139	 0.0	 0.0	 1	 -30.0	 30.0;
	7529	 2941	 0.035058	 0.124769	 0.0	 244	 244	 244	 0.0	 0.0	 1	 -30.0	 30.0;
	2896	 11533	 0.015934	 0.05876	 0.0	 519	 519	 519	 0.0	 0.0	 1	 -30.0	 30.0;
	868	 8074	 0.020099	 0.03862	 0.0	 726	 726	 726	 0.0	 0.0	 1	 -30.0	 30.0;
	3162	 5505	 0.04176	 0.103083	 0.0	 285	 285	 285	 0.0	 0.0	 1	 -30.0	 30.0;
	5465	 5505	 0.066719	 0.165537	 0.0	 177	 177	 177	 0.0	 0.0	 1	 -30.0	 30.0;
	12567	 7311	 0.00013	 0.00095	 0.0	 32943	 32943	 32943	 0.0	 0.0	 1	 -30.0	 30.0;
	4006	 9812	 0.033777	 0.06776	 0.0	 418	 418	 418	 0.0	 0.0	 1	 -30.0	 30.0;
	12156	 9812	 0.057388	 0.126289	 0.0	 228	 228	 228	 0.0	 0.0	 1	 -30.0	 30.0;
	2195	 13376	 0.0019	 0.0204	 0.0	 1852	 1852	 1852	 0.0	 0.0	 1	 -30.0	 30.0;
	12231	 12409	 0.007529	 0.025372	 0.0	 1194	 1194	 1194	 0.0	 0.0	 1	 -30.0	 30.0;
	12231	 2374	 0.023917	 0.064636	 0.0	 459	 459	 459	 0.0	 0.0	 1	 -30.0	 30.0;
	12231	 8540	 0.039612	 0.099818	 0.0	 295	 295	 295	 0.0	 0.0	 1	 -30.0	 30.0;
	12231	 10867	 0.012388	 0.038802	 0.0	 776	 776	 776	 0.0	 0.0	 1	 -30.0	 30.0;
	12409	 10867	 0.004281	 0.015678	 0.0	 1944	 1944	 1944	 0.0	 0.0	 1	 -30.0	 30.0;
	11103	 11712	 0.013463	 0.033289	 0.0	 880	 880	 880	 0.0	 0.0	 1	 -30.0	 30.0;
	12644	 11712	 0.015893	 0.039901	 0.0	 736	 736	 736	 0.0	 0.0	 1	 -30.0	 30.0;
	12644	 11103	 0.005934	 0.021686	 0.0	 1405	 1405	 1405	 0.0	 0.0	 1	 -30.0	 30.0;
	9436	 11103	 0.009107	 0.02843	 0.0	 1059	 1059	 1059	 0.0	 0.0	 1	 -30.0	 30.0;
	12644	 9436	 0.005802	 0.020083	 0.0	 1512	 1512	 1512	 0.0	 0.0	 1	 -30.0	 30.0;
	12644	 2579	 0.10495	 0.203661	 0.0	 138	 138	 138	 0.0	 0.0	 1	 -30.0	 30.0;
	12644	 9038	 0.026372	 0.04995	 0.0	 560	 560	 560	 0.0	 0.0	 1	 -30.0	 30.0;
	967	 12298	 0.00738	 0.044	 0.0	 709	 709	 709	 0.0	 0.0	 1	 -30.0	 30.0;
	12298	 11733	 0.010591	 0.05825	 0.0	 534	 534	 534	 0.0	 0.0	 1	 -30.0	 30.0;
	7125	 967	 0.01318	 0.05764	 0.0	 535	 535	 535	 0.0	 0.0	 1	 -30.0	 30.0;
	967	 6450	 0.0143	 0.06869	 0.0	 451	 451	 451	 0.0	 0.0	 1	 -30.0	 30.0;
	11127	 3131	 0.022099	 0.080636	 0.0	 378	 378	 378	 0.0	 0.0	 1	 -30.0	 30.0;
	1568	 2380	 0.039843	 0.08557	 0.0	 335	 335	 335	 0.0	 0.0	 1	 -30.0	 30.0;
	2380	 12427	 0.007909	 0.022124	 0.0	 1345	 1345	 1345	 0.0	 0.0	 1	 -30.0	 30.0;
	12290	 180	 0.051017	 0.111273	 0.0	 259	 259	 259	 0.0	 0.0	 1	 -30.0	 30.0;
	9994	 2374	 0.010331	 0.038289	 0.0	 797	 797	 797	 0.0	 0.0	 1	 -30.0	 30.0;
	7686	 3689	 0.02343	 0.058603	 0.0	 501	 501	 501	 0.0	 0.0	 1	 -30.0	 30.0;
	12632	 2818	 0.0009	 0.00851	 0.0	 4434	 4434	 4434	 0.0	 0.0	 1	 -30.0	 30.0;
	2818	 8891	 0.00157	 0.01488	 0.0	 2513	 2513	 2513	 0.0	 0.0	 1	 -30.0	 30.0;
	7125	 10005	 0.00682	 0.03224	 0.0	 959	 959	 959	 0.0	 0.0	 1	 -30.0	 30.0;
	11663	 12034	 0.01719	 0.033322	 0.0	 843	 843	 843	 0.0	 0.0	 1	 -30.0	 30.0;
	12034	 11014	 0.080446	 0.14995	 0.0	 186	 186	 186	 0.0	 0.0	 1	 -30.0	 30.0;
	7033	 6851	 0.055678	 0.123917	 0.0	 233	 233	 233	 0.0	 0.0	 1	 -30.0	 30.0;
	1739	 2444	 0.014463	 0.040066	 0.0	 742	 742	 742	 0.0	 0.0	 1	 -30.0	 30.0;
	1739	 12220	 0.013107	 0.048314	 0.0	 631	 631	 631	 0.0	 0.0	 1	 -30.0	 30.0;
	6377	 2798	 0.123174	 0.23414	 0.0	 120	 120	 120	 0.0	 0.0	 1	 -30.0	 30.0;
	4574	 8991	 0.00557	 0.011256	 0.0	 2516	 2516	 2516	 0.0	 0.0	 1	 -30.0	 30.0;
	4574	 8289	 0.007967	 0.018719	 0.0	 1553	 1553	 1553	 0.0	 0.0	 1	 -30.0	 30.0;
	12235	 8289	 0.076711	 0.159554	 0.0	 179	 179	 179	 0.0	 0.0	 1	 -30.0	 30.0;
	808	 9572	 0.012669	 0.049364	 0.0	 620	 620	 620	 0.0	 0.0	 1	 -30.0	 30.0;
	808	 7586	 0.015719	 0.058826	 0.0	 519	 519	 519	 0.0	 0.0	 1	 -30.0	 30.0;
	4816	 1994	 0.007397	 0.027686	 0.0	 1103	 1103	 1103	 0.0	 0.0	 1	 -30.0	 30.0;
	4816	 3118	 0.006967	 0.02505	 0.0	 1215	 1215	 1215	 0.0	 0.0	 1	 -30.0	 30.0;
	8078	 12826	 0.037653	 0.076876	 0.0	 370	 370	 370	 0.0	 0.0	 1	 -30.0	 30.0;
	5925	 67	 0.011	 0.029826	 0.0	 994	 994	 994	 0.0	 0.0	 1	 -30.0	 30.0;
	7010	 7529	 0.042446	 0.107058	 0.0	 275	 275	 275	 0.0	 0.0	 1	 -30.0	 30.0;
	6858	 10471	 0.011008	 0.025711	 0.0	 1130	 1130	 1130	 0.0	 0.0	 1	 -30.0	 30.0;
	10519	 11014	 0.014818	 0.04719	 0.0	 639	 639	 639	 0.0	 0.0	 1	 -30.0	 30.0;
	10519	 11014	 0.011802	 0.040711	 0.0	 746	 746	 746	 0.0	 0.0	 1	 -30.0	 30.0;
	11014	 10519	 0.010802	 0.039769	 0.0	 767	 767	 767	 0.0	 0.0	 1	 -30.0	 30.0;
	10519	 2807	 0.003331	 0.011496	 0.0	 2640	 2640	 2640	 0.0	 0.0	 1	 -30.0	 30.0;
	10519	 12290	 0.041256	 0.083702	 0.0	 339	 339	 339	 0.0	 0.0	 1	 -30.0	 30.0;
	2807	 11014	 0.011223	 0.030413	 0.0	 975	 975	 975	 0.0	 0.0	 1	 -30.0	 30.0;
	11014	 4394	 0.105562	 0.208901	 0.0	 135	 135	 135	 0.0	 0.0	 1	 -30.0	 30.0;
	11014	 3162	 0.021612	 0.065496	 0.0	 458	 458	 458	 0.0	 0.0	 1	 -30.0	 30.0;
	12632	 9582	 0.0056	 0.03178	 0.0	 1176	 1176	 1176	 0.0	 0.0	 1	 -30.0	 30.0;
	4106	 1948	 0.005364	 0.01443	 0.0	 2052	 2052	 2052	 0.0	 0.0	 1	 -30.0	 30.0;
	8805	 12326	 0.007132	 0.016347	 0.0	 1772	 1772	 1772	 0.0	 0.0	 1	 -30.0	 30.0;
	12326	 3118	 0.035281	 0.111719	 0.0	 270	 270	 270	 0.0	 0.0	 1	 -30.0	 30.0;
	2579	 8805	 0.027669	 0.067686	 0.0	 432	 432	 432	 0.0	 0.0	 1	 -30.0	 30.0;
	8805	 4532	 0.086157	 0.181149	 0.0	 158	 158	 158	 0.0	 0.0	 1	 -30.0	 30.0;
	6681	 12354	 0.019983	 0.054711	 0.0	 543	 543	 543	 0.0	 0.0	 1	 -30.0	 30.0;
	6681	 6260	 0.007041	 0.032174	 0.0	 960	 960	 960	 0.0	 0.0	 1	 -30.0	 30.0;
	5495	 9290	 0.050587	 0.128397	 0.0	 229	 229	 229	 0.0	 0.0	 1	 -30.0	 30.0;
	12354	 10602	 0.014983	 0.031364	 0.0	 909	 909	 909	 0.0	 0.0	 1	 -30.0	 30.0;
	10602	 9160	 0.010653	 0.019	 0.0	 1451	 1451	 1451	 0.0	 0.0	 1	 -30.0	 30.0;
	8271	 7029	 0.00189	 0.02064	 0.0	 1814	 1814	 1814	 0.0	 0.0	 1	 -30.0	 30.0;
	8271	 7029	 0.00227	 0.01922	 0.0	 1943	 1943	 1943	 0.0	 0.0	 1	 -30.0	 30.0;
	7029	 1255	 0.00167	 0.02044	 0.0	 1850	 1850	 1850	 0.0	 0.0	 1	 -30.0	 30.0;
	3902	 9828	 0.016341	 0.07818	 0.0	 396	 396	 396	 0.0	 0.0	 1	 -30.0	 30.0;
	11007	 9828	 0.005409	 0.024729	 0.0	 1248	 1248	 1248	 0.0	 0.0	 1	 -30.0	 30.0;
	9828	 2095	 0.00525	 0.04099	 0.0	 765	 765	 765	 0.0	 0.0	 1	 -30.0	 30.0;
	12354	 4978	 0.00714	 0.025347	 0.0	 1200	 1200	 1200	 0.0	 0.0	 1	 -30.0	 30.0;
	12354	 5518	 0.00819	 0.025802	 0.0	 1167	 1167	 1167	 0.0	 0.0	 1	 -30.0	 30.0;
	9160	 12354	 0.006322	 0.014314	 0.0	 2019	 2019	 2019	 0.0	 0.0	 1	 -30.0	 30.0;
	7611	 1568	 0.037678	 0.087512	 0.0	 332	 332	 332	 0.0	 0.0	 1	 -30.0	 30.0;
	7611	 10552	 0.010942	 0.034529	 0.0	 873	 873	 873	 0.0	 0.0	 1	 -30.0	 30.0;
	4978	 10552	 0.007041	 0.02714	 0.0	 1127	 1127	 1127	 0.0	 0.0	 1	 -30.0	 30.0;
	10552	 5518	 0.002826	 0.010496	 0.0	 2906	 2906	 2906	 0.0	 0.0	 1	 -30.0	 30.0;
	10798	 8271	 0.0001	 0.00124	 0.0	 30218	 30218	 30218	 0.0	 0.0	 1	 -30.0	 30.0;
	10798	 6525	 3e-05	 0.00027	 0.0	 138377	 138377	 138377	 0.0	 0.0	 1	 -30.0	 30.0;
	10798	 9119	 2e-05	 0.00021	 0.0	 178202	 178202	 178202	 0.0	 0.0	 1	 -30.0	 30.0;
	10798	 8271	 0.00011	 0.00133	 0.0	 28169	 28169	 28169	 0.0	 0.0	 1	 -30.0	 30.0;
	10798	 13376	 0.00062	 0.00694	 0.0	 5396	 5396	 5396	 0.0	 0.0	 1	 -30.0	 30.0;
	3902	 11413	 0.005281	 0.04189	 0.0	 749	 749	 749	 0.0	 0.0	 1	 -30.0	 30.0;
	3902	 5284	 0.00014	 0.000651	 0.0	 47437	 47437	 47437	 0.0	 0.0	 1	 -30.0	 30.0;
	3902	 1635	 0.000229	 0.00107	 0.0	 28868	 28868	 28868	 0.0	 0.0	 1	 -30.0	 30.0;
	3902	 4800	 0.000229	 0.001039	 0.0	 29690	 29690	 29690	 0.0	 0.0	 1	 -30.0	 30.0;
	3902	 6991	 0.00013	 0.00086	 0.0	 36317	 36317	 36317	 0.0	 0.0	 1	 -30.0	 30.0;
	3902	 10515	 0.00013	 0.00087	 0.0	 35909	 35909	 35909	 0.0	 0.0	 1	 -30.0	 30.0;
	3902	 8332	 0.001539	 0.012651	 0.0	 2479	 2479	 2479	 0.0	 0.0	 1	 -30.0	 30.0;
	3902	 1011	 0.00806	 0.047091	 0.0	 662	 662	 662	 0.0	 0.0	 1	 -30.0	 30.0;
	12427	 10500	 0.04943	 0.099331	 0.0	 285	 285	 285	 0.0	 0.0	 1	 -30.0	 30.0;
	2532	 489	 0.050488	 0.104149	 0.0	 273	 273	 273	 0.0	 0.0	 1	 -30.0	 30.0;
	9691	 10936	 0.003702	 0.008934	 0.0	 3267	 3267	 3267	 0.0	 0.0	 1	 -30.0	 30.0;
	1568	 10936	 0.074446	 0.138033	 0.0	 202	 202	 202	 0.0	 0.0	 1	 -30.0	 30.0;
	5508	 12402	 0.008479	 0.021653	 0.0	 1359	 1359	 1359	 0.0	 0.0	 1	 -30.0	 30.0;
	5508	 12402	 0.005314	 0.019479	 0.0	 1565	 1565	 1565	 0.0	 0.0	 1	 -30.0	 30.0;
	12493	 2405	 0.00104	 0.01121	 0.0	 3370	 3370	 3370	 0.0	 0.0	 1	 -30.0	 30.0;
	2095	 12731	 0.01118	 0.07193	 0.0	 434	 434	 434	 0.0	 0.0	 1	 -30.0	 30.0;
	8487	 6843	 0.002777	 0.008174	 0.0	 3659	 3659	 3659	 0.0	 0.0	 1	 -30.0	 30.0;
	9275	 9971	 0.006058	 0.02362	 0.0	 1296	 1296	 1296	 0.0	 0.0	 1	 -30.0	 30.0;
	9582	 10718	 0.00192	 0.01477	 0.0	 2524	 2524	 2524	 0.0	 0.0	 1	 -30.0	 30.0;
	11533	 9971	 0.025331	 0.098711	 0.0	 310	 310	 310	 0.0	 0.0	 1	 -30.0	 30.0;
	7033	 5762	 0.05886	 0.113157	 0.0	 248	 248	 248	 0.0	 0.0	 1	 -30.0	 30.0;
	740	 5762	 0.046851	 0.110231	 0.0	 264	 264	 264	 0.0	 0.0	 1	 -30.0	 30.0;
	1151	 7010	 0.02895	 0.10819	 0.0	 283	 283	 283	 0.0	 0.0	 1	 -30.0	 30.0;
	1528	 12235	 0.079438	 0.11481	 0.0	 227	 227	 227	 0.0	 0.0	 1	 -30.0	 30.0;
	1528	 12235	 0.077967	 0.117314	 0.0	 225	 225	 225	 0.0	 0.0	 1	 -30.0	 30.0;
	12235	 9994	 0.032669	 0.091388	 0.0	 326	 326	 326	 0.0	 0.0	 1	 -30.0	 30.0;
	1234	 4394	 0.008421	 0.02657	 0.0	 1134	 1134	 1134	 0.0	 0.0	 1	 -30.0	 30.0;
	3162	 1234	 0.082727	 0.14876	 0.0	 186	 186	 186	 0.0	 0.0	 1	 -30.0	 30.0;
	6450	 12567	 0.00637	 0.029669	 0.0	 1041	 1041	 1041	 0.0	 0.0	 1	 -30.0	 30.0;
	6069	 1528	 0.020223	 0.033198	 0.0	 813	 813	 813	 0.0	 0.0	 1	 -30.0	 30.0;
	6069	 1528	 0.017843	 0.033876	 0.0	 825	 825	 825	 0.0	 0.0	 1	 -30.0	 30.0;
	9765	 4006	 0.022058	 0.05405	 0.0	 542	 542	 542	 0.0	 0.0	 1	 -30.0	 30.0;
	9765	 13126	 0.019826	 0.073909	 0.0	 413	 413	 413	 0.0	 0.0	 1	 -30.0	 30.0;
	13588	 4875	 0.063107	 0.131711	 0.0	 217	 217	 217	 0.0	 0.0	 1	 -30.0	 30.0;
	7485	 2444	 0.012099	 0.029041	 0.0	 1005	 1005	 1005	 0.0	 0.0	 1	 -30.0	 30.0;
	7485	 2444	 0.006273	 0.019033	 0.0	 1577	 1577	 1577	 0.0	 0.0	 1	 -30.0	 30.0;
	7485	 11269	 0.007603	 0.021273	 0.0	 1399	 1399	 1399	 0.0	 0.0	 1	 -30.0	 30.0;
	7485	 11269	 0.011041	 0.027339	 0.0	 1072	 1072	 1072	 0.0	 0.0	 1	 -30.0	 30.0;
	12661	 9917	 0.011636	 0.032562	 0.0	 914	 914	 914	 0.0	 0.0	 1	 -30.0	 30.0;
	12661	 2444	 0.007091	 0.019058	 0.0	 1554	 1554	 1554	 0.0	 0.0	 1	 -30.0	 30.0;
	9917	 11269	 0.006653	 0.020967	 0.0	 1436	 1436	 1436	 0.0	 0.0	 1	 -30.0	 30.0;
	13546	 12567	 0.00212	 0.01695	 0.0	 1850	 1850	 1850	 0.0	 0.0	 1	 -30.0	 30.0;
	13546	 12567	 0.002349	 0.0155	 0.0	 2015	 2015	 2015	 0.0	 0.0	 1	 -30.0	 30.0;
	2444	 12312	 0.053901	 0.092744	 0.0	 295	 295	 295	 0.0	 0.0	 1	 -30.0	 30.0;
	1923	 8201	 0.003273	 0.010033	 0.0	 2994	 2994	 2994	 0.0	 0.0	 1	 -30.0	 30.0;
	1923	 3597	 0.005066	 0.013769	 0.0	 2153	 2153	 2153	 0.0	 0.0	 1	 -30.0	 30.0;
	8201	 3597	 0.007826	 0.028587	 0.0	 1066	 1066	 1066	 0.0	 0.0	 1	 -30.0	 30.0;
	3597	 7586	 0.032769	 0.058711	 0.0	 470	 470	 470	 0.0	 0.0	 1	 -30.0	 30.0;
	11847	 11720	 0.053702	 0.134017	 0.0	 219	 219	 219	 0.0	 0.0	 1	 -30.0	 30.0;
	8271	 3715	 0.00147	 0.01305	 0.0	 2863	 2863	 2863	 0.0	 0.0	 1	 -30.0	 30.0;
	6745	 8271	 0.00019	 0.00195	 0.0	 19187	 19187	 19187	 0.0	 0.0	 1	 -30.0	 30.0;
	12832	 8271	 0.00019	 0.00191	 0.0	 19585	 19585	 19585	 0.0	 0.0	 1	 -30.0	 30.0;
	7047	 4346	 0.006413	 0.019917	 0.0	 1510	 1510	 1510	 0.0	 0.0	 1	 -30.0	 30.0;
	6069	 4346	 0.011562	 0.044182	 0.0	 692	 692	 692	 0.0	 0.0	 1	 -30.0	 30.0;
	8792	 7047	 0.002512	 0.008421	 0.0	 3595	 3595	 3595	 0.0	 0.0	 1	 -30.0	 30.0;
	725	 5495	 0.041702	 0.098711	 0.0	 295	 295	 295	 0.0	 0.0	 1	 -30.0	 30.0;
	740	 725	 0.034347	 0.061636	 0.0	 448	 448	 448	 0.0	 0.0	 1	 -30.0	 30.0;
	7033	 2103	 0.004289	 0.01243	 0.0	 2403	 2403	 2403	 0.0	 0.0	 1	 -30.0	 30.0;
	8727	 2103	 0.000686	 0.001471	 0.0	 19462	 19462	 19462	 0.0	 0.0	 1	 -30.0	 30.0;
	7033	 8392	 0.006612	 0.01886	 0.0	 1581	 1581	 1581	 0.0	 0.0	 1	 -30.0	 30.0;
	11415	 8392	 0.008388	 0.023339	 0.0	 1274	 1274	 1274	 0.0	 0.0	 1	 -30.0	 30.0;
	7033	 8727	 0.004372	 0.012174	 0.0	 2442	 2442	 2442	 0.0	 0.0	 1	 -30.0	 30.0;
	7033	 11415	 0.013413	 0.047793	 0.0	 637	 637	 637	 0.0	 0.0	 1	 -30.0	 30.0;
	1568	 13208	 0.08438	 0.183769	 0.0	 157	 157	 157	 0.0	 0.0	 1	 -30.0	 30.0;
	4006	 5904	 0.006372	 0.01681	 0.0	 1758	 1758	 1758	 0.0	 0.0	 1	 -30.0	 30.0;
	12220	 7586	 0.028579	 0.084149	 0.0	 356	 356	 356	 0.0	 0.0	 1	 -30.0	 30.0;
	12220	 6229	 0.007008	 0.022388	 0.0	 1347	 1347	 1347	 0.0	 0.0	 1	 -30.0	 30.0;
	11847	 12638	 0.003	 0.005058	 0.0	 5372	 5372	 5372	 0.0	 0.0	 1	 -30.0	 30.0;
	416	 12638	 0.002669	 0.005727	 0.0	 5000	 5000	 5000	 0.0	 0.0	 1	 -30.0	 30.0;
	12638	 3273	 0.003661	 0.008818	 0.0	 3309	 3309	 3309	 0.0	 0.0	 1	 -30.0	 30.0;
	12638	 6069	 0.029843	 0.069744	 0.0	 417	 417	 417	 0.0	 0.0	 1	 -30.0	 30.0;
	416	 5079	 0.006438	 0.01824	 0.0	 1634	 1634	 1634	 0.0	 0.0	 1	 -30.0	 30.0;
	416	 5079	 0.006322	 0.018636	 0.0	 1606	 1606	 1606	 0.0	 0.0	 1	 -30.0	 30.0;
	12313	 12493	 0.00068	 0.00797	 0.0	 4700	 4700	 4700	 0.0	 0.0	 1	 -30.0	 30.0;
	5079	 12826	 0.032364	 0.088289	 0.0	 336	 336	 336	 0.0	 0.0	 1	 -30.0	 30.0;
	5079	 6069	 0.027066	 0.084496	 0.0	 357	 357	 357	 0.0	 0.0	 1	 -30.0	 30.0;
	5079	 6069	 0.026554	 0.086256	 0.0	 350	 350	 350	 0.0	 0.0	 1	 -30.0	 30.0;
	6069	 3273	 0.029901	 0.071322	 0.0	 409	 409	 409	 0.0	 0.0	 1	 -30.0	 30.0;
	868	 740	 0.011901	 0.023818	 0.0	 1187	 1187	 1187	 0.0	 0.0	 1	 -30.0	 30.0;
	67	 740	 0.012132	 0.023322	 0.0	 1202	 1202	 1202	 0.0	 0.0	 1	 -30.0	 30.0;
	7184	 11007	 0.0098	 0.062349	 0.0	 501	 501	 501	 0.0	 0.0	 1	 -30.0	 30.0;
	868	 10072	 0.004182	 0.012678	 0.0	 2367	 2367	 2367	 0.0	 0.0	 1	 -30.0	 30.0;
	67	 10072	 0.003636	 0.014636	 0.0	 2095	 2095	 2095	 0.0	 0.0	 1	 -30.0	 30.0;
	12826	 7046	 0.01919	 0.045041	 0.0	 646	 646	 646	 0.0	 0.0	 1	 -30.0	 30.0;
	8328	 5221	 0.009793	 0.037174	 0.0	 822	 822	 822	 0.0	 0.0	 1	 -30.0	 30.0;
	5221	 2022	 0.004281	 0.010339	 0.0	 2823	 2823	 2823	 0.0	 0.0	 1	 -30.0	 30.0;
	5221	 2022	 0.005521	 0.021471	 0.0	 1425	 1425	 1425	 0.0	 0.0	 1	 -30.0	 30.0;
	1255	 387	 0.0011	 0.01325	 0.0	 2376	 2376	 2376	 0.0	 0.0	 1	 -30.0	 30.0;
	1568	 12427	 0.018421	 0.051372	 0.0	 579	 579	 579	 0.0	 0.0	 1	 -30.0	 30.0;
	1568	 1424	 0.011521	 0.042529	 0.0	 717	 717	 717	 0.0	 0.0	 1	 -30.0	 30.0;
	3689	 2079	 0.025182	 0.071554	 0.0	 417	 417	 417	 0.0	 0.0	 1	 -30.0	 30.0;
	13260	 4701	 0.0	 0.000413	 0.0	 76483	 76483	 76483	 0.0	 0.0	 1	 -30.0	 30.0;
	1994	 6197	 0.014603	 0.03386	 0.0	 857	 857	 857	 0.0	 0.0	 1	 -30.0	 30.0;
	6441	 3689	 0.022066	 0.054521	 0.0	 538	 538	 538	 0.0	 0.0	 1	 -30.0	 30.0;
	2798	 6441	 0.041471	 0.090793	 0.0	 317	 317	 317	 0.0	 0.0	 1	 -30.0	 30.0;
	6069	 8792	 0.008843	 0.031901	 0.0	 955	 955	 955	 0.0	 0.0	 1	 -30.0	 30.0;
	5511	 12567	 0.00038	 0.003091	 0.0	 10143	 10143	 10143	 0.0	 0.0	 1	 -30.0	 30.0;
	5511	 12567	 0.0005	 0.002901	 0.0	 10731	 10731	 10731	 0.0	 0.0	 1	 -30.0	 30.0;
	11269	 12312	 0.032132	 0.318198	 0.0	 99	 99	 99	 0.0	 0.0	 1	 -30.0	 30.0;
	11269	 3118	 0.058554	 0.146124	 0.0	 201	 201	 201	 0.0	 0.0	 1	 -30.0	 30.0;
	8265	 11269	 0.023917	 0.073289	 0.0	 410	 410	 410	 0.0	 0.0	 1	 -30.0	 30.0;
	11269	 6197	 0.040818	 0.089273	 0.0	 322	 322	 322	 0.0	 0.0	 1	 -30.0	 30.0;
	9582	 3212	 2e-05	 0.00025	 0.0	 149888	 149888	 149888	 0.0	 0.0	 1	 -30.0	 30.0;
	9582	 3212	 2e-05	 0.00026	 0.0	 144157	 144157	 144157	 0.0	 0.0	 1	 -30.0	 30.0;
	3212	 3923	 0.00082	 0.00822	 0.0	 4551	 4551	 4551	 0.0	 0.0	 1	 -30.0	 30.0;
	3131	 9038	 0.014339	 0.031777	 0.0	 907	 907	 907	 0.0	 0.0	 1	 -30.0	 30.0;
	7010	 9298	 0.011364	 0.034364	 0.0	 873	 873	 873	 0.0	 0.0	 1	 -30.0	 30.0;
	9298	 4304	 0.000347	 0.001066	 0.0	 28177	 28177	 28177	 0.0	 0.0	 1	 -30.0	 30.0;
	6229	 12312	 0.012752	 0.036041	 0.0	 827	 827	 827	 0.0	 0.0	 1	 -30.0	 30.0;
	7581	 12312	 0.000669	 0.001281	 0.0	 21858	 21858	 21858	 0.0	 0.0	 1	 -30.0	 30.0;
	7581	 12312	 0.000661	 0.001314	 0.0	 21475	 21475	 21475	 0.0	 0.0	 1	 -30.0	 30.0;
	13126	 5904	 0.005289	 0.014942	 0.0	 1993	 1993	 1993	 0.0	 0.0	 1	 -30.0	 30.0;
	2798	 12156	 0.004256	 0.007364	 0.0	 3714	 3714	 3714	 0.0	 0.0	 1	 -30.0	 30.0;
	2532	 12156	 0.003992	 0.009107	 0.0	 3177	 3177	 3177	 0.0	 0.0	 1	 -30.0	 30.0;
	9666	 11435	 0.041488	 0.08662	 0.0	 329	 329	 329	 0.0	 0.0	 1	 -30.0	 30.0;
	11435	 13588	 0.00486	 0.010132	 0.0	 2811	 2811	 2811	 0.0	 0.0	 1	 -30.0	 30.0;
	11435	 632	 0.00495	 0.009934	 0.0	 2846	 2846	 2846	 0.0	 0.0	 1	 -30.0	 30.0;
	632	 13588	 0.00505	 0.009719	 0.0	 2884	 2884	 2884	 0.0	 0.0	 1	 -30.0	 30.0;
	1424	 12427	 0.00776	 0.027521	 0.0	 1105	 1105	 1105	 0.0	 0.0	 1	 -30.0	 30.0;
	3041	 3548	 0.00262	 0.007628	 0.0	 3917	 3917	 3917	 0.0	 0.0	 1	 -30.0	 30.0;
	8265	 6197	 0.001793	 0.005471	 0.0	 5487	 5487	 5487	 0.0	 0.0	 1	 -30.0	 30.0;
	13632	 5465	 0.000537	 0.015661	 0.0	 2016	 2016	 2016	 0.0	 0.0	 1	 -30.0	 30.0;
	7010	 4304	 0.01124	 0.036826	 0.0	 821	 821	 821	 0.0	 0.0	 1	 -30.0	 30.0;
	10322	 7215	 0.00156	 0.01791	 0.0	 1758	 1758	 1758	 0.0	 0.0	 1	 -30.0	 30.0;
	7215	 10709	 0.00155	 0.01686	 0.0	 1866	 1866	 1866	 0.0	 0.0	 1	 -30.0	 30.0;
	7215	 10709	 0.00152	 0.01719	 0.0	 1831	 1831	 1831	 0.0	 0.0	 1	 -30.0	 30.0;
	12158	 7215	 0.00068	 0.00644	 0.0	 4878	 4878	 4878	 0.0	 0.0	 1	 -30.0	 30.0;
	12158	 7215	 0.00069	 0.0063	 0.0	 4985	 4985	 4985	 0.0	 0.0	 1	 -30.0	 30.0;
	7215	 8477	 0.00112	 0.01064	 0.0	 2953	 2953	 2953	 0.0	 0.0	 1	 -30.0	 30.0;
	3071	 7270	 0.00151	 0.011539	 0.0	 2715	 2715	 2715	 0.0	 0.0	 1	 -30.0	 30.0;
	11977	 3071	 0.00788	 0.05236	 0.0	 597	 597	 597	 0.0	 0.0	 1	 -30.0	 30.0;
	9388	 10709	 0.00128	 0.0126	 0.0	 2495	 2495	 2495	 0.0	 0.0	 1	 -30.0	 30.0;
	1165	 9388	 0.00037	 0.00409	 0.0	 7692	 7692	 7692	 0.0	 0.0	 1	 -30.0	 30.0;
	1165	 9388	 0.00036	 0.00417	 0.0	 7547	 7547	 7547	 0.0	 0.0	 1	 -30.0	 30.0;
	9388	 8477	 0.00122	 0.0112	 0.0	 2804	 2804	 2804	 0.0	 0.0	 1	 -30.0	 30.0;
	11977	 12261	 0.006591	 0.04075	 0.0	 766	 766	 766	 0.0	 0.0	 1	 -30.0	 30.0;
	4131	 7270	 0.007961	 0.05756	 0.0	 544	 544	 544	 0.0	 0.0	 1	 -30.0	 30.0;
	7441	 3791	 0.00059	 0.0085	 0.0	 3708	 3708	 3708	 0.0	 0.0	 1	 -30.0	 30.0;
	3791	 8008	 0.00084	 0.0118	 0.0	 2671	 2671	 2671	 0.0	 0.0	 1	 -30.0	 30.0;
	3791	 9434	 0.00178	 0.01804	 0.0	 1743	 1743	 1743	 0.0	 0.0	 1	 -30.0	 30.0;
	7264	 8432	 0.00937	 0.073969	 0.0	 424	 424	 424	 0.0	 0.0	 1	 -30.0	 30.0;
	7264	 4629	 0.011081	 0.06593	 0.0	 473	 473	 473	 0.0	 0.0	 1	 -30.0	 30.0;
	7264	 4082	 0.009669	 0.04251	 0.0	 725	 725	 725	 0.0	 0.0	 1	 -30.0	 30.0;
	10124	 13346	 0.00073	 0.00713	 0.0	 4408	 4408	 4408	 0.0	 0.0	 1	 -30.0	 30.0;
	7678	 8008	 0.00034	 0.00345	 0.0	 9112	 9112	 9112	 0.0	 0.0	 1	 -30.0	 30.0;
	10910	 10320	 0.00012	 0.00128	 0.0	 24570	 24570	 24570	 0.0	 0.0	 1	 -30.0	 30.0;
	10910	 388	 0.00012	 0.00123	 0.0	 25560	 25560	 25560	 0.0	 0.0	 1	 -30.0	 30.0;
	2456	 2913	 9e-05	 0.00112	 0.0	 28113	 28113	 28113	 0.0	 0.0	 1	 -30.0	 30.0;
	1898	 1199	 0.00062	 0.00866	 0.0	 3639	 3639	 3639	 0.0	 0.0	 1	 -30.0	 30.0;
	10910	 1898	 0.00157	 0.01614	 0.0	 1948	 1948	 1948	 0.0	 0.0	 1	 -30.0	 30.0;
	10910	 1898	 0.0014	 0.01829	 0.0	 1722	 1722	 1722	 0.0	 0.0	 1	 -30.0	 30.0;
	430	 4014	 0.00078	 0.00805	 0.0	 3906	 3906	 3906	 0.0	 0.0	 1	 -30.0	 30.0;
	4014	 6044	 0.00094	 0.01427	 0.0	 2209	 2209	 2209	 0.0	 0.0	 1	 -30.0	 30.0;
	11378	 8008	 0.00024	 0.00283	 0.0	 11122	 11122	 11122	 0.0	 0.0	 1	 -30.0	 30.0;
	8008	 1199	 0.00099	 0.00865	 0.0	 3629	 3629	 3629	 0.0	 0.0	 1	 -30.0	 30.0;
	10910	 8008	 0.0011	 0.01426	 0.0	 2209	 2209	 2209	 0.0	 0.0	 1	 -30.0	 30.0;
	8432	 6284	 0.006919	 0.050521	 0.0	 620	 620	 620	 0.0	 0.0	 1	 -30.0	 30.0;
	5959	 7459	 0.0006	 0.00646	 0.0	 4869	 4869	 4869	 0.0	 0.0	 1	 -30.0	 30.0;
	5959	 8466	 0.00127	 0.0128	 0.0	 2456	 2456	 2456	 0.0	 0.0	 1	 -30.0	 30.0;
	5959	 13463	 0.00052	 0.00496	 0.0	 6334	 6334	 6334	 0.0	 0.0	 1	 -30.0	 30.0;
	5959	 11565	 0.00064	 0.00886	 0.0	 3556	 3556	 3556	 0.0	 0.0	 1	 -30.0	 30.0;
	5959	 11565	 0.00072	 0.00868	 0.0	 3627	 3627	 3627	 0.0	 0.0	 1	 -30.0	 30.0;
	430	 12141	 0.00232	 0.02522	 0.0	 1248	 1248	 1248	 0.0	 0.0	 1	 -30.0	 30.0;
	10910	 430	 0.0003	 0.00304	 0.0	 10341	 10341	 10341	 0.0	 0.0	 1	 -30.0	 30.0;
	10910	 430	 0.00032	 0.00306	 0.0	 10267	 10267	 10267	 0.0	 0.0	 1	 -30.0	 30.0;
	10910	 430	 0.00028	 0.00307	 0.0	 10247	 10247	 10247	 0.0	 0.0	 1	 -30.0	 30.0;
	13346	 11056	 0.00092	 0.00969	 0.0	 3246	 3246	 3246	 0.0	 0.0	 1	 -30.0	 30.0;
	13346	 8466	 0.00181	 0.01696	 0.0	 1852	 1852	 1852	 0.0	 0.0	 1	 -30.0	 30.0;
	13346	 9434	 0.00132	 0.01148	 0.0	 2734	 2734	 2734	 0.0	 0.0	 1	 -30.0	 30.0;
	11056	 6044	 0.00108	 0.01087	 0.0	 2892	 2892	 2892	 0.0	 0.0	 1	 -30.0	 30.0;
	7459	 12141	 0.00209	 0.01924	 0.0	 1633	 1633	 1633	 0.0	 0.0	 1	 -30.0	 30.0;
	13463	 7459	 0.00036	 0.00457	 0.0	 6891	 6891	 6891	 0.0	 0.0	 1	 -30.0	 30.0;
	7459	 2456	 0.0017	 0.01986	 0.0	 1585	 1585	 1585	 0.0	 0.0	 1	 -30.0	 30.0;
	1199	 3272	 0.00059	 0.00982	 0.0	 3211	 3211	 3211	 0.0	 0.0	 1	 -30.0	 30.0;
	6921	 4082	 0.00494	 0.03182	 0.0	 981	 981	 981	 0.0	 0.0	 1	 -30.0	 30.0;
	6921	 4082	 0.004841	 0.03245	 0.0	 963	 963	 963	 0.0	 0.0	 1	 -30.0	 30.0;
	6044	 9434	 0.00036	 0.00391	 0.0	 8045	 8045	 8045	 0.0	 0.0	 1	 -30.0	 30.0;
	11565	 2456	 0.00071	 0.00983	 0.0	 3206	 3206	 3206	 0.0	 0.0	 1	 -30.0	 30.0;
	11565	 2456	 0.00081	 0.00963	 0.0	 3269	 3269	 3269	 0.0	 0.0	 1	 -30.0	 30.0;
	7850	 1144	 0.006271	 0.03645	 0.0	 855	 855	 855	 0.0	 0.0	 1	 -30.0	 30.0;
	11323	 12959	 0.186281	 0.374281	 0.0	 76	 76	 76	 0.0	 0.0	 1	 -30.0	 30.0;
	11835	 12959	 0.089612	 0.230339	 0.0	 128	 128	 128	 0.0	 0.0	 1	 -30.0	 30.0;
	11561	 6149	 0.00393	 0.04552	 0.0	 692	 692	 692	 0.0	 0.0	 1	 -30.0	 30.0;
	5799	 8882	 0.004169	 0.02651	 0.0	 1178	 1178	 1178	 0.0	 0.0	 1	 -30.0	 30.0;
	5799	 8882	 0.003831	 0.02438	 0.0	 1280	 1280	 1280	 0.0	 0.0	 1	 -30.0	 30.0;
	5799	 7850	 0.00789	 0.04725	 0.0	 660	 660	 660	 0.0	 0.0	 1	 -30.0	 30.0;
	5799	 7850	 0.008039	 0.046219	 0.0	 674	 674	 674	 0.0	 0.0	 1	 -30.0	 30.0;
	1351	 3321	 0.040174	 0.084397	 0.0	 338	 338	 338	 0.0	 0.0	 1	 -30.0	 30.0;
	10826	 12633	 0.00166	 0.01276	 0.0	 2455	 2455	 2455	 0.0	 0.0	 1	 -30.0	 30.0;
	13474	 8882	 0.00094	 0.00599	 0.0	 5210	 5210	 5210	 0.0	 0.0	 1	 -30.0	 30.0;
	13474	 8882	 0.00107	 0.00587	 0.0	 5294	 5294	 5294	 0.0	 0.0	 1	 -30.0	 30.0;
	9599	 8560	 0.011901	 0.028364	 0.0	 1027	 1027	 1027	 0.0	 0.0	 1	 -30.0	 30.0;
	8560	 3321	 0.059091	 0.102636	 0.0	 267	 267	 267	 0.0	 0.0	 1	 -30.0	 30.0;
	11835	 8560	 0.090471	 0.19919	 0.0	 145	 145	 145	 0.0	 0.0	 1	 -30.0	 30.0;
	879	 2402	 0.00755	 0.050919	 0.0	 614	 614	 614	 0.0	 0.0	 1	 -30.0	 30.0;
	879	 2402	 0.0077	 0.04988	 0.0	 626	 626	 626	 0.0	 0.0	 1	 -30.0	 30.0;
	6231	 11323	 0.238893	 0.453901	 0.0	 62	 62	 62	 0.0	 0.0	 1	 -30.0	 30.0;
	657	 6231	 0.062719	 0.104479	 0.0	 260	 260	 260	 0.0	 0.0	 1	 -30.0	 30.0;
	7850	 2402	 0.000979	 0.074909	 0.0	 422	 422	 422	 0.0	 0.0	 1	 -30.0	 30.0;
	7850	 2402	 0.000961	 0.076349	 0.0	 414	 414	 414	 0.0	 0.0	 1	 -30.0	 30.0;
	7397	 2402	 0.002159	 0.079031	 0.0	 400	 400	 400	 0.0	 0.0	 1	 -30.0	 30.0;
	7397	 2402	 0.001961	 0.09125	 0.0	 347	 347	 347	 0.0	 0.0	 1	 -30.0	 30.0;
	657	 11323	 0.066636	 0.183934	 0.0	 162	 162	 162	 0.0	 0.0	 1	 -30.0	 30.0;
	6538	 10041	 0.00028	 0.00282	 0.0	 11147	 11147	 11147	 0.0	 0.0	 1	 -30.0	 30.0;
	6538	 8623	 0.00018	 0.00233	 0.0	 13517	 13517	 13517	 0.0	 0.0	 1	 -30.0	 30.0;
	1161	 7955	 4e-05	 0.0004	 0.0	 78577	 78577	 78577	 0.0	 0.0	 1	 -30.0	 30.0;
	1161	 8364	 0.0017	 0.01741	 0.0	 1806	 1806	 1806	 0.0	 0.0	 1	 -30.0	 30.0;
	1161	 8623	 0.00097	 0.0123	 0.0	 2561	 2561	 2561	 0.0	 0.0	 1	 -30.0	 30.0;
	1161	 2885	 0.00057	 0.00725	 0.0	 4344	 4344	 4344	 0.0	 0.0	 1	 -30.0	 30.0;
	7260	 7955	 0.00177	 0.01811	 0.0	 1736	 1736	 1736	 0.0	 0.0	 1	 -30.0	 30.0;
	7260	 10123	 0.00049	 0.00505	 0.0	 6226	 6226	 6226	 0.0	 0.0	 1	 -30.0	 30.0;
	7260	 9640	 0.00199	 0.02534	 0.0	 1243	 1243	 1243	 0.0	 0.0	 1	 -30.0	 30.0;
	7260	 10041	 0.00024	 0.00242	 0.0	 12989	 12989	 12989	 0.0	 0.0	 1	 -30.0	 30.0;
	781	 6831	 0.01379	 0.0443	 0.0	 681	 681	 681	 0.0	 0.0	 1	 -30.0	 30.0;
	781	 9251	 0.00615	 0.04848	 0.0	 647	 647	 647	 0.0	 0.0	 1	 -30.0	 30.0;
	781	 12787	 0.02224	 0.07142	 0.0	 423	 423	 423	 0.0	 0.0	 1	 -30.0	 30.0;
	781	 8335	 0.0084	 0.06621	 0.0	 474	 474	 474	 0.0	 0.0	 1	 -30.0	 30.0;
	11	 1019	 7e-05	 0.00068	 0.0	 46208	 46208	 46208	 0.0	 0.0	 1	 -30.0	 30.0;
	11	 9103	 0.00669	 0.05272	 0.0	 595	 595	 595	 0.0	 0.0	 1	 -30.0	 30.0;
	11	 12491	 0.003	 0.03068	 0.0	 1025	 1025	 1025	 0.0	 0.0	 1	 -30.0	 30.0;
	11	 12420	 0.01129	 0.05381	 0.0	 575	 575	 575	 0.0	 0.0	 1	 -30.0	 30.0;
	1019	 2379	 0.02312	 0.11021	 0.0	 281	 281	 281	 0.0	 0.0	 1	 -30.0	 30.0;
	1019	 12491	 0.0044	 0.03467	 0.0	 904	 904	 904	 0.0	 0.0	 1	 -30.0	 30.0;
	2379	 851	 0.00113	 0.00362	 0.0	 8330	 8330	 8330	 0.0	 0.0	 1	 -30.0	 30.0;
	2379	 851	 0.00113	 0.00362	 0.0	 8330	 8330	 8330	 0.0	 0.0	 1	 -30.0	 30.0;
	2379	 3392	 0.00603	 0.02877	 0.0	 1075	 1075	 1075	 0.0	 0.0	 1	 -30.0	 30.0;
	11825	 9103	 0.01127	 0.0691	 0.0	 452	 452	 452	 0.0	 0.0	 1	 -30.0	 30.0;
	11825	 214	 0.01447	 0.04647	 0.0	 650	 650	 650	 0.0	 0.0	 1	 -30.0	 30.0;
	11825	 6831	 0.00858	 0.06762	 0.0	 464	 464	 464	 0.0	 0.0	 1	 -30.0	 30.0;
	11825	 10797	 0.00026	 0.00161	 0.0	 19369	 19369	 19369	 0.0	 0.0	 1	 -30.0	 30.0;
	9103	 214	 0.0037	 0.02918	 0.0	 1074	 1074	 1074	 0.0	 0.0	 1	 -30.0	 30.0;
	9103	 11918	 0.00847	 0.0404	 0.0	 766	 766	 766	 0.0	 0.0	 1	 -30.0	 30.0;
	9103	 12974	 0.00026	 0.00161	 0.0	 19369	 19369	 19369	 0.0	 0.0	 1	 -30.0	 30.0;
	214	 12491	 0.00935	 0.03001	 0.0	 1005	 1005	 1005	 0.0	 0.0	 1	 -30.0	 30.0;
	214	 12491	 0.00553	 0.02634	 0.0	 1174	 1174	 1174	 0.0	 0.0	 1	 -30.0	 30.0;
	214	 6019	 0.00318	 0.0251	 0.0	 1249	 1249	 1249	 0.0	 0.0	 1	 -30.0	 30.0;
	214	 3392	 0.00689	 0.05429	 0.0	 578	 578	 578	 0.0	 0.0	 1	 -30.0	 30.0;
	10736	 3075	 0.00617	 0.02941	 0.0	 1052	 1052	 1052	 0.0	 0.0	 1	 -30.0	 30.0;
	10736	 9251	 0.00476	 0.0375	 0.0	 836	 836	 836	 0.0	 0.0	 1	 -30.0	 30.0;
	3075	 10550	 0.0157	 0.07482	 0.0	 414	 414	 414	 0.0	 0.0	 1	 -30.0	 30.0;
	4821	 11337	 0.02731	 0.08769	 0.0	 344	 344	 344	 0.0	 0.0	 1	 -30.0	 30.0;
	4821	 9339	 0.03423	 0.10993	 0.0	 275	 275	 275	 0.0	 0.0	 1	 -30.0	 30.0;
	6831	 9565	 0.00112	 0.01141	 0.0	 2756	 2756	 2756	 0.0	 0.0	 1	 -30.0	 30.0;
	6831	 6019	 0.00895	 0.07061	 0.0	 444	 444	 444	 0.0	 0.0	 1	 -30.0	 30.0;
	6831	 12089	 0.01187	 0.05656	 0.0	 547	 547	 547	 0.0	 0.0	 1	 -30.0	 30.0;
	3446	 9339	 0.00922	 0.04395	 0.0	 704	 704	 704	 0.0	 0.0	 1	 -30.0	 30.0;
	3446	 8335	 0.00995	 0.07845	 0.0	 400	 400	 400	 0.0	 0.0	 1	 -30.0	 30.0;
	10550	 12787	 0.01548	 0.04972	 0.0	 607	 607	 607	 0.0	 0.0	 1	 -30.0	 30.0;
	10550	 12089	 0.00339	 0.01616	 0.0	 1914	 1914	 1914	 0.0	 0.0	 1	 -30.0	 30.0;
	1856	 11918	 0.00851	 0.04056	 0.0	 763	 763	 763	 0.0	 0.0	 1	 -30.0	 30.0;
	9565	 10797	 0.0099	 0.06074	 0.0	 514	 514	 514	 0.0	 0.0	 1	 -30.0	 30.0;
	9339	 1654	 0.01001	 0.07892	 0.0	 398	 398	 398	 0.0	 0.0	 1	 -30.0	 30.0;
	9339	 8335	 0.01647	 0.07854	 0.0	 394	 394	 394	 0.0	 0.0	 1	 -30.0	 30.0;
	12491	 1654	 0.00392	 0.03091	 0.0	 1014	 1014	 1014	 0.0	 0.0	 1	 -30.0	 30.0;
	12420	 3392	 0.00603	 0.02877	 0.0	 1075	 1075	 1075	 0.0	 0.0	 1	 -30.0	 30.0;
	9313	 8364	 0.00043	 0.00443	 0.0	 7097	 7097	 7097	 0.0	 0.0	 1	 -30.0	 30.0;
	9640	 3730	 6e-05	 0.0008	 0.0	 39374	 39374	 39374	 0.0	 0.0	 1	 -30.0	 30.0;
	9640	 1187	 0.00029	 0.00366	 0.0	 8604	 8604	 8604	 0.0	 0.0	 1	 -30.0	 30.0;
	9640	 940	 0.00051	 0.00643	 0.0	 4898	 4898	 4898	 0.0	 0.0	 1	 -30.0	 30.0;
	9640	 9200	 0.00033	 0.00424	 0.0	 7428	 7428	 7428	 0.0	 0.0	 1	 -30.0	 30.0;
	8364	 5348	 0.00034	 0.00432	 0.0	 7290	 7290	 7290	 0.0	 0.0	 1	 -30.0	 30.0;
	8364	 13005	 0.00013	 0.00145	 0.0	 21698	 21698	 21698	 0.0	 0.0	 1	 -30.0	 30.0;
	8364	 1187	 0.00018	 0.00233	 0.0	 13517	 13517	 13517	 0.0	 0.0	 1	 -30.0	 30.0;
	5348	 11896	 0.00034	 0.00432	 0.0	 7290	 7290	 7290	 0.0	 0.0	 1	 -30.0	 30.0;
	5348	 6535	 0.00208	 0.02643	 0.0	 1192	 1192	 1192	 0.0	 0.0	 1	 -30.0	 30.0;
	5348	 10858	 0.00209	 0.0266	 0.0	 1184	 1184	 1184	 0.0	 0.0	 1	 -30.0	 30.0;
	5348	 2885	 0.00057	 0.00725	 0.0	 4344	 4344	 4344	 0.0	 0.0	 1	 -30.0	 30.0;
	11707	 9704	 0.00034	 0.00153	 0.0	 20154	 20154	 20154	 0.0	 0.0	 1	 -30.0	 30.0;
	11707	 9704	 0.00034	 0.00153	 0.0	 20154	 20154	 20154	 0.0	 0.0	 1	 -30.0	 30.0;
	13005	 1187	 8e-05	 0.00089	 0.0	 35349	 35349	 35349	 0.0	 0.0	 1	 -30.0	 30.0;
	13005	 12365	 6e-05	 0.00067	 0.0	 46958	 46958	 46958	 0.0	 0.0	 1	 -30.0	 30.0;
	9146	 7900	 0.00181	 0.01428	 0.0	 2195	 2195	 2195	 0.0	 0.0	 1	 -30.0	 30.0;
	9146	 7900	 0.00181	 0.01428	 0.0	 2195	 2195	 2195	 0.0	 0.0	 1	 -30.0	 30.0;
	9146	 4389	 0.00576	 0.03535	 0.0	 882	 882	 882	 0.0	 0.0	 1	 -30.0	 30.0;
	9146	 13288	 0.00576	 0.03535	 0.0	 882	 882	 882	 0.0	 0.0	 1	 -30.0	 30.0;
	9147	 7550	 0.00526	 0.02505	 0.0	 1235	 1235	 1235	 0.0	 0.0	 1	 -30.0	 30.0;
	9147	 7550	 0.00526	 0.02505	 0.0	 1235	 1235	 1235	 0.0	 0.0	 1	 -30.0	 30.0;
	9147	 12357	 0.00159	 0.01612	 0.0	 2343	 2343	 2343	 0.0	 0.0	 1	 -30.0	 30.0;
	9147	 12357	 0.00159	 0.01612	 0.0	 2343	 2343	 2343	 0.0	 0.0	 1	 -30.0	 30.0;
	9147	 3941	 0.00121	 0.01227	 0.0	 3078	 3078	 3078	 0.0	 0.0	 1	 -30.0	 30.0;
	9147	 3941	 0.00121	 0.01227	 0.0	 3078	 3078	 3078	 0.0	 0.0	 1	 -30.0	 30.0;
	10353	 1207	 0.00132	 0.0063	 0.0	 4908	 4908	 4908	 0.0	 0.0	 1	 -30.0	 30.0;
	7293	 4263	 0.0019	 0.00905	 0.0	 3416	 3416	 3416	 0.0	 0.0	 1	 -30.0	 30.0;
	7293	 4263	 0.0019	 0.00905	 0.0	 3416	 3416	 3416	 0.0	 0.0	 1	 -30.0	 30.0;
	7293	 2825	 0.00025	 0.00264	 0.0	 11912	 11912	 11912	 0.0	 0.0	 1	 -30.0	 30.0;
	7293	 2825	 0.0002	 0.00204	 0.0	 15411	 15411	 15411	 0.0	 0.0	 1	 -30.0	 30.0;
	7293	 1207	 0.00031	 0.00316	 0.0	 9949	 9949	 9949	 0.0	 0.0	 1	 -30.0	 30.0;
	7293	 5969	 0.00031	 0.00316	 0.0	 9949	 9949	 9949	 0.0	 0.0	 1	 -30.0	 30.0;
	7900	 3237	 0.00145	 0.01145	 0.0	 2737	 2737	 2737	 0.0	 0.0	 1	 -30.0	 30.0;
	7900	 13211	 0.00141	 0.01116	 0.0	 2809	 2809	 2809	 0.0	 0.0	 1	 -30.0	 30.0;
	9058	 10916	 0.00036	 0.00359	 0.0	 8755	 8755	 8755	 0.0	 0.0	 1	 -30.0	 30.0;
	9058	 10916	 0.00036	 0.00359	 0.0	 8755	 8755	 8755	 0.0	 0.0	 1	 -30.0	 30.0;
	3237	 13211	 0.00066	 0.00518	 0.0	 6050	 6050	 6050	 0.0	 0.0	 1	 -30.0	 30.0;
	11319	 8501	 0.00049	 0.00496	 0.0	 6338	 6338	 6338	 0.0	 0.0	 1	 -30.0	 30.0;
	11319	 3397	 0.00028	 0.00296	 0.0	 10624	 10624	 10624	 0.0	 0.0	 1	 -30.0	 30.0;
	11319	 9768	 0.00028	 0.00304	 0.0	 10347	 10347	 10347	 0.0	 0.0	 1	 -30.0	 30.0;
	3760	 7550	 0.00654	 0.03119	 0.0	 992	 992	 992	 0.0	 0.0	 1	 -30.0	 30.0;
	3760	 4971	 0.00108	 0.00517	 0.0	 5981	 5981	 5981	 0.0	 0.0	 1	 -30.0	 30.0;
	3760	 4971	 0.00108	 0.00517	 0.0	 5981	 5981	 5981	 0.0	 0.0	 1	 -30.0	 30.0;
	8501	 7747	 0.00119	 0.00941	 0.0	 3331	 3331	 3331	 0.0	 0.0	 1	 -30.0	 30.0;
	8501	 7747	 0.00119	 0.00941	 0.0	 3331	 3331	 3331	 0.0	 0.0	 1	 -30.0	 30.0;
	4389	 4970	 0.0061	 0.03744	 0.0	 833	 833	 833	 0.0	 0.0	 1	 -30.0	 30.0;
	4389	 4970	 0.0061	 0.03744	 0.0	 833	 833	 833	 0.0	 0.0	 1	 -30.0	 30.0;
	4389	 13288	 0.00052	 0.00321	 0.0	 9714	 9714	 9714	 0.0	 0.0	 1	 -30.0	 30.0;
	4970	 13211	 0.00298	 0.02354	 0.0	 1332	 1332	 1332	 0.0	 0.0	 1	 -30.0	 30.0;
	4970	 13211	 0.00298	 0.02354	 0.0	 1332	 1332	 1332	 0.0	 0.0	 1	 -30.0	 30.0;
	4970	 12811	 0.00298	 0.02354	 0.0	 1332	 1332	 1332	 0.0	 0.0	 1	 -30.0	 30.0;
	4970	 12811	 0.00298	 0.02354	 0.0	 1332	 1332	 1332	 0.0	 0.0	 1	 -30.0	 30.0;
	3399	 11944	 0.00026	 0.00267	 0.0	 11775	 11775	 11775	 0.0	 0.0	 1	 -30.0	 30.0;
	3399	 12634	 0.00021	 0.00224	 0.0	 14040	 14040	 14040	 0.0	 0.0	 1	 -30.0	 30.0;
	4971	 9576	 0.00173	 0.01365	 0.0	 2296	 2296	 2296	 0.0	 0.0	 1	 -30.0	 30.0;
	4971	 9576	 0.00173	 0.01365	 0.0	 2296	 2296	 2296	 0.0	 0.0	 1	 -30.0	 30.0;
	3397	 7747	 0.00037	 0.00401	 0.0	 7844	 7844	 7844	 0.0	 0.0	 1	 -30.0	 30.0;
	3397	 7747	 0.00037	 0.00401	 0.0	 7844	 7844	 7844	 0.0	 0.0	 1	 -30.0	 30.0;
	7747	 13511	 0.00073	 0.00744	 0.0	 4226	 4226	 4226	 0.0	 0.0	 1	 -30.0	 30.0;
	7747	 13511	 0.00073	 0.00744	 0.0	 4226	 4226	 4226	 0.0	 0.0	 1	 -30.0	 30.0;
	9159	 9704	 0.00031	 0.00329	 0.0	 9559	 9559	 9559	 0.0	 0.0	 1	 -30.0	 30.0;
	9159	 9704	 0.00025	 0.00254	 0.0	 12377	 12377	 12377	 0.0	 0.0	 1	 -30.0	 30.0;
	9159	 9113	 0.00031	 0.0031	 0.0	 10139	 10139	 10139	 0.0	 0.0	 1	 -30.0	 30.0;
	9159	 9113	 0.00031	 0.0031	 0.0	 10139	 10139	 10139	 0.0	 0.0	 1	 -30.0	 30.0;
	8950	 8037	 0.00034	 0.00108	 0.0	 27898	 27898	 27898	 0.0	 0.0	 1	 -30.0	 30.0;
	13499	 8037	 0.00042	 0.00449	 0.0	 7005	 7005	 7005	 0.0	 0.0	 1	 -30.0	 30.0;
	13499	 12634	 0.00025	 0.00248	 0.0	 12673	 12673	 12673	 0.0	 0.0	 1	 -30.0	 30.0;
	7703	 10667	 0.00119	 0.01202	 0.0	 2616	 2616	 2616	 0.0	 0.0	 1	 -30.0	 30.0;
	7703	 10667	 0.00119	 0.01202	 0.0	 2616	 2616	 2616	 0.0	 0.0	 1	 -30.0	 30.0;
	7703	 10916	 0.00034	 0.00341	 0.0	 9218	 9218	 9218	 0.0	 0.0	 1	 -30.0	 30.0;
	7703	 10916	 0.00034	 0.00341	 0.0	 9218	 9218	 9218	 0.0	 0.0	 1	 -30.0	 30.0;
	7480	 7788	 0.00034	 0.00369	 0.0	 8525	 8525	 8525	 0.0	 0.0	 1	 -30.0	 30.0;
	11944	 12634	 0.00053	 0.00569	 0.0	 5528	 5528	 5528	 0.0	 0.0	 1	 -30.0	 30.0;
	11944	 5969	 0.00336	 0.016	 0.0	 1933	 1933	 1933	 0.0	 0.0	 1	 -30.0	 30.0;
	10667	 3276	 0.00827	 0.03943	 0.0	 785	 785	 785	 0.0	 0.0	 1	 -30.0	 30.0;
	10667	 3276	 0.00827	 0.03943	 0.0	 785	 785	 785	 0.0	 0.0	 1	 -30.0	 30.0;
	12357	 10663	 0.00073	 0.00785	 0.0	 4813	 4813	 4813	 0.0	 0.0	 1	 -30.0	 30.0;
	12357	 3941	 0.00117	 0.00926	 0.0	 4028	 4028	 4028	 0.0	 0.0	 1	 -30.0	 30.0;
	10663	 12626	 0.00037	 0.00401	 0.0	 7844	 7844	 7844	 0.0	 0.0	 1	 -30.0	 30.0;
	3730	 12365	 0.00012	 0.00134	 0.0	 23479	 23479	 23479	 0.0	 0.0	 1	 -30.0	 30.0;
	11896	 2609	 0.00023	 0.00298	 0.0	 10569	 10569	 10569	 0.0	 0.0	 1	 -30.0	 30.0;
	2273	 5861	 0.00087	 0.01433	 0.0	 2201	 2201	 2201	 0.0	 0.0	 1	 -30.0	 30.0;
	2273	 5861	 0.00088	 0.01455	 0.0	 2167	 2167	 2167	 0.0	 0.0	 1	 -30.0	 30.0;
	2273	 12845	 0.00133	 0.01364	 0.0	 2305	 2305	 2305	 0.0	 0.0	 1	 -30.0	 30.0;
	2273	 7206	 0.00064	 0.00644	 0.0	 4881	 4881	 4881	 0.0	 0.0	 1	 -30.0	 30.0;
	2273	 10858	 0.00025	 0.00324	 0.0	 9721	 9721	 9721	 0.0	 0.0	 1	 -30.0	 30.0;
	2273	 12897	 0.00276	 0.02823	 0.0	 1114	 1114	 1114	 0.0	 0.0	 1	 -30.0	 30.0;
	2273	 2477	 0.00266	 0.02691	 0.0	 1169	 1169	 1169	 0.0	 0.0	 1	 -30.0	 30.0;
	2273	 9769	 0.00196	 0.01981	 0.0	 1587	 1587	 1587	 0.0	 0.0	 1	 -30.0	 30.0;
	2273	 7769	 0.0023	 0.03797	 0.0	 831	 831	 831	 0.0	 0.0	 1	 -30.0	 30.0;
	5861	 2609	 0.00027	 0.00344	 0.0	 9155	 9155	 9155	 0.0	 0.0	 1	 -30.0	 30.0;
	5861	 940	 0.00032	 0.00526	 0.0	 5995	 5995	 5995	 0.0	 0.0	 1	 -30.0	 30.0;
	5861	 7206	 0.001	 0.0101	 0.0	 3113	 3113	 3113	 0.0	 0.0	 1	 -30.0	 30.0;
	5861	 7166	 0.00017	 0.00279	 0.0	 11301	 11301	 11301	 0.0	 0.0	 1	 -30.0	 30.0;
	12845	 6535	 0.00097	 0.0123	 0.0	 2561	 2561	 2561	 0.0	 0.0	 1	 -30.0	 30.0;
	12845	 7209	 0.00228	 0.02898	 0.0	 1087	 1087	 1087	 0.0	 0.0	 1	 -30.0	 30.0;
	12845	 1652	 0.00269	 0.03425	 0.0	 920	 920	 920	 0.0	 0.0	 1	 -30.0	 30.0;
	12845	 10819	 0.00096	 0.00982	 0.0	 3202	 3202	 3202	 0.0	 0.0	 1	 -30.0	 30.0;
	2609	 10858	 0.00105	 0.01739	 0.0	 1814	 1814	 1814	 0.0	 0.0	 1	 -30.0	 30.0;
	2609	 9200	 0.00028	 0.00351	 0.0	 8971	 8971	 8971	 0.0	 0.0	 1	 -30.0	 30.0;
	940	 7166	 0.00017	 0.00279	 0.0	 11301	 11301	 11301	 0.0	 0.0	 1	 -30.0	 30.0;
	5268	 1828	 0.00278	 0.01325	 0.0	 2334	 2334	 2334	 0.0	 0.0	 1	 -30.0	 30.0;
	5268	 6730	 0.04068	 0.19392	 0.0	 160	 160	 160	 0.0	 0.0	 1	 -30.0	 30.0;
	1828	 9755	 0.01464	 0.04701	 0.0	 642	 642	 642	 0.0	 0.0	 1	 -30.0	 30.0;
	1828	 3756	 0.01526	 0.07272	 0.0	 426	 426	 426	 0.0	 0.0	 1	 -30.0	 30.0;
	1828	 8947	 0.02017	 0.09615	 0.0	 322	 322	 322	 0.0	 0.0	 1	 -30.0	 30.0;
	1828	 10083	 0.01254	 0.05979	 0.0	 518	 518	 518	 0.0	 0.0	 1	 -30.0	 30.0;
	9336	 12328	 0.0046	 0.03624	 0.0	 865	 865	 865	 0.0	 0.0	 1	 -30.0	 30.0;
	9336	 2860	 0.01993	 0.064	 0.0	 472	 472	 472	 0.0	 0.0	 1	 -30.0	 30.0;
	686	 1733	 0.00974	 0.03128	 0.0	 965	 965	 965	 0.0	 0.0	 1	 -30.0	 30.0;
	686	 2367	 0.01464	 0.04701	 0.0	 642	 642	 642	 0.0	 0.0	 1	 -30.0	 30.0;
	686	 6730	 0.04605	 0.14789	 0.0	 204	 204	 204	 0.0	 0.0	 1	 -30.0	 30.0;
	1733	 9882	 0.00287	 0.00922	 0.0	 3272	 3272	 3272	 0.0	 0.0	 1	 -30.0	 30.0;
	2889	 5975	 0.00308	 0.0315	 0.0	 999	 999	 999	 0.0	 0.0	 1	 -30.0	 30.0;
	2889	 7107	 0.00298	 0.02354	 0.0	 1332	 1332	 1332	 0.0	 0.0	 1	 -30.0	 30.0;
	3855	 2565	 0.0033	 0.02605	 0.0	 1203	 1203	 1203	 0.0	 0.0	 1	 -30.0	 30.0;
	3855	 7001	 0.00239	 0.02444	 0.0	 1287	 1287	 1287	 0.0	 0.0	 1	 -30.0	 30.0;
	3855	 11937	 0.0003	 0.00312	 0.0	 10078	 10078	 10078	 0.0	 0.0	 1	 -30.0	 30.0;
	3855	 6308	 0.00318	 0.0251	 0.0	 1249	 1249	 1249	 0.0	 0.0	 1	 -30.0	 30.0;
	1258	 6292	 0.00043	 0.00434	 0.0	 7243	 7243	 7243	 0.0	 0.0	 1	 -30.0	 30.0;
	1258	 1498	 0.00259	 0.0204	 0.0	 1537	 1537	 1537	 0.0	 0.0	 1	 -30.0	 30.0;
	2565	 11879	 0.00305	 0.01454	 0.0	 2127	 2127	 2127	 0.0	 0.0	 1	 -30.0	 30.0;
	2565	 11879	 0.00305	 0.01454	 0.0	 2127	 2127	 2127	 0.0	 0.0	 1	 -30.0	 30.0;
	2565	 7107	 0.00119	 0.00941	 0.0	 3331	 3331	 3331	 0.0	 0.0	 1	 -30.0	 30.0;
	9755	 12328	 0.02353	 0.07557	 0.0	 400	 400	 400	 0.0	 0.0	 1	 -30.0	 30.0;
	7798	 13453	 0.00306	 0.02416	 0.0	 1298	 1298	 1298	 0.0	 0.0	 1	 -30.0	 30.0;
	7798	 1124	 0.00398	 0.03138	 0.0	 999	 999	 999	 0.0	 0.0	 1	 -30.0	 30.0;
	1860	 12328	 0.01471	 0.07013	 0.0	 441	 441	 441	 0.0	 0.0	 1	 -30.0	 30.0;
	391	 7991	 0.00325	 0.03326	 0.0	 946	 946	 946	 0.0	 0.0	 1	 -30.0	 30.0;
	391	 7627	 0.0006	 0.00607	 0.0	 5179	 5179	 5179	 0.0	 0.0	 1	 -30.0	 30.0;
	391	 7001	 0.00146	 0.01493	 0.0	 2106	 2106	 2106	 0.0	 0.0	 1	 -30.0	 30.0;
	391	 8408	 0.00061	 0.0062	 0.0	 5071	 5071	 5071	 0.0	 0.0	 1	 -30.0	 30.0;
	391	 555	 0.00075	 0.00356	 0.0	 8683	 8683	 8683	 0.0	 0.0	 1	 -30.0	 30.0;
	8925	 7715	 0.00921	 0.0305	 0.0	 992	 992	 992	 0.0	 0.0	 1	 -30.0	 30.0;
	2367	 12328	 0.01233	 0.0396	 0.0	 762	 762	 762	 0.0	 0.0	 1	 -30.0	 30.0;
	12689	 5556	 0.0117	 0.05575	 0.0	 555	 555	 555	 0.0	 0.0	 1	 -30.0	 30.0;
	12689	 5556	 0.0117	 0.05575	 0.0	 555	 555	 555	 0.0	 0.0	 1	 -30.0	 30.0;
	12689	 1760	 0.00169	 0.00808	 0.0	 3827	 3827	 3827	 0.0	 0.0	 1	 -30.0	 30.0;
	12689	 4034	 0.00235	 0.01851	 0.0	 1693	 1693	 1693	 0.0	 0.0	 1	 -30.0	 30.0;
	12689	 4034	 0.00235	 0.01851	 0.0	 1693	 1693	 1693	 0.0	 0.0	 1	 -30.0	 30.0;
	12689	 1124	 0.00119	 0.00941	 0.0	 3331	 3331	 3331	 0.0	 0.0	 1	 -30.0	 30.0;
	12689	 1124	 0.00119	 0.00941	 0.0	 3331	 3331	 3331	 0.0	 0.0	 1	 -30.0	 30.0;
	11587	 5891	 0.00046	 0.00497	 0.0	 6329	 6329	 6329	 0.0	 0.0	 1	 -30.0	 30.0;
	5975	 7991	 0.00024	 0.00188	 0.0	 16667	 16667	 16667	 0.0	 0.0	 1	 -30.0	 30.0;
	12609	 3756	 0.01288	 0.06141	 0.0	 504	 504	 504	 0.0	 0.0	 1	 -30.0	 30.0;
	12609	 6730	 0.02105	 0.10035	 0.0	 309	 309	 309	 0.0	 0.0	 1	 -30.0	 30.0;
	10066	 11937	 0.001	 0.00785	 0.0	 3992	 3992	 3992	 0.0	 0.0	 1	 -30.0	 30.0;
	10066	 6308	 0.008	 0.06307	 0.0	 497	 497	 497	 0.0	 0.0	 1	 -30.0	 30.0;
	1674	 473	 0.00046	 0.00497	 0.0	 6329	 6329	 6329	 0.0	 0.0	 1	 -30.0	 30.0;
	1674	 10641	 0.00034	 0.0036	 0.0	 8736	 8736	 8736	 0.0	 0.0	 1	 -30.0	 30.0;
	6787	 6308	 0.01068	 0.0509	 0.0	 608	 608	 608	 0.0	 0.0	 1	 -30.0	 30.0;
	6787	 13501	 0.00475	 0.02262	 0.0	 1367	 1367	 1367	 0.0	 0.0	 1	 -30.0	 30.0;
	4538	 555	 0.00022	 0.0024	 0.0	 13107	 13107	 13107	 0.0	 0.0	 1	 -30.0	 30.0;
	4538	 1741	 0.00054	 0.00259	 0.0	 11940	 11940	 11940	 0.0	 0.0	 1	 -30.0	 30.0;
	473	 6013	 0.00041	 0.00441	 0.0	 7132	 7132	 7132	 0.0	 0.0	 1	 -30.0	 30.0;
	473	 6013	 0.00041	 0.00441	 0.0	 7132	 7132	 7132	 0.0	 0.0	 1	 -30.0	 30.0;
	473	 10641	 0.00031	 0.0031	 0.0	 10139	 10139	 10139	 0.0	 0.0	 1	 -30.0	 30.0;
	473	 4583	 0.00259	 0.0204	 0.0	 1537	 1537	 1537	 0.0	 0.0	 1	 -30.0	 30.0;
	13458	 11396	 0.0044	 0.03467	 0.0	 904	 904	 904	 0.0	 0.0	 1	 -30.0	 30.0;
	13458	 5556	 0.01353	 0.10669	 0.0	 294	 294	 294	 0.0	 0.0	 1	 -30.0	 30.0;
	9720	 5556	 0.01736	 0.08274	 0.0	 374	 374	 374	 0.0	 0.0	 1	 -30.0	 30.0;
	9720	 5556	 0.01736	 0.08274	 0.0	 374	 374	 374	 0.0	 0.0	 1	 -30.0	 30.0;
	5891	 10641	 0.00034	 0.0036	 0.0	 8736	 8736	 8736	 0.0	 0.0	 1	 -30.0	 30.0;
	7627	 7466	 0.00035	 0.00353	 0.0	 8905	 8905	 8905	 0.0	 0.0	 1	 -30.0	 30.0;
	7627	 7466	 0.00035	 0.00353	 0.0	 8905	 8905	 8905	 0.0	 0.0	 1	 -30.0	 30.0;
	13453	 1124	 0.00131	 0.01036	 0.0	 3025	 3025	 3025	 0.0	 0.0	 1	 -30.0	 30.0;
	6535	 10858	 1.5e-05	 0.000199	 0.0	 158282	 158282	 158282	 0.0	 0.0	 1	 -30.0	 30.0;
	11396	 5556	 0.00637	 0.05021	 0.0	 625	 625	 625	 0.0	 0.0	 1	 -30.0	 30.0;
	5556	 7715	 0.0105	 0.03466	 0.0	 873	 873	 873	 0.0	 0.0	 1	 -30.0	 30.0;
	6308	 13501	 0.01576	 0.07514	 0.0	 412	 412	 412	 0.0	 0.0	 1	 -30.0	 30.0;
	6308	 1498	 0.00112	 0.01202	 0.0	 2617	 2617	 2617	 0.0	 0.0	 1	 -30.0	 30.0;
	5798	 4034	 0.00028	 0.0009	 0.0	 33513	 33513	 33513	 0.0	 0.0	 1	 -30.0	 30.0;
	9882	 12564	 0.0165	 0.05297	 0.0	 570	 570	 570	 0.0	 0.0	 1	 -30.0	 30.0;
	7206	 12897	 0.00233	 0.02385	 0.0	 1319	 1319	 1319	 0.0	 0.0	 1	 -30.0	 30.0;
	4034	 3861	 0.00547	 0.04315	 0.0	 727	 727	 727	 0.0	 0.0	 1	 -30.0	 30.0;
	4034	 3861	 0.00547	 0.04315	 0.0	 727	 727	 727	 0.0	 0.0	 1	 -30.0	 30.0;
	10858	 7769	 0.00219	 0.03613	 0.0	 873	 873	 873	 0.0	 0.0	 1	 -30.0	 30.0;
	12809	 12897	 0.00032	 0.00326	 0.0	 9644	 9644	 9644	 0.0	 0.0	 1	 -30.0	 30.0;
	12809	 2683	 0.00215	 0.022	 0.0	 1429	 1429	 1429	 0.0	 0.0	 1	 -30.0	 30.0;
	12809	 10885	 0.00173	 0.01767	 0.0	 1780	 1780	 1780	 0.0	 0.0	 1	 -30.0	 30.0;
	7910	 12801	 0.00318	 0.0251	 0.0	 1249	 1249	 1249	 0.0	 0.0	 1	 -30.0	 30.0;
	7910	 6125	 0.00497	 0.03923	 0.0	 799	 799	 799	 0.0	 0.0	 1	 -30.0	 30.0;
	7910	 10089	 0.00199	 0.01569	 0.0	 1998	 1998	 1998	 0.0	 0.0	 1	 -30.0	 30.0;
	7218	 799	 0.00147	 0.01161	 0.0	 2700	 2700	 2700	 0.0	 0.0	 1	 -30.0	 30.0;
	7218	 10277	 0.00511	 0.04032	 0.0	 778	 778	 778	 0.0	 0.0	 1	 -30.0	 30.0;
	13373	 12437	 0.00103	 0.00816	 0.0	 3841	 3841	 3841	 0.0	 0.0	 1	 -30.0	 30.0;
	13373	 1628	 0.00139	 0.01098	 0.0	 2855	 2855	 2855	 0.0	 0.0	 1	 -30.0	 30.0;
	13373	 2042	 0.00298	 0.02354	 0.0	 1332	 1332	 1332	 0.0	 0.0	 1	 -30.0	 30.0;
	12437	 2042	 0.00199	 0.01569	 0.0	 1998	 1998	 1998	 0.0	 0.0	 1	 -30.0	 30.0;
	6783	 12292	 0.01132	 0.05397	 0.0	 573	 573	 573	 0.0	 0.0	 1	 -30.0	 30.0;
	6783	 9026	 0.00358	 0.02824	 0.0	 1110	 1110	 1110	 0.0	 0.0	 1	 -30.0	 30.0;
	6783	 3930	 0.00085	 0.00404	 0.0	 7652	 7652	 7652	 0.0	 0.0	 1	 -30.0	 30.0;
	6783	 12801	 0.00358	 0.02824	 0.0	 1110	 1110	 1110	 0.0	 0.0	 1	 -30.0	 30.0;
	6783	 12801	 0.00358	 0.02824	 0.0	 1110	 1110	 1110	 0.0	 0.0	 1	 -30.0	 30.0;
	11052	 11710	 0.00086	 0.0053	 0.0	 5883	 5883	 5883	 0.0	 0.0	 1	 -30.0	 30.0;
	11052	 11710	 0.00086	 0.0053	 0.0	 5883	 5883	 5883	 0.0	 0.0	 1	 -30.0	 30.0;
	11052	 10277	 0.00219	 0.01726	 0.0	 1816	 1816	 1816	 0.0	 0.0	 1	 -30.0	 30.0;
	11052	 2152	 0.00505	 0.02408	 0.0	 1284	 1284	 1284	 0.0	 0.0	 1	 -30.0	 30.0;
	799	 5865	 0.00402	 0.03169	 0.0	 989	 989	 989	 0.0	 0.0	 1	 -30.0	 30.0;
	799	 9036	 0.00468	 0.03687	 0.0	 850	 850	 850	 0.0	 0.0	 1	 -30.0	 30.0;
	799	 9036	 0.00468	 0.03687	 0.0	 850	 850	 850	 0.0	 0.0	 1	 -30.0	 30.0;
	799	 10277	 0.00643	 0.05068	 0.0	 619	 619	 619	 0.0	 0.0	 1	 -30.0	 30.0;
	799	 8947	 0.04025	 0.12927	 0.0	 234	 234	 234	 0.0	 0.0	 1	 -30.0	 30.0;
	5865	 10277	 0.00302	 0.02385	 0.0	 1314	 1314	 1314	 0.0	 0.0	 1	 -30.0	 30.0;
	160	 3936	 0.01417	 0.06755	 0.0	 458	 458	 458	 0.0	 0.0	 1	 -30.0	 30.0;
	160	 5942	 0.01503	 0.04827	 0.0	 625	 625	 625	 0.0	 0.0	 1	 -30.0	 30.0;
	160	 12292	 0.02556	 0.12185	 0.0	 254	 254	 254	 0.0	 0.0	 1	 -30.0	 30.0;
	3861	 9036	 0.02618	 0.08407	 0.0	 359	 359	 359	 0.0	 0.0	 1	 -30.0	 30.0;
	3936	 12292	 0.01105	 0.05268	 0.0	 587	 587	 587	 0.0	 0.0	 1	 -30.0	 30.0;
	5942	 9711	 0.00788	 0.06213	 0.0	 505	 505	 505	 0.0	 0.0	 1	 -30.0	 30.0;
	5942	 9026	 0.00298	 0.02354	 0.0	 1332	 1332	 1332	 0.0	 0.0	 1	 -30.0	 30.0;
	5942	 1628	 0.00199	 0.01569	 0.0	 1998	 1998	 1998	 0.0	 0.0	 1	 -30.0	 30.0;
	6706	 12292	 0.02098	 0.10003	 0.0	 310	 310	 310	 0.0	 0.0	 1	 -30.0	 30.0;
	6706	 3257	 0.00793	 0.03781	 0.0	 818	 818	 818	 0.0	 0.0	 1	 -30.0	 30.0;
	12292	 3930	 0.01136	 0.05414	 0.0	 572	 572	 572	 0.0	 0.0	 1	 -30.0	 30.0;
	12292	 3257	 0.02597	 0.12379	 0.0	 250	 250	 250	 0.0	 0.0	 1	 -30.0	 30.0;
	9711	 8947	 0.02004	 0.06436	 0.0	 469	 469	 469	 0.0	 0.0	 1	 -30.0	 30.0;
	12897	 8508	 0.00229	 0.02909	 0.0	 1083	 1083	 1083	 0.0	 0.0	 1	 -30.0	 30.0;
	9026	 1628	 0.00338	 0.02667	 0.0	 1175	 1175	 1175	 0.0	 0.0	 1	 -30.0	 30.0;
	9026	 1628	 0.00338	 0.02667	 0.0	 1175	 1175	 1175	 0.0	 0.0	 1	 -30.0	 30.0;
	12801	 10089	 0.00298	 0.02354	 0.0	 1332	 1332	 1332	 0.0	 0.0	 1	 -30.0	 30.0;
	6125	 3257	 0.01407	 0.0452	 0.0	 668	 668	 668	 0.0	 0.0	 1	 -30.0	 30.0;
	2683	 3973	 0.00128	 0.01308	 0.0	 2404	 2404	 2404	 0.0	 0.0	 1	 -30.0	 30.0;
	5044	 2226	 0.00438	 0.03452	 0.0	 908	 908	 908	 0.0	 0.0	 1	 -30.0	 30.0;
	5044	 13574	 0.01992	 0.15706	 0.0	 200	 200	 200	 0.0	 0.0	 1	 -30.0	 30.0;
	5044	 3257	 0.03389	 0.10884	 0.0	 278	 278	 278	 0.0	 0.0	 1	 -30.0	 30.0;
	5044	 1690	 0.01313	 0.10355	 0.0	 303	 303	 303	 0.0	 0.0	 1	 -30.0	 30.0;
	5044	 11788	 0.00557	 0.04393	 0.0	 714	 714	 714	 0.0	 0.0	 1	 -30.0	 30.0;
	2226	 4867	 0.01008	 0.03236	 0.0	 932	 932	 932	 0.0	 0.0	 1	 -30.0	 30.0;
	2226	 12783	 0.01493	 0.11768	 0.0	 267	 267	 267	 0.0	 0.0	 1	 -30.0	 30.0;
	4867	 10061	 0.03074	 0.09872	 0.0	 306	 306	 306	 0.0	 0.0	 1	 -30.0	 30.0;
	4867	 10061	 0.04301	 0.13813	 0.0	 219	 219	 219	 0.0	 0.0	 1	 -30.0	 30.0;
	6791	 10139	 0.01407	 0.0452	 0.0	 668	 668	 668	 0.0	 0.0	 1	 -30.0	 30.0;
	6791	 3257	 0.02883	 0.09257	 0.0	 326	 326	 326	 0.0	 0.0	 1	 -30.0	 30.0;
	6791	 1690	 0.00796	 0.06276	 0.0	 500	 500	 500	 0.0	 0.0	 1	 -30.0	 30.0;
	6791	 10003	 0.0045	 0.01446	 0.0	 2086	 2086	 2086	 0.0	 0.0	 1	 -30.0	 30.0;
	10139	 2535	 0.01712	 0.05496	 0.0	 549	 549	 549	 0.0	 0.0	 1	 -30.0	 30.0;
	13085	 13574	 0.02573	 0.08263	 0.0	 365	 365	 365	 0.0	 0.0	 1	 -30.0	 30.0;
	13085	 2535	 0.05152	 0.16543	 0.0	 183	 183	 183	 0.0	 0.0	 1	 -30.0	 30.0;
	13574	 5266	 0.01871	 0.11474	 0.0	 272	 272	 272	 0.0	 0.0	 1	 -30.0	 30.0;
	13574	 11932	 0.05489	 0.17628	 0.0	 172	 172	 172	 0.0	 0.0	 1	 -30.0	 30.0;
	13574	 1690	 0.01186	 0.09351	 0.0	 336	 336	 336	 0.0	 0.0	 1	 -30.0	 30.0;
	13574	 7868	 0.00169	 0.01334	 0.0	 2350	 2350	 2350	 0.0	 0.0	 1	 -30.0	 30.0;
	13574	 7868	 0.00169	 0.01334	 0.0	 2350	 2350	 2350	 0.0	 0.0	 1	 -30.0	 30.0;
	5266	 263	 0.00811	 0.02603	 0.0	 1159	 1159	 1159	 0.0	 0.0	 1	 -30.0	 30.0;
	5266	 10758	 0.00034	 0.00162	 0.0	 19083	 19083	 19083	 0.0	 0.0	 1	 -30.0	 30.0;
	5266	 10758	 0.00034	 0.00162	 0.0	 19083	 19083	 19083	 0.0	 0.0	 1	 -30.0	 30.0;
	11932	 263	 0.00736	 0.05805	 0.0	 540	 540	 540	 0.0	 0.0	 1	 -30.0	 30.0;
	13396	 12783	 0.01094	 0.0863	 0.0	 364	 364	 364	 0.0	 0.0	 1	 -30.0	 30.0;
	13396	 263	 0.01214	 0.09571	 0.0	 328	 328	 328	 0.0	 0.0	 1	 -30.0	 30.0;
	12783	 3623	 0.00895	 0.07061	 0.0	 444	 444	 444	 0.0	 0.0	 1	 -30.0	 30.0;
	12783	 1280	 0.03063	 0.09836	 0.0	 307	 307	 307	 0.0	 0.0	 1	 -30.0	 30.0;
	8508	 3973	 0.00242	 0.03076	 0.0	 1024	 1024	 1024	 0.0	 0.0	 1	 -30.0	 30.0;
	7720	 10885	 0.00083	 0.00845	 0.0	 3721	 3721	 3721	 0.0	 0.0	 1	 -30.0	 30.0;
	7720	 6700	 0.0056	 0.05722	 0.0	 550	 550	 550	 0.0	 0.0	 1	 -30.0	 30.0;
	7720	 8641	 0.0036	 0.03646	 0.0	 863	 863	 863	 0.0	 0.0	 1	 -30.0	 30.0;
	7720	 13258	 0.001	 0.0101	 0.0	 3113	 3113	 3113	 0.0	 0.0	 1	 -30.0	 30.0;
	3993	 7364	 0.02308	 0.07413	 0.0	 407	 407	 407	 0.0	 0.0	 1	 -30.0	 30.0;
	3993	 11555	 0.01683	 0.05406	 0.0	 558	 558	 558	 0.0	 0.0	 1	 -30.0	 30.0;
	9833	 8481	 0.03322	 0.10667	 0.0	 283	 283	 283	 0.0	 0.0	 1	 -30.0	 30.0;
	9833	 8930	 0.01094	 0.0863	 0.0	 364	 364	 364	 0.0	 0.0	 1	 -30.0	 30.0;
	11788	 8464	 0.01546	 0.07369	 0.0	 420	 420	 420	 0.0	 0.0	 1	 -30.0	 30.0;
	13430	 8947	 0.00526	 0.02505	 0.0	 1235	 1235	 1235	 0.0	 0.0	 1	 -30.0	 30.0;
	13430	 6786	 0.02898	 0.13817	 0.0	 224	 224	 224	 0.0	 0.0	 1	 -30.0	 30.0;
	12288	 7255	 0.01773	 0.08452	 0.0	 366	 366	 366	 0.0	 0.0	 1	 -30.0	 30.0;
	12288	 7172	 0.01368	 0.04393	 0.0	 687	 687	 687	 0.0	 0.0	 1	 -30.0	 30.0;
	12288	 1551	 0.02365	 0.07594	 0.0	 398	 398	 398	 0.0	 0.0	 1	 -30.0	 30.0;
	12288	 10601	 0.00078	 0.00372	 0.0	 8311	 8311	 8311	 0.0	 0.0	 1	 -30.0	 30.0;
	12288	 10601	 0.00078	 0.00372	 0.0	 8311	 8311	 8311	 0.0	 0.0	 1	 -30.0	 30.0;
	7364	 5941	 0.02759	 0.08859	 0.0	 341	 341	 341	 0.0	 0.0	 1	 -30.0	 30.0;
	6782	 12236	 0.01576	 0.05062	 0.0	 596	 596	 596	 0.0	 0.0	 1	 -30.0	 30.0;
	8464	 13630	 0.02664	 0.12702	 0.0	 244	 244	 244	 0.0	 0.0	 1	 -30.0	 30.0;
	12670	 13630	 0.02162	 0.06943	 0.0	 435	 435	 435	 0.0	 0.0	 1	 -30.0	 30.0;
	12670	 6986	 0.03187	 0.10233	 0.0	 295	 295	 295	 0.0	 0.0	 1	 -30.0	 30.0;
	7907	 11555	 0.02168	 0.06961	 0.0	 434	 434	 434	 0.0	 0.0	 1	 -30.0	 30.0;
	11555	 6786	 0.03827	 0.18245	 0.0	 170	 170	 170	 0.0	 0.0	 1	 -30.0	 30.0;
	11555	 6771	 0.01465	 0.06981	 0.0	 443	 443	 443	 0.0	 0.0	 1	 -30.0	 30.0;
	11555	 1551	 0.00661	 0.05209	 0.0	 602	 602	 602	 0.0	 0.0	 1	 -30.0	 30.0;
	11555	 1551	 0.00782	 0.06166	 0.0	 509	 509	 509	 0.0	 0.0	 1	 -30.0	 30.0;
	5941	 7255	 0.0366	 0.11752	 0.0	 257	 257	 257	 0.0	 0.0	 1	 -30.0	 30.0;
	8481	 8638	 0.00326	 0.01049	 0.0	 2876	 2876	 2876	 0.0	 0.0	 1	 -30.0	 30.0;
	8481	 8638	 0.00326	 0.01049	 0.0	 2876	 2876	 2876	 0.0	 0.0	 1	 -30.0	 30.0;
	8481	 8638	 0.00326	 0.01049	 0.0	 2876	 2876	 2876	 0.0	 0.0	 1	 -30.0	 30.0;
	8481	 7255	 0.00732	 0.03491	 0.0	 886	 886	 886	 0.0	 0.0	 1	 -30.0	 30.0;
	8481	 7255	 0.00732	 0.03491	 0.0	 886	 886	 886	 0.0	 0.0	 1	 -30.0	 30.0;
	8481	 13630	 0.03063	 0.09836	 0.0	 307	 307	 307	 0.0	 0.0	 1	 -30.0	 30.0;
	8481	 13630	 0.03063	 0.09836	 0.0	 307	 307	 307	 0.0	 0.0	 1	 -30.0	 30.0;
	8947	 7172	 0.01768	 0.05677	 0.0	 532	 532	 532	 0.0	 0.0	 1	 -30.0	 30.0;
	8947	 6786	 0.03438	 0.16386	 0.0	 189	 189	 189	 0.0	 0.0	 1	 -30.0	 30.0;
	8947	 10083	 0.01017	 0.04848	 0.0	 638	 638	 638	 0.0	 0.0	 1	 -30.0	 30.0;
	10397	 6786	 0.0	 0.04891	 0.0	 646	 646	 646	 0.0	 0.0	 1	 -30.0	 30.0;
	10397	 13630	 0.00081	 0.00388	 0.0	 7970	 7970	 7970	 0.0	 0.0	 1	 -30.0	 30.0;
	10397	 13630	 0.00081	 0.00388	 0.0	 7970	 7970	 7970	 0.0	 0.0	 1	 -30.0	 30.0;
	6786	 1551	 0.03824	 0.18228	 0.0	 170	 170	 170	 0.0	 0.0	 1	 -30.0	 30.0;
	6986	 12236	 0.02207	 0.07087	 0.0	 426	 426	 426	 0.0	 0.0	 1	 -30.0	 30.0;
	6986	 10244	 0.0165	 0.05297	 0.0	 570	 570	 570	 0.0	 0.0	 1	 -30.0	 30.0;
	8778	 6700	 0.00094	 0.00958	 0.0	 3282	 3282	 3282	 0.0	 0.0	 1	 -30.0	 30.0;
	8778	 3808	 0.0009	 0.01147	 0.0	 2746	 2746	 2746	 0.0	 0.0	 1	 -30.0	 30.0;
	8778	 12251	 2e-05	 0.00026	 0.0	 121132	 121132	 121132	 0.0	 0.0	 1	 -30.0	 30.0;
	8778	 12251	 2e-05	 0.00026	 0.0	 121132	 121132	 121132	 0.0	 0.0	 1	 -30.0	 30.0;
	8778	 3973	 0.00162	 0.01656	 0.0	 1899	 1899	 1899	 0.0	 0.0	 1	 -30.0	 30.0;
	8778	 3841	 0.00039	 0.00641	 0.0	 4919	 4919	 4919	 0.0	 0.0	 1	 -30.0	 30.0;
	6700	 3841	 0.00027	 0.00444	 0.0	 7102	 7102	 7102	 0.0	 0.0	 1	 -30.0	 30.0;
	6700	 1297	 0.00288	 0.02946	 0.0	 1068	 1068	 1068	 0.0	 0.0	 1	 -30.0	 30.0;
	6700	 1297	 0.00192	 0.02444	 0.0	 1289	 1289	 1289	 0.0	 0.0	 1	 -30.0	 30.0;
	3808	 12975	 0.00094	 0.01197	 0.0	 2631	 2631	 2631	 0.0	 0.0	 1	 -30.0	 30.0;
	3808	 5794	 0.00106	 0.01087	 0.0	 2893	 2893	 2893	 0.0	 0.0	 1	 -30.0	 30.0;
	2776	 7815	 0.00677	 0.05335	 0.0	 588	 588	 588	 0.0	 0.0	 1	 -30.0	 30.0;
	2776	 7815	 0.00677	 0.05335	 0.0	 588	 588	 588	 0.0	 0.0	 1	 -30.0	 30.0;
	7117	 716	 0.00051	 0.00242	 0.0	 12773	 12773	 12773	 0.0	 0.0	 1	 -30.0	 30.0;
	7117	 716	 0.00051	 0.00242	 0.0	 12773	 12773	 12773	 0.0	 0.0	 1	 -30.0	 30.0;
	7117	 8590	 0.00026	 0.00204	 0.0	 15360	 15360	 15360	 0.0	 0.0	 1	 -30.0	 30.0;
	7117	 8590	 0.00026	 0.00204	 0.0	 15360	 15360	 15360	 0.0	 0.0	 1	 -30.0	 30.0;
	9735	 716	 0.00139	 0.00663	 0.0	 4663	 4663	 4663	 0.0	 0.0	 1	 -30.0	 30.0;
	9735	 716	 0.00139	 0.00663	 0.0	 4663	 4663	 4663	 0.0	 0.0	 1	 -30.0	 30.0;
	9735	 8590	 0.00075	 0.00356	 0.0	 8683	 8683	 8683	 0.0	 0.0	 1	 -30.0	 30.0;
	9735	 8590	 0.00075	 0.00356	 0.0	 8683	 8683	 8683	 0.0	 0.0	 1	 -30.0	 30.0;
	6152	 11207	 0.00321	 0.03286	 0.0	 957	 957	 957	 0.0	 0.0	 1	 -30.0	 30.0;
	6152	 11207	 0.00321	 0.03286	 0.0	 957	 957	 957	 0.0	 0.0	 1	 -30.0	 30.0;
	11427	 7357	 0.01875	 0.06021	 0.0	 501	 501	 501	 0.0	 0.0	 1	 -30.0	 30.0;
	11427	 10988	 0.02489	 0.07991	 0.0	 378	 378	 378	 0.0	 0.0	 1	 -30.0	 30.0;
	13613	 3920	 0.00115	 0.0091	 0.0	 3444	 3444	 3444	 0.0	 0.0	 1	 -30.0	 30.0;
	13613	 1712	 0.00037	 0.00164	 0.0	 18789	 18789	 18789	 0.0	 0.0	 1	 -30.0	 30.0;
	13613	 5870	 0.00082	 0.00881	 0.0	 3570	 3570	 3570	 0.0	 0.0	 1	 -30.0	 30.0;
	13613	 497	 0.001	 0.00785	 0.0	 3992	 3992	 3992	 0.0	 0.0	 1	 -30.0	 30.0;
	13613	 10316	 0.00043	 0.00465	 0.0	 6765	 6765	 6765	 0.0	 0.0	 1	 -30.0	 30.0;
	7402	 8046	 0.00045	 0.00203	 0.0	 15192	 15192	 15192	 0.0	 0.0	 1	 -30.0	 30.0;
	7402	 11465	 0.00028	 0.00304	 0.0	 10347	 10347	 10347	 0.0	 0.0	 1	 -30.0	 30.0;
	2628	 8854	 0.00037	 0.00164	 0.0	 18789	 18789	 18789	 0.0	 0.0	 1	 -30.0	 30.0;
	2628	 13347	 0.00033	 0.00148	 0.0	 20832	 20832	 20832	 0.0	 0.0	 1	 -30.0	 30.0;
	2628	 12605	 0.0002	 0.00216	 0.0	 14562	 14562	 14562	 0.0	 0.0	 1	 -30.0	 30.0;
	2628	 4320	 0.00037	 0.00372	 0.0	 8450	 8450	 8450	 0.0	 0.0	 1	 -30.0	 30.0;
	9429	 12605	 0.00065	 0.00697	 0.0	 4513	 4513	 4513	 0.0	 0.0	 1	 -30.0	 30.0;
	9429	 1256	 0.00015	 0.0016	 0.0	 19656	 19656	 19656	 0.0	 0.0	 1	 -30.0	 30.0;
	3370	 11207	 0.002	 0.00953	 0.0	 3244	 3244	 3244	 0.0	 0.0	 1	 -30.0	 30.0;
	3370	 11207	 0.002	 0.00953	 0.0	 3244	 3244	 3244	 0.0	 0.0	 1	 -30.0	 30.0;
	5390	 13347	 0.0006	 0.00268	 0.0	 11502	 11502	 11502	 0.0	 0.0	 1	 -30.0	 30.0;
	5390	 11921	 0.00239	 0.01883	 0.0	 1665	 1665	 1665	 0.0	 0.0	 1	 -30.0	 30.0;
	5390	 4320	 0.00117	 0.00926	 0.0	 3385	 3385	 3385	 0.0	 0.0	 1	 -30.0	 30.0;
	8590	 11740	 0.00026	 0.00161	 0.0	 19369	 19369	 19369	 0.0	 0.0	 1	 -30.0	 30.0;
	8590	 11740	 0.00026	 0.00161	 0.0	 19369	 19369	 19369	 0.0	 0.0	 1	 -30.0	 30.0;
	7773	 4408	 0.00061	 0.00291	 0.0	 10624	 10624	 10624	 0.0	 0.0	 1	 -30.0	 30.0;
	7773	 4408	 0.00061	 0.00291	 0.0	 10624	 10624	 10624	 0.0	 0.0	 1	 -30.0	 30.0;
	11271	 3920	 0.00062	 0.00632	 0.0	 4975	 4975	 4975	 0.0	 0.0	 1	 -30.0	 30.0;
	11271	 3920	 0.00062	 0.00632	 0.0	 4975	 4975	 4975	 0.0	 0.0	 1	 -30.0	 30.0;
	11271	 497	 0.001	 0.00785	 0.0	 3992	 3992	 3992	 0.0	 0.0	 1	 -30.0	 30.0;
	11921	 4320	 0.00231	 0.0182	 0.0	 1722	 1722	 1722	 0.0	 0.0	 1	 -30.0	 30.0;
	8046	 11207	 0.00233	 0.01836	 0.0	 1707	 1707	 1707	 0.0	 0.0	 1	 -30.0	 30.0;
	8046	 13624	 0.0043	 0.03389	 0.0	 925	 925	 925	 0.0	 0.0	 1	 -30.0	 30.0;
	12605	 4320	 0.00017	 0.00174	 0.0	 18068	 18068	 18068	 0.0	 0.0	 1	 -30.0	 30.0;
	12605	 4320	 0.00017	 0.00174	 0.0	 18068	 18068	 18068	 0.0	 0.0	 1	 -30.0	 30.0;
	12605	 11255	 0.0005	 0.00537	 0.0	 5857	 5857	 5857	 0.0	 0.0	 1	 -30.0	 30.0;
	4565	 5870	 0.006	 0.0286	 0.0	 1081	 1081	 1081	 0.0	 0.0	 1	 -30.0	 30.0;
	4565	 602	 0.01187	 0.05656	 0.0	 547	 547	 547	 0.0	 0.0	 1	 -30.0	 30.0;
	4565	 4739	 0.00022	 0.0024	 0.0	 13107	 13107	 13107	 0.0	 0.0	 1	 -30.0	 30.0;
	8511	 7357	 0.01419	 0.04556	 0.0	 662	 662	 662	 0.0	 0.0	 1	 -30.0	 30.0;
	8511	 4015	 0.01712	 0.08161	 0.0	 379	 379	 379	 0.0	 0.0	 1	 -30.0	 30.0;
	12068	 4408	 0.00173	 0.00824	 0.0	 3752	 3752	 3752	 0.0	 0.0	 1	 -30.0	 30.0;
	12068	 4408	 0.00173	 0.00824	 0.0	 3752	 3752	 3752	 0.0	 0.0	 1	 -30.0	 30.0;
	11465	 11207	 0.00199	 0.01569	 0.0	 1998	 1998	 1998	 0.0	 0.0	 1	 -30.0	 30.0;
	11465	 13624	 0.00716	 0.05648	 0.0	 555	 555	 555	 0.0	 0.0	 1	 -30.0	 30.0;
	11451	 7815	 0.00915	 0.07217	 0.0	 435	 435	 435	 0.0	 0.0	 1	 -30.0	 30.0;
	11451	 4320	 0.00793	 0.03781	 0.0	 818	 818	 818	 0.0	 0.0	 1	 -30.0	 30.0;
	7357	 10988	 0.00796	 0.06276	 0.0	 500	 500	 500	 0.0	 0.0	 1	 -30.0	 30.0;
	7815	 4320	 0.01796	 0.05768	 0.0	 523	 523	 523	 0.0	 0.0	 1	 -30.0	 30.0;
	7815	 13634	 0.00013	 0.00136	 0.0	 23121	 23121	 23121	 0.0	 0.0	 1	 -30.0	 30.0;
	13413	 4408	 0.00179	 0.01412	 0.0	 2220	 2220	 2220	 0.0	 0.0	 1	 -30.0	 30.0;
	13413	 7421	 0.00338	 0.01085	 0.0	 2780	 2780	 2780	 0.0	 0.0	 1	 -30.0	 30.0;
	5870	 13624	 0.0009	 0.00706	 0.0	 4439	 4439	 4439	 0.0	 0.0	 1	 -30.0	 30.0;
	5870	 13624	 0.0009	 0.00706	 0.0	 4439	 4439	 4439	 0.0	 0.0	 1	 -30.0	 30.0;
	12660	 3606	 0.02308	 0.07413	 0.0	 407	 407	 407	 0.0	 0.0	 1	 -30.0	 30.0;
	12660	 6504	 0.00669	 0.05272	 0.0	 595	 595	 595	 0.0	 0.0	 1	 -30.0	 30.0;
	8984	 6755	 0.02866	 0.09203	 0.0	 328	 328	 328	 0.0	 0.0	 1	 -30.0	 30.0;
	8984	 3821	 0.06565	 0.21081	 0.0	 144	 144	 144	 0.0	 0.0	 1	 -30.0	 30.0;
	8984	 1579	 0.03479	 0.11173	 0.0	 270	 270	 270	 0.0	 0.0	 1	 -30.0	 30.0;
	3623	 1280	 0.03243	 0.10414	 0.0	 290	 290	 290	 0.0	 0.0	 1	 -30.0	 30.0;
	1280	 10061	 0.00784	 0.06182	 0.0	 507	 507	 507	 0.0	 0.0	 1	 -30.0	 30.0;
	1280	 7421	 0.02196	 0.07051	 0.0	 428	 428	 428	 0.0	 0.0	 1	 -30.0	 30.0;
	6755	 3158	 0.01323	 0.04249	 0.0	 710	 710	 710	 0.0	 0.0	 1	 -30.0	 30.0;
	11373	 602	 0.00336	 0.016	 0.0	 1933	 1933	 1933	 0.0	 0.0	 1	 -30.0	 30.0;
	11373	 602	 0.00325	 0.01551	 0.0	 1994	 1994	 1994	 0.0	 0.0	 1	 -30.0	 30.0;
	11373	 10909	 0.02303	 0.07395	 0.0	 408	 408	 408	 0.0	 0.0	 1	 -30.0	 30.0;
	11373	 3606	 0.00845	 0.02712	 0.0	 1112	 1112	 1112	 0.0	 0.0	 1	 -30.0	 30.0;
	602	 10316	 0.00678	 0.03232	 0.0	 957	 957	 957	 0.0	 0.0	 1	 -30.0	 30.0;
	3158	 10909	 0.0322	 0.10342	 0.0	 292	 292	 292	 0.0	 0.0	 1	 -30.0	 30.0;
	10061	 6504	 0.0002	 0.00157	 0.0	 19959	 19959	 19959	 0.0	 0.0	 1	 -30.0	 30.0;
	10244	 8181	 0.05906	 0.18966	 0.0	 160	 160	 160	 0.0	 0.0	 1	 -30.0	 30.0;
	10244	 9548	 0.00676	 0.0217	 0.0	 1390	 1390	 1390	 0.0	 0.0	 1	 -30.0	 30.0;
	3821	 8930	 0.02488	 0.19613	 0.0	 160	 160	 160	 0.0	 0.0	 1	 -30.0	 30.0;
	3821	 9548	 0.00676	 0.0217	 0.0	 1390	 1390	 1390	 0.0	 0.0	 1	 -30.0	 30.0;
	10586	 1297	 0.00094	 0.00956	 0.0	 3289	 3289	 3289	 0.0	 0.0	 1	 -30.0	 30.0;
	10586	 12110	 0.00025	 0.00258	 0.0	 12187	 12187	 12187	 0.0	 0.0	 1	 -30.0	 30.0;
	1297	 12110	 0.00082	 0.00843	 0.0	 3730	 3730	 3730	 0.0	 0.0	 1	 -30.0	 30.0;
	1297	 10975	 0.00156	 0.01988	 0.0	 1585	 1585	 1585	 0.0	 0.0	 1	 -30.0	 30.0;
	12110	 12975	 0.00146	 0.01855	 0.0	 1698	 1698	 1698	 0.0	 0.0	 1	 -30.0	 30.0;
	6313	 7276	 0.02449	 0.07865	 0.0	 384	 384	 384	 0.0	 0.0	 1	 -30.0	 30.0;
	6313	 7879	 0.01055	 0.08316	 0.0	 377	 377	 377	 0.0	 0.0	 1	 -30.0	 30.0;
	6037	 13065	 0.02753	 0.08841	 0.0	 342	 342	 342	 0.0	 0.0	 1	 -30.0	 30.0;
	6037	 2039	 0.02393	 0.07684	 0.0	 393	 393	 393	 0.0	 0.0	 1	 -30.0	 30.0;
	12296	 484	 0.01566	 0.07466	 0.0	 415	 415	 415	 0.0	 0.0	 1	 -30.0	 30.0;
	4015	 10988	 0.00519	 0.04095	 0.0	 766	 766	 766	 0.0	 0.0	 1	 -30.0	 30.0;
	4015	 6257	 0.02286	 0.0734	 0.0	 411	 411	 411	 0.0	 0.0	 1	 -30.0	 30.0;
	4015	 2824	 0.02226	 0.08078	 0.0	 377	 377	 377	 0.0	 0.0	 1	 -30.0	 30.0;
	8178	 484	 0.01817	 0.08662	 0.0	 357	 357	 357	 0.0	 0.0	 1	 -30.0	 30.0;
	8178	 2567	 0.01576	 0.07514	 0.0	 412	 412	 412	 0.0	 0.0	 1	 -30.0	 30.0;
	11777	 13065	 0.02697	 0.0866	 0.0	 349	 349	 349	 0.0	 0.0	 1	 -30.0	 30.0;
	11777	 1722	 0.00929	 0.02983	 0.0	 1012	 1012	 1012	 0.0	 0.0	 1	 -30.0	 30.0;
	11777	 7276	 0.03508	 0.11264	 0.0	 268	 268	 268	 0.0	 0.0	 1	 -30.0	 30.0;
	11777	 10716	 0.01405	 0.11077	 0.0	 283	 283	 283	 0.0	 0.0	 1	 -30.0	 30.0;
	13065	 10199	 0.03479	 0.11173	 0.0	 270	 270	 270	 0.0	 0.0	 1	 -30.0	 30.0;
	10259	 2096	 0.01937	 0.06219	 0.0	 485	 485	 485	 0.0	 0.0	 1	 -30.0	 30.0;
	10259	 1912	 0.03778	 0.12132	 0.0	 249	 249	 249	 0.0	 0.0	 1	 -30.0	 30.0;
	10259	 2037	 0.00497	 0.03923	 0.0	 799	 799	 799	 0.0	 0.0	 1	 -30.0	 30.0;
	1277	 1497	 0.01864	 0.08888	 0.0	 348	 348	 348	 0.0	 0.0	 1	 -30.0	 30.0;
	1277	 1497	 0.01864	 0.08888	 0.0	 348	 348	 348	 0.0	 0.0	 1	 -30.0	 30.0;
	1722	 2039	 0.01774	 0.05695	 0.0	 530	 530	 530	 0.0	 0.0	 1	 -30.0	 30.0;
	1722	 7879	 0.00292	 0.02306	 0.0	 1359	 1359	 1359	 0.0	 0.0	 1	 -30.0	 30.0;
	2039	 2412	 0.004	 0.01284	 0.0	 2349	 2349	 2349	 0.0	 0.0	 1	 -30.0	 30.0;
	2039	 2188	 0.00985	 0.03164	 0.0	 954	 954	 954	 0.0	 0.0	 1	 -30.0	 30.0;
	2039	 7879	 0.00336	 0.02652	 0.0	 1182	 1182	 1182	 0.0	 0.0	 1	 -30.0	 30.0;
	2039	 7879	 0.00336	 0.02652	 0.0	 1182	 1182	 1182	 0.0	 0.0	 1	 -30.0	 30.0;
	2412	 5441	 0.02179	 0.07184	 0.0	 421	 421	 421	 0.0	 0.0	 1	 -30.0	 30.0;
	2096	 2037	 0.00697	 0.05491	 0.0	 571	 571	 571	 0.0	 0.0	 1	 -30.0	 30.0;
	2096	 10109	 0.01119	 0.05333	 0.0	 580	 580	 580	 0.0	 0.0	 1	 -30.0	 30.0;
	2096	 10109	 0.01119	 0.05333	 0.0	 580	 580	 580	 0.0	 0.0	 1	 -30.0	 30.0;
	2096	 52	 0.04645	 0.14916	 0.0	 203	 203	 203	 0.0	 0.0	 1	 -30.0	 30.0;
	10988	 1098	 0.00402	 0.04114	 0.0	 765	 765	 765	 0.0	 0.0	 1	 -30.0	 30.0;
	10988	 8050	 0.00279	 0.02851	 0.0	 1103	 1103	 1103	 0.0	 0.0	 1	 -30.0	 30.0;
	10988	 5818	 0.02688	 0.12815	 0.0	 242	 242	 242	 0.0	 0.0	 1	 -30.0	 30.0;
	1579	 6257	 0.03125	 0.10034	 0.0	 301	 301	 301	 0.0	 0.0	 1	 -30.0	 30.0;
	1579	 2188	 0.00619	 0.01989	 0.0	 1517	 1517	 1517	 0.0	 0.0	 1	 -30.0	 30.0;
	6966	 1912	 0.02466	 0.07919	 0.0	 381	 381	 381	 0.0	 0.0	 1	 -30.0	 30.0;
	6966	 12149	 0.00563	 0.01808	 0.0	 1669	 1669	 1669	 0.0	 0.0	 1	 -30.0	 30.0;
	12718	 2567	 0.00693	 0.02224	 0.0	 1356	 1356	 1356	 0.0	 0.0	 1	 -30.0	 30.0;
	12718	 2567	 0.00693	 0.02224	 0.0	 1356	 1356	 1356	 0.0	 0.0	 1	 -30.0	 30.0;
	7616	 7276	 0.02567	 0.08245	 0.0	 366	 366	 366	 0.0	 0.0	 1	 -30.0	 30.0;
	7616	 9965	 0.02944	 0.09456	 0.0	 319	 319	 319	 0.0	 0.0	 1	 -30.0	 30.0;
	1098	 8050	 0.0025	 0.02552	 0.0	 1232	 1232	 1232	 0.0	 0.0	 1	 -30.0	 30.0;
	1497	 1912	 0.00584	 0.05974	 0.0	 527	 527	 527	 0.0	 0.0	 1	 -30.0	 30.0;
	1497	 5818	 0.00956	 0.09776	 0.0	 322	 322	 322	 0.0	 0.0	 1	 -30.0	 30.0;
	1497	 7594	 0.00563	 0.01808	 0.0	 1669	 1669	 1669	 0.0	 0.0	 1	 -30.0	 30.0;
	484	 5818	 0.01044	 0.04977	 0.0	 622	 622	 622	 0.0	 0.0	 1	 -30.0	 30.0;
	484	 2567	 0.00495	 0.03907	 0.0	 803	 803	 803	 0.0	 0.0	 1	 -30.0	 30.0;
	1912	 5818	 0.00545	 0.04299	 0.0	 729	 729	 729	 0.0	 0.0	 1	 -30.0	 30.0;
	6257	 12149	 0.02252	 0.07232	 0.0	 418	 418	 418	 0.0	 0.0	 1	 -30.0	 30.0;
	5818	 2567	 0.01603	 0.07644	 0.0	 405	 405	 405	 0.0	 0.0	 1	 -30.0	 30.0;
	5818	 5441	 0.03924	 0.12602	 0.0	 240	 240	 240	 0.0	 0.0	 1	 -30.0	 30.0;
	5818	 2824	 0.01798	 0.06704	 0.0	 456	 456	 456	 0.0	 0.0	 1	 -30.0	 30.0;
	10975	 12144	 0.0	 -0.0207	 0.0	 1526	 1526	 1526	 0.0	 0.0	 1	 -30.0	 30.0;
	215	 7953	 0.00149	 0.01526	 0.0	 2061	 2061	 2061	 0.0	 0.0	 1	 -30.0	 30.0;
	215	 7953	 0.00099	 0.01264	 0.0	 2492	 2492	 2492	 0.0	 0.0	 1	 -30.0	 30.0;
	215	 2748	 0.00168	 0.01713	 0.0	 1836	 1836	 1836	 0.0	 0.0	 1	 -30.0	 30.0;
	215	 4804	 0.00131	 0.01663	 0.0	 1894	 1894	 1894	 0.0	 0.0	 1	 -30.0	 30.0;
	7953	 2748	 0.00131	 0.01663	 0.0	 1894	 1894	 1894	 0.0	 0.0	 1	 -30.0	 30.0;
	7953	 12144	 0.00222	 0.02826	 0.0	 1115	 1115	 1115	 0.0	 0.0	 1	 -30.0	 30.0;
	1897	 11963	 0.01284	 0.04122	 0.0	 732	 732	 732	 0.0	 0.0	 1	 -30.0	 30.0;
	1897	 8600	 0.00563	 0.01808	 0.0	 1669	 1669	 1669	 0.0	 0.0	 1	 -30.0	 30.0;
	11864	 9428	 0.01094	 0.0863	 0.0	 364	 364	 364	 0.0	 0.0	 1	 -30.0	 30.0;
	11864	 1830	 0.0061	 0.02909	 0.0	 1063	 1063	 1063	 0.0	 0.0	 1	 -30.0	 30.0;
	11864	 886	 0.00537	 0.04236	 0.0	 740	 740	 740	 0.0	 0.0	 1	 -30.0	 30.0;
	13186	 2266	 0.01255	 0.04032	 0.0	 749	 749	 749	 0.0	 0.0	 1	 -30.0	 30.0;
	13186	 9965	 0.01092	 0.03508	 0.0	 860	 860	 860	 0.0	 0.0	 1	 -30.0	 30.0;
	13186	 7457	 0.01689	 0.05424	 0.0	 557	 557	 557	 0.0	 0.0	 1	 -30.0	 30.0;
	13186	 11852	 0.00011	 0.00036	 0.0	 83913	 83913	 83913	 0.0	 0.0	 1	 -30.0	 30.0;
	12327	 12036	 0.02393	 0.07684	 0.0	 393	 393	 393	 0.0	 0.0	 1	 -30.0	 30.0;
	12327	 12036	 0.00856	 0.06747	 0.0	 465	 465	 465	 0.0	 0.0	 1	 -30.0	 30.0;
	12327	 12036	 0.00856	 0.06747	 0.0	 465	 465	 465	 0.0	 0.0	 1	 -30.0	 30.0;
	12327	 2266	 0.00602	 0.01935	 0.0	 1559	 1559	 1559	 0.0	 0.0	 1	 -30.0	 30.0;
	12327	 9965	 0.0058	 0.02763	 0.0	 1119	 1119	 1119	 0.0	 0.0	 1	 -30.0	 30.0;
	12327	 9965	 0.0058	 0.02763	 0.0	 1119	 1119	 1119	 0.0	 0.0	 1	 -30.0	 30.0;
	12036	 12848	 0.02978	 0.09564	 0.0	 316	 316	 316	 0.0	 0.0	 1	 -30.0	 30.0;
	12036	 12848	 0.01194	 0.09414	 0.0	 333	 333	 333	 0.0	 0.0	 1	 -30.0	 30.0;
	12036	 12848	 0.01194	 0.09414	 0.0	 333	 333	 333	 0.0	 0.0	 1	 -30.0	 30.0;
	11963	 8514	 0.00796	 0.06276	 0.0	 500	 500	 500	 0.0	 0.0	 1	 -30.0	 30.0;
	11963	 3762	 0.00398	 0.03138	 0.0	 999	 999	 999	 0.0	 0.0	 1	 -30.0	 30.0;
	11963	 11991	 0.00458	 0.03609	 0.0	 869	 869	 869	 0.0	 0.0	 1	 -30.0	 30.0;
	10568	 2266	 0.00298	 0.00958	 0.0	 3149	 3149	 3149	 0.0	 0.0	 1	 -30.0	 30.0;
	12848	 52	 0.03001	 0.09637	 0.0	 313	 313	 313	 0.0	 0.0	 1	 -30.0	 30.0;
	10274	 1830	 0.00983	 0.04686	 0.0	 660	 660	 660	 0.0	 0.0	 1	 -30.0	 30.0;
	10274	 1830	 0.00796	 0.06276	 0.0	 500	 500	 500	 0.0	 0.0	 1	 -30.0	 30.0;
	2266	 9965	 0.00462	 0.01483	 0.0	 2034	 2034	 2034	 0.0	 0.0	 1	 -30.0	 30.0;
	2266	 1717	 0.001	 0.00785	 0.0	 3992	 3992	 3992	 0.0	 0.0	 1	 -30.0	 30.0;
	2266	 1717	 0.001	 0.00785	 0.0	 3992	 3992	 3992	 0.0	 0.0	 1	 -30.0	 30.0;
	9428	 8514	 0.01239	 0.03978	 0.0	 759	 759	 759	 0.0	 0.0	 1	 -30.0	 30.0;
	9428	 8514	 0.00749	 0.03571	 0.0	 866	 866	 866	 0.0	 0.0	 1	 -30.0	 30.0;
	9428	 8514	 0.00749	 0.03571	 0.0	 866	 866	 866	 0.0	 0.0	 1	 -30.0	 30.0;
	9428	 886	 0.00478	 0.03766	 0.0	 833	 833	 833	 0.0	 0.0	 1	 -30.0	 30.0;
	9428	 11991	 0.0038	 0.02997	 0.0	 1046	 1046	 1046	 0.0	 0.0	 1	 -30.0	 30.0;
	9428	 519	 0.00394	 0.01266	 0.0	 2383	 2383	 2383	 0.0	 0.0	 1	 -30.0	 30.0;
	8514	 1830	 0.0199	 0.1569	 0.0	 200	 200	 200	 0.0	 0.0	 1	 -30.0	 30.0;
	8514	 11389	 0.00677	 0.05335	 0.0	 588	 588	 588	 0.0	 0.0	 1	 -30.0	 30.0;
	9965	 8600	 0.00298	 0.02354	 0.0	 1332	 1332	 1332	 0.0	 0.0	 1	 -30.0	 30.0;
	9965	 8600	 0.00298	 0.02354	 0.0	 1332	 1332	 1332	 0.0	 0.0	 1	 -30.0	 30.0;
	8600	 3762	 0.00458	 0.03609	 0.0	 869	 869	 869	 0.0	 0.0	 1	 -30.0	 30.0;
	10490	 11742	 0.00133	 0.01349	 0.0	 2331	 2331	 2331	 0.0	 0.0	 1	 -30.0	 30.0;
	10490	 10018	 0.00047	 0.00772	 0.0	 4085	 4085	 4085	 0.0	 0.0	 1	 -30.0	 30.0;
	10490	 6028	 0.00698	 0.07071	 0.0	 445	 445	 445	 0.0	 0.0	 1	 -30.0	 30.0;
	11742	 10018	 0.00048	 0.00615	 0.0	 5121	 5121	 5121	 0.0	 0.0	 1	 -30.0	 30.0;
	11742	 8624	 0.00048	 0.00615	 0.0	 5121	 5121	 5121	 0.0	 0.0	 1	 -30.0	 30.0;
	11742	 10266	 0.0014	 0.01429	 0.0	 2200	 2200	 2200	 0.0	 0.0	 1	 -30.0	 30.0;
	11742	 4116	 0.00156	 0.01982	 0.0	 1589	 1589	 1589	 0.0	 0.0	 1	 -30.0	 30.0;
	1952	 9639	 0.02032	 0.06527	 0.0	 463	 463	 463	 0.0	 0.0	 1	 -30.0	 30.0;
	1952	 9528	 0.04842	 0.15549	 0.0	 194	 194	 194	 0.0	 0.0	 1	 -30.0	 30.0;
	1952	 5853	 0.00957	 0.03074	 0.0	 982	 982	 982	 0.0	 0.0	 1	 -30.0	 30.0;
	1952	 7439	 0.00729	 0.03474	 0.0	 890	 890	 890	 0.0	 0.0	 1	 -30.0	 30.0;
	9907	 9528	 0.0198	 0.15612	 0.0	 201	 201	 201	 0.0	 0.0	 1	 -30.0	 30.0;
	9907	 6270	 0.07263	 0.23323	 0.0	 130	 130	 130	 0.0	 0.0	 1	 -30.0	 30.0;
	9907	 5313	 0.01194	 0.09414	 0.0	 333	 333	 333	 0.0	 0.0	 1	 -30.0	 30.0;
	9907	 5313	 0.01194	 0.09414	 0.0	 333	 333	 333	 0.0	 0.0	 1	 -30.0	 30.0;
	10511	 1569	 0.00902	 0.04299	 0.0	 720	 720	 720	 0.0	 0.0	 1	 -30.0	 30.0;
	10511	 1569	 0.00902	 0.04299	 0.0	 720	 720	 720	 0.0	 0.0	 1	 -30.0	 30.0;
	10511	 3200	 0.00203	 0.0097	 0.0	 3188	 3188	 3188	 0.0	 0.0	 1	 -30.0	 30.0;
	1569	 12620	 0.01407	 0.0452	 0.0	 668	 668	 668	 0.0	 0.0	 1	 -30.0	 30.0;
	1569	 10179	 0.01149	 0.05478	 0.0	 565	 565	 565	 0.0	 0.0	 1	 -30.0	 30.0;
	1119	 2344	 0.01396	 0.04484	 0.0	 673	 673	 673	 0.0	 0.0	 1	 -30.0	 30.0;
	1119	 2344	 0.01396	 0.04484	 0.0	 673	 673	 673	 0.0	 0.0	 1	 -30.0	 30.0;
	2589	 2765	 0.00712	 0.03394	 0.0	 911	 911	 911	 0.0	 0.0	 1	 -30.0	 30.0;
	2589	 2765	 0.00712	 0.03394	 0.0	 911	 911	 911	 0.0	 0.0	 1	 -30.0	 30.0;
	2589	 2344	 0.02421	 0.07774	 0.0	 388	 388	 388	 0.0	 0.0	 1	 -30.0	 30.0;
	2589	 10807	 0.02083	 0.0669	 0.0	 451	 451	 451	 0.0	 0.0	 1	 -30.0	 30.0;
	2765	 13534	 0.02034	 0.09696	 0.0	 319	 319	 319	 0.0	 0.0	 1	 -30.0	 30.0;
	2765	 452	 0.01526	 0.07272	 0.0	 426	 426	 426	 0.0	 0.0	 1	 -30.0	 30.0;
	2765	 9684	 0.02949	 0.14059	 0.0	 220	 220	 220	 0.0	 0.0	 1	 -30.0	 30.0;
	2765	 4017	 0.01095	 0.0522	 0.0	 593	 593	 593	 0.0	 0.0	 1	 -30.0	 30.0;
	2765	 4017	 0.01095	 0.0522	 0.0	 593	 593	 593	 0.0	 0.0	 1	 -30.0	 30.0;
	2765	 11062	 0.01763	 0.08403	 0.0	 368	 368	 368	 0.0	 0.0	 1	 -30.0	 30.0;
	2765	 8165	 0.00814	 0.03878	 0.0	 798	 798	 798	 0.0	 0.0	 1	 -30.0	 30.0;
	10781	 10820	 0.01898	 0.0905	 0.0	 342	 342	 342	 0.0	 0.0	 1	 -30.0	 30.0;
	10781	 10820	 0.01898	 0.0905	 0.0	 342	 342	 342	 0.0	 0.0	 1	 -30.0	 30.0;
	3024	 12103	 0.00394	 0.01266	 0.0	 2383	 2383	 2383	 0.0	 0.0	 1	 -30.0	 30.0;
	3024	 9684	 0.00576	 0.02747	 0.0	 1126	 1126	 1126	 0.0	 0.0	 1	 -30.0	 30.0;
	3024	 12067	 0.01436	 0.0461	 0.0	 655	 655	 655	 0.0	 0.0	 1	 -30.0	 30.0;
	3024	 7829	 0.02534	 0.08136	 0.0	 371	 371	 371	 0.0	 0.0	 1	 -30.0	 30.0;
	12103	 11148	 0.02646	 0.08498	 0.0	 355	 355	 355	 0.0	 0.0	 1	 -30.0	 30.0;
	12103	 9684	 0.0059	 0.02812	 0.0	 1100	 1100	 1100	 0.0	 0.0	 1	 -30.0	 30.0;
	12103	 2344	 0.02984	 0.09582	 0.0	 315	 315	 315	 0.0	 0.0	 1	 -30.0	 30.0;
	12103	 8321	 0.00796	 0.06276	 0.0	 500	 500	 500	 0.0	 0.0	 1	 -30.0	 30.0;
	12103	 8165	 0.01729	 0.08242	 0.0	 376	 376	 376	 0.0	 0.0	 1	 -30.0	 30.0;
	6528	 7827	 0.00569	 0.02715	 0.0	 1139	 1139	 1139	 0.0	 0.0	 1	 -30.0	 30.0;
	6528	 11160	 0.01543	 0.07353	 0.0	 421	 421	 421	 0.0	 0.0	 1	 -30.0	 30.0;
	6528	 11160	 0.01543	 0.07353	 0.0	 421	 421	 421	 0.0	 0.0	 1	 -30.0	 30.0;
	6528	 9684	 0.00529	 0.02521	 0.0	 1227	 1227	 1227	 0.0	 0.0	 1	 -30.0	 30.0;
	6528	 9684	 0.00529	 0.02521	 0.0	 1227	 1227	 1227	 0.0	 0.0	 1	 -30.0	 30.0;
	6528	 10955	 0.00024	 0.00113	 0.0	 27344	 27344	 27344	 0.0	 0.0	 1	 -30.0	 30.0;
	6528	 10955	 0.00024	 0.00113	 0.0	 27344	 27344	 27344	 0.0	 0.0	 1	 -30.0	 30.0;
	6528	 12957	 0.00959	 0.04573	 0.0	 677	 677	 677	 0.0	 0.0	 1	 -30.0	 30.0;
	6528	 13168	 0.02252	 0.07232	 0.0	 418	 418	 418	 0.0	 0.0	 1	 -30.0	 30.0;
	6528	 12935	 0.01689	 0.05424	 0.0	 557	 557	 557	 0.0	 0.0	 1	 -30.0	 30.0;
	10457	 9528	 0.03125	 0.10034	 0.0	 301	 301	 301	 0.0	 0.0	 1	 -30.0	 30.0;
	10457	 5853	 0.0078	 0.03717	 0.0	 832	 832	 832	 0.0	 0.0	 1	 -30.0	 30.0;
	10457	 5853	 0.0078	 0.03717	 0.0	 832	 832	 832	 0.0	 0.0	 1	 -30.0	 30.0;
	10457	 10582	 0.00678	 0.03232	 0.0	 957	 957	 957	 0.0	 0.0	 1	 -30.0	 30.0;
	10457	 10582	 0.00678	 0.03232	 0.0	 957	 957	 957	 0.0	 0.0	 1	 -30.0	 30.0;
	10457	 7439	 0.01295	 0.06173	 0.0	 501	 501	 501	 0.0	 0.0	 1	 -30.0	 30.0;
	6042	 10179	 0.012	 0.05721	 0.0	 541	 541	 541	 0.0	 0.0	 1	 -30.0	 30.0;
	6042	 10179	 0.012	 0.05721	 0.0	 541	 541	 541	 0.0	 0.0	 1	 -30.0	 30.0;
	6042	 2344	 0.00332	 0.01584	 0.0	 1952	 1952	 1952	 0.0	 0.0	 1	 -30.0	 30.0;
	6042	 2344	 0.00332	 0.01584	 0.0	 1952	 1952	 1952	 0.0	 0.0	 1	 -30.0	 30.0;
	6042	 11884	 0.00986	 0.04703	 0.0	 658	 658	 658	 0.0	 0.0	 1	 -30.0	 30.0;
	6042	 11884	 0.00986	 0.04703	 0.0	 658	 658	 658	 0.0	 0.0	 1	 -30.0	 30.0;
	4124	 11884	 0.0002	 0.00204	 0.0	 15411	 15411	 15411	 0.0	 0.0	 1	 -30.0	 30.0;
	4124	 11884	 0.0002	 0.00204	 0.0	 15411	 15411	 15411	 0.0	 0.0	 1	 -30.0	 30.0;
	13534	 7827	 0.02081	 0.09922	 0.0	 312	 312	 312	 0.0	 0.0	 1	 -30.0	 30.0;
	13534	 7827	 0.02081	 0.09922	 0.0	 312	 312	 312	 0.0	 0.0	 1	 -30.0	 30.0;
	13534	 11884	 0.01672	 0.0537	 0.0	 562	 562	 562	 0.0	 0.0	 1	 -30.0	 30.0;
	13534	 12067	 0.01171	 0.03761	 0.0	 802	 802	 802	 0.0	 0.0	 1	 -30.0	 30.0;
	13534	 11062	 0.00407	 0.01939	 0.0	 1595	 1595	 1595	 0.0	 0.0	 1	 -30.0	 30.0;
	7827	 12957	 0.00959	 0.04573	 0.0	 677	 677	 677	 0.0	 0.0	 1	 -30.0	 30.0;
	7827	 3511	 0.00113	 0.00362	 0.0	 8330	 8330	 8330	 0.0	 0.0	 1	 -30.0	 30.0;
	12620	 11884	 0.00296	 0.02338	 0.0	 1341	 1341	 1341	 0.0	 0.0	 1	 -30.0	 30.0;
	10179	 9676	 0.01366	 0.06513	 0.0	 475	 475	 475	 0.0	 0.0	 1	 -30.0	 30.0;
	10179	 11884	 0.00093	 0.0095	 0.0	 3310	 3310	 3310	 0.0	 0.0	 1	 -30.0	 30.0;
	10179	 1989	 0.00034	 0.00162	 0.0	 19083	 19083	 19083	 0.0	 0.0	 1	 -30.0	 30.0;
	9676	 3200	 0.01786	 0.08516	 0.0	 364	 364	 364	 0.0	 0.0	 1	 -30.0	 30.0;
	7292	 9639	 0.0045	 0.01446	 0.0	 2086	 2086	 2086	 0.0	 0.0	 1	 -30.0	 30.0;
	7292	 2950	 0.0116	 0.03725	 0.0	 810	 810	 810	 0.0	 0.0	 1	 -30.0	 30.0;
	7292	 9456	 0.02629	 0.08443	 0.0	 358	 358	 358	 0.0	 0.0	 1	 -30.0	 30.0;
	9639	 2950	 0.00709	 0.02278	 0.0	 1324	 1324	 1324	 0.0	 0.0	 1	 -30.0	 30.0;
	452	 11148	 0.01051	 0.0501	 0.0	 618	 618	 618	 0.0	 0.0	 1	 -30.0	 30.0;
	11160	 713	 0.02353	 0.07557	 0.0	 400	 400	 400	 0.0	 0.0	 1	 -30.0	 30.0;
	11160	 8321	 0.00799	 0.02567	 0.0	 1175	 1175	 1175	 0.0	 0.0	 1	 -30.0	 30.0;
	11160	 2950	 0.02168	 0.06961	 0.0	 434	 434	 434	 0.0	 0.0	 1	 -30.0	 30.0;
	11160	 8983	 0.00608	 0.01953	 0.0	 1545	 1545	 1545	 0.0	 0.0	 1	 -30.0	 30.0;
	11160	 787	 0.00169	 0.00808	 0.0	 3827	 3827	 3827	 0.0	 0.0	 1	 -30.0	 30.0;
	11160	 787	 0.00169	 0.00808	 0.0	 3827	 3827	 3827	 0.0	 0.0	 1	 -30.0	 30.0;
	1949	 2950	 0.15283	 0.86416	 0.0	 36	 36	 36	 0.0	 0.0	 1	 -30.0	 30.0;
	1949	 2762	 0.0045	 0.01446	 0.0	 2086	 2086	 2086	 0.0	 0.0	 1	 -30.0	 30.0;
	1949	 8876	 0.00336	 0.016	 0.0	 1933	 1933	 1933	 0.0	 0.0	 1	 -30.0	 30.0;
	10820	 2950	 0.00125	 0.00989	 0.0	 3169	 3169	 3169	 0.0	 0.0	 1	 -30.0	 30.0;
	10820	 7723	 0.00153	 0.01208	 0.0	 2595	 2595	 2595	 0.0	 0.0	 1	 -30.0	 30.0;
	10820	 787	 0.01265	 0.06028	 0.0	 513	 513	 513	 0.0	 0.0	 1	 -30.0	 30.0;
	10820	 787	 0.01265	 0.06028	 0.0	 513	 513	 513	 0.0	 0.0	 1	 -30.0	 30.0;
	10820	 7439	 0.00576	 0.02747	 0.0	 1126	 1126	 1126	 0.0	 0.0	 1	 -30.0	 30.0;
	10820	 7439	 0.00576	 0.02747	 0.0	 1126	 1126	 1126	 0.0	 0.0	 1	 -30.0	 30.0;
	2344	 6532	 0.00056	 0.00181	 0.0	 16672	 16672	 16672	 0.0	 0.0	 1	 -30.0	 30.0;
	11884	 11999	 0.00225	 0.00723	 0.0	 4172	 4172	 4172	 0.0	 0.0	 1	 -30.0	 30.0;
	11884	 1204	 0.0006	 0.00471	 0.0	 6653	 6653	 6653	 0.0	 0.0	 1	 -30.0	 30.0;
	8321	 8983	 0.01413	 0.04538	 0.0	 665	 665	 665	 0.0	 0.0	 1	 -30.0	 30.0;
	8321	 7829	 0.00338	 0.01085	 0.0	 2780	 2780	 2780	 0.0	 0.0	 1	 -30.0	 30.0;
	4017	 8584	 0.01065	 0.05074	 0.0	 610	 610	 610	 0.0	 0.0	 1	 -30.0	 30.0;
	4017	 8584	 0.01065	 0.05074	 0.0	 610	 610	 610	 0.0	 0.0	 1	 -30.0	 30.0;
	4017	 12098	 0.00506	 0.03985	 0.0	 787	 787	 787	 0.0	 0.0	 1	 -30.0	 30.0;
	2950	 8983	 0.01368	 0.04393	 0.0	 687	 687	 687	 0.0	 0.0	 1	 -30.0	 30.0;
	9528	 7883	 0.00034	 0.00108	 0.0	 27898	 27898	 27898	 0.0	 0.0	 1	 -30.0	 30.0;
	9528	 6270	 0.05067	 0.16272	 0.0	 186	 186	 186	 0.0	 0.0	 1	 -30.0	 30.0;
	9456	 3573	 0.03125	 0.10034	 0.0	 301	 301	 301	 0.0	 0.0	 1	 -30.0	 30.0;
	7723	 2762	 0.00113	 0.00362	 0.0	 8330	 8330	 8330	 0.0	 0.0	 1	 -30.0	 30.0;
	12067	 12957	 0.01293	 0.10199	 0.0	 308	 308	 308	 0.0	 0.0	 1	 -30.0	 30.0;
	12067	 12957	 0.01293	 0.10199	 0.0	 308	 308	 308	 0.0	 0.0	 1	 -30.0	 30.0;
	12067	 8485	 0.00106	 0.01086	 0.0	 2895	 2895	 2895	 0.0	 0.0	 1	 -30.0	 30.0;
	12067	 8485	 0.00106	 0.01086	 0.0	 2895	 2895	 2895	 0.0	 0.0	 1	 -30.0	 30.0;
	8983	 11766	 0.00139	 0.01098	 0.0	 2855	 2855	 2855	 0.0	 0.0	 1	 -30.0	 30.0;
	8983	 11766	 0.00139	 0.01098	 0.0	 2855	 2855	 2855	 0.0	 0.0	 1	 -30.0	 30.0;
	10018	 2752	 0.0017	 0.02161	 0.0	 1458	 1458	 1458	 0.0	 0.0	 1	 -30.0	 30.0;
	3200	 8140	 0.00895	 0.07061	 0.0	 444	 444	 444	 0.0	 0.0	 1	 -30.0	 30.0;
	3200	 8140	 0.00895	 0.07061	 0.0	 444	 444	 444	 0.0	 0.0	 1	 -30.0	 30.0;
	5853	 7439	 0.00695	 0.03313	 0.0	 934	 934	 934	 0.0	 0.0	 1	 -30.0	 30.0;
	5853	 7439	 0.00746	 0.03555	 0.0	 870	 870	 870	 0.0	 0.0	 1	 -30.0	 30.0;
	5853	 8876	 0.00929	 0.04428	 0.0	 699	 699	 699	 0.0	 0.0	 1	 -30.0	 30.0;
	191	 8624	 0.00084	 0.01064	 0.0	 2960	 2960	 2960	 0.0	 0.0	 1	 -30.0	 30.0;
	191	 4116	 0.00274	 0.03491	 0.0	 903	 903	 903	 0.0	 0.0	 1	 -30.0	 30.0;
	2477	 7209	 0.00153	 0.01547	 0.0	 2032	 2032	 2032	 0.0	 0.0	 1	 -30.0	 30.0;
	9769	 3045	 0.00328	 0.03317	 0.0	 948	 948	 948	 0.0	 0.0	 1	 -30.0	 30.0;
	9769	 13258	 0.00137	 0.01387	 0.0	 2267	 2267	 2267	 0.0	 0.0	 1	 -30.0	 30.0;
	3045	 7209	 0.00066	 0.00666	 0.0	 4720	 4720	 4720	 0.0	 0.0	 1	 -30.0	 30.0;
	3045	 12844	 0.0053	 0.05369	 0.0	 586	 586	 586	 0.0	 0.0	 1	 -30.0	 30.0;
	3045	 7647	 0.0053	 0.05369	 0.0	 586	 586	 586	 0.0	 0.0	 1	 -30.0	 30.0;
	7209	 7769	 0.00025	 0.00417	 0.0	 7562	 7562	 7562	 0.0	 0.0	 1	 -30.0	 30.0;
	7209	 3317	 0.00037	 0.00465	 0.0	 6772	 6772	 6772	 0.0	 0.0	 1	 -30.0	 30.0;
	7209	 8817	 0.00347	 0.04417	 0.0	 713	 713	 713	 0.0	 0.0	 1	 -30.0	 30.0;
	7209	 6223	 0.00347	 0.04417	 0.0	 713	 713	 713	 0.0	 0.0	 1	 -30.0	 30.0;
	7769	 10487	 0.0017	 0.02819	 0.0	 1119	 1119	 1119	 0.0	 0.0	 1	 -30.0	 30.0;
	7769	 3066	 0.0017	 0.02819	 0.0	 1119	 1119	 1119	 0.0	 0.0	 1	 -30.0	 30.0;
	12424	 2928	 0.00049	 0.00496	 0.0	 6338	 6338	 6338	 0.0	 0.0	 1	 -30.0	 30.0;
	12424	 9803	 0.00139	 0.01098	 0.0	 2855	 2855	 2855	 0.0	 0.0	 1	 -30.0	 30.0;
	12424	 8705	 0.00031	 0.00329	 0.0	 9559	 9559	 9559	 0.0	 0.0	 1	 -30.0	 30.0;
	12424	 9529	 0.00424	 0.0202	 0.0	 1531	 1531	 1531	 0.0	 0.0	 1	 -30.0	 30.0;
	12424	 9529	 0.00424	 0.0202	 0.0	 1531	 1531	 1531	 0.0	 0.0	 1	 -30.0	 30.0;
	12424	 5233	 0.01197	 0.05705	 0.0	 542	 542	 542	 0.0	 0.0	 1	 -30.0	 30.0;
	12424	 7763	 0.00052	 0.00561	 0.0	 5607	 5607	 5607	 0.0	 0.0	 1	 -30.0	 30.0;
	5469	 9803	 0.00199	 0.01569	 0.0	 1998	 1998	 1998	 0.0	 0.0	 1	 -30.0	 30.0;
	5469	 9803	 0.00139	 0.01098	 0.0	 2855	 2855	 2855	 0.0	 0.0	 1	 -30.0	 30.0;
	5469	 8808	 0.00255	 0.02008	 0.0	 1561	 1561	 1561	 0.0	 0.0	 1	 -30.0	 30.0;
	5469	 8808	 0.00777	 0.02495	 0.0	 1209	 1209	 1209	 0.0	 0.0	 1	 -30.0	 30.0;
	5469	 8808	 0.00255	 0.02008	 0.0	 1561	 1561	 1561	 0.0	 0.0	 1	 -30.0	 30.0;
	5469	 8808	 0.00777	 0.02495	 0.0	 1209	 1209	 1209	 0.0	 0.0	 1	 -30.0	 30.0;
	2928	 9803	 0.00475	 0.02262	 0.0	 1367	 1367	 1367	 0.0	 0.0	 1	 -30.0	 30.0;
	2928	 8303	 0.00031	 0.00329	 0.0	 9559	 9559	 9559	 0.0	 0.0	 1	 -30.0	 30.0;
	2928	 5233	 0.0101	 0.04816	 0.0	 642	 642	 642	 0.0	 0.0	 1	 -30.0	 30.0;
	3964	 9529	 0.00929	 0.04428	 0.0	 699	 699	 699	 0.0	 0.0	 1	 -30.0	 30.0;
	3964	 13457	 0.01119	 0.05333	 0.0	 580	 580	 580	 0.0	 0.0	 1	 -30.0	 30.0;
	6244	 6781	 0.00468	 0.03687	 0.0	 850	 850	 850	 0.0	 0.0	 1	 -30.0	 30.0;
	6244	 12868	 0.00225	 0.00723	 0.0	 4172	 4172	 4172	 0.0	 0.0	 1	 -30.0	 30.0;
	6244	 12967	 0.05517	 0.17718	 0.0	 171	 171	 171	 0.0	 0.0	 1	 -30.0	 30.0;
	13044	 13	 0.01616	 0.05189	 0.0	 582	 582	 582	 0.0	 0.0	 1	 -30.0	 30.0;
	13044	 5233	 0.03603	 0.11571	 0.0	 261	 261	 261	 0.0	 0.0	 1	 -30.0	 30.0;
	13184	 3562	 0.00263	 0.02071	 0.0	 1514	 1514	 1514	 0.0	 0.0	 1	 -30.0	 30.0;
	13184	 629	 0.00508	 0.02424	 0.0	 1276	 1276	 1276	 0.0	 0.0	 1	 -30.0	 30.0;
	13	 6730	 0.00545	 0.04299	 0.0	 729	 729	 729	 0.0	 0.0	 1	 -30.0	 30.0;
	13297	 3562	 0.01505	 0.07175	 0.0	 431	 431	 431	 0.0	 0.0	 1	 -30.0	 30.0;
	13297	 3562	 0.01505	 0.07175	 0.0	 431	 431	 431	 0.0	 0.0	 1	 -30.0	 30.0;
	11188	 1746	 0.01431	 0.0682	 0.0	 454	 454	 454	 0.0	 0.0	 1	 -30.0	 30.0;
	11188	 3315	 0.00267	 0.02103	 0.0	 1491	 1491	 1491	 0.0	 0.0	 1	 -30.0	 30.0;
	11188	 3315	 0.00267	 0.02103	 0.0	 1491	 1491	 1491	 0.0	 0.0	 1	 -30.0	 30.0;
	3317	 7972	 0.00346	 0.04406	 0.0	 715	 715	 715	 0.0	 0.0	 1	 -30.0	 30.0;
	3562	 629	 0.00332	 0.0262	 0.0	 1197	 1197	 1197	 0.0	 0.0	 1	 -30.0	 30.0;
	3562	 8166	 0.00895	 0.07061	 0.0	 444	 444	 444	 0.0	 0.0	 1	 -30.0	 30.0;
	3562	 6647	 0.00298	 0.02354	 0.0	 1332	 1332	 1332	 0.0	 0.0	 1	 -30.0	 30.0;
	2704	 9369	 0.00079	 0.00253	 0.0	 11918	 11918	 11918	 0.0	 0.0	 1	 -30.0	 30.0;
	2704	 11356	 0.00451	 0.02149	 0.0	 1439	 1439	 1439	 0.0	 0.0	 1	 -30.0	 30.0;
	2704	 10703	 0.01458	 0.06949	 0.0	 445	 445	 445	 0.0	 0.0	 1	 -30.0	 30.0;
	1746	 11356	 0.02044	 0.06563	 0.0	 460	 460	 460	 0.0	 0.0	 1	 -30.0	 30.0;
	1746	 1174	 0.03316	 0.10649	 0.0	 284	 284	 284	 0.0	 0.0	 1	 -30.0	 30.0;
	11356	 13457	 0.00441	 0.02101	 0.0	 1472	 1472	 1472	 0.0	 0.0	 1	 -30.0	 30.0;
	11356	 13457	 0.00441	 0.02101	 0.0	 1472	 1472	 1472	 0.0	 0.0	 1	 -30.0	 30.0;
	11356	 9180	 0.02373	 0.11312	 0.0	 274	 274	 274	 0.0	 0.0	 1	 -30.0	 30.0;
	9803	 7893	 0.00251	 0.01977	 0.0	 1586	 1586	 1586	 0.0	 0.0	 1	 -30.0	 30.0;
	9803	 3315	 0.00298	 0.02354	 0.0	 1332	 1332	 1332	 0.0	 0.0	 1	 -30.0	 30.0;
	9529	 8169	 0.00607	 0.02893	 0.0	 1069	 1069	 1069	 0.0	 0.0	 1	 -30.0	 30.0;
	9529	 7763	 0.0003	 0.0032	 0.0	 9828	 9828	 9828	 0.0	 0.0	 1	 -30.0	 30.0;
	7893	 3315	 0.00106	 0.00832	 0.0	 3767	 3767	 3767	 0.0	 0.0	 1	 -30.0	 30.0;
	6781	 6958	 0.00762	 0.06009	 0.0	 522	 522	 522	 0.0	 0.0	 1	 -30.0	 30.0;
	8808	 11843	 0.00524	 0.03214	 0.0	 970	 970	 970	 0.0	 0.0	 1	 -30.0	 30.0;
	8808	 11843	 0.00524	 0.03214	 0.0	 970	 970	 970	 0.0	 0.0	 1	 -30.0	 30.0;
	8808	 5533	 0.00068	 0.00323	 0.0	 9570	 9570	 9570	 0.0	 0.0	 1	 -30.0	 30.0;
	9328	 5233	 0.00526	 0.02505	 0.0	 1235	 1235	 1235	 0.0	 0.0	 1	 -30.0	 30.0;
	9328	 5233	 0.00526	 0.02505	 0.0	 1235	 1235	 1235	 0.0	 0.0	 1	 -30.0	 30.0;
	9328	 6958	 0.00345	 0.0353	 0.0	 891	 891	 891	 0.0	 0.0	 1	 -30.0	 30.0;
	9328	 6958	 0.00345	 0.0353	 0.0	 891	 891	 891	 0.0	 0.0	 1	 -30.0	 30.0;
	9328	 9495	 0.00122	 0.01306	 0.0	 2409	 2409	 2409	 0.0	 0.0	 1	 -30.0	 30.0;
	9328	 9495	 0.00122	 0.01306	 0.0	 2409	 2409	 2409	 0.0	 0.0	 1	 -30.0	 30.0;
	11843	 3315	 0.00796	 0.06276	 0.0	 500	 500	 500	 0.0	 0.0	 1	 -30.0	 30.0;
	8166	 6647	 0.00677	 0.05335	 0.0	 588	 588	 588	 0.0	 0.0	 1	 -30.0	 30.0;
	3315	 9990	 0.00239	 0.01883	 0.0	 1665	 1665	 1665	 0.0	 0.0	 1	 -30.0	 30.0;
	3315	 12623	 0.00239	 0.01883	 0.0	 1665	 1665	 1665	 0.0	 0.0	 1	 -30.0	 30.0;
	12868	 13450	 0.01407	 0.0452	 0.0	 668	 668	 668	 0.0	 0.0	 1	 -30.0	 30.0;
	13457	 8169	 0.00763	 0.03636	 0.0	 851	 851	 851	 0.0	 0.0	 1	 -30.0	 30.0;
	9990	 7763	 0.00022	 0.0024	 0.0	 13107	 13107	 13107	 0.0	 0.0	 1	 -30.0	 30.0;
	12623	 7763	 0.00022	 0.0024	 0.0	 13107	 13107	 13107	 0.0	 0.0	 1	 -30.0	 30.0;
	12096	 1652	 0.00282	 0.03584	 0.0	 879	 879	 879	 0.0	 0.0	 1	 -30.0	 30.0;
	12096	 11647	 0.0	 -0.0228	 0.0	 1386	 1386	 1386	 0.0	 0.0	 1	 -30.0	 30.0;
	7972	 11647	 0.0	 -0.0228	 0.0	 1386	 1386	 1386	 0.0	 0.0	 1	 -30.0	 30.0;
	12230	 11647	 0.0	 -0.0228	 0.0	 1386	 1386	 1386	 0.0	 0.0	 1	 -30.0	 30.0;
	12230	 6634	 0.00219	 0.02793	 0.0	 1128	 1128	 1128	 0.0	 0.0	 1	 -30.0	 30.0;
	11647	 8026	 0.00198	 0.02025	 0.0	 1553	 1553	 1553	 0.0	 0.0	 1	 -30.0	 30.0;
	11647	 2129	 0.00248	 0.02534	 0.0	 1241	 1241	 1241	 0.0	 0.0	 1	 -30.0	 30.0;
	6718	 639	 0.02365	 0.07594	 0.0	 398	 398	 398	 0.0	 0.0	 1	 -30.0	 30.0;
	6718	 8363	 0.0532	 0.17086	 0.0	 177	 177	 177	 0.0	 0.0	 1	 -30.0	 30.0;
	4271	 11833	 0.02252	 0.07232	 0.0	 418	 418	 418	 0.0	 0.0	 1	 -30.0	 30.0;
	4271	 9252	 0.02252	 0.07232	 0.0	 418	 418	 418	 0.0	 0.0	 1	 -30.0	 30.0;
	10880	 12927	 0.02624	 0.08425	 0.0	 358	 358	 358	 0.0	 0.0	 1	 -30.0	 30.0;
	10880	 10777	 0.00951	 0.03056	 0.0	 987	 987	 987	 0.0	 0.0	 1	 -30.0	 30.0;
	10880	 20	 0.01802	 0.05786	 0.0	 522	 522	 522	 0.0	 0.0	 1	 -30.0	 30.0;
	13438	 12154	 0.00845	 0.02712	 0.0	 1112	 1112	 1112	 0.0	 0.0	 1	 -30.0	 30.0;
	13438	 908	 0.02736	 0.08787	 0.0	 344	 344	 344	 0.0	 0.0	 1	 -30.0	 30.0;
	1601	 9462	 0.01393	 0.10983	 0.0	 286	 286	 286	 0.0	 0.0	 1	 -30.0	 30.0;
	1601	 5985	 0.0131	 0.08035	 0.0	 388	 388	 388	 0.0	 0.0	 1	 -30.0	 30.0;
	1601	 9800	 0.01847	 0.0593	 0.0	 509	 509	 509	 0.0	 0.0	 1	 -30.0	 30.0;
	1174	 2117	 0.06942	 0.22293	 0.0	 136	 136	 136	 0.0	 0.0	 1	 -30.0	 30.0;
	1174	 12608	 0.0183	 0.05876	 0.0	 514	 514	 514	 0.0	 0.0	 1	 -30.0	 30.0;
	1174	 11890	 0.04065	 0.13054	 0.0	 232	 232	 232	 0.0	 0.0	 1	 -30.0	 30.0;
	2117	 11833	 0.01098	 0.03526	 0.0	 856	 856	 856	 0.0	 0.0	 1	 -30.0	 30.0;
	2117	 12154	 0.03665	 0.1177	 0.0	 257	 257	 257	 0.0	 0.0	 1	 -30.0	 30.0;
	2117	 908	 0.03001	 0.09637	 0.0	 313	 313	 313	 0.0	 0.0	 1	 -30.0	 30.0;
	2117	 10549	 0.00478	 0.03766	 0.0	 833	 833	 833	 0.0	 0.0	 1	 -30.0	 30.0;
	2117	 10549	 0.00478	 0.03766	 0.0	 833	 833	 833	 0.0	 0.0	 1	 -30.0	 30.0;
	11833	 12154	 0.01592	 0.12552	 0.0	 250	 250	 250	 0.0	 0.0	 1	 -30.0	 30.0;
	12927	 8449	 0.04189	 0.13452	 0.0	 225	 225	 225	 0.0	 0.0	 1	 -30.0	 30.0;
	12154	 5458	 0.02049	 0.06581	 0.0	 459	 459	 459	 0.0	 0.0	 1	 -30.0	 30.0;
	10777	 292	 0.06227	 0.19997	 0.0	 151	 151	 151	 0.0	 0.0	 1	 -30.0	 30.0;
	12608	 4500	 0.03806	 0.12222	 0.0	 247	 247	 247	 0.0	 0.0	 1	 -30.0	 30.0;
	12608	 2910	 0.01393	 0.10983	 0.0	 286	 286	 286	 0.0	 0.0	 1	 -30.0	 30.0;
	7799	 639	 0.01671	 0.07967	 0.0	 389	 389	 389	 0.0	 0.0	 1	 -30.0	 30.0;
	7799	 4930	 0.02712	 0.12928	 0.0	 240	 240	 240	 0.0	 0.0	 1	 -30.0	 30.0;
	639	 6396	 0.03361	 0.10794	 0.0	 280	 280	 280	 0.0	 0.0	 1	 -30.0	 30.0;
	9462	 9252	 0.01204	 0.05737	 0.0	 539	 539	 539	 0.0	 0.0	 1	 -30.0	 30.0;
	20	 5458	 0.02522	 0.081	 0.0	 373	 373	 373	 0.0	 0.0	 1	 -30.0	 30.0;
	20	 8363	 0.00591	 0.01898	 0.0	 1589	 1589	 1589	 0.0	 0.0	 1	 -30.0	 30.0;
	20	 6164	 0.04375	 0.14048	 0.0	 215	 215	 215	 0.0	 0.0	 1	 -30.0	 30.0;
	6479	 10609	 0.01171	 0.03761	 0.0	 802	 802	 802	 0.0	 0.0	 1	 -30.0	 30.0;
	6479	 8877	 0.03389	 0.10884	 0.0	 278	 278	 278	 0.0	 0.0	 1	 -30.0	 30.0;
	10609	 9252	 0.01019	 0.03272	 0.0	 922	 922	 922	 0.0	 0.0	 1	 -30.0	 30.0;
	5985	 3033	 0.0131	 0.08035	 0.0	 388	 388	 388	 0.0	 0.0	 1	 -30.0	 30.0;
	6874	 10487	 0.0	 -0.03116	 0.0	 1014	 1014	 1014	 0.0	 0.0	 1	 -30.0	 30.0;
	6874	 13337	 0.00123	 0.02042	 0.0	 1545	 1545	 1545	 0.0	 0.0	 1	 -30.0	 30.0;
	13231	 3066	 0.0	 -0.03116	 0.0	 1014	 1014	 1014	 0.0	 0.0	 1	 -30.0	 30.0;
	13231	 13337	 0.00123	 0.02042	 0.0	 1545	 1545	 1545	 0.0	 0.0	 1	 -30.0	 30.0;
	2202	 12486	 0.0	 -0.0228	 0.0	 1386	 1386	 1386	 0.0	 0.0	 1	 -30.0	 30.0;
	2202	 8817	 0.0	 -0.0228	 0.0	 1386	 1386	 1386	 0.0	 0.0	 1	 -30.0	 30.0;
	1618	 6223	 0.0	 -0.023	 0.0	 1374	 1374	 1374	 0.0	 0.0	 1	 -30.0	 30.0;
	1618	 9905	 0.0	 -0.023	 0.0	 1374	 1374	 1374	 0.0	 0.0	 1	 -30.0	 30.0;
	12486	 1036	 0.00262	 0.03338	 0.0	 944	 944	 944	 0.0	 0.0	 1	 -30.0	 30.0;
	9905	 10726	 0.00266	 0.03382	 0.0	 932	 932	 932	 0.0	 0.0	 1	 -30.0	 30.0;
	12844	 6395	 0.0	 -0.0242	 0.0	 1306	 1306	 1306	 0.0	 0.0	 1	 -30.0	 30.0;
	7647	 6395	 0.0	 -0.0242	 0.0	 1306	 1306	 1306	 0.0	 0.0	 1	 -30.0	 30.0;
	6395	 1036	 0.00287	 0.02938	 0.0	 1071	 1071	 1071	 0.0	 0.0	 1	 -30.0	 30.0;
	6395	 8751	 0.00544	 0.05508	 0.0	 571	 571	 571	 0.0	 0.0	 1	 -30.0	 30.0;
	6395	 8751	 0.00544	 0.05508	 0.0	 571	 571	 571	 0.0	 0.0	 1	 -30.0	 30.0;
	13337	 1365	 0.00139	 0.02301	 0.0	 1371	 1371	 1371	 0.0	 0.0	 1	 -30.0	 30.0;
	13337	 7644	 0.00139	 0.02301	 0.0	 1371	 1371	 1371	 0.0	 0.0	 1	 -30.0	 30.0;
	13337	 4417	 0.00099	 0.01644	 0.0	 1918	 1918	 1918	 0.0	 0.0	 1	 -30.0	 30.0;
	13337	 10351	 0.00294	 0.03741	 0.0	 842	 842	 842	 0.0	 0.0	 1	 -30.0	 30.0;
	9583	 3033	 0.02252	 0.07232	 0.0	 418	 418	 418	 0.0	 0.0	 1	 -30.0	 30.0;
	9583	 9800	 0.0174	 0.05587	 0.0	 540	 540	 540	 0.0	 0.0	 1	 -30.0	 30.0;
	9583	 6396	 0.02509	 0.11958	 0.0	 259	 259	 259	 0.0	 0.0	 1	 -30.0	 30.0;
	9583	 9564	 0.00902	 0.04299	 0.0	 720	 720	 720	 0.0	 0.0	 1	 -30.0	 30.0;
	9583	 9564	 0.00902	 0.04299	 0.0	 720	 720	 720	 0.0	 0.0	 1	 -30.0	 30.0;
	9583	 598	 0.04087	 0.13126	 0.0	 230	 230	 230	 0.0	 0.0	 1	 -30.0	 30.0;
	9583	 10528	 0.02196	 0.07051	 0.0	 428	 428	 428	 0.0	 0.0	 1	 -30.0	 30.0;
	3573	 11079	 0.01582	 0.0508	 0.0	 594	 594	 594	 0.0	 0.0	 1	 -30.0	 30.0;
	3573	 972	 0.04712	 0.15133	 0.0	 200	 200	 200	 0.0	 0.0	 1	 -30.0	 30.0;
	3033	 231	 0.02055	 0.06599	 0.0	 458	 458	 458	 0.0	 0.0	 1	 -30.0	 30.0;
	3033	 6901	 0.00339	 0.01616	 0.0	 1914	 1914	 1914	 0.0	 0.0	 1	 -30.0	 30.0;
	3033	 6901	 0.00339	 0.01616	 0.0	 1914	 1914	 1914	 0.0	 0.0	 1	 -30.0	 30.0;
	3033	 1703	 0.01098	 0.03526	 0.0	 856	 856	 856	 0.0	 0.0	 1	 -30.0	 30.0;
	5684	 8877	 0.03271	 0.10504	 0.0	 288	 288	 288	 0.0	 0.0	 1	 -30.0	 30.0;
	5684	 5851	 0.02145	 0.06888	 0.0	 438	 438	 438	 0.0	 0.0	 1	 -30.0	 30.0;
	5684	 10703	 0.00644	 0.0307	 0.0	 1007	 1007	 1007	 0.0	 0.0	 1	 -30.0	 30.0;
	5684	 9180	 0.00644	 0.0307	 0.0	 1007	 1007	 1007	 0.0	 0.0	 1	 -30.0	 30.0;
	5684	 2311	 0.03029	 0.09727	 0.0	 311	 311	 311	 0.0	 0.0	 1	 -30.0	 30.0;
	6396	 231	 0.00255	 0.02008	 0.0	 1561	 1561	 1561	 0.0	 0.0	 1	 -30.0	 30.0;
	6396	 231	 0.00434	 0.02069	 0.0	 1495	 1495	 1495	 0.0	 0.0	 1	 -30.0	 30.0;
	6396	 231	 0.00434	 0.02069	 0.0	 1495	 1495	 1495	 0.0	 0.0	 1	 -30.0	 30.0;
	4249	 231	 0.01633	 0.05243	 0.0	 576	 576	 576	 0.0	 0.0	 1	 -30.0	 30.0;
	231	 6901	 0.00729	 0.03474	 0.0	 890	 890	 890	 0.0	 0.0	 1	 -30.0	 30.0;
	231	 6901	 0.00729	 0.03474	 0.0	 890	 890	 890	 0.0	 0.0	 1	 -30.0	 30.0;
	6901	 1942	 0.00034	 0.00162	 0.0	 19083	 19083	 19083	 0.0	 0.0	 1	 -30.0	 30.0;
	6901	 1942	 0.00034	 0.00162	 0.0	 19083	 19083	 19083	 0.0	 0.0	 1	 -30.0	 30.0;
	12215	 10703	 0.00085	 0.00404	 0.0	 7652	 7652	 7652	 0.0	 0.0	 1	 -30.0	 30.0;
	12215	 9180	 0.00085	 0.00404	 0.0	 7652	 7652	 7652	 0.0	 0.0	 1	 -30.0	 30.0;
	8877	 598	 0.00501	 0.01609	 0.0	 1875	 1875	 1875	 0.0	 0.0	 1	 -30.0	 30.0;
	1169	 11079	 0.02015	 0.06473	 0.0	 466	 466	 466	 0.0	 0.0	 1	 -30.0	 30.0;
	1169	 10528	 0.01407	 0.0452	 0.0	 668	 668	 668	 0.0	 0.0	 1	 -30.0	 30.0;
	11079	 7710	 0.00935	 0.07374	 0.0	 425	 425	 425	 0.0	 0.0	 1	 -30.0	 30.0;
	8507	 1703	 0.01042	 0.03345	 0.0	 902	 902	 902	 0.0	 0.0	 1	 -30.0	 30.0;
	8507	 7710	 0.01478	 0.07046	 0.0	 439	 439	 439	 0.0	 0.0	 1	 -30.0	 30.0;
	5851	 972	 0.04572	 0.14681	 0.0	 206	 206	 206	 0.0	 0.0	 1	 -30.0	 30.0;
	7710	 11683	 0.01029	 0.08112	 0.0	 387	 387	 387	 0.0	 0.0	 1	 -30.0	 30.0;
	7710	 11683	 0.01029	 0.08112	 0.0	 387	 387	 387	 0.0	 0.0	 1	 -30.0	 30.0;
	7710	 10528	 0.00836	 0.0659	 0.0	 476	 476	 476	 0.0	 0.0	 1	 -30.0	 30.0;
	6028	 2748	 0.0	 -0.0207	 0.0	 1526	 1526	 1526	 0.0	 0.0	 1	 -30.0	 30.0;
	2748	 2162	 0.00193	 0.01978	 0.0	 1590	 1590	 1590	 0.0	 0.0	 1	 -30.0	 30.0;
	2748	 8641	 0.00224	 0.02269	 0.0	 1386	 1386	 1386	 0.0	 0.0	 1	 -30.0	 30.0;
	11389	 12569	 0.01071	 0.08441	 0.0	 372	 372	 372	 0.0	 0.0	 1	 -30.0	 30.0;
	3000	 2644	 0.02733	 0.09705	 0.0	 314	 314	 314	 0.0	 0.0	 1	 -30.0	 30.0;
	3000	 2311	 0.03029	 0.09727	 0.0	 311	 311	 311	 0.0	 0.0	 1	 -30.0	 30.0;
	13299	 11006	 0.02308	 0.07413	 0.0	 407	 407	 407	 0.0	 0.0	 1	 -30.0	 30.0;
	13299	 2644	 0.02305	 0.08331	 0.0	 366	 366	 366	 0.0	 0.0	 1	 -30.0	 30.0;
	7043	 1622	 0.03288	 0.10559	 0.0	 286	 286	 286	 0.0	 0.0	 1	 -30.0	 30.0;
	7043	 8728	 0.0077	 0.04725	 0.0	 660	 660	 660	 0.0	 0.0	 1	 -30.0	 30.0;
	7043	 11359	 0.00796	 0.06276	 0.0	 500	 500	 500	 0.0	 0.0	 1	 -30.0	 30.0;
	7043	 13587	 0.00648	 0.02079	 0.0	 1451	 1451	 1451	 0.0	 0.0	 1	 -30.0	 30.0;
	6270	 9629	 0.00895	 0.07061	 0.0	 444	 444	 444	 0.0	 0.0	 1	 -30.0	 30.0;
	6270	 13050	 0.01407	 0.0452	 0.0	 668	 668	 668	 0.0	 0.0	 1	 -30.0	 30.0;
	1622	 8411	 0.00816	 0.02622	 0.0	 1151	 1151	 1151	 0.0	 0.0	 1	 -30.0	 30.0;
	1622	 9629	 0.00959	 0.07563	 0.0	 415	 415	 415	 0.0	 0.0	 1	 -30.0	 30.0;
	1622	 10441	 0.01017	 0.04848	 0.0	 638	 638	 638	 0.0	 0.0	 1	 -30.0	 30.0;
	5016	 3784	 0.01786	 0.08516	 0.0	 364	 364	 364	 0.0	 0.0	 1	 -30.0	 30.0;
	5016	 8728	 0.01926	 0.11812	 0.0	 264	 264	 264	 0.0	 0.0	 1	 -30.0	 30.0;
	4866	 1221	 0.00239	 0.01883	 0.0	 1665	 1665	 1665	 0.0	 0.0	 1	 -30.0	 30.0;
	4866	 1221	 0.00239	 0.01883	 0.0	 1665	 1665	 1665	 0.0	 0.0	 1	 -30.0	 30.0;
	4866	 12569	 0.04076	 0.1309	 0.0	 231	 231	 231	 0.0	 0.0	 1	 -30.0	 30.0;
	4866	 8728	 0.00814	 0.06417	 0.0	 489	 489	 489	 0.0	 0.0	 1	 -30.0	 30.0;
	1221	 11006	 0.00776	 0.06119	 0.0	 513	 513	 513	 0.0	 0.0	 1	 -30.0	 30.0;
	11006	 8728	 0.00665	 0.04082	 0.0	 764	 764	 764	 0.0	 0.0	 1	 -30.0	 30.0;
	11006	 8728	 0.00665	 0.04082	 0.0	 764	 764	 764	 0.0	 0.0	 1	 -30.0	 30.0;
	3784	 8411	 0.04943	 0.15874	 0.0	 190	 190	 190	 0.0	 0.0	 1	 -30.0	 30.0;
	12569	 7650	 0.02196	 0.07051	 0.0	 428	 428	 428	 0.0	 0.0	 1	 -30.0	 30.0;
	12569	 13587	 0.04155	 0.13343	 0.0	 227	 227	 227	 0.0	 0.0	 1	 -30.0	 30.0;
	2162	 10351	 0.0	 -0.01731	 0.0	 1825	 1825	 1825	 0.0	 0.0	 1	 -30.0	 30.0;
	8728	 3387	 0.01127	 0.0691	 0.0	 452	 452	 452	 0.0	 0.0	 1	 -30.0	 30.0;
	7650	 10125	 0.04279	 0.13741	 0.0	 220	 220	 220	 0.0	 0.0	 1	 -30.0	 30.0;
	8375	 13587	 0.00113	 0.00362	 0.0	 8330	 8330	 8330	 0.0	 0.0	 1	 -30.0	 30.0;
	8181	 8930	 0.00108	 0.00847	 0.0	 3700	 3700	 3700	 0.0	 0.0	 1	 -30.0	 30.0;
	8181	 3554	 0.05089	 0.16344	 0.0	 185	 185	 185	 0.0	 0.0	 1	 -30.0	 30.0;
	8930	 5580	 0.05315	 0.17067	 0.0	 177	 177	 177	 0.0	 0.0	 1	 -30.0	 30.0;
	8930	 10199	 0.00995	 0.07845	 0.0	 400	 400	 400	 0.0	 0.0	 1	 -30.0	 30.0;
	10125	 5580	 0.03406	 0.10938	 0.0	 276	 276	 276	 0.0	 0.0	 1	 -30.0	 30.0;
	10125	 13515	 0.00966	 0.04606	 0.0	 672	 672	 672	 0.0	 0.0	 1	 -30.0	 30.0;
	10125	 11173	 0.03429	 0.11011	 0.0	 274	 274	 274	 0.0	 0.0	 1	 -30.0	 30.0;
	3554	 8160	 0.01858	 0.05966	 0.0	 506	 506	 506	 0.0	 0.0	 1	 -30.0	 30.0;
	3554	 9675	 0.00466	 0.03672	 0.0	 854	 854	 854	 0.0	 0.0	 1	 -30.0	 30.0;
	2927	 81	 0.01485	 0.07078	 0.0	 437	 437	 437	 0.0	 0.0	 1	 -30.0	 30.0;
	2927	 4474	 0.01509	 0.04845	 0.0	 623	 623	 623	 0.0	 0.0	 1	 -30.0	 30.0;
	2927	 7119	 0.01824	 0.05858	 0.0	 515	 515	 515	 0.0	 0.0	 1	 -30.0	 30.0;
	2927	 7457	 0.01464	 0.04701	 0.0	 642	 642	 642	 0.0	 0.0	 1	 -30.0	 30.0;
	81	 11876	 0.00432	 0.03405	 0.0	 921	 921	 921	 0.0	 0.0	 1	 -30.0	 30.0;
	81	 10716	 0.01183	 0.0564	 0.0	 549	 549	 549	 0.0	 0.0	 1	 -30.0	 30.0;
	5580	 12967	 0.03367	 0.10812	 0.0	 279	 279	 279	 0.0	 0.0	 1	 -30.0	 30.0;
	5580	 10199	 0.04712	 0.15133	 0.0	 200	 200	 200	 0.0	 0.0	 1	 -30.0	 30.0;
	8160	 7119	 0.0165	 0.05297	 0.0	 570	 570	 570	 0.0	 0.0	 1	 -30.0	 30.0;
	8160	 2207	 0.02204	 0.10504	 0.0	 295	 295	 295	 0.0	 0.0	 1	 -30.0	 30.0;
	11876	 9675	 0.00219	 0.01726	 0.0	 1816	 1816	 1816	 0.0	 0.0	 1	 -30.0	 30.0;
	11876	 1698	 0.00225	 0.00723	 0.0	 4172	 4172	 4172	 0.0	 0.0	 1	 -30.0	 30.0;
	4474	 8539	 0.00715	 0.02296	 0.0	 1314	 1314	 1314	 0.0	 0.0	 1	 -30.0	 30.0;
	9675	 10199	 0.01791	 0.14121	 0.0	 222	 222	 222	 0.0	 0.0	 1	 -30.0	 30.0;
	13515	 2207	 0.01356	 0.06464	 0.0	 479	 479	 479	 0.0	 0.0	 1	 -30.0	 30.0;
	9367	 3888	 0.01768	 0.05677	 0.0	 532	 532	 532	 0.0	 0.0	 1	 -30.0	 30.0;
	9367	 4335	 0.0103	 0.03309	 0.0	 912	 912	 912	 0.0	 0.0	 1	 -30.0	 30.0;
	8026	 2129	 0.00124	 0.01579	 0.0	 1995	 1995	 1995	 0.0	 0.0	 1	 -30.0	 30.0;
	2129	 4820	 0.00037	 0.00374	 0.0	 8405	 8405	 8405	 0.0	 0.0	 1	 -30.0	 30.0;
	2129	 4820	 0.00037	 0.00374	 0.0	 8405	 8405	 8405	 0.0	 0.0	 1	 -30.0	 30.0;
	2129	 5088	 0.00207	 0.03419	 0.0	 923	 923	 923	 0.0	 0.0	 1	 -30.0	 30.0;
	9927	 3888	 0.00946	 0.04509	 0.0	 686	 686	 686	 0.0	 0.0	 1	 -30.0	 30.0;
	9927	 5820	 0.00576	 0.02747	 0.0	 1126	 1126	 1126	 0.0	 0.0	 1	 -30.0	 30.0;
	7248	 10369	 0.02387	 0.07666	 0.0	 394	 394	 394	 0.0	 0.0	 1	 -30.0	 30.0;
	7248	 7578	 0.04842	 0.15549	 0.0	 194	 194	 194	 0.0	 0.0	 1	 -30.0	 30.0;
	3888	 5820	 0.00508	 0.02424	 0.0	 1276	 1276	 1276	 0.0	 0.0	 1	 -30.0	 30.0;
	3888	 10369	 0.05444	 0.17483	 0.0	 173	 173	 173	 0.0	 0.0	 1	 -30.0	 30.0;
	9071	 12157	 0.0326	 0.10468	 0.0	 289	 289	 289	 0.0	 0.0	 1	 -30.0	 30.0;
	9071	 9300	 0.02269	 0.07286	 0.0	 414	 414	 414	 0.0	 0.0	 1	 -30.0	 30.0;
	11535	 3624	 0.01831	 0.08726	 0.0	 355	 355	 355	 0.0	 0.0	 1	 -30.0	 30.0;
	11535	 6444	 0.04183	 0.13433	 0.0	 225	 225	 225	 0.0	 0.0	 1	 -30.0	 30.0;
	8449	 7697	 0.00513	 0.04048	 0.0	 775	 775	 775	 0.0	 0.0	 1	 -30.0	 30.0;
	8449	 767	 0.00169	 0.00542	 0.0	 5564	 5564	 5564	 0.0	 0.0	 1	 -30.0	 30.0;
	8449	 13178	 0.00541	 0.04268	 0.0	 735	 735	 735	 0.0	 0.0	 1	 -30.0	 30.0;
	8449	 3565	 0.00396	 0.03122	 0.0	 1004	 1004	 1004	 0.0	 0.0	 1	 -30.0	 30.0;
	8449	 168	 0.02288	 0.10908	 0.0	 284	 284	 284	 0.0	 0.0	 1	 -30.0	 30.0;
	8449	 9854	 0.02881	 0.13736	 0.0	 226	 226	 226	 0.0	 0.0	 1	 -30.0	 30.0;
	11964	 2910	 0.03941	 0.12656	 0.0	 239	 239	 239	 0.0	 0.0	 1	 -30.0	 30.0;
	11964	 9300	 0.01396	 0.04484	 0.0	 673	 673	 673	 0.0	 0.0	 1	 -30.0	 30.0;
	12157	 4996	 0.03969	 0.12746	 0.0	 237	 237	 237	 0.0	 0.0	 1	 -30.0	 30.0;
	4	 3507	 0.00034	 0.00162	 0.0	 19083	 19083	 19083	 0.0	 0.0	 1	 -30.0	 30.0;
	4	 7182	 0.00051	 0.00242	 0.0	 12773	 12773	 12773	 0.0	 0.0	 1	 -30.0	 30.0;
	2860	 6382	 0.02145	 0.06888	 0.0	 438	 438	 438	 0.0	 0.0	 1	 -30.0	 30.0;
	2860	 1461	 0.00518	 0.01663	 0.0	 1814	 1814	 1814	 0.0	 0.0	 1	 -30.0	 30.0;
	2860	 3507	 0.00085	 0.00404	 0.0	 7652	 7652	 7652	 0.0	 0.0	 1	 -30.0	 30.0;
	2860	 7182	 0.00052	 0.00246	 0.0	 12563	 12563	 12563	 0.0	 0.0	 1	 -30.0	 30.0;
	2860	 5894	 0.00555	 0.04377	 0.0	 716	 716	 716	 0.0	 0.0	 1	 -30.0	 30.0;
	3235	 4500	 0.02252	 0.07232	 0.0	 418	 418	 418	 0.0	 0.0	 1	 -30.0	 30.0;
	3235	 12564	 0.0165	 0.05297	 0.0	 570	 570	 570	 0.0	 0.0	 1	 -30.0	 30.0;
	4500	 12356	 0.02398	 0.07702	 0.0	 392	 392	 392	 0.0	 0.0	 1	 -30.0	 30.0;
	12356	 2910	 0.00822	 0.0264	 0.0	 1143	 1143	 1143	 0.0	 0.0	 1	 -30.0	 30.0;
	11612	 908	 0.04954	 0.1591	 0.0	 190	 190	 190	 0.0	 0.0	 1	 -30.0	 30.0;
	11612	 11890	 0.0237	 0.07612	 0.0	 397	 397	 397	 0.0	 0.0	 1	 -30.0	 30.0;
	5558	 3624	 0.02117	 0.06798	 0.0	 444	 444	 444	 0.0	 0.0	 1	 -30.0	 30.0;
	5558	 11890	 0.02809	 0.09022	 0.0	 335	 335	 335	 0.0	 0.0	 1	 -30.0	 30.0;
	5558	 3459	 0.01126	 0.03616	 0.0	 835	 835	 835	 0.0	 0.0	 1	 -30.0	 30.0;
	4996	 3459	 0.01278	 0.04104	 0.0	 735	 735	 735	 0.0	 0.0	 1	 -30.0	 30.0;
	4996	 7578	 0.0036	 0.01157	 0.0	 2607	 2607	 2607	 0.0	 0.0	 1	 -30.0	 30.0;
	11960	 908	 0.02871	 0.09221	 0.0	 328	 328	 328	 0.0	 0.0	 1	 -30.0	 30.0;
	11960	 4335	 0.03384	 0.10866	 0.0	 278	 278	 278	 0.0	 0.0	 1	 -30.0	 30.0;
	908	 4335	 0.04971	 0.15965	 0.0	 189	 189	 189	 0.0	 0.0	 1	 -30.0	 30.0;
	908	 6444	 0.01576	 0.05062	 0.0	 596	 596	 596	 0.0	 0.0	 1	 -30.0	 30.0;
	4335	 7697	 0.00306	 0.02416	 0.0	 1298	 1298	 1298	 0.0	 0.0	 1	 -30.0	 30.0;
	4335	 13178	 0.00346	 0.0273	 0.0	 1148	 1148	 1148	 0.0	 0.0	 1	 -30.0	 30.0;
	4335	 3565	 0.00522	 0.02489	 0.0	 1243	 1243	 1243	 0.0	 0.0	 1	 -30.0	 30.0;
	7697	 13178	 0.00048	 0.00226	 0.0	 13672	 13672	 13672	 0.0	 0.0	 1	 -30.0	 30.0;
	7697	 12262	 0.00048	 0.00226	 0.0	 13672	 13672	 13672	 0.0	 0.0	 1	 -30.0	 30.0;
	9300	 6382	 0.00766	 0.02459	 0.0	 1227	 1227	 1227	 0.0	 0.0	 1	 -30.0	 30.0;
	9300	 5894	 0.00557	 0.04393	 0.0	 714	 714	 714	 0.0	 0.0	 1	 -30.0	 30.0;
	12262	 3565	 0.00237	 0.01131	 0.0	 2734	 2734	 2734	 0.0	 0.0	 1	 -30.0	 30.0;
	5088	 10067	 0.00258	 0.04274	 0.0	 738	 738	 738	 0.0	 0.0	 1	 -30.0	 30.0;
	125	 2725	 0.00861	 0.04105	 0.0	 754	 754	 754	 0.0	 0.0	 1	 -30.0	 30.0;
	125	 1200	 0.01719	 0.08193	 0.0	 378	 378	 378	 0.0	 0.0	 1	 -30.0	 30.0;
	125	 1200	 0.01719	 0.08193	 0.0	 378	 378	 378	 0.0	 0.0	 1	 -30.0	 30.0;
	125	 6426	 0.01305	 0.06222	 0.0	 497	 497	 497	 0.0	 0.0	 1	 -30.0	 30.0;
	3453	 13182	 0.01326	 0.06319	 0.0	 490	 490	 490	 0.0	 0.0	 1	 -30.0	 30.0;
	3453	 5574	 0.03288	 0.15675	 0.0	 198	 198	 198	 0.0	 0.0	 1	 -30.0	 30.0;
	3453	 11614	 0.0059	 0.02812	 0.0	 1100	 1100	 1100	 0.0	 0.0	 1	 -30.0	 30.0;
	3453	 13416	 0.01898	 0.0905	 0.0	 342	 342	 342	 0.0	 0.0	 1	 -30.0	 30.0;
	13488	 7865	 0.02173	 0.06979	 0.0	 433	 433	 433	 0.0	 0.0	 1	 -30.0	 30.0;
	13488	 10572	 0.01007	 0.07939	 0.0	 395	 395	 395	 0.0	 0.0	 1	 -30.0	 30.0;
	13488	 8294	 0.04673	 0.15006	 0.0	 201	 201	 201	 0.0	 0.0	 1	 -30.0	 30.0;
	13488	 7348	 0.001	 0.00785	 0.0	 3992	 3992	 3992	 0.0	 0.0	 1	 -30.0	 30.0;
	7865	 1200	 0.02168	 0.06961	 0.0	 434	 434	 434	 0.0	 0.0	 1	 -30.0	 30.0;
	2725	 13182	 0.01261	 0.06011	 0.0	 515	 515	 515	 0.0	 0.0	 1	 -30.0	 30.0;
	7658	 5574	 0.01464	 0.04701	 0.0	 642	 642	 642	 0.0	 0.0	 1	 -30.0	 30.0;
	8467	 1307	 0.01647	 0.07854	 0.0	 394	 394	 394	 0.0	 0.0	 1	 -30.0	 30.0;
	8467	 1307	 0.0264	 0.08479	 0.0	 356	 356	 356	 0.0	 0.0	 1	 -30.0	 30.0;
	8467	 5574	 0.01441	 0.06868	 0.0	 451	 451	 451	 0.0	 0.0	 1	 -30.0	 30.0;
	8467	 5574	 0.02393	 0.07684	 0.0	 393	 393	 393	 0.0	 0.0	 1	 -30.0	 30.0;
	2243	 1307	 0.01407	 0.06706	 0.0	 461	 461	 461	 0.0	 0.0	 1	 -30.0	 30.0;
	2243	 11754	 0.00508	 0.02424	 0.0	 1276	 1276	 1276	 0.0	 0.0	 1	 -30.0	 30.0;
	1200	 2629	 0.00557	 0.04393	 0.0	 714	 714	 714	 0.0	 0.0	 1	 -30.0	 30.0;
	1200	 2629	 0.00557	 0.04393	 0.0	 714	 714	 714	 0.0	 0.0	 1	 -30.0	 30.0;
	1200	 12105	 0.00393	 0.0241	 0.0	 1294	 1294	 1294	 0.0	 0.0	 1	 -30.0	 30.0;
	13182	 6426	 0.00783	 0.03733	 0.0	 829	 829	 829	 0.0	 0.0	 1	 -30.0	 30.0;
	13182	 11614	 0.01824	 0.08694	 0.0	 356	 356	 356	 0.0	 0.0	 1	 -30.0	 30.0;
	5363	 5574	 0.00951	 0.075	 0.0	 418	 418	 418	 0.0	 0.0	 1	 -30.0	 30.0;
	5363	 3513	 0.00438	 0.03452	 0.0	 908	 908	 908	 0.0	 0.0	 1	 -30.0	 30.0;
	951	 7159	 0.02314	 0.07431	 0.0	 406	 406	 406	 0.0	 0.0	 1	 -30.0	 30.0;
	951	 9668	 0.0199	 0.1569	 0.0	 200	 200	 200	 0.0	 0.0	 1	 -30.0	 30.0;
	951	 13442	 0.00818	 0.06449	 0.0	 486	 486	 486	 0.0	 0.0	 1	 -30.0	 30.0;
	1307	 5574	 0.03085	 0.14706	 0.0	 211	 211	 211	 0.0	 0.0	 1	 -30.0	 30.0;
	1307	 168	 0.01814	 0.08646	 0.0	 358	 358	 358	 0.0	 0.0	 1	 -30.0	 30.0;
	1307	 9854	 0.01187	 0.05656	 0.0	 547	 547	 547	 0.0	 0.0	 1	 -30.0	 30.0;
	1307	 11754	 0.01356	 0.06464	 0.0	 479	 479	 479	 0.0	 0.0	 1	 -30.0	 30.0;
	6426	 5879	 0.05844	 0.18767	 0.0	 161	 161	 161	 0.0	 0.0	 1	 -30.0	 30.0;
	5574	 3513	 0.01075	 0.08473	 0.0	 370	 370	 370	 0.0	 0.0	 1	 -30.0	 30.0;
	5574	 11614	 0.04729	 0.15187	 0.0	 199	 199	 199	 0.0	 0.0	 1	 -30.0	 30.0;
	5574	 13416	 0.01458	 0.06949	 0.0	 445	 445	 445	 0.0	 0.0	 1	 -30.0	 30.0;
	7159	 13442	 0.00774	 0.06103	 0.0	 514	 514	 514	 0.0	 0.0	 1	 -30.0	 30.0;
	3513	 11614	 0.01094	 0.0863	 0.0	 364	 364	 364	 0.0	 0.0	 1	 -30.0	 30.0;
	3513	 11614	 0.01094	 0.0863	 0.0	 364	 364	 364	 0.0	 0.0	 1	 -30.0	 30.0;
	10067	 3088	 0.00033	 0.00416	 0.0	 7570	 7570	 7570	 0.0	 0.0	 1	 -30.0	 30.0;
	2629	 10572	 0.00318	 0.0251	 0.0	 1249	 1249	 1249	 0.0	 0.0	 1	 -30.0	 30.0;
	2629	 6255	 0.00199	 0.01569	 0.0	 1998	 1998	 1998	 0.0	 0.0	 1	 -30.0	 30.0;
	10572	 7348	 0.00597	 0.04707	 0.0	 666	 666	 666	 0.0	 0.0	 1	 -30.0	 30.0;
	10572	 6255	 0.00199	 0.01569	 0.0	 1998	 1998	 1998	 0.0	 0.0	 1	 -30.0	 30.0;
	8462	 10673	 0.00238	 0.03034	 0.0	 1038	 1038	 1038	 0.0	 0.0	 1	 -30.0	 30.0;
	8462	 8874	 0.00264	 0.03358	 0.0	 938	 938	 938	 0.0	 0.0	 1	 -30.0	 30.0;
	8462	 3088	 0.00228	 0.02909	 0.0	 1083	 1083	 1083	 0.0	 0.0	 1	 -30.0	 30.0;
	10153	 3959	 0.05152	 0.16543	 0.0	 183	 183	 183	 0.0	 0.0	 1	 -30.0	 30.0;
	10153	 13100	 0.01719	 0.13556	 0.0	 232	 232	 232	 0.0	 0.0	 1	 -30.0	 30.0;
	10153	 3431	 0.02074	 0.16349	 0.0	 192	 192	 192	 0.0	 0.0	 1	 -30.0	 30.0;
	8294	 10561	 0.04358	 0.13994	 0.0	 216	 216	 216	 0.0	 0.0	 1	 -30.0	 30.0;
	1143	 5879	 0.03136	 0.10071	 0.0	 300	 300	 300	 0.0	 0.0	 1	 -30.0	 30.0;
	1143	 8252	 0.00782	 0.06166	 0.0	 509	 509	 509	 0.0	 0.0	 1	 -30.0	 30.0;
	1143	 12557	 0.01807	 0.05804	 0.0	 520	 520	 520	 0.0	 0.0	 1	 -30.0	 30.0;
	1143	 1659	 0.00022	 0.00072	 0.0	 41957	 41957	 41957	 0.0	 0.0	 1	 -30.0	 30.0;
	5879	 7783	 0.03158	 0.10143	 0.0	 298	 298	 298	 0.0	 0.0	 1	 -30.0	 30.0;
	10561	 9668	 0.02477	 0.07955	 0.0	 380	 380	 380	 0.0	 0.0	 1	 -30.0	 30.0;
	3959	 8280	 0.02314	 0.07431	 0.0	 406	 406	 406	 0.0	 0.0	 1	 -30.0	 30.0;
	4799	 3765	 0.01464	 0.04701	 0.0	 642	 642	 642	 0.0	 0.0	 1	 -30.0	 30.0;
	4799	 7783	 0.02902	 0.13833	 0.0	 224	 224	 224	 0.0	 0.0	 1	 -30.0	 30.0;
	4799	 4402	 0.0241	 0.07738	 0.0	 390	 390	 390	 0.0	 0.0	 1	 -30.0	 30.0;
	4799	 292	 0.07702	 0.24733	 0.0	 122	 122	 122	 0.0	 0.0	 1	 -30.0	 30.0;
	10200	 7680	 0.00619	 0.01989	 0.0	 1517	 1517	 1517	 0.0	 0.0	 1	 -30.0	 30.0;
	3736	 8252	 0.00448	 0.02748	 0.0	 1135	 1135	 1135	 0.0	 0.0	 1	 -30.0	 30.0;
	3736	 8252	 0.00448	 0.02748	 0.0	 1135	 1135	 1135	 0.0	 0.0	 1	 -30.0	 30.0;
	3736	 605	 0.02929	 0.13962	 0.0	 222	 222	 222	 0.0	 0.0	 1	 -30.0	 30.0;
	3736	 13100	 0.01572	 0.12395	 0.0	 253	 253	 253	 0.0	 0.0	 1	 -30.0	 30.0;
	3736	 6753	 0.01194	 0.09414	 0.0	 333	 333	 333	 0.0	 0.0	 1	 -30.0	 30.0;
	8252	 931	 0.00629	 0.04958	 0.0	 633	 633	 633	 0.0	 0.0	 1	 -30.0	 30.0;
	3765	 5043	 0.03491	 0.1121	 0.0	 270	 270	 270	 0.0	 0.0	 1	 -30.0	 30.0;
	605	 4050	 0.01593	 0.07595	 0.0	 408	 408	 408	 0.0	 0.0	 1	 -30.0	 30.0;
	13100	 9668	 0.05405	 0.17357	 0.0	 174	 174	 174	 0.0	 0.0	 1	 -30.0	 30.0;
	13100	 6753	 0.01174	 0.09257	 0.0	 339	 339	 339	 0.0	 0.0	 1	 -30.0	 30.0;
	8280	 9668	 0.03254	 0.19959	 0.0	 157	 157	 157	 0.0	 0.0	 1	 -30.0	 30.0;
	7680	 292	 0.00659	 0.02115	 0.0	 1426	 1426	 1426	 0.0	 0.0	 1	 -30.0	 30.0;
	7680	 292	 0.00659	 0.02115	 0.0	 1426	 1426	 1426	 0.0	 0.0	 1	 -30.0	 30.0;
	4402	 12557	 0.03356	 0.10776	 0.0	 280	 280	 280	 0.0	 0.0	 1	 -30.0	 30.0;
	4402	 240	 0.03277	 0.10523	 0.0	 287	 287	 287	 0.0	 0.0	 1	 -30.0	 30.0;
	5043	 292	 0.03783	 0.1215	 0.0	 249	 249	 249	 0.0	 0.0	 1	 -30.0	 30.0;
	292	 7791	 0.0181	 0.08629	 0.0	 359	 359	 359	 0.0	 0.0	 1	 -30.0	 30.0;
	10673	 11184	 0.00235	 0.02992	 0.0	 1053	 1053	 1053	 0.0	 0.0	 1	 -30.0	 30.0;
	10266	 10726	 0.00211	 0.02153	 0.0	 1461	 1461	 1461	 0.0	 0.0	 1	 -30.0	 30.0;
	474	 10726	 0.00232	 0.02949	 0.0	 1068	 1068	 1068	 0.0	 0.0	 1	 -30.0	 30.0;
	474	 11407	 0.00179	 0.02959	 0.0	 1066	 1066	 1066	 0.0	 0.0	 1	 -30.0	 30.0;
	474	 10892	 0.00179	 0.02959	 0.0	 1066	 1066	 1066	 0.0	 0.0	 1	 -30.0	 30.0;
	474	 4116	 0.00134	 0.01702	 0.0	 1851	 1851	 1851	 0.0	 0.0	 1	 -30.0	 30.0;
	474	 7800	 0.00084	 0.01064	 0.0	 2960	 2960	 2960	 0.0	 0.0	 1	 -30.0	 30.0;
	474	 7448	 0.00124	 0.01268	 0.0	 2480	 2480	 2480	 0.0	 0.0	 1	 -30.0	 30.0;
	474	 4624	 0.00106	 0.01347	 0.0	 2338	 2338	 2338	 0.0	 0.0	 1	 -30.0	 30.0;
	1036	 10726	 0.00023	 0.00231	 0.0	 13607	 13607	 13607	 0.0	 0.0	 1	 -30.0	 30.0;
	1036	 8751	 0.00335	 0.03421	 0.0	 919	 919	 919	 0.0	 0.0	 1	 -30.0	 30.0;
	10726	 13612	 0.00024	 0.00241	 0.0	 13043	 13043	 13043	 0.0	 0.0	 1	 -30.0	 30.0;
	10726	 13612	 0.00024	 0.00241	 0.0	 13043	 13043	 13043	 0.0	 0.0	 1	 -30.0	 30.0;
	10726	 13612	 0.00024	 0.00241	 0.0	 13043	 13043	 13043	 0.0	 0.0	 1	 -30.0	 30.0;
	10726	 13612	 0.00024	 0.00241	 0.0	 13043	 13043	 13043	 0.0	 0.0	 1	 -30.0	 30.0;
	10726	 4417	 0.00075	 0.01233	 0.0	 2558	 2558	 2558	 0.0	 0.0	 1	 -30.0	 30.0;
	11407	 1365	 0.0	 -0.03116	 0.0	 1014	 1014	 1014	 0.0	 0.0	 1	 -30.0	 30.0;
	10892	 7644	 0.0	 -0.03116	 0.0	 1014	 1014	 1014	 0.0	 0.0	 1	 -30.0	 30.0;
	4116	 8356	 3e-05	 0.00033	 0.0	 95327	 95327	 95327	 0.0	 0.0	 1	 -30.0	 30.0;
	5743	 8751	 0.00182	 0.02317	 0.0	 1360	 1360	 1360	 0.0	 0.0	 1	 -30.0	 30.0;
	5743	 6634	 0.00081	 0.01031	 0.0	 3055	 3055	 3055	 0.0	 0.0	 1	 -30.0	 30.0;
	3198	 8751	 0.00177	 0.01813	 0.0	 1735	 1735	 1735	 0.0	 0.0	 1	 -30.0	 30.0;
	3198	 8751	 0.00175	 0.01789	 0.0	 1758	 1758	 1758	 0.0	 0.0	 1	 -30.0	 30.0;
	3198	 4624	 0.00099	 0.01257	 0.0	 2506	 2506	 2506	 0.0	 0.0	 1	 -30.0	 30.0;
	3198	 3669	 0.00125	 0.01594	 0.0	 1976	 1976	 1976	 0.0	 0.0	 1	 -30.0	 30.0;
	3198	 3669	 0.00125	 0.01594	 0.0	 1976	 1976	 1976	 0.0	 0.0	 1	 -30.0	 30.0;
	8751	 1608	 0.00014	 0.00139	 0.0	 22611	 22611	 22611	 0.0	 0.0	 1	 -30.0	 30.0;
	8751	 1608	 0.00014	 0.00139	 0.0	 22611	 22611	 22611	 0.0	 0.0	 1	 -30.0	 30.0;
	8751	 1608	 0.00014	 0.00139	 0.0	 22611	 22611	 22611	 0.0	 0.0	 1	 -30.0	 30.0;
	8751	 8874	 0.00198	 0.02527	 0.0	 1247	 1247	 1247	 0.0	 0.0	 1	 -30.0	 30.0;
	1500	 7614	 0.00845	 0.02712	 0.0	 1112	 1112	 1112	 0.0	 0.0	 1	 -30.0	 30.0;
	1500	 25	 0.00736	 0.05805	 0.0	 540	 540	 540	 0.0	 0.0	 1	 -30.0	 30.0;
	1500	 1922	 0.02438	 0.07829	 0.0	 386	 386	 386	 0.0	 0.0	 1	 -30.0	 30.0;
	7614	 4293	 0.02308	 0.07413	 0.0	 407	 407	 407	 0.0	 0.0	 1	 -30.0	 30.0;
	7614	 7569	 0.01802	 0.05786	 0.0	 522	 522	 522	 0.0	 0.0	 1	 -30.0	 30.0;
	7614	 12759	 0.02252	 0.07232	 0.0	 418	 418	 418	 0.0	 0.0	 1	 -30.0	 30.0;
	9092	 12686	 0.01397	 0.08565	 0.0	 364	 364	 364	 0.0	 0.0	 1	 -30.0	 30.0;
	9092	 10350	 0.01937	 0.06219	 0.0	 485	 485	 485	 0.0	 0.0	 1	 -30.0	 30.0;
	9092	 12061	 0.01205	 0.07392	 0.0	 422	 422	 422	 0.0	 0.0	 1	 -30.0	 30.0;
	8584	 11262	 0.00788	 0.02531	 0.0	 1192	 1192	 1192	 0.0	 0.0	 1	 -30.0	 30.0;
	8584	 7090	 0.01464	 0.04701	 0.0	 642	 642	 642	 0.0	 0.0	 1	 -30.0	 30.0;
	25	 4293	 0.00394	 0.01266	 0.0	 2383	 2383	 2383	 0.0	 0.0	 1	 -30.0	 30.0;
	25	 5801	 0.03491	 0.1121	 0.0	 270	 270	 270	 0.0	 0.0	 1	 -30.0	 30.0;
	25	 4410	 0.02534	 0.08136	 0.0	 371	 371	 371	 0.0	 0.0	 1	 -30.0	 30.0;
	11972	 1956	 0.0469	 0.15061	 0.0	 201	 201	 201	 0.0	 0.0	 1	 -30.0	 30.0;
	11972	 1956	 0.0469	 0.15061	 0.0	 201	 201	 201	 0.0	 0.0	 1	 -30.0	 30.0;
	11972	 7906	 0.03913	 0.12566	 0.0	 241	 241	 241	 0.0	 0.0	 1	 -30.0	 30.0;
	11972	 7906	 0.03913	 0.12566	 0.0	 241	 241	 241	 0.0	 0.0	 1	 -30.0	 30.0;
	11972	 8633	 0.05332	 0.17309	 0.0	 175	 175	 175	 0.0	 0.0	 1	 -30.0	 30.0;
	11972	 8633	 0.05332	 0.17309	 0.0	 175	 175	 175	 0.0	 0.0	 1	 -30.0	 30.0;
	5801	 1886	 0.01015	 0.08002	 0.0	 392	 392	 392	 0.0	 0.0	 1	 -30.0	 30.0;
	5801	 12686	 0.0317	 0.10179	 0.0	 297	 297	 297	 0.0	 0.0	 1	 -30.0	 30.0;
	5801	 9507	 0.00719	 0.03426	 0.0	 903	 903	 903	 0.0	 0.0	 1	 -30.0	 30.0;
	5801	 9507	 0.00719	 0.03426	 0.0	 903	 903	 903	 0.0	 0.0	 1	 -30.0	 30.0;
	5801	 6558	 0.00143	 0.0113	 0.0	 2774	 2774	 2774	 0.0	 0.0	 1	 -30.0	 30.0;
	5801	 6558	 0.00143	 0.0113	 0.0	 2774	 2774	 2774	 0.0	 0.0	 1	 -30.0	 30.0;
	2233	 8052	 0.03463	 0.11119	 0.0	 272	 272	 272	 0.0	 0.0	 1	 -30.0	 30.0;
	2233	 9819	 0.01306	 0.04195	 0.0	 719	 719	 719	 0.0	 0.0	 1	 -30.0	 30.0;
	2233	 11943	 0.01689	 0.05424	 0.0	 557	 557	 557	 0.0	 0.0	 1	 -30.0	 30.0;
	8429	 1510	 0.03074	 0.09872	 0.0	 306	 306	 306	 0.0	 0.0	 1	 -30.0	 30.0;
	8429	 10243	 0.03547	 0.1139	 0.0	 265	 265	 265	 0.0	 0.0	 1	 -30.0	 30.0;
	667	 11594	 0.04622	 0.14844	 0.0	 204	 204	 204	 0.0	 0.0	 1	 -30.0	 30.0;
	667	 9253	 0.04949	 0.15892	 0.0	 190	 190	 190	 0.0	 0.0	 1	 -30.0	 30.0;
	667	 7791	 0.05106	 0.16399	 0.0	 184	 184	 184	 0.0	 0.0	 1	 -30.0	 30.0;
	1510	 4930	 0.0282	 0.13445	 0.0	 230	 230	 230	 0.0	 0.0	 1	 -30.0	 30.0;
	1510	 8633	 0.01391	 0.04653	 0.0	 651	 651	 651	 0.0	 0.0	 1	 -30.0	 30.0;
	1510	 8633	 0.01391	 0.04653	 0.0	 651	 651	 651	 0.0	 0.0	 1	 -30.0	 30.0;
	1510	 4768	 0.00282	 0.00904	 0.0	 3336	 3336	 3336	 0.0	 0.0	 1	 -30.0	 30.0;
	1510	 4768	 0.00282	 0.00904	 0.0	 3336	 3336	 3336	 0.0	 0.0	 1	 -30.0	 30.0;
	10807	 5403	 0.03744	 0.12023	 0.0	 251	 251	 251	 0.0	 0.0	 1	 -30.0	 30.0;
	6638	 5403	 0.00974	 0.03128	 0.0	 965	 965	 965	 0.0	 0.0	 1	 -30.0	 30.0;
	6638	 5403	 0.01357	 0.04357	 0.0	 693	 693	 693	 0.0	 0.0	 1	 -30.0	 30.0;
	6638	 1886	 0.00563	 0.01808	 0.0	 1669	 1669	 1669	 0.0	 0.0	 1	 -30.0	 30.0;
	6638	 5648	 0.02263	 0.07268	 0.0	 415	 415	 415	 0.0	 0.0	 1	 -30.0	 30.0;
	10541	 4768	 0.03265	 0.10486	 0.0	 288	 288	 288	 0.0	 0.0	 1	 -30.0	 30.0;
	10541	 3003	 0.03491	 0.1121	 0.0	 270	 270	 270	 0.0	 0.0	 1	 -30.0	 30.0;
	5403	 7050	 0.00444	 0.02117	 0.0	 1461	 1461	 1461	 0.0	 0.0	 1	 -30.0	 30.0;
	5403	 7050	 0.00444	 0.02117	 0.0	 1461	 1461	 1461	 0.0	 0.0	 1	 -30.0	 30.0;
	5403	 7906	 0.01605	 0.05153	 0.0	 586	 586	 586	 0.0	 0.0	 1	 -30.0	 30.0;
	5403	 7906	 0.01605	 0.05153	 0.0	 586	 586	 586	 0.0	 0.0	 1	 -30.0	 30.0;
	5403	 6816	 0.01407	 0.0452	 0.0	 668	 668	 668	 0.0	 0.0	 1	 -30.0	 30.0;
	7050	 1886	 0.01244	 0.03996	 0.0	 755	 755	 755	 0.0	 0.0	 1	 -30.0	 30.0;
	7050	 1886	 0.01244	 0.03996	 0.0	 755	 755	 755	 0.0	 0.0	 1	 -30.0	 30.0;
	1886	 11911	 0.01271	 0.0606	 0.0	 511	 511	 511	 0.0	 0.0	 1	 -30.0	 30.0;
	10243	 11594	 0.02928	 0.09402	 0.0	 321	 321	 321	 0.0	 0.0	 1	 -30.0	 30.0;
	10243	 11594	 0.02928	 0.09402	 0.0	 321	 321	 321	 0.0	 0.0	 1	 -30.0	 30.0;
	10243	 8233	 0.04909	 0.15766	 0.0	 192	 192	 192	 0.0	 0.0	 1	 -30.0	 30.0;
	7569	 3713	 0.04335	 0.13922	 0.0	 217	 217	 217	 0.0	 0.0	 1	 -30.0	 30.0;
	11594	 6164	 0.02695	 0.12847	 0.0	 241	 241	 241	 0.0	 0.0	 1	 -30.0	 30.0;
	11594	 2299	 0.02695	 0.12847	 0.0	 241	 241	 241	 0.0	 0.0	 1	 -30.0	 30.0;
	3713	 6074	 0.0122	 0.09618	 0.0	 326	 326	 326	 0.0	 0.0	 1	 -30.0	 30.0;
	3713	 3357	 0.0304	 0.09763	 0.0	 309	 309	 309	 0.0	 0.0	 1	 -30.0	 30.0;
	9253	 10810	 0.03536	 0.11354	 0.0	 266	 266	 266	 0.0	 0.0	 1	 -30.0	 30.0;
	9253	 10248	 0.00338	 0.01085	 0.0	 2780	 2780	 2780	 0.0	 0.0	 1	 -30.0	 30.0;
	9253	 3357	 0.02837	 0.09112	 0.0	 331	 331	 331	 0.0	 0.0	 1	 -30.0	 30.0;
	9253	 729	 0.0139	 0.06626	 0.0	 467	 467	 467	 0.0	 0.0	 1	 -30.0	 30.0;
	12098	 10828	 0.00325	 0.01551	 0.0	 1994	 1994	 1994	 0.0	 0.0	 1	 -30.0	 30.0;
	12098	 7906	 0.01376	 0.06561	 0.0	 472	 472	 472	 0.0	 0.0	 1	 -30.0	 30.0;
	12098	 11731	 0.00472	 0.03718	 0.0	 843	 843	 843	 0.0	 0.0	 1	 -30.0	 30.0;
	8052	 13484	 0.00756	 0.05962	 0.0	 526	 526	 526	 0.0	 0.0	 1	 -30.0	 30.0;
	8052	 13484	 0.00756	 0.05962	 0.0	 526	 526	 526	 0.0	 0.0	 1	 -30.0	 30.0;
	8052	 4965	 0.00631	 0.02025	 0.0	 1490	 1490	 1490	 0.0	 0.0	 1	 -30.0	 30.0;
	8052	 402	 0.01194	 0.09414	 0.0	 333	 333	 333	 0.0	 0.0	 1	 -30.0	 30.0;
	429	 10828	 0.0047	 0.03703	 0.0	 847	 847	 847	 0.0	 0.0	 1	 -30.0	 30.0;
	429	 7906	 0.0152	 0.04882	 0.0	 618	 618	 618	 0.0	 0.0	 1	 -30.0	 30.0;
	429	 11731	 0.00115	 0.0091	 0.0	 3444	 3444	 3444	 0.0	 0.0	 1	 -30.0	 30.0;
	8233	 10810	 0.0179	 0.05749	 0.0	 525	 525	 525	 0.0	 0.0	 1	 -30.0	 30.0;
	8233	 1956	 0.01211	 0.03887	 0.0	 776	 776	 776	 0.0	 0.0	 1	 -30.0	 30.0;
	8233	 12759	 0.02517	 0.08082	 0.0	 374	 374	 374	 0.0	 0.0	 1	 -30.0	 30.0;
	10828	 3003	 0.00619	 0.01989	 0.0	 1517	 1517	 1517	 0.0	 0.0	 1	 -30.0	 30.0;
	7906	 6816	 0.01464	 0.04701	 0.0	 642	 642	 642	 0.0	 0.0	 1	 -30.0	 30.0;
	12366	 8580	 0.01757	 0.05641	 0.0	 535	 535	 535	 0.0	 0.0	 1	 -30.0	 30.0;
	12366	 8974	 0.01878	 0.06123	 0.0	 494	 494	 494	 0.0	 0.0	 1	 -30.0	 30.0;
	1922	 5648	 0.02674	 0.08588	 0.0	 352	 352	 352	 0.0	 0.0	 1	 -30.0	 30.0;
	6164	 7791	 0.04673	 0.15006	 0.0	 201	 201	 201	 0.0	 0.0	 1	 -30.0	 30.0;
	6164	 2299	 0.00271	 0.01293	 0.0	 2391	 2391	 2391	 0.0	 0.0	 1	 -30.0	 30.0;
	6074	 8974	 0.02424	 0.07877	 0.0	 384	 384	 384	 0.0	 0.0	 1	 -30.0	 30.0;
	12686	 9507	 0.00822	 0.0648	 0.0	 484	 484	 484	 0.0	 0.0	 1	 -30.0	 30.0;
	12686	 1693	 0.02871	 0.09221	 0.0	 328	 328	 328	 0.0	 0.0	 1	 -30.0	 30.0;
	9187	 3956	 0.00263	 0.02071	 0.0	 1514	 1514	 1514	 0.0	 0.0	 1	 -30.0	 30.0;
	9187	 10350	 0.02224	 0.07142	 0.0	 423	 423	 423	 0.0	 0.0	 1	 -30.0	 30.0;
	9187	 8138	 0.00261	 0.02055	 0.0	 1525	 1525	 1525	 0.0	 0.0	 1	 -30.0	 30.0;
	9187	 1693	 0.00845	 0.02712	 0.0	 1112	 1112	 1112	 0.0	 0.0	 1	 -30.0	 30.0;
	9819	 12061	 0.0114	 0.0699	 0.0	 447	 447	 447	 0.0	 0.0	 1	 -30.0	 30.0;
	3956	 5440	 0.01407	 0.0452	 0.0	 668	 668	 668	 0.0	 0.0	 1	 -30.0	 30.0;
	8580	 13484	 0.00796	 0.06276	 0.0	 500	 500	 500	 0.0	 0.0	 1	 -30.0	 30.0;
	8580	 11943	 0.00563	 0.01808	 0.0	 1669	 1669	 1669	 0.0	 0.0	 1	 -30.0	 30.0;
	8580	 7860	 0.01126	 0.03616	 0.0	 835	 835	 835	 0.0	 0.0	 1	 -30.0	 30.0;
	8138	 1693	 0.00597	 0.04707	 0.0	 666	 666	 666	 0.0	 0.0	 1	 -30.0	 30.0;
	8138	 12061	 0.01393	 0.10983	 0.0	 286	 286	 286	 0.0	 0.0	 1	 -30.0	 30.0;
	8138	 7860	 0.03828	 0.12294	 0.0	 246	 246	 246	 0.0	 0.0	 1	 -30.0	 30.0;
	7800	 11422	 0.00117	 0.01496	 0.0	 2106	 2106	 2106	 0.0	 0.0	 1	 -30.0	 30.0;
	7448	 8356	 0.00076	 0.00964	 0.0	 3267	 3267	 3267	 0.0	 0.0	 1	 -30.0	 30.0;
	13473	 8270	 0.00085	 0.01081	 0.0	 2914	 2914	 2914	 0.0	 0.0	 1	 -30.0	 30.0;
	13473	 11422	 0.00093	 0.0118	 0.0	 2669	 2669	 2669	 0.0	 0.0	 1	 -30.0	 30.0;
	2227	 8974	 0.00697	 0.05491	 0.0	 571	 571	 571	 0.0	 0.0	 1	 -30.0	 30.0;
	2227	 8974	 0.00697	 0.05491	 0.0	 571	 571	 571	 0.0	 0.0	 1	 -30.0	 30.0;
	466	 3003	 0.00113	 0.00362	 0.0	 8330	 8330	 8330	 0.0	 0.0	 1	 -30.0	 30.0;
	3300	 7860	 0.00056	 0.00181	 0.0	 16672	 16672	 16672	 0.0	 0.0	 1	 -30.0	 30.0;
	10248	 4364	 0.00338	 0.01085	 0.0	 2780	 2780	 2780	 0.0	 0.0	 1	 -30.0	 30.0;
	3669	 12408	 0.00122	 0.01546	 0.0	 2037	 2037	 2037	 0.0	 0.0	 1	 -30.0	 30.0;
	4818	 3431	 0.03378	 0.10848	 0.0	 279	 279	 279	 0.0	 0.0	 1	 -30.0	 30.0;
	4818	 9950	 0.0117	 0.09226	 0.0	 340	 340	 340	 0.0	 0.0	 1	 -30.0	 30.0;
	4818	 4050	 0.01891	 0.14906	 0.0	 211	 211	 211	 0.0	 0.0	 1	 -30.0	 30.0;
	4818	 4050	 0.01891	 0.14906	 0.0	 211	 211	 211	 0.0	 0.0	 1	 -30.0	 30.0;
	11743	 5237	 0.07702	 0.24733	 0.0	 122	 122	 122	 0.0	 0.0	 1	 -30.0	 30.0;
	11743	 11282	 0.01526	 0.07272	 0.0	 426	 426	 426	 0.0	 0.0	 1	 -30.0	 30.0;
	2576	 6537	 0.0308	 0.0989	 0.0	 305	 305	 305	 0.0	 0.0	 1	 -30.0	 30.0;
	2576	 1006	 0.02787	 0.0895	 0.0	 337	 337	 337	 0.0	 0.0	 1	 -30.0	 30.0;
	2576	 4748	 0.00038	 0.00298	 0.0	 10515	 10515	 10515	 0.0	 0.0	 1	 -30.0	 30.0;
	2576	 4748	 0.00038	 0.00298	 0.0	 10515	 10515	 10515	 0.0	 0.0	 1	 -30.0	 30.0;
	3203	 9950	 0.02291	 0.18059	 0.0	 174	 174	 174	 0.0	 0.0	 1	 -30.0	 30.0;
	3203	 3574	 0.00593	 0.02828	 0.0	 1094	 1094	 1094	 0.0	 0.0	 1	 -30.0	 30.0;
	3203	 11432	 0.00776	 0.06119	 0.0	 513	 513	 513	 0.0	 0.0	 1	 -30.0	 30.0;
	8787	 380	 0.04262	 0.13687	 0.0	 221	 221	 221	 0.0	 0.0	 1	 -30.0	 30.0;
	8787	 3600	 0.02065	 0.09841	 0.0	 315	 315	 315	 0.0	 0.0	 1	 -30.0	 30.0;
	8787	 7140	 0.05591	 0.17953	 0.0	 168	 168	 168	 0.0	 0.0	 1	 -30.0	 30.0;
	8787	 1064	 0.01196	 0.0943	 0.0	 333	 333	 333	 0.0	 0.0	 1	 -30.0	 30.0;
	8787	 1064	 0.01196	 0.0943	 0.0	 333	 333	 333	 0.0	 0.0	 1	 -30.0	 30.0;
	741	 3443	 0.00644	 0.0307	 0.0	 1007	 1007	 1007	 0.0	 0.0	 1	 -30.0	 30.0;
	741	 3443	 0.00644	 0.0307	 0.0	 1007	 1007	 1007	 0.0	 0.0	 1	 -30.0	 30.0;
	11013	 1049	 0.00241	 0.01898	 0.0	 1651	 1651	 1651	 0.0	 0.0	 1	 -30.0	 30.0;
	11013	 1049	 0.00241	 0.01898	 0.0	 1651	 1651	 1651	 0.0	 0.0	 1	 -30.0	 30.0;
	11013	 1049	 0.00249	 0.01961	 0.0	 1598	 1598	 1598	 0.0	 0.0	 1	 -30.0	 30.0;
	11013	 9163	 0.01208	 0.09524	 0.0	 330	 330	 330	 0.0	 0.0	 1	 -30.0	 30.0;
	11013	 5407	 0.07229	 0.23215	 0.0	 130	 130	 130	 0.0	 0.0	 1	 -30.0	 30.0;
	1049	 1387	 0.0264	 0.08479	 0.0	 356	 356	 356	 0.0	 0.0	 1	 -30.0	 30.0;
	1049	 3443	 0.00762	 0.06009	 0.0	 522	 522	 522	 0.0	 0.0	 1	 -30.0	 30.0;
	1049	 1006	 0.01057	 0.08331	 0.0	 377	 377	 377	 0.0	 0.0	 1	 -30.0	 30.0;
	1049	 5522	 0.0029	 0.02291	 0.0	 1368	 1368	 1368	 0.0	 0.0	 1	 -30.0	 30.0;
	1049	 5522	 0.0029	 0.02291	 0.0	 1368	 1368	 1368	 0.0	 0.0	 1	 -30.0	 30.0;
	6627	 10121	 0.01582	 0.0508	 0.0	 594	 594	 594	 0.0	 0.0	 1	 -30.0	 30.0;
	6627	 9950	 0.04887	 0.15693	 0.0	 193	 193	 193	 0.0	 0.0	 1	 -30.0	 30.0;
	3357	 380	 0.01668	 0.07951	 0.0	 389	 389	 389	 0.0	 0.0	 1	 -30.0	 30.0;
	3357	 380	 0.01668	 0.07951	 0.0	 389	 389	 389	 0.0	 0.0	 1	 -30.0	 30.0;
	3357	 6412	 0.00749	 0.02405	 0.0	 1254	 1254	 1254	 0.0	 0.0	 1	 -30.0	 30.0;
	3357	 729	 0.00617	 0.02941	 0.0	 1052	 1052	 1052	 0.0	 0.0	 1	 -30.0	 30.0;
	3357	 4364	 0.02815	 0.0904	 0.0	 334	 334	 334	 0.0	 0.0	 1	 -30.0	 30.0;
	3357	 1056	 0.02388	 0.0804	 0.0	 377	 377	 377	 0.0	 0.0	 1	 -30.0	 30.0;
	5237	 9950	 0.05461	 0.17538	 0.0	 172	 172	 172	 0.0	 0.0	 1	 -30.0	 30.0;
	5237	 11684	 0.02032	 0.06527	 0.0	 463	 463	 463	 0.0	 0.0	 1	 -30.0	 30.0;
	3431	 11684	 0.05236	 0.16814	 0.0	 180	 180	 180	 0.0	 0.0	 1	 -30.0	 30.0;
	1387	 3443	 0.00555	 0.04377	 0.0	 716	 716	 716	 0.0	 0.0	 1	 -30.0	 30.0;
	1387	 2944	 0.00788	 0.02531	 0.0	 1192	 1192	 1192	 0.0	 0.0	 1	 -30.0	 30.0;
	9163	 4965	 0.01003	 0.07908	 0.0	 397	 397	 397	 0.0	 0.0	 1	 -30.0	 30.0;
	380	 7185	 0.01194	 0.09414	 0.0	 333	 333	 333	 0.0	 0.0	 1	 -30.0	 30.0;
	6412	 2944	 0.01982	 0.06364	 0.0	 474	 474	 474	 0.0	 0.0	 1	 -30.0	 30.0;
	6412	 10314	 0.00169	 0.00542	 0.0	 5564	 5564	 5564	 0.0	 0.0	 1	 -30.0	 30.0;
	3600	 3574	 0.01393	 0.10983	 0.0	 286	 286	 286	 0.0	 0.0	 1	 -30.0	 30.0;
	4965	 5407	 0.01172	 0.09241	 0.0	 340	 340	 340	 0.0	 0.0	 1	 -30.0	 30.0;
	8738	 3437	 0.00441	 0.02101	 0.0	 1472	 1472	 1472	 0.0	 0.0	 1	 -30.0	 30.0;
	7140	 9950	 0.04014	 0.12891	 0.0	 234	 234	 234	 0.0	 0.0	 1	 -30.0	 30.0;
	8346	 7673	 0.00597	 0.04707	 0.0	 666	 666	 666	 0.0	 0.0	 1	 -30.0	 30.0;
	8346	 7673	 0.00597	 0.04707	 0.0	 666	 666	 666	 0.0	 0.0	 1	 -30.0	 30.0;
	8346	 3253	 0.01017	 0.04848	 0.0	 638	 638	 638	 0.0	 0.0	 1	 -30.0	 30.0;
	8346	 3253	 0.01017	 0.04848	 0.0	 638	 638	 638	 0.0	 0.0	 1	 -30.0	 30.0;
	8346	 7185	 0.00298	 0.02354	 0.0	 1332	 1332	 1332	 0.0	 0.0	 1	 -30.0	 30.0;
	8346	 1064	 0.0002	 0.00157	 0.0	 19959	 19959	 19959	 0.0	 0.0	 1	 -30.0	 30.0;
	8346	 1064	 0.0002	 0.00157	 0.0	 19959	 19959	 19959	 0.0	 0.0	 1	 -30.0	 30.0;
	2175	 7642	 0.01689	 0.05424	 0.0	 557	 557	 557	 0.0	 0.0	 1	 -30.0	 30.0;
	2175	 1178	 4e-05	 0.00041	 0.0	 76679	 76679	 76679	 0.0	 0.0	 1	 -30.0	 30.0;
	2175	 918	 0.01848	 0.06679	 0.0	 456	 456	 456	 0.0	 0.0	 1	 -30.0	 30.0;
	2175	 918	 0.02061	 0.06617	 0.0	 456	 456	 456	 0.0	 0.0	 1	 -30.0	 30.0;
	12315	 5407	 0.01925	 0.06183	 0.0	 488	 488	 488	 0.0	 0.0	 1	 -30.0	 30.0;
	12315	 7642	 0.00617	 0.04864	 0.0	 645	 645	 645	 0.0	 0.0	 1	 -30.0	 30.0;
	5407	 402	 0.00847	 0.0404	 0.0	 766	 766	 766	 0.0	 0.0	 1	 -30.0	 30.0;
	10121	 6537	 0.01064	 0.03417	 0.0	 883	 883	 883	 0.0	 0.0	 1	 -30.0	 30.0;
	10121	 918	 0.04286	 0.14508	 0.0	 209	 209	 209	 0.0	 0.0	 1	 -30.0	 30.0;
	240	 3437	 0.01729	 0.08242	 0.0	 376	 376	 376	 0.0	 0.0	 1	 -30.0	 30.0;
	240	 3437	 0.01729	 0.08242	 0.0	 376	 376	 376	 0.0	 0.0	 1	 -30.0	 30.0;
	240	 1056	 0.01149	 0.04063	 0.0	 749	 749	 749	 0.0	 0.0	 1	 -30.0	 30.0;
	5618	 11282	 0.01328	 0.13577	 0.0	 232	 232	 232	 0.0	 0.0	 1	 -30.0	 30.0;
	5618	 918	 0.02061	 0.06617	 0.0	 456	 456	 456	 0.0	 0.0	 1	 -30.0	 30.0;
	7642	 4748	 0.02567	 0.2024	 0.0	 155	 155	 155	 0.0	 0.0	 1	 -30.0	 30.0;
	12408	 11184	 0.00268	 0.03408	 0.0	 925	 925	 925	 0.0	 0.0	 1	 -30.0	 30.0;
	12408	 8270	 0.00052	 0.00665	 0.0	 4736	 4736	 4736	 0.0	 0.0	 1	 -30.0	 30.0;
	4748	 11432	 0.0004	 0.00314	 0.0	 9980	 9980	 9980	 0.0	 0.0	 1	 -30.0	 30.0;
	3190	 4364	 0.01126	 0.03616	 0.0	 835	 835	 835	 0.0	 0.0	 1	 -30.0	 30.0;
	11184	 5949	 0.00209	 0.0266	 0.0	 1184	 1184	 1184	 0.0	 0.0	 1	 -30.0	 30.0;
	8270	 8119	 0.00105	 0.0133	 0.0	 2368	 2368	 2368	 0.0	 0.0	 1	 -30.0	 30.0;
	4804	 2752	 0.00189	 0.02411	 0.0	 1307	 1307	 1307	 0.0	 0.0	 1	 -30.0	 30.0;
	11928	 11422	 0.0	 0.0002	 0.0	 157937	 157937	 157937	 0.0	 0.0	 1	 -30.0	 30.0;
	5949	 8119	 0.00196	 0.02494	 0.0	 1263	 1263	 1263	 0.0	 0.0	 1	 -30.0	 30.0;
	8119	 8892	 0.00034	 0.00432	 0.0	 7290	 7290	 7290	 0.0	 0.0	 1	 -30.0	 30.0;
	8408	 13128	 0.00067	 0.00682	 0.0	 4610	 4610	 4610	 0.0	 0.0	 1	 -30.0	 30.0;
	13128	 1741	 0.00022	 0.0024	 0.0	 13107	 13107	 13107	 0.0	 0.0	 1	 -30.0	 30.0;
	11255	 1256	 0.00636	 0.02043	 0.0	 1477	 1477	 1477	 0.0	 0.0	 1	 -30.0	 30.0;
	9601	 12149	 6.3e-05	 0.00019	 0.0	 157801	 157801	 157801	 0.0	 0.0	 1	 -30.0	 30.0;
	7348	 13442	 0.00398	 0.03138	 0.0	 999	 999	 999	 0.0	 0.0	 1	 -30.0	 30.0;
	7348	 13442	 0.00398	 0.03138	 0.0	 999	 999	 999	 0.0	 0.0	 1	 -30.0	 30.0;
	5440	 4410	 0.00394	 0.01266	 0.0	 2383	 2383	 2383	 0.0	 0.0	 1	 -30.0	 30.0;
	12438	 11943	 0.00011	 0.00036	 0.0	 83913	 83913	 83913	 0.0	 0.0	 1	 -30.0	 30.0;
	8859	 10123	 0.00135	 0.01379	 0.0	 2739	 2739	 2739	 1.052632	 0.0	 1	 -30.0	 30.0;
	4222	 7260	 0.00097	 0.01239	 0.0	 3053	 3053	 3053	 1.052632	 0.0	 1	 -30.0	 30.0;
	642	 6538	 0.00084	 0.01064	 0.0	 3555	 3555	 3555	 1.052632	 0.0	 1	 -30.0	 30.0;
	11825	 2422	 0.0	 2.80858	 0.0	 12	 12	 12	 1.0	 0.0	 1	 -30.0	 30.0;
	11825	 7731	 0.0	 8.84701	 0.0	 4	 4	 4	 1.0	 0.0	 1	 -30.0	 30.0;
	11825	 1599	 0.0	 2.52772	 0.0	 13	 13	 13	 1.0	 0.0	 1	 -30.0	 30.0;
	11825	 9830	 0.0	 2.52772	 0.0	 13	 13	 13	 1.0	 0.0	 1	 -30.0	 30.0;
	11825	 7962	 0.0	 3.53881	 0.0	 9	 9	 9	 1.0	 0.0	 1	 -30.0	 30.0;
	11825	 11903	 0.0	 3.53881	 0.0	 9	 9	 9	 1.0	 0.0	 1	 -30.0	 30.0;
	11825	 12507	 0.0	 8.84701	 0.0	 4	 4	 4	 1.0	 0.0	 1	 -30.0	 30.0;
	11825	 3894	 0.0	 2.52772	 0.0	 13	 13	 13	 1.0	 0.0	 1	 -30.0	 30.0;
	11825	 8359	 0.0	 1.41552	 0.0	 23	 23	 23	 1.0	 0.0	 1	 -30.0	 30.0;
	11825	 5658	 0.0	 8.74925	 0.0	 4	 4	 4	 1.0	 0.0	 1	 -30.0	 30.0;
	11825	 423	 0.0	 8.74925	 0.0	 4	 4	 4	 1.0	 0.0	 1	 -30.0	 30.0;
	11825	 2192	 0.0	 8.74925	 0.0	 4	 4	 4	 1.0	 0.0	 1	 -30.0	 30.0;
	11825	 4611	 0.0	 8.74925	 0.0	 4	 4	 4	 1.0	 0.0	 1	 -30.0	 30.0;
	11825	 2526	 0.0	 8.74925	 0.0	 4	 4	 4	 1.0	 0.0	 1	 -30.0	 30.0;
	9103	 4746	 0.0	 2.11983	 0.0	 15	 15	 15	 1.0	 0.0	 1	 -30.0	 30.0;
	9103	 10613	 0.0	 6.3595	 0.0	 5	 5	 5	 1.0	 0.0	 1	 -30.0	 30.0;
	214	 1048	 0.0	 5.36212	 0.0	 6	 6	 6	 1.0	 0.0	 1	 -30.0	 30.0;
	214	 5254	 0.0	 5.36212	 0.0	 6	 6	 6	 1.0	 0.0	 1	 -30.0	 30.0;
	214	 8246	 0.0	 5.36212	 0.0	 6	 6	 6	 1.0	 0.0	 1	 -30.0	 30.0;
	214	 3360	 0.0	 5.36212	 0.0	 6	 6	 6	 1.0	 0.0	 1	 -30.0	 30.0;
	214	 6347	 0.0	 5.36212	 0.0	 6	 6	 6	 1.0	 0.0	 1	 -30.0	 30.0;
	214	 11781	 0.0	 2.29805	 0.0	 14	 14	 14	 1.0	 0.0	 1	 -30.0	 30.0;
	214	 3348	 0.0	 0.94626	 0.0	 34	 34	 34	 1.0	 0.0	 1	 -30.0	 30.0;
	214	 13510	 0.0	 8.31475	 0.0	 4	 4	 4	 1.0	 0.0	 1	 -30.0	 30.0;
	214	 9797	 0.0	 8.31475	 0.0	 4	 4	 4	 1.0	 0.0	 1	 -30.0	 30.0;
	214	 5210	 0.0	 3.3259	 0.0	 10	 10	 10	 1.0	 0.0	 1	 -30.0	 30.0;
	214	 9728	 0.0	 5.54317	 0.0	 6	 6	 6	 1.0	 0.0	 1	 -30.0	 30.0;
	214	 635	 0.0	 5.54317	 0.0	 6	 6	 6	 1.0	 0.0	 1	 -30.0	 30.0;
	214	 12541	 0.0	 3.3259	 0.0	 10	 10	 10	 1.0	 0.0	 1	 -30.0	 30.0;
	214	 11393	 0.0	 8.31475	 0.0	 4	 4	 4	 1.0	 0.0	 1	 -30.0	 30.0;
	214	 9056	 0.0	 2.07869	 0.0	 16	 16	 16	 1.0	 0.0	 1	 -30.0	 30.0;
	214	 4009	 0.0	 8.31475	 0.0	 4	 4	 4	 1.0	 0.0	 1	 -30.0	 30.0;
	214	 12221	 0.0	 1.66295	 0.0	 19	 19	 19	 1.0	 0.0	 1	 -30.0	 30.0;
	214	 392	 0.0	 2.53082	 0.0	 13	 13	 13	 1.0	 0.0	 1	 -30.0	 30.0;
	214	 9421	 0.0	 2.95262	 0.0	 11	 11	 11	 1.0	 0.0	 1	 -30.0	 30.0;
	214	 10829	 0.0	 2.53082	 0.0	 13	 13	 13	 1.0	 0.0	 1	 -30.0	 30.0;
	214	 1088	 0.0	 8.85787	 0.0	 4	 4	 4	 1.0	 0.0	 1	 -30.0	 30.0;
	214	 8764	 0.0	 0.70863	 0.0	 45	 45	 45	 1.0	 0.0	 1	 -30.0	 30.0;
	214	 5333	 0.0	 2.53082	 0.0	 13	 13	 13	 1.0	 0.0	 1	 -30.0	 30.0;
	214	 9997	 0.0	 8.31475	 0.0	 4	 4	 4	 1.0	 0.0	 1	 -30.0	 30.0;
	2042	 10452	 -0.02733	 0.34076	 0.0	 93	 93	 93	 1.0	 0.0	 1	 -30.0	 30.0;
	2042	 5116	 -0.01665	 0.37435	 0.0	 85	 85	 85	 1.0	 0.0	 1	 -30.0	 30.0;
	2042	 12383	 0.0	 0.34335	 0.0	 92	 92	 92	 1.0	 0.0	 1	 -30.0	 30.0;
	2042	 7114	 0.0	 0.42788	 0.0	 74	 74	 74	 1.0	 0.0	 1	 -30.0	 30.0;
	2042	 10891	 -0.02145	 0.31331	 0.0	 101	 101	 101	 1.0	 0.0	 1	 -30.0	 30.0;
	2042	 8033	 0.0	 0.19668	 0.0	 161	 161	 161	 1.0	 0.0	 1	 -30.0	 30.0;
	2042	 2712	 0.0	 0.37196	 0.0	 85	 85	 85	 1.0	 0.0	 1	 -30.0	 30.0;
	7827	 5316	 0.11123	 1.47467	 0.0	 22	 22	 22	 1.0	 0.0	 1	 -30.0	 30.0;
	7119	 332	 0.06731	 4.18579	 0.0	 8	 8	 8	 1.0	 0.0	 1	 -30.0	 30.0;
	7119	 1421	 0.06731	 4.18579	 0.0	 8	 8	 8	 1.0	 0.0	 1	 -30.0	 30.0;
	7119	 6717	 0.06731	 4.18579	 0.0	 8	 8	 8	 1.0	 0.0	 1	 -30.0	 30.0;
	4116	 6272	 0.0	 2.04539	 0.0	 16	 16	 16	 1.0	 0.0	 1	 -30.0	 30.0;
	4116	 11672	 0.0	 4.09078	 0.0	 8	 8	 8	 1.0	 0.0	 1	 -30.0	 30.0;
	10180	 111	 0.00431	 0.09324	 0.0	 339	 339	 339	 1.0	 0.0	 1	 -30.0	 30.0;
	10180	 111	 0.0044	 0.091339	 0.0	 346	 346	 346	 1.0	 0.0	 1	 -30.0	 30.0;
	11863	 8494	 0.006356	 0.142878	 0.0	 221	 221	 221	 1.026667	 0.0	 1	 -30.0	 30.0;
	3549	 10458	 0.00523	 0.10214	 0.0	 309	 309	 309	 1.0	 0.0	 1	 -30.0	 30.0;
	3549	 10458	 0.00532	 0.099917	 0.0	 316	 316	 316	 1.0	 0.0	 1	 -30.0	 30.0;
	3549	 10458	 0.00442	 0.105388	 0.0	 300	 300	 300	 1.0	 0.0	 1	 -30.0	 30.0;
	12153	 8241	 0.001002	 0.059033	 0.0	 643	 643	 643	 1.052632	 0.0	 1	 -30.0	 30.0;
	12153	 8241	 0.000812	 0.056028	 0.0	 678	 678	 678	 1.052632	 0.0	 1	 -30.0	 30.0;
	10717	 11653	 0.000921	 0.058347	 0.0	 651	 651	 651	 1.052632	 0.0	 1	 -30.0	 30.0;
	11653	 10859	 0.0016	 0.07243	 0.0	 437	 437	 437	 1.0	 0.0	 1	 -30.0	 30.0;
	11653	 10859	 0.00182	 0.07098	 0.0	 445	 445	 445	 1.0	 0.0	 1	 -30.0	 30.0;
	11653	 10859	 0.00185	 0.06953	 0.0	 455	 455	 455	 1.0	 0.0	 1	 -30.0	 30.0;
	414	 12283	 0.00349	 0.07969	 0.0	 396	 396	 396	 1.0	 0.0	 1	 -30.0	 30.0;
	414	 12283	 0.00355	 0.07799	 0.0	 405	 405	 405	 1.0	 0.0	 1	 -30.0	 30.0;
	2209	 414	 0.001101	 0.048618	 0.0	 781	 781	 781	 1.052632	 0.0	 1	 -30.0	 30.0;
	2209	 414	 0.000984	 0.055107	 0.0	 689	 689	 689	 1.052632	 0.0	 1	 -30.0	 30.0;
	2972	 13068	 0.00175	 0.07752	 0.0	 408	 408	 408	 1.0	 0.0	 1	 -30.0	 30.0;
	2972	 13068	 0.00171	 0.07901	 0.0	 400	 400	 400	 1.0	 0.0	 1	 -30.0	 30.0;
	8698	 6348	 0.00302	 0.091446	 0.0	 346	 346	 346	 1.0	 0.0	 1	 -30.0	 30.0;
	8698	 6348	 0.00295	 0.084678	 0.0	 373	 373	 373	 1.0	 0.0	 1	 -30.0	 30.0;
	8720	 6779	 0.0018	 0.07815	 0.0	 405	 405	 405	 1.0	 0.0	 1	 -30.0	 30.0;
	8720	 6779	 0.00185	 0.07724	 0.0	 409	 409	 409	 1.0	 0.0	 1	 -30.0	 30.0;
	8720	 6779	 0.00193	 0.07007	 0.0	 451	 451	 451	 1.0	 0.0	 1	 -30.0	 30.0;
	850	 3658	 0.00205	 0.094653	 0.0	 401	 401	 401	 1.052632	 0.0	 1	 -30.0	 30.0;
	7565	 756	 0.000454	 0.028947	 0.0	 1092	 1092	 1092	 1.013237	 -0.010791	 1	 -30.0	 30.0;
	7565	 756	 0.0004	 0.032809	 0.0	 963	 963	 963	 1.013237	 -0.010791	 1	 -30.0	 30.0;
	3133	 11180	 0.000342	 0.033341	 0.0	 948	 948	 948	 0.85879	 0.0	 1	 -30.0	 30.0;
	1929	 11180	 0.000342	 0.03398	 0.0	 930	 930	 930	 0.859279	 0.0	 1	 -30.0	 30.0;
	9701	 11180	 0.000121	 0.016316	 0.0	 1936	 1936	 1936	 0.998827	 0.048422	 1	 -30.0	 30.0;
	9701	 5617	 0.000121	 0.025279	 0.0	 1250	 1250	 1250	 0.953802	 -0.305146	 1	 -30.0	 30.0;
	8760	 2611	 0.000347	 0.031823	 0.0	 993	 993	 993	 1.019726	 -0.021448	 1	 -30.0	 30.0;
	8760	 2611	 0.000356	 0.031177	 0.0	 1014	 1014	 1014	 1.019726	 -0.021448	 1	 -30.0	 30.0;
	6316	 971	 0.0	 0.046856	 0.0	 675	 675	 675	 1.0	 -0.305565	 1	 -30.0	 30.0;
	6316	 2611	 0.0	 0.045844	 0.0	 690	 690	 690	 1.0	 0.305565	 1	 -30.0	 30.0;
	4778	 8152	 0.000431	 0.03794	 0.0	 833	 833	 833	 1.083008	 -0.111289	 1	 -30.0	 30.0;
	4778	 8152	 0.00038	 0.046489	 0.0	 680	 680	 680	 1.098173	 -0.129803	 1	 -30.0	 30.0;
	5140	 8509	 0.0004	 0.033343	 0.0	 948	 948	 948	 1.006865	 0.0	 1	 -30.0	 30.0;
	5140	 8509	 0.0004	 0.033981	 0.0	 930	 930	 930	 1.006865	 0.0	 1	 -30.0	 30.0;
	8134	 8509	 0.000121	 0.015958	 0.0	 1980	 1980	 1980	 0.998827	 0.048422	 1	 -30.0	 30.0;
	8134	 5450	 0.000121	 0.014773	 0.0	 2139	 2139	 2139	 0.998827	 0.048422	 1	 -30.0	 30.0;
	517	 446	 0.000131	 0.014593	 0.0	 2165	 2165	 2165	 0.999706	 -0.024225	 1	 -30.0	 30.0;
	517	 9874	 0.000141	 0.013923	 0.0	 2269	 2269	 2269	 0.0	 0.0	 1	 -30.0	 30.0;
	4357	 5711	 0.000194	 0.013059	 0.0	 2419	 2419	 2419	 0.981541	 0.0	 1	 -30.0	 30.0;
	11750	 404	 0.000463	 0.031001	 0.0	 1019	 1019	 1019	 0.966619	 0.0	 1	 -30.0	 30.0;
	11750	 404	 0.000472	 0.030331	 0.0	 1042	 1042	 1042	 0.967946	 0.0	 1	 -30.0	 30.0;
	672	 249	 0.000163	 0.015501	 0.0	 2038	 2038	 2038	 0.947992	 0.0	 1	 -30.0	 30.0;
	8315	 8142	 0.001987	 0.071722	 0.0	 441	 441	 441	 0.960533	 0.0	 1	 -30.0	 30.0;
	3604	 9284	 0.000756	 0.051399	 0.0	 615	 615	 615	 0.948208	 0.0	 1	 -30.0	 30.0;
	3604	 9284	 0.000746	 0.05345	 0.0	 591	 591	 591	 0.957785	 0.0	 1	 -30.0	 30.0;
	10639	 13644	 0.00069	 0.04333	 0.0	 729	 729	 729	 1.052632	 0.0	 1	 -30.0	 30.0;
	3925	 10834	 0.0022	 0.065399	 0.0	 483	 483	 483	 0.966291	 0.0	 1	 -30.0	 30.0;
	3925	 10834	 0.002235	 0.064019	 0.0	 494	 494	 494	 0.916317	 0.0	 1	 -30.0	 30.0;
	12721	 7418	 0.00168	 0.07424	 0.0	 426	 426	 426	 1.0	 0.0	 1	 -30.0	 30.0;
	1360	 5067	 0.002036	 0.070048	 0.0	 451	 451	 451	 0.95687	 0.0	 1	 -30.0	 30.0;
	1360	 5067	 0.001997	 0.071368	 0.0	 443	 443	 443	 0.955577	 0.0	 1	 -30.0	 30.0;
	5338	 1360	 0.00035	 0.032859	 0.0	 1155	 1155	 1155	 1.052632	 0.0	 1	 -30.0	 30.0;
	5338	 1360	 0.0004	 0.0322	 0.0	 1179	 1179	 1179	 1.052632	 0.0	 1	 -30.0	 30.0;
	3750	 5578	 0.00205	 0.06915	 0.0	 457	 457	 457	 1.0	 0.0	 1	 -30.0	 30.0;
	3750	 5578	 0.00082	 0.07342	 0.0	 431	 431	 431	 1.0	 0.0	 1	 -30.0	 30.0;
	524	 4231	 0.002658	 0.07732	 0.0	 409	 409	 409	 0.985917	 0.0	 1	 -30.0	 30.0;
	524	 4231	 0.002712	 0.075649	 0.0	 418	 418	 418	 0.989209	 0.0	 1	 -30.0	 30.0;
	7701	 5663	 0.00065	 0.04604	 0.0	 824	 824	 824	 1.052632	 0.0	 1	 -30.0	 30.0;
	10387	 3766	 0.00062	 0.03629	 0.0	 1046	 1046	 1046	 1.052632	 0.0	 1	 -30.0	 30.0;
	10387	 2914	 0.00019	 0.03263	 0.0	 1163	 1163	 1163	 1.052632	 0.0	 1	 -30.0	 30.0;
	3840	 1375	 0.001797	 0.07284	 0.0	 434	 434	 434	 0.973898	 0.0	 1	 -30.0	 30.0;
	4711	 12377	 0.002712	 0.072578	 0.0	 435	 435	 435	 0.922299	 0.0	 1	 -30.0	 30.0;
	10677	 524	 0.00047	 0.0307	 0.0	 1236	 1236	 1236	 1.052632	 0.0	 1	 -30.0	 30.0;
	11279	 5793	 0.002601	 0.071481	 0.0	 442	 442	 442	 0.969761	 0.0	 1	 -30.0	 30.0;
	11279	 5793	 0.002653	 0.06993	 0.0	 452	 452	 452	 0.957071	 0.0	 1	 -30.0	 30.0;
	8195	 11279	 0.00037	 0.034169	 0.0	 925	 925	 925	 1.052632	 0.0	 1	 -30.0	 30.0;
	8195	 11279	 0.00037	 0.034831	 0.0	 907	 907	 907	 1.052632	 0.0	 1	 -30.0	 30.0;
	9783	 5452	 0.0004	 0.03524	 0.0	 1077	 1077	 1077	 1.052632	 0.0	 1	 -30.0	 30.0;
	9783	 5161	 0.00069	 0.04525	 0.0	 839	 839	 839	 1.052632	 0.0	 1	 -30.0	 30.0;
	13164	 11388	 0.00069	 0.04231	 0.0	 897	 897	 897	 1.052632	 0.0	 1	 -30.0	 30.0;
	4485	 11018	 0.00119	 0.073146	 0.0	 432	 432	 432	 0.969375	 0.0	 1	 -30.0	 30.0;
	4485	 11018	 0.002764	 0.071607	 0.0	 441	 441	 441	 0.944216	 0.0	 1	 -30.0	 30.0;
	3183	 3359	 0.000742	 0.067219	 0.0	 470	 470	 470	 0.96844	 0.0	 1	 -30.0	 30.0;
	3183	 3359	 0.000793	 0.06388	 0.0	 495	 495	 495	 0.973571	 0.0	 1	 -30.0	 30.0;
	8848	 13586	 0.000609	 0.046809	 0.0	 675	 675	 675	 0.930147	 0.0	 1	 -30.0	 30.0;
	8848	 4381	 0.00059	 0.04521	 0.0	 699	 699	 699	 0.878149	 0.0	 1	 -30.0	 30.0;
	11493	 4381	 0.519194	 5.108058	 0.0	 7	 7	 7	 1.0	 0.0	 1	 -30.0	 30.0;
	7727	 3277	 0.000559	 0.039982	 0.0	 790	 790	 790	 0.938747	 0.0	 1	 -30.0	 30.0;
	7727	 8135	 0.000537	 0.045312	 0.0	 698	 698	 698	 0.962486	 0.0	 1	 -30.0	 30.0;
	7221	 2593	 0.000889	 0.061549	 0.0	 514	 514	 514	 0.965788	 0.0	 1	 -30.0	 30.0;
	2593	 1142	 1.467822	 7.764888	 0.0	 4	 4	 4	 1.0	 0.0	 1	 -30.0	 30.0;
	9805	 6724	 0.000586	 0.049031	 0.0	 645	 645	 645	 0.920896	 0.0	 1	 -30.0	 30.0;
	3500	 5137	 0.000417	 0.047801	 0.0	 661	 661	 661	 0.93016	 0.0	 1	 -30.0	 30.0;
	1937	 9970	 0.000755	 0.05143	 0.0	 615	 615	 615	 0.979149	 0.0	 1	 -30.0	 30.0;
	2394	 342	 0.000733	 0.052399	 0.0	 603	 603	 603	 0.893108	 0.0	 1	 -30.0	 30.0;
	11493	 9970	 0.00078	 0.064311	 0.0	 492	 492	 492	 1.0	 0.0	 1	 -30.0	 30.0;
	962	 4784	 0.00089	 0.048632	 0.0	 650	 650	 650	 0.950966	 0.0	 1	 -30.0	 30.0;
	7602	 1142	 0.00855	 0.08972	 0.0	 351	 351	 351	 1.0	 0.0	 1	 -30.0	 30.0;
	2044	 1142	 0.00223	 0.04836	 0.0	 653	 653	 653	 1.0	 0.0	 1	 -30.0	 30.0;
	10523	 3070	 0.000581	 0.043111	 0.0	 733	 733	 733	 0.912599	 0.0	 1	 -30.0	 30.0;
	9981	 13254	 0.000579	 0.043272	 0.0	 730	 730	 730	 0.90589	 0.0	 1	 -30.0	 30.0;
	5402	 10366	 0.000586	 0.049031	 0.0	 645	 645	 645	 0.910127	 0.0	 1	 -30.0	 30.0;
	12041	 6499	 0.000559	 0.049192	 0.0	 643	 643	 643	 0.922734	 0.0	 1	 -30.0	 30.0;
	13341	 11058	 0.000573	 0.051129	 0.0	 618	 618	 618	 0.907986	 0.0	 1	 -30.0	 30.0;
	3238	 7602	 0.000417	 0.039229	 0.0	 806	 806	 806	 0.953969	 0.0	 1	 -30.0	 30.0;
	7602	 9831	 0.230542	 1.197733	 0.0	 26	 26	 26	 1.0	 0.0	 1	 -30.0	 30.0;
	7602	 12273	 0.02284	 0.2644	 0.0	 120	 120	 120	 1.0	 0.0	 1	 -30.0	 30.0;
	7602	 3510	 0.08537	 0.736798	 0.0	 52	 52	 52	 1.0	 0.0	 1	 -30.0	 30.0;
	7602	 6844	 1.402768	 3.640289	 0.0	 9	 9	 9	 1.0	 0.0	 1	 -30.0	 30.0;
	7602	 6590	 1.050227	 4.450207	 0.0	 7	 7	 7	 1.0	 0.0	 1	 -30.0	 30.0;
	12038	 9831	 0.000716	 0.04371	 0.0	 723	 723	 723	 0.946441	 0.0	 1	 -30.0	 30.0;
	2044	 9831	 0.518622	 2.317689	 0.0	 14	 14	 14	 1.0	 0.0	 1	 -30.0	 30.0;
	7626	 12273	 0.00059	 0.045662	 0.0	 692	 692	 692	 1.01916	 0.0	 1	 -30.0	 30.0;
	7626	 2191	 0.000603	 0.050959	 0.0	 620	 620	 620	 0.956199	 0.0	 1	 -30.0	 30.0;
	2044	 12273	 0.047769	 0.554178	 0.0	 57	 57	 57	 1.0	 0.0	 1	 -30.0	 30.0;
	11382	 10883	 0.000591	 0.045153	 0.0	 700	 700	 700	 0.930134	 0.0	 1	 -30.0	 30.0;
	11382	 412	 0.0006	 0.047778	 0.0	 662	 662	 662	 0.924997	 0.0	 1	 -30.0	 30.0;
	11493	 8395	 0.02436	 0.270151	 0.0	 117	 117	 117	 1.0	 0.0	 1	 -30.0	 30.0;
	5712	 2044	 0.000802	 0.05727	 0.0	 552	 552	 552	 0.928766	 0.0	 1	 -30.0	 30.0;
	5712	 2044	 0.000823	 0.056059	 0.0	 564	 564	 564	 0.934686	 0.0	 1	 -30.0	 30.0;
	2044	 3510	 0.188099	 1.291901	 0.0	 30	 30	 30	 1.0	 0.0	 1	 -30.0	 30.0;
	2044	 6844	 2.466323	 7.26343	 0.0	 5	 5	 5	 1.0	 0.0	 1	 -30.0	 30.0;
	3239	 4174	 0.000523	 0.050352	 0.0	 628	 628	 628	 0.901137	 0.0	 1	 -30.0	 30.0;
	13103	 8395	 0.000682	 0.049638	 0.0	 637	 637	 637	 0.969199	 0.0	 1	 -30.0	 30.0;
	13103	 3579	 0.00099	 0.04736	 0.0	 667	 667	 667	 1.014121	 0.0	 1	 -30.0	 30.0;
	471	 3510	 0.000616	 0.048759	 0.0	 779	 779	 779	 0.897787	 0.0	 1	 -30.0	 30.0;
	11179	 7780	 9e-05	 0.008611	 0.0	 3669	 3669	 3669	 0.0	 0.0	 1	 -30.0	 30.0;
	8510	 11012	 9e-05	 0.015192	 0.0	 2080	 2080	 2080	 1.0	 -0.428189	 1	 -30.0	 30.0;
	129	 6590	 0.000664	 0.045609	 0.0	 693	 693	 693	 0.910348	 0.0	 1	 -30.0	 30.0;
	3618	 6844	 0.000649	 0.044862	 0.0	 705	 705	 705	 0.926974	 0.0	 1	 -30.0	 30.0;
	8729	 6473	 0.00067	 0.04326	 0.0	 731	 731	 731	 0.906404	 0.0	 1	 -30.0	 30.0;
	3049	 8729	 9e-05	 0.012629	 0.0	 2502	 2502	 2502	 1.0	 0.304578	 1	 -30.0	 30.0;
	10227	 5892	 0.000246	 0.018419	 0.0	 2060	 2060	 2060	 0.915375	 0.063819	 1	 -30.0	 30.0;
	5892	 8032	 0.00131	 0.07578	 0.0	 496	 496	 496	 1.045454	 0.0	 1	 -30.0	 30.0;
	5892	 8032	 0.00128	 0.07077	 0.0	 532	 532	 532	 1.045454	 0.0	 1	 -30.0	 30.0;
	4589	 12971	 0.00131	 0.062651	 0.0	 505	 505	 505	 1.0	 0.0	 1	 -30.0	 30.0;
	4589	 12971	 0.00133	 0.0577	 0.0	 548	 548	 548	 1.0	 0.0	 1	 -30.0	 30.0;
	7401	 2028	 0.001495	 0.059475	 0.0	 531	 531	 531	 0.974576	 0.0	 1	 -30.0	 30.0;
	7401	 13653	 0.001453	 0.061392	 0.0	 515	 515	 515	 0.974576	 0.0	 1	 -30.0	 30.0;
	3581	 7895	 0.001475	 0.074554	 0.0	 509	 509	 509	 0.981267	 0.0	 1	 -30.0	 30.0;
	3581	 7895	 0.001309	 0.084508	 0.0	 449	 449	 449	 0.981267	 0.0	 1	 -30.0	 30.0;
	1248	 2267	 0.00119	 0.084099	 0.0	 376	 376	 376	 1.0	 0.0	 1	 -30.0	 30.0;
	6446	 1542	 0.00117	 0.064859	 0.0	 585	 585	 585	 1.0	 0.0	 1	 -30.0	 30.0;
	6446	 1542	 0.00114	 0.066091	 0.0	 574	 574	 574	 1.0	 0.0	 1	 -30.0	 30.0;
	11068	 8672	 0.001225	 0.083401	 0.0	 455	 455	 455	 0.973021	 0.0	 1	 -30.0	 30.0;
	11068	 8672	 0.001394	 0.082574	 0.0	 460	 460	 460	 0.973021	 0.0	 1	 -30.0	 30.0;
	5019	 6742	 0.001415	 0.080475	 0.0	 393	 393	 393	 0.973021	 0.0	 1	 -30.0	 30.0;
	5019	 6742	 0.001447	 0.078793	 0.0	 401	 401	 401	 0.973021	 0.0	 1	 -30.0	 30.0;
	13321	 13072	 0.001444	 0.074683	 0.0	 423	 423	 423	 0.981267	 0.0	 1	 -30.0	 30.0;
	13321	 13072	 0.001475	 0.073051	 0.0	 433	 433	 433	 0.981267	 0.0	 1	 -30.0	 30.0;
	1292	 6703	 0.001316	 0.070415	 0.0	 449	 449	 449	 0.974576	 0.0	 1	 -30.0	 30.0;
	11423	 5014	 0.00128	 0.065919	 0.0	 480	 480	 480	 1.0	 0.0	 1	 -30.0	 30.0;
	13151	 704	 0.001056	 0.075919	 0.0	 500	 500	 500	 1.052632	 0.0	 1	 -30.0	 30.0;
	1784	 704	 0.001451	 0.078431	 0.0	 403	 403	 403	 0.905512	 0.0	 1	 -30.0	 30.0;
	1784	 704	 0.001415	 0.075297	 0.0	 420	 420	 420	 0.905512	 0.0	 1	 -30.0	 30.0;
	3834	 2401	 0.001411	 0.061844	 0.0	 511	 511	 511	 0.974576	 0.0	 1	 -30.0	 30.0;
	3834	 2401	 0.001432	 0.058938	 0.0	 536	 536	 536	 0.974576	 0.0	 1	 -30.0	 30.0;
	3420	 2931	 0.00229	 0.085231	 0.0	 371	 371	 371	 0.979339	 0.0	 1	 -30.0	 30.0;
	7537	 832	 0.001474	 0.06058	 0.0	 522	 522	 522	 0.974576	 0.0	 1	 -30.0	 30.0;
	2035	 1873	 0.00125	 0.064651	 0.0	 489	 489	 489	 1.0	 0.0	 1	 -30.0	 30.0;
	2035	 1873	 0.00123	 0.065919	 0.0	 480	 480	 480	 1.0	 0.0	 1	 -30.0	 30.0;
	2035	 1873	 0.0012	 0.06718	 0.0	 471	 471	 471	 1.0	 0.0	 1	 -30.0	 30.0;
	573	 10751	 0.001221	 0.069631	 0.0	 454	 454	 454	 0.982906	 0.0	 1	 -30.0	 30.0;
	573	 10751	 0.00119	 0.065604	 0.0	 482	 482	 482	 0.982906	 0.0	 1	 -30.0	 30.0;
	2384	 13523	 0.001039	 0.045925	 0.0	 688	 688	 688	 0.981267	 0.0	 1	 -30.0	 30.0;
	13646	 13522	 0.000406	 0.027181	 0.0	 1396	 1396	 1396	 1.57924	 -0.661366	 1	 -30.0	 30.0;
	13522	 2673	 0.001563	 0.060356	 0.0	 524	 524	 524	 0.982906	 0.0	 1	 -30.0	 30.0;
	13522	 2673	 0.001459	 0.059041	 0.0	 535	 535	 535	 0.982906	 0.0	 1	 -30.0	 30.0;
	8812	 1580	 0.001531	 0.068989	 0.0	 458	 458	 458	 0.942623	 0.0	 1	 -30.0	 30.0;
	12258	 9419	 0.000318	 0.014328	 0.0	 2648	 2648	 2648	 1.002506	 0.0	 1	 -30.0	 30.0;
	2900	 8749	 0.000246	 0.018419	 0.0	 2060	 2060	 2060	 0.915375	 0.063819	 1	 -30.0	 30.0;
	8749	 5414	 0.00121	 0.066091	 0.0	 569	 569	 569	 1.0	 0.0	 1	 -30.0	 30.0;
	8749	 5414	 0.00118	 0.062289	 0.0	 604	 604	 604	 1.0	 0.0	 1	 -30.0	 30.0;
	12618	 9130	 0.001646	 0.071174	 0.0	 444	 444	 444	 0.905512	 0.0	 1	 -30.0	 30.0;
	12618	 9130	 0.00229	 0.087099	 0.0	 363	 363	 363	 1.045454	 0.0	 1	 -30.0	 30.0;
	2745	 1565	 0.001421	 0.061107	 0.0	 621	 621	 621	 0.974576	 0.0	 1	 -30.0	 30.0;
	12830	 4536	 0.001573	 0.080941	 0.0	 391	 391	 391	 0.956938	 0.0	 1	 -30.0	 30.0;
	12830	 4536	 0.001594	 0.078385	 0.0	 403	 403	 403	 0.956938	 0.0	 1	 -30.0	 30.0;
	7538	 12389	 0.001369	 0.06454	 0.0	 490	 490	 490	 0.974576	 0.0	 1	 -30.0	 30.0;
	7538	 12389	 0.001348	 0.065203	 0.0	 485	 485	 485	 0.974576	 0.0	 1	 -30.0	 30.0;
	1643	 4221	 0.001295	 0.071353	 0.0	 443	 443	 443	 0.974576	 0.0	 1	 -30.0	 30.0;
	1643	 4221	 0.001295	 0.070826	 0.0	 446	 446	 446	 0.974576	 0.0	 1	 -30.0	 30.0;
	2145	 6309	 0.001441	 0.084934	 0.0	 372	 372	 372	 0.956938	 0.0	 1	 -30.0	 30.0;
	2145	 6309	 0.001463	 0.083626	 0.0	 378	 378	 378	 0.956938	 0.0	 1	 -30.0	 30.0;
	5852	 46	 0.000448	 0.016447	 0.0	 1920	 1920	 1920	 1.002506	 0.0	 1	 -30.0	 30.0;
	5852	 2346	 0.001134	 0.053193	 0.0	 594	 594	 594	 0.998185	 0.0	 1	 -30.0	 30.0;
	46	 2346	 0.00136	 0.057539	 0.0	 549	 549	 549	 1.0	 0.0	 1	 -30.0	 30.0;
	5205	 6143	 0.001432	 0.06454	 0.0	 490	 490	 490	 0.974576	 0.0	 1	 -30.0	 30.0;
	969	 5917	 0.00195	 0.114628	 0.0	 276	 276	 276	 0.979339	 0.0	 1	 -30.0	 30.0;
	2598	 10920	 0.001295	 0.067067	 0.0	 471	 471	 471	 0.974576	 0.0	 1	 -30.0	 30.0;
	349	 13276	 0.001242	 0.074563	 0.0	 424	 424	 424	 0.974576	 0.0	 1	 -30.0	 30.0;
	9002	 6629	 0.00126	 0.060099	 0.0	 526	 526	 526	 1.0	 0.0	 1	 -30.0	 30.0;
	9002	 6629	 0.00135	 0.06051	 0.0	 522	 522	 522	 1.0	 0.0	 1	 -30.0	 30.0;
	10919	 5136	 0.00036	 0.042469	 0.0	 894	 894	 894	 1.052174	 0.0	 1	 -30.0	 30.0;
	1708	 8682	 0.001278	 0.05335	 0.0	 592	 592	 592	 0.973021	 0.0	 1	 -30.0	 30.0;
	9895	 7914	 0.000503	 0.049251	 0.0	 642	 642	 642	 0.977126	 -0.14746	 1	 -30.0	 30.0;
	9895	 7914	 0.000503	 0.048177	 0.0	 656	 656	 656	 0.977126	 -0.14746	 1	 -30.0	 30.0;
	2956	 6660	 0.000333	 0.021103	 0.0	 1497	 1497	 1497	 0.972707	 0.0	 1	 -30.0	 30.0;
	13180	 10140	 0.00044	 0.033083	 0.0	 955	 955	 955	 0.977126	 -0.043442	 1	 -30.0	 30.0;
	5115	 3596	 0.000164	 0.013858	 0.0	 2280	 2280	 2280	 0.9919	 0.0	 1	 -30.0	 30.0;
	7231	 4303	 0.000353	 0.046754	 0.0	 676	 676	 676	 0.937567	 -0.262319	 1	 -30.0	 30.0;
	2225	 5238	 0.000159	 0.030001	 0.0	 1053	 1053	 1053	 0.937567	 0.16528	 1	 -30.0	 30.0;
	4782	 3568	 0.000273	 0.016349	 0.0	 1932	 1932	 1932	 0.956938	 0.01672	 1	 -30.0	 30.0;
	1939	 9543	 0.000289	 0.027718	 0.0	 1140	 1140	 1140	 1.036553	 -0.169835	 1	 -30.0	 30.0;
	8399	 9418	 0.00142	 0.02765	 0.0	 1141	 1141	 1141	 1.0	 0.0	 1	 -30.0	 30.0;
	8399	 9418	 0.00145	 0.02707	 0.0	 1166	 1166	 1166	 1.0	 0.0	 1	 -30.0	 30.0;
	2399	 565	 0.000469	 0.030842	 0.0	 1025	 1025	 1025	 0.997643	 0.0	 1	 -30.0	 30.0;
	6503	 565	 0.00435	 0.076291	 0.0	 414	 414	 414	 1.0	 0.432244	 1	 -30.0	 30.0;
	6173	 10574	 0.000352	 0.020852	 0.0	 1515	 1515	 1515	 1.03275	 0.0	 1	 -30.0	 30.0;
	6000	 217	 0.0003	 0.01099	 0.0	 2874	 2874	 2874	 1.0	 0.0	 1	 -30.0	 30.0;
	6000	 217	 0.00029	 0.0112	 0.0	 2820	 2820	 2820	 1.0	 0.0	 1	 -30.0	 30.0;
	7078	 6129	 0.000375	 0.018768	 0.0	 1683	 1683	 1683	 1.028418	 0.0	 1	 -30.0	 30.0;
	4399	 3110	 0.000537	 0.028553	 0.0	 1107	 1107	 1107	 0.991288	 0.0	 1	 -30.0	 30.0;
	4399	 3110	 0.000537	 0.028002	 0.0	 1128	 1128	 1128	 0.988586	 0.0	 1	 -30.0	 30.0;
	2362	 5841	 0.000622	 0.033296	 0.0	 949	 949	 949	 0.956938	 0.0	 1	 -30.0	 30.0;
	2362	 5841	 0.000622	 0.029475	 0.0	 1072	 1072	 1072	 0.956938	 0.00962	 1	 -30.0	 30.0;
	1194	 566	 0.00072	 0.026242	 0.0	 1204	 1204	 1204	 0.957131	 0.0	 1	 -30.0	 30.0;
	1194	 566	 0.000644	 0.029735	 0.0	 1063	 1063	 1063	 0.957131	 0.0	 1	 -30.0	 30.0;
	1788	 1140	 0.00314	 0.168928	 0.0	 187	 187	 187	 1.0	 0.024998	 1	 -30.0	 30.0;
	1788	 1140	 0.00307	 0.172182	 0.0	 184	 184	 184	 1.0	 0.024998	 1	 -30.0	 30.0;
	892	 8601	 0.000188	 0.016506	 0.0	 1914	 1914	 1914	 0.973613	 0.0	 1	 -30.0	 30.0;
	10332	 8762	 0.000259	 0.027074	 0.0	 1167	 1167	 1167	 1.002506	 0.0	 1	 -30.0	 30.0;
	4802	 436	 0.000437	 0.02611	 0.0	 1210	 1210	 1210	 1.047869	 0.0	 1	 -30.0	 30.0;
	12785	 4872	 0.000446	 0.025573	 0.0	 1235	 1235	 1235	 1.047869	 0.0	 1	 -30.0	 30.0;
	10774	 3721	 0.00032	 0.02243	 0.0	 1409	 1409	 1409	 1.034211	 0.0	 1	 -30.0	 30.0;
	10838	 9099	 6.091942	 8.676029	 0.0	 3	 3	 3	 1.0	 0.0	 1	 -30.0	 30.0;
	8035	 9099	 6.444008	 8.676035	 0.0	 3	 3	 3	 1.0	 0.0	 1	 -30.0	 30.0;
	11812	 9099	 23.9876	 40.776864	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	12474	 9099	 35.24587	 57.202482	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	91	 9099	 45.97521	 69.597102	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	10349	 9099	 0.081469	 0.775971	 0.0	 41	 41	 41	 1.0	 0.0	 1	 -30.0	 30.0;
	12274	 9099	 32.03719	 50.568181	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	1789	 9099	 0.628884	 2.485744	 0.0	 13	 13	 13	 1.0	 0.0	 1	 -30.0	 30.0;
	10838	 11009	 12.31426	 19.110329	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	8035	 11009	 13.03616	 19.128307	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	10349	 11009	 0.197581	 1.393719	 0.0	 23	 23	 23	 1.0	 0.0	 1	 -30.0	 30.0;
	1789	 11009	 1.415165	 4.81467	 0.0	 7	 7	 7	 1.0	 0.0	 1	 -30.0	 30.0;
	7867	 3932	 0.13108	 0.821607	 0.0	 38	 38	 38	 1.0	 0.0	 1	 -30.0	 30.0;
	9172	 3932	 0.129079	 0.839681	 0.0	 38	 38	 38	 1.0	 0.0	 1	 -30.0	 30.0;
	9153	 3773	 0.069591	 0.599051	 0.0	 53	 53	 53	 1.0	 0.0	 1	 -30.0	 30.0;
	9153	 1645	 0.04983	 0.471267	 0.0	 67	 67	 67	 1.0	 0.0	 1	 -30.0	 30.0;
	9153	 4860	 0.00502	 0.310928	 0.0	 102	 102	 102	 1.0	 0.0	 1	 -30.0	 30.0;
	131	 707	 5.68843	 10.297518	 0.0	 3	 3	 3	 1.0	 0.0	 1	 -30.0	 30.0;
	12474	 707	 48.32851	 56.749998	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	11732	 707	 23.27066	 28.824377	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	3895	 707	 50.96074	 55.43596	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	131	 9072	 5.967355	 9.180988	 0.0	 3	 3	 3	 1.0	 0.0	 1	 -30.0	 30.0;
	12474	 9072	 44.27686	 58.522723	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	11732	 9072	 20.49132	 30.954553	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	3895	 9072	 43.12397	 61.993787	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	10335	 5899	 -0.04093	 0.365413	 0.0	 86	 86	 86	 1.0	 0.0	 1	 -30.0	 30.0;
	10335	 1467	 0.140533	 1.138574	 0.0	 28	 28	 28	 1.0	 0.0	 1	 -30.0	 30.0;
	10335	 5005	 0.151053	 1.206163	 0.0	 26	 26	 26	 1.0	 0.0	 1	 -30.0	 30.0;
	10335	 5923	 3.496607	 8.23892	 0.0	 4	 4	 4	 1.0	 0.0	 1	 -30.0	 30.0;
	10335	 1752	 3.21482	 7.345567	 0.0	 4	 4	 4	 1.0	 0.0	 1	 -30.0	 30.0;
	10335	 644	 0.136738	 1.1482	 0.0	 28	 28	 28	 1.0	 0.0	 1	 -30.0	 30.0;
	10335	 2726	 0.138539	 1.094044	 0.0	 29	 29	 29	 1.0	 0.0	 1	 -30.0	 30.0;
	10335	 5344	 0.077251	 0.917036	 0.0	 35	 35	 35	 1.0	 0.0	 1	 -30.0	 30.0;
	10335	 2264	 0.954778	 3.73151	 0.0	 9	 9	 9	 1.0	 0.0	 1	 -30.0	 30.0;
	10335	 4342	 0.745845	 4.144945	 0.0	 8	 8	 8	 1.0	 0.0	 1	 -30.0	 30.0;
	10335	 1684	 0.723892	 4.195776	 0.0	 8	 8	 8	 1.0	 0.0	 1	 -30.0	 30.0;
	12622	 5899	 0.47093	 3.07252	 0.0	 11	 11	 11	 1.0	 0.0	 1	 -30.0	 30.0;
	272	 5899	 0.45124	 2.967768	 0.0	 11	 11	 11	 1.0	 0.0	 1	 -30.0	 30.0;
	4883	 5899	 0.460083	 2.907231	 0.0	 11	 11	 11	 1.0	 0.0	 1	 -30.0	 30.0;
	7997	 5899	 2.286777	 7.419422	 0.0	 5	 5	 5	 1.0	 0.0	 1	 -30.0	 30.0;
	6414	 5899	 3.438636	 9.067975	 0.0	 4	 4	 4	 1.0	 0.0	 1	 -30.0	 30.0;
	12406	 5899	 0.885578	 3.747314	 0.0	 9	 9	 9	 1.0	 0.0	 1	 -30.0	 30.0;
	8314	 5899	 0.788967	 4.246901	 0.0	 8	 8	 8	 1.0	 0.0	 1	 -30.0	 30.0;
	9085	 5899	 1.804731	 7.772521	 0.0	 5	 5	 5	 1.0	 0.0	 1	 -30.0	 30.0;
	10280	 7699	 0.000716	 0.032505	 0.0	 972	 972	 972	 0.957364	 0.0	 1	 -30.0	 30.0;
	10280	 7699	 0.00056	 0.04105	 0.0	 770	 770	 770	 0.982537	 0.0	 1	 -30.0	 30.0;
	10280	 7699	 0.00057	 0.040211	 0.0	 786	 786	 786	 0.987993	 0.0	 1	 -30.0	 30.0;
	376	 7699	 10.24442	 15.278311	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	6032	 7699	 10.4376	 14.953303	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	3603	 7699	 31.55372	 31.927684	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	2174	 7699	 0.02494	 0.501983	 0.0	 63	 63	 63	 1.0	 0.0	 1	 -30.0	 30.0;
	7131	 7699	 2.458264	 5.693595	 0.0	 6	 6	 6	 1.0	 0.0	 1	 -30.0	 30.0;
	13017	 7699	 21.7686	 29.266527	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	6550	 7699	 0.260765	 1.554236	 0.0	 21	 21	 21	 1.0	 0.0	 1	 -30.0	 30.0;
	964	 7699	 0.41095	 2.453926	 0.0	 13	 13	 13	 1.0	 0.0	 1	 -30.0	 30.0;
	13282	 7699	 1.358636	 3.804546	 0.0	 8	 8	 8	 1.0	 0.0	 1	 -30.0	 30.0;
	12961	 12536	 0.00445	 0.11669	 0.0	 271	 271	 271	 1.0	 0.0	 1	 -30.0	 30.0;
	3288	 260	 0.02812	 0.471488	 0.0	 67	 67	 67	 1.0	 0.0	 1	 -30.0	 30.0;
	2382	 260	 0.109781	 0.670062	 0.0	 47	 47	 47	 1.0	 0.0	 1	 -30.0	 30.0;
	5152	 260	 0.11731	 0.676136	 0.0	 47	 47	 47	 1.0	 0.0	 1	 -30.0	 30.0;
	10382	 11302	 0.000443	 0.034282	 0.0	 1107	 1107	 1107	 0.914188	 0.0	 1	 -30.0	 30.0;
	6823	 11302	 0.000407	 0.0336	 0.0	 1130	 1130	 1130	 0.914919	 0.0	 1	 -30.0	 30.0;
	131	 11302	 0.05005	 0.961922	 0.0	 40	 40	 40	 1.0	 0.0	 1	 -30.0	 30.0;
	10838	 11302	 20.2438	 55.378103	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	8035	 11302	 20.42293	 51.698341	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	11812	 11302	 7.97376	 20.509093	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	12474	 11302	 1.402252	 5.36219	 0.0	 7	 7	 7	 1.0	 0.0	 1	 -30.0	 30.0;
	91	 11302	 4.842562	 10.371072	 0.0	 4	 4	 4	 1.0	 0.0	 1	 -30.0	 30.0;
	11732	 11302	 0.593884	 2.602686	 0.0	 15	 15	 15	 1.0	 0.0	 1	 -30.0	 30.0;
	12274	 11302	 9.390701	 21.464872	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	3895	 11302	 1.334504	 5.801447	 0.0	 7	 7	 7	 1.0	 0.0	 1	 -30.0	 30.0;
	12622	 1467	 1.754986	 5.357133	 0.0	 6	 6	 6	 1.0	 0.0	 1	 -30.0	 30.0;
	12622	 5005	 1.766898	 5.923268	 0.0	 6	 6	 6	 1.0	 0.0	 1	 -30.0	 30.0;
	12622	 5923	 1.832964	 7.959834	 0.0	 4	 4	 4	 1.0	 0.0	 1	 -30.0	 30.0;
	12622	 1752	 1.611565	 6.707825	 0.0	 5	 5	 5	 1.0	 0.0	 1	 -30.0	 30.0;
	12622	 644	 -0.019578	 0.602618	 0.0	 53	 53	 53	 1.0	 0.0	 1	 -30.0	 30.0;
	12622	 2726	 -0.018109	 0.575138	 0.0	 55	 55	 55	 1.0	 0.0	 1	 -30.0	 30.0;
	12622	 5344	 2.305263	 5.580056	 0.0	 6	 6	 6	 1.0	 0.0	 1	 -30.0	 30.0;
	12622	 2264	 0.324709	 1.981648	 0.0	 16	 16	 16	 1.0	 0.0	 1	 -30.0	 30.0;
	12622	 4342	 11.49377	 18.997923	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	12622	 1684	 10.16551	 21.393357	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	12622	 5667	 0.00083	 0.06663	 0.0	 475	 475	 475	 1.041579	 0.0	 1	 -30.0	 30.0;
	9636	 7765	 0.220599	 1.426839	 0.0	 22	 22	 22	 1.0	 0.0	 1	 -30.0	 30.0;
	13354	 7765	 0.215413	 1.319979	 0.0	 29	 29	 29	 1.0	 0.0	 1	 -30.0	 30.0;
	9506	 7765	 0.07932	 0.491198	 0.0	 64	 64	 64	 1.0	 0.0	 1	 -30.0	 30.0;
	1172	 7765	 0.05112	 0.388202	 0.0	 81	 81	 81	 1.0	 0.0	 1	 -30.0	 30.0;
	5569	 7765	 7.957025	 11.110533	 0.0	 3	 3	 3	 1.0	 0.0	 1	 -30.0	 30.0;
	8176	 7765	 8.10723	 10.874171	 0.0	 3	 3	 3	 1.0	 0.0	 1	 -30.0	 30.0;
	6825	 7765	 0.19505	 0.651797	 0.0	 47	 47	 47	 1.0	 0.0	 1	 -30.0	 30.0;
	10957	 7765	 0.273698	 1.122666	 0.0	 28	 28	 28	 1.0	 0.0	 1	 -30.0	 30.0;
	9636	 9820	 -0.016694	 0.279194	 0.0	 113	 113	 113	 1.0	 0.0	 1	 -30.0	 30.0;
	9636	 9820	 0.00066	 0.04694	 0.0	 673	 673	 673	 1.071156	 0.0	 1	 -30.0	 30.0;
	9636	 7733	 0.262431	 2.115858	 0.0	 15	 15	 15	 1.0	 0.0	 1	 -30.0	 30.0;
	9636	 3193	 0.251911	 2.002563	 0.0	 16	 16	 16	 1.0	 0.0	 1	 -30.0	 30.0;
	9636	 6386	 0.086669	 0.634127	 0.0	 50	 50	 50	 1.0	 0.0	 1	 -30.0	 30.0;
	13354	 9820	 -0.018471	 0.253657	 0.0	 150	 150	 150	 1.0	 0.0	 1	 -30.0	 30.0;
	13354	 9820	 0.000298	 0.012803	 0.0	 2963	 2963	 2963	 1.148319	 0.0	 1	 -30.0	 30.0;
	13354	 7733	 0.307389	 1.800831	 0.0	 21	 21	 21	 1.0	 0.0	 1	 -30.0	 30.0;
	13354	 3193	 0.307181	 1.800693	 0.0	 21	 21	 21	 1.0	 0.0	 1	 -30.0	 30.0;
	13354	 6386	 0.083082	 0.659398	 0.0	 58	 58	 58	 1.0	 0.0	 1	 -30.0	 30.0;
	9506	 9820	 2.852479	 6.564462	 0.0	 5	 5	 5	 1.0	 0.0	 1	 -30.0	 30.0;
	1172	 9820	 0.610723	 2.391322	 0.0	 13	 13	 13	 1.0	 0.0	 1	 -30.0	 30.0;
	5569	 9820	 0.796095	 2.828719	 0.0	 11	 11	 11	 1.0	 0.0	 1	 -30.0	 30.0;
	8176	 9820	 0.778781	 2.619215	 0.0	 12	 12	 12	 1.0	 0.0	 1	 -30.0	 30.0;
	6825	 9820	 5.253512	 8.690912	 0.0	 4	 4	 4	 1.0	 0.0	 1	 -30.0	 30.0;
	10957	 9820	 0.14057	 0.924359	 0.0	 34	 34	 34	 1.0	 0.0	 1	 -30.0	 30.0;
	622	 7915	 0.00012	 0.01406	 0.0	 2247	 2247	 2247	 1.0	 0.41413	 1	 -30.0	 30.0;
	9506	 3170	 0.00012	 0.013772	 0.0	 2294	 2294	 2294	 1.0	 0.41413	 1	 -30.0	 30.0;
	9506	 7733	 34.83864	 37.361504	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	9506	 3193	 31.4626	 43.434901	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	9506	 6386	 9.837258	 14.382266	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	2872	 13213	 0.124359	 1.222541	 0.0	 26	 26	 26	 1.0	 0.0	 1	 -30.0	 30.0;
	7278	 13213	 0.121719	 1.24562	 0.0	 26	 26	 26	 1.0	 0.0	 1	 -30.0	 30.0;
	2872	 10921	 0.11651	 1.13624	 0.0	 28	 28	 28	 1.0	 0.0	 1	 -30.0	 30.0;
	7278	 10921	 0.13205	 1.113513	 0.0	 29	 29	 29	 1.0	 0.0	 1	 -30.0	 30.0;
	6362	 1167	 0.000447	 0.03387	 0.0	 933	 933	 933	 0.987247	 0.0	 1	 -30.0	 30.0;
	6362	 3932	 0.188878	 0.872161	 0.0	 36	 36	 36	 1.0	 0.0	 1	 -30.0	 30.0;
	6362	 10699	 0.000399	 0.010683	 0.0	 2955	 2955	 2955	 1.015002	 0.0	 1	 -30.0	 30.0;
	13454	 3746	 0.01902	 0.177292	 0.0	 178	 178	 178	 1.0	 0.0	 1	 -30.0	 30.0;
	13454	 12363	 0.079771	 0.509993	 0.0	 62	 62	 62	 1.0	 0.0	 1	 -30.0	 30.0;
	13454	 5547	 0.00919	 0.137159	 0.0	 230	 230	 230	 1.0	 0.0	 1	 -30.0	 30.0;
	131	 13629	 10.8518	 37.942518	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	131	 8267	 20.41343	 54.805408	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	131	 4147	 20.30263	 51.706374	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	131	 11448	 0.787812	 4.341828	 0.0	 8	 8	 8	 1.0	 0.0	 1	 -30.0	 30.0;
	131	 2359	 0.590422	 4.326316	 0.0	 8	 8	 8	 1.0	 0.0	 1	 -30.0	 30.0;
	131	 366	 0.712119	 2.758379	 0.0	 12	 12	 12	 1.0	 0.0	 1	 -30.0	 30.0;
	131	 1535	 0.891274	 4.745083	 0.0	 7	 7	 7	 1.0	 0.0	 1	 -30.0	 30.0;
	131	 5183	 27.32618	 53.325484	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	131	 7014	 0.072382	 1.414889	 0.0	 27	 27	 27	 1.0	 0.0	 1	 -30.0	 30.0;
	131	 12720	 0.070083	 1.331163	 0.0	 29	 29	 29	 1.0	 0.0	 1	 -30.0	 30.0;
	131	 9401	 0.02163	 0.743629	 0.0	 51	 51	 51	 1.0	 0.0	 1	 -30.0	 30.0;
	131	 2256	 3.623961	 20.259002	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	131	 1566	 0.851039	 4.324031	 0.0	 8	 8	 8	 1.0	 0.0	 1	 -30.0	 30.0;
	131	 5754	 1.040443	 4.789612	 0.0	 7	 7	 7	 1.0	 0.0	 1	 -30.0	 30.0;
	1172	 7733	 8.633058	 14.86384	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	5569	 7733	 0.05238	 0.529835	 0.0	 60	 60	 60	 1.0	 0.0	 1	 -30.0	 30.0;
	8176	 7733	 0.05337	 0.518554	 0.0	 61	 61	 61	 1.0	 0.0	 1	 -30.0	 30.0;
	6825	 7733	 56.80165	 51.109504	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	10957	 7733	 2.452686	 6.967768	 0.0	 5	 5	 5	 1.0	 0.0	 1	 -30.0	 30.0;
	1172	 3193	 8.052273	 16.496276	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	5569	 3193	 0.04414	 0.60938	 0.0	 52	 52	 52	 1.0	 0.0	 1	 -30.0	 30.0;
	8176	 3193	 0.0432	 0.620868	 0.0	 51	 51	 51	 1.0	 0.0	 1	 -30.0	 30.0;
	6825	 3193	 47.16736	 58.301648	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	10957	 3193	 2.566529	 6.851652	 0.0	 5	 5	 5	 1.0	 0.0	 1	 -30.0	 30.0;
	10838	 13629	 21.60319	 36.731304	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	10838	 8267	 38.25416	 49.701504	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	10838	 4147	 39.65235	 49.572723	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	10838	 11448	 13.37881	 27.533241	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	10838	 2359	 11.70014	 34.83726	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	10838	 366	 0.03578	 2.06572	 0.0	 16	 16	 16	 1.0	 0.0	 1	 -30.0	 30.0;
	10838	 9823	 44.92382	 57.412053	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	10838	 6896	 5.792867	 13.966068	 0.0	 3	 3	 3	 1.0	 0.0	 1	 -30.0	 30.0;
	10838	 10979	 5.68705	 12.979224	 0.0	 3	 3	 3	 1.0	 0.0	 1	 -30.0	 30.0;
	10838	 1535	 23.49307	 56.524238	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	10838	 5183	 0.817382	 3.615513	 0.0	 9	 9	 9	 1.0	 0.0	 1	 -30.0	 30.0;
	10838	 7014	 1.090651	 5.780887	 0.0	 7	 7	 7	 1.0	 0.0	 1	 -30.0	 30.0;
	10838	 12720	 1.04626	 5.209279	 0.0	 8	 8	 8	 1.0	 0.0	 1	 -30.0	 30.0;
	10838	 7916	 0.644758	 1.803532	 0.0	 20	 20	 20	 1.0	 0.0	 1	 -30.0	 30.0;
	10838	 3743	 0.580852	 2.069945	 0.0	 18	 18	 18	 1.0	 0.0	 1	 -30.0	 30.0;
	10838	 9401	 15.32341	 41.617723	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	10838	 4717	 37.75623	 69.158594	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	10838	 2256	 4.031925	 12.920362	 0.0	 3	 3	 3	 1.0	 0.0	 1	 -30.0	 30.0;
	8035	 13629	 19.41759	 39.081025	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	8035	 8267	 38.13227	 52.87396	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	8035	 4147	 39.55609	 52.783939	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	8035	 11448	 13.35596	 29.188359	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	8035	 2359	 13.38227	 31.89335	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	8035	 366	 0.06002	 1.808379	 0.0	 18	 18	 18	 1.0	 0.0	 1	 -30.0	 30.0;
	8035	 9823	 48.46122	 56.359411	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	8035	 6896	 6.294598	 13.758307	 0.0	 3	 3	 3	 1.0	 0.0	 1	 -30.0	 30.0;
	8035	 10979	 6.185319	 14.074795	 0.0	 3	 3	 3	 1.0	 0.0	 1	 -30.0	 30.0;
	8035	 1535	 21.89474	 63.064402	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	8035	 5183	 0.750554	 3.860318	 0.0	 9	 9	 9	 1.0	 0.0	 1	 -30.0	 30.0;
	8035	 7014	 1.114889	 6.088781	 0.0	 7	 7	 7	 1.0	 0.0	 1	 -30.0	 30.0;
	8035	 12720	 1.069114	 5.491413	 0.0	 7	 7	 7	 1.0	 0.0	 1	 -30.0	 30.0;
	8035	 7916	 0.653109	 1.929778	 0.0	 19	 19	 19	 1.0	 0.0	 1	 -30.0	 30.0;
	8035	 3743	 0.672888	 1.912604	 0.0	 19	 19	 19	 1.0	 0.0	 1	 -30.0	 30.0;
	8035	 9401	 18.13504	 36.319253	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	8035	 4717	 40.86842	 68.019379	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	8035	 2256	 4.398892	 12.729917	 0.0	 3	 3	 3	 1.0	 0.0	 1	 -30.0	 30.0;
	8653	 3932	 0.0384	 0.48786	 0.0	 65	 65	 65	 1.0	 0.0	 1	 -30.0	 30.0;
	272	 1467	 0.17575	 1.589628	 0.0	 20	 20	 20	 1.0	 0.0	 1	 -30.0	 30.0;
	272	 5005	 0.16178	 1.59079	 0.0	 20	 20	 20	 1.0	 0.0	 1	 -30.0	 30.0;
	272	 5923	 22.34695	 35.318561	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	272	 1752	 20.61288	 31.520779	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	272	 644	 1.071953	 3.96018	 0.0	 8	 8	 8	 1.0	 0.0	 1	 -30.0	 30.0;
	272	 2726	 1.073546	 3.773961	 0.0	 9	 9	 9	 1.0	 0.0	 1	 -30.0	 30.0;
	272	 5344	 1.477701	 3.981233	 0.0	 8	 8	 8	 1.0	 0.0	 1	 -30.0	 30.0;
	272	 2264	 5.635665	 13.348342	 0.0	 3	 3	 3	 1.0	 0.0	 1	 -30.0	 30.0;
	272	 4342	 13.41828	 27.828945	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	272	 1684	 13.04432	 28.183522	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	4883	 1467	 0.17575	 1.589628	 0.0	 20	 20	 20	 1.0	 0.0	 1	 -30.0	 30.0;
	4883	 5005	 0.161789	 1.590785	 0.0	 20	 20	 20	 1.0	 0.0	 1	 -30.0	 30.0;
	4883	 5923	 22.34695	 35.318561	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	4883	 1752	 20.61288	 31.520779	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	4883	 644	 1.071953	 3.96018	 0.0	 8	 8	 8	 1.0	 0.0	 1	 -30.0	 30.0;
	4883	 2726	 1.073546	 3.773961	 0.0	 9	 9	 9	 1.0	 0.0	 1	 -30.0	 30.0;
	4883	 5344	 1.477701	 3.981233	 0.0	 8	 8	 8	 1.0	 0.0	 1	 -30.0	 30.0;
	4883	 2264	 5.635665	 13.348342	 0.0	 3	 3	 3	 1.0	 0.0	 1	 -30.0	 30.0;
	4883	 4342	 13.41828	 27.828945	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	4883	 1684	 13.04432	 28.183522	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	7997	 1467	 7.514876	 17.076863	 0.0	 3	 3	 3	 1.0	 0.0	 1	 -30.0	 30.0;
	6414	 1467	 10.18967	 19.679343	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	12406	 1467	 1.403533	 4.891322	 0.0	 7	 7	 7	 1.0	 0.0	 1	 -30.0	 30.0;
	8314	 1467	 1.431054	 4.791528	 0.0	 7	 7	 7	 1.0	 0.0	 1	 -30.0	 30.0;
	9085	 1467	 7.830992	 14.143185	 0.0	 3	 3	 3	 1.0	 0.0	 1	 -30.0	 30.0;
	7997	 5005	 9.209711	 15.822724	 0.0	 3	 3	 3	 1.0	 0.0	 1	 -30.0	 30.0;
	6414	 5005	 13.04525	 19.283054	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	12406	 5005	 1.367066	 5.515496	 0.0	 6	 6	 6	 1.0	 0.0	 1	 -30.0	 30.0;
	8314	 5005	 1.339153	 5.62376	 0.0	 6	 6	 6	 1.0	 0.0	 1	 -30.0	 30.0;
	9085	 5005	 7.23719	 17.339673	 0.0	 3	 3	 3	 1.0	 0.0	 1	 -30.0	 30.0;
	3464	 1758	 0.00696	 0.20656	 0.0	 153	 153	 153	 1.0	 0.0	 1	 -30.0	 30.0;
	2872	 1758	 0.085711	 0.903781	 0.0	 35	 35	 35	 1.0	 0.0	 1	 -30.0	 30.0;
	7278	 1758	 0.09713	 0.885702	 0.0	 36	 36	 36	 1.0	 0.0	 1	 -30.0	 30.0;
	1172	 6386	 2.771122	 4.936011	 0.0	 6	 6	 6	 1.0	 0.0	 1	 -30.0	 30.0;
	2872	 9140	 0.296032	 1.447438	 0.0	 22	 22	 22	 1.0	 0.0	 1	 -30.0	 30.0;
	2872	 141	 0.281413	 1.320152	 0.0	 29	 29	 29	 1.0	 0.0	 1	 -30.0	 30.0;
	7278	 9140	 0.307202	 1.385873	 0.0	 23	 23	 23	 1.0	 0.0	 1	 -30.0	 30.0;
	7278	 141	 0.25536	 1.463643	 0.0	 26	 26	 26	 1.0	 0.0	 1	 -30.0	 30.0;
	1550	 9140	 0.00046	 0.03669	 0.0	 861	 861	 861	 0.902975	 0.0	 1	 -30.0	 30.0;
	10000	 141	 0.000808	 0.04562	 0.0	 832	 832	 832	 0.895125	 0.0	 1	 -30.0	 30.0;
	10000	 141	 0.000438	 0.03862	 0.0	 983	 983	 983	 0.879211	 0.0	 1	 -30.0	 30.0;
	3288	 4180	 0.037081	 0.480186	 0.0	 66	 66	 66	 1.0	 0.0	 1	 -30.0	 30.0;
	2382	 4180	 0.074531	 0.583946	 0.0	 54	 54	 54	 1.0	 0.0	 1	 -30.0	 30.0;
	5152	 4180	 0.08	 0.590186	 0.0	 54	 54	 54	 1.0	 0.0	 1	 -30.0	 30.0;
	5912	 11734	 0.000127	 0.009835	 0.0	 3212	 3212	 3212	 1.034606	 0.0	 1	 -30.0	 30.0;
	7454	 3986	 0.10579	 0.434903	 0.0	 71	 71	 71	 1.0	 0.0	 1	 -30.0	 30.0;
	7454	 12363	 0.09937	 0.415727	 0.0	 74	 74	 74	 1.0	 0.0	 1	 -30.0	 30.0;
	2586	 3986	 0.095997	 0.482181	 0.0	 65	 65	 65	 1.0	 0.0	 1	 -30.0	 30.0;
	2586	 12363	 0.086717	 0.480388	 0.0	 65	 65	 65	 1.0	 0.0	 1	 -30.0	 30.0;
	5380	 4199	 0.00013	 0.011536	 0.0	 2738	 2738	 2738	 1.088419	 0.0	 1	 -30.0	 30.0;
	7997	 5923	 0.873905	 3.992149	 0.0	 10	 10	 10	 1.0	 0.0	 1	 -30.0	 30.0;
	6414	 5923	 0.120211	 1.173533	 0.0	 27	 27	 27	 1.0	 0.0	 1	 -30.0	 30.0;
	12406	 5923	 7.082025	 15.591937	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	8314	 5923	 7.220868	 15.273755	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	9085	 5923	 0.872831	 3.28905	 0.0	 12	 12	 12	 1.0	 0.0	 1	 -30.0	 30.0;
	7997	 1752	 0.921508	 3.094834	 0.0	 12	 12	 12	 1.0	 0.0	 1	 -30.0	 30.0;
	6414	 1752	 0.129919	 0.960764	 0.0	 33	 33	 33	 1.0	 0.0	 1	 -30.0	 30.0;
	12406	 1752	 6.142769	 14.777069	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	8314	 1752	 6.017355	 15.066946	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	9085	 1752	 0.694463	 3.375206	 0.0	 12	 12	 12	 1.0	 0.0	 1	 -30.0	 30.0;
	7997	 644	 7.254848	 17.556091	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	7997	 2726	 6.944598	 15.819948	 0.0	 3	 3	 3	 1.0	 0.0	 1	 -30.0	 30.0;
	7997	 5344	 0.962188	 3.649169	 0.0	 11	 11	 11	 1.0	 0.0	 1	 -30.0	 30.0;
	7997	 2264	 2.525	 6.52029	 0.0	 6	 6	 6	 1.0	 0.0	 1	 -30.0	 30.0;
	7997	 4342	 0.00154	 0.39572	 0.0	 96	 96	 96	 1.0	 0.0	 1	 -30.0	 30.0;
	7997	 1684	 0.0014	 0.384758	 0.0	 99	 99	 99	 1.0	 0.0	 1	 -30.0	 30.0;
	5569	 6386	 0.590782	 1.406718	 0.0	 21	 21	 21	 1.0	 0.0	 1	 -30.0	 30.0;
	8176	 6386	 0.526337	 1.594252	 0.0	 19	 19	 19	 1.0	 0.0	 1	 -30.0	 30.0;
	11812	 13629	 0.836859	 5.618595	 0.0	 6	 6	 6	 1.0	 0.0	 1	 -30.0	 30.0;
	12474	 13629	 1.237665	 7.884711	 0.0	 4	 4	 4	 1.0	 0.0	 1	 -30.0	 30.0;
	11732	 13629	 3.449174	 20.571071	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	10349	 13629	 5.302273	 16.162393	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	12274	 13629	 0.789525	 4.620455	 0.0	 7	 7	 7	 1.0	 0.0	 1	 -30.0	 30.0;
	1789	 13629	 2.372521	 10.507644	 0.0	 3	 3	 3	 1.0	 0.0	 1	 -30.0	 30.0;
	2123	 4147	 0.000495	 0.033881	 0.0	 933	 933	 933	 0.892514	 0.0	 1	 -30.0	 30.0;
	11812	 8267	 2.23905	 7.164463	 0.0	 5	 5	 5	 1.0	 0.0	 1	 -30.0	 30.0;
	12474	 8267	 3.327273	 9.634503	 0.0	 4	 4	 4	 1.0	 0.0	 1	 -30.0	 30.0;
	11732	 8267	 8.134091	 27.90289	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	10349	 8267	 10.55806	 23.307847	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	12274	 8267	 1.718843	 7.201859	 0.0	 5	 5	 5	 1.0	 0.0	 1	 -30.0	 30.0;
	1789	 8267	 4.571488	 16.921905	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	11812	 4147	 1.894649	 7.933677	 0.0	 4	 4	 4	 1.0	 0.0	 1	 -30.0	 30.0;
	12474	 4147	 3.133678	 10.68802	 0.0	 3	 3	 3	 1.0	 0.0	 1	 -30.0	 30.0;
	11732	 4147	 8.769008	 26.754135	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	10349	 4147	 11.85517	 21.464873	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	12274	 4147	 2.005517	 6.368182	 0.0	 5	 5	 5	 1.0	 0.0	 1	 -30.0	 30.0;
	1789	 4147	 5.553718	 14.366735	 0.0	 3	 3	 3	 1.0	 0.0	 1	 -30.0	 30.0;
	7042	 359	 0.000206	 0.020261	 0.0	 1559	 1559	 1559	 1.029618	 0.0	 1	 -30.0	 30.0;
	4338	 1990	 9.6e-05	 0.010041	 0.0	 3146	 3146	 3146	 1.024823	 0.0	 1	 -30.0	 30.0;
	6414	 644	 4.540289	 12.081814	 0.0	 3	 3	 3	 1.0	 0.0	 1	 -30.0	 30.0;
	12406	 644	 0.14887	 1.547789	 0.0	 21	 21	 21	 1.0	 0.0	 1	 -30.0	 30.0;
	8314	 644	 0.145641	 1.433141	 0.0	 22	 22	 22	 1.0	 0.0	 1	 -30.0	 30.0;
	9085	 644	 7.255165	 15.148962	 0.0	 3	 3	 3	 1.0	 0.0	 1	 -30.0	 30.0;
	6414	 2726	 4.918802	 10.649998	 0.0	 3	 3	 3	 1.0	 0.0	 1	 -30.0	 30.0;
	12406	 2726	 0.170281	 1.312108	 0.0	 24	 24	 24	 1.0	 0.0	 1	 -30.0	 30.0;
	8314	 2726	 0.17349	 1.284174	 0.0	 25	 25	 25	 1.0	 0.0	 1	 -30.0	 30.0;
	9085	 2726	 7.658058	 13.540087	 0.0	 3	 3	 3	 1.0	 0.0	 1	 -30.0	 30.0;
	10367	 4860	 1.803947	 6.514197	 0.0	 5	 5	 5	 1.0	 0.0	 1	 -30.0	 30.0;
	10367	 8960	 1.414404	 5.42687	 0.0	 6	 6	 6	 1.0	 0.0	 1	 -30.0	 30.0;
	10367	 1779	 0.097091	 1.338712	 0.0	 24	 24	 24	 1.0	 0.0	 1	 -30.0	 30.0;
	10367	 6012	 0.069813	 0.61338	 0.0	 52	 52	 52	 1.0	 0.0	 1	 -30.0	 30.0;
	9178	 4860	 1.656925	 6.386704	 0.0	 5	 5	 5	 1.0	 0.0	 1	 -30.0	 30.0;
	9178	 8960	 1.503047	 5.113989	 0.0	 6	 6	 6	 1.0	 0.0	 1	 -30.0	 30.0;
	9178	 1779	 0.107382	 1.212396	 0.0	 26	 26	 26	 1.0	 0.0	 1	 -30.0	 30.0;
	9178	 6012	 0.080478	 0.53394	 0.0	 59	 59	 59	 1.0	 0.0	 1	 -30.0	 30.0;
	6414	 5344	 1.566157	 4.554339	 0.0	 7	 7	 7	 1.0	 0.0	 1	 -30.0	 30.0;
	12406	 5344	 3.21405	 6.727273	 0.0	 5	 5	 5	 1.0	 0.0	 1	 -30.0	 30.0;
	8314	 5344	 2.86343	 7.62438	 0.0	 4	 4	 4	 1.0	 0.0	 1	 -30.0	 30.0;
	9085	 5344	 0.784091	 3.665289	 0.0	 11	 11	 11	 1.0	 0.0	 1	 -30.0	 30.0;
	11812	 11448	 -0.013061	 0.68473	 0.0	 47	 47	 47	 1.0	 0.0	 1	 -30.0	 30.0;
	11812	 2359	 0.02627	 0.92126	 0.0	 35	 35	 35	 1.0	 0.0	 1	 -30.0	 30.0;
	11812	 366	 5.225831	 17.344184	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	11812	 917	 37.01108	 55.722988	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	11812	 4995	 38.53255	 55.73961	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	11812	 1535	 0.00421	 0.609432	 0.0	 52	 52	 52	 1.0	 0.0	 1	 -30.0	 30.0;
	11812	 5183	 3.373338	 12.718144	 0.0	 3	 3	 3	 1.0	 0.0	 1	 -30.0	 30.0;
	11812	 7014	 5.841413	 14.226459	 0.0	 3	 3	 3	 1.0	 0.0	 1	 -30.0	 30.0;
	11812	 12720	 4.851247	 14.847647	 0.0	 3	 3	 3	 1.0	 0.0	 1	 -30.0	 30.0;
	11812	 7916	 15.98753	 46.096945	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	11812	 3743	 15.83449	 47.580335	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	11812	 9401	 5.167521	 17.612876	 0.0	 3	 3	 3	 1.0	 0.0	 1	 -30.0	 30.0;
	11812	 2256	 0.170402	 3.131509	 0.0	 11	 11	 11	 1.0	 0.0	 1	 -30.0	 30.0;
	11812	 7691	 13.13227	 24.978533	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	11812	 6065	 11.55748	 21.738223	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	12474	 11448	 0.071828	 1.118006	 0.0	 29	 29	 29	 1.0	 0.0	 1	 -30.0	 30.0;
	12474	 2359	 0.01624	 0.986219	 0.0	 33	 33	 33	 1.0	 0.0	 1	 -30.0	 30.0;
	12474	 366	 1.180471	 4.696329	 0.0	 7	 7	 7	 1.0	 0.0	 1	 -30.0	 30.0;
	12474	 1535	 0.01296	 0.834834	 0.0	 38	 38	 38	 1.0	 0.0	 1	 -30.0	 30.0;
	12474	 5183	 4.962535	 20.238919	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	12474	 7014	 0.872438	 4.821676	 0.0	 8	 8	 8	 1.0	 0.0	 1	 -30.0	 30.0;
	12474	 12720	 0.801593	 4.526524	 0.0	 9	 9	 9	 1.0	 0.0	 1	 -30.0	 30.0;
	12474	 7916	 20.20014	 50.806099	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	12474	 3743	 23.16066	 50.423823	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	12474	 9401	 0.966621	 4.164474	 0.0	 9	 9	 9	 1.0	 0.0	 1	 -30.0	 30.0;
	12474	 2256	 0.448781	 4.337397	 0.0	 8	 8	 8	 1.0	 0.0	 1	 -30.0	 30.0;
	12474	 1566	 11.58657	 23.771465	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	12474	 5754	 13.00554	 26.333102	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	12474	 7691	 17.94044	 35.608035	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	12474	 6065	 15.18213	 32.262467	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	6414	 2264	 0.430249	 2.466066	 0.0	 13	 13	 13	 1.0	 0.0	 1	 -30.0	 30.0;
	6414	 4342	 0.0683	 0.916828	 0.0	 35	 35	 35	 1.0	 0.0	 1	 -30.0	 30.0;
	6414	 1684	 0.06612	 0.843352	 0.0	 38	 38	 38	 1.0	 0.0	 1	 -30.0	 30.0;
	12406	 2264	 1.444298	 4.757438	 0.0	 7	 7	 7	 1.0	 0.0	 1	 -30.0	 30.0;
	8314	 2264	 1.472603	 4.660331	 0.0	 7	 7	 7	 1.0	 0.0	 1	 -30.0	 30.0;
	9085	 2264	 2.284917	 6.055578	 0.0	 6	 6	 6	 1.0	 0.0	 1	 -30.0	 30.0;
	722	 10991	 0.000504	 0.031781	 0.0	 994	 994	 994	 1.041866	 0.0	 1	 -30.0	 30.0;
	722	 4860	 0.086683	 1.502285	 0.0	 21	 21	 21	 1.0	 0.0	 1	 -30.0	 30.0;
	722	 8960	 0.05572	 1.389266	 0.0	 23	 23	 23	 1.0	 0.0	 1	 -30.0	 30.0;
	722	 1779	 0.40606	 1.910249	 0.0	 17	 17	 17	 1.0	 0.0	 1	 -30.0	 30.0;
	722	 6012	 0.0265	 0.438137	 0.0	 72	 72	 72	 1.0	 0.0	 1	 -30.0	 30.0;
	11650	 9023	 0.000669	 0.032368	 0.0	 976	 976	 976	 1.076608	 0.0	 1	 -30.0	 30.0;
	12406	 4342	 16.48554	 31.878093	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	8314	 4342	 18.68347	 31.239671	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	9085	 4342	 -0.006984	 0.380578	 0.0	 100	 100	 100	 1.0	 0.0	 1	 -30.0	 30.0;
	12406	 1684	 19.27748	 29.774787	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	8314	 1684	 19.64132	 29.142564	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	9085	 1684	 -0.0075	 0.354442	 0.0	 108	 108	 108	 1.0	 0.0	 1	 -30.0	 30.0;
	478	 4860	 0.979504	 4.164463	 0.0	 8	 8	 8	 1.0	 0.0	 1	 -30.0	 30.0;
	8529	 4860	 0.241095	 2.041488	 0.0	 16	 16	 16	 1.0	 0.0	 1	 -30.0	 30.0;
	5951	 4860	 0.239525	 2.084091	 0.0	 16	 16	 16	 1.0	 0.0	 1	 -30.0	 30.0;
	478	 8960	 0.733492	 3.60186	 0.0	 9	 9	 9	 1.0	 0.0	 1	 -30.0	 30.0;
	8529	 8960	 0.176539	 1.602479	 0.0	 20	 20	 20	 1.0	 0.0	 1	 -30.0	 30.0;
	5951	 8960	 0.203141	 1.572934	 0.0	 20	 20	 20	 1.0	 0.0	 1	 -30.0	 30.0;
	91	 11448	 3.658471	 11.068596	 0.0	 3	 3	 3	 1.0	 0.0	 1	 -30.0	 30.0;
	11732	 11448	 0.10706	 1.950682	 0.0	 17	 17	 17	 1.0	 0.0	 1	 -30.0	 30.0;
	10349	 11448	 10.14339	 24.185954	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	12274	 11448	 0.07038	 1.132707	 0.0	 28	 28	 28	 1.0	 0.0	 1	 -30.0	 30.0;
	3895	 11448	 3.802686	 12.010955	 0.0	 3	 3	 3	 1.0	 0.0	 1	 -30.0	 30.0;
	1789	 11448	 3.583058	 17.321278	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	91	 2359	 2.938636	 13.075416	 0.0	 3	 3	 3	 1.0	 0.0	 1	 -30.0	 30.0;
	11732	 2359	 0.00024	 2.372521	 0.0	 14	 14	 14	 1.0	 0.0	 1	 -30.0	 30.0;
	10349	 2359	 9.23781	 30.750004	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	12274	 2359	 0.041469	 1.048347	 0.0	 31	 31	 31	 1.0	 0.0	 1	 -30.0	 30.0;
	3895	 2359	 3.576446	 11.947316	 0.0	 3	 3	 3	 1.0	 0.0	 1	 -30.0	 30.0;
	1789	 2359	 4.138017	 18.151449	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	478	 3932	 0.107147	 0.58482	 0.0	 54	 54	 54	 1.0	 0.0	 1	 -30.0	 30.0;
	478	 1779	 7.159972	 13.527699	 0.0	 3	 3	 3	 1.0	 0.0	 1	 -30.0	 30.0;
	478	 6012	 1.77874	 5.115028	 0.0	 6	 6	 6	 1.0	 0.0	 1	 -30.0	 30.0;
	10349	 8608	 7.195455	 16.568181	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	1789	 8608	 40.97313	 63.811984	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	10349	 4055	 7.423554	 18.762807	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	1789	 4055	 42.39256	 65.737609	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	91	 366	 -0.016674	 0.278698	 0.0	 114	 114	 114	 1.0	 0.0	 1	 -30.0	 30.0;
	91	 1535	 5.349861	 16.166202	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	91	 5183	 9.134349	 25.279081	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	91	 7014	 0.197001	 1.168768	 0.0	 33	 33	 33	 1.0	 0.0	 1	 -30.0	 30.0;
	91	 12720	 0.18955	 1.05277	 0.0	 36	 36	 36	 1.0	 0.0	 1	 -30.0	 30.0;
	91	 7916	 6.030263	 16.006928	 0.0	 3	 3	 3	 1.0	 0.0	 1	 -30.0	 30.0;
	91	 3743	 5.975346	 16.528394	 0.0	 3	 3	 3	 1.0	 0.0	 1	 -30.0	 30.0;
	91	 9401	 3.107895	 9.123269	 0.0	 4	 4	 4	 1.0	 0.0	 1	 -30.0	 30.0;
	91	 2256	 11.81025	 37.443907	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	91	 1566	 27.31856	 49.591408	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	91	 5754	 34.37812	 55.136426	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	11732	 366	 0.231281	 1.502872	 0.0	 21	 21	 21	 1.0	 0.0	 1	 -30.0	 30.0;
	12274	 366	 7.048967	 19.24607	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	3895	 366	 0.229277	 1.235537	 0.0	 26	 26	 26	 1.0	 0.0	 1	 -30.0	 30.0;
	1789	 366	 2.544835	 7.532231	 0.0	 4	 4	 4	 1.0	 0.0	 1	 -30.0	 30.0;
	10349	 8156	 35.47521	 51.481403	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	10349	 6030	 34.64256	 52.336781	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	6825	 6386	 15.75277	 20.093496	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	9567	 2772	 0.000283	 0.012832	 0.0	 2462	 2462	 2462	 1.014459	 0.0	 1	 -30.0	 30.0;
	12271	 2801	 0.000292	 0.01188	 0.0	 2659	 2659	 2659	 0.984333	 0.0	 1	 -30.0	 30.0;
	10446	 917	 0.000398	 0.034511	 0.0	 916	 916	 916	 0.921465	 0.0	 1	 -30.0	 30.0;
	12274	 917	 33.09298	 47.6281	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	12274	 4995	 34.44215	 47.623971	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	11732	 1535	 0.161039	 2.815236	 0.0	 12	 12	 12	 1.0	 0.0	 1	 -30.0	 30.0;
	11732	 5183	 9.489612	 27.308865	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	11732	 7014	 0.246808	 1.61939	 0.0	 24	 24	 24	 1.0	 0.0	 1	 -30.0	 30.0;
	11732	 12720	 0.228082	 1.521121	 0.0	 25	 25	 25	 1.0	 0.0	 1	 -30.0	 30.0;
	11732	 7916	 18.28047	 42.772855	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	11732	 3743	 18.10111	 44.135045	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	11732	 9401	 0.331281	 2.194459	 0.0	 18	 18	 18	 1.0	 0.0	 1	 -30.0	 30.0;
	11732	 2256	 0.752078	 9.020083	 0.0	 4	 4	 4	 1.0	 0.0	 1	 -30.0	 30.0;
	11732	 1566	 4.985803	 12.659968	 0.0	 3	 3	 3	 1.0	 0.0	 1	 -30.0	 30.0;
	11732	 5754	 5.581648	 14.030467	 0.0	 3	 3	 3	 1.0	 0.0	 1	 -30.0	 30.0;
	9492	 6495	 0.000476	 0.03161	 0.0	 1201	 1201	 1201	 0.909467	 0.0	 1	 -30.0	 30.0;
	9492	 9067	 0.000457	 0.030901	 0.0	 1228	 1228	 1228	 0.908902	 0.0	 1	 -30.0	 30.0;
	10349	 12043	 1.305041	 5.872521	 0.0	 6	 6	 6	 1.0	 0.0	 1	 -30.0	 30.0;
	1789	 12043	 12.81343	 30.764465	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	10349	 9823	 0.657355	 3.229132	 0.0	 10	 10	 10	 1.0	 0.0	 1	 -30.0	 30.0;
	1789	 9823	 6.467975	 16.903509	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	10349	 6896	 -0.017839	 0.427271	 0.0	 74	 74	 74	 1.0	 0.0	 1	 -30.0	 30.0;
	10349	 10979	 -0.020298	 0.420457	 0.0	 76	 76	 76	 1.0	 0.0	 1	 -30.0	 30.0;
	10349	 5183	 0.05596	 1.32043	 0.0	 24	 24	 24	 1.0	 0.0	 1	 -30.0	 30.0;
	10349	 7916	 0.430997	 2.378602	 0.0	 16	 16	 16	 1.0	 0.0	 1	 -30.0	 30.0;
	10349	 3743	 0.443573	 2.357341	 0.0	 16	 16	 16	 1.0	 0.0	 1	 -30.0	 30.0;
	10349	 4717	 0.073677	 2.231025	 0.0	 15	 15	 15	 1.0	 0.0	 1	 -30.0	 30.0;
	10349	 2256	 0.927909	 4.907895	 0.0	 7	 7	 7	 1.0	 0.0	 1	 -30.0	 30.0;
	10349	 7691	 42.82895	 57.943891	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	10349	 6065	 36.44598	 52.531845	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	7108	 10979	 0.00037	 0.03817	 0.0	 828	 828	 828	 0.98054	 0.0	 1	 -30.0	 30.0;
	7108	 6896	 0.000309	 0.035711	 0.0	 885	 885	 885	 0.977048	 0.0	 1	 -30.0	 30.0;
	1789	 6896	 0.529731	 3.305372	 0.0	 10	 10	 10	 1.0	 0.0	 1	 -30.0	 30.0;
	1789	 10979	 0.54188	 3.249793	 0.0	 10	 10	 10	 1.0	 0.0	 1	 -30.0	 30.0;
	12274	 1535	 -0.008017	 0.233843	 0.0	 135	 135	 135	 1.0	 0.0	 1	 -30.0	 30.0;
	12274	 5183	 5.680748	 16.603181	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	12274	 7014	 6.552285	 16.597649	 0.0	 3	 3	 3	 1.0	 0.0	 1	 -30.0	 30.0;
	12274	 12720	 5.444182	 17.322713	 0.0	 3	 3	 3	 1.0	 0.0	 1	 -30.0	 30.0;
	12274	 7916	 24.32756	 59.210516	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	12274	 3743	 24.09903	 61.117023	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	12274	 9401	 5.625068	 20.064407	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	12274	 2256	 0.456198	 4.138435	 0.0	 8	 8	 8	 1.0	 0.0	 1	 -30.0	 30.0;
	12274	 7691	 11.52632	 21.784622	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	12274	 6065	 10.14543	 18.959839	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	12274	 1535	 0.000476	 0.031631	 0.0	 999	 999	 999	 0.889435	 0.0	 1	 -30.0	 30.0;
	3895	 1535	 5.521694	 14.730582	 0.0	 3	 3	 3	 1.0	 0.0	 1	 -30.0	 30.0;
	1789	 1535	 19.34525	 41.508264	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	3895	 5183	 32.73967	 68.105374	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	1789	 5183	 -0.083244	 0.946591	 0.0	 34	 34	 34	 1.0	 0.0	 1	 -30.0	 30.0;
	6656	 7014	 0.000447	 0.035271	 0.0	 1076	 1076	 1076	 0.895342	 0.0	 1	 -30.0	 30.0;
	3895	 7014	 -0.015103	 0.337521	 0.0	 113	 113	 113	 1.0	 0.0	 1	 -30.0	 30.0;
	3895	 12720	 -0.012686	 0.286488	 0.0	 133	 133	 133	 1.0	 0.0	 1	 -30.0	 30.0;
	3895	 7916	 27.97992	 45.335871	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	3895	 3743	 28.86773	 44.978518	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	3895	 9401	 0.994044	 4.152008	 0.0	 9	 9	 9	 1.0	 0.0	 1	 -30.0	 30.0;
	3895	 2256	 19.05609	 41.630194	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	3895	 1566	 11.95776	 23.687676	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	3895	 5754	 11.73892	 30.398893	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	1789	 7014	 10.39773	 25.376037	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	1789	 12720	 9.457438	 23.791321	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	1789	 7916	 0.000409	 0.036341	 0.0	 1044	 1044	 1044	 0.87261	 0.0	 1	 -30.0	 30.0;
	1789	 7916	 -0.006942	 0.494855	 0.0	 77	 77	 77	 1.0	 0.0	 1	 -30.0	 30.0;
	1789	 3743	 -0.008161	 0.491033	 0.0	 78	 78	 78	 1.0	 0.0	 1	 -30.0	 30.0;
	1789	 4717	 4.701801	 16.907201	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	1789	 2256	 0.18313	 2.973269	 0.0	 11	 11	 11	 1.0	 0.0	 1	 -30.0	 30.0;
	1789	 7691	 30.6392	 44.945983	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	1789	 6065	 27.01524	 39.081706	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	9085	 12614	 0.000757	 0.064121	 0.0	 592	 592	 592	 1.085043	 0.0	 1	 -30.0	 30.0;
	8529	 1779	 2.158264	 7.671693	 0.0	 4	 4	 4	 1.0	 0.0	 1	 -30.0	 30.0;
	5951	 1779	 2.128512	 7.829339	 0.0	 4	 4	 4	 1.0	 0.0	 1	 -30.0	 30.0;
	8529	 6012	 0.536593	 2.637604	 0.0	 12	 12	 12	 1.0	 0.0	 1	 -30.0	 30.0;
	5951	 6012	 0.529487	 2.445638	 0.0	 13	 13	 13	 1.0	 0.0	 1	 -30.0	 30.0;
	10957	 13306	 0.00039	 0.016602	 0.0	 1903	 1903	 1903	 0.960225	 -0.068985	 1	 -30.0	 30.0;
	10957	 6386	 0.856787	 2.082133	 0.0	 15	 15	 15	 1.0	 0.0	 1	 -30.0	 30.0;
	12058	 3119	 0.000515	 0.03175	 0.0	 995	 995	 995	 0.996485	 0.0	 1	 -30.0	 30.0;
	12058	 3119	 0.000408	 0.036729	 0.0	 860	 860	 860	 0.996624	 0.0	 1	 -30.0	 30.0;
	3043	 5297	 0.00648	 0.148407	 0.0	 256	 256	 256	 1.0	 0.0	 1	 -30.0	 30.0;
	3635	 5297	 0.00055	 0.038349	 0.0	 990	 990	 990	 0.857944	 0.0	 1	 -30.0	 30.0;
	2376	 4127	 0.114331	 0.894649	 0.0	 36	 36	 36	 1.0	 0.0	 1	 -30.0	 30.0;
	2354	 4127	 3.931818	 5.960743	 0.0	 5	 5	 5	 1.0	 0.0	 1	 -30.0	 30.0;
	7451	 4127	 1.022872	 2.477479	 0.0	 12	 12	 12	 1.0	 0.0	 1	 -30.0	 30.0;
	2265	 4127	 1.145744	 2.668595	 0.0	 11	 11	 11	 1.0	 0.0	 1	 -30.0	 30.0;
	12109	 4127	 0.115521	 0.652645	 0.0	 48	 48	 48	 1.0	 0.0	 1	 -30.0	 30.0;
	2376	 9057	 0.342335	 1.036053	 0.0	 29	 29	 29	 1.0	 0.0	 1	 -30.0	 30.0;
	9661	 11453	 0.08144	 0.487603	 0.0	 64	 64	 64	 1.0	 0.0	 1	 -30.0	 30.0;
	10358	 80	 0.492025	 1.533306	 0.0	 20	 20	 20	 1.0	 0.0	 1	 -30.0	 30.0;
	3462	 7437	 0.00079	 0.058401	 0.0	 541	 541	 541	 1.0	 0.0	 1	 -30.0	 30.0;
	3462	 7437	 0.00077	 0.05951	 0.0	 531	 531	 531	 1.0	 0.0	 1	 -30.0	 30.0;
	2376	 5802	 0.000209	 0.016646	 0.0	 1898	 1898	 1898	 0.960405	 0.0	 1	 -30.0	 30.0;
	2376	 587	 -0.020062	 0.263393	 0.0	 120	 120	 120	 1.0	 0.0	 1	 -30.0	 30.0;
	2376	 7275	 0.02611	 0.389661	 0.0	 81	 81	 81	 1.0	 0.0	 1	 -30.0	 30.0;
	2376	 1611	 0.02953	 0.274197	 0.0	 115	 115	 115	 1.0	 0.0	 1	 -30.0	 30.0;
	2376	 587	 0.000249	 0.015313	 0.0	 2063	 2063	 2063	 0.963743	 0.0	 1	 -30.0	 30.0;
	2376	 13460	 0.000151	 0.014993	 0.0	 2107	 2107	 2107	 1.037521	 0.0	 1	 -30.0	 30.0;
	6804	 2393	 0.01135	 0.389938	 0.0	 81	 81	 81	 1.0	 0.0	 1	 -30.0	 30.0;
	6804	 5190	 0.03467	 0.4241	 0.0	 75	 75	 75	 1.0	 0.0	 1	 -30.0	 30.0;
	10358	 2314	 0.000159	 0.018964	 0.0	 1666	 1666	 1666	 0.954163	 0.0	 1	 -30.0	 30.0;
	10358	 2314	 -0.01126	 0.214855	 0.0	 147	 147	 147	 1.0	 0.0	 1	 -30.0	 30.0;
	10358	 12360	 0.20036	 1.026385	 0.0	 31	 31	 31	 1.0	 0.0	 1	 -30.0	 30.0;
	10358	 13555	 0.117071	 0.511302	 0.0	 61	 61	 61	 1.0	 0.0	 1	 -30.0	 30.0;
	5633	 3742	 0.093303	 0.945014	 0.0	 34	 34	 34	 1.0	 0.0	 1	 -30.0	 30.0;
	1025	 3742	 0.01297	 0.327971	 0.0	 97	 97	 97	 1.0	 0.0	 1	 -30.0	 30.0;
	3417	 3742	 0.05929	 0.601787	 0.0	 53	 53	 53	 1.0	 0.0	 1	 -30.0	 30.0;
	9661	 6301	 0.05013	 0.919979	 0.0	 35	 35	 35	 1.0	 0.0	 1	 -30.0	 30.0;
	9661	 3085	 0.0477	 0.865888	 0.0	 37	 37	 37	 1.0	 0.0	 1	 -30.0	 30.0;
	2354	 3879	 0.749308	 2.45464	 0.0	 13	 13	 13	 1.0	 0.0	 1	 -30.0	 30.0;
	2354	 8543	 2.902839	 5.007549	 0.0	 6	 6	 6	 1.0	 0.0	 1	 -30.0	 30.0;
	4172	 2393	 0.03282	 0.444566	 0.0	 71	 71	 71	 1.0	 0.0	 1	 -30.0	 30.0;
	11636	 3742	 0.186479	 0.852913	 0.0	 37	 37	 37	 1.0	 0.0	 1	 -30.0	 30.0;
	2948	 3742	 0.185979	 0.818905	 0.0	 38	 38	 38	 1.0	 0.0	 1	 -30.0	 30.0;
	10879	 3742	 1.207107	 3.026033	 0.0	 10	 10	 10	 1.0	 0.0	 1	 -30.0	 30.0;
	9048	 3742	 0.414669	 1.672355	 0.0	 19	 19	 19	 1.0	 0.0	 1	 -30.0	 30.0;
	7451	 3879	 0.129612	 0.934834	 0.0	 34	 34	 34	 1.0	 0.0	 1	 -30.0	 30.0;
	7451	 8543	 0.796053	 2.21392	 0.0	 14	 14	 14	 1.0	 0.0	 1	 -30.0	 30.0;
	2265	 3879	 0.136461	 1.06849	 0.0	 30	 30	 30	 1.0	 0.0	 1	 -30.0	 30.0;
	2265	 8543	 0.838366	 2.528809	 0.0	 12	 12	 12	 1.0	 0.0	 1	 -30.0	 30.0;
	1620	 11840	 0.000206	 0.015885	 0.0	 1989	 1989	 1989	 1.065581	 0.0	 1	 -30.0	 30.0;
	11151	 1910	 0.000298	 0.029295	 0.0	 1079	 1079	 1079	 1.085859	 -0.169703	 1	 -30.0	 30.0;
	6796	 8189	 0.01604	 0.374051	 0.0	 85	 85	 85	 1.0	 0.0	 1	 -30.0	 30.0;
	3026	 8189	 0.01635	 0.36626	 0.0	 87	 87	 87	 1.0	 0.0	 1	 -30.0	 30.0;
	4172	 8189	 0.024141	 0.327376	 0.0	 97	 97	 97	 1.0	 0.0	 1	 -30.0	 30.0;
	9156	 8189	 0.02194	 0.458409	 0.0	 69	 69	 69	 1.0	 0.0	 1	 -30.0	 30.0;
	2843	 13196	 0.00046	 0.03512	 0.0	 900	 900	 900	 0.998397	 0.0	 1	 -30.0	 30.0;
	2843	 2600	 0.000328	 0.017373	 0.0	 1818	 1818	 1818	 1.008118	 0.0	 1	 -30.0	 30.0;
	4172	 5190	 0.00056	 0.05575	 0.0	 567	 567	 567	 1.0	 0.0	 1	 -30.0	 30.0;
	9661	 3817	 0.09537	 0.774091	 0.0	 41	 41	 41	 1.0	 0.0	 1	 -30.0	 30.0;
	9661	 7035	 0.325393	 1.201922	 0.0	 26	 26	 26	 1.0	 0.0	 1	 -30.0	 30.0;
	9661	 11123	 0.367459	 1.167149	 0.0	 26	 26	 26	 1.0	 0.0	 1	 -30.0	 30.0;
	9156	 584	 0.0008	 0.04856	 0.0	 651	 651	 651	 1.0	 0.0	 1	 -30.0	 30.0;
	1894	 234	 0.000151	 0.010302	 0.0	 3066	 3066	 3066	 1.042652	 0.0	 1	 -30.0	 30.0;
	1894	 2319	 0.00033	 0.038031	 0.0	 831	 831	 831	 1.005085	 0.0	 1	 -30.0	 30.0;
	1894	 2319	 0.00034	 0.037211	 0.0	 849	 849	 849	 1.005257	 0.0	 1	 -30.0	 30.0;
	12109	 3879	 -0.016405	 0.249504	 0.0	 127	 127	 127	 1.0	 0.0	 1	 -30.0	 30.0;
	12109	 8543	 0.087209	 0.621302	 0.0	 51	 51	 51	 1.0	 0.0	 1	 -30.0	 30.0;
	12918	 7095	 0.15538	 0.761901	 0.0	 41	 41	 41	 1.0	 0.0	 1	 -30.0	 30.0;
	5993	 7095	 0.15969	 0.749463	 0.0	 42	 42	 42	 1.0	 0.0	 1	 -30.0	 30.0;
	10087	 7095	 1.428926	 3.608884	 0.0	 9	 9	 9	 1.0	 0.0	 1	 -30.0	 30.0;
	8361	 7095	 0.861797	 2.342768	 0.0	 13	 13	 13	 1.0	 0.0	 1	 -30.0	 30.0;
	9091	 4168	 0.119958	 0.657978	 0.0	 48	 48	 48	 1.0	 0.0	 1	 -30.0	 30.0;
	5557	 9394	 0.172789	 1.348017	 0.0	 24	 24	 24	 1.0	 0.0	 1	 -30.0	 30.0;
	3447	 9394	 0.00088	 0.381756	 0.0	 83	 83	 83	 1.0	 0.0	 1	 -30.0	 30.0;
	3260	 9394	 0.0061	 0.418244	 0.0	 76	 76	 76	 1.0	 0.0	 1	 -30.0	 30.0;
	6117	 10372	 0.05995	 0.76688	 0.0	 42	 42	 42	 1.0	 0.0	 1	 -30.0	 30.0;
	8691	 10372	 0.0653	 0.750992	 0.0	 42	 42	 42	 1.0	 0.0	 1	 -30.0	 30.0;
	2728	 10372	 -0.003347	 0.292562	 0.0	 108	 108	 108	 1.0	 0.0	 1	 -30.0	 30.0;
	4506	 11358	 1.83593	 3.666115	 0.0	 8	 8	 8	 1.0	 0.0	 1	 -30.0	 30.0;
	13547	 11358	 0.052409	 0.497211	 0.0	 64	 64	 64	 1.0	 0.0	 1	 -30.0	 30.0;
	1649	 3636	 0.436797	 1.36533	 0.0	 23	 23	 23	 1.0	 0.0	 1	 -30.0	 30.0;
	10400	 3636	 0.094151	 0.896736	 0.0	 36	 36	 36	 1.0	 0.0	 1	 -30.0	 30.0;
	1983	 11136	 0.00721	 0.237881	 0.0	 133	 133	 133	 1.0	 0.0	 1	 -30.0	 30.0;
	1983	 7018	 0.140762	 0.856856	 0.0	 37	 37	 37	 1.0	 0.0	 1	 -30.0	 30.0;
	12051	 11136	 0.05419	 0.633158	 0.0	 50	 50	 50	 1.0	 0.0	 1	 -30.0	 30.0;
	12051	 7018	 0.0291	 0.36903	 0.0	 86	 86	 86	 1.0	 0.0	 1	 -30.0	 30.0;
	4556	 4168	 0.143641	 0.91531	 0.0	 35	 35	 35	 1.0	 0.0	 1	 -30.0	 30.0;
	1723	 4168	 0.025969	 0.445888	 0.0	 71	 71	 71	 1.0	 0.0	 1	 -30.0	 30.0;
	1771	 4168	 0.270372	 0.785723	 0.0	 39	 39	 39	 1.0	 0.0	 1	 -30.0	 30.0;
	7818	 4168	 0.05175	 0.49312	 0.0	 64	 64	 64	 1.0	 0.0	 1	 -30.0	 30.0;
	7012	 4168	 0.08601	 0.600496	 0.0	 53	 53	 53	 1.0	 0.0	 1	 -30.0	 30.0;
	8784	 4168	 0.531591	 1.712665	 0.0	 18	 18	 18	 1.0	 0.0	 1	 -30.0	 30.0;
	10047	 4168	 0.43593	 1.756797	 0.0	 18	 18	 18	 1.0	 0.0	 1	 -30.0	 30.0;
	7835	 6099	 0.01926	 0.358289	 0.0	 89	 89	 89	 1.0	 0.0	 1	 -30.0	 30.0;
	10846	 7216	 0.01795	 0.317397	 0.0	 100	 100	 100	 1.0	 0.0	 1	 -30.0	 30.0;
	5557	 228	 0.00761	 0.279277	 0.0	 114	 114	 114	 1.0	 0.0	 1	 -30.0	 30.0;
	3447	 228	 0.260062	 1.120476	 0.0	 28	 28	 28	 1.0	 0.0	 1	 -30.0	 30.0;
	3260	 228	 0.158651	 0.983822	 0.0	 32	 32	 32	 1.0	 0.0	 1	 -30.0	 30.0;
	5557	 6735	 0.00395	 0.366116	 0.0	 87	 87	 87	 1.0	 0.0	 1	 -30.0	 30.0;
	8870	 6735	 0.083409	 0.606219	 0.0	 52	 52	 52	 1.0	 0.0	 1	 -30.0	 30.0;
	3447	 6735	 0.195669	 1.120144	 0.0	 28	 28	 28	 1.0	 0.0	 1	 -30.0	 30.0;
	3260	 6735	 0.104969	 1.02188	 0.0	 31	 31	 31	 1.0	 0.0	 1	 -30.0	 30.0;
	4570	 6735	 0.042831	 0.74374	 0.0	 43	 43	 43	 1.0	 0.0	 1	 -30.0	 30.0;
	4506	 12086	 0.000242	 0.029698	 0.0	 1064	 1064	 1064	 0.945816	 0.090914	 1	 -30.0	 30.0;
	4506	 10015	 -0.003203	 0.14994	 0.0	 211	 211	 211	 1.0	 0.0	 1	 -30.0	 30.0;
	4506	 10015	 0.000451	 0.034969	 0.0	 904	 904	 904	 1.022789	 0.0	 1	 -30.0	 30.0;
	4506	 10225	 0.113213	 0.498338	 0.0	 62	 62	 62	 1.0	 0.0	 1	 -30.0	 30.0;
	9468	 3227	 0.00055	 0.0343	 0.0	 921	 921	 921	 0.917643	 0.0	 1	 -30.0	 30.0;
	5993	 13243	 0.000264	 0.023375	 0.0	 1352	 1352	 1352	 1.049631	 -0.088275	 1	 -30.0	 30.0;
	12918	 7494	 0.01862	 0.220201	 0.0	 143	 143	 143	 1.0	 0.0	 1	 -30.0	 30.0;
	5993	 7494	 0.0168	 0.250561	 0.0	 126	 126	 126	 1.0	 0.0	 1	 -30.0	 30.0;
	1649	 7018	 0.202902	 0.952701	 0.0	 33	 33	 33	 1.0	 0.0	 1	 -30.0	 30.0;
	1649	 13016	 0.949862	 3.139543	 0.0	 10	 10	 10	 1.0	 0.0	 1	 -30.0	 30.0;
	1649	 2365	 0.00261	 0.215422	 0.0	 147	 147	 147	 1.0	 0.0	 1	 -30.0	 30.0;
	10904	 6104	 -0.02155	 0.439897	 0.0	 72	 72	 72	 1.0	 0.0	 1	 -30.0	 30.0;
	8870	 6104	 0.07045	 1.003492	 0.0	 32	 32	 32	 1.0	 0.0	 1	 -30.0	 30.0;
	10904	 12768	 0.00807	 0.465263	 0.0	 68	 68	 68	 1.0	 0.0	 1	 -30.0	 30.0;
	10904	 9268	 0.194723	 1.065305	 0.0	 30	 30	 30	 1.0	 0.0	 1	 -30.0	 30.0;
	10904	 5095	 0.7241	 1.639128	 0.0	 18	 18	 18	 1.0	 0.0	 1	 -30.0	 30.0;
	10904	 7630	 0.514127	 1.973476	 0.0	 16	 16	 16	 1.0	 0.0	 1	 -30.0	 30.0;
	10904	 12875	 0.06643	 0.866482	 0.0	 37	 37	 37	 1.0	 0.0	 1	 -30.0	 30.0;
	10904	 5550	 0.55937	 2.088574	 0.0	 15	 15	 15	 1.0	 0.0	 1	 -30.0	 30.0;
	10904	 5687	 0.522202	 2.029502	 0.0	 16	 16	 16	 1.0	 0.0	 1	 -30.0	 30.0;
	10904	 11156	 0.30876	 1.923338	 0.0	 17	 17	 17	 1.0	 0.0	 1	 -30.0	 30.0;
	4685	 10914	 0.06357	 0.598203	 0.0	 53	 53	 53	 1.0	 0.0	 1	 -30.0	 30.0;
	12475	 10914	 0.000445	 0.035961	 0.0	 879	 879	 879	 0.918248	 0.0	 1	 -30.0	 30.0;
	9641	 10914	 0.01179	 0.332211	 0.0	 96	 96	 96	 1.0	 0.0	 1	 -30.0	 30.0;
	1149	 10914	 0.02131	 0.372955	 0.0	 85	 85	 85	 1.0	 0.0	 1	 -30.0	 30.0;
	6597	 10914	 0.00274	 0.381756	 0.0	 83	 83	 83	 1.0	 0.0	 1	 -30.0	 30.0;
	10087	 7494	 0.293141	 1.107872	 0.0	 28	 28	 28	 1.0	 0.0	 1	 -30.0	 30.0;
	8361	 7494	 0.144281	 0.82905	 0.0	 38	 38	 38	 1.0	 0.0	 1	 -30.0	 30.0;
	3566	 3503	 0.00458	 0.288905	 0.0	 110	 110	 110	 1.0	 0.0	 1	 -30.0	 30.0;
	6522	 462	 0.365888	 1.746611	 0.0	 18	 18	 18	 1.0	 0.0	 1	 -30.0	 30.0;
	3081	 462	 1.44438	 5.252272	 0.0	 6	 6	 6	 1.0	 0.0	 1	 -30.0	 30.0;
	2602	 462	 0.059581	 0.615888	 0.0	 52	 52	 52	 1.0	 0.0	 1	 -30.0	 30.0;
	5257	 462	 3.709298	 8.934297	 0.0	 4	 4	 4	 1.0	 0.0	 1	 -30.0	 30.0;
	10026	 462	 0.140919	 0.944236	 0.0	 34	 34	 34	 1.0	 0.0	 1	 -30.0	 30.0;
	2201	 239	 0.0005	 0.0343	 0.0	 921	 921	 921	 0.884937	 0.0	 1	 -30.0	 30.0;
	13547	 239	 0.01962	 0.216178	 0.0	 146	 146	 146	 1.0	 0.0	 1	 -30.0	 30.0;
	8870	 12768	 0.398678	 1.516364	 0.0	 21	 21	 21	 1.0	 0.0	 1	 -30.0	 30.0;
	8870	 1246	 0.09755	 0.839897	 0.0	 38	 38	 38	 1.0	 0.0	 1	 -30.0	 30.0;
	4570	 1246	 0.499525	 2.142562	 0.0	 15	 15	 15	 1.0	 0.0	 1	 -30.0	 30.0;
	1872	 6099	 0.01537	 0.348347	 0.0	 91	 91	 91	 1.0	 0.0	 1	 -30.0	 30.0;
	5394	 6099	 0.01946	 0.372727	 0.0	 85	 85	 85	 1.0	 0.0	 1	 -30.0	 30.0;
	9641	 9245	 0.01679	 0.350455	 0.0	 91	 91	 91	 1.0	 0.0	 1	 -30.0	 30.0;
	1149	 9245	 0.0005	 0.324174	 0.0	 98	 98	 98	 1.0	 0.0	 1	 -30.0	 30.0;
	6597	 9245	 0.049469	 0.557004	 0.0	 57	 57	 57	 1.0	 0.0	 1	 -30.0	 30.0;
	1723	 8592	 0.0005	 0.031271	 0.0	 1010	 1010	 1010	 1.0	 0.0	 1	 -30.0	 30.0;
	6522	 8592	 0.422748	 2.328099	 0.0	 14	 14	 14	 1.0	 0.0	 1	 -30.0	 30.0;
	3081	 8592	 1.022934	 4.279959	 0.0	 8	 8	 8	 1.0	 0.0	 1	 -30.0	 30.0;
	2602	 8592	 0.256612	 1.738141	 0.0	 18	 18	 18	 1.0	 0.0	 1	 -30.0	 30.0;
	5257	 8592	 2.300207	 9.353099	 0.0	 4	 4	 4	 1.0	 0.0	 1	 -30.0	 30.0;
	10026	 8592	 0.0157	 0.997789	 0.0	 32	 32	 32	 1.0	 0.0	 1	 -30.0	 30.0;
	8870	 10093	 0.022021	 0.625496	 0.0	 51	 51	 51	 1.0	 0.0	 1	 -30.0	 30.0;
	4570	 10093	 0.223988	 1.463946	 0.0	 22	 22	 22	 1.0	 0.0	 1	 -30.0	 30.0;
	6522	 8936	 -0.037934	 0.385868	 0.0	 82	 82	 82	 1.0	 0.0	 1	 -30.0	 30.0;
	3081	 8936	 2.334711	 7.437397	 0.0	 5	 5	 5	 1.0	 0.0	 1	 -30.0	 30.0;
	2602	 8936	 0.137849	 1.103905	 0.0	 29	 29	 29	 1.0	 0.0	 1	 -30.0	 30.0;
	5257	 8936	 5.726446	 13.392563	 0.0	 3	 3	 3	 1.0	 0.0	 1	 -30.0	 30.0;
	10026	 8936	 0.183531	 1.402418	 0.0	 23	 23	 23	 1.0	 0.0	 1	 -30.0	 30.0;
	12854	 6522	 3.1e-05	 0.002643	 0.0	 11951	 11951	 11951	 0.993885	 -0.110645	 1	 -30.0	 30.0;
	6522	 7527	 2.374861	 8.881579	 0.0	 4	 4	 4	 1.0	 0.0	 1	 -30.0	 30.0;
	6522	 11961	 0.158643	 1.604501	 0.0	 20	 20	 20	 1.0	 0.0	 1	 -30.0	 30.0;
	6522	 3731	 0.204162	 1.92777	 0.0	 17	 17	 17	 1.0	 0.0	 1	 -30.0	 30.0;
	6522	 12457	 0.169439	 2.010873	 0.0	 16	 16	 16	 1.0	 0.0	 1	 -30.0	 30.0;
	3081	 7527	 -0.011343	 0.25657	 0.0	 123	 123	 123	 1.0	 0.0	 1	 -30.0	 30.0;
	3081	 7527	 0.000423	 0.033381	 0.0	 947	 947	 947	 0.876622	 0.0	 1	 -30.0	 30.0;
	2602	 7527	 6.533884	 12.310123	 0.0	 3	 3	 3	 1.0	 0.0	 1	 -30.0	 30.0;
	5257	 7527	 0.04751	 0.576054	 0.0	 55	 55	 55	 1.0	 0.0	 1	 -30.0	 30.0;
	10026	 7527	 0.21343	 1.602582	 0.0	 20	 20	 20	 1.0	 0.0	 1	 -30.0	 30.0;
	3081	 11961	 7.076177	 15.615651	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	3081	 3731	 6.591413	 15.880881	 0.0	 2	 2	 2	 1.0	 0.0	 1	 -30.0	 30.0;
	3081	 12457	 0.187507	 2.209903	 0.0	 15	 15	 15	 1.0	 0.0	 1	 -30.0	 30.0;
	1179	 9396	 0.0004	 0.149419	 0.0	 212	 212	 212	 1.0	 0.0	 1	 -30.0	 30.0;
	8361	 9396	 0.027469	 0.320806	 0.0	 99	 99	 99	 1.0	 0.0	 1	 -30.0	 30.0;
	10846	 9396	 0.00659	 0.53155	 0.0	 60	 60	 60	 1.0	 0.0	 1	 -30.0	 30.0;
	6598	 8996	 0.45281	 1.969855	 0.0	 16	 16	 16	 1.0	 0.0	 1	 -30.0	 30.0;
	13441	 8996	 0.561302	 2.344628	 0.0	 14	 14	 14	 1.0	 0.0	 1	 -30.0	 30.0;
	12362	 8996	 0.03438	 0.839277	 0.0	 38	 38	 38	 1.0	 0.0	 1	 -30.0	 30.0;
	1820	 3742	 -0.00126	 0.238202	 0.0	 133	 133	 133	 1.0	 0.0	 1	 -30.0	 30.0;
	1820	 3742	 0.000426	 0.017209	 0.0	 1835	 1835	 1835	 1.002506	 0.0	 1	 -30.0	 30.0;
	1820	 185	 0.01628	 0.291863	 0.0	 109	 109	 109	 1.0	 0.0	 1	 -30.0	 30.0;
	10196	 12543	 -0.010145	 0.227045	 0.0	 139	 139	 139	 1.0	 0.0	 1	 -30.0	 30.0;
	6598	 4735	 0.00079	 0.680124	 0.0	 47	 47	 47	 1.0	 0.0	 1	 -30.0	 30.0;
	13441	 4735	 -6.2e-05	 0.76438	 0.0	 42	 42	 42	 1.0	 0.0	 1	 -30.0	 30.0;
	12362	 4735	 0.288988	 1.328967	 0.0	 24	 24	 24	 1.0	 0.0	 1	 -30.0	 30.0;
	6598	 444	 0.289174	 0.947893	 0.0	 32	 32	 32	 1.0	 0.0	 1	 -30.0	 30.0;
	13441	 444	 0.357831	 1.127893	 0.0	 27	 27	 27	 1.0	 0.0	 1	 -30.0	 30.0;
	12362	 444	 0.00434	 0.222459	 0.0	 142	 142	 142	 1.0	 0.0	 1	 -30.0	 30.0;
	12850	 11860	 0.162281	 0.824401	 0.0	 38	 38	 38	 1.0	 0.0	 1	 -30.0	 30.0;
	2525	 11860	 0.510455	 1.73717	 0.0	 18	 18	 18	 1.0	 0.0	 1	 -30.0	 30.0;
	909	 11860	 0.218822	 1.471838	 0.0	 22	 22	 22	 1.0	 0.0	 1	 -30.0	 30.0;
	2114	 11860	 0.029581	 0.641756	 0.0	 50	 50	 50	 1.0	 0.0	 1	 -30.0	 30.0;
	6916	 11860	 0.269194	 1.398492	 0.0	 23	 23	 23	 1.0	 0.0	 1	 -30.0	 30.0;
	1149	 10055	 0.01824	 0.407147	 0.0	 78	 78	 78	 1.0	 0.0	 1	 -30.0	 30.0;
	1149	 10493	 0.01992	 0.388733	 0.0	 82	 82	 82	 1.0	 0.0	 1	 -30.0	 30.0;
	10196	 2779	 0.504669	 1.26314	 0.0	 24	 24	 24	 1.0	 0.0	 1	 -30.0	 30.0;
	854	 8044	 0.180042	 0.913089	 0.0	 34	 34	 34	 1.0	 0.0	 1	 -30.0	 30.0;
	854	 3171	 0.28705	 1.359279	 0.0	 23	 23	 23	 1.0	 0.0	 1	 -30.0	 30.0;
	13539	 6637	 0.02939	 0.690041	 0.0	 46	 46	 46	 1.0	 0.0	 1	 -30.0	 30.0;
	11674	 6637	 0.106211	 0.857975	 0.0	 37	 37	 37	 1.0	 0.0	 1	 -30.0	 30.0;
	13539	 2431	 0.03057	 0.640372	 0.0	 50	 50	 50	 1.0	 0.0	 1	 -30.0	 30.0;
	11674	 2431	 0.11774	 0.83438	 0.0	 38	 38	 38	 1.0	 0.0	 1	 -30.0	 30.0;
	2602	 3731	 0.000416	 0.031501	 0.0	 1003	 1003	 1003	 0.909421	 0.0	 1	 -30.0	 30.0;
	2602	 11961	 -0.02392	 0.308892	 0.0	 102	 102	 102	 1.0	 0.0	 1	 -30.0	 30.0;
	2602	 3731	 -0.021129	 0.40847	 0.0	 78	 78	 78	 1.0	 0.0	 1	 -30.0	 30.0;
	2602	 12457	 0.801524	 3.248477	 0.0	 10	 10	 10	 1.0	 0.0	 1	 -30.0	 30.0;
	5257	 11961	 15.18223	 29.541321	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	10026	 11961	 0.810744	 3.364049	 0.0	 10	 10	 10	 1.0	 0.0	 1	 -30.0	 30.0;
	5257	 3731	 13.91921	 30.6467	 0.0	 1	 1	 1	 1.0	 0.0	 1	 -30.0	 30.0;
	10026	 3731	 0.716322	 3.154132	 0.0	 10	 10	 10	 1.0	 0.0	 1	 -30.0	 30.0;
	10846	 793	 0.00489	 0.406095	 0.0	 78	 78	 78	 1.0	 0.0	 1	 -30.0	 30.0;
	12850	 8677	 0.447909	 1.098823	 0.0	 27	 27	 27	 1.0	 0.0	 1	 -30.0	 30.0;
	12850	 9658	 0.01056	 0.353927	 0.0	 90	 90	 90	 1.0	 0.0	 1	 -30.0	 30.0;
	12850	 1626	 0.7509	 1.841551	 0.0	 16	 16	 16	 1.0	 0.0	 1	 -30.0	 30.0;
	2525	 8677	 0.375789	 0.752493	 0.0	 38	 38	 38	 1.0	 0.0	 1	 -30.0	 30.0;
	2525	 9658	 0.190388	 1.261149	 0.0	 25	 25	 25	 1.0	 0.0	 1	 -30.0	 30.0;
	2525	 1626	 0.05324	 0.584501	 0.0	 54	 54	 54	 1.0	 0.0	 1	 -30.0	 30.0;
	5784	 8044	 0.01773	 0.615173	 0.0	 52	 52	 52	 1.0	 0.0	 1	 -30.0	 30.0;
	5784	 10203	 0.01987	 0.600173	 0.0	 53	 53	 53	 1.0	 0.0	 1	 -30.0	 30.0;
	3229	 8044	 0.466918	 1.296815	 0.0	 23	 23	 23	 1.0	 0.0	 1	 -30.0	 30.0;
	3229	 3171	 0.815443	 1.930956	 0.0	 16	 16	 16	 1.0	 0.0	 1	 -30.0	 30.0;
	6598	 6259	 0.02061	 0.308595	 0.0	 103	 103	 103	 1.0	 0.0	 1	 -30.0	 30.0;
	13441	 6259	 0.02549	 0.367231	 0.0	 86	 86	 86	 1.0	 0.0	 1	 -30.0	 30.0;
	12362	 6259	 0.00824	 0.278492	 0.0	 114	 114	 114	 1.0	 0.0	 1	 -30.0	 30.0;
	5257	 12457	 0.71662	 3.572645	 0.0	 9	 9	 9	 1.0	 0.0	 1	 -30.0	 30.0;
	4685	 4749	 0.045599	 0.50595	 0.0	 63	 63	 63	 1.0	 0.0	 1	 -30.0	 30.0;
	13539	 996	 0.00887	 0.706717	 0.0	 45	 45	 45	 1.0	 0.0	 1	 -30.0	 30.0;
	13539	 10794	 0.04089	 0.90831	 0.0	 35	 35	 35	 1.0	 0.0	 1	 -30.0	 30.0;
	13539	 6683	 0.04322	 0.911288	 0.0	 35	 35	 35	 1.0	 0.0	 1	 -30.0	 30.0;
	490	 8044	 0.032849	 0.6625	 0.0	 48	 48	 48	 1.0	 0.0	 1	 -30.0	 30.0;
	680	 8044	 0.03726	 0.637562	 0.0	 50	 50	 50	 1.0	 0.0	 1	 -30.0	 30.0;
	148	 8044	 0.074341	 0.632975	 0.0	 50	 50	 50	 1.0	 0.0	 1	 -30.0	 30.0;
	9278	 8044	 0.07781	 0.62157	 0.0	 51	 51	 51	 1.0	 0.0	 1	 -30.0	 30.0;
	909	 8677	 0.534411	 1.302908	 0.0	 23	 23	 23	 1.0	 0.0	 1	 -30.0	 30.0;
	909	 9658	 0.02355	 0.61356	 0.0	 52	 52	 52	 1.0	 0.0	 1	 -30.0	 30.0;
	909	 1626	 0.420249	 1.970499	 0.0	 16	 16	 16	 1.0	 0.0	 1	 -30.0	 30.0;
	2114	 8677	 0.229855	 0.963099	 0.0	 32	 32	 32	 1.0	 0.0	 1	 -30.0	 30.0;
	6916	 8677	 0.074669	 0.41343	 0.0	 76	 76	 76	 1.0	 0.0	 1	 -30.0	 30.0;
	10196	 6981	 0.06182	 0.403213	 0.0	 78	 78	 78	 1.0	 0.0	 1	 -30.0	 30.0;
	10026	 12457	 -0.029256	 0.40562	 0.0	 78	 78	 78	 1.0	 0.0	 1	 -30.0	 30.0;
	8870	 9268	 0.0033	 0.455227	 0.0	 70	 70	 70	 1.0	 0.0	 1	 -30.0	 30.0;
	4685	 9268	 0.00124	 0.284731	 0.0	 111	 111	 111	 1.0	 0.0	 1	 -30.0	 30.0;
	118	 10055	 0.04584	 0.400152	 0.0	 79	 79	 79	 1.0	 0.0	 1	 -30.0	 30.0;
	118	 10493	 0.03961	 0.441877	 0.0	 72	 72	 72	 1.0	 0.0	 1	 -30.0	 30.0;
	8870	 3748	 0.282149	 1.82343	 0.0	 18	 18	 18	 1.0	 0.0	 1	 -30.0	 30.0;
	4570	 3748	 -0.001467	 0.288285	 0.0	 110	 110	 110	 1.0	 0.0	 1	 -30.0	 30.0;
	9487	 5095	 0.000203	 0.026879	 0.0	 1176	 1176	 1176	 1.049631	 -0.088275	 1	 -30.0	 30.0;
	8870	 5095	 3.246901	 6.102273	 0.0	 5	 5	 5	 1.0	 0.0	 1	 -30.0	 30.0;
	7990	 8260	 0.000187	 0.028583	 0.0	 1106	 1106	 1106	 1.062286	 0.114968	 1	 -30.0	 30.0;
	7990	 8260	 0.000198	 0.028	 0.0	 1129	 1129	 1129	 1.062286	 0.114968	 1	 -30.0	 30.0;
	8616	 8260	 0.046659	 0.29938	 0.0	 105	 105	 105	 1.0	 0.0	 1	 -30.0	 30.0;
	6117	 12560	 0.02508	 0.489778	 0.0	 65	 65	 65	 1.0	 0.0	 1	 -30.0	 30.0;
	6117	 11208	 0.0359	 0.39268	 0.0	 81	 81	 81	 1.0	 0.0	 1	 -30.0	 30.0;
	8691	 12560	 0.01931	 0.550478	 0.0	 58	 58	 58	 1.0	 0.0	 1	 -30.0	 30.0;
	8691	 11208	 0.0365	 0.48437	 0.0	 66	 66	 66	 1.0	 0.0	 1	 -30.0	 30.0;
	2114	 9658	 -0.015393	 0.242665	 0.0	 130	 130	 130	 1.0	 0.0	 1	 -30.0	 30.0;
	2114	 9658	 0.00024	 0.016571	 0.0	 1906	 1906	 1906	 0.99092	 0.0	 1	 -30.0	 30.0;
	6916	 9658	 0.778884	 2.360744	 0.0	 13	 13	 13	 1.0	 0.0	 1	 -30.0	 30.0;
	2114	 1626	 0.834349	 2.163366	 0.0	 14	 14	 14	 1.0	 0.0	 1	 -30.0	 30.0;
	2728	 12560	 0.02768	 0.486653	 0.0	 65	 65	 65	 1.0	 0.0	 1	 -30.0	 30.0;
	2728	 12560	 0.0005	 0.0343	 0.0	 921	 921	 921	 0.925399	 0.0	 1	 -30.0	 30.0;
	2728	 11208	 0.170748	 0.871399	 0.0	 36	 36	 36	 1.0	 0.0	 1	 -30.0	 30.0;
	8870	 7630	 3.440496	 6.966735	 0.0	 5	 5	 5	 1.0	 0.0	 1	 -30.0	 30.0;
	8870	 12875	 -0.025	 0.350744	 0.0	 90	 90	 90	 1.0	 0.0	 1	 -30.0	 30.0;
	8870	 5550	 3.294252	 7.269391	 0.0	 4	 4	 4	 1.0	 0.0	 1	 -30.0	 30.0;
	8870	 5687	 3.075277	 7.063712	 0.0	 5	 5	 5	 1.0	 0.0	 1	 -30.0	 30.0;
	8870	 11156	 2.188573	 6.820568	 0.0	 5	 5	 5	 1.0	 0.0	 1	 -30.0	 30.0;
	8616	 3171	 0.03254	 0.295443	 0.0	 107	 107	 107	 1.0	 0.0	 1	 -30.0	 30.0;
	4570	 4305	 0.000216	 0.016549	 0.0	 1909	 1909	 1909	 0.953239	 0.0	 1	 -30.0	 30.0;
	10400	 7018	 0.00914	 0.394959	 0.0	 80	 80	 80	 1.0	 0.0	 1	 -30.0	 30.0;
	11674	 996	 0.11943	 0.839463	 0.0	 38	 38	 38	 1.0	 0.0	 1	 -30.0	 30.0;
	10846	 996	 0.02832	 0.560682	 0.0	 57	 57	 57	 1.0	 0.0	 1	 -30.0	 30.0;
	10846	 5661	 0.025289	 0.560351	 0.0	 57	 57	 57	 1.0	 0.0	 1	 -30.0	 30.0;
	10400	 13016	 0.203901	 1.623181	 0.0	 20	 20	 20	 1.0	 0.0	 1	 -30.0	 30.0;
	9013	 4956	 0.000184	 0.025546	 0.0	 1237	 1237	 1237	 1.049631	 -0.088275	 1	 -30.0	 30.0;
	6597	 10055	 0.0086	 0.46804	 0.0	 68	 68	 68	 1.0	 0.0	 1	 -30.0	 30.0;
	6597	 10493	 0.00772	 0.464148	 0.0	 69	 69	 69	 1.0	 0.0	 1	 -30.0	 30.0;
	13547	 12769	 0.08261	 0.429463	 0.0	 73	 73	 73	 1.0	 0.0	 1	 -30.0	 30.0;
	13547	 8118	 0.09332	 0.419277	 0.0	 74	 74	 74	 1.0	 0.0	 1	 -30.0	 30.0;
	490	 10203	 0.06593	 0.705471	 0.0	 45	 45	 45	 1.0	 0.0	 1	 -30.0	 30.0;
	680	 10203	 0.070298	 0.687417	 0.0	 46	 46	 46	 1.0	 0.0	 1	 -30.0	 30.0;
	13171	 7609	 0.000348	 0.027366	 0.0	 1155	 1155	 1155	 1.085859	 0.169702	 1	 -30.0	 30.0;
	13547	 7766	 0.000239	 0.02019	 0.0	 1565	 1565	 1565	 1.043143	 0.07517	 1	 -30.0	 30.0;
	11674	 10794	 0.0275	 0.64187	 0.0	 50	 50	 50	 1.0	 0.0	 1	 -30.0	 30.0;
	11674	 6683	 0.02423	 0.621711	 0.0	 51	 51	 51	 1.0	 0.0	 1	 -30.0	 30.0;
	10400	 2365	 0.021711	 0.411839	 0.0	 77	 77	 77	 1.0	 0.0	 1	 -30.0	 30.0;
	10400	 2365	 0.000216	 0.018022	 0.0	 1753	 1753	 1753	 1.004737	 0.0	 1	 -30.0	 30.0;
	10400	 9625	 0.000173	 0.017112	 0.0	 1846	 1846	 1846	 1.006033	 0.0	 1	 -30.0	 30.0;
	11436	 11156	 0.000179	 0.024707	 0.0	 1279	 1279	 1279	 1.049631	 -0.088275	 1	 -30.0	 30.0;
	11436	 11156	 0.000209	 0.023899	 0.0	 1322	 1322	 1322	 1.049631	 -0.088275	 1	 -30.0	 30.0;
	6916	 1626	 -0.024793	 0.19232	 0.0	 163	 163	 163	 1.0	 0.0	 1	 -30.0	 30.0;
	6598	 2128	 0.000274	 0.023047	 0.0	 1371	 1371	 1371	 1.049631	 -0.088275	 1	 -30.0	 30.0;
	12362	 2536	 0.000476	 0.030991	 0.0	 1020	 1020	 1020	 0.924062	 0.0	 1	 -30.0	 30.0;
	148	 3171	 0.11386	 1.025723	 0.0	 31	 31	 31	 1.0	 0.0	 1	 -30.0	 30.0;
	9278	 3171	 0.111979	 1.046363	 0.0	 31	 31	 31	 1.0	 0.0	 1	 -30.0	 30.0;
	9278	 568	 0.00022	 0.026909	 0.0	 1174	 1174	 1174	 1.049631	 -0.088275	 1	 -30.0	 30.0;
	12987	 12396	 0.383283	 2.185803	 0.0	 18	 18	 18	 1.0	 0.0	 1	 -30.0	 30.0;
	12987	 9924	 0.497389	 1.835595	 0.0	 20	 20	 20	 1.0	 0.0	 1	 -30.0	 30.0;
	6850	 10235	 0.000615	 0.029917	 0.0	 1056	 1056	 1056	 0.946179	 0.0	 1	 -30.0	 30.0;
	6850	 10235	 0.000634	 0.029307	 0.0	 1078	 1078	 1078	 1.168511	 0.0	 1	 -30.0	 30.0;
	2716	 13230	 -0.02062	 0.218203	 0.0	 172	 172	 172	 1.0	 0.0	 1	 -30.0	 30.0;
	2716	 4092	 0.20759	 1.109002	 0.0	 34	 34	 34	 1.0	 0.0	 1	 -30.0	 30.0;
	2716	 645	 0.275429	 1.015166	 0.0	 36	 36	 36	 1.0	 0.0	 1	 -30.0	 30.0;
	2716	 712	 1.042036	 2.256095	 0.0	 16	 16	 16	 1.0	 0.0	 1	 -30.0	 30.0;
	748	 13230	 0.10976	 0.74593	 0.0	 50	 50	 50	 1.0	 0.0	 1	 -30.0	 30.0;
	2684	 13230	 0.287831	 1.163678	 0.0	 32	 32	 32	 1.0	 0.0	 1	 -30.0	 30.0;
	795	 12063	 0.07	 0.46124	 0.0	 68	 68	 68	 1.0	 0.0	 1	 -30.0	 30.0;
	10162	 12063	 0.068479	 0.427066	 0.0	 74	 74	 74	 1.0	 0.0	 1	 -30.0	 30.0;
	7574	 9680	 0.103857	 0.477763	 0.0	 78	 78	 78	 1.0	 0.0	 1	 -30.0	 30.0;
	7574	 6056	 1.274515	 2.49626	 0.0	 14	 14	 14	 1.0	 0.0	 1	 -30.0	 30.0;
	9460	 9680	 0.107943	 0.458262	 0.0	 81	 81	 81	 1.0	 0.0	 1	 -30.0	 30.0;
	9460	 6056	 1.323546	 2.392243	 0.0	 14	 14	 14	 1.0	 0.0	 1	 -30.0	 30.0;
	12151	 12396	 0.209487	 1.002909	 0.0	 38	 38	 38	 1.0	 0.0	 1	 -30.0	 30.0;
	12151	 9924	 0.126607	 0.574751	 0.0	 65	 65	 65	 1.0	 0.0	 1	 -30.0	 30.0;
	3115	 2049	 0.00044	 0.03688	 0.0	 1029	 1029	 1029	 1.02179	 0.0	 1	 -30.0	 30.0;
	3115	 11366	 0.01559	 0.151898	 0.0	 249	 249	 249	 1.0	 0.0	 1	 -30.0	 30.0;
	6458	 3921	 0.20449	 0.679959	 0.0	 54	 54	 54	 1.0	 0.0	 1	 -30.0	 30.0;
	9450	 4092	 0.105249	 0.487299	 0.0	 76	 76	 76	 1.0	 0.0	 1	 -30.0	 30.0;
	748	 4092	 0.000246	 0.024009	 0.0	 1566	 1566	 1566	 0.999313	 -0.092965	 1	 -30.0	 30.0;
	748	 4092	 -0.01905	 0.247025	 0.0	 152	 152	 152	 1.0	 0.0	 1	 -30.0	 30.0;
	748	 645	 1.418837	 2.394528	 0.0	 14	 14	 14	 1.0	 0.0	 1	 -30.0	 30.0;
	748	 712	 0.205332	 0.854986	 0.0	 44	 44	 44	 1.0	 0.0	 1	 -30.0	 30.0;
	6457	 4092	 1.852727	 2.747521	 0.0	 12	 12	 12	 1.0	 0.0	 1	 -30.0	 30.0;
	2684	 4092	 1.359979	 2.972315	 0.0	 12	 12	 12	 1.0	 0.0	 1	 -30.0	 30.0;
	2684	 645	 0.02269	 0.199771	 0.0	 187	 187	 187	 1.0	 0.0	 1	 -30.0	 30.0;
	6458	 5521	 0.00688	 0.14088	 0.0	 269	 269	 269	 1.0	 0.0	 1	 -30.0	 30.0;
	11659	 9680	 0.00021	 0.022916	 0.0	 1379	 1379	 1379	 0.976337	 -0.045364	 1	 -30.0	 30.0;
	11659	 9680	 0.00021	 0.02236	 0.0	 1413	 1413	 1413	 0.982187	 -0.057056	 1	 -30.0	 30.0;
	6973	 277	 0.021781	 0.193349	 0.0	 163	 163	 163	 1.0	 0.0	 1	 -30.0	 30.0;
	2684	 712	 0.037729	 0.222665	 0.0	 168	 168	 168	 1.0	 0.0	 1	 -30.0	 30.0;
	8715	 11366	 0.05599	 0.311752	 0.0	 120	 120	 120	 1.0	 0.0	 1	 -30.0	 30.0;
	6933	 8132	 0.000687	 0.037873	 0.0	 834	 834	 834	 1.030749	 0.0	 1	 -30.0	 30.0;
	4218	 8132	 0.000697	 0.03705	 0.0	 853	 853	 853	 1.0213	 0.0	 1	 -30.0	 30.0;
	6973	 11046	 0.000258	 0.015179	 0.0	 2081	 2081	 2081	 1.043597	 0.0	 1	 -30.0	 30.0;
	6973	 11046	 -0.008698	 0.24938	 0.0	 127	 127	 127	 1.0	 0.0	 1	 -30.0	 30.0;
	6973	 11046	 0.000218	 0.015068	 0.0	 2097	 2097	 2097	 1.043697	 0.0	 1	 -30.0	 30.0;
	795	 11046	 0.055651	 0.515413	 0.0	 61	 61	 61	 1.0	 0.0	 1	 -30.0	 30.0;
	10162	 11046	 0.05444	 0.477231	 0.0	 66	 66	 66	 1.0	 0.0	 1	 -30.0	 30.0;
	6458	 4615	 0.153248	 0.626697	 0.0	 59	 59	 59	 1.0	 0.0	 1	 -30.0	 30.0;
	5273	 313	 -0.003823	 0.150277	 0.0	 251	 251	 251	 1.0	 0.0	 1	 -30.0	 30.0;
	5273	 313	 0.00069	 0.03981	 0.0	 945	 945	 945	 1.129864	 0.0	 1	 -30.0	 30.0;
	284	 313	 0.056219	 0.23343	 0.0	 157	 157	 157	 1.0	 0.0	 1	 -30.0	 30.0;
	3291	 12396	 0.000243	 0.01637	 0.0	 2318	 2318	 2318	 0.933986	 -0.032541	 1	 -30.0	 30.0;
	3291	 12396	 -0.011591	 0.366818	 0.0	 104	 104	 104	 1.0	 0.0	 1	 -30.0	 30.0;
	3291	 9924	 0.145519	 0.713643	 0.0	 53	 53	 53	 1.0	 0.0	 1	 -30.0	 30.0;
	739	 12396	 0.000231	 0.015741	 0.0	 2410	 2410	 2410	 0.933986	 -0.032541	 1	 -30.0	 30.0;
	739	 12396	 -0.010888	 0.388409	 0.0	 98	 98	 98	 1.0	 0.0	 1	 -30.0	 30.0;
	739	 9924	 0.157909	 0.659799	 0.0	 56	 56	 56	 1.0	 0.0	 1	 -30.0	 30.0;
	2509	 10997	 0.00297	 0.141711	 0.0	 223	 223	 223	 1.0	 0.0	 1	 -30.0	 30.0;
	6595	 4615	 0.000245	 0.011573	 0.0	 3278	 3278	 3278	 1.063511	 0.0	 1	 -30.0	 30.0;
	6595	 4615	 0.000255	 0.011329	 0.0	 3348	 3348	 3348	 1.066278	 0.0	 1	 -30.0	 30.0;
	284	 1224	 0.000697	 0.027473	 0.0	 1381	 1381	 1381	 1.140456	 0.0	 1	 -30.0	 30.0;
	284	 1224	 0.000627	 0.031139	 0.0	 1219	 1219	 1219	 1.050543	 0.0	 1	 -30.0	 30.0;
	11275	 6442	 0.00203	 0.101959	 0.0	 310	 310	 310	 0.935144	 0.0	 1	 -30.0	 30.0;
	11275	 6442	 0.00195	 0.103917	 0.0	 304	 304	 304	 0.934857	 0.0	 1	 -30.0	 30.0;
	11518	 12899	 0.00341	 0.14428	 0.0	 219	 219	 219	 1.007584	 -0.012893	 1	 -30.0	 30.0;
	9006	 3632	 0.001812	 0.129205	 0.0	 245	 245	 245	 1.091659	 -0.183486	 1	 -30.0	 30.0;
	9006	 3632	 0.001982	 0.126629	 0.0	 250	 250	 250	 1.091659	 -0.183486	 1	 -30.0	 30.0;
	6702	 8295	 0.00153	 0.094124	 0.0	 336	 336	 336	 0.923203	 0.0	 1	 -30.0	 30.0;
	6702	 8295	 0.00156	 0.092157	 0.0	 343	 343	 343	 0.915583	 0.0	 1	 -30.0	 30.0;
	5740	 6625	 0.00512	 0.156934	 0.0	 202	 202	 202	 1.010993	 0.0	 1	 -30.0	 30.0;
	5740	 2262	 0.00513	 0.153636	 0.0	 206	 206	 206	 1.010221	 0.0	 1	 -30.0	 30.0;
	1615	 8420	 0.001473	 0.055275	 0.0	 572	 572	 572	 1.007611	 0.0	 1	 -30.0	 30.0;
	8161	 11298	 0.000628	 0.026981	 0.0	 1171	 1171	 1171	 0.98557	 0.0	 1	 -30.0	 30.0;
	9727	 9494	 0.000768	 0.027532	 0.0	 1147	 1147	 1147	 0.998512	 0.0	 1	 -30.0	 30.0;
	2337	 6209	 0.000778	 0.05467	 0.0	 578	 578	 578	 1.00533	 0.0	 1	 -30.0	 30.0;
	2337	 6209	 0.000767	 0.055473	 0.0	 570	 570	 570	 1.002994	 0.0	 1	 -30.0	 30.0;
	9493	 12719	 0.000905	 0.055047	 0.0	 574	 574	 574	 1.017266	 0.0	 1	 -30.0	 30.0;
	10869	 2932	 0.000902	 0.025704	 0.0	 1229	 1229	 1229	 1.077405	 0.0	 1	 -30.0	 30.0;
	10869	 2932	 0.000902	 0.024552	 0.0	 1286	 1286	 1286	 0.979902	 0.0	 1	 -30.0	 30.0;
	7387	 2932	 0.000437	 0.013336	 0.0	 2368	 2368	 2368	 0.973277	 0.0	 1	 -30.0	 30.0;
	428	 10739	 0.001665	 0.048767	 0.0	 648	 648	 648	 1.023061	 0.0	 1	 -30.0	 30.0;
	6191	 3261	 0.00083	 0.05142	 0.0	 615	 615	 615	 1.004796	 0.0	 1	 -30.0	 30.0;
	6191	 3261	 0.000754	 0.045701	 0.0	 692	 692	 692	 1.028944	 0.0	 1	 -30.0	 30.0;
	7978	 11053	 0.000798	 0.052223	 0.0	 605	 605	 605	 1.002851	 0.0	 1	 -30.0	 30.0;
	9500	 2391	 0.000748	 0.052717	 0.0	 600	 600	 600	 0.964338	 0.0	 1	 -30.0	 30.0;
	5173	 327	 0.000435	 0.02158	 0.0	 1464	 1464	 1464	 0.984122	 0.0	 1	 -30.0	 30.0;
	7453	 12066	 0.000871	 0.0262	 0.0	 1205	 1205	 1205	 0.990725	 0.0	 1	 -30.0	 30.0;
	8871	 6744	 0.000881	 0.047183	 0.0	 670	 670	 670	 0.9851	 0.0	 1	 -30.0	 30.0;
	6230	 3205	 0.000214	 0.018189	 0.0	 1737	 1737	 1737	 0.966505	 0.0	 1	 -30.0	 30.0;
	6915	 8410	 0.000545	 0.028951	 0.0	 1091	 1091	 1091	 0.991711	 0.0	 1	 -30.0	 30.0;
	7896	 10888	 0.000433	 0.016641	 0.0	 1898	 1898	 1898	 1.034384	 0.0	 1	 -30.0	 30.0;
	7896	 10888	 0.000271	 0.019483	 0.0	 1622	 1622	 1622	 1.039631	 0.0	 1	 -30.0	 30.0;
	1388	 5387	 0.000292	 0.041885	 0.0	 755	 755	 755	 1.006448	 0.0	 1	 -30.0	 30.0;
	1388	 5387	 0.000283	 0.025435	 0.0	 1242	 1242	 1242	 1.022071	 0.0	 1	 -30.0	 30.0;
	10105	 7259	 0.00019	 0.020772	 0.0	 1521	 1521	 1521	 0.994689	 0.0	 1	 -30.0	 30.0;
	4268	 10628	 0.000567	 0.0487	 0.0	 649	 649	 649	 1.005621	 0.0	 1	 -30.0	 30.0;
	4268	 10628	 0.000292	 0.024683	 0.0	 1280	 1280	 1280	 1.021598	 0.0	 1	 -30.0	 30.0;
	6662	 10992	 0.000238	 0.020505	 0.0	 1541	 1541	 1541	 0.991229	 0.0	 1	 -30.0	 30.0;
	6662	 10992	 0.000302	 0.024253	 0.0	 1303	 1303	 1303	 1.005556	 0.0	 1	 -30.0	 30.0;
	2214	 4789	 0.000394	 0.025662	 0.0	 1231	 1231	 1231	 0.97307	 0.0	 1	 -30.0	 30.0;
	2214	 4789	 0.000403	 0.026263	 0.0	 1203	 1203	 1203	 0.970495	 0.0	 1	 -30.0	 30.0;
	2214	 4789	 0.000358	 0.02845	 0.0	 1111	 1111	 1111	 0.985386	 0.0	 1	 -30.0	 30.0;
	1709	 5206	 0.000184	 0.020004	 0.0	 1579	 1579	 1579	 0.999118	 0.0	 1	 -30.0	 30.0;
	9891	 7037	 0.000287	 0.030676	 0.0	 1030	 1030	 1030	 0.997019	 0.0	 1	 -30.0	 30.0;
	1567	 9431	 0.000183	 0.021447	 0.0	 1473	 1473	 1473	 0.987623	 0.0	 1	 -30.0	 30.0;
	1567	 9431	 0.000183	 0.019858	 0.0	 1591	 1591	 1591	 0.981425	 0.0	 1	 -30.0	 30.0;
	13545	 9509	 0.000196	 0.019264	 0.0	 1640	 1640	 1640	 0.988502	 0.0	 1	 -30.0	 30.0;
	13545	 9509	 0.000205	 0.018521	 0.0	 1706	 1706	 1706	 1.01561	 0.0	 1	 -30.0	 30.0;
	8272	 4929	 0.000205	 0.018131	 0.0	 1743	 1743	 1743	 0.961546	 0.0	 1	 -30.0	 30.0;
	1009	 10220	 0.000224	 0.01875	 0.0	 1685	 1685	 1685	 1.136953	 0.0	 1	 -30.0	 30.0;
	1009	 10220	 0.000685	 0.016451	 0.0	 1919	 1919	 1919	 0.960333	 0.0	 1	 -30.0	 30.0;
	6340	 5358	 0.00021	 0.024641	 0.0	 1282	 1282	 1282	 0.963809	 0.0	 1	 -30.0	 30.0;
	6340	 5358	 0.00021	 0.025112	 0.0	 1258	 1258	 1258	 0.965125	 0.0	 1	 -30.0	 30.0;
	11828	 5909	 0.0	 0.00554	 0.0	 5702	 5702	 5702	 0.0	 0.0	 1	 -30.0	 30.0;
	2829	 1460	 0.0	 0.004842	 0.0	 6524	 6524	 6524	 0.997125	 -0.075844	 1	 -30.0	 30.0;
	701	 9886	 0.000205	 0.016639	 0.0	 1899	 1899	 1899	 1.003672	 0.0	 1	 -30.0	 30.0;
	701	 9886	 0.000214	 0.017035	 0.0	 1855	 1855	 1855	 1.002044	 0.0	 1	 -30.0	 30.0;
	701	 9886	 0.000214	 0.016674	 0.0	 1895	 1895	 1895	 0.983466	 0.0	 1	 -30.0	 30.0;
	5878	 4948	 0.000224	 0.018397	 0.0	 1717	 1717	 1717	 0.99081	 0.0	 1	 -30.0	 30.0;
	4412	 1018	 0.000522	 0.027299	 0.0	 1157	 1157	 1157	 0.983724	 0.0	 1	 -30.0	 30.0;
	4412	 1018	 0.000646	 0.037462	 0.0	 844	 844	 844	 0.994076	 0.0	 1	 -30.0	 30.0;
	8475	 10394	 0.000244	 0.033945	 0.0	 931	 931	 931	 1.063896	 0.0	 1	 -30.0	 30.0;
	8475	 10394	 0.000196	 0.023262	 0.0	 1358	 1358	 1358	 1.032098	 0.0	 1	 -30.0	 30.0;
	2059	 10394	 0.00091	 0.001563	 0.0	 17465	 17465	 17465	 0.999969	 -0.007859	 1	 -30.0	 30.0;
	2775	 6324	 0.000179	 0.016955	 0.0	 1863	 1863	 1863	 1.033369	 0.0	 1	 -30.0	 30.0;
	10704	 631	 0.000206	 0.01883	 0.0	 1678	 1678	 1678	 0.979095	 0.0	 1	 -30.0	 30.0;
	8800	 11725	 0.000233	 0.018474	 0.0	 1710	 1710	 1710	 0.91598	 0.0	 1	 -30.0	 30.0;
	8800	 11725	 0.000421	 0.031827	 0.0	 993	 993	 993	 1.185762	 0.0	 1	 -30.0	 30.0;
	1524	 13279	 0.000219	 0.016973	 0.0	 1861	 1861	 1861	 1.036934	 0.0	 1	 -30.0	 30.0;
	11828	 2503	 0.000213	 0.020004	 0.0	 1579	 1579	 1579	 0.972687	 0.0	 1	 -30.0	 30.0;
	1068	 1975	 0.000556	 0.033053	 0.0	 956	 956	 956	 0.991034	 0.0	 1	 -30.0	 30.0;
	6365	 12553	 0.000508	 0.028375	 0.0	 1114	 1114	 1114	 1.003719	 0.0	 1	 -30.0	 30.0;
	5002	 2036	 0.000179	 0.022003	 0.0	 1436	 1436	 1436	 0.983999	 0.0	 1	 -30.0	 30.0;
	3905	 13349	 0.000209	 0.02019	 0.0	 1565	 1565	 1565	 0.95643	 0.0	 1	 -30.0	 30.0;
	3905	 13349	 0.000214	 0.020311	 0.0	 1556	 1556	 1556	 0.957146	 0.0	 1	 -30.0	 30.0;
	10840	 7911	 0.000616	 0.030505	 0.0	 1036	 1036	 1036	 0.998594	 0.0	 1	 -30.0	 30.0;
	10840	 7911	 0.000626	 0.029369	 0.0	 1076	 1076	 1076	 0.998622	 0.0	 1	 -30.0	 30.0;
	3492	 5566	 0.000214	 0.019409	 0.0	 1628	 1628	 1628	 0.98363	 0.0	 1	 -30.0	 30.0;
	3492	 5566	 0.000192	 0.022	 0.0	 1436	 1436	 1436	 0.990701	 0.0	 1	 -30.0	 30.0;
	7640	 3189	 0.000531	 0.03466	 0.0	 912	 912	 912	 1.004979	 0.0	 1	 -30.0	 30.0;
	8556	 11983	 0.000531	 0.035228	 0.0	 897	 897	 897	 0.996232	 0.0	 1	 -30.0	 30.0;
	8556	 11983	 0.00049	 0.031535	 0.0	 1002	 1002	 1002	 0.996119	 0.0	 1	 -30.0	 30.0;
	8556	 11983	 0.000209	 0.020964	 0.0	 1507	 1507	 1507	 0.939959	 0.0	 1	 -30.0	 30.0;
	205	 1755	 0.000393	 0.02663	 0.0	 1187	 1187	 1187	 1.013061	 0.0	 1	 -30.0	 30.0;
	205	 1755	 0.000402	 0.026088	 0.0	 1211	 1211	 1211	 1.013764	 0.0	 1	 -30.0	 30.0;
	1512	 9362	 0.000201	 0.017787	 0.0	 1776	 1776	 1776	 0.981478	 0.0	 1	 -30.0	 30.0;
	5568	 1147	 0.000289	 0.018121	 0.0	 1743	 1743	 1743	 1.030461	 0.0	 1	 -30.0	 30.0;
	2052	 6733	 0.000643	 0.024464	 0.0	 1291	 1291	 1291	 1.002263	 0.0	 1	 -30.0	 30.0;
	2052	 6733	 0.000568	 0.027771	 0.0	 1138	 1138	 1138	 0.988227	 0.0	 1	 -30.0	 30.0;
	1203	 5642	 0.000506	 0.031833	 0.0	 993	 993	 993	 0.996877	 0.0	 1	 -30.0	 30.0;
	1203	 5642	 0.000196	 0.024118	 0.0	 1310	 1310	 1310	 0.98502	 0.0	 1	 -30.0	 30.0;
	8622	 13135	 0.000205	 0.022593	 0.0	 1399	 1399	 1399	 1.106495	 0.0	 1	 -30.0	 30.0;
	8622	 13135	 0.000186	 0.01968	 0.0	 1605	 1605	 1605	 0.945775	 0.0	 1	 -30.0	 30.0;
	8622	 13135	 0.000205	 0.01997	 0.0	 1582	 1582	 1582	 0.953095	 0.0	 1	 -30.0	 30.0;
	1673	 3846	 0.000215	 0.018787	 0.0	 1682	 1682	 1682	 1.003969	 0.0	 1	 -30.0	 30.0;
	1673	 3846	 0.000215	 0.018388	 0.0	 1718	 1718	 1718	 1.002646	 0.0	 1	 -30.0	 30.0;
	4779	 9114	 0.000224	 0.018834	 0.0	 1678	 1678	 1678	 0.997384	 0.0	 1	 -30.0	 30.0;
	5573	 1612	 0.000433	 0.043546	 0.0	 726	 726	 726	 1.057492	 0.0	 1	 -30.0	 30.0;
	11083	 4466	 0.000234	 0.018757	 0.0	 1684	 1684	 1684	 0.989873	 0.0	 1	 -30.0	 30.0;
	11083	 4466	 0.000197	 0.019207	 0.0	 1645	 1645	 1645	 0.991518	 0.0	 1	 -30.0	 30.0;
	11083	 4466	 0.000197	 0.019495	 0.0	 1621	 1621	 1621	 0.992052	 0.0	 1	 -30.0	 30.0;
	9773	 11466	 0.00018	 0.021226	 0.0	 1489	 1489	 1489	 1.04087	 0.0	 1	 -30.0	 30.0;
	9773	 11466	 0.000812	 0.03849	 0.0	 821	 821	 821	 1.050815	 0.0	 1	 -30.0	 30.0;
	3230	 6177	 0.000205	 0.02035	 0.0	 1553	 1553	 1553	 1.048518	 0.0	 1	 -30.0	 30.0;
	1060	 5766	 0.000593	 0.031521	 0.0	 1002	 1002	 1002	 0.998708	 0.0	 1	 -30.0	 30.0;
	1060	 5766	 0.000612	 0.031123	 0.0	 1015	 1015	 1015	 0.998743	 0.0	 1	 -30.0	 30.0;
	1060	 5766	 0.000427	 0.024994	 0.0	 1264	 1264	 1264	 0.988957	 0.0	 1	 -30.0	 30.0;
	3958	 608	 0.000667	 0.027207	 0.0	 1161	 1161	 1161	 0.981105	 0.0	 1	 -30.0	 30.0;
	3958	 608	 0.000621	 0.030836	 0.0	 1025	 1025	 1025	 1.02183	 0.0	 1	 -30.0	 30.0;
	449	 1334	 0.000192	 0.020791	 0.0	 1520	 1520	 1520	 1.000069	 0.0	 1	 -30.0	 30.0;
	449	 1334	 0.000192	 0.02119	 0.0	 1491	 1491	 1491	 0.991682	 0.0	 1	 -30.0	 30.0;
	9878	 40	 0.000686	 0.030987	 0.0	 1020	 1020	 1020	 1.00917	 0.0	 1	 -30.0	 30.0;
	4332	 8256	 0.000194	 0.020764	 0.0	 1522	 1522	 1522	 0.991744	 0.0	 1	 -30.0	 30.0;
	257	 2633	 0.000717	 0.038087	 0.0	 830	 830	 830	 1.014054	 0.0	 1	 -30.0	 30.0;
	12754	 4323	 0.000206	 0.01883	 0.0	 1678	 1678	 1678	 1.001238	 0.0	 1	 -30.0	 30.0;
	12754	 116	 0.000206	 0.018439	 0.0	 1713	 1713	 1713	 1.000839	 0.0	 1	 -30.0	 30.0;
	10272	 41	 0.000219	 0.017019	 0.0	 1856	 1856	 1856	 0.93708	 0.0	 1	 -30.0	 30.0;
	10272	 41	 0.000224	 0.016641	 0.0	 1898	 1898	 1898	 1.105076	 0.0	 1	 -30.0	 30.0;
	9663	 340	 0.000676	 0.047085	 0.0	 671	 671	 671	 1.015319	 0.0	 1	 -30.0	 30.0;
	9663	 340	 0.000667	 0.048014	 0.0	 658	 658	 658	 1.016183	 0.0	 1	 -30.0	 30.0;
	10769	 5778	 0.000196	 0.019215	 0.0	 1644	 1644	 1644	 1.001385	 0.0	 1	 -30.0	 30.0;
	5833	 8585	 0.000253	 0.025528	 0.0	 1238	 1238	 1238	 1.014185	 0.0	 1	 -30.0	 30.0;
	12079	 10130	 0.00021	 0.017884	 0.0	 1767	 1767	 1767	 0.980239	 0.0	 1	 -30.0	 30.0;
	12079	 10130	 0.00021	 0.017518	 0.0	 1804	 1804	 1804	 0.979239	 0.0	 1	 -30.0	 30.0;
	2449	 2731	 0.000219	 0.017358	 0.0	 1820	 1820	 1820	 0.886675	 0.0	 1	 -30.0	 30.0;
	2449	 2731	 0.000219	 0.016973	 0.0	 1861	 1861	 1861	 1.040658	 0.0	 1	 -30.0	 30.0;
	5198	 1227	 0.000295	 0.027995	 0.0	 1129	 1129	 1129	 0.997171	 0.0	 1	 -30.0	 30.0;
	5198	 1227	 0.000277	 0.027486	 0.0	 1150	 1150	 1150	 1.002862	 0.0	 1	 -30.0	 30.0;
	957	 4876	 0.000489	 0.032074	 0.0	 985	 985	 985	 1.001121	 0.0	 1	 -30.0	 30.0;
	8883	 4497	 0.00018	 0.02129	 0.0	 1484	 1484	 1484	 1.028583	 0.0	 1	 -30.0	 30.0;
	1543	 11738	 0.000366	 0.029147	 0.0	 1084	 1084	 1084	 0.99364	 0.0	 1	 -30.0	 30.0;
	1543	 11738	 0.000366	 0.028067	 0.0	 1126	 1126	 1126	 1.002233	 0.0	 1	 -30.0	 30.0;
	1543	 11738	 0.00042	 0.026331	 0.0	 1200	 1200	 1200	 0.990472	 0.0	 1	 -30.0	 30.0;
	7258	 11673	 0.000441	 0.01916	 0.0	 1649	 1649	 1649	 0.964133	 0.0	 1	 -30.0	 30.0;
	10884	 8972	 0.000391	 0.024766	 0.0	 1276	 1276	 1276	 0.979452	 0.0	 1	 -30.0	 30.0;
	10884	 8972	 0.000401	 0.024225	 0.0	 1304	 1304	 1304	 0.979476	 0.0	 1	 -30.0	 30.0;
	10884	 6828	 0.000408	 0.028237	 0.0	 1119	 1119	 1119	 0.981165	 0.0	 1	 -30.0	 30.0;
	10183	 6790	 0.000199	 0.018609	 0.0	 1698	 1698	 1698	 0.972278	 0.0	 1	 -30.0	 30.0;
	3862	 13240	 0.000196	 0.021597	 0.0	 1463	 1463	 1463	 1.019951	 0.0	 1	 -30.0	 30.0;
	3862	 13240	 0.000186	 0.022003	 0.0	 1436	 1436	 1436	 0.967128	 0.0	 1	 -30.0	 30.0;
	4089	 4803	 0.000186	 0.019718	 0.0	 1602	 1602	 1602	 0.992589	 0.0	 1	 -30.0	 30.0;
	6524	 2062	 0.000205	 0.022703	 0.0	 1392	 1392	 1392	 1.015338	 0.0	 1	 -30.0	 30.0;
	1163	 11469	 0.000228	 0.021908	 0.0	 1442	 1442	 1442	 0.964453	 0.0	 1	 -30.0	 30.0;
	10894	 11166	 0.000322	 0.028734	 0.0	 1100	 1100	 1100	 0.987134	 0.0	 1	 -30.0	 30.0;
	10894	 13462	 0.000319	 0.026574	 0.0	 1189	 1189	 1189	 1.020058	 0.0	 1	 -30.0	 30.0;
	5263	 1756	 0.000289	 0.018298	 0.0	 1727	 1727	 1727	 1.082094	 0.0	 1	 -30.0	 30.0;
	5263	 1756	 0.000199	 0.02111	 0.0	 1497	 1497	 1497	 1.070801	 0.0	 1	 -30.0	 30.0;
	11270	 12225	 0.000196	 0.02119	 0.0	 1491	 1491	 1491	 0.989832	 0.0	 1	 -30.0	 30.0;
	11270	 12225	 0.000196	 0.021597	 0.0	 1463	 1463	 1463	 0.990939	 0.0	 1	 -30.0	 30.0;
	6614	 2140	 0.001097	 0.082091	 0.0	 385	 385	 385	 1.004174	 0.0	 1	 -30.0	 30.0;
	6614	 2140	 0.000406	 0.048834	 0.0	 647	 647	 647	 1.056479	 0.0	 1	 -30.0	 30.0;
	6614	 2140	 7.2e-05	 0.017798	 0.0	 1775	 1775	 1775	 1.007737	 0.0	 1	 -30.0	 30.0;
	6614	 2140	 0.000424	 0.04684	 0.0	 675	 675	 675	 1.056821	 0.0	 1	 -30.0	 30.0;
	12155	 6004	 0.000224	 0.01875	 0.0	 1685	 1685	 1685	 0.992009	 0.0	 1	 -30.0	 30.0;
	12155	 6004	 0.000224	 0.018334	 0.0	 1723	 1723	 1723	 0.992184	 0.0	 1	 -30.0	 30.0;
	1810	 6271	 0.000379	 0.018493	 0.0	 1708	 1708	 1708	 1.043052	 0.0	 1	 -30.0	 30.0;
	1810	 6271	 0.000253	 0.019711	 0.0	 1603	 1603	 1603	 1.045217	 0.0	 1	 -30.0	 30.0;
	570	 11776	 0.000196	 0.016483	 0.0	 1917	 1917	 1917	 0.987356	 0.0	 1	 -30.0	 30.0;
	570	 11776	 0.000186	 0.022421	 0.0	 1409	 1409	 1409	 1.000553	 0.0	 1	 -30.0	 30.0;
	9883	 6027	 0.00046	 0.030794	 0.0	 1026	 1026	 1026	 1.023789	 0.0	 1	 -30.0	 30.0;
	13300	 3475	 0.000695	 0.049098	 0.0	 644	 644	 644	 0.982143	 0.0	 1	 -30.0	 30.0;
	13300	 3475	 0.000355	 0.024893	 0.0	 1269	 1269	 1269	 0.945703	 0.0	 1	 -30.0	 30.0;
	924	 3475	 0.000365	 0.024372	 0.0	 1296	 1296	 1296	 0.951103	 0.0	 1	 -30.0	 30.0;
	4543	 11390	 0.000411	 0.023652	 0.0	 1336	 1336	 1336	 0.936202	 0.0	 1	 -30.0	 30.0;
	9749	 7207	 0.000386	 0.025673	 0.0	 1231	 1231	 1231	 0.941054	 0.0	 1	 -30.0	 30.0;
	9749	 7207	 0.000344	 0.029336	 0.0	 1077	 1077	 1077	 0.940894	 0.0	 1	 -30.0	 30.0;
	1190	 6613	 0.000653	 0.052104	 0.0	 607	 607	 607	 0.982143	 0.0	 1	 -30.0	 30.0;
	1190	 6613	 0.000767	 0.043531	 0.0	 726	 726	 726	 0.982143	 0.0	 1	 -30.0	 30.0;
	5026	 8307	 0.000323	 0.028314	 0.0	 1116	 1116	 1116	 0.942497	 0.0	 1	 -30.0	 30.0;
	5026	 8307	 0.000323	 0.025999	 0.0	 1215	 1215	 1215	 0.942876	 0.0	 1	 -30.0	 30.0;
	5026	 10642	 0.000365	 0.025478	 0.0	 1240	 1240	 1240	 0.942686	 0.0	 1	 -30.0	 30.0;
	1251	 9209	 0.00086	 0.039291	 0.0	 804	 804	 804	 0.982143	 0.0	 1	 -30.0	 30.0;
	1041	 1777	 0.000355	 0.026586	 0.0	 1189	 1189	 1189	 0.93516	 0.0	 1	 -30.0	 30.0;
	1041	 1777	 0.000375	 0.026313	 0.0	 1201	 1201	 1201	 0.935102	 0.0	 1	 -30.0	 30.0;
	9068	 3391	 0.000344	 0.023329	 0.0	 1354	 1354	 1354	 0.959849	 0.0	 1	 -30.0	 30.0;
	9068	 3391	 0.000302	 0.026375	 0.0	 1198	 1198	 1198	 0.958344	 0.0	 1	 -30.0	 30.0;
	13566	 4205	 0.000788	 0.04323	 0.0	 731	 731	 731	 0.982143	 0.0	 1	 -30.0	 30.0;
	13566	 4205	 0.000767	 0.04407	 0.0	 717	 717	 717	 0.982143	 0.0	 1	 -30.0	 30.0;
	1920	 8521	 0.000767	 0.043562	 0.0	 725	 725	 725	 0.982143	 0.0	 1	 -30.0	 30.0;
	1920	 8521	 0.000788	 0.041281	 0.0	 766	 766	 766	 0.982143	 0.0	 1	 -30.0	 30.0;
	1920	 8521	 0.000892	 0.040524	 0.0	 780	 780	 780	 0.982143	 0.0	 1	 -30.0	 30.0;
	4638	 12483	 0.000975	 0.043562	 0.0	 725	 725	 725	 0.982143	 0.0	 1	 -30.0	 30.0;
	4638	 12483	 0.000757	 0.042649	 0.0	 741	 741	 741	 0.982143	 0.0	 1	 -30.0	 30.0;
	6488	 3378	 0.000261	 0.030762	 0.0	 1027	 1027	 1027	 0.92865	 0.0	 1	 -30.0	 30.0;
	6488	 3378	 0.000261	 0.030088	 0.0	 1050	 1050	 1050	 0.928516	 0.0	 1	 -30.0	 30.0;
	7339	 8926	 0.000323	 0.026447	 0.0	 1195	 1195	 1195	 0.941588	 0.0	 1	 -30.0	 30.0;
	7339	 2058	 0.000323	 0.026885	 0.0	 1175	 1175	 1175	 0.93842	 0.0	 1	 -30.0	 30.0;
	10941	 806	 0.000323	 0.02748	 0.0	 1150	 1150	 1150	 0.939738	 0.0	 1	 -30.0	 30.0;
	10941	 806	 0.000292	 0.028158	 0.0	 1122	 1122	 1122	 0.939729	 0.0	 1	 -30.0	 30.0;
	806	 7319	 0.0	 0.014868	 0.0	 2125	 2125	 2125	 1.0	 0.19252	 1	 -30.0	 30.0;
	7987	 3056	 0.000736	 0.044526	 0.0	 710	 710	 710	 0.982143	 0.0	 1	 -30.0	 30.0;
	4094	 13471	 0.00086	 0.039488	 0.0	 800	 800	 800	 0.982143	 0.0	 1	 -30.0	 30.0;
	5236	 9561	 0.000365	 0.024372	 0.0	 1296	 1296	 1296	 0.939493	 0.0	 1	 -30.0	 30.0;
	5236	 9561	 0.000375	 0.023986	 0.0	 1317	 1317	 1317	 0.939428	 0.0	 1	 -30.0	 30.0;
	6589	 2737	 0.000386	 0.025673	 0.0	 1231	 1231	 1231	 0.943953	 0.0	 1	 -30.0	 30.0;
	3805	 2538	 0.000809	 0.042318	 0.0	 747	 747	 747	 0.982143	 0.0	 1	 -30.0	 30.0;
	5160	 8217	 0.000705	 0.042038	 0.0	 752	 752	 752	 0.982143	 0.0	 1	 -30.0	 30.0;
	5197	 544	 0.000334	 0.028022	 0.0	 1128	 1128	 1128	 0.967208	 0.0	 1	 -30.0	 30.0;
	5197	 2615	 0.000353	 0.022403	 0.0	 1410	 1410	 1410	 0.982143	 0.0	 1	 -30.0	 30.0;
	3395	 544	 0.000313	 0.026354	 0.0	 1199	 1199	 1199	 0.965958	 0.0	 1	 -30.0	 30.0;
	3395	 544	 0.000323	 0.025478	 0.0	 1240	 1240	 1240	 0.966322	 0.0	 1	 -30.0	 30.0;
	2677	 11371	 0.000344	 0.024622	 0.0	 1283	 1283	 1283	 0.946628	 0.0	 1	 -30.0	 30.0;
	167	 11371	 0.000355	 0.024038	 0.0	 1314	 1314	 1314	 0.94666	 0.0	 1	 -30.0	 30.0;
	3609	 10683	 0.000881	 0.038244	 0.0	 826	 826	 826	 0.982143	 0.0	 1	 -30.0	 30.0;
	3609	 10683	 0.000757	 0.040959	 0.0	 772	 772	 772	 0.982143	 0.0	 1	 -30.0	 30.0;
	9	 2951	 0.000354	 0.028765	 0.0	 1099	 1099	 1099	 0.936462	 0.0	 1	 -30.0	 30.0;
	9087	 2951	 0.000354	 0.027114	 0.0	 1165	 1165	 1165	 0.937994	 0.0	 1	 -30.0	 30.0;
	11842	 2951	 0.000695	 0.04748	 0.0	 666	 666	 666	 0.982143	 0.0	 1	 -30.0	 30.0;
	6777	 2296	 0.000323	 0.028314	 0.0	 1116	 1116	 1116	 0.937091	 0.0	 1	 -30.0	 30.0;
	6777	 2296	 0.000323	 0.026354	 0.0	 1199	 1199	 1199	 0.937017	 0.0	 1	 -30.0	 30.0;
	6777	 2296	 0.000323	 0.025696	 0.0	 1230	 1230	 1230	 0.936983	 0.0	 1	 -30.0	 30.0;
	8137	 1420	 0.000355	 0.027305	 0.0	 1157	 1157	 1157	 0.933898	 0.0	 1	 -30.0	 30.0;
	8137	 1420	 0.000355	 0.026666	 0.0	 1185	 1185	 1185	 0.93371	 0.0	 1	 -30.0	 30.0;
	8137	 1420	 0.000923	 0.037456	 0.0	 844	 844	 844	 0.982143	 0.0	 1	 -30.0	 30.0;
	8137	 1420	 0.000788	 0.035217	 0.0	 897	 897	 897	 0.982143	 0.0	 1	 -30.0	 30.0;
	1707	 10943	 0.000323	 0.026739	 0.0	 1182	 1182	 1182	 0.945782	 0.0	 1	 -30.0	 30.0;
	1707	 10943	 0.000323	 0.02749	 0.0	 1149	 1149	 1149	 0.945551	 0.0	 1	 -30.0	 30.0;
	3556	 7192	 0.000313	 0.027324	 0.0	 1156	 1156	 1156	 0.941516	 0.0	 1	 -30.0	 30.0;
	3556	 7192	 0.000313	 0.028074	 0.0	 1126	 1126	 1126	 0.94145	 0.0	 1	 -30.0	 30.0;
	1185	 8038	 0.000601	 0.024984	 0.0	 1264	 1264	 1264	 0.983506	 0.0	 1	 -30.0	 30.0;
	1185	 8038	 0.000715	 0.022797	 0.0	 1385	 1385	 1385	 0.986405	 0.0	 1	 -30.0	 30.0;
	1185	 8038	 0.000344	 0.024893	 0.0	 1269	 1269	 1269	 0.933442	 0.0	 1	 -30.0	 30.0;
	7274	 11696	 0.000365	 0.024163	 0.0	 1308	 1308	 1308	 0.944221	 0.0	 1	 -30.0	 30.0;
	7274	 11696	 0.000344	 0.02385	 0.0	 1325	 1325	 1325	 0.94451	 0.0	 1	 -30.0	 30.0;
	7324	 10802	 0.000757	 0.040182	 0.0	 786	 786	 786	 0.982143	 0.0	 1	 -30.0	 30.0;
	1100	 5520	 0.000323	 0.028937	 0.0	 1092	 1092	 1092	 0.940338	 0.0	 1	 -30.0	 30.0;
	5445	 1829	 0.000354	 0.026958	 0.0	 1172	 1172	 1172	 0.935886	 0.0	 1	 -30.0	 30.0;
	5445	 1829	 0.000778	 0.045656	 0.0	 692	 692	 692	 0.982143	 0.0	 1	 -30.0	 30.0;
	5445	 1829	 0.000695	 0.048932	 0.0	 646	 646	 646	 0.982143	 0.0	 1	 -30.0	 30.0;
	5445	 1829	 0.000302	 0.025926	 0.0	 1219	 1219	 1219	 0.936144	 0.0	 1	 -30.0	 30.0;
	9843	 13380	 0.000355	 0.027328	 0.0	 1156	 1156	 1156	 0.930802	 0.0	 1	 -30.0	 30.0;
	9843	 13380	 0.000365	 0.027156	 0.0	 1164	 1164	 1164	 0.930683	 0.0	 1	 -30.0	 30.0;
	13490	 8642	 0.000355	 0.024299	 0.0	 1300	 1300	 1300	 0.94568	 0.0	 1	 -30.0	 30.0;
	2580	 1153	 0.000375	 0.026313	 0.0	 1201	 1201	 1201	 0.937729	 0.0	 1	 -30.0	 30.0;
	2580	 1153	 0.000375	 0.025605	 0.0	 1234	 1234	 1234	 0.937682	 0.0	 1	 -30.0	 30.0;
	4714	 2203	 0.000334	 0.026291	 0.0	 1202	 1202	 1202	 0.945241	 0.0	 1	 -30.0	 30.0;
	4714	 2203	 0.000705	 0.046735	 0.0	 676	 676	 676	 0.982143	 0.0	 1	 -30.0	 30.0;
	2919	 6011	 0.000313	 0.026875	 0.0	 1176	 1176	 1176	 0.952228	 0.0	 1	 -30.0	 30.0;
	2919	 6011	 0.000302	 0.027376	 0.0	 1154	 1154	 1154	 0.952006	 0.0	 1	 -30.0	 30.0;
	6741	 7462	 0.000664	 0.044868	 0.0	 704	 704	 704	 0.982143	 0.0	 1	 -30.0	 30.0;
	3010	 7462	 0.000809	 0.044526	 0.0	 710	 710	 710	 0.982143	 0.0	 1	 -30.0	 30.0;
	8243	 12724	 0.00086	 0.034253	 0.0	 922	 922	 922	 0.98188	 0.0	 1	 -30.0	 30.0;
	8243	 12724	 0.000355	 0.024372	 0.0	 1296	 1296	 1296	 0.931285	 0.0	 1	 -30.0	 30.0;
	4088	 2184	 0.000365	 0.023788	 0.0	 1328	 1328	 1328	 0.936712	 0.0	 1	 -30.0	 30.0;
	6661	 10021	 0.000375	 0.023204	 0.0	 1362	 1362	 1362	 0.948852	 0.0	 1	 -30.0	 30.0;
	6661	 10021	 0.000302	 0.026593	 0.0	 1188	 1188	 1188	 0.947797	 0.0	 1	 -30.0	 30.0;
	2507	 5664	 0.000323	 0.029256	 0.0	 1080	 1080	 1080	 0.934986	 0.0	 1	 -30.0	 30.0;
	2507	 5664	 0.000334	 0.029986	 0.0	 1054	 1054	 1054	 0.93499	 0.0	 1	 -30.0	 30.0;
	2507	 5664	 0.000355	 0.030979	 0.0	 1020	 1020	 1020	 0.934976	 0.0	 1	 -30.0	 30.0;
	3616	 6666	 0.000302	 0.025707	 0.0	 1229	 1229	 1229	 0.942193	 0.0	 1	 -30.0	 30.0;
	3616	 6666	 0.000344	 0.025405	 0.0	 1244	 1244	 1244	 0.942155	 0.0	 1	 -30.0	 30.0;
	4435	 8929	 0.00012	 0.010039	 0.0	 3147	 3147	 3147	 1.0	 0.108521	 1	 -30.0	 30.0;
	7414	 11183	 0.000365	 0.023715	 0.0	 1332	 1332	 1332	 0.941104	 0.0	 1	 -30.0	 30.0;
	12476	 12299	 0.000365	 0.023517	 0.0	 1344	 1344	 1344	 0.946514	 0.0	 1	 -30.0	 30.0;
	12476	 8034	 0.000334	 0.026812	 0.0	 1179	 1179	 1179	 0.949752	 0.0	 1	 -30.0	 30.0;
	12511	 13001	 0.000695	 0.047253	 0.0	 669	 669	 669	 0.982143	 0.0	 1	 -30.0	 30.0;
	11017	 13001	 0.000778	 0.043759	 0.0	 722	 722	 722	 0.982143	 0.0	 1	 -30.0	 30.0;
	227	 11066	 0.000313	 0.030636	 0.0	 1031	 1031	 1031	 0.930512	 0.0	 1	 -30.0	 30.0;
	227	 11066	 0.000313	 0.028286	 0.0	 1117	 1117	 1117	 0.929988	 0.0	 1	 -30.0	 30.0;
	227	 11066	 0.000344	 0.028115	 0.0	 1124	 1124	 1124	 0.929896	 0.0	 1	 -30.0	 30.0;
	3627	 7129	 0.000902	 0.039425	 0.0	 801	 801	 801	 0.982143	 0.0	 1	 -30.0	 30.0;
	3383	 5616	 0.000355	 0.024237	 0.0	 1304	 1304	 1304	 0.942651	 0.0	 1	 -30.0	 30.0;
	12835	 4954	 0.000375	 0.023986	 0.0	 1317	 1317	 1317	 0.945624	 0.0	 1	 -30.0	 30.0;
	12835	 4954	 0.000375	 0.023861	 0.0	 1324	 1324	 1324	 0.945648	 0.0	 1	 -30.0	 30.0;
	2124	 158	 0.000819	 0.04153	 0.0	 761	 761	 761	 0.982143	 0.0	 1	 -30.0	 30.0;
	2124	 158	 0.000809	 0.042701	 0.0	 740	 740	 740	 0.982143	 0.0	 1	 -30.0	 30.0;
	13480	 3995	 0.000334	 0.028022	 0.0	 1128	 1128	 1128	 0.930785	 0.0	 1	 -30.0	 30.0;
	4416	 1314	 0.000632	 0.048237	 0.0	 655	 655	 655	 0.982143	 0.0	 1	 -30.0	 30.0;
	4416	 1314	 0.000632	 0.045159	 0.0	 700	 700	 700	 0.982143	 0.0	 1	 -30.0	 30.0;
	4416	 1314	 0.000715	 0.044039	 0.0	 718	 718	 718	 0.982143	 0.0	 1	 -30.0	 30.0;
	5763	 9938	 0.00074	 0.044479	 0.0	 711	 711	 711	 0.986547	 0.0	 1	 -30.0	 30.0;
	5763	 5914	 0.00074	 0.043811	 0.0	 721	 721	 721	 0.986547	 0.0	 1	 -30.0	 30.0;
	6512	 4974	 0.000375	 0.02385	 0.0	 1325	 1325	 1325	 0.951331	 0.0	 1	 -30.0	 30.0;
	6512	 4974	 0.000365	 0.023267	 0.0	 1358	 1358	 1358	 0.951635	 0.0	 1	 -30.0	 30.0;
	6512	 4974	 0.000323	 0.026739	 0.0	 1182	 1182	 1182	 0.95056	 0.0	 1	 -30.0	 30.0;
	1554	 10795	 0.000684	 0.047025	 0.0	 672	 672	 672	 0.982143	 0.0	 1	 -30.0	 30.0;
	13455	 3083	 0.000313	 0.02748	 0.0	 1150	 1150	 1150	 0.944823	 0.0	 1	 -30.0	 30.0;
	9592	 12495	 0.000323	 0.028554	 0.0	 1107	 1107	 1107	 0.933305	 0.0	 1	 -30.0	 30.0;
	9592	 12495	 0.000302	 0.026437	 0.0	 1195	 1195	 1195	 0.933048	 0.0	 1	 -30.0	 30.0;
	10309	 11074	 0.000365	 0.025551	 0.0	 1237	 1237	 1237	 0.934453	 0.0	 1	 -30.0	 30.0;
	10309	 11074	 0.000344	 0.024893	 0.0	 1269	 1269	 1269	 0.934463	 0.0	 1	 -30.0	 30.0;
	10309	 13372	 0.000375	 0.024508	 0.0	 1289	 1289	 1289	 0.960551	 0.0	 1	 -30.0	 30.0;
	10059	 9913	 0.000778	 0.041157	 0.0	 768	 768	 768	 0.982143	 0.0	 1	 -30.0	 30.0;
	10059	 9913	 0.000923	 0.03702	 0.0	 853	 853	 853	 0.982143	 0.0	 1	 -30.0	 30.0;
	10059	 9913	 0.000302	 0.026593	 0.0	 1188	 1188	 1188	 0.953169	 0.0	 1	 -30.0	 30.0;
	1465	 10468	 0.000344	 0.029667	 0.0	 1065	 1065	 1065	 0.928657	 0.0	 1	 -30.0	 30.0;
	1465	 55	 0.000334	 0.02748	 0.0	 1150	 1150	 1150	 0.933328	 0.0	 1	 -30.0	 30.0;
	1229	 10468	 0.000323	 0.030636	 0.0	 1031	 1031	 1031	 0.932366	 0.0	 1	 -30.0	 30.0;
	1229	 55	 0.000323	 0.028526	 0.0	 1108	 1108	 1108	 0.937672	 0.0	 1	 -30.0	 30.0;
	13621	 9096	 0.000344	 0.025332	 0.0	 1247	 1247	 1247	 0.943426	 0.0	 1	 -30.0	 30.0;
	13621	 12207	 0.000334	 0.024674	 0.0	 1281	 1281	 1281	 0.941774	 0.0	 1	 -30.0	 30.0;
	13621	 9992	 0.000344	 0.02457	 0.0	 1286	 1286	 1286	 0.940947	 0.0	 1	 -30.0	 30.0;
	5299	 9740	 0.000365	 0.023788	 0.0	 1328	 1328	 1328	 0.935351	 0.0	 1	 -30.0	 30.0;
	11015	 9611	 0.000365	 0.023601	 0.0	 1339	 1339	 1339	 0.955118	 0.0	 1	 -30.0	 30.0;
	11015	 9611	 0.000344	 0.02652	 0.0	 1191	 1191	 1191	 0.953676	 0.0	 1	 -30.0	 30.0;
	10996	 9611	 0.000344	 0.027272	 0.0	 1159	 1159	 1159	 0.953967	 0.0	 1	 -30.0	 30.0;
	10996	 9611	 0.000334	 0.027563	 0.0	 1146	 1146	 1146	 0.953841	 0.0	 1	 -30.0	 30.0;
	2849	 9710	 0.000313	 0.030636	 0.0	 1031	 1031	 1031	 0.951606	 0.0	 1	 -30.0	 30.0;
	2849	 9710	 0.000313	 0.028286	 0.0	 1117	 1117	 1117	 0.952467	 0.0	 1	 -30.0	 30.0;
	7948	 1162	 0.000881	 0.036803	 0.0	 859	 859	 859	 0.992378	 0.0	 1	 -30.0	 30.0;
	7948	 1162	 0.000902	 0.036668	 0.0	 862	 862	 862	 0.992425	 0.0	 1	 -30.0	 30.0;
	7948	 1162	 0.000881	 0.034014	 0.0	 929	 929	 929	 0.993191	 0.0	 1	 -30.0	 30.0;
	7280	 5559	 0.000365	 0.026027	 0.0	 1214	 1214	 1214	 0.937778	 0.0	 1	 -30.0	 30.0;
	7280	 5559	 0.000386	 0.025673	 0.0	 1231	 1231	 1231	 0.937768	 0.0	 1	 -30.0	 30.0;
	10630	 6586	 0.00012	 0.009966	 0.0	 3170	 3170	 3170	 1.0	 -0.036236	 1	 -30.0	 30.0;
	13583	 82	 0.00017	 0.006789	 0.0	 4652	 4652	 4652	 1.0	 -0.086984	 1	 -30.0	 30.0;
	13583	 4479	 0.000664	 0.047107	 0.0	 671	 671	 671	 0.982143	 0.0	 1	 -30.0	 30.0;
	2075	 1783	 0.000313	 0.028314	 0.0	 1116	 1116	 1116	 0.93521	 0.0	 1	 -30.0	 30.0;
	2075	 1783	 0.000334	 0.025707	 0.0	 1229	 1229	 1229	 0.934745	 0.0	 1	 -30.0	 30.0;
	2075	 2217	 0.000344	 0.025478	 0.0	 1240	 1240	 1240	 0.931132	 0.0	 1	 -30.0	 30.0;
	11026	 2217	 0.000344	 0.027236	 0.0	 1160	 1160	 1160	 0.931428	 0.0	 1	 -30.0	 30.0;
	11026	 2217	 0.000375	 0.026518	 0.0	 1192	 1192	 1192	 0.931193	 0.0	 1	 -30.0	 30.0;
	10081	 2224	 0.000386	 0.02646	 0.0	 1194	 1194	 1194	 0.925602	 0.0	 1	 -30.0	 30.0;
	4266	 6	 0.000788	 0.040317	 0.0	 784	 784	 784	 0.982143	 0.0	 1	 -30.0	 30.0;
	11004	 820	 0.000323	 0.025863	 0.0	 1222	 1222	 1222	 0.949117	 0.0	 1	 -30.0	 30.0;
	1086	 3185	 1e-05	 0.023516	 0.0	 1344	 1344	 1344	 1.0	 -0.146705	 1	 -30.0	 30.0;
	6081	 5428	 0.000334	 0.030306	 0.0	 1043	 1043	 1043	 0.945073	 0.0	 1	 -30.0	 30.0;
	6081	 5428	 0.000302	 0.030636	 0.0	 1032	 1032	 1032	 0.945165	 0.0	 1	 -30.0	 30.0;
	10933	 5386	 0.00011	 0.011411	 0.0	 2769	 2769	 2769	 1.0	 0.085905	 1	 -30.0	 30.0;
	12094	 9593	 0.000344	 0.024841	 0.0	 1272	 1272	 1272	 0.945982	 0.0	 1	 -30.0	 30.0;
	12094	 9593	 0.000365	 0.025029	 0.0	 1262	 1262	 1262	 0.945927	 0.0	 1	 -30.0	 30.0;
	12094	 9593	 0.000355	 0.024101	 0.0	 1311	 1311	 1311	 0.946218	 0.0	 1	 -30.0	 30.0;
	6061	 235	 0.000344	 0.02385	 0.0	 1325	 1325	 1325	 0.943808	 0.0	 1	 -30.0	 30.0;
	6061	 235	 0.000411	 0.02313	 0.0	 1366	 1366	 1366	 0.943451	 0.0	 1	 -30.0	 30.0;
	6061	 235	 0.000829	 0.042764	 0.0	 739	 739	 739	 0.982143	 0.0	 1	 -30.0	 30.0;
	8497	 13448	 0.000705	 0.04748	 0.0	 666	 666	 666	 0.982143	 0.0	 1	 -30.0	 30.0;
	8497	 2050	 0.000323	 0.029986	 0.0	 1054	 1054	 1054	 0.93585	 0.0	 1	 -30.0	 30.0;
	8497	 2050	 0.000302	 0.029952	 0.0	 1055	 1055	 1055	 0.935892	 0.0	 1	 -30.0	 30.0;
	13408	 7811	 0.000746	 0.041064	 0.0	 770	 770	 770	 0.982143	 0.0	 1	 -30.0	 30.0;
	13408	 7811	 0.000881	 0.042214	 0.0	 749	 749	 749	 0.982143	 0.0	 1	 -30.0	 30.0;
	3376	 11774	 0.00086	 0.041209	 0.0	 767	 767	 767	 0.982143	 0.0	 1	 -30.0	 30.0;
	3376	 11774	 0.000912	 0.038669	 0.0	 817	 817	 817	 0.982143	 0.0	 1	 -30.0	 30.0;
	11927	 244	 0.000375	 0.026244	 0.0	 1204	 1204	 1204	 0.95253	 0.0	 1	 -30.0	 30.0;
	11927	 244	 0.000375	 0.025457	 0.0	 1241	 1241	 1241	 0.95286	 0.0	 1	 -30.0	 30.0;
	12417	 1657	 0.000302	 0.029096	 0.0	 1086	 1086	 1086	 0.934819	 0.0	 1	 -30.0	 30.0;
	6937	 3180	 0.000302	 0.029667	 0.0	 1065	 1065	 1065	 0.947685	 0.0	 1	 -30.0	 30.0;
	2433	 955	 0.000334	 0.027563	 0.0	 1146	 1146	 1146	 0.945284	 0.0	 1	 -30.0	 30.0;
	2433	 955	 0.000323	 0.028074	 0.0	 1126	 1126	 1126	 0.94517	 0.0	 1	 -30.0	 30.0;
	1269	 11276	 0.000736	 0.041064	 0.0	 770	 770	 770	 0.982143	 0.0	 1	 -30.0	 30.0;
	12272	 11276	 0.001234	 0.040109	 0.0	 788	 788	 788	 0.982143	 0.0	 1	 -30.0	 30.0;
	12272	 11276	 0.000757	 0.043209	 0.0	 731	 731	 731	 0.982143	 0.0	 1	 -30.0	 30.0;
	1127	 9274	 0.000323	 0.026586	 0.0	 1189	 1189	 1189	 0.962929	 0.0	 1	 -30.0	 30.0;
	6157	 422	 0.000788	 0.040296	 0.0	 784	 784	 784	 0.982143	 0.0	 1	 -30.0	 30.0;
	6157	 422	 0.000912	 0.040514	 0.0	 780	 780	 780	 0.982143	 0.0	 1	 -30.0	 30.0;
	2936	 5132	 0.000798	 0.042183	 0.0	 749	 749	 749	 0.982143	 0.0	 1	 -30.0	 30.0;
	2936	 5132	 0.000778	 0.043147	 0.0	 732	 732	 732	 0.982143	 0.0	 1	 -30.0	 30.0;
	10294	 12739	 0.000323	 0.027793	 0.0	 1137	 1137	 1137	 0.924286	 0.0	 1	 -30.0	 30.0;
	10294	 12739	 0.000302	 0.027918	 0.0	 1132	 1132	 1132	 0.924396	 0.0	 1	 -30.0	 30.0;
	10294	 12739	 0.000302	 0.025926	 0.0	 1219	 1219	 1219	 0.923543	 0.0	 1	 -30.0	 30.0;
	6599	 4246	 0.000344	 0.024956	 0.0	 1266	 1266	 1266	 0.942973	 0.0	 1	 -30.0	 30.0;
	6599	 4246	 0.000355	 0.024435	 0.0	 1293	 1293	 1293	 0.942949	 0.0	 1	 -30.0	 30.0;
	5623	 459	 0.000386	 0.026392	 0.0	 1197	 1197	 1197	 0.931256	 0.0	 1	 -30.0	 30.0;
	8232	 459	 0.000365	 0.025525	 0.0	 1238	 1238	 1238	 0.928969	 0.0	 1	 -30.0	 30.0;
	2467	 169	 0.000344	 0.029986	 0.0	 1054	 1054	 1054	 0.938164	 0.0	 1	 -30.0	 30.0;
	2467	 169	 0.000323	 0.029838	 0.0	 1059	 1059	 1059	 0.938248	 0.0	 1	 -30.0	 30.0;
	3891	 8318	 0.000323	 0.02748	 0.0	 1150	 1150	 1150	 0.933289	 0.0	 1	 -30.0	 30.0;
	3891	 8318	 0.000313	 0.028001	 0.0	 1129	 1129	 1129	 0.933329	 0.0	 1	 -30.0	 30.0;
	634	 4730	 0.000179	 0.012988	 0.0	 2432	 2432	 2432	 0.997782	 0.0	 1	 -30.0	 30.0;
	634	 10310	 0.000198	 0.012724	 0.0	 2483	 2483	 2483	 0.994148	 0.0	 1	 -30.0	 30.0;
	634	 3428	 0.000207	 0.012469	 0.0	 2533	 2533	 2533	 0.994117	 0.0	 1	 -30.0	 30.0;
	634	 2710	 0.000207	 0.012206	 0.0	 2588	 2588	 2588	 0.99408	 0.0	 1	 -30.0	 30.0;
	634	 4980	 0.000217	 0.012912	 0.0	 2447	 2447	 2447	 0.99109	 0.0	 1	 -30.0	 30.0;
	634	 8350	 0.000217	 0.012627	 0.0	 2502	 2502	 2502	 0.99109	 0.0	 1	 -30.0	 30.0;
	634	 4502	 0.000198	 0.014317	 0.0	 2207	 2207	 2207	 0.991478	 0.0	 1	 -30.0	 30.0;
	634	 4502	 0.000189	 0.014592	 0.0	 2165	 2165	 2165	 0.991479	 0.0	 1	 -30.0	 30.0;
	634	 11544	 0.000354	 0.02725	 0.0	 1160	 1160	 1160	 0.96645	 0.0	 1	 -30.0	 30.0;
	1356	 12535	 0.000628	 0.042428	 0.0	 745	 745	 745	 1.009174	 0.0	 1	 -30.0	 30.0;
	1356	 12535	 0.000726	 0.044039	 0.0	 718	 718	 718	 0.982143	 0.0	 1	 -30.0	 30.0;
	5249	 8605	 0.000365	 0.024893	 0.0	 1269	 1269	 1269	 0.95138	 0.0	 1	 -30.0	 30.0;
	5249	 8605	 0.000438	 0.02457	 0.0	 1286	 1286	 1286	 0.951402	 0.0	 1	 -30.0	 30.0;
	5249	 8605	 0.000365	 0.023986	 0.0	 1317	 1317	 1317	 0.9518	 0.0	 1	 -30.0	 30.0;
	13130	 8620	 0.000375	 0.023267	 0.0	 1358	 1358	 1358	 0.955216	 0.0	 1	 -30.0	 30.0;
	13130	 8620	 0.000323	 0.026375	 0.0	 1198	 1198	 1198	 0.954101	 0.0	 1	 -30.0	 30.0;
	2564	 3540	 0.000334	 0.029735	 0.0	 1063	 1063	 1063	 0.929892	 0.0	 1	 -30.0	 30.0;
	2564	 3540	 0.000313	 0.030237	 0.0	 1045	 1045	 1045	 0.930119	 0.0	 1	 -30.0	 30.0;
	4880	 3018	 0.000767	 0.044049	 0.0	 717	 717	 717	 0.982143	 0.0	 1	 -30.0	 30.0;
	4880	 3018	 0.000302	 0.026072	 0.0	 1212	 1212	 1212	 0.940778	 0.0	 1	 -30.0	 30.0;
	4880	 3018	 0.00085	 0.039892	 0.0	 792	 792	 792	 0.982143	 0.0	 1	 -30.0	 30.0;
	3448	 13294	 0.000344	 0.024956	 0.0	 1266	 1266	 1266	 0.969247	 0.0	 1	 -30.0	 30.0;
	13152	 13294	 0.000334	 0.026666	 0.0	 1185	 1185	 1185	 0.935423	 0.0	 1	 -30.0	 30.0;
	2961	 7229	 0.000365	 0.023788	 0.0	 1328	 1328	 1328	 0.957187	 0.0	 1	 -30.0	 30.0;
	2961	 7229	 0.000365	 0.023465	 0.0	 1346	 1346	 1346	 0.957349	 0.0	 1	 -30.0	 30.0;
	326	 2206	 0.000334	 0.026447	 0.0	 1195	 1195	 1195	 0.942707	 0.0	 1	 -30.0	 30.0;
	5846	 7838	 0.000323	 0.027042	 0.0	 1169	 1169	 1169	 0.941267	 0.0	 1	 -30.0	 30.0;
	5846	 7838	 0.000313	 0.02748	 0.0	 1150	 1150	 1150	 0.94124	 0.0	 1	 -30.0	 30.0;
	5846	 7838	 0.000302	 0.028314	 0.0	 1116	 1116	 1116	 0.94117	 0.0	 1	 -30.0	 30.0;
	5846	 10989	 0.000323	 0.025853	 0.0	 1222	 1222	 1222	 0.943398	 0.0	 1	 -30.0	 30.0;
	5846	 10989	 0.000365	 0.026197	 0.0	 1206	 1206	 1206	 0.943251	 0.0	 1	 -30.0	 30.0;
	5846	 10989	 0.000365	 0.025165	 0.0	 1256	 1256	 1256	 0.943464	 0.0	 1	 -30.0	 30.0;
	8070	 7112	 0.000355	 0.024237	 0.0	 1304	 1304	 1304	 0.955747	 0.0	 1	 -30.0	 30.0;
	8070	 2866	 0.000375	 0.024247	 0.0	 1303	 1303	 1303	 0.94273	 0.0	 1	 -30.0	 30.0;
	3090	 7112	 0.000365	 0.023267	 0.0	 1358	 1358	 1358	 0.956532	 0.0	 1	 -30.0	 30.0;
	3090	 2866	 0.000342	 0.023139	 0.0	 1365	 1365	 1365	 0.982143	 0.0	 1	 -30.0	 30.0;
	2348	 8175	 0.000344	 0.026666	 0.0	 1185	 1185	 1185	 0.956163	 0.0	 1	 -30.0	 30.0;
	2348	 1000	 0.000334	 0.027021	 0.0	 1169	 1169	 1169	 0.946614	 0.0	 1	 -30.0	 30.0;
	1158	 8175	 0.000302	 0.027615	 0.0	 1144	 1144	 1144	 0.955743	 0.0	 1	 -30.0	 30.0;
	1158	 1000	 0.000313	 0.026135	 0.0	 1209	 1209	 1209	 0.946825	 0.0	 1	 -30.0	 30.0;
	6736	 13022	 0.000365	 0.025905	 0.0	 1220	 1220	 1220	 0.942272	 0.0	 1	 -30.0	 30.0;
	6736	 13022	 0.000355	 0.025238	 0.0	 1252	 1252	 1252	 0.942404	 0.0	 1	 -30.0	 30.0;
	4194	 6189	 0.000334	 0.026814	 0.0	 1178	 1178	 1178	 0.93534	 0.0	 1	 -30.0	 30.0;
	1639	 9626	 0.001242	 0.083148	 0.0	 380	 380	 380	 0.945477	 0.0	 1	 -30.0	 30.0;
	1639	 6077	 0.0017	 0.090508	 0.0	 349	 349	 349	 0.945477	 0.0	 1	 -30.0	 30.0;
	2753	 3087	 0.001648	 0.071935	 0.0	 528	 528	 528	 1.018675	 0.0	 1	 -30.0	 30.0;
	2753	 9433	 0.001742	 0.073131	 0.0	 519	 519	 519	 0.999333	 0.0	 1	 -30.0	 30.0;
	237	 11610	 0.000914	 0.088676	 0.0	 357	 357	 357	 0.986842	 0.0	 1	 -30.0	 30.0;
	237	 7510	 0.000955	 0.085404	 0.0	 370	 370	 370	 0.986842	 0.0	 1	 -30.0	 30.0;
	2551	 5694	 0.001479	 0.088626	 0.0	 429	 429	 429	 0.986842	 0.0	 1	 -30.0	 30.0;
	2551	 6184	 0.00153	 0.084928	 0.0	 447	 447	 447	 0.986842	 0.0	 1	 -30.0	 30.0;
	10587	 8940	 0.00151	 0.102577	 0.0	 370	 370	 370	 0.945477	 0.0	 1	 -30.0	 30.0;
	12028	 3629	 0.000884	 0.108054	 0.0	 352	 352	 352	 0.945477	 0.0	 1	 -30.0	 30.0;
	12488	 2856	 0.001413	 0.034472	 0.0	 1100	 1100	 1100	 1.053539	 0.0	 1	 -30.0	 30.0;
	12293	 8073	 0.001099	 0.069265	 0.0	 548	 548	 548	 1.018675	 0.0	 1	 -30.0	 30.0;
	105	 5239	 0.000904	 0.088121	 0.0	 431	 431	 431	 0.986842	 0.0	 1	 -30.0	 30.0;
	6381	 4100	 0.001386	 0.094158	 0.0	 403	 403	 403	 0.986842	 0.0	 1	 -30.0	 30.0;
	6381	 4100	 0.001355	 0.096007	 0.0	 396	 396	 396	 0.986842	 0.0	 1	 -30.0	 30.0;
	7298	 1671	 0.001456	 0.098925	 0.0	 384	 384	 384	 0.962772	 0.0	 1	 -30.0	 30.0;
	7298	 1671	 0.001424	 0.100867	 0.0	 377	 377	 377	 0.962772	 0.0	 1	 -30.0	 30.0;
	2812	 2545	 0.001442	 0.086424	 0.0	 439	 439	 439	 0.999333	 0.0	 1	 -30.0	 30.0;
	1624	 12444	 0.001317	 0.070127	 0.0	 541	 541	 541	 1.074114	 0.0	 1	 -30.0	 30.0;
	884	 3755	 0.000991	 0.083602	 0.0	 454	 454	 454	 0.999333	 0.0	 1	 -30.0	 30.0;
	884	 3755	 0.001272	 0.097228	 0.0	 391	 391	 391	 0.999333	 0.0	 1	 -30.0	 30.0;
	884	 10166	 0.000968	 0.088836	 0.0	 424	 424	 424	 0.974659	 0.0	 1	 -30.0	 30.0;
	884	 10166	 0.001537	 0.08896	 0.0	 423	 423	 423	 0.974659	 0.0	 1	 -30.0	 30.0;
	884	 10166	 0.0018	 0.078579	 0.0	 479	 479	 479	 0.974659	 0.0	 1	 -30.0	 30.0;
	642	 3703	 0.001071	 0.079233	 0.0	 479	 479	 479	 0.999333	 0.0	 1	 -30.0	 30.0;
	8575	 5752	 0.001301	 0.088365	 0.0	 430	 430	 430	 1.018675	 0.0	 1	 -30.0	 30.0;
	8575	 7023	 0.001436	 0.082886	 0.0	 454	 454	 454	 1.018675	 0.0	 1	 -30.0	 30.0;
	8575	 5355	 0.001701	 0.102782	 0.0	 370	 370	 370	 0.923361	 0.0	 1	 -30.0	 30.0;
	10290	 12950	 0.001352	 0.091819	 0.0	 414	 414	 414	 0.999333	 0.0	 1	 -30.0	 30.0;
	2194	 2805	 0.001737	 0.085791	 0.0	 369	 369	 369	 0.962772	 0.0	 1	 -30.0	 30.0;
	2194	 4579	 0.001331	 0.087657	 0.0	 361	 361	 361	 0.945477	 0.0	 1	 -30.0	 30.0;
	2194	 2805	 0.001877	 0.07879	 0.0	 401	 401	 401	 0.962772	 0.0	 1	 -30.0	 30.0;
	2194	 3263	 0.001672	 0.089295	 0.0	 354	 354	 354	 0.962772	 0.0	 1	 -30.0	 30.0;
	2194	 4579	 0.001421	 0.10862	 0.0	 291	 291	 291	 0.945477	 0.0	 1	 -30.0	 30.0;
	2194	 3263	 0.001338	 0.09699	 0.0	 326	 326	 326	 0.962772	 0.0	 1	 -30.0	 30.0;
	4404	 7520	 0.001224	 0.093571	 0.0	 406	 406	 406	 1.018675	 0.0	 1	 -30.0	 30.0;
	2850	 3660	 0.001667	 0.092522	 0.0	 342	 342	 342	 0.945477	 0.0	 1	 -30.0	 30.0;
	2850	 1540	 0.0017	 0.090508	 0.0	 349	 349	 349	 0.945477	 0.0	 1	 -30.0	 30.0;
	4111	 5040	 0.001177	 0.089984	 0.0	 422	 422	 422	 1.038781	 0.0	 1	 -30.0	 30.0;
	8853	 9985	 0.000976	 0.083762	 0.0	 453	 453	 453	 0.986842	 0.0	 1	 -30.0	 30.0;
	8853	 3269	 0.001221	 0.074424	 0.0	 510	 510	 510	 0.974659	 0.0	 1	 -30.0	 30.0;
	7622	 12284	 0.001205	 0.088315	 0.0	 358	 358	 358	 1.038781	 0.0	 1	 -30.0	 30.0;
	4835	 6198	 0.000951	 0.081618	 0.0	 387	 387	 387	 0.999333	 0.0	 1	 -30.0	 30.0;
	4835	 8670	 0.0011	 0.085679	 0.0	 369	 369	 369	 0.962772	 0.0	 1	 -30.0	 30.0;
	4835	 8670	 0.000895	 0.099866	 0.0	 317	 317	 317	 0.962772	 0.0	 1	 -30.0	 30.0;
	6583	 12130	 0.0	 0.064	 0.0	 494	 494	 494	 0.955796	 0.0	 1	 -30.0	 30.0;
	6583	 12130	 0.0	 0.06267	 0.0	 505	 505	 505	 0.95527	 0.0	 1	 -30.0	 30.0;
	6583	 12130	 0.0	 0.06134	 0.0	 515	 515	 515	 0.954721	 0.0	 1	 -30.0	 30.0;
	2245	 6732	 0.0	 0.06295	 0.0	 502	 502	 502	 0.983015	 0.0	 1	 -30.0	 30.0;
	2245	 6732	 0.0	 0.07135	 0.0	 443	 443	 443	 0.982368	 0.0	 1	 -30.0	 30.0;
	4642	 2855	 0.0	 0.04729	 0.0	 803	 803	 803	 1.012296	 0.0	 1	 -30.0	 30.0;
	4642	 2855	 0.0	 0.0482	 0.0	 788	 788	 788	 1.013058	 0.0	 1	 -30.0	 30.0;
	4642	 2855	 0.0	 0.04911	 0.0	 773	 773	 773	 1.013799	 0.0	 1	 -30.0	 30.0;
	4915	 13255	 0.0	 0.06744	 0.0	 469	 469	 469	 0.990953	 0.0	 1	 -30.0	 30.0;
	11209	 1067	 0.0	 0.145661	 0.0	 217	 217	 217	 1.052174	 0.0	 1	 -30.0	 30.0;
	13272	 7347	 0.0	 0.03024	 0.0	 1045	 1045	 1045	 1.052632	 0.0	 1	 -30.0	 30.0;
	13272	 7347	 0.0	 0.029729	 0.0	 1063	 1063	 1063	 1.052632	 0.0	 1	 -30.0	 30.0;
	7347	 10395	 0.0	 0.07191	 0.0	 440	 440	 440	 0.965461	 0.0	 1	 -30.0	 30.0;
	7347	 10395	 0.0	 0.0815	 0.0	 388	 388	 388	 0.967264	 0.0	 1	 -30.0	 30.0;
	13415	 4035	 0.0	 0.07843	 0.0	 403	 403	 403	 0.952986	 0.0	 1	 -30.0	 30.0;
	3592	 8015	 0.0	 0.033891	 0.0	 933	 933	 933	 1.052632	 0.0	 1	 -30.0	 30.0;
	3592	 8015	 0.0	 0.035419	 0.0	 892	 892	 892	 1.052632	 0.0	 1	 -30.0	 30.0;
	8015	 11628	 0.0	 0.07323	 0.0	 432	 432	 432	 0.960506	 0.0	 1	 -30.0	 30.0;
	8015	 11628	 0.0	 0.07177	 0.0	 441	 441	 441	 0.961229	 0.0	 1	 -30.0	 30.0;
	8006	 187	 0.0	 0.06789	 0.0	 466	 466	 466	 0.936347	 0.0	 1	 -30.0	 30.0;
	8006	 187	 0.0	 0.06524	 0.0	 485	 485	 485	 0.936691	 0.0	 1	 -30.0	 30.0;
	8006	 187	 0.0	 0.06385	 0.0	 495	 495	 495	 0.936788	 0.0	 1	 -30.0	 30.0;
	3795	 8133	 0.0	 0.04033	 0.0	 941	 941	 941	 1.052174	 0.0	 1	 -30.0	 30.0;
	8002	 5638	 0.0	 0.07024	 0.0	 450	 450	 450	 0.967111	 0.0	 1	 -30.0	 30.0;
	8002	 5638	 0.0	 0.07161	 0.0	 442	 442	 442	 0.966242	 0.0	 1	 -30.0	 30.0;
	9037	 1219	 0.0	 0.06784	 0.0	 466	 466	 466	 1.03429	 0.0	 1	 -30.0	 30.0;
	2132	 9949	 0.0	 0.071916	 0.0	 440	 440	 440	 0.945577	 0.0	 1	 -30.0	 30.0;
	10240	 6720	 0.0	 0.07323	 0.0	 432	 432	 432	 0.985392	 0.0	 1	 -30.0	 30.0;
	10240	 6720	 0.0	 0.07177	 0.0	 441	 441	 441	 0.985537	 0.0	 1	 -30.0	 30.0;
	10347	 2751	 0.0	 0.0447	 0.0	 707	 707	 707	 1.052174	 0.0	 1	 -30.0	 30.0;
	10347	 2751	 0.0	 0.04377	 0.0	 722	 722	 722	 1.052174	 0.0	 1	 -30.0	 30.0;
	10347	 2751	 0.0	 0.04123	 0.0	 767	 767	 767	 1.052174	 0.0	 1	 -30.0	 30.0;
	3423	 11770	 0.0	 0.06295	 0.0	 502	 502	 502	 0.989703	 0.0	 1	 -30.0	 30.0;
	3423	 11770	 0.0	 0.07135	 0.0	 443	 443	 443	 0.986826	 0.0	 1	 -30.0	 30.0;
	8344	 7098	 0.0	 0.07014	 0.0	 451	 451	 451	 0.911963	 0.0	 1	 -30.0	 30.0;
	8344	 7098	 0.0	 0.07149	 0.0	 442	 442	 442	 0.912529	 0.0	 1	 -30.0	 30.0;
	2024	 6485	 0.0	 0.034531	 0.0	 915	 915	 915	 0.973598	 0.0	 1	 -30.0	 30.0;
	2024	 10014	 0.0	 0.04656	 0.0	 679	 679	 679	 0.980849	 0.0	 1	 -30.0	 30.0;
	2024	 10014	 0.0	 0.04563	 0.0	 693	 693	 693	 0.980159	 0.0	 1	 -30.0	 30.0;
	2582	 6459	 0.000229	 0.01234	 0.0	 3074	 3074	 3074	 0.872915	 0.0	 1	 -30.0	 30.0;
	2582	 6459	 0.000229	 0.0122	 0.0	 3110	 3110	 3110	 0.872741	 0.0	 1	 -30.0	 30.0;
	12573	 4076	 0.001485	 0.065805	 0.0	 577	 577	 577	 0.956938	 0.0	 1	 -30.0	 30.0;
	12573	 4076	 0.001583	 0.06586	 0.0	 576	 576	 576	 0.956938	 0.0	 1	 -30.0	 30.0;
	7706	 4076	 0.00175	 0.070701	 0.0	 537	 537	 537	 0.952381	 0.0	 1	 -30.0	 30.0;
	7706	 4076	 0.00169	 0.0715	 0.0	 531	 531	 531	 0.952381	 0.0	 1	 -30.0	 30.0;
	9848	 9665	 0.001228	 0.060916	 0.0	 623	 623	 623	 0.950231	 0.0	 1	 -30.0	 30.0;
	9848	 9665	 0.00116	 0.063798	 0.0	 595	 595	 595	 1.02073	 0.0	 1	 -30.0	 30.0;
	9848	 9665	 0.00113	 0.059295	 0.0	 640	 640	 640	 1.024588	 0.0	 1	 -30.0	 30.0;
	7957	 9665	 0.00177	 0.06853	 0.0	 461	 461	 461	 0.93473	 0.0	 1	 -30.0	 30.0;
	10922	 3077	 0.001363	 0.063835	 0.0	 495	 495	 495	 0.990157	 0.0	 1	 -30.0	 30.0;
	10922	 3077	 0.001457	 0.067155	 0.0	 471	 471	 471	 0.987625	 0.0	 1	 -30.0	 30.0;
	13262	 3077	 0.00193	 0.06377	 0.0	 496	 496	 496	 0.937593	 0.0	 1	 -30.0	 30.0;
	13262	 3077	 0.00194	 0.06188	 0.0	 511	 511	 511	 0.937259	 0.0	 1	 -30.0	 30.0;
	4348	 7201	 0.00045	 0.02807	 0.0	 1352	 1352	 1352	 1.002506	 0.0	 1	 -30.0	 30.0;
	4348	 3036	 0.00042	 0.028021	 0.0	 1354	 1354	 1354	 1.002506	 0.0	 1	 -30.0	 30.0;
	12666	 8194	 0.001208	 0.06631	 0.0	 567	 567	 567	 1.006816	 0.0	 1	 -30.0	 30.0;
	12666	 8194	 0.001228	 0.066264	 0.0	 568	 568	 568	 1.006868	 0.0	 1	 -30.0	 30.0;
	10686	 4099	 0.00047	 0.026469	 0.0	 1194	 1194	 1194	 1.002506	 0.0	 1	 -30.0	 30.0;
	13229	 10478	 0.00186	 0.06826	 0.0	 556	 556	 556	 0.892378	 0.0	 1	 -30.0	 30.0;
	829	 208	 0.001431	 0.068667	 0.0	 548	 548	 548	 0.956938	 0.0	 1	 -30.0	 30.0;
	829	 208	 0.001529	 0.068787	 0.0	 547	 547	 547	 0.956938	 0.0	 1	 -30.0	 30.0;
	1313	 208	 0.00193	 0.06377	 0.0	 595	 595	 595	 0.952381	 0.0	 1	 -30.0	 30.0;
	1313	 208	 0.00194	 0.06188	 0.0	 613	 613	 613	 0.952381	 0.0	 1	 -30.0	 30.0;
	4899	 7506	 0.0	 0.00898	 0.0	 3518	 3518	 3518	 0.0	 0.0	 1	 -30.0	 30.0;
	3705	 9266	 0.0	 0.00433	 0.0	 7295	 7295	 7295	 0.0	 0.0	 1	 -30.0	 30.0;
	9266	 7058	 0.007955	 0.151636	 0.0	 250	 250	 250	 0.929293	 0.0	 1	 -30.0	 30.0;
	10740	 6332	 0.000271	 0.030694	 0.0	 1030	 1030	 1030	 1.052632	 0.0	 1	 -30.0	 30.0;
	10740	 6332	 0.000271	 0.02842	 0.0	 1112	 1112	 1112	 1.052632	 0.0	 1	 -30.0	 30.0;
	7434	 6145	 0.00064	 0.0518	 0.0	 610	 610	 610	 0.0	 0.0	 1	 -30.0	 30.0;
	8840	 8919	 0.00072	 0.05075	 0.0	 623	 623	 623	 0.0	 0.0	 1	 -30.0	 30.0;
	2519	 12023	 0.0	 0.23657	 0.0	 134	 134	 134	 0.0	 0.0	 1	 -30.0	 30.0;
	12587	 10646	 0.0	 0.020113	 0.0	 1571	 1571	 1571	 1.006865	 0.0	 1	 -30.0	 30.0;
	12587	 9197	 0.0	 0.019669	 0.0	 1606	 1606	 1606	 1.006865	 0.0	 1	 -30.0	 30.0;
	5232	 9683	 0.000325	 0.028508	 0.0	 1108	 1108	 1108	 1.006865	 0.0	 1	 -30.0	 30.0;
	5232	 9683	 0.000316	 0.031545	 0.0	 1002	 1002	 1002	 1.006865	 0.0	 1	 -30.0	 30.0;
	13516	 9007	 0.000355	 0.023171	 0.0	 1364	 1364	 1364	 1.006865	 0.0	 1	 -30.0	 30.0;
	3949	 2083	 0.000296	 0.032897	 0.0	 961	 961	 961	 1.006865	 0.0	 1	 -30.0	 30.0;
	3949	 2083	 0.000296	 0.030461	 0.0	 1037	 1037	 1037	 1.006865	 0.0	 1	 -30.0	 30.0;
	6957	 3	 5.9e-05	 0.022767	 0.0	 1388	 1388	 1388	 1.006865	 0.0	 1	 -30.0	 30.0;
	1541	 9070	 0.000335	 0.029237	 0.0	 1081	 1081	 1081	 1.006865	 0.0	 1	 -30.0	 30.0;
	8349	 13406	 0.000385	 0.027846	 0.0	 1135	 1135	 1135	 1.006865	 0.0	 1	 -30.0	 30.0;
	10467	 10025	 0.000444	 0.020064	 0.0	 1574	 1574	 1574	 1.006865	 0.0	 1	 -30.0	 30.0;
	12345	 60	 0.00033	 0.02558	 0.0	 1235	 1235	 1235	 1.0	 0.0	 1	 -30.0	 30.0;
	11181	 9338	 0.0	 0.026909	 0.0	 1174	 1174	 1174	 0.0	 0.0	 1	 -30.0	 30.0;
	10714	 11027	 0.000385	 0.022737	 0.0	 1390	 1390	 1390	 1.006865	 0.0	 1	 -30.0	 30.0;
	4421	 1028	 0.000375	 0.022441	 0.0	 1408	 1408	 1408	 1.006865	 0.0	 1	 -30.0	 30.0;
	11639	 8959	 -0.002742	 0.00908	 0.0	 3331	 3331	 3331	 0.0	 0.0	 1	 -30.0	 30.0;
	11639	 13350	 -0.00268	 0.00837	 0.0	 3595	 3595	 3595	 0.0	 0.0	 1	 -30.0	 30.0;
	11639	 10040	 -0.00304	 0.00824	 0.0	 3597	 3597	 3597	 0.0	 0.0	 1	 -30.0	 30.0;
	10548	 7864	 -0.003927	 0.00795	 0.0	 3563	 3563	 3563	 0.0	 0.0	 1	 -30.0	 30.0;
	10548	 21	 -0.00401	 0.00794	 0.0	 3552	 3552	 3552	 0.0	 0.0	 1	 -30.0	 30.0;
	6756	 13304	 0.0	 0.00765	 0.0	 4130	 4130	 4130	 0.0	 0.0	 1	 -30.0	 30.0;
	6756	 2211	 0.0	 0.00748	 0.0	 4223	 4223	 4223	 0.0	 0.0	 1	 -30.0	 30.0;
	10793	 2588	 -0.000111	 0.00565	 0.0	 5590	 5590	 5590	 0.0	 0.0	 1	 -30.0	 30.0;
	10793	 5916	 -0.000339	 0.00645	 0.0	 4891	 4891	 4891	 0.0	 0.0	 1	 -30.0	 30.0;
	10793	 8502	 -0.000332	 0.00657	 0.0	 4802	 4802	 4802	 0.0	 0.0	 1	 -30.0	 30.0;
	10793	 6461	 -0.000118	 0.00525	 0.0	 6016	 6016	 6016	 0.0	 0.0	 1	 -30.0	 30.0;
	7092	 9760	 0.00593	 0.0602	 0.0	 523	 523	 523	 0.0	 0.0	 1	 -30.0	 30.0;
	7092	 4687	 8e-05	 0.00811	 0.0	 3895	 3895	 3895	 0.0	 0.0	 1	 -30.0	 30.0;
	7092	 7308	 -0.003927	 0.00835	 0.0	 3424	 3424	 3424	 0.0	 0.0	 1	 -30.0	 30.0;
	3752	 11372	 0.0	 0.028951	 0.0	 1092	 1092	 1092	 1.006865	 0.0	 1	 -30.0	 30.0;
	3752	 2942	 0.0	 0.02833	 0.0	 1115	 1115	 1115	 1.006865	 0.0	 1	 -30.0	 30.0;
	142	 4356	 0.000424	 0.020212	 0.0	 1563	 1563	 1563	 1.006865	 0.0	 1	 -30.0	 30.0;
	6695	 2484	 0.00128	 0.05539	 0.0	 571	 571	 571	 0.0	 0.0	 1	 -30.0	 30.0;
	6695	 8104	 0.00126	 0.056469	 0.0	 560	 560	 560	 0.0	 0.0	 1	 -30.0	 30.0;
	6695	 5995	 0.00123	 0.05756	 0.0	 549	 549	 549	 0.0	 0.0	 1	 -30.0	 30.0;
	2089	 434	 0.0	 0.046831	 0.0	 675	 675	 675	 0.0	 0.0	 1	 -30.0	 30.0;
	4515	 1102	 0.0	 0.03197	 0.0	 989	 989	 989	 1.006865	 0.0	 1	 -30.0	 30.0;
	7461	 10383	 0.0	 0.027151	 0.0	 1164	 1164	 1164	 1.044622	 0.0	 1	 -30.0	 30.0;
	5447	 1299	 0.0	 0.0197	 0.0	 1604	 1604	 1604	 0.0	 0.0	 1	 -30.0	 30.0;
	10618	 6282	 0.000335	 0.028458	 0.0	 1110	 1110	 1110	 1.006865	 0.0	 1	 -30.0	 30.0;
	10618	 6282	 0.000375	 0.027846	 0.0	 1135	 1135	 1135	 1.006865	 0.0	 1	 -30.0	 30.0;
	12414	 1676	 0.00073	 0.01489	 0.0	 2119	 2119	 2119	 0.0	 0.0	 1	 -30.0	 30.0;
	10553	 12002	 0.0	 0.00864	 0.0	 3656	 3656	 3656	 0.0	 0.0	 1	 -30.0	 30.0;
	10553	 1931	 0.0	 0.00881	 0.0	 3586	 3586	 3586	 0.0	 0.0	 1	 -30.0	 30.0;
	10525	 2899	 0.000325	 0.028961	 0.0	 1091	 1091	 1091	 1.006865	 0.0	 1	 -30.0	 30.0;
	4628	 11452	 0.000296	 0.025084	 0.0	 1260	 1260	 1260	 1.006865	 0.0	 1	 -30.0	 30.0;
	10874	 10969	 0.000325	 0.025765	 0.0	 1226	 1226	 1226	 1.006865	 0.0	 1	 -30.0	 30.0;
	10874	 10969	 0.000375	 0.020301	 0.0	 1556	 1556	 1556	 1.006865	 0.0	 1	 -30.0	 30.0;
	10874	 10969	 0.000345	 0.021109	 0.0	 1497	 1497	 1497	 1.006865	 0.0	 1	 -30.0	 30.0;
	4486	 183	 0.000385	 0.02101	 0.0	 1504	 1504	 1504	 1.006865	 0.0	 1	 -30.0	 30.0;
	2297	 11100	 0.000424	 0.019472	 0.0	 1622	 1622	 1622	 1.006865	 0.0	 1	 -30.0	 30.0;
	2297	 11100	 0.000434	 0.019048	 0.0	 1658	 1658	 1658	 1.006865	 0.0	 1	 -30.0	 30.0;
	1309	 6384	 0.000325	 0.025637	 0.0	 1233	 1233	 1233	 1.006865	 0.0	 1	 -30.0	 30.0;
	1309	 6384	 0.000355	 0.026564	 0.0	 1189	 1189	 1189	 1.006865	 0.0	 1	 -30.0	 30.0;
	11460	 6574	 0.000355	 0.021553	 0.0	 1466	 1466	 1466	 1.006865	 0.0	 1	 -30.0	 30.0;
	11460	 6574	 0.000128	 0.022007	 0.0	 1436	 1436	 1436	 1.006865	 0.0	 1	 -30.0	 30.0;
	1186	 437	 6e-05	 0.00994	 0.0	 3178	 3178	 3178	 0.979973	 0.200467	 1	 -30.0	 30.0;
	12182	 437	 7e-05	 0.009939	 0.0	 3179	 3179	 3179	 0.977987	 0.210204	 1	 -30.0	 30.0;
	437	 1487	 0.000395	 0.021454	 0.0	 1473	 1473	 1473	 1.006865	 0.0	 1	 -30.0	 30.0;
	9642	 4794	 -0.000388	 0.0074	 0.0	 4263	 4263	 4263	 0.0	 0.0	 1	 -30.0	 30.0;
	3331	 7406	 -0.000402	 0.00724	 0.0	 4357	 4357	 4357	 0.0	 0.0	 1	 -30.0	 30.0;
	7482	 2310	 -0.000589	 0.01411	 0.0	 2237	 2237	 2237	 0.0	 0.0	 1	 -30.0	 30.0;
	4882	 11681	 -0.00036	 0.00803	 0.0	 3930	 3930	 3930	 0.0	 0.0	 1	 -30.0	 30.0;
	12148	 9303	 0.0	 0.040449	 0.0	 781	 781	 781	 0.956938	 0.0	 1	 -30.0	 30.0;
	5827	 7994	 0.000345	 0.026071	 0.0	 1212	 1212	 1212	 1.006865	 0.0	 1	 -30.0	 30.0;
	3777	 12047	 0.0	 0.00046	 0.0	 68669	 68669	 68669	 0.0	 0.0	 1	 -30.0	 30.0;
	3777	 10091	 0.0	 0.00043	 0.0	 73459	 73459	 73459	 0.0	 0.0	 1	 -30.0	 30.0;
	1233	 2661	 0.000375	 0.022007	 0.0	 1436	 1436	 1436	 1.006865	 0.0	 1	 -30.0	 30.0;
	1332	 10853	 0.000385	 0.020196	 0.0	 1564	 1564	 1564	 0.993901	 0.0	 1	 -30.0	 30.0;
	7797	 10325	 0.000375	 0.026624	 0.0	 1187	 1187	 1187	 0.993901	 0.0	 1	 -30.0	 30.0;
	6482	 2017	 0.000425	 0.021208	 0.0	 1490	 1490	 1490	 0.993901	 0.0	 1	 -30.0	 30.0;
	11938	 3830	 0.000466	 0.020185	 0.0	 1565	 1565	 1565	 0.993901	 0.0	 1	 -30.0	 30.0;
	5689	 2300	 0.000324	 0.022139	 0.0	 1427	 1427	 1427	 0.993901	 0.0	 1	 -30.0	 30.0;
	5689	 2300	 0.000324	 0.022706	 0.0	 1392	 1392	 1392	 0.993901	 0.0	 1	 -30.0	 30.0;
	5689	 2300	 0.000314	 0.023142	 0.0	 1365	 1365	 1365	 0.993901	 0.0	 1	 -30.0	 30.0;
	13320	 10730	 0.000344	 0.024832	 0.0	 1272	 1272	 1272	 0.993901	 0.0	 1	 -30.0	 30.0;
	13320	 12508	 0.000334	 0.023071	 0.0	 1369	 1369	 1369	 0.993901	 0.0	 1	 -30.0	 30.0;
	3876	 546	 0.000335	 0.022767	 0.0	 1388	 1388	 1388	 1.006865	 0.0	 1	 -30.0	 30.0;
	3837	 502	 0.00071	 0.030845	 0.0	 1024	 1024	 1024	 1.006865	 0.0	 1	 -30.0	 30.0;
	7796	 10175	 0.000385	 0.019472	 0.0	 1622	 1622	 1622	 1.006865	 0.0	 1	 -30.0	 30.0;
	7796	 6062	 0.000395	 0.019057	 0.0	 1658	 1658	 1658	 1.006865	 0.0	 1	 -30.0	 30.0;
	7796	 1847	 0.000404	 0.018643	 0.0	 1694	 1694	 1694	 1.006865	 0.0	 1	 -30.0	 30.0;
	7796	 7467	 0.0	 0.027866	 0.0	 1134	 1134	 1134	 1.006865	 0.0	 1	 -30.0	 30.0;
	2403	 11071	 0.000325	 0.032245	 0.0	 980	 980	 980	 1.006865	 0.0	 1	 -30.0	 30.0;
	3187	 12549	 0.000365	 0.022599	 0.0	 1398	 1398	 1398	 1.006865	 0.0	 1	 -30.0	 30.0;
	3187	 12549	 0.000355	 0.023023	 0.0	 1372	 1372	 1372	 1.006865	 0.0	 1	 -30.0	 30.0;
	2476	 5906	 0.0	 0.032004	 0.0	 987	 987	 987	 1.045454	 0.0	 1	 -30.0	 30.0;
	330	 5906	 0.00141	 0.091249	 0.0	 347	 347	 347	 0.916326	 -0.411983	 1	 -30.0	 30.0;
	3843	 13428	 0.000434	 0.019018	 0.0	 1661	 1661	 1661	 1.006865	 0.0	 1	 -30.0	 30.0;
	2550	 12979	 0.000404	 0.020497	 0.0	 1541	 1541	 1541	 1.006865	 0.0	 1	 -30.0	 30.0;
	8192	 11171	 0.00074	 0.029553	 0.0	 1069	 1069	 1069	 1.006865	 0.0	 1	 -30.0	 30.0;
	9199	 2407	 0.000454	 0.019669	 0.0	 1606	 1606	 1606	 1.006865	 0.0	 1	 -30.0	 30.0;
	11008	 3901	 0.00206	 0.09005	 0.0	 351	 351	 351	 1.0	 0.0	 1	 -30.0	 30.0;
	4750	 372	 0.00039	 0.03411	 0.0	 1113	 1113	 1113	 1.052632	 0.0	 1	 -30.0	 30.0;
	4750	 372	 0.0004	 0.034469	 0.0	 1101	 1101	 1101	 1.052632	 0.0	 1	 -30.0	 30.0;
	12534	 3174	 0.00183	 0.090471	 0.0	 350	 350	 350	 1.026087	 0.0	 1	 -30.0	 30.0;
	12534	 3174	 0.00187	 0.07429	 0.0	 426	 426	 426	 1.026087	 0.0	 1	 -30.0	 30.0;
	11249	 2674	 0.00077	 0.04355	 0.0	 872	 872	 872	 0.999313	 0.0	 1	 -30.0	 30.0;
	11249	 2674	 0.00077	 0.04266	 0.0	 890	 890	 890	 0.999313	 0.0	 1	 -30.0	 30.0;
	10744	 10278	 0.00116	 0.04106	 0.0	 916	 916	 916	 1.052632	 0.0	 1	 -30.0	 30.0;
	10744	 10278	 0.00118	 0.04119	 0.0	 913	 913	 913	 1.052632	 0.0	 1	 -30.0	 30.0;
	5821	 4247	 0.0012	 0.03931	 0.0	 965	 965	 965	 1.052632	 0.0	 1	 -30.0	 30.0;
	5821	 4247	 0.00107	 0.04567	 0.0	 831	 831	 831	 1.052632	 0.0	 1	 -30.0	 30.0;
	10542	 9615	 0.002282	 0.077224	 0.0	 409	 409	 409	 0.911217	 0.0	 1	 -30.0	 30.0;
	6182	 9615	 0.00102	 0.04862	 0.0	 781	 781	 781	 1.052632	 0.0	 1	 -30.0	 30.0;
	6182	 9615	 0.001	 0.04954	 0.0	 766	 766	 766	 1.052632	 0.0	 1	 -30.0	 30.0;
	4747	 1776	 0.00098	 0.04477	 0.0	 848	 848	 848	 1.052632	 0.0	 1	 -30.0	 30.0;
	4747	 1776	 0.00111	 0.04387	 0.0	 865	 865	 865	 1.052632	 0.0	 1	 -30.0	 30.0;
	494	 8150	 0.00113	 0.04193	 0.0	 905	 905	 905	 1.052632	 0.0	 1	 -30.0	 30.0;
	13118	 5577	 0.002522	 0.074933	 0.0	 422	 422	 422	 1.014981	 0.0	 1	 -30.0	 30.0;
	1974	 7318	 0.001252	 0.073601	 0.0	 430	 430	 430	 0.969039	 0.0	 1	 -30.0	 30.0;
	5189	 7318	 0.001271	 0.072001	 0.0	 439	 439	 439	 0.967402	 0.0	 1	 -30.0	 30.0;
	10030	 8979	 0.000442	 0.040802	 0.0	 775	 775	 775	 0.88875	 0.0	 1	 -30.0	 30.0;
	1155	 12901	 0.00048	 0.041601	 0.0	 760	 760	 760	 0.970291	 0.0	 1	 -30.0	 30.0;
	2493	 10226	 0.000543	 0.04261	 0.0	 742	 742	 742	 1.040113	 0.0	 1	 -30.0	 30.0;
	871	 10226	 0.000534	 0.04342	 0.0	 728	 728	 728	 1.039423	 0.0	 1	 -30.0	 30.0;
	12422	 10224	 0.003895	 0.040564	 0.0	 776	 776	 776	 0.993456	 0.0	 1	 -30.0	 30.0;
	12422	 10224	 0.004413	 0.039762	 0.0	 790	 790	 790	 0.962152	 0.0	 1	 -30.0	 30.0;
	12422	 10224	 0.004498	 0.038954	 0.0	 806	 806	 806	 0.912809	 0.0	 1	 -30.0	 30.0;
	2719	 8098	 0.000621	 0.0376	 0.0	 840	 840	 840	 0.989172	 0.0	 1	 -30.0	 30.0;
	5101	 8098	 0.00063	 0.0368	 0.0	 859	 859	 859	 0.961251	 0.0	 1	 -30.0	 30.0;
	5101	 11519	 0.00064	 0.036	 0.0	 878	 878	 878	 1.032687	 0.0	 1	 -30.0	 30.0;
	424	 5822	 0.000555	 0.040801	 0.0	 775	 775	 775	 0.994301	 0.0	 1	 -30.0	 30.0;
	11893	 2101	 0.000546	 0.0416	 0.0	 760	 760	 760	 0.995285	 0.0	 1	 -30.0	 30.0;
	11893	 11831	 0.000527	 0.0424	 0.0	 745	 745	 745	 0.995648	 0.0	 1	 -30.0	 30.0;
	7325	 1667	 0.000456	 0.043201	 0.0	 732	 732	 732	 0.989708	 0.0	 1	 -30.0	 30.0;
	7325	 1667	 0.000447	 0.040001	 0.0	 790	 790	 790	 0.989326	 0.0	 1	 -30.0	 30.0;
	1289	 1667	 0.000505	 0.039202	 0.0	 806	 806	 806	 0.992153	 0.0	 1	 -30.0	 30.0;
	1289	 1667	 0.000513	 0.038402	 0.0	 823	 823	 823	 0.992281	 0.0	 1	 -30.0	 30.0;
	7067	 6275	 0.000513	 0.037602	 0.0	 840	 840	 840	 0.995172	 0.0	 1	 -30.0	 30.0;
	4355	 6275	 0.00052	 0.036802	 0.0	 859	 859	 859	 0.99467	 0.0	 1	 -30.0	 30.0;
	1592	 6275	 0.000529	 0.036002	 0.0	 878	 878	 878	 0.994917	 0.0	 1	 -30.0	 30.0;
	11934	 9064	 0.000473	 0.040802	 0.0	 775	 775	 775	 0.971823	 0.0	 1	 -30.0	 30.0;
	12977	 9064	 0.000465	 0.041601	 0.0	 760	 760	 760	 0.971689	 0.0	 1	 -30.0	 30.0;
	5967	 9165	 7e-05	 0.021201	 0.0	 1790	 1790	 1790	 0.962697	 0.0	 1	 -30.0	 30.0;
	2853	 6373	 7e-05	 0.021599	 0.0	 1757	 1757	 1757	 0.955482	 0.0	 1	 -30.0	 30.0;
	7545	 4906	 0.00054	 0.04	 0.0	 790	 790	 790	 0.98421	 0.0	 1	 -30.0	 30.0;
	7545	 4906	 0.000472	 0.039202	 0.0	 806	 806	 806	 1.053753	 0.0	 1	 -30.0	 30.0;
	3892	 4906	 0.00048	 0.038402	 0.0	 823	 823	 823	 1.042821	 0.0	 1	 -30.0	 30.0;
	3892	 4906	 0.00064	 0.0376	 0.0	 840	 840	 840	 0.98421	 0.0	 1	 -30.0	 30.0;
	2269	 11567	 0.000333	 0.029441	 0.0	 1073	 1073	 1073	 0.982097	 0.0	 1	 -30.0	 30.0;
	8081	 12550	 0.000353	 0.028801	 0.0	 1097	 1097	 1097	 0.925857	 0.0	 1	 -30.0	 30.0;
	8081	 12550	 0.000312	 0.032641	 0.0	 968	 968	 968	 0.991744	 0.0	 1	 -30.0	 30.0;
	2409	 13039	 0.000529	 0.041601	 0.0	 760	 760	 760	 0.955654	 0.0	 1	 -30.0	 30.0;
	1593	 13039	 0.000511	 0.042401	 0.0	 745	 745	 745	 0.96444	 0.0	 1	 -30.0	 30.0;
	12369	 11060	 0.000633	 0.051521	 0.0	 614	 614	 614	 0.989866	 0.0	 1	 -30.0	 30.0;
	12369	 11060	 0.000616	 0.047701	 0.0	 663	 663	 663	 0.969648	 0.0	 1	 -30.0	 30.0;
	1112	 11060	 0.000701	 0.046752	 0.0	 676	 676	 676	 0.97025	 0.0	 1	 -30.0	 30.0;
	4743	 8827	 0.000811	 0.04579	 0.0	 690	 690	 690	 0.937412	 0.0	 1	 -30.0	 30.0;
	547	 8827	 0.000831	 0.04484	 0.0	 705	 705	 705	 0.936876	 0.0	 1	 -30.0	 30.0;
	547	 8827	 0.000841	 0.043881	 0.0	 720	 720	 720	 0.935984	 0.0	 1	 -30.0	 30.0;
	8845	 10912	 0.000621	 0.036001	 0.0	 878	 878	 878	 1.032266	 0.0	 1	 -30.0	 30.0;
	8845	 9802	 0.000555	 0.040801	 0.0	 775	 775	 775	 1.023829	 0.0	 1	 -30.0	 30.0;
	11660	 5649	 0.000563	 0.0416	 0.0	 760	 760	 760	 1.022087	 0.0	 1	 -30.0	 30.0;
	2553	 1456	 0.000543	 0.0424	 0.0	 745	 745	 745	 0.946093	 0.0	 1	 -30.0	 30.0;
	11313	 1848	 0.001026	 0.086398	 0.0	 366	 366	 366	 0.955665	 0.0	 1	 -30.0	 30.0;
	199	 1848	 0.001007	 0.080001	 0.0	 395	 395	 395	 0.951634	 0.0	 1	 -30.0	 30.0;
	4653	 2386	 0.000522	 0.039201	 0.0	 806	 806	 806	 1.00279	 0.0	 1	 -30.0	 30.0;
	8261	 2386	 0.00053	 0.038401	 0.0	 823	 823	 823	 1.006204	 0.0	 1	 -30.0	 30.0;
	6366	 2386	 0.000548	 0.037601	 0.0	 840	 840	 840	 0.85156	 0.0	 1	 -30.0	 30.0;
	7003	 2792	 3e-05	 0.00853	 0.0	 3704	 3704	 3704	 0.902577	 0.445071	 1	 -30.0	 30.0;
	6333	 6307	 0.000907	 0.042929	 0.0	 736	 736	 736	 0.978955	 0.0	 1	 -30.0	 30.0;
	10205	 6237	 7.7e-05	 0.0204	 0.0	 1860	 1860	 1860	 1.114721	 0.0	 1	 -30.0	 30.0;
	8646	 10205	 3e-05	 0.00975	 0.0	 3892	 3892	 3892	 0.902577	 0.445071	 1	 -30.0	 30.0;
	6237	 6307	 0.000773	 0.05056	 0.0	 625	 625	 625	 0.986156	 0.0	 1	 -30.0	 30.0;
	8593	 3890	 0.000728	 0.043197	 0.0	 732	 732	 732	 1.041291	 0.0	 1	 -30.0	 30.0;
	616	 367	 0.000447	 0.040001	 0.0	 790	 790	 790	 1.042918	 0.0	 1	 -30.0	 30.0;
	13170	 8819	 0.00061	 0.0392	 0.0	 806	 806	 806	 1.01718	 0.0	 1	 -30.0	 30.0;
	7752	 12831	 0.001203	 0.076801	 0.0	 412	 412	 412	 0.986892	 0.0	 1	 -30.0	 30.0;
	13242	 12831	 0.001223	 0.075201	 0.0	 420	 420	 420	 0.987006	 0.0	 1	 -30.0	 30.0;
	11462	 10336	 0.004533	 0.037356	 0.0	 840	 840	 840	 0.99379	 0.0	 1	 -30.0	 30.0;
	8768	 520	 0.004615	 0.036549	 0.0	 858	 858	 858	 0.99232	 0.0	 1	 -30.0	 30.0;
	9879	 2388	 0.004113	 0.041392	 0.0	 760	 760	 760	 0.993178	 0.0	 1	 -30.0	 30.0;
	5998	 10902	 0.000627	 0.041599	 0.0	 760	 760	 760	 1.044268	 0.0	 1	 -30.0	 30.0;
	1508	 12184	 0.001048	 0.084802	 0.0	 373	 373	 373	 1.000584	 0.0	 1	 -30.0	 30.0;
	5693	 12184	 0.001029	 0.086397	 0.0	 366	 366	 366	 1.000869	 0.0	 1	 -30.0	 30.0;
	113	 7789	 0.000808	 0.047709	 0.0	 662	 662	 662	 1.052369	 0.0	 1	 -30.0	 30.0;
	6578	 4321	 0.00061	 0.0392	 0.0	 806	 806	 806	 0.989376	 0.0	 1	 -30.0	 30.0;
	6578	 4321	 0.00062	 0.0384	 0.0	 823	 823	 823	 0.989186	 0.0	 1	 -30.0	 30.0;
	9167	 4321	 0.00064	 0.0376	 0.0	 840	 840	 840	 0.993068	 0.0	 1	 -30.0	 30.0;
	583	 8829	 0.00063	 0.0368	 0.0	 859	 859	 859	 0.968844	 0.0	 1	 -30.0	 30.0;
	8504	 7652	 0.00064	 0.036	 0.0	 878	 878	 878	 1.024568	 0.0	 1	 -30.0	 30.0;
	8504	 7652	 0.000573	 0.0408	 0.0	 775	 775	 775	 0.979515	 0.0	 1	 -30.0	 30.0;
	9483	 3555	 0.001067	 0.083199	 0.0	 380	 380	 380	 1.003168	 0.0	 1	 -30.0	 30.0;
	7724	 3555	 0.001048	 0.084802	 0.0	 373	 373	 373	 1.001883	 0.0	 1	 -30.0	 30.0;
	2040	 9145	 6e-05	 0.11487	 0.0	 275	 275	 275	 1.0	 0.0	 1	 -30.0	 30.0;
	6805	 9145	 0.20187	 1.758347	 0.0	 18	 18	 18	 1.0	 0.0	 1	 -30.0	 30.0;
	9356	 5651	 0.03911	 0.342562	 0.0	 92	 92	 92	 1.0	 0.0	 1	 -30.0	 30.0;
	4318	 6737	 0.01564	 0.58593	 0.0	 54	 54	 54	 1.0	 0.0	 1	 -30.0	 30.0;
	4318	 6716	 -0.000248	 0.227727	 0.0	 139	 139	 139	 1.0	 0.0	 1	 -30.0	 30.0;
	13169	 1379	 0.01414	 0.513223	 0.0	 62	 62	 62	 1.0	 0.0	 1	 -30.0	 30.0;
	5421	 1379	 -0.007335	 0.347624	 0.0	 91	 91	 91	 1.0	 0.0	 1	 -30.0	 30.0;
	8011	 1379	 -0.006901	 0.404112	 0.0	 79	 79	 79	 1.0	 0.0	 1	 -30.0	 30.0;
	11162	 5015	 0.051021	 0.452583	 0.0	 70	 70	 70	 1.0	 0.0	 1	 -30.0	 30.0;
	5572	 933	 0.586797	 1.843698	 0.0	 17	 17	 17	 1.0	 0.0	 1	 -30.0	 30.0;
	317	 933	 0.487562	 1.572644	 0.0	 20	 20	 20	 1.0	 0.0	 1	 -30.0	 30.0;
	7104	 933	 0.12936	 0.588864	 0.0	 53	 53	 53	 1.0	 0.0	 1	 -30.0	 30.0;
	9104	 6113	 0.000246	 0.025121	 0.0	 1258	 1258	 1258	 0.961864	 0.0	 1	 -30.0	 30.0;
	6805	 10689	 0.10005	 1.276798	 0.0	 25	 25	 25	 1.0	 0.0	 1	 -30.0	 30.0;
	5421	 10689	 0.21936	 1.401591	 0.0	 23	 23	 23	 1.0	 0.0	 1	 -30.0	 30.0;
	8011	 10689	 0.22688	 1.394834	 0.0	 23	 23	 23	 1.0	 0.0	 1	 -30.0	 30.0;
	2040	 3601	 0.04986	 0.379174	 0.0	 83	 83	 83	 1.0	 0.0	 1	 -30.0	 30.0;
	5572	 1363	 0.02303	 0.62419	 0.0	 51	 51	 51	 1.0	 0.0	 1	 -30.0	 30.0;
	5572	 611	 0.03435	 0.639633	 0.0	 50	 50	 50	 1.0	 0.0	 1	 -30.0	 30.0;
	374	 12450	 0.01742	 0.603616	 0.0	 53	 53	 53	 1.0	 0.0	 1	 -30.0	 30.0;
	12364	 12450	 0.14245	 1.97967	 0.0	 16	 16	 16	 1.0	 0.0	 1	 -30.0	 30.0;
	1597	 12450	 -0.000145	 0.32938	 0.0	 96	 96	 96	 1.0	 0.0	 1	 -30.0	 30.0;
	6653	 4669	 -0.000298	 0.102701	 0.0	 308	 308	 308	 1.0	 0.0	 1	 -30.0	 30.0;
	530	 9705	 0.000708	 0.03271	 0.0	 966	 966	 966	 1.035157	 0.0	 1	 -30.0	 30.0;
	530	 11541	 0.06719	 0.834339	 0.0	 38	 38	 38	 1.0	 0.0	 1	 -30.0	 30.0;
	8923	 6644	 0.050909	 0.307686	 0.0	 102	 102	 102	 1.0	 0.0	 1	 -30.0	 30.0;
	1405	 6644	 0.212521	 0.943657	 0.0	 33	 33	 33	 1.0	 0.0	 1	 -30.0	 30.0;
	6246	 12361	 -0.002652	 0.490201	 0.0	 65	 65	 65	 1.0	 0.0	 1	 -30.0	 30.0;
	6246	 8216	 0.02628	 0.438469	 0.0	 72	 72	 72	 1.0	 0.0	 1	 -30.0	 30.0;
	12187	 12361	 -0.008241	 0.388947	 0.0	 82	 82	 82	 1.0	 0.0	 1	 -30.0	 30.0;
	11045	 12361	 0.000226	 0.024837	 0.0	 1272	 1272	 1272	 1.036011	 0.0	 1	 -30.0	 30.0;
	3952	 12361	 0.106109	 0.699359	 0.0	 45	 45	 45	 1.0	 0.0	 1	 -30.0	 30.0;
	3952	 8216	 0.02855	 0.418988	 0.0	 76	 76	 76	 1.0	 0.0	 1	 -30.0	 30.0;
	1597	 488	 0.292479	 1.229545	 0.0	 25	 25	 25	 1.0	 0.0	 1	 -30.0	 30.0;
	317	 4669	 0.757066	 1.631798	 0.0	 18	 18	 18	 1.0	 0.0	 1	 -30.0	 30.0;
	7104	 4669	 0.384752	 1.021653	 0.0	 29	 29	 29	 1.0	 0.0	 1	 -30.0	 30.0;
	7601	 6887	 -0.014297	 0.212851	 0.0	 149	 149	 149	 1.0	 0.0	 1	 -30.0	 30.0;
	7601	 6887	 0.000444	 0.031171	 0.0	 1014	 1014	 1014	 0.960552	 0.0	 1	 -30.0	 30.0;
	7601	 5153	 -0.014091	 0.217459	 0.0	 145	 145	 145	 1.0	 0.0	 1	 -30.0	 30.0;
	11162	 12209	 0.00894	 0.300393	 0.0	 106	 106	 106	 1.0	 0.0	 1	 -30.0	 30.0;
	13061	 13263	 0.049771	 0.546674	 0.0	 58	 58	 58	 1.0	 0.0	 1	 -30.0	 30.0;
	3159	 12798	 0.000737	 0.026925	 0.0	 1173	 1173	 1173	 1.044741	 0.0	 1	 -30.0	 30.0;
	3159	 12798	 0.000845	 0.026029	 0.0	 1213	 1213	 1213	 1.013524	 0.0	 1	 -30.0	 30.0;
	13061	 4463	 0.05157	 0.475537	 0.0	 67	 67	 67	 1.0	 0.0	 1	 -30.0	 30.0;
	11162	 3967	 0.054781	 0.446446	 0.0	 71	 71	 71	 1.0	 0.0	 1	 -30.0	 30.0;
	5039	 2867	 0.000452	 0.023578	 0.0	 1340	 1340	 1340	 0.970414	 0.0	 1	 -30.0	 30.0;
	4911	 4104	 -0.010579	 0.27814	 0.0	 114	 114	 114	 1.0	 0.0	 1	 -30.0	 30.0;
	4911	 7423	 -0.007004	 0.324484	 0.0	 98	 98	 98	 1.0	 0.0	 1	 -30.0	 30.0;
	12364	 8031	 -0.034029	 0.423698	 0.0	 75	 75	 75	 1.0	 0.0	 1	 -30.0	 30.0;
	4071	 2121	 0.000384	 0.0242	 0.0	 1306	 1306	 1306	 1.003202	 0.0	 1	 -30.0	 30.0;
	2040	 2121	 0.299587	 1.849794	 0.0	 17	 17	 17	 1.0	 0.0	 1	 -30.0	 30.0;
	2040	 7741	 0.301095	 1.740868	 0.0	 18	 18	 18	 1.0	 0.0	 1	 -30.0	 30.0;
	1585	 7101	 0.000759	 0.019191	 0.0	 1645	 1645	 1645	 1.143233	 0.0	 1	 -30.0	 30.0;
	374	 10265	 0.170173	 0.568199	 0.0	 54	 54	 54	 1.0	 0.0	 1	 -30.0	 30.0;
	11162	 9811	 0.00708	 0.453843	 0.0	 70	 70	 70	 1.0	 0.0	 1	 -30.0	 30.0;
	13061	 9811	 0.057719	 0.644008	 0.0	 49	 49	 49	 1.0	 0.0	 1	 -30.0	 30.0;
	10360	 10265	 0.077609	 0.938223	 0.0	 34	 34	 34	 1.0	 0.0	 1	 -30.0	 30.0;
	1597	 10265	 0.200409	 0.618946	 0.0	 49	 49	 49	 1.0	 0.0	 1	 -30.0	 30.0;
	11162	 4972	 0.152771	 0.863657	 0.0	 37	 37	 37	 1.0	 0.0	 1	 -30.0	 30.0;
	13061	 4972	 -0.001921	 0.311818	 0.0	 102	 102	 102	 1.0	 0.0	 1	 -30.0	 30.0;
	1597	 843	 0.305992	 1.948119	 0.0	 17	 17	 17	 1.0	 0.0	 1	 -30.0	 30.0;
	13061	 8020	 0.17005	 0.993099	 0.0	 32	 32	 32	 1.0	 0.0	 1	 -30.0	 30.0;
	10338	 2452	 0.000257	 0.029742	 0.0	 1063	 1063	 1063	 0.983674	 0.0	 1	 -30.0	 30.0;
	10338	 4736	 0.000268	 0.029134	 0.0	 1085	 1085	 1085	 0.977352	 0.0	 1	 -30.0	 30.0;
	5525	 7483	 -0.014277	 0.154039	 0.0	 205	 205	 205	 1.0	 0.0	 1	 -30.0	 30.0;
	5525	 7483	 0.000738	 0.031616	 0.0	 999	 999	 999	 0.971178	 0.0	 1	 -30.0	 30.0;
	733	 7483	 0.251178	 0.958099	 0.0	 32	 32	 32	 1.0	 0.0	 1	 -30.0	 30.0;
	5525	 561	 0.08599	 0.668788	 0.0	 47	 47	 47	 1.0	 0.0	 1	 -30.0	 30.0;
	7328	 11541	 0.000241	 0.02217	 0.0	 1425	 1425	 1425	 1.003292	 0.0	 1	 -30.0	 30.0;
	733	 3208	 -0.003678	 0.380909	 0.0	 83	 83	 83	 1.0	 0.0	 1	 -30.0	 30.0;
	12852	 3208	 -0.011302	 0.627045	 0.0	 51	 51	 51	 1.0	 0.0	 1	 -30.0	 30.0;
	733	 2802	 0.00797	 0.426157	 0.0	 75	 75	 75	 1.0	 0.0	 1	 -30.0	 30.0;
	12852	 2802	 0.058159	 0.835806	 0.0	 38	 38	 38	 1.0	 0.0	 1	 -30.0	 30.0;
	733	 2754	 0.00907	 0.406178	 0.0	 78	 78	 78	 1.0	 0.0	 1	 -30.0	 30.0;
	12852	 2754	 0.059789	 0.790103	 0.0	 40	 40	 40	 1.0	 0.0	 1	 -30.0	 30.0;
	733	 561	 0.04738	 0.355028	 0.0	 89	 89	 89	 1.0	 0.0	 1	 -30.0	 30.0;
	733	 7843	 0.00166	 0.210118	 0.0	 151	 151	 151	 1.0	 0.0	 1	 -30.0	 30.0;
	1405	 1114	 0.000234	 0.03334	 0.0	 948	 948	 948	 0.954161	 0.0	 1	 -30.0	 30.0;
	1405	 11590	 -0.007978	 0.33365	 0.0	 95	 95	 95	 1.0	 0.0	 1	 -30.0	 30.0;
	1405	 13563	 -0.007673	 0.339439	 0.0	 94	 94	 94	 1.0	 0.0	 1	 -30.0	 30.0;
	12852	 12998	 0.000213	 0.026084	 0.0	 1211	 1211	 1211	 0.949952	 0.0	 1	 -30.0	 30.0;
	12852	 561	 0.079162	 0.676053	 0.0	 47	 47	 47	 1.0	 0.0	 1	 -30.0	 30.0;
	12852	 5555	 -0.012742	 0.556163	 0.0	 57	 57	 57	 1.0	 0.0	 1	 -30.0	 30.0;
	12852	 7843	 0.05625	 0.586697	 0.0	 54	 54	 54	 1.0	 0.0	 1	 -30.0	 30.0;
	9356	 7690	 0.11012	 1.389876	 0.0	 23	 23	 23	 1.0	 0.0	 1	 -30.0	 30.0;
	12364	 4850	 0.12839	 0.634174	 0.0	 49	 49	 49	 1.0	 0.0	 1	 -30.0	 30.0;
	12364	 4850	 0.000265	 0.029415	 0.0	 1074	 1074	 1074	 0.954132	 0.0	 1	 -30.0	 30.0;
	4243	 3694	 0.01031	 0.165651	 0.0	 191	 191	 191	 1.0	 0.0	 1	 -30.0	 30.0;
	1141	 10131	 0.000906	 0.032368	 0.0	 976	 976	 976	 1.074593	 0.0	 1	 -30.0	 30.0;
	4911	 10131	 0.258574	 1.91281	 0.0	 17	 17	 17	 1.0	 0.0	 1	 -30.0	 30.0;
	4318	 12597	 0.114169	 0.69781	 0.0	 45	 45	 45	 1.0	 0.0	 1	 -30.0	 30.0;
	1597	 10697	 0.215475	 0.921488	 0.0	 34	 34	 34	 1.0	 0.0	 1	 -30.0	 30.0;
	1597	 399	 0.000388	 0.026559	 0.0	 1190	 1190	 1190	 1.024188	 0.0	 1	 -30.0	 30.0;
	1597	 399	 -0.012727	 0.168081	 0.0	 188	 188	 188	 1.0	 0.0	 1	 -30.0	 30.0;
	1597	 9019	 0.11171	 0.548317	 0.0	 57	 57	 57	 1.0	 0.0	 1	 -30.0	 30.0;
	4243	 5555	 0.04893	 0.453587	 0.0	 70	 70	 70	 1.0	 0.0	 1	 -30.0	 30.0;
	4318	 7534	 0.000427	 0.025869	 0.0	 1221	 1221	 1221	 1.014006	 0.0	 1	 -30.0	 30.0;
	4318	 1998	 0.000379	 0.029319	 0.0	 1078	 1078	 1078	 1.029958	 0.0	 1	 -30.0	 30.0;
	11162	 4325	 0.086233	 0.611399	 0.0	 52	 52	 52	 1.0	 0.0	 1	 -30.0	 30.0;
	11162	 5867	 0.03295	 0.399238	 0.0	 79	 79	 79	 1.0	 0.0	 1	 -30.0	 30.0;
	13061	 8240	 0.034401	 0.560661	 0.0	 57	 57	 57	 1.0	 0.0	 1	 -30.0	 30.0;
	8472	 3667	 0.04848	 0.4525	 0.0	 70	 70	 70	 1.0	 0.0	 1	 -30.0	 30.0;
	8472	 5950	 0.05627	 0.448553	 0.0	 70	 70	 70	 1.0	 0.0	 1	 -30.0	 30.0;
	34	 246	 0.000262	 0.020993	 0.0	 1505	 1505	 1505	 1.007843	 0.0	 1	 -30.0	 30.0;
	7104	 246	 0.093521	 0.726302	 0.0	 44	 44	 44	 1.0	 0.0	 1	 -30.0	 30.0;
	7104	 9654	 0.170831	 0.824835	 0.0	 38	 38	 38	 1.0	 0.0	 1	 -30.0	 30.0;
	9356	 5867	 0.05836	 0.35759	 0.0	 88	 88	 88	 1.0	 0.0	 1	 -30.0	 30.0;
	9162	 4325	 0.000563	 0.031553	 0.0	 1001	 1001	 1001	 0.989721	 0.0	 1	 -30.0	 30.0;
	7104	 5298	 0.04447	 0.619827	 0.0	 51	 51	 51	 1.0	 0.0	 1	 -30.0	 30.0;
	9519	 4873	 0.001519	 0.050701	 0.0	 623	 623	 623	 1.013513	 0.0	 1	 -30.0	 30.0;
	186	 7935	 0.000821	 0.051524	 0.0	 613	 613	 613	 1.052632	 0.0	 1	 -30.0	 30.0;
	186	 7935	 0.000803	 0.047869	 0.0	 660	 660	 660	 1.052632	 0.0	 1	 -30.0	 30.0;
	647	 6349	 0.000466	 0.029318	 0.0	 1078	 1078	 1078	 1.025291	 0.0	 1	 -30.0	 30.0;
	3465	 6920	 0.000463	 0.028006	 0.0	 1128	 1128	 1128	 1.038781	 0.0	 1	 -30.0	 30.0;
	3465	 6920	 0.000463	 0.026569	 0.0	 1189	 1189	 1189	 1.038781	 0.0	 1	 -30.0	 30.0;
	13247	 12999	 0.000556	 0.030088	 0.0	 1050	 1050	 1050	 1.08147	 0.0	 1	 -30.0	 30.0;
	13247	 12999	 0.000581	 0.029019	 0.0	 1089	 1089	 1089	 1.08147	 0.0	 1	 -30.0	 30.0;
	8480	 1022	 0.0017	 0.077979	 0.0	 405	 405	 405	 1.0	 0.0	 1	 -30.0	 30.0;
	12100	 8027	 0.000569	 0.046371	 0.0	 682	 682	 682	 1.052632	 0.0	 1	 -30.0	 30.0;
	12100	 8027	 0.00056	 0.047255	 0.0	 669	 669	 669	 1.052632	 0.0	 1	 -30.0	 30.0;
	789	 6379	 0.0008	 0.050159	 0.0	 630	 630	 630	 1.066857	 0.0	 1	 -30.0	 30.0;
	8865	 7323	 0.000379	 0.039836	 0.0	 793	 793	 793	 1.052632	 0.0	 1	 -30.0	 30.0;
	8865	 7323	 0.000433	 0.039042	 0.0	 810	 810	 810	 1.052632	 0.0	 1	 -30.0	 30.0;
	2715	 10792	 0.000448	 0.032183	 0.0	 982	 982	 982	 1.066857	 0.0	 1	 -30.0	 30.0;
	12487	 1767	 0.000498	 0.034255	 0.0	 923	 923	 923	 1.041667	 0.0	 1	 -30.0	 30.0;
	12487	 1767	 0.000507	 0.033509	 0.0	 943	 943	 943	 1.041667	 0.0	 1	 -30.0	 30.0;
	9043	 3445	 0.000415	 0.040631	 0.0	 778	 778	 778	 1.052632	 0.0	 1	 -30.0	 30.0;
	9043	 3445	 0.000406	 0.041434	 0.0	 763	 763	 763	 1.052632	 0.0	 1	 -30.0	 30.0;
	8085	 1993	 0.000397	 0.037986	 0.0	 832	 832	 832	 1.052632	 0.0	 1	 -30.0	 30.0;
	11490	 2814	 0.000322	 0.035886	 0.0	 881	 881	 881	 1.043149	 0.0	 1	 -30.0	 30.0;
	1463	 10949	 0.000408	 0.039074	 0.0	 809	 809	 809	 0.989653	 0.0	 1	 -30.0	 30.0;
	9196	 9925	 0.000417	 0.026115	 0.0	 1210	 1210	 1210	 1.062288	 0.0	 1	 -30.0	 30.0;
	9196	 9925	 0.000443	 0.02577	 0.0	 1226	 1226	 1226	 1.062288	 0.0	 1	 -30.0	 30.0;
	4330	 9126	 0.000396	 0.033918	 0.0	 932	 932	 932	 1.02924	 0.0	 1	 -30.0	 30.0;
	11719	 254	 0.000406	 0.023438	 0.0	 1348	 1348	 1348	 1.052632	 0.0	 1	 -30.0	 30.0;
	11719	 254	 0.000352	 0.026759	 0.0	 1181	 1181	 1181	 1.052632	 0.0	 1	 -30.0	 30.0;
	9534	 10982	 0.000334	 0.036651	 0.0	 862	 862	 862	 1.052632	 0.0	 1	 -30.0	 30.0;
	9534	 10982	 0.000334	 0.037354	 0.0	 846	 846	 846	 1.052632	 0.0	 1	 -30.0	 30.0;
	6592	 6120	 0.000305	 0.035675	 0.0	 886	 886	 886	 1.087225	 0.0	 1	 -30.0	 30.0;
	6592	 6120	 0.000296	 0.033035	 0.0	 957	 957	 957	 1.087225	 0.0	 1	 -30.0	 30.0;
	6592	 6120	 0.000338	 0.032376	 0.0	 976	 976	 976	 1.087225	 0.0	 1	 -30.0	 30.0;
	9511	 12530	 0.000285	 0.02604	 0.0	 1213	 1213	 1213	 1.199891	 0.0	 1	 -30.0	 30.0;
	1463	 1754	 0.000419	 0.02814	 0.0	 1123	 1123	 1123	 0.989653	 0.0	 1	 -30.0	 30.0;
	4330	 13513	 0.000453	 0.025129	 0.0	 1257	 1257	 1257	 1.02924	 0.0	 1	 -30.0	 30.0;
	4330	 9305	 0.000453	 0.02528	 0.0	 1250	 1250	 1250	 1.02924	 0.0	 1	 -30.0	 30.0;
	7395	 677	 0.00174	 0.07467	 0.0	 423	 423	 423	 1.049587	 0.0	 1	 -30.0	 30.0;
	7395	 736	 0.00171	 0.07614	 0.0	 415	 415	 415	 1.049587	 0.0	 1	 -30.0	 30.0;
	1925	 8341	 0.00172	 0.099322	 0.0	 382	 382	 382	 1.052632	 0.0	 1	 -30.0	 30.0;
	1925	 8341	 0.00168	 0.101198	 0.0	 375	 375	 375	 1.052632	 0.0	 1	 -30.0	 30.0;
	13051	 10539	 0.00363	 0.146413	 0.0	 260	 260	 260	 1.049587	 0.0	 1	 -30.0	 30.0;
	13051	 10539	 0.00182	 0.07175	 0.0	 529	 529	 529	 1.049587	 0.0	 1	 -30.0	 30.0;
	2469	 9101	 0.0019	 0.08995	 0.0	 422	 422	 422	 1.052632	 0.0	 1	 -30.0	 30.0;
	6954	 7927	 0.00189	 0.06882	 0.0	 459	 459	 459	 1.049587	 0.0	 1	 -30.0	 30.0;
	6954	 1205	 0.00192	 0.06735	 0.0	 469	 469	 469	 1.049587	 0.0	 1	 -30.0	 30.0;
	6146	 10976	 0.00196	 0.06589	 0.0	 480	 480	 480	 1.049587	 0.0	 1	 -30.0	 30.0;
	5486	 1103	 0.00171	 0.07614	 0.0	 415	 415	 415	 1.049587	 0.0	 1	 -30.0	 30.0;
	8051	 8833	 0.00167	 0.0776	 0.0	 489	 489	 489	 1.049587	 0.0	 1	 -30.0	 30.0;
	10871	 4510	 0.000646	 0.061526	 0.0	 611	 611	 611	 1.003288	 -0.001353	 1	 -30.0	 30.0;
	10871	 4510	 0.000636	 0.056994	 0.0	 660	 660	 660	 1.003288	 -0.001353	 1	 -30.0	 30.0;
	4510	 922	 0.00182	 0.07175	 0.0	 529	 529	 529	 1.049587	 0.0	 1	 -30.0	 30.0;
	4510	 4852	 0.00185	 0.07028	 0.0	 540	 540	 540	 1.049587	 0.0	 1	 -30.0	 30.0;
	3476	 9139	 0.00194	 0.088083	 0.0	 431	 431	 431	 1.052632	 0.0	 1	 -30.0	 30.0;
	3476	 9888	 0.00198	 0.086207	 0.0	 440	 440	 440	 1.052632	 0.0	 1	 -30.0	 30.0;
	6415	 10002	 0.00196	 0.06589	 0.0	 576	 576	 576	 1.049587	 0.0	 1	 -30.0	 30.0;
	11513	 9234	 0.000697	 0.032338	 0.0	 1163	 1163	 1163	 1.002506	 0.0	 1	 -30.0	 30.0;
	9234	 13293	 0.00171	 0.07614	 0.0	 499	 499	 499	 1.049587	 0.0	 1	 -30.0	 30.0;
	10593	 3637	 0.000667	 0.033601	 0.0	 1119	 1119	 1119	 1.002506	 0.0	 1	 -30.0	 30.0;
	10593	 3637	 0.000647	 0.034238	 0.0	 1098	 1098	 1098	 1.002506	 0.0	 1	 -30.0	 30.0;
	3637	 4361	 0.0016	 0.07553	 0.0	 503	 503	 503	 1.061984	 0.0	 1	 -30.0	 30.0;
	3637	 1683	 0.00182	 0.07402	 0.0	 513	 513	 513	 1.061984	 0.0	 1	 -30.0	 30.0;
	6935	 8512	 0.0019	 0.08995	 0.0	 422	 422	 422	 1.052632	 0.0	 1	 -30.0	 30.0;
	8186	 5583	 0.00189	 0.06882	 0.0	 459	 459	 459	 1.049587	 0.0	 1	 -30.0	 30.0;
	8186	 899	 0.00192	 0.06735	 0.0	 469	 469	 469	 1.049587	 0.0	 1	 -30.0	 30.0;
	9116	 127	 0.00201	 0.084331	 0.0	 450	 450	 450	 1.052632	 0.0	 1	 -30.0	 30.0;
	9116	 127	 0.00179	 0.095578	 0.0	 397	 397	 397	 1.052632	 0.0	 1	 -30.0	 30.0;
	13638	 2924	 0.00171	 0.07614	 0.0	 415	 415	 415	 1.049587	 0.0	 1	 -30.0	 30.0;
	5480	 1293	 0.00167	 0.0776	 0.0	 407	 407	 407	 1.049587	 0.0	 1	 -30.0	 30.0;
	1193	 2833	 0.00168	 0.101198	 0.0	 375	 375	 375	 1.052632	 0.0	 1	 -30.0	 30.0;
	9834	 12952	 0.00165	 0.093702	 0.0	 405	 405	 405	 1.052632	 0.0	 1	 -30.0	 30.0;
	9834	 2002	 0.00187	 0.091826	 0.0	 414	 414	 414	 1.052632	 0.0	 1	 -30.0	 30.0;
	9238	 13204	 0.0019	 0.08995	 0.0	 352	 352	 352	 1.052632	 0.0	 1	 -30.0	 30.0;
	5579	 13378	 0.00189	 0.06882	 0.0	 552	 552	 552	 1.049587	 0.0	 1	 -30.0	 30.0;
	5579	 13378	 0.00192	 0.06735	 0.0	 564	 564	 564	 1.049587	 0.0	 1	 -30.0	 30.0;
	7281	 10770	 0.00196	 0.06589	 0.0	 576	 576	 576	 1.049587	 0.0	 1	 -30.0	 30.0;
	7281	 9459	 0.00174	 0.07467	 0.0	 508	 508	 508	 1.049587	 0.0	 1	 -30.0	 30.0;
	11589	 4560	 0.00171	 0.07614	 0.0	 415	 415	 415	 1.049587	 0.0	 1	 -30.0	 30.0;
	5719	 7158	 0.00167	 0.0776	 0.0	 407	 407	 407	 1.049587	 0.0	 1	 -30.0	 30.0;
	2986	 11540	 0.00164	 0.07907	 0.0	 400	 400	 400	 1.049587	 0.0	 1	 -30.0	 30.0;
	13627	 9770	 0.00045	 0.04299	 0.0	 735	 735	 735	 1.113821	 0.0	 1	 -30.0	 30.0;
	13315	 4641	 0.00051	 0.04213	 0.0	 750	 750	 750	 1.113821	 0.0	 1	 -30.0	 30.0;
	1705	 1706	 0.00185	 0.07028	 0.0	 450	 450	 450	 1.049587	 0.0	 1	 -30.0	 30.0;
	1705	 1706	 0.00189	 0.06882	 0.0	 459	 459	 459	 1.049587	 0.0	 1	 -30.0	 30.0;
	293	 6175	 0.00192	 0.06735	 0.0	 469	 469	 469	 1.049587	 0.0	 1	 -30.0	 30.0;
	293	 8417	 0.00196	 0.06589	 0.0	 480	 480	 480	 1.049587	 0.0	 1	 -30.0	 30.0;
	7326	 5374	 0.00179	 0.095578	 0.0	 397	 397	 397	 1.052632	 0.0	 1	 -30.0	 30.0;
	7326	 5374	 0.00176	 0.097446	 0.0	 390	 390	 390	 1.052632	 0.0	 1	 -30.0	 30.0;
	2884	 1799	 0.00167	 0.0776	 0.0	 407	 407	 407	 1.049587	 0.0	 1	 -30.0	 30.0;
	2884	 1799	 0.00164	 0.07907	 0.0	 400	 400	 400	 1.049587	 0.0	 1	 -30.0	 30.0;
	12012	 8051	 0.000637	 0.031701	 0.0	 1186	 1186	 1186	 1.002506	 0.0	 1	 -30.0	 30.0;
	12012	 11679	 0.000716	 0.031064	 0.0	 1210	 1210	 1210	 1.002506	 0.0	 1	 -30.0	 30.0;
	11679	 13236	 0.00185	 0.07028	 0.0	 540	 540	 540	 1.049587	 0.0	 1	 -30.0	 30.0;
	11679	 1890	 0.00189	 0.06882	 0.0	 552	 552	 552	 1.049587	 0.0	 1	 -30.0	 30.0;
	3411	 2744	 0.00192	 0.06735	 0.0	 469	 469	 469	 1.049587	 0.0	 1	 -30.0	 30.0;
	3411	 2744	 0.00196	 0.06589	 0.0	 480	 480	 480	 1.049587	 0.0	 1	 -30.0	 30.0;
	9488	 12371	 0.00174	 0.07467	 0.0	 423	 423	 423	 1.049587	 0.0	 1	 -30.0	 30.0;
	11682	 7764	 0.00171	 0.07614	 0.0	 415	 415	 415	 1.049587	 0.0	 1	 -30.0	 30.0;
	9128	 2511	 0.00084	 0.0322	 0.0	 1178	 1178	 1178	 1.052632	 0.0	 1	 -30.0	 30.0;
	2511	 4297	 0.00238	 0.123248	 0.0	 257	 257	 257	 1.049587	 0.0	 1	 -30.0	 30.0;
	7984	 10393	 0.00269	 0.109562	 0.0	 289	 289	 289	 1.049587	 0.0	 1	 -30.0	 30.0;
	8931	 12463	 0.00275	 0.107281	 0.0	 295	 295	 295	 1.049587	 0.0	 1	 -30.0	 30.0;
	6941	 4396	 0.000766	 0.029164	 0.0	 1289	 1289	 1289	 1.002506	 0.0	 1	 -30.0	 30.0;
	6941	 4396	 0.000776	 0.028526	 0.0	 1318	 1318	 1318	 1.002506	 0.0	 1	 -30.0	 30.0;
	4396	 12301	 0.00174	 0.07467	 0.0	 508	 508	 508	 1.049587	 0.0	 1	 -30.0	 30.0;
	4396	 3435	 0.00171	 0.07614	 0.0	 499	 499	 499	 1.049587	 0.0	 1	 -30.0	 30.0;
	12860	 2548	 0.00167	 0.0776	 0.0	 489	 489	 489	 1.049587	 0.0	 1	 -30.0	 30.0;
	5789	 2671	 0.00168	 0.101198	 0.0	 375	 375	 375	 1.052632	 0.0	 1	 -30.0	 30.0;
	5789	 5487	 0.00165	 0.093702	 0.0	 405	 405	 405	 1.052632	 0.0	 1	 -30.0	 30.0;
	1371	 10664	 0.000716	 0.031064	 0.0	 1210	 1210	 1210	 1.002506	 0.0	 1	 -30.0	 30.0;
	1371	 5020	 0.000736	 0.030437	 0.0	 1235	 1235	 1235	 1.002506	 0.0	 1	 -30.0	 30.0;
	5020	 703	 0.00189	 0.06882	 0.0	 552	 552	 552	 1.049587	 0.0	 1	 -30.0	 30.0;
	5020	 703	 0.00192	 0.06735	 0.0	 564	 564	 564	 1.049587	 0.0	 1	 -30.0	 30.0;
	9741	 6410	 0.00196	 0.06589	 0.0	 480	 480	 480	 1.049587	 0.0	 1	 -30.0	 30.0;
	11491	 6657	 0.00174	 0.07467	 0.0	 508	 508	 508	 1.049587	 0.0	 1	 -30.0	 30.0;
	2385	 9239	 0.00171	 0.07614	 0.0	 499	 499	 499	 1.049587	 0.0	 1	 -30.0	 30.0;
	2385	 9239	 0.00167	 0.0776	 0.0	 489	 489	 489	 1.049587	 0.0	 1	 -30.0	 30.0;
	6453	 7040	 0.00168	 0.101198	 0.0	 375	 375	 375	 1.052632	 0.0	 1	 -30.0	 30.0;
	6889	 5659	 0.00062	 0.03068	 0.0	 1226	 1226	 1226	 1.015698	 0.0	 1	 -30.0	 30.0;
	6889	 9703	 0.000458	 0.027443	 0.0	 1370	 1370	 1370	 1.002506	 0.0	 1	 -30.0	 30.0;
	6889	 9703	 0.000468	 0.026875	 0.0	 1399	 1399	 1399	 1.002506	 0.0	 1	 -30.0	 30.0;
	12516	 13461	 0.001543	 0.057853	 0.0	 656	 656	 656	 0.892857	 0.0	 1	 -30.0	 30.0;
	6261	 1121	 0.00198	 0.086207	 0.0	 440	 440	 440	 1.052632	 0.0	 1	 -30.0	 30.0;
	10999	 4447	 0.00196	 0.06589	 0.0	 576	 576	 576	 1.049587	 0.0	 1	 -30.0	 30.0;
	4908	 8684	 0.00174	 0.07467	 0.0	 423	 423	 423	 1.049587	 0.0	 1	 -30.0	 30.0;
	2416	 9838	 0.00171	 0.07614	 0.0	 415	 415	 415	 1.049587	 0.0	 1	 -30.0	 30.0;
	4894	 13139	 0.000667	 0.033601	 0.0	 1129	 1129	 1129	 1.002506	 0.0	 1	 -30.0	 30.0;
	4894	 11041	 0.00168	 0.101198	 0.0	 375	 375	 375	 1.052632	 0.0	 1	 -30.0	 30.0;
	13139	 11041	 0.0016	 0.07321	 0.0	 432	 432	 432	 1.049587	 0.0	 1	 -30.0	 30.0;
	10698	 11075	 0.0019	 0.08995	 0.0	 422	 422	 422	 1.052632	 0.0	 1	 -30.0	 30.0;
	13221	 5372	 0.000746	 0.029801	 0.0	 1060	 1060	 1060	 1.002506	 0.0	 1	 -30.0	 30.0;
	6364	 5597	 0.00198	 0.086207	 0.0	 440	 440	 440	 1.052632	 0.0	 1	 -30.0	 30.0;
	7782	 4362	 0.00196	 0.06589	 0.0	 480	 480	 480	 1.049587	 0.0	 1	 -30.0	 30.0;
	12756	 7306	 0.00174	 0.07467	 0.0	 423	 423	 423	 1.049587	 0.0	 1	 -30.0	 30.0;
	883	 10413	 0.000677	 0.032965	 0.0	 1151	 1151	 1151	 1.002506	 0.0	 1	 -30.0	 30.0;
	883	 12669	 0.000667	 0.033601	 0.0	 1129	 1129	 1129	 1.002506	 0.0	 1	 -30.0	 30.0;
	883	 1870	 0.00168	 0.101198	 0.0	 375	 375	 375	 1.052632	 0.0	 1	 -30.0	 30.0;
	883	 7301	 0.00165	 0.093702	 0.0	 405	 405	 405	 1.052632	 0.0	 1	 -30.0	 30.0;
	10256	 6914	 0.000716	 0.031064	 0.0	 1017	 1017	 1017	 1.002506	 0.0	 1	 -30.0	 30.0;
	10256	 6914	 0.000736	 0.030437	 0.0	 1038	 1038	 1038	 1.002506	 0.0	 1	 -30.0	 30.0;
	10256	 6914	 0.000746	 0.029801	 0.0	 1060	 1060	 1060	 1.002506	 0.0	 1	 -30.0	 30.0;
	6914	 5738	 0.00192	 0.06735	 0.0	 469	 469	 469	 1.049587	 0.0	 1	 -30.0	 30.0;
	6914	 5738	 0.00196	 0.06589	 0.0	 480	 480	 480	 1.049587	 0.0	 1	 -30.0	 30.0;
	2204	 2960	 0.00179	 0.095578	 0.0	 397	 397	 397	 1.052632	 0.0	 1	 -30.0	 30.0;
	2204	 5768	 0.00176	 0.097446	 0.0	 390	 390	 390	 1.052632	 0.0	 1	 -30.0	 30.0;
	12015	 7629	 0.00167	 0.0776	 0.0	 489	 489	 489	 1.049587	 0.0	 1	 -30.0	 30.0;
	7303	 47	 0.00164	 0.07907	 0.0	 400	 400	 400	 1.049587	 0.0	 1	 -30.0	 30.0;
	3047	 744	 0.0016	 0.07321	 0.0	 432	 432	 432	 1.049587	 0.0	 1	 -30.0	 30.0;
	3047	 744	 0.00182	 0.07175	 0.0	 441	 441	 441	 1.049587	 0.0	 1	 -30.0	 30.0;
	13036	 12177	 0.0019	 0.08995	 0.0	 422	 422	 422	 1.052632	 0.0	 1	 -30.0	 30.0;
	13036	 12177	 0.00194	 0.088083	 0.0	 431	 431	 431	 1.052632	 0.0	 1	 -30.0	 30.0;
	595	 12177	 0.00192	 0.06735	 0.0	 564	 564	 564	 1.049587	 0.0	 1	 -30.0	 30.0;
	10654	 13239	 0.00196	 0.06589	 0.0	 480	 480	 480	 1.049587	 0.0	 1	 -30.0	 30.0;
	7575	 12496	 0.00174	 0.07467	 0.0	 423	 423	 423	 1.049587	 0.0	 1	 -30.0	 30.0;
	6343	 6387	 0.00387	 0.152273	 0.0	 208	 208	 208	 1.049587	 0.0	 1	 -30.0	 30.0;
	6989	 398	 0.000667	 0.033601	 0.0	 1119	 1119	 1119	 1.002506	 0.0	 1	 -30.0	 30.0;
	6989	 4571	 0.00168	 0.101198	 0.0	 375	 375	 375	 1.052632	 0.0	 1	 -30.0	 30.0;
	6989	 7138	 0.00165	 0.093702	 0.0	 405	 405	 405	 1.052632	 0.0	 1	 -30.0	 30.0;
	6474	 11554	 0.00182	 0.07175	 0.0	 441	 441	 441	 1.049587	 0.0	 1	 -30.0	 30.0;
	6474	 11554	 0.00185	 0.07028	 0.0	 450	 450	 450	 1.049587	 0.0	 1	 -30.0	 30.0;
	10584	 1325	 0.00189	 0.06882	 0.0	 459	 459	 459	 1.049587	 0.0	 1	 -30.0	 30.0;
	10584	 1325	 0.00192	 0.06735	 0.0	 469	 469	 469	 1.049587	 0.0	 1	 -30.0	 30.0;
	5758	 876	 0.00196	 0.07015	 0.0	 541	 541	 541	 1.07438	 0.0	 1	 -30.0	 30.0;
	1619	 876	 0.00174	 0.0795	 0.0	 478	 478	 478	 1.07438	 0.0	 1	 -30.0	 30.0;
	4169	 3871	 0.00136	 0.05901	 0.0	 643	 643	 643	 1.052632	 0.0	 1	 -30.0	 30.0;
	4169	 838	 0.00133	 0.06014	 0.0	 631	 631	 631	 1.052632	 0.0	 1	 -30.0	 30.0;
	1383	 8207	 0.00164	 0.07907	 0.0	 400	 400	 400	 1.049587	 0.0	 1	 -30.0	 30.0;
	1383	 3332	 0.0016	 0.07321	 0.0	 432	 432	 432	 1.049587	 0.0	 1	 -30.0	 30.0;
	1720	 11215	 0.000716	 0.031064	 0.0	 1221	 1221	 1221	 1.002506	 0.0	 1	 -30.0	 30.0;
	11215	 6434	 0.00185	 0.07028	 0.0	 450	 450	 450	 1.049587	 0.0	 1	 -30.0	 30.0;
	7313	 3125	 0.00189	 0.06882	 0.0	 459	 459	 459	 1.049587	 0.0	 1	 -30.0	 30.0;
	6514	 219	 0.00158	 0.05564	 0.0	 568	 568	 568	 1.0	 0.0	 1	 -30.0	 30.0;
	6514	 8607	 0.00179	 0.0695	 0.0	 455	 455	 455	 1.0	 0.0	 1	 -30.0	 30.0;
	4227	 504	 0.00084	 0.04445	 0.0	 711	 711	 711	 1.0	 0.0	 1	 -30.0	 30.0;
	4227	 504	 0.0008	 0.04546	 0.0	 695	 695	 695	 1.0	 0.0	 1	 -30.0	 30.0;
	4227	 504	 0.00219	 0.08229	 0.0	 384	 384	 384	 1.0	 0.0	 1	 -30.0	 30.0;
	4227	 504	 0.00069	 0.04566	 0.0	 692	 692	 692	 1.047826	 0.0	 1	 -30.0	 30.0;
	13329	 5775	 0.00072	 0.04835	 0.0	 654	 654	 654	 0.999313	 0.0	 1	 -30.0	 30.0;
	13329	 5775	 0.00082	 0.04738	 0.0	 667	 667	 667	 0.999313	 0.0	 1	 -30.0	 30.0;
	7771	 3356	 0.00045	 0.03151	 0.0	 1003	 1003	 1003	 1.052632	 0.0	 1	 -30.0	 30.0;
	7771	 12489	 0.00048	 0.026419	 0.0	 1196	 1196	 1196	 1.052632	 0.0	 1	 -30.0	 30.0;
	4491	 12490	 0.0022	 0.07023	 0.0	 450	 450	 450	 1.0	 0.0	 1	 -30.0	 30.0;
	4095	 329	 0.00241	 0.0727	 0.0	 522	 522	 522	 1.052174	 0.0	 1	 -30.0	 30.0;
	4095	 329	 0.00081	 0.04644	 0.0	 817	 817	 817	 1.052174	 0.0	 1	 -30.0	 30.0;
	7786	 4358	 0.00158	 0.08045	 0.0	 393	 393	 393	 1.0	 0.0	 1	 -30.0	 30.0;
	11494	 13273	 0.00069	 0.04707	 0.0	 671	 671	 671	 1.052174	 0.0	 1	 -30.0	 30.0;
	2195	 12231	 0.00075	 0.04866	 0.0	 650	 650	 650	 1.052174	 0.0	 1	 -30.0	 30.0;
	2195	 12231	 0.00076	 0.04586	 0.0	 689	 689	 689	 1.052174	 0.0	 1	 -30.0	 30.0;
	12298	 12644	 0.00189	 0.07781	 0.0	 406	 406	 406	 1.0	 0.0	 1	 -30.0	 30.0;
	12298	 12644	 0.00205	 0.07804	 0.0	 405	 405	 405	 1.0	 0.0	 1	 -30.0	 30.0;
	967	 11127	 0.00207	 0.091083	 0.0	 347	 347	 347	 1.0	 0.0	 1	 -30.0	 30.0;
	967	 11127	 0.00211	 0.06802	 0.0	 465	 465	 465	 1.0	 0.0	 1	 -30.0	 30.0;
	2818	 11663	 0.0008	 0.03997	 0.0	 949	 949	 949	 1.052174	 0.0	 1	 -30.0	 30.0;
	10005	 11663	 0.00159	 0.086876	 0.0	 364	 364	 364	 1.0	 0.0	 1	 -30.0	 30.0;
	10005	 11663	 0.0026	 0.07998	 0.0	 395	 395	 395	 1.0	 0.0	 1	 -30.0	 30.0;
	7125	 11014	 0.00154	 0.086488	 0.0	 366	 366	 366	 1.0	 0.0	 1	 -30.0	 30.0;
	12632	 7125	 0.00052	 0.033159	 0.0	 953	 953	 953	 1.052632	 0.0	 1	 -30.0	 30.0;
	12632	 11014	 0.00072	 0.0451	 0.0	 701	 701	 701	 1.052174	 0.0	 1	 -30.0	 30.0;
	12632	 11014	 0.00068	 0.04531	 0.0	 698	 698	 698	 1.052174	 0.0	 1	 -30.0	 30.0;
	7029	 9828	 0.00042	 0.030281	 0.0	 1253	 1253	 1253	 1.052632	 0.0	 1	 -30.0	 30.0;
	7029	 12354	 0.00079	 0.04086	 0.0	 929	 929	 929	 1.052174	 0.0	 1	 -30.0	 30.0;
	9828	 7611	 0.00168	 0.07343	 0.0	 431	 431	 431	 1.0	 0.0	 1	 -30.0	 30.0;
	10798	 3902	 0.00038	 0.033591	 0.0	 1130	 1130	 1130	 1.052632	 0.0	 1	 -30.0	 30.0;
	10798	 3902	 0.00037	 0.03405	 0.0	 1115	 1115	 1115	 1.052632	 0.0	 1	 -30.0	 30.0;
	2405	 12731	 0.00039	 0.034849	 0.0	 907	 907	 907	 1.052632	 0.0	 1	 -30.0	 30.0;
	2405	 5508	 0.00063	 0.04764	 0.0	 663	 663	 663	 1.052174	 0.0	 1	 -30.0	 30.0;
	2405	 5508	 0.00074	 0.044626	 0.0	 708	 708	 708	 1.006865	 0.0	 1	 -30.0	 30.0;
	10718	 11533	 0.00069	 0.04232	 0.0	 897	 897	 897	 1.052632	 0.0	 1	 -30.0	 30.0;
	11733	 9765	 0.00228	 0.07286	 0.0	 434	 434	 434	 1.0	 0.0	 1	 -30.0	 30.0;
	11733	 9765	 0.00189	 0.07059	 0.0	 448	 448	 448	 1.0	 0.0	 1	 -30.0	 30.0;
	13546	 2444	 0.00195	 0.07374	 0.0	 429	 429	 429	 1.0	 0.0	 1	 -30.0	 30.0;
	13546	 2444	 0.00199	 0.07214	 0.0	 438	 438	 438	 1.0	 0.0	 1	 -30.0	 30.0;
	5434	 8201	 0.00177	 0.07931	 0.0	 399	 399	 399	 1.0	 0.0	 1	 -30.0	 30.0;
	5434	 8201	 0.00174	 0.08086	 0.0	 391	 391	 391	 1.0	 0.0	 1	 -30.0	 30.0;
	11413	 7033	 0.0015	 0.08239	 0.0	 384	 384	 384	 1.0	 0.0	 1	 -30.0	 30.0;
	11413	 7033	 0.00149	 0.091992	 0.0	 344	 344	 344	 1.0	 0.0	 1	 -30.0	 30.0;
	12313	 5079	 0.00066	 0.04441	 0.0	 855	 855	 855	 1.052174	 0.0	 1	 -30.0	 30.0;
	2505	 5079	 0.00171	 0.07418	 0.0	 426	 426	 426	 1.0	 0.0	 1	 -30.0	 30.0;
	2505	 5079	 0.00175	 0.07267	 0.0	 435	 435	 435	 1.0	 0.0	 1	 -30.0	 30.0;
	3715	 7184	 0.00053	 0.03038	 0.0	 1249	 1249	 1249	 1.052632	 0.0	 1	 -30.0	 30.0;
	7184	 868	 0.00165	 0.07003	 0.0	 451	 451	 451	 1.0	 0.0	 1	 -30.0	 30.0;
	7184	 67	 0.00217	 0.07323	 0.0	 432	 432	 432	 1.0	 0.0	 1	 -30.0	 30.0;
	387	 2022	 0.00072	 0.0453	 0.0	 698	 698	 698	 1.052174	 0.0	 1	 -30.0	 30.0;
	11007	 1568	 0.0021	 0.08257	 0.0	 383	 383	 383	 1.0	 0.0	 1	 -30.0	 30.0;
	11007	 1568	 0.00186	 0.087719	 0.0	 361	 361	 361	 1.0	 0.0	 1	 -30.0	 30.0;
	1255	 13260	 0.00076	 0.04796	 0.0	 659	 659	 659	 1.052174	 0.0	 1	 -30.0	 30.0;
	1255	 4701	 0.00075	 0.04466	 0.0	 708	 708	 708	 1.052174	 0.0	 1	 -30.0	 30.0;
	5511	 11269	 0.00401	 0.10005	 0.0	 316	 316	 316	 1.0	 0.0	 1	 -30.0	 30.0;
	5511	 11269	 0.00272	 0.07842	 0.0	 403	 403	 403	 1.0	 0.0	 1	 -30.0	 30.0;
	5511	 11269	 0.00278	 0.07679	 0.0	 412	 412	 412	 1.0	 0.0	 1	 -30.0	 30.0;
	5511	 11269	 0.00283	 0.07515	 0.0	 421	 421	 421	 1.0	 0.0	 1	 -30.0	 30.0;
	9582	 12567	 0.00045	 0.029271	 0.0	 1296	 1296	 1296	 1.052632	 0.0	 1	 -30.0	 30.0;
	9582	 12567	 0.0004	 0.033169	 0.0	 1144	 1144	 1144	 1.052632	 0.0	 1	 -30.0	 30.0;
	9582	 12567	 0.00039	 0.03382	 0.0	 1122	 1122	 1122	 1.052632	 0.0	 1	 -30.0	 30.0;
	3923	 7581	 0.00064	 0.04577	 0.0	 829	 829	 829	 1.052632	 0.0	 1	 -30.0	 30.0;
	1011	 2798	 0.00147	 0.08395	 0.0	 377	 377	 377	 1.0	 0.0	 1	 -30.0	 30.0;
	1011	 2532	 0.00184	 0.07633	 0.0	 414	 414	 414	 1.0	 0.0	 1	 -30.0	 30.0;
	8891	 13588	 0.00074	 0.04352	 0.0	 872	 872	 872	 1.052174	 0.0	 1	 -30.0	 30.0;
	2095	 7010	 0.00176	 0.08177	 0.0	 387	 387	 387	 1.0	 0.0	 1	 -30.0	 30.0;
	2095	 7010	 0.00242	 0.06613	 0.0	 478	 478	 478	 1.0	 0.0	 1	 -30.0	 30.0;
	7215	 3071	 0.00042	 0.030031	 0.0	 1052	 1052	 1052	 0.99815	 0.0	 1	 -30.0	 30.0;
	7215	 3071	 0.00043	 0.02938	 0.0	 1076	 1076	 1076	 0.998666	 0.0	 1	 -30.0	 30.0;
	10322	 13504	 0.00014	 0.019637	 0.0	 1609	 1609	 1609	 1.0	 0.199334	 1	 -30.0	 30.0;
	8477	 11977	 0.00037	 0.03395	 0.0	 931	 931	 931	 0.969972	 0.0	 1	 -30.0	 30.0;
	6044	 5814	 1.8e-05	 0.052587	 0.0	 601	 601	 601	 1.052632	 0.0	 1	 -30.0	 30.0;
	4082	 5814	 5.5e-05	 0.082396	 0.0	 384	 384	 384	 1.04762	 0.0	 1	 -30.0	 30.0;
	1144	 12959	 0.001416	 0.043162	 0.0	 732	 732	 732	 0.92437	 0.0	 1	 -30.0	 30.0;
	1144	 12959	 0.001603	 0.042296	 0.0	 747	 747	 747	 0.92437	 0.0	 1	 -30.0	 30.0;
	6149	 5799	 0.000806	 0.025741	 0.0	 1227	 1227	 1227	 1.002506	 0.0	 1	 -30.0	 30.0;
	6149	 5799	 0.000826	 0.025204	 0.0	 1253	 1253	 1253	 1.002506	 0.0	 1	 -30.0	 30.0;
	6149	 10826	 0.000107	 0.01357	 0.0	 2328	 2328	 2328	 1.059051	 0.0	 1	 -30.0	 30.0;
	5799	 1351	 0.00228	 0.07939	 0.0	 398	 398	 398	 1.0	 0.0	 1	 -30.0	 30.0;
	10826	 5799	 0.001087	 0.043438	 0.0	 727	 727	 727	 1.000679	 -0.007974	 1	 -30.0	 30.0;
	10826	 5799	 0.001067	 0.077593	 0.0	 408	 408	 408	 1.00317	 -0.04898	 1	 -30.0	 30.0;
	8882	 8560	 0.001301	 0.061931	 0.0	 510	 510	 510	 0.948276	 0.0	 1	 -30.0	 30.0;
	8882	 8560	 0.001268	 0.063098	 0.0	 501	 501	 501	 0.948276	 0.0	 1	 -30.0	 30.0;
	13474	 9599	 0.002358	 0.088053	 0.0	 359	 359	 359	 0.948276	 0.0	 1	 -30.0	 30.0;
	13474	 9599	 0.00268	 0.086295	 0.0	 366	 366	 366	 0.948276	 0.0	 1	 -30.0	 30.0;
	11561	 879	 0.000779	 0.042361	 0.0	 746	 746	 746	 1.061123	 0.005681	 1	 -30.0	 30.0;
	879	 6231	 0.001565	 0.062128	 0.0	 509	 509	 509	 0.932204	 0.0	 1	 -30.0	 30.0;
	879	 6231	 0.001588	 0.060806	 0.0	 520	 520	 520	 0.932204	 0.0	 1	 -30.0	 30.0;
	7850	 11835	 0.002713	 0.092944	 0.0	 340	 340	 340	 0.916667	 0.0	 1	 -30.0	 30.0;
	7850	 11835	 0.002464	 0.122138	 0.0	 259	 259	 259	 0.916667	 0.0	 1	 -30.0	 30.0;
	7397	 657	 0.002739	 0.116189	 0.0	 272	 272	 272	 0.932204	 0.0	 1	 -30.0	 30.0;
	7397	 657	 0.002681	 0.118434	 0.0	 267	 267	 267	 0.932204	 0.0	 1	 -30.0	 30.0;
	9363	 12633	 0.000212	 0.013811	 0.0	 2747	 2747	 2747	 1.067899	 0.133383	 1	 -30.0	 30.0;
	12894	 5804	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.023076	 0.0	 1	 -30.0	 30.0;
	12894	 7115	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.023076	 0.0	 1	 -30.0	 30.0;
	12894	 3481	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.023076	 0.0	 1	 -30.0	 30.0;
	12894	 4910	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.023076	 0.0	 1	 -30.0	 30.0;
	12894	 6291	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.023076	 0.0	 1	 -30.0	 30.0;
	12894	 7625	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.023076	 0.0	 1	 -30.0	 30.0;
	12894	 10785	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.023076	 0.0	 1	 -30.0	 30.0;
	12894	 7057	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.023076	 0.0	 1	 -30.0	 30.0;
	12894	 8370	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.023076	 0.0	 1	 -30.0	 30.0;
	12894	 8159	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.023076	 0.0	 1	 -30.0	 30.0;
	7344	 4480	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.019827	 0.0	 1	 -30.0	 30.0;
	7344	 6135	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.019827	 0.0	 1	 -30.0	 30.0;
	3901	 10983	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.01416	 0.0	 1	 -30.0	 30.0;
	3901	 564	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.01416	 0.0	 1	 -30.0	 30.0;
	3901	 3617	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.01416	 0.0	 1	 -30.0	 30.0;
	12265	 6846	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.02288	 0.0	 1	 -30.0	 30.0;
	12265	 9976	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.02288	 0.0	 1	 -30.0	 30.0;
	12265	 1895	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.02288	 0.0	 1	 -30.0	 30.0;
	372	 4692	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.024035	 0.0	 1	 -30.0	 30.0;
	372	 5627	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.024035	 0.0	 1	 -30.0	 30.0;
	10709	 6780	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.021194	 0.0	 1	 -30.0	 30.0;
	10709	 3577	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.021194	 0.0	 1	 -30.0	 30.0;
	10709	 531	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.021194	 0.0	 1	 -30.0	 30.0;
	10709	 7105	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.021194	 0.0	 1	 -30.0	 30.0;
	10709	 10352	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.021194	 0.0	 1	 -30.0	 30.0;
	10709	 2473	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.021194	 0.0	 1	 -30.0	 30.0;
	10709	 13122	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.021194	 0.0	 1	 -30.0	 30.0;
	10709	 6049	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.021194	 0.0	 1	 -30.0	 30.0;
	10709	 2786	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.021194	 0.0	 1	 -30.0	 30.0;
	10709	 8524	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.021194	 0.0	 1	 -30.0	 30.0;
	10709	 11699	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.021194	 0.0	 1	 -30.0	 30.0;
	10709	 1192	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.021194	 0.0	 1	 -30.0	 30.0;
	10709	 4298	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.021194	 0.0	 1	 -30.0	 30.0;
	10709	 7447	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.021194	 0.0	 1	 -30.0	 30.0;
	10709	 10605	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.021194	 0.0	 1	 -30.0	 30.0;
	10709	 12035	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.021194	 0.0	 1	 -30.0	 30.0;
	10709	 1516	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.021194	 0.0	 1	 -30.0	 30.0;
	10709	 4671	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.021194	 0.0	 1	 -30.0	 30.0;
	10709	 6225	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.021194	 0.0	 1	 -30.0	 30.0;
	8477	 2462	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.015768	 0.0	 1	 -30.0	 30.0;
	8477	 6317	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.015768	 0.0	 1	 -30.0	 30.0;
	8477	 2084	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.015768	 0.0	 1	 -30.0	 30.0;
	11379	 1606	 0.002119	 0.084719	 0.0	 444	 444	 444	 1.086887	 0.0	 1	 -30.0	 30.0;
	11379	 6885	 0.002119	 0.084719	 0.0	 444	 444	 444	 1.086887	 0.0	 1	 -30.0	 30.0;
	11379	 9960	 0.002119	 0.084719	 0.0	 444	 444	 444	 1.086887	 0.0	 1	 -30.0	 30.0;
	11379	 10847	 0.002119	 0.084719	 0.0	 444	 444	 444	 1.086887	 0.0	 1	 -30.0	 30.0;
	11379	 7930	 0.000531	 0.021225	 0.0	 1771	 1771	 1771	 1.081998	 0.0	 1	 -30.0	 30.0;
	11379	 9687	 0.000531	 0.021225	 0.0	 1771	 1771	 1771	 1.081998	 0.0	 1	 -30.0	 30.0;
	11379	 12962	 0.000531	 0.021225	 0.0	 1771	 1771	 1771	 1.081998	 0.0	 1	 -30.0	 30.0;
	12770	 7173	 0.002119	 0.084719	 0.0	 444	 444	 444	 1.083997	 0.0	 1	 -30.0	 30.0;
	12770	 3962	 0.002119	 0.084719	 0.0	 444	 444	 444	 1.083997	 0.0	 1	 -30.0	 30.0;
	12770	 910	 0.002119	 0.084719	 0.0	 444	 444	 444	 1.083997	 0.0	 1	 -30.0	 30.0;
	3896	 1096	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.007824	 0.0	 1	 -30.0	 30.0;
	3896	 10865	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.007824	 0.0	 1	 -30.0	 30.0;
	3896	 7689	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.007824	 0.0	 1	 -30.0	 30.0;
	3896	 5765	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.007824	 0.0	 1	 -30.0	 30.0;
	5694	 7356	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.017619	 0.0	 1	 -30.0	 30.0;
	5694	 11891	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.017619	 0.0	 1	 -30.0	 30.0;
	5694	 8704	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.017619	 0.0	 1	 -30.0	 30.0;
	5694	 5739	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.017619	 0.0	 1	 -30.0	 30.0;
	6184	 8793	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.014202	 0.0	 1	 -30.0	 30.0;
	6184	 11996	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.014202	 0.0	 1	 -30.0	 30.0;
	6184	 9236	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.014202	 0.0	 1	 -30.0	 30.0;
	6184	 6799	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.014202	 0.0	 1	 -30.0	 30.0;
	12700	 9884	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.012597	 0.0	 1	 -30.0	 30.0;
	12700	 13133	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.012597	 0.0	 1	 -30.0	 30.0;
	12700	 2485	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.012597	 0.0	 1	 -30.0	 30.0;
	12700	 5420	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.012597	 0.0	 1	 -30.0	 30.0;
	12700	 8490	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.012597	 0.0	 1	 -30.0	 30.0;
	12700	 7064	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.012597	 0.0	 1	 -30.0	 30.0;
	3649	 3854	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.012275	 0.0	 1	 -30.0	 30.0;
	3649	 798	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.012275	 0.0	 1	 -30.0	 30.0;
	3649	 13409	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.012275	 0.0	 1	 -30.0	 30.0;
	3649	 8096	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.012275	 0.0	 1	 -30.0	 30.0;
	10587	 4448	 0.000531	 0.021225	 0.0	 1771	 1771	 1771	 1.080715	 0.0	 1	 -30.0	 30.0;
	10587	 1308	 0.000531	 0.021225	 0.0	 1771	 1771	 1771	 1.080715	 0.0	 1	 -30.0	 30.0;
	11210	 13327	 0.000531	 0.021225	 0.0	 1771	 1771	 1771	 1.051932	 0.0	 1	 -30.0	 30.0;
	12488	 5319	 0.000531	 0.021225	 0.0	 1787	 1787	 1787	 1.071813	 0.0	 1	 -30.0	 30.0;
	2551	 5581	 0.000531	 0.021225	 0.0	 1787	 1787	 1787	 1.034901	 0.0	 1	 -30.0	 30.0;
	2551	 11483	 0.000531	 0.021225	 0.0	 1787	 1787	 1787	 1.034901	 0.0	 1	 -30.0	 30.0;
	2551	 6436	 0.000531	 0.021225	 0.0	 1787	 1787	 1787	 1.034901	 0.0	 1	 -30.0	 30.0;
	8575	 1323	 0.000531	 0.021225	 0.0	 1771	 1771	 1771	 1.080717	 0.0	 1	 -30.0	 30.0;
	8575	 4443	 0.000531	 0.021225	 0.0	 1771	 1771	 1771	 1.080717	 0.0	 1	 -30.0	 30.0;
	8575	 8632	 0.000531	 0.021225	 0.0	 1771	 1771	 1771	 1.080717	 0.0	 1	 -30.0	 30.0;
	12933	 10535	 0.000531	 0.021225	 0.0	 1787	 1787	 1787	 0.974802	 0.0	 1	 -30.0	 30.0;
	12933	 2895	 0.000531	 0.021225	 0.0	 1787	 1787	 1787	 0.974802	 0.0	 1	 -30.0	 30.0;
	4568	 9370	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.02559	 0.0	 1	 -30.0	 30.0;
	4568	 9281	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.02559	 0.0	 1	 -30.0	 30.0;
	7622	 8763	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.01765	 0.0	 1	 -30.0	 30.0;
	7622	 2777	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.01765	 0.0	 1	 -30.0	 30.0;
	7622	 1455	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.01765	 0.0	 1	 -30.0	 30.0;
	7622	 6507	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.01765	 0.0	 1	 -30.0	 30.0;
	7622	 6034	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.01765	 0.0	 1	 -30.0	 30.0;
	7622	 1749	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.01765	 0.0	 1	 -30.0	 30.0;
	7622	 5924	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.01765	 0.0	 1	 -30.0	 30.0;
	7622	 458	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.01765	 0.0	 1	 -30.0	 30.0;
	4568	 6754	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.025589	 0.0	 1	 -30.0	 30.0;
	4568	 39	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.025589	 0.0	 1	 -30.0	 30.0;
	12284	 1125	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.013076	 0.0	 1	 -30.0	 30.0;
	12284	 7668	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.013076	 0.0	 1	 -30.0	 30.0;
	12284	 666	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.013076	 0.0	 1	 -30.0	 30.0;
	12284	 824	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.013076	 0.0	 1	 -30.0	 30.0;
	3818	 6103	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.007697	 0.0	 1	 -30.0	 30.0;
	11951	 1072	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.026731	 0.0	 1	 -30.0	 30.0;
	11951	 5341	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.026731	 0.0	 1	 -30.0	 30.0;
	11951	 11299	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.026731	 0.0	 1	 -30.0	 30.0;
	2678	 2970	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.024028	 0.0	 1	 -30.0	 30.0;
	2678	 5037	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.024028	 0.0	 1	 -30.0	 30.0;
	2678	 12099	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.024028	 0.0	 1	 -30.0	 30.0;
	2678	 5548	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.024028	 0.0	 1	 -30.0	 30.0;
	2678	 12612	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.024028	 0.0	 1	 -30.0	 30.0;
	2678	 8969	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.024028	 0.0	 1	 -30.0	 30.0;
	6551	 10408	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.025318	 0.0	 1	 -30.0	 30.0;
	6551	 6539	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.025318	 0.0	 1	 -30.0	 30.0;
	6551	 13651	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.025318	 0.0	 1	 -30.0	 30.0;
	4813	 1278	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.030195	 0.0	 1	 -30.0	 30.0;
	4813	 2662	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.030195	 0.0	 1	 -30.0	 30.0;
	4813	 888	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.030195	 0.0	 1	 -30.0	 30.0;
	4813	 7392	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.030195	 0.0	 1	 -30.0	 30.0;
	4813	 1324	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.030195	 0.0	 1	 -30.0	 30.0;
	4813	 7875	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.030195	 0.0	 1	 -30.0	 30.0;
	12680	 12641	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.067331	 0.0	 1	 -30.0	 30.0;
	12680	 7111	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.067331	 0.0	 1	 -30.0	 30.0;
	679	 10640	 0.000708	 0.02832	 0.0	 1340	 1340	 1340	 1.072713	 0.0	 1	 -30.0	 30.0;
	679	 11154	 0.000708	 0.02832	 0.0	 1340	 1340	 1340	 1.072713	 0.0	 1	 -30.0	 30.0;
	2993	 4310	 0.000531	 0.021225	 0.0	 1787	 1787	 1787	 1.074993	 0.0	 1	 -30.0	 30.0;
	12838	 1071	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.009536	 0.0	 1	 -30.0	 30.0;
	12838	 6948	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.009536	 0.0	 1	 -30.0	 30.0;
	4783	 394	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.003735	 0.0	 1	 -30.0	 30.0;
	4783	 10418	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.003735	 0.0	 1	 -30.0	 30.0;
	4783	 869	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.003735	 0.0	 1	 -30.0	 30.0;
	5808	 7859	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.017956	 0.0	 1	 -30.0	 30.0;
	5808	 1305	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.017956	 0.0	 1	 -30.0	 30.0;
	5808	 9614	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.017956	 0.0	 1	 -30.0	 30.0;
	5808	 1763	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.017956	 0.0	 1	 -30.0	 30.0;
	5808	 4988	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.017956	 0.0	 1	 -30.0	 30.0;
	1613	 4339	 0.00547	 0.21875	 0.0	 145	 145	 145	 1.01239	 0.0	 1	 -30.0	 30.0;
	1613	 4938	 0.00547	 0.21875	 0.0	 145	 145	 145	 1.01239	 0.0	 1	 -30.0	 30.0;
	1613	 7039	 0.00547	 0.21875	 0.0	 145	 145	 145	 1.006664	 0.0	 1	 -30.0	 30.0;
	1613	 8029	 0.00547	 0.21875	 0.0	 145	 145	 145	 1.006664	 0.0	 1	 -30.0	 30.0;
	1613	 1017	 0.00547	 0.21875	 0.0	 145	 145	 145	 1.006664	 0.0	 1	 -30.0	 30.0;
	11260	 6670	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.009764	 0.0	 1	 -30.0	 30.0;
	11260	 13292	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.009764	 0.0	 1	 -30.0	 30.0;
	11260	 7116	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.009764	 0.0	 1	 -30.0	 30.0;
	11260	 133	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.009764	 0.0	 1	 -30.0	 30.0;
	11260	 5723	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.009764	 0.0	 1	 -30.0	 30.0;
	11260	 9374	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.009764	 0.0	 1	 -30.0	 30.0;
	11260	 4440	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.009764	 0.0	 1	 -30.0	 30.0;
	11260	 11487	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.009764	 0.0	 1	 -30.0	 30.0;
	11260	 3915	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.009764	 0.0	 1	 -30.0	 30.0;
	11260	 11005	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.009764	 0.0	 1	 -30.0	 30.0;
	13548	 5439	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.0091	 0.0	 1	 -30.0	 30.0;
	13548	 6068	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.0091	 0.0	 1	 -30.0	 30.0;
	13548	 4934	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.0091	 0.0	 1	 -30.0	 30.0;
	13548	 11988	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.0091	 0.0	 1	 -30.0	 30.0;
	13548	 2459	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.0091	 0.0	 1	 -30.0	 30.0;
	13548	 3248	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.0091	 0.0	 1	 -30.0	 30.0;
	13548	 1304	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.0091	 0.0	 1	 -30.0	 30.0;
	13548	 7858	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.0091	 0.0	 1	 -30.0	 30.0;
	13548	 859	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.0091	 0.0	 1	 -30.0	 30.0;
	13548	 7365	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.0091	 0.0	 1	 -30.0	 30.0;
	2873	 3292	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.0106	 0.0	 1	 -30.0	 30.0;
	2873	 11643	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.0106	 0.0	 1	 -30.0	 30.0;
	2873	 626	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.0106	 0.0	 1	 -30.0	 30.0;
	2873	 11131	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.0106	 0.0	 1	 -30.0	 30.0;
	2873	 4063	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.0106	 0.0	 1	 -30.0	 30.0;
	7748	 9766	 0.004587	 0.183429	 0.0	 173	 173	 173	 1.016154	 0.0	 1	 -30.0	 30.0;
	7748	 11802	 0.004587	 0.183429	 0.0	 173	 173	 173	 1.010452	 0.0	 1	 -30.0	 30.0;
	7748	 4377	 0.004587	 0.183429	 0.0	 173	 173	 173	 1.010452	 0.0	 1	 -30.0	 30.0;
	7748	 5940	 0.004587	 0.183429	 0.0	 173	 173	 173	 1.010452	 0.0	 1	 -30.0	 30.0;
	7748	 5755	 0.004587	 0.183429	 0.0	 173	 173	 173	 1.010452	 0.0	 1	 -30.0	 30.0;
	7748	 10833	 0.004587	 0.183429	 0.0	 173	 173	 173	 1.010452	 0.0	 1	 -30.0	 30.0;
	7748	 4238	 0.004587	 0.183429	 0.0	 173	 173	 173	 1.010452	 0.0	 1	 -30.0	 30.0;
	7748	 181	 0.004587	 0.183429	 0.0	 173	 173	 173	 1.010452	 0.0	 1	 -30.0	 30.0;
	7748	 4761	 0.004587	 0.183429	 0.0	 173	 173	 173	 1.010452	 0.0	 1	 -30.0	 30.0;
	3764	 144	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.009661	 0.0	 1	 -30.0	 30.0;
	3764	 7139	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.009661	 0.0	 1	 -30.0	 30.0;
	3764	 12551	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.009661	 0.0	 1	 -30.0	 30.0;
	7231	 7252	 0.000212	 0.008494	 0.0	 3718	 3718	 3718	 1.02036	 0.0	 1	 -30.0	 30.0;
	7231	 241	 0.000212	 0.008494	 0.0	 3718	 3718	 3718	 1.02036	 0.0	 1	 -30.0	 30.0;
	4303	 5979	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.021922	 0.0	 1	 -30.0	 30.0;
	4303	 12282	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.021922	 0.0	 1	 -30.0	 30.0;
	4303	 6487	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.021922	 0.0	 1	 -30.0	 30.0;
	4303	 395	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.021922	 0.0	 1	 -30.0	 30.0;
	4303	 995	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.021922	 0.0	 1	 -30.0	 30.0;
	4303	 9317	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.021922	 0.0	 1	 -30.0	 30.0;
	4303	 3468	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.021922	 0.0	 1	 -30.0	 30.0;
	4303	 9354	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.021922	 0.0	 1	 -30.0	 30.0;
	2116	 3404	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.02243	 0.0	 1	 -30.0	 30.0;
	2116	 8852	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.02243	 0.0	 1	 -30.0	 30.0;
	2116	 2242	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.02243	 0.0	 1	 -30.0	 30.0;
	2116	 8367	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.02243	 0.0	 1	 -30.0	 30.0;
	2116	 1794	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.02243	 0.0	 1	 -30.0	 30.0;
	2116	 7890	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.02243	 0.0	 1	 -30.0	 30.0;
	2116	 1330	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.02243	 0.0	 1	 -30.0	 30.0;
	2116	 11315	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.02243	 0.0	 1	 -30.0	 30.0;
	2116	 4763	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.02243	 0.0	 1	 -30.0	 30.0;
	2116	 10001	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.02243	 0.0	 1	 -30.0	 30.0;
	8695	 3361	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.021706	 0.0	 1	 -30.0	 30.0;
	8695	 9520	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.021706	 0.0	 1	 -30.0	 30.0;
	8695	 7812	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.021706	 0.0	 1	 -30.0	 30.0;
	8695	 10935	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.021706	 0.0	 1	 -30.0	 30.0;
	12322	 4354	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.016195	 0.0	 1	 -30.0	 30.0;
	12322	 10469	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.016195	 0.0	 1	 -30.0	 30.0;
	12322	 3845	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.016195	 0.0	 1	 -30.0	 30.0;
	12322	 8067	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.016195	 0.0	 1	 -30.0	 30.0;
	12322	 9149	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.016195	 0.0	 1	 -30.0	 30.0;
	12322	 13223	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.016195	 0.0	 1	 -30.0	 30.0;
	12322	 6123	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.016195	 0.0	 1	 -30.0	 30.0;
	12322	 54	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.016195	 0.0	 1	 -30.0	 30.0;
	12322	 6602	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.016195	 0.0	 1	 -30.0	 30.0;
	12322	 12216	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.016195	 0.0	 1	 -30.0	 30.0;
	12322	 5187	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.016195	 0.0	 1	 -30.0	 30.0;
	1378	 12728	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.019852	 0.0	 1	 -30.0	 30.0;
	1378	 5672	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.019852	 0.0	 1	 -30.0	 30.0;
	1378	 11221	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.019852	 0.0	 1	 -30.0	 30.0;
	1378	 4133	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.019852	 0.0	 1	 -30.0	 30.0;
	1378	 3683	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.019852	 0.0	 1	 -30.0	 30.0;
	1378	 10788	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.019852	 0.0	 1	 -30.0	 30.0;
	1378	 4191	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.019852	 0.0	 1	 -30.0	 30.0;
	1378	 11264	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.019852	 0.0	 1	 -30.0	 30.0;
	1378	 2698	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.019852	 0.0	 1	 -30.0	 30.0;
	1378	 9808	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.019852	 0.0	 1	 -30.0	 30.0;
	1378	 3176	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.019852	 0.0	 1	 -30.0	 30.0;
	2225	 5347	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.01408	 0.0	 1	 -30.0	 30.0;
	2225	 2080	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.01408	 0.0	 1	 -30.0	 30.0;
	2225	 8637	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.01408	 0.0	 1	 -30.0	 30.0;
	2225	 10633	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.01408	 0.0	 1	 -30.0	 30.0;
	2225	 4004	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.01408	 0.0	 1	 -30.0	 30.0;
	2225	 11128	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.01408	 0.0	 1	 -30.0	 30.0;
	2225	 4573	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.01408	 0.0	 1	 -30.0	 30.0;
	2225	 9662	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.01408	 0.0	 1	 -30.0	 30.0;
	2225	 3029	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.01408	 0.0	 1	 -30.0	 30.0;
	2225	 2681	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.01408	 0.0	 1	 -30.0	 30.0;
	2225	 3535	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.01408	 0.0	 1	 -30.0	 30.0;
	1736	 12448	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.019924	 0.0	 1	 -30.0	 30.0;
	1736	 1701	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.019924	 0.0	 1	 -30.0	 30.0;
	1736	 5188	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.019924	 0.0	 1	 -30.0	 30.0;
	1736	 12217	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.019924	 0.0	 1	 -30.0	 30.0;
	1736	 4675	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.019924	 0.0	 1	 -30.0	 30.0;
	1736	 11729	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.019924	 0.0	 1	 -30.0	 30.0;
	1736	 4135	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.019924	 0.0	 1	 -30.0	 30.0;
	2917	 11230	 0.113636	 4.544034	 0.0	 7	 7	 7	 1.018546	 0.0	 1	 -30.0	 30.0;
	2917	 3650	 0.113636	 4.544034	 0.0	 7	 7	 7	 1.013574	 0.0	 1	 -30.0	 30.0;
	8505	 7142	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.020717	 0.0	 1	 -30.0	 30.0;
	8505	 5335	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.020717	 0.0	 1	 -30.0	 30.0;
	8505	 7289	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.020717	 0.0	 1	 -30.0	 30.0;
	8505	 3644	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.020717	 0.0	 1	 -30.0	 30.0;
	8505	 9179	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.020717	 0.0	 1	 -30.0	 30.0;
	8505	 3139	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.020717	 0.0	 1	 -30.0	 30.0;
	8505	 9775	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.020717	 0.0	 1	 -30.0	 30.0;
	8505	 3050	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.020717	 0.0	 1	 -30.0	 30.0;
	322	 3724	 0.000212	 0.008494	 0.0	 3718	 3718	 3718	 1.032123	 0.0	 1	 -30.0	 30.0;
	322	 10330	 0.000212	 0.008494	 0.0	 3718	 3718	 3718	 1.032123	 0.0	 1	 -30.0	 30.0;
	10861	 8573	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.010402	 0.0	 1	 -30.0	 30.0;
	10861	 2429	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.010402	 0.0	 1	 -30.0	 30.0;
	10861	 9061	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.010402	 0.0	 1	 -30.0	 30.0;
	10861	 12528	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.010402	 0.0	 1	 -30.0	 30.0;
	10861	 5963	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.010402	 0.0	 1	 -30.0	 30.0;
	10861	 13041	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.010402	 0.0	 1	 -30.0	 30.0;
	10861	 11467	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.010402	 0.0	 1	 -30.0	 30.0;
	10861	 9873	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.010402	 0.0	 1	 -30.0	 30.0;
	4525	 4264	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.016218	 0.0	 1	 -30.0	 30.0;
	4525	 354	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.016218	 0.0	 1	 -30.0	 30.0;
	4525	 7317	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.016218	 0.0	 1	 -30.0	 30.0;
	4525	 10527	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.016218	 0.0	 1	 -30.0	 30.0;
	4525	 3899	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.016218	 0.0	 1	 -30.0	 30.0;
	4525	 1972	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.016218	 0.0	 1	 -30.0	 30.0;
	4525	 11648	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.016218	 0.0	 1	 -30.0	 30.0;
	4525	 1514	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.016218	 0.0	 1	 -30.0	 30.0;
	4525	 8063	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.016218	 0.0	 1	 -30.0	 30.0;
	4525	 2877	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.016218	 0.0	 1	 -30.0	 30.0;
	8693	 9521	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.008217	 0.0	 1	 -30.0	 30.0;
	6185	 2410	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.011955	 0.0	 1	 -30.0	 30.0;
	4831	 9041	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.011309	 0.0	 1	 -30.0	 30.0;
	4831	 121	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.011309	 0.0	 1	 -30.0	 30.0;
	4831	 12911	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.011309	 0.0	 1	 -30.0	 30.0;
	4831	 6210	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.011309	 0.0	 1	 -30.0	 30.0;
	4831	 13303	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.011309	 0.0	 1	 -30.0	 30.0;
	4831	 5741	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.011309	 0.0	 1	 -30.0	 30.0;
	4831	 12822	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.011309	 0.0	 1	 -30.0	 30.0;
	4831	 7168	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.011309	 0.0	 1	 -30.0	 30.0;
	4831	 623	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.011309	 0.0	 1	 -30.0	 30.0;
	4831	 10384	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.011309	 0.0	 1	 -30.0	 30.0;
	210	 153	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.021101	 0.0	 1	 -30.0	 30.0;
	210	 8092	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.021101	 0.0	 1	 -30.0	 30.0;
	210	 1553	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.021101	 0.0	 1	 -30.0	 30.0;
	210	 9297	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.021101	 0.0	 1	 -30.0	 30.0;
	11596	 2210	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.021887	 0.0	 1	 -30.0	 30.0;
	11596	 9809	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.021887	 0.0	 1	 -30.0	 30.0;
	11596	 2700	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.021887	 0.0	 1	 -30.0	 30.0;
	11596	 8326	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.021887	 0.0	 1	 -30.0	 30.0;
	11596	 1288	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.021887	 0.0	 1	 -30.0	 30.0;
	11596	 8797	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.021887	 0.0	 1	 -30.0	 30.0;
	11596	 1757	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.021887	 0.0	 1	 -30.0	 30.0;
	11596	 11265	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.021887	 0.0	 1	 -30.0	 30.0;
	3591	 4193	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.012762	 0.0	 1	 -30.0	 30.0;
	3591	 259	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.012762	 0.0	 1	 -30.0	 30.0;
	11417	 6820	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.017812	 0.0	 1	 -30.0	 30.0;
	11417	 8851	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.017812	 0.0	 1	 -30.0	 30.0;
	11417	 6341	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.017812	 0.0	 1	 -30.0	 30.0;
	11417	 1202	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.017812	 0.0	 1	 -30.0	 30.0;
	11417	 7740	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.017812	 0.0	 1	 -30.0	 30.0;
	11417	 724	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.017812	 0.0	 1	 -30.0	 30.0;
	7621	 7242	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.017708	 0.0	 1	 -30.0	 30.0;
	7621	 13412	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.017708	 0.0	 1	 -30.0	 30.0;
	7621	 8686	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.017708	 0.0	 1	 -30.0	 30.0;
	7621	 10696	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.017708	 0.0	 1	 -30.0	 30.0;
	7621	 4074	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.017708	 0.0	 1	 -30.0	 30.0;
	7621	 11155	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.017708	 0.0	 1	 -30.0	 30.0;
	7621	 4594	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.017708	 0.0	 1	 -30.0	 30.0;
	7621	 11654	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.017708	 0.0	 1	 -30.0	 30.0;
	566	 5109	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.021154	 0.0	 1	 -30.0	 30.0;
	566	 12195	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.021154	 0.0	 1	 -30.0	 30.0;
	5209	 5641	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.014692	 0.0	 1	 -30.0	 30.0;
	5209	 12717	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.014692	 0.0	 1	 -30.0	 30.0;
	5209	 6107	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.014692	 0.0	 1	 -30.0	 30.0;
	5209	 12227	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.014692	 0.0	 1	 -30.0	 30.0;
	5209	 13174	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.014692	 0.0	 1	 -30.0	 30.0;
	5209	 7028	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.014692	 0.0	 1	 -30.0	 30.0;
	5209	 18	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.014692	 0.0	 1	 -30.0	 30.0;
	5209	 4384	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.014692	 0.0	 1	 -30.0	 30.0;
	5209	 477	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.014692	 0.0	 1	 -30.0	 30.0;
	11908	 7939	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.016774	 0.0	 1	 -30.0	 30.0;
	11908	 938	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.016774	 0.0	 1	 -30.0	 30.0;
	11908	 4563	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.016774	 0.0	 1	 -30.0	 30.0;
	11908	 11115	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.016774	 0.0	 1	 -30.0	 30.0;
	11908	 3323	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.016774	 0.0	 1	 -30.0	 30.0;
	4468	 12819	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.015232	 0.0	 1	 -30.0	 30.0;
	4468	 2796	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.015232	 0.0	 1	 -30.0	 30.0;
	4468	 9901	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.015232	 0.0	 1	 -30.0	 30.0;
	4468	 2332	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.015232	 0.0	 1	 -30.0	 30.0;
	4468	 9427	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.015232	 0.0	 1	 -30.0	 30.0;
	4468	 1889	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.015232	 0.0	 1	 -30.0	 30.0;
	8450	 29	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.009474	 0.0	 1	 -30.0	 30.0;
	13051	 9123	 0.002119	 0.084719	 0.0	 448	 448	 448	 1.034311	 0.0	 1	 -30.0	 30.0;
	13051	 2066	 0.002119	 0.084719	 0.0	 448	 448	 448	 1.034311	 0.0	 1	 -30.0	 30.0;
	9101	 4052	 0.004836	 0.193363	 0.0	 164	 164	 164	 1.006755	 0.0	 1	 -30.0	 30.0;
	9101	 2583	 0.004836	 0.193363	 0.0	 164	 164	 164	 1.001944	 0.0	 1	 -30.0	 30.0;
	9101	 9192	 0.004836	 0.193363	 0.0	 164	 164	 164	 1.001944	 0.0	 1	 -30.0	 30.0;
	10976	 8687	 0.002119	 0.084719	 0.0	 373	 373	 373	 0.993441	 0.0	 1	 -30.0	 30.0;
	10976	 721	 0.002119	 0.084719	 0.0	 373	 373	 373	 0.993441	 0.0	 1	 -30.0	 30.0;
	7247	 1685	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.024172	 0.0	 1	 -30.0	 30.0;
	7247	 8253	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.024172	 0.0	 1	 -30.0	 30.0;
	7247	 1208	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.024172	 0.0	 1	 -30.0	 30.0;
	8366	 12390	 0.000531	 0.021225	 0.0	 1787	 1787	 1787	 1.036935	 0.0	 1	 -30.0	 30.0;
	8366	 5354	 0.000531	 0.021225	 0.0	 1787	 1787	 1787	 1.036935	 0.0	 1	 -30.0	 30.0;
	11513	 5155	 0.000708	 0.02832	 0.0	 1340	 1340	 1340	 1.04316	 0.0	 1	 -30.0	 30.0;
	6415	 11704	 0.000708	 0.02832	 0.0	 1340	 1340	 1340	 1.04464	 0.0	 1	 -30.0	 30.0;
	3637	 5356	 0.002119	 0.084719	 0.0	 448	 448	 448	 1.03628	 0.0	 1	 -30.0	 30.0;
	3637	 3154	 0.002119	 0.084719	 0.0	 448	 448	 448	 1.03628	 0.0	 1	 -30.0	 30.0;
	4361	 5653	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.013203	 0.0	 1	 -30.0	 30.0;
	4361	 3508	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.013203	 0.0	 1	 -30.0	 30.0;
	1683	 6296	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.015199	 0.0	 1	 -30.0	 30.0;
	1683	 12900	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.015199	 0.0	 1	 -30.0	 30.0;
	12349	 2789	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.009563	 0.0	 1	 -30.0	 30.0;
	12349	 9422	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.009563	 0.0	 1	 -30.0	 30.0;
	12349	 8976	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.009563	 0.0	 1	 -30.0	 30.0;
	2563	 8961	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.007875	 0.0	 1	 -30.0	 30.0;
	2563	 2803	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.007875	 0.0	 1	 -30.0	 30.0;
	3144	 6440	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.009522	 0.0	 1	 -30.0	 30.0;
	3144	 8726	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.009522	 0.0	 1	 -30.0	 30.0;
	658	 7951	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.01597	 0.0	 1	 -30.0	 30.0;
	1403	 1896	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.006727	 0.0	 1	 -30.0	 30.0;
	425	 12537	 0.000212	 0.008494	 0.0	 4466	 4466	 4466	 1.039709	 0.0	 1	 -30.0	 30.0;
	425	 9148	 0.000212	 0.008494	 0.0	 4466	 4466	 4466	 1.03971	 0.0	 1	 -30.0	 30.0;
	12672	 7031	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.005675	 0.0	 1	 -30.0	 30.0;
	12672	 9288	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.005675	 0.0	 1	 -30.0	 30.0;
	10498	 6346	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.007155	 0.0	 1	 -30.0	 30.0;
	10498	 12400	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.007155	 0.0	 1	 -30.0	 30.0;
	10498	 5842	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.007155	 0.0	 1	 -30.0	 30.0;
	11164	 266	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.009142	 0.0	 1	 -30.0	 30.0;
	11164	 7249	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.009142	 0.0	 1	 -30.0	 30.0;
	11164	 13456	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.009142	 0.0	 1	 -30.0	 30.0;
	1926	 5592	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.000368	 0.0	 1	 -30.0	 30.0;
	1926	 496	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.000368	 0.0	 1	 -30.0	 30.0;
	3612	 4324	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.006795	 0.0	 1	 -30.0	 30.0;
	9112	 11065	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.016738	 0.0	 1	 -30.0	 30.0;
	9112	 3990	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.016738	 0.0	 1	 -30.0	 30.0;
	9112	 10612	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.016738	 0.0	 1	 -30.0	 30.0;
	6134	 3517	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.015029	 0.0	 1	 -30.0	 30.0;
	6134	 12091	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.015029	 0.0	 1	 -30.0	 30.0;
	6134	 5029	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.015029	 0.0	 1	 -30.0	 30.0;
	10024	 11577	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.009875	 0.0	 1	 -30.0	 30.0;
	10024	 4513	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.009875	 0.0	 1	 -30.0	 30.0;
	1034	 13086	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.012243	 0.0	 1	 -30.0	 30.0;
	1034	 6016	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.012243	 0.0	 1	 -30.0	 30.0;
	1034	 7933	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.012243	 0.0	 1	 -30.0	 30.0;
	2874	 1382	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.00515	 0.0	 1	 -30.0	 30.0;
	2874	 8415	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.00515	 0.0	 1	 -30.0	 30.0;
	11508	 1834	 0.013661	 0.546277	 0.0	 58	 58	 58	 1.002341	 0.0	 1	 -30.0	 30.0;
	12413	 8900	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.03175	 0.0	 1	 -30.0	 30.0;
	12413	 9321	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.03175	 0.0	 1	 -30.0	 30.0;
	9876	 9389	 0.020833	 0.833073	 0.0	 38	 38	 38	 1.004194	 0.0	 1	 -30.0	 30.0;
	2010	 2756	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.004507	 0.0	 1	 -30.0	 30.0;
	2010	 9860	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.004507	 0.0	 1	 -30.0	 30.0;
	9161	 3234	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.007962	 0.0	 1	 -30.0	 30.0;
	9161	 9169	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.007962	 0.0	 1	 -30.0	 30.0;
	8337	 5593	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.008019	 0.0	 1	 -30.0	 30.0;
	8337	 12681	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.008019	 0.0	 1	 -30.0	 30.0;
	11433	 6076	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.009669	 0.0	 1	 -30.0	 30.0;
	11433	 11145	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.009669	 0.0	 1	 -30.0	 30.0;
	11433	 4590	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.009669	 0.0	 1	 -30.0	 30.0;
	12371	 11652	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.00586	 0.0	 1	 -30.0	 30.0;
	12371	 5099	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.00586	 0.0	 1	 -30.0	 30.0;
	2511	 1031	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.023477	 0.0	 1	 -30.0	 30.0;
	2511	 7561	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.023477	 0.0	 1	 -30.0	 30.0;
	8917	 10218	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.007312	 0.0	 1	 -30.0	 30.0;
	8917	 8205	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.007312	 0.0	 1	 -30.0	 30.0;
	8917	 9081	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.007312	 0.0	 1	 -30.0	 30.0;
	7984	 11285	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.020825	 0.0	 1	 -30.0	 30.0;
	7984	 4752	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.020825	 0.0	 1	 -30.0	 30.0;
	7984	 7754	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.020825	 0.0	 1	 -30.0	 30.0;
	12860	 2627	 0.000531	 0.021225	 0.0	 1787	 1787	 1787	 1.054708	 0.0	 1	 -30.0	 30.0;
	12860	 9265	 0.000531	 0.021225	 0.0	 1787	 1787	 1787	 1.054708	 0.0	 1	 -30.0	 30.0;
	6424	 3543	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.025153	 0.0	 1	 -30.0	 30.0;
	6424	 10158	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.025153	 0.0	 1	 -30.0	 30.0;
	7584	 8109	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.01477	 0.0	 1	 -30.0	 30.0;
	7584	 11880	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.01477	 0.0	 1	 -30.0	 30.0;
	10664	 12563	 0.000531	 0.021225	 0.0	 1787	 1787	 1787	 1.037102	 0.0	 1	 -30.0	 30.0;
	5020	 2670	 0.002119	 0.084719	 0.0	 448	 448	 448	 1.030227	 0.0	 1	 -30.0	 30.0;
	5020	 9301	 0.002119	 0.084719	 0.0	 448	 448	 448	 1.030227	 0.0	 1	 -30.0	 30.0;
	9270	 12902	 0.006944	 0.277691	 0.0	 114	 114	 114	 1.012092	 0.0	 1	 -30.0	 30.0;
	9270	 5357	 0.006944	 0.277691	 0.0	 114	 114	 114	 1.004875	 0.0	 1	 -30.0	 30.0;
	12081	 12387	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.015132	 0.0	 1	 -30.0	 30.0;
	12081	 2790	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.015132	 0.0	 1	 -30.0	 30.0;
	9239	 5166	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.019313	 0.0	 1	 -30.0	 30.0;
	9239	 7146	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.019313	 0.0	 1	 -30.0	 30.0;
	7040	 937	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.009191	 0.0	 1	 -30.0	 30.0;
	7040	 8409	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.009191	 0.0	 1	 -30.0	 30.0;
	420	 1376	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.00599	 0.0	 1	 -30.0	 30.0;
	420	 6990	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.00599	 0.0	 1	 -30.0	 30.0;
	4827	 13639	 0.006831	 0.273139	 0.0	 116	 116	 116	 1.01509	 0.0	 1	 -30.0	 30.0;
	4827	 7167	 0.006831	 0.273139	 0.0	 116	 116	 116	 1.009134	 0.0	 1	 -30.0	 30.0;
	5659	 4718	 0.000531	 0.021225	 0.0	 1787	 1787	 1787	 1.033693	 0.0	 1	 -30.0	 30.0;
	9703	 2624	 0.000531	 0.021225	 0.0	 1787	 1787	 1787	 1.03365	 0.0	 1	 -30.0	 30.0;
	8673	 12636	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.011827	 0.0	 1	 -30.0	 30.0;
	8673	 7236	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.011827	 0.0	 1	 -30.0	 30.0;
	11431	 715	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.011851	 0.0	 1	 -30.0	 30.0;
	11431	 7700	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.011851	 0.0	 1	 -30.0	 30.0;
	13461	 11030	 0.002119	 0.084719	 0.0	 448	 448	 448	 1.043444	 0.0	 1	 -30.0	 30.0;
	8684	 8206	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.007837	 0.0	 1	 -30.0	 30.0;
	8684	 1641	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.007837	 0.0	 1	 -30.0	 30.0;
	2862	 11638	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.007064	 0.0	 1	 -30.0	 30.0;
	2862	 2102	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.007064	 0.0	 1	 -30.0	 30.0;
	3092	 5416	 0.005208	 0.208268	 0.0	 183	 183	 183	 1.030223	 0.0	 1	 -30.0	 30.0;
	3092	 12451	 0.005208	 0.208268	 0.0	 183	 183	 183	 1.030223	 0.0	 1	 -30.0	 30.0;
	3092	 10386	 0.005208	 0.208268	 0.0	 183	 183	 183	 1.030223	 0.0	 1	 -30.0	 30.0;
	8985	 3270	 0.020833	 0.833073	 0.0	 38	 38	 38	 1.003211	 0.0	 1	 -30.0	 30.0;
	6579	 9896	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.013992	 0.0	 1	 -30.0	 30.0;
	9454	 2785	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.999066	 0.0	 1	 -30.0	 30.0;
	9454	 2767	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.999066	 0.0	 1	 -30.0	 30.0;
	9454	 4282	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.999066	 0.0	 1	 -30.0	 30.0;
	6904	 10881	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.999253	 0.0	 1	 -30.0	 30.0;
	6904	 3771	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.999253	 0.0	 1	 -30.0	 30.0;
	6904	 10417	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.999253	 0.0	 1	 -30.0	 30.0;
	7629	 754	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.020652	 0.0	 1	 -30.0	 30.0;
	7629	 5456	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.020652	 0.0	 1	 -30.0	 30.0;
	2954	 6992	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.030856	 0.0	 1	 -30.0	 30.0;
	2954	 13147	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.030856	 0.0	 1	 -30.0	 30.0;
	2216	 4367	 0.000531	 0.021225	 0.0	 1787	 1787	 1787	 1.043072	 0.0	 1	 -30.0	 30.0;
	4769	 13322	 0.000531	 0.021225	 0.0	 1787	 1787	 1787	 1.037866	 0.0	 1	 -30.0	 30.0;
	4769	 4670	 0.000531	 0.021225	 0.0	 1787	 1787	 1787	 1.037866	 0.0	 1	 -30.0	 30.0;
	4769	 10715	 0.000531	 0.021225	 0.0	 1787	 1787	 1787	 1.037866	 0.0	 1	 -30.0	 30.0;
	2450	 11076	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.010814	 0.0	 1	 -30.0	 30.0;
	6856	 12208	 0.000531	 0.021225	 0.0	 1787	 1787	 1787	 1.041055	 0.0	 1	 -30.0	 30.0;
	6856	 5674	 0.000531	 0.021225	 0.0	 1787	 1787	 1787	 1.041055	 0.0	 1	 -30.0	 30.0;
	1380	 13467	 0.013736	 0.549279	 0.0	 58	 58	 58	 1.016236	 0.0	 1	 -30.0	 30.0;
	6945	 1906	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.009007	 0.0	 1	 -30.0	 30.0;
	6945	 4366	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.009007	 0.0	 1	 -30.0	 30.0;
	5744	 2351	 0.020661	 0.826188	 0.0	 39	 39	 39	 1.001301	 0.0	 1	 -30.0	 30.0;
	9066	 8958	 0.000212	 0.008494	 0.0	 3718	 3718	 3718	 1.026768	 0.0	 1	 -30.0	 30.0;
	12432	 3607	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.023314	 0.0	 1	 -30.0	 30.0;
	12432	 9738	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.023314	 0.0	 1	 -30.0	 30.0;
	12584	 9084	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.012083	 0.0	 1	 -30.0	 30.0;
	12584	 5444	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.012083	 0.0	 1	 -30.0	 30.0;
	10323	 12494	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.010488	 0.0	 1	 -30.0	 30.0;
	10323	 9035	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.010488	 0.0	 1	 -30.0	 30.0;
	10323	 1969	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.010488	 0.0	 1	 -30.0	 30.0;
	1986	 2592	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.010656	 0.0	 1	 -30.0	 30.0;
	11735	 7388	 0.000212	 0.008494	 0.0	 4466	 4466	 4466	 1.029522	 0.0	 1	 -30.0	 30.0;
	11735	 5797	 0.000531	 0.021225	 0.0	 1787	 1787	 1787	 1.030088	 0.0	 1	 -30.0	 30.0;
	11735	 12874	 0.000531	 0.021225	 0.0	 1787	 1787	 1787	 1.030088	 0.0	 1	 -30.0	 30.0;
	11735	 6903	 0.000531	 0.021225	 0.0	 1787	 1787	 1787	 1.030104	 0.0	 1	 -30.0	 30.0;
	11735	 13530	 0.000531	 0.021225	 0.0	 1787	 1787	 1787	 1.030104	 0.0	 1	 -30.0	 30.0;
	11735	 3280	 0.000708	 0.02832	 0.0	 1340	 1340	 1340	 1.032185	 0.0	 1	 -30.0	 30.0;
	11735	 11619	 0.000708	 0.02832	 0.0	 1340	 1340	 1340	 1.032185	 0.0	 1	 -30.0	 30.0;
	4523	 66	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.016289	 0.0	 1	 -30.0	 30.0;
	4523	 7073	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.016289	 0.0	 1	 -30.0	 30.0;
	13107	 533	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.004105	 0.0	 1	 -30.0	 30.0;
	6922	 7511	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.004095	 0.0	 1	 -30.0	 30.0;
	10124	 7551	 0.002133	 0.085298	 0.0	 371	 371	 371	 1.012741	 0.0	 1	 -30.0	 30.0;
	10124	 567	 0.002133	 0.085298	 0.0	 371	 371	 371	 1.006257	 0.0	 1	 -30.0	 30.0;
	7441	 5587	 0.000424	 0.016973	 0.0	 1861	 1861	 1861	 1.019586	 0.0	 1	 -30.0	 30.0;
	7678	 12665	 0.000424	 0.016973	 0.0	 1861	 1861	 1861	 1.020616	 0.0	 1	 -30.0	 30.0;
	10320	 6058	 0.000424	 0.016973	 0.0	 1861	 1861	 1861	 1.02349	 0.0	 1	 -30.0	 30.0;
	388	 13158	 0.000424	 0.016973	 0.0	 1861	 1861	 1861	 1.023498	 0.0	 1	 -30.0	 30.0;
	2913	 2964	 0.005747	 0.229813	 0.0	 138	 138	 138	 1.020977	 0.0	 1	 -30.0	 30.0;
	2913	 10100	 0.005747	 0.229813	 0.0	 138	 138	 138	 1.020977	 0.0	 1	 -30.0	 30.0;
	2913	 3474	 0.005747	 0.229813	 0.0	 138	 138	 138	 1.015977	 0.0	 1	 -30.0	 30.0;
	2913	 10581	 0.005747	 0.229813	 0.0	 138	 138	 138	 1.015977	 0.0	 1	 -30.0	 30.0;
	2913	 2056	 0.005747	 0.229813	 0.0	 138	 138	 138	 1.015977	 0.0	 1	 -30.0	 30.0;
	2913	 9109	 0.005747	 0.229813	 0.0	 138	 138	 138	 1.015977	 0.0	 1	 -30.0	 30.0;
	2913	 2496	 0.005747	 0.229813	 0.0	 138	 138	 138	 1.015977	 0.0	 1	 -30.0	 30.0;
	2913	 9604	 0.005747	 0.229813	 0.0	 138	 138	 138	 1.015977	 0.0	 1	 -30.0	 30.0;
	1898	 9597	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.016787	 0.0	 1	 -30.0	 30.0;
	11378	 8191	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.017272	 0.0	 1	 -30.0	 30.0;
	11378	 10249	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.017272	 0.0	 1	 -30.0	 30.0;
	11378	 6465	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.017272	 0.0	 1	 -30.0	 30.0;
	11378	 5764	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.017272	 0.0	 1	 -30.0	 30.0;
	11378	 12321	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.017272	 0.0	 1	 -30.0	 30.0;
	11378	 5292	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.017272	 0.0	 1	 -30.0	 30.0;
	11378	 11822	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.017272	 0.0	 1	 -30.0	 30.0;
	11378	 4777	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.017272	 0.0	 1	 -30.0	 30.0;
	11378	 11328	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.017272	 0.0	 1	 -30.0	 30.0;
	11378	 4252	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.017272	 0.0	 1	 -30.0	 30.0;
	11378	 10845	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.017272	 0.0	 1	 -30.0	 30.0;
	12707	 5637	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.018396	 0.0	 1	 -30.0	 30.0;
	12707	 5718	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.018396	 0.0	 1	 -30.0	 30.0;
	1282	 3823	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.009963	 0.0	 1	 -30.0	 30.0;
	1282	 10918	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.009963	 0.0	 1	 -30.0	 30.0;
	1282	 2368	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.009963	 0.0	 1	 -30.0	 30.0;
	1282	 470	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.009963	 0.0	 1	 -30.0	 30.0;
	1282	 4203	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.009963	 0.0	 1	 -30.0	 30.0;
	2985	 6651	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.014438	 0.0	 1	 -30.0	 30.0;
	2985	 10738	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.014438	 0.0	 1	 -30.0	 30.0;
	2985	 4120	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.014438	 0.0	 1	 -30.0	 30.0;
	2985	 2172	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.014438	 0.0	 1	 -30.0	 30.0;
	2985	 8753	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.014438	 0.0	 1	 -30.0	 30.0;
	2985	 9627	 0.000212	 0.008494	 0.0	 3718	 3718	 3718	 1.014172	 0.0	 1	 -30.0	 30.0;
	1282	 8770	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.011503	 0.0	 1	 -30.0	 30.0;
	1282	 819	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.011503	 0.0	 1	 -30.0	 30.0;
	1282	 3553	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.011503	 0.0	 1	 -30.0	 30.0;
	1282	 1262	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.011503	 0.0	 1	 -30.0	 30.0;
	6724	 11677	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.020245	 0.0	 1	 -30.0	 30.0;
	6724	 10390	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.020245	 0.0	 1	 -30.0	 30.0;
	5402	 4509	 0.000212	 0.008494	 0.0	 3718	 3718	 3718	 1.023751	 0.0	 1	 -30.0	 30.0;
	5402	 6085	 0.000212	 0.008494	 0.0	 3718	 3718	 3718	 1.023751	 0.0	 1	 -30.0	 30.0;
	10981	 3330	 0.01	 0.399875	 0.0	 79	 79	 79	 1.023355	 0.0	 1	 -30.0	 30.0;
	3238	 4309	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.02251	 0.0	 1	 -30.0	 30.0;
	3238	 585	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.02251	 0.0	 1	 -30.0	 30.0;
	3238	 3792	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.02251	 0.0	 1	 -30.0	 30.0;
	3238	 10901	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.02251	 0.0	 1	 -30.0	 30.0;
	3238	 3296	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.02251	 0.0	 1	 -30.0	 30.0;
	9831	 10406	 0.006068	 0.242643	 0.0	 131	 131	 131	 1.013469	 0.0	 1	 -30.0	 30.0;
	13656	 9206	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.027689	 0.0	 1	 -30.0	 30.0;
	13656	 2625	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.027689	 0.0	 1	 -30.0	 30.0;
	11702	 693	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.027677	 0.0	 1	 -30.0	 30.0;
	11702	 7233	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.027677	 0.0	 1	 -30.0	 30.0;
	9098	 11403	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.028413	 0.0	 1	 -30.0	 30.0;
	9098	 2053	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.028413	 0.0	 1	 -30.0	 30.0;
	9098	 7674	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.028413	 0.0	 1	 -30.0	 30.0;
	61	 13192	 0.000212	 0.008494	 0.0	 3718	 3718	 3718	 1.035966	 0.0	 1	 -30.0	 30.0;
	10744	 1559	 0.000531	 0.021225	 0.0	 1771	 1771	 1771	 1.080738	 0.0	 1	 -30.0	 30.0;
	10278	 2197	 0.000531	 0.021225	 0.0	 1787	 1787	 1787	 1.079849	 0.0	 1	 -30.0	 30.0;
	2474	 3922	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.017692	 0.0	 1	 -30.0	 30.0;
	2474	 11010	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.017692	 0.0	 1	 -30.0	 30.0;
	1286	 2955	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.017539	 0.0	 1	 -30.0	 30.0;
	7368	 10092	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.016598	 0.0	 1	 -30.0	 30.0;
	7368	 3471	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.016598	 0.0	 1	 -30.0	 30.0;
	9490	 10575	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.019432	 0.0	 1	 -30.0	 30.0;
	9490	 3947	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.019432	 0.0	 1	 -30.0	 30.0;
	9490	 11039	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.019432	 0.0	 1	 -30.0	 30.0;
	5329	 4483	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.016081	 0.0	 1	 -30.0	 30.0;
	5329	 11551	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.016081	 0.0	 1	 -30.0	 30.0;
	11941	 4985	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.022769	 0.0	 1	 -30.0	 30.0;
	11941	 12049	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.022769	 0.0	 1	 -30.0	 30.0;
	12482	 9408	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.030673	 0.0	 1	 -30.0	 30.0;
	12482	 7499	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.030673	 0.0	 1	 -30.0	 30.0;
	5577	 5761	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.004987	 0.0	 1	 -30.0	 30.0;
	5577	 12310	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.004987	 0.0	 1	 -30.0	 30.0;
	5577	 7164	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.004987	 0.0	 1	 -30.0	 30.0;
	5577	 182	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.004987	 0.0	 1	 -30.0	 30.0;
	1506	 10165	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.028483	 0.0	 1	 -30.0	 30.0;
	5015	 5036	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.017975	 0.0	 1	 -30.0	 30.0;
	5015	 13658	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.017975	 0.0	 1	 -30.0	 30.0;
	6113	 3165	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.019664	 0.0	 1	 -30.0	 30.0;
	9643	 5517	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.016681	 0.0	 1	 -30.0	 30.0;
	10689	 6847	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.01291	 0.0	 1	 -30.0	 30.0;
	10689	 12973	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.01291	 0.0	 1	 -30.0	 30.0;
	3601	 10987	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.011987	 0.0	 1	 -30.0	 30.0;
	3601	 753	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.011987	 0.0	 1	 -30.0	 30.0;
	5572	 7734	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.010487	 0.0	 1	 -30.0	 30.0;
	5572	 289	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.010493	 0.0	 1	 -30.0	 30.0;
	6653	 7071	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.025474	 0.0	 1	 -30.0	 30.0;
	6653	 13235	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.025474	 0.0	 1	 -30.0	 30.0;
	6653	 6620	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.025474	 0.0	 1	 -30.0	 30.0;
	6653	 10505	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.025474	 0.0	 1	 -30.0	 30.0;
	6653	 6729	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.025474	 0.0	 1	 -30.0	 30.0;
	6653	 11786	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.025474	 0.0	 1	 -30.0	 30.0;
	537	 9852	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.019566	 0.0	 1	 -30.0	 30.0;
	530	 3224	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.026211	 0.0	 1	 -30.0	 30.0;
	13654	 4400	 0.000531	 0.021225	 0.0	 1787	 1787	 1787	 1.035648	 0.0	 1	 -30.0	 30.0;
	13654	 11982	 0.000531	 0.021225	 0.0	 1787	 1787	 1787	 1.035648	 0.0	 1	 -30.0	 30.0;
	13654	 4928	 0.000531	 0.021225	 0.0	 1787	 1787	 1787	 1.035648	 0.0	 1	 -30.0	 30.0;
	488	 476	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 0.990884	 0.0	 1	 -30.0	 30.0;
	4669	 4371	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.022655	 0.0	 1	 -30.0	 30.0;
	6887	 12381	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.008553	 0.0	 1	 -30.0	 30.0;
	6887	 5350	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.008553	 0.0	 1	 -30.0	 30.0;
	5153	 12914	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.008542	 0.0	 1	 -30.0	 30.0;
	5153	 5825	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.008542	 0.0	 1	 -30.0	 30.0;
	12209	 1394	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.014772	 0.0	 1	 -30.0	 30.0;
	13263	 6667	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.014886	 0.0	 1	 -30.0	 30.0;
	10020	 229	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.013241	 0.0	 1	 -30.0	 30.0;
	10020	 6769	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.013241	 0.0	 1	 -30.0	 30.0;
	7817	 10388	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.01327	 0.0	 1	 -30.0	 30.0;
	7817	 6842	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.01327	 0.0	 1	 -30.0	 30.0;
	4463	 2301	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.016044	 0.0	 1	 -30.0	 30.0;
	4104	 2561	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.009961	 0.0	 1	 -30.0	 30.0;
	4104	 8651	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.009961	 0.0	 1	 -30.0	 30.0;
	7423	 11504	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.010373	 0.0	 1	 -30.0	 30.0;
	8031	 13012	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.0253	 0.0	 1	 -30.0	 30.0;
	8031	 1636	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.022618	 0.0	 1	 -30.0	 30.0;
	8031	 7712	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.022618	 0.0	 1	 -30.0	 30.0;
	2109	 7005	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.016125	 0.0	 1	 -30.0	 30.0;
	2109	 492	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.014629	 0.0	 1	 -30.0	 30.0;
	2109	 7045	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.014629	 0.0	 1	 -30.0	 30.0;
	2121	 5534	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.019116	 0.0	 1	 -30.0	 30.0;
	2121	 12606	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.019116	 0.0	 1	 -30.0	 30.0;
	7741	 5034	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.019552	 0.0	 1	 -30.0	 30.0;
	4071	 13620	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.018741	 0.0	 1	 -30.0	 30.0;
	4071	 6500	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.018741	 0.0	 1	 -30.0	 30.0;
	4071	 13123	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.018741	 0.0	 1	 -30.0	 30.0;
	7101	 4013	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 0.98444	 0.0	 1	 -30.0	 30.0;
	7101	 11096	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 0.98444	 0.0	 1	 -30.0	 30.0;
	1585	 3551	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.026268	 0.0	 1	 -30.0	 30.0;
	1585	 10647	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.026268	 0.0	 1	 -30.0	 30.0;
	374	 2819	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.010526	 0.0	 1	 -30.0	 30.0;
	374	 5575	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.010526	 0.0	 1	 -30.0	 30.0;
	11767	 5023	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.022689	 0.0	 1	 -30.0	 30.0;
	11767	 11586	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.022689	 0.0	 1	 -30.0	 30.0;
	10265	 9815	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.998115	 0.0	 1	 -30.0	 30.0;
	843	 2642	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.004532	 0.0	 1	 -30.0	 30.0;
	11297	 4344	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.003947	 0.0	 1	 -30.0	 30.0;
	11297	 778	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.003947	 0.0	 1	 -30.0	 30.0;
	8020	 6476	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.01097	 0.0	 1	 -30.0	 30.0;
	2452	 13079	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.018906	 0.0	 1	 -30.0	 30.0;
	2452	 7654	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.018728	 0.0	 1	 -30.0	 30.0;
	4736	 12016	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.018853	 0.0	 1	 -30.0	 30.0;
	4736	 13333	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.018853	 0.0	 1	 -30.0	 30.0;
	10338	 1561	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.013748	 0.0	 1	 -30.0	 30.0;
	7483	 2559	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.007021	 0.0	 1	 -30.0	 30.0;
	7483	 11588	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.007021	 0.0	 1	 -30.0	 30.0;
	4373	 3031	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.013739	 0.0	 1	 -30.0	 30.0;
	11541	 648	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.000552	 0.0	 1	 -30.0	 30.0;
	3208	 328	 0.003521	 0.140801	 0.0	 225	 225	 225	 0.99659	 0.0	 1	 -30.0	 30.0;
	2802	 6886	 0.003521	 0.140801	 0.0	 225	 225	 225	 0.996518	 0.0	 1	 -30.0	 30.0;
	2754	 8772	 0.003521	 0.140801	 0.0	 225	 225	 225	 0.996625	 0.0	 1	 -30.0	 30.0;
	1405	 7474	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.997192	 0.0	 1	 -30.0	 30.0;
	11590	 248	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.013833	 0.0	 1	 -30.0	 30.0;
	13563	 1629	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.013822	 0.0	 1	 -30.0	 30.0;
	6805	 1419	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.021964	 0.0	 1	 -30.0	 30.0;
	6805	 8447	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.021964	 0.0	 1	 -30.0	 30.0;
	10360	 956	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.020059	 0.0	 1	 -30.0	 30.0;
	10360	 7342	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.020059	 0.0	 1	 -30.0	 30.0;
	12963	 12794	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.014455	 0.0	 1	 -30.0	 30.0;
	1107	 5714	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.014539	 0.0	 1	 -30.0	 30.0;
	317	 358	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.020862	 0.0	 1	 -30.0	 30.0;
	4850	 7334	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.025181	 0.0	 1	 -30.0	 30.0;
	4850	 13560	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.025181	 0.0	 1	 -30.0	 30.0;
	4850	 10567	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.025243	 0.0	 1	 -30.0	 30.0;
	12364	 7929	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.012377	 0.0	 1	 -30.0	 30.0;
	12364	 10102	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.012377	 0.0	 1	 -30.0	 30.0;
	10131	 828	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.012069	 0.0	 1	 -30.0	 30.0;
	1141	 7808	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.02645	 0.0	 1	 -30.0	 30.0;
	1141	 12065	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.02645	 0.0	 1	 -30.0	 30.0;
	1141	 5503	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.025452	 0.0	 1	 -30.0	 30.0;
	13004	 11578	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.990651	 0.0	 1	 -30.0	 30.0;
	399	 8914	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.006118	 0.0	 1	 -30.0	 30.0;
	399	 2292	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.006118	 0.0	 1	 -30.0	 30.0;
	9019	 9387	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.006561	 0.0	 1	 -30.0	 30.0;
	9019	 932	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.006561	 0.0	 1	 -30.0	 30.0;
	5874	 7931	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.016527	 0.0	 1	 -30.0	 30.0;
	7534	 2894	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.020891	 0.0	 1	 -30.0	 30.0;
	7534	 9527	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.020891	 0.0	 1	 -30.0	 30.0;
	1998	 1552	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.022077	 0.0	 1	 -30.0	 30.0;
	1998	 8097	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.022077	 0.0	 1	 -30.0	 30.0;
	4318	 9875	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.025043	 0.0	 1	 -30.0	 30.0;
	4318	 2760	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.025043	 0.0	 1	 -30.0	 30.0;
	4318	 10357	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.025043	 0.0	 1	 -30.0	 30.0;
	4318	 3255	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.025043	 0.0	 1	 -30.0	 30.0;
	4318	 13137	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.025221	 0.0	 1	 -30.0	 30.0;
	4318	 1851	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.025221	 0.0	 1	 -30.0	 30.0;
	4318	 9392	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.025221	 0.0	 1	 -30.0	 30.0;
	4318	 2302	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.025221	 0.0	 1	 -30.0	 30.0;
	8240	 10946	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.016109	 0.0	 1	 -30.0	 30.0;
	8472	 13145	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.024494	 0.0	 1	 -30.0	 30.0;
	5555	 13081	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.002029	 0.0	 1	 -30.0	 30.0;
	6712	 6477	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.012988	 0.0	 1	 -30.0	 30.0;
	6712	 12570	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.012988	 0.0	 1	 -30.0	 30.0;
	13061	 4622	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.020316	 0.0	 1	 -30.0	 30.0;
	5474	 12088	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.998327	 0.0	 1	 -30.0	 30.0;
	200	 5512	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.998339	 0.0	 1	 -30.0	 30.0;
	9356	 11579	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.026884	 0.0	 1	 -30.0	 30.0;
	9356	 5025	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.026884	 0.0	 1	 -30.0	 30.0;
	4325	 532	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.021429	 0.0	 1	 -30.0	 30.0;
	4325	 7072	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.021429	 0.0	 1	 -30.0	 30.0;
	10849	 12373	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.022217	 0.0	 1	 -30.0	 30.0;
	10849	 5816	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.022217	 0.0	 1	 -30.0	 30.0;
	9162	 9250	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.017502	 0.0	 1	 -30.0	 30.0;
	9162	 3463	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.017502	 0.0	 1	 -30.0	 30.0;
	4316	 6713	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.003702	 0.0	 1	 -30.0	 30.0;
	7104	 3943	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.0207	 0.0	 1	 -30.0	 30.0;
	5867	 12477	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.014852	 0.0	 1	 -30.0	 30.0;
	5867	 5911	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.014852	 0.0	 1	 -30.0	 30.0;
	2926	 12013	 0.001328	 0.05309	 0.0	 595	 595	 595	 1.015309	 0.0	 1	 -30.0	 30.0;
	857	 4952	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.019486	 0.0	 1	 -30.0	 30.0;
	9320	 11037	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.009842	 0.0	 1	 -30.0	 30.0;
	12514	 4473	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.018644	 0.0	 1	 -30.0	 30.0;
	3952	 1369	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.0148	 0.0	 1	 -30.0	 30.0;
	3952	 7925	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.0148	 0.0	 1	 -30.0	 30.0;
	3952	 925	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.0148	 0.0	 1	 -30.0	 30.0;
	3952	 3469	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.011666	 0.0	 1	 -30.0	 30.0;
	611	 6096	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.992718	 0.0	 1	 -30.0	 30.0;
	3532	 9542	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.988462	 0.0	 1	 -30.0	 30.0;
	3532	 4256	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.988462	 0.0	 1	 -30.0	 30.0;
	9390	 10841	 0.002119	 0.084719	 0.0	 373	 373	 373	 0.990449	 0.0	 1	 -30.0	 30.0;
	9390	 9556	 0.002119	 0.084719	 0.0	 373	 373	 373	 0.990449	 0.0	 1	 -30.0	 30.0;
	11547	 9690	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.018049	 0.0	 1	 -30.0	 30.0;
	11547	 2584	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.018049	 0.0	 1	 -30.0	 30.0;
	11488	 12799	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.01708	 0.0	 1	 -30.0	 30.0;
	11488	 4686	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.01708	 0.0	 1	 -30.0	 30.0;
	11488	 11251	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.01708	 0.0	 1	 -30.0	 30.0;
	49	 4126	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.001032	 0.0	 1	 -30.0	 30.0;
	1681	 11214	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.000717	 0.0	 1	 -30.0	 30.0;
	574	 3646	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.005173	 0.0	 1	 -30.0	 30.0;
	574	 10743	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.005173	 0.0	 1	 -30.0	 30.0;
	574	 1070	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.005173	 0.0	 1	 -30.0	 30.0;
	5461	 7613	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.999317	 0.0	 1	 -30.0	 30.0;
	5461	 1532	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.999317	 0.0	 1	 -30.0	 30.0;
	6248	 8089	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.002569	 0.0	 1	 -30.0	 30.0;
	12976	 12042	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.002186	 0.0	 1	 -30.0	 30.0;
	13210	 8563	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.999674	 0.0	 1	 -30.0	 30.0;
	13210	 2458	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.999674	 0.0	 1	 -30.0	 30.0;
	9451	 12419	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.001874	 0.0	 1	 -30.0	 30.0;
	9451	 9120	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.001874	 0.0	 1	 -30.0	 30.0;
	9451	 2063	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.001874	 0.0	 1	 -30.0	 30.0;
	4093	 4167	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.997667	 0.0	 1	 -30.0	 30.0;
	4093	 11250	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.997667	 0.0	 1	 -30.0	 30.0;
	4093	 1359	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.997667	 0.0	 1	 -30.0	 30.0;
	4093	 11773	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.997667	 0.0	 1	 -30.0	 30.0;
	2404	 3166	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.000999	 0.0	 1	 -30.0	 30.0;
	2404	 10283	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.000999	 0.0	 1	 -30.0	 30.0;
	2404	 3680	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.000999	 0.0	 1	 -30.0	 30.0;
	9259	 4130	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 0.997419	 0.0	 1	 -30.0	 30.0;
	5259	 6195	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.999525	 0.0	 1	 -30.0	 30.0;
	5259	 13298	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.999525	 0.0	 1	 -30.0	 30.0;
	1129	 8421	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.999538	 0.0	 1	 -30.0	 30.0;
	1129	 2222	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.999538	 0.0	 1	 -30.0	 30.0;
	1016	 11377	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 0.9975	 0.0	 1	 -30.0	 30.0;
	8230	 1796	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 0.996803	 0.0	 1	 -30.0	 30.0;
	6356	 11895	 0.003521	 0.140801	 0.0	 225	 225	 225	 0.996434	 0.0	 1	 -30.0	 30.0;
	6356	 13232	 0.003521	 0.140801	 0.0	 225	 225	 225	 0.996434	 0.0	 1	 -30.0	 30.0;
	6356	 1043	 0.003521	 0.140801	 0.0	 225	 225	 225	 0.996434	 0.0	 1	 -30.0	 30.0;
	2846	 8945	 0.003521	 0.140801	 0.0	 225	 225	 225	 0.993484	 0.0	 1	 -30.0	 30.0;
	2846	 2787	 0.003521	 0.140801	 0.0	 225	 225	 225	 0.993484	 0.0	 1	 -30.0	 30.0;
	2846	 9417	 0.003521	 0.140801	 0.0	 225	 225	 225	 0.993484	 0.0	 1	 -30.0	 30.0;
	915	 9282	 0.003521	 0.140801	 0.0	 225	 225	 225	 0.989587	 0.0	 1	 -30.0	 30.0;
	915	 2647	 0.003521	 0.140801	 0.0	 225	 225	 225	 0.989587	 0.0	 1	 -30.0	 30.0;
	915	 9756	 0.003521	 0.140801	 0.0	 225	 225	 225	 0.989587	 0.0	 1	 -30.0	 30.0;
	11381	 3396	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.003999	 0.0	 1	 -30.0	 30.0;
	11381	 11473	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.003999	 0.0	 1	 -30.0	 30.0;
	11381	 4925	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.003999	 0.0	 1	 -30.0	 30.0;
	960	 10978	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.010194	 0.0	 1	 -30.0	 30.0;
	960	 4411	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.010194	 0.0	 1	 -30.0	 30.0;
	960	 10862	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.010194	 0.0	 1	 -30.0	 30.0;
	5860	 1960	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.010498	 0.0	 1	 -30.0	 30.0;
	5860	 115	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.010498	 0.0	 1	 -30.0	 30.0;
	4401	 6066	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 0.99924	 0.0	 1	 -30.0	 30.0;
	2240	 11745	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.026659	 0.0	 1	 -30.0	 30.0;
	2240	 4697	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.026659	 0.0	 1	 -30.0	 30.0;
	12752	 11226	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.020882	 0.0	 1	 -30.0	 30.0;
	12752	 3663	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.020882	 0.0	 1	 -30.0	 30.0;
	12752	 9793	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.020882	 0.0	 1	 -30.0	 30.0;
	10741	 6156	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.016153	 0.0	 1	 -30.0	 30.0;
	10741	 11716	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.016153	 0.0	 1	 -30.0	 30.0;
	4033	 1013	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.993208	 0.0	 1	 -30.0	 30.0;
	4033	 9138	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.993208	 0.0	 1	 -30.0	 30.0;
	8480	 10037	 0.003521	 0.140801	 0.0	 225	 225	 225	 0.993172	 0.0	 1	 -30.0	 30.0;
	8480	 1869	 0.003521	 0.140801	 0.0	 225	 225	 225	 0.993172	 0.0	 1	 -30.0	 30.0;
	8480	 12388	 0.003521	 0.140801	 0.0	 225	 225	 225	 0.993172	 0.0	 1	 -30.0	 30.0;
	5565	 10110	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.996909	 0.0	 1	 -30.0	 30.0;
	5565	 7976	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.996909	 0.0	 1	 -30.0	 30.0;
	5565	 9314	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.996909	 0.0	 1	 -30.0	 30.0;
	3809	 10534	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.004248	 0.0	 1	 -30.0	 30.0;
	3809	 4949	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.004248	 0.0	 1	 -30.0	 30.0;
	3809	 11986	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.004248	 0.0	 1	 -30.0	 30.0;
	1490	 10017	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.018767	 0.0	 1	 -30.0	 30.0;
	1490	 3403	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.018767	 0.0	 1	 -30.0	 30.0;
	1490	 9508	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.018767	 0.0	 1	 -30.0	 30.0;
	12185	 4793	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.002358	 0.0	 1	 -30.0	 30.0;
	12185	 13330	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.002358	 0.0	 1	 -30.0	 30.0;
	12185	 10223	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.002358	 0.0	 1	 -30.0	 30.0;
	3140	 8538	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.007799	 0.0	 1	 -30.0	 30.0;
	3140	 1963	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.007799	 0.0	 1	 -30.0	 30.0;
	3140	 11975	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.007799	 0.0	 1	 -30.0	 30.0;
	9050	 7156	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.997082	 0.0	 1	 -30.0	 30.0;
	9050	 5715	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.997082	 0.0	 1	 -30.0	 30.0;
	11216	 5896	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.016528	 0.0	 1	 -30.0	 30.0;
	11216	 13468	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.016528	 0.0	 1	 -30.0	 30.0;
	11216	 6363	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.016528	 0.0	 1	 -30.0	 30.0;
	2848	 11976	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.027914	 0.0	 1	 -30.0	 30.0;
	2848	 4922	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.027914	 0.0	 1	 -30.0	 30.0;
	2848	 12459	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.027914	 0.0	 1	 -30.0	 30.0;
	5799	 8655	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.009997	 0.0	 1	 -30.0	 30.0;
	5799	 8912	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.009997	 0.0	 1	 -30.0	 30.0;
	5799	 1839	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.009997	 0.0	 1	 -30.0	 30.0;
	5799	 11558	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.009997	 0.0	 1	 -30.0	 30.0;
	5799	 4998	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.009997	 0.0	 1	 -30.0	 30.0;
	5799	 11051	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.009997	 0.0	 1	 -30.0	 30.0;
	5799	 4499	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.009997	 0.0	 1	 -30.0	 30.0;
	5799	 10589	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.009997	 0.0	 1	 -30.0	 30.0;
	5799	 3971	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.009997	 0.0	 1	 -30.0	 30.0;
	5799	 10101	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.009997	 0.0	 1	 -30.0	 30.0;
	10826	 3482	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.004834	 0.0	 1	 -30.0	 30.0;
	10826	 9613	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.004834	 0.0	 1	 -30.0	 30.0;
	10826	 2976	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.004834	 0.0	 1	 -30.0	 30.0;
	10826	 8387	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.004834	 0.0	 1	 -30.0	 30.0;
	10826	 1344	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.004834	 0.0	 1	 -30.0	 30.0;
	10826	 10617	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.004834	 0.0	 1	 -30.0	 30.0;
	10826	 901	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.004834	 0.0	 1	 -30.0	 30.0;
	10826	 9359	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.004834	 0.0	 1	 -30.0	 30.0;
	10826	 681	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.004834	 0.0	 1	 -30.0	 30.0;
	10826	 8884	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.004834	 0.0	 1	 -30.0	 30.0;
	10180	 7849	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.016245	 0.0	 1	 -30.0	 30.0;
	9689	 11736	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.016673	 0.0	 1	 -30.0	 30.0;
	10859	 2569	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.011995	 0.0	 1	 -30.0	 30.0;
	7106	 1627	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.018131	 0.0	 1	 -30.0	 30.0;
	4150	 10373	 0.001059	 0.04236	 0.0	 746	 746	 746	 1.019146	 0.0	 1	 -30.0	 30.0;
	119	 5192	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.01486	 0.0	 1	 -30.0	 30.0;
	8722	 921	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.004646	 0.0	 1	 -30.0	 30.0;
	8722	 676	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.004646	 0.0	 1	 -30.0	 30.0;
	8722	 1372	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.004646	 0.0	 1	 -30.0	 30.0;
	8722	 8894	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.004646	 0.0	 1	 -30.0	 30.0;
	8410	 5138	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.009277	 0.0	 1	 -30.0	 30.0;
	8410	 10246	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.009277	 0.0	 1	 -30.0	 30.0;
	8410	 3633	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.009277	 0.0	 1	 -30.0	 30.0;
	8410	 9342	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.009277	 0.0	 1	 -30.0	 30.0;
	1303	 3984	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.014305	 0.0	 1	 -30.0	 30.0;
	1303	 12415	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.014305	 0.0	 1	 -30.0	 30.0;
	1303	 4505	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.014305	 0.0	 1	 -30.0	 30.0;
	3116	 2205	 0.025773	 1.030606	 0.0	 31	 31	 31	 1.003846	 0.0	 1	 -30.0	 30.0;
	3116	 8791	 0.025773	 1.030606	 0.0	 31	 31	 31	 1.00377	 0.0	 1	 -30.0	 30.0;
	7896	 10448	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.026048	 0.0	 1	 -30.0	 30.0;
	7896	 3343	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.026048	 0.0	 1	 -30.0	 30.0;
	7896	 7133	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.026048	 0.0	 1	 -30.0	 30.0;
	7896	 134	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.026048	 0.0	 1	 -30.0	 30.0;
	10888	 197	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.012659	 0.0	 1	 -30.0	 30.0;
	10888	 6734	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.012659	 0.0	 1	 -30.0	 30.0;
	10888	 926	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.012659	 0.0	 1	 -30.0	 30.0;
	5604	 12411	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.005436	 0.0	 1	 -30.0	 30.0;
	5604	 5850	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.005436	 0.0	 1	 -30.0	 30.0;
	5604	 12934	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.005436	 0.0	 1	 -30.0	 30.0;
	5604	 6331	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.005436	 0.0	 1	 -30.0	 30.0;
	1388	 7354	 0.000212	 0.008494	 0.0	 3718	 3718	 3718	 1.010913	 0.0	 1	 -30.0	 30.0;
	1388	 11521	 0.000212	 0.008494	 0.0	 3718	 3718	 3718	 1.010913	 0.0	 1	 -30.0	 30.0;
	1388	 4959	 0.000212	 0.008494	 0.0	 3718	 3718	 3718	 1.010913	 0.0	 1	 -30.0	 30.0;
	2306	 3409	 0.013298	 0.531749	 0.0	 60	 60	 60	 1.010032	 0.0	 1	 -30.0	 30.0;
	2306	 10022	 0.013298	 0.531749	 0.0	 60	 60	 60	 1.004611	 0.0	 1	 -30.0	 30.0;
	2306	 3886	 0.013298	 0.531749	 0.0	 60	 60	 60	 1.004611	 0.0	 1	 -30.0	 30.0;
	2306	 10516	 0.013298	 0.531749	 0.0	 60	 60	 60	 1.004611	 0.0	 1	 -30.0	 30.0;
	6137	 12097	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.004259	 0.0	 1	 -30.0	 30.0;
	6137	 5546	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.004259	 0.0	 1	 -30.0	 30.0;
	6137	 7539	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.004259	 0.0	 1	 -30.0	 30.0;
	6137	 6025	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.004259	 0.0	 1	 -30.0	 30.0;
	6137	 8519	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.004259	 0.0	 1	 -30.0	 30.0;
	6137	 8389	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.004259	 0.0	 1	 -30.0	 30.0;
	6137	 2510	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.004259	 0.0	 1	 -30.0	 30.0;
	6137	 815	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.004259	 0.0	 1	 -30.0	 30.0;
	1029	 3893	 0.012755	 0.510045	 0.0	 62	 62	 62	 1.022966	 0.0	 1	 -30.0	 30.0;
	1029	 10986	 0.012755	 0.510045	 0.0	 62	 62	 62	 1.017812	 0.0	 1	 -30.0	 30.0;
	1029	 3434	 0.012755	 0.510045	 0.0	 62	 62	 62	 1.017812	 0.0	 1	 -30.0	 30.0;
	1029	 10520	 0.012755	 0.510045	 0.0	 62	 62	 62	 1.017812	 0.0	 1	 -30.0	 30.0;
	12004	 1123	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.015216	 0.0	 1	 -30.0	 30.0;
	12004	 7667	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.015216	 0.0	 1	 -30.0	 30.0;
	12004	 4495	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.015216	 0.0	 1	 -30.0	 30.0;
	12004	 11049	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.015216	 0.0	 1	 -30.0	 30.0;
	12004	 10629	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.015216	 0.0	 1	 -30.0	 30.0;
	12004	 4000	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.015216	 0.0	 1	 -30.0	 30.0;
	12004	 6912	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.015216	 0.0	 1	 -30.0	 30.0;
	290	 2464	 0.039062	 1.562012	 0.0	 21	 21	 21	 1.005436	 0.0	 1	 -30.0	 30.0;
	2064	 5135	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.005105	 0.0	 1	 -30.0	 30.0;
	2064	 12211	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.005105	 0.0	 1	 -30.0	 30.0;
	2064	 4616	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.005105	 0.0	 1	 -30.0	 30.0;
	2064	 11680	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.005105	 0.0	 1	 -30.0	 30.0;
	2064	 4102	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.005105	 0.0	 1	 -30.0	 30.0;
	11501	 1104	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.001065	 0.0	 1	 -30.0	 30.0;
	11501	 1055	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.001065	 0.0	 1	 -30.0	 30.0;
	11501	 408	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.001065	 0.0	 1	 -30.0	 30.0;
	11501	 7371	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.001065	 0.0	 1	 -30.0	 30.0;
	11501	 5391	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.001065	 0.0	 1	 -30.0	 30.0;
	11501	 8820	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.001065	 0.0	 1	 -30.0	 30.0;
	3786	 10998	 0.000212	 0.008494	 0.0	 3718	 3718	 3718	 1.020727	 0.0	 1	 -30.0	 30.0;
	3786	 3265	 0.000212	 0.008494	 0.0	 3718	 3718	 3718	 1.020727	 0.0	 1	 -30.0	 30.0;
	2557	 13607	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.004215	 0.0	 1	 -30.0	 30.0;
	2557	 4987	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.004215	 0.0	 1	 -30.0	 30.0;
	6841	 4326	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.000189	 0.0	 1	 -30.0	 30.0;
	6841	 12542	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.000189	 0.0	 1	 -30.0	 30.0;
	6841	 5977	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.000189	 0.0	 1	 -30.0	 30.0;
	8978	 12045	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.001074	 0.0	 1	 -30.0	 30.0;
	1377	 5490	 0.009653	 0.38598	 0.0	 82	 82	 82	 0.999185	 0.0	 1	 -30.0	 30.0;
	1377	 11560	 0.009653	 0.38598	 0.0	 82	 82	 82	 0.993513	 0.0	 1	 -30.0	 30.0;
	1377	 2809	 0.009653	 0.38598	 0.0	 82	 82	 82	 0.993513	 0.0	 1	 -30.0	 30.0;
	1377	 12323	 0.009653	 0.38598	 0.0	 82	 82	 82	 0.993513	 0.0	 1	 -30.0	 30.0;
	1377	 188	 0.009653	 0.38598	 0.0	 82	 82	 82	 0.993513	 0.0	 1	 -30.0	 30.0;
	7876	 4703	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.004786	 0.0	 1	 -30.0	 30.0;
	7876	 11749	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.004786	 0.0	 1	 -30.0	 30.0;
	7876	 9713	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.004786	 0.0	 1	 -30.0	 30.0;
	7876	 2610	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.004786	 0.0	 1	 -30.0	 30.0;
	13307	 9144	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.011119	 0.0	 1	 -30.0	 30.0;
	13307	 1423	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.011119	 0.0	 1	 -30.0	 30.0;
	13307	 6998	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.011119	 0.0	 1	 -30.0	 30.0;
	13307	 4347	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.011119	 0.0	 1	 -30.0	 30.0;
	13307	 10120	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.011119	 0.0	 1	 -30.0	 30.0;
	1996	 1462	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.007174	 0.0	 1	 -30.0	 30.0;
	1996	 9512	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.007174	 0.0	 1	 -30.0	 30.0;
	1996	 2408	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.007174	 0.0	 1	 -30.0	 30.0;
	1996	 841	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.007174	 0.0	 1	 -30.0	 30.0;
	1996	 7351	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.007174	 0.0	 1	 -30.0	 30.0;
	1996	 1274	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.007174	 0.0	 1	 -30.0	 30.0;
	1996	 6650	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.007174	 0.0	 1	 -30.0	 30.0;
	1996	 13569	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.007174	 0.0	 1	 -30.0	 30.0;
	10312	 637	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.016623	 0.0	 1	 -30.0	 30.0;
	10312	 7634	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.016623	 0.0	 1	 -30.0	 30.0;
	3461	 12786	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.005028	 0.0	 1	 -30.0	 30.0;
	3461	 7122	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.005028	 0.0	 1	 -30.0	 30.0;
	3461	 7304	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.005028	 0.0	 1	 -30.0	 30.0;
	3461	 9357	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.005028	 0.0	 1	 -30.0	 30.0;
	3461	 1257	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.005028	 0.0	 1	 -30.0	 30.0;
	3461	 8774	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.005028	 0.0	 1	 -30.0	 30.0;
	3461	 1732	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.005028	 0.0	 1	 -30.0	 30.0;
	5419	 3329	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.001974	 0.0	 1	 -30.0	 30.0;
	5419	 9953	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.001974	 0.0	 1	 -30.0	 30.0;
	5419	 2828	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.001974	 0.0	 1	 -30.0	 30.0;
	5419	 9464	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.001974	 0.0	 1	 -30.0	 30.0;
	5419	 4301	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.001974	 0.0	 1	 -30.0	 30.0;
	5419	 10907	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.001974	 0.0	 1	 -30.0	 30.0;
	1457	 3228	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.997477	 0.0	 1	 -30.0	 30.0;
	1457	 783	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.997477	 0.0	 1	 -30.0	 30.0;
	1457	 6861	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.997477	 0.0	 1	 -30.0	 30.0;
	6367	 304	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.007255	 0.0	 1	 -30.0	 30.0;
	13233	 4209	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.013579	 0.0	 1	 -30.0	 30.0;
	13233	 10808	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.013579	 0.0	 1	 -30.0	 30.0;
	13233	 3710	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.013579	 0.0	 1	 -30.0	 30.0;
	13233	 7784	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.013579	 0.0	 1	 -30.0	 30.0;
	13233	 1306	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.013579	 0.0	 1	 -30.0	 30.0;
	13233	 6870	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.013579	 0.0	 1	 -30.0	 30.0;
	13233	 179	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.013579	 0.0	 1	 -30.0	 30.0;
	13233	 11968	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.013579	 0.0	 1	 -30.0	 30.0;
	8692	 10315	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.004319	 0.0	 1	 -30.0	 30.0;
	8692	 3206	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.004319	 0.0	 1	 -30.0	 30.0;
	8692	 11761	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.004319	 0.0	 1	 -30.0	 30.0;
	8692	 4715	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.004319	 0.0	 1	 -30.0	 30.0;
	8692	 33	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.004319	 0.0	 1	 -30.0	 30.0;
	8692	 4217	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.004319	 0.0	 1	 -30.0	 30.0;
	7241	 5473	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.014928	 0.0	 1	 -30.0	 30.0;
	7241	 12024	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.014928	 0.0	 1	 -30.0	 30.0;
	7241	 7297	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.014928	 0.0	 1	 -30.0	 30.0;
	7241	 5317	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.014928	 0.0	 1	 -30.0	 30.0;
	7241	 12341	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.014928	 0.0	 1	 -30.0	 30.0;
	4003	 11797	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.001878	 0.0	 1	 -30.0	 30.0;
	4003	 4757	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.001878	 0.0	 1	 -30.0	 30.0;
	4003	 7833	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.001878	 0.0	 1	 -30.0	 30.0;
	4003	 4226	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.001878	 0.0	 1	 -30.0	 30.0;
	10578	 5992	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.012864	 0.0	 1	 -30.0	 30.0;
	10578	 2183	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.012864	 0.0	 1	 -30.0	 30.0;
	10578	 9273	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.012864	 0.0	 1	 -30.0	 30.0;
	10578	 3384	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.012864	 0.0	 1	 -30.0	 30.0;
	10578	 10004	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.012864	 0.0	 1	 -30.0	 30.0;
	10578	 3877	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.012864	 0.0	 1	 -30.0	 30.0;
	10578	 8810	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.012864	 0.0	 1	 -30.0	 30.0;
	64	 3148	 0.027778	 1.110764	 0.0	 29	 29	 29	 1.000772	 0.0	 1	 -30.0	 30.0;
	64	 4673	 0.027778	 1.110764	 0.0	 29	 29	 29	 0.99517	 0.0	 1	 -30.0	 30.0;
	11878	 2676	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.004754	 0.0	 1	 -30.0	 30.0;
	4566	 9312	 0.022727	 0.908807	 0.0	 35	 35	 35	 1.00487	 0.0	 1	 -30.0	 30.0;
	4566	 6127	 0.022727	 0.908807	 0.0	 35	 35	 35	 0.999253	 0.0	 1	 -30.0	 30.0;
	13117	 8099	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.005602	 0.0	 1	 -30.0	 30.0;
	13117	 2635	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.005602	 0.0	 1	 -30.0	 30.0;
	13117	 9742	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.005602	 0.0	 1	 -30.0	 30.0;
	13117	 3146	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.005602	 0.0	 1	 -30.0	 30.0;
	13117	 10264	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.005602	 0.0	 1	 -30.0	 30.0;
	13117	 1731	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.005602	 0.0	 1	 -30.0	 30.0;
	4557	 1148	 0.022936	 0.917144	 0.0	 35	 35	 35	 1.003357	 0.0	 1	 -30.0	 30.0;
	4557	 2793	 0.022936	 0.917144	 0.0	 35	 35	 35	 0.997818	 0.0	 1	 -30.0	 30.0;
	5258	 698	 0.007716	 0.308546	 0.0	 103	 103	 103	 1.003186	 0.0	 1	 -30.0	 30.0;
	5258	 10615	 0.007716	 0.308546	 0.0	 103	 103	 103	 0.997349	 0.0	 1	 -30.0	 30.0;
	8475	 13411	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.020516	 0.0	 1	 -30.0	 30.0;
	8475	 8342	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.020516	 0.0	 1	 -30.0	 30.0;
	8475	 1310	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.020516	 0.0	 1	 -30.0	 30.0;
	8475	 2347	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.020516	 0.0	 1	 -30.0	 30.0;
	8475	 1774	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.020516	 0.0	 1	 -30.0	 30.0;
	2059	 12887	 0.038462	 1.537981	 0.0	 21	 21	 21	 1.00422	 0.0	 1	 -30.0	 30.0;
	7254	 5805	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.00527	 0.0	 1	 -30.0	 30.0;
	7254	 13370	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.00527	 0.0	 1	 -30.0	 30.0;
	7254	 6278	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.00527	 0.0	 1	 -30.0	 30.0;
	2775	 9881	 0.043103	 1.723599	 0.0	 19	 19	 19	 1.012693	 0.0	 1	 -30.0	 30.0;
	10704	 5260	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 0.996531	 0.0	 1	 -30.0	 30.0;
	10704	 2881	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 0.996531	 0.0	 1	 -30.0	 30.0;
	10704	 2880	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 0.996531	 0.0	 1	 -30.0	 30.0;
	13279	 8530	 0.010638	 0.425399	 0.0	 75	 75	 75	 1.003196	 0.0	 1	 -30.0	 30.0;
	13279	 8531	 0.010638	 0.425399	 0.0	 75	 75	 75	 0.997489	 0.0	 1	 -30.0	 30.0;
	13279	 8534	 0.010638	 0.425399	 0.0	 75	 75	 75	 0.997489	 0.0	 1	 -30.0	 30.0;
	13279	 8535	 0.010638	 0.425399	 0.0	 75	 75	 75	 0.997489	 0.0	 1	 -30.0	 30.0;
	13279	 8533	 0.010638	 0.425399	 0.0	 75	 75	 75	 0.997489	 0.0	 1	 -30.0	 30.0;
	5256	 6155	 0.006649	 0.265874	 0.0	 119	 119	 119	 1.00474	 0.0	 1	 -30.0	 30.0;
	5256	 6159	 0.006649	 0.265874	 0.0	 119	 119	 119	 0.998979	 0.0	 1	 -30.0	 30.0;
	5256	 6160	 0.006649	 0.265874	 0.0	 119	 119	 119	 0.998979	 0.0	 1	 -30.0	 30.0;
	5256	 10977	 0.006649	 0.265874	 0.0	 119	 119	 119	 0.998979	 0.0	 1	 -30.0	 30.0;
	5256	 13261	 0.006649	 0.265874	 0.0	 119	 119	 119	 0.998979	 0.0	 1	 -30.0	 30.0;
	1068	 6548	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.012774	 0.0	 1	 -30.0	 30.0;
	1068	 6547	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.012774	 0.0	 1	 -30.0	 30.0;
	1068	 13069	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.012774	 0.0	 1	 -30.0	 30.0;
	1068	 12102	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.012774	 0.0	 1	 -30.0	 30.0;
	1068	 6544	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.012774	 0.0	 1	 -30.0	 30.0;
	10340	 1957	 0.016234	 0.649148	 0.0	 49	 49	 49	 1.001406	 0.0	 1	 -30.0	 30.0;
	10340	 1954	 0.016234	 0.649148	 0.0	 49	 49	 49	 0.995859	 0.0	 1	 -30.0	 30.0;
	10340	 1953	 0.016234	 0.649148	 0.0	 49	 49	 49	 0.995859	 0.0	 1	 -30.0	 30.0;
	5566	 8053	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.009577	 0.0	 1	 -30.0	 30.0;
	5566	 7943	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.009577	 0.0	 1	 -30.0	 30.0;
	5566	 8055	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.009577	 0.0	 1	 -30.0	 30.0;
	5566	 8056	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.009577	 0.0	 1	 -30.0	 30.0;
	5566	 7490	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.009577	 0.0	 1	 -30.0	 30.0;
	5566	 7932	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.009577	 0.0	 1	 -30.0	 30.0;
	11468	 6641	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.014193	 0.0	 1	 -30.0	 30.0;
	11468	 6642	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.014193	 0.0	 1	 -30.0	 30.0;
	11468	 6639	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.014193	 0.0	 1	 -30.0	 30.0;
	11468	 6640	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.014193	 0.0	 1	 -30.0	 30.0;
	11468	 100	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.014193	 0.0	 1	 -30.0	 30.0;
	11468	 99	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.014193	 0.0	 1	 -30.0	 30.0;
	2714	 102	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.025369	 0.0	 1	 -30.0	 30.0;
	2714	 101	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.025369	 0.0	 1	 -30.0	 30.0;
	2714	 97	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.025369	 0.0	 1	 -30.0	 30.0;
	2714	 96	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.025369	 0.0	 1	 -30.0	 30.0;
	2714	 98	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.025369	 0.0	 1	 -30.0	 30.0;
	9646	 1505	 0.009728	 0.388983	 0.0	 82	 82	 82	 0.99539	 0.0	 1	 -30.0	 30.0;
	9646	 9416	 0.009728	 0.388983	 0.0	 82	 82	 82	 0.989722	 0.0	 1	 -30.0	 30.0;
	9646	 1511	 0.009728	 0.388983	 0.0	 82	 82	 82	 0.989722	 0.0	 1	 -30.0	 30.0;
	9646	 8200	 0.009728	 0.388983	 0.0	 82	 82	 82	 0.989722	 0.0	 1	 -30.0	 30.0;
	9646	 7587	 0.009728	 0.388983	 0.0	 82	 82	 82	 0.989722	 0.0	 1	 -30.0	 30.0;
	3450	 5212	 0.003098	 0.123877	 0.0	 255	 255	 255	 1.010409	 0.0	 1	 -30.0	 30.0;
	3450	 5213	 0.003098	 0.123877	 0.0	 255	 255	 255	 1.004436	 0.0	 1	 -30.0	 30.0;
	3450	 5585	 0.003098	 0.123877	 0.0	 255	 255	 255	 1.004436	 0.0	 1	 -30.0	 30.0;
	3450	 5215	 0.003098	 0.123877	 0.0	 255	 255	 255	 1.004436	 0.0	 1	 -30.0	 30.0;
	3450	 5216	 0.003098	 0.123877	 0.0	 255	 255	 255	 1.004436	 0.0	 1	 -30.0	 30.0;
	3450	 5624	 0.003098	 0.123877	 0.0	 255	 255	 255	 1.004436	 0.0	 1	 -30.0	 30.0;
	205	 3867	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.009578	 0.0	 1	 -30.0	 30.0;
	205	 3866	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.009578	 0.0	 1	 -30.0	 30.0;
	205	 8759	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.009578	 0.0	 1	 -30.0	 30.0;
	2383	 1044	 0.039062	 1.562012	 0.0	 21	 21	 21	 1.001311	 0.0	 1	 -30.0	 30.0;
	719	 1046	 0.024272	 0.97057	 0.0	 33	 33	 33	 1.003605	 0.0	 1	 -30.0	 30.0;
	719	 1045	 0.024272	 0.97057	 0.0	 33	 33	 33	 0.998099	 0.0	 1	 -30.0	 30.0;
	900	 362	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.000042	 0.0	 1	 -30.0	 30.0;
	900	 363	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.000042	 0.0	 1	 -30.0	 30.0;
	900	 360	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.000042	 0.0	 1	 -30.0	 30.0;
	900	 361	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.000042	 0.0	 1	 -30.0	 30.0;
	900	 368	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.000042	 0.0	 1	 -30.0	 30.0;
	900	 369	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.000042	 0.0	 1	 -30.0	 30.0;
	900	 6931	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.000042	 0.0	 1	 -30.0	 30.0;
	900	 6930	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.000042	 0.0	 1	 -30.0	 30.0;
	2052	 5777	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.008331	 0.0	 1	 -30.0	 30.0;
	2052	 5776	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.008331	 0.0	 1	 -30.0	 30.0;
	2052	 5782	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.008331	 0.0	 1	 -30.0	 30.0;
	2052	 5781	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.008331	 0.0	 1	 -30.0	 30.0;
	1203	 7143	 0.02381	 0.952083	 0.0	 34	 34	 34	 1.012157	 0.0	 1	 -30.0	 30.0;
	1203	 7144	 0.02381	 0.952083	 0.0	 34	 34	 34	 1.006915	 0.0	 1	 -30.0	 30.0;
	5642	 2166	 0.009615	 0.384495	 0.0	 83	 83	 83	 1.009944	 0.0	 1	 -30.0	 30.0;
	5642	 7141	 0.009615	 0.384495	 0.0	 83	 83	 83	 1.004376	 0.0	 1	 -30.0	 30.0;
	5642	 594	 0.009615	 0.384495	 0.0	 83	 83	 83	 1.004376	 0.0	 1	 -30.0	 30.0;
	5642	 593	 0.009615	 0.384495	 0.0	 83	 83	 83	 1.004376	 0.0	 1	 -30.0	 30.0;
	5642	 3614	 0.009615	 0.384495	 0.0	 83	 83	 83	 1.004376	 0.0	 1	 -30.0	 30.0;
	7440	 8343	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.013087	 0.0	 1	 -30.0	 30.0;
	7440	 12761	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.013087	 0.0	 1	 -30.0	 30.0;
	7440	 12760	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.013087	 0.0	 1	 -30.0	 30.0;
	7440	 12763	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.013087	 0.0	 1	 -30.0	 30.0;
	7440	 8354	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.013087	 0.0	 1	 -30.0	 30.0;
	7440	 8357	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.013087	 0.0	 1	 -30.0	 30.0;
	10906	 589	 0.015244	 0.609566	 0.0	 52	 52	 52	 1.002407	 0.0	 1	 -30.0	 30.0;
	10906	 10509	 0.015244	 0.609566	 0.0	 52	 52	 52	 0.996654	 0.0	 1	 -30.0	 30.0;
	10906	 10510	 0.015244	 0.609566	 0.0	 52	 52	 52	 0.996654	 0.0	 1	 -30.0	 30.0;
	3191	 10507	 0.039062	 1.562012	 0.0	 21	 21	 21	 1.007221	 0.0	 1	 -30.0	 30.0;
	1982	 10508	 0.018797	 0.751645	 0.0	 43	 43	 43	 1.005485	 0.0	 1	 -30.0	 30.0;
	1982	 6252	 0.018797	 0.751645	 0.0	 43	 43	 43	 1.000027	 0.0	 1	 -30.0	 30.0;
	1982	 10512	 0.018797	 0.751645	 0.0	 43	 43	 43	 1.000027	 0.0	 1	 -30.0	 30.0;
	10450	 4893	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 0.998716	 0.0	 1	 -30.0	 30.0;
	10450	 4892	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 0.998716	 0.0	 1	 -30.0	 30.0;
	10450	 4897	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 0.998716	 0.0	 1	 -30.0	 30.0;
	10450	 4896	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 0.998716	 0.0	 1	 -30.0	 30.0;
	13135	 1454	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.008012	 0.0	 1	 -30.0	 30.0;
	13135	 1453	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.008012	 0.0	 1	 -30.0	 30.0;
	13135	 9047	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.008012	 0.0	 1	 -30.0	 30.0;
	13135	 1451	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.008012	 0.0	 1	 -30.0	 30.0;
	7100	 10361	 0.030488	 1.219131	 0.0	 26	 26	 26	 1.014807	 0.0	 1	 -30.0	 30.0;
	7100	 3885	 0.030488	 1.219131	 0.0	 26	 26	 26	 1.009649	 0.0	 1	 -30.0	 30.0;
	4705	 1450	 0.003521	 0.140801	 0.0	 225	 225	 225	 0.997964	 0.0	 1	 -30.0	 30.0;
	4705	 1449	 0.003521	 0.140801	 0.0	 225	 225	 225	 0.997964	 0.0	 1	 -30.0	 30.0;
	4705	 1448	 0.003521	 0.140801	 0.0	 225	 225	 225	 0.997964	 0.0	 1	 -30.0	 30.0;
	4705	 1447	 0.003521	 0.140801	 0.0	 225	 225	 225	 0.997964	 0.0	 1	 -30.0	 30.0;
	4705	 9246	 0.003521	 0.140801	 0.0	 225	 225	 225	 0.997964	 0.0	 1	 -30.0	 30.0;
	4705	 1381	 0.003521	 0.140801	 0.0	 225	 225	 225	 0.997964	 0.0	 1	 -30.0	 30.0;
	4705	 9247	 0.003521	 0.140801	 0.0	 225	 225	 225	 0.997964	 0.0	 1	 -30.0	 30.0;
	8484	 11705	 0.015625	 0.624805	 0.0	 51	 51	 51	 1.012683	 0.0	 1	 -30.0	 30.0;
	8484	 11709	 0.015625	 0.624805	 0.0	 51	 51	 51	 1.007095	 0.0	 1	 -30.0	 30.0;
	8484	 2335	 0.015625	 0.624805	 0.0	 51	 51	 51	 1.007095	 0.0	 1	 -30.0	 30.0;
	3846	 9244	 0.006039	 0.24147	 0.0	 131	 131	 131	 1.011205	 0.0	 1	 -30.0	 30.0;
	3846	 9243	 0.006039	 0.24147	 0.0	 131	 131	 131	 1.005549	 0.0	 1	 -30.0	 30.0;
	3846	 9241	 0.006039	 0.24147	 0.0	 131	 131	 131	 1.005549	 0.0	 1	 -30.0	 30.0;
	3846	 9240	 0.006039	 0.24147	 0.0	 131	 131	 131	 1.005549	 0.0	 1	 -30.0	 30.0;
	3846	 2163	 0.006039	 0.24147	 0.0	 131	 131	 131	 1.005549	 0.0	 1	 -30.0	 30.0;
	3846	 2164	 0.006039	 0.24147	 0.0	 131	 131	 131	 1.005549	 0.0	 1	 -30.0	 30.0;
	6501	 4644	 0.013812	 0.552314	 0.0	 58	 58	 58	 1.004827	 0.0	 1	 -30.0	 30.0;
	6501	 13351	 0.013812	 0.552314	 0.0	 58	 58	 58	 0.999231	 0.0	 1	 -30.0	 30.0;
	6501	 4646	 0.013812	 0.552314	 0.0	 58	 58	 58	 0.999231	 0.0	 1	 -30.0	 30.0;
	6501	 4647	 0.013812	 0.552314	 0.0	 58	 58	 58	 0.999231	 0.0	 1	 -30.0	 30.0;
	4869	 4648	 0.009579	 0.383022	 0.0	 83	 83	 83	 1.016353	 0.0	 1	 -30.0	 30.0;
	4869	 4649	 0.009579	 0.383022	 0.0	 83	 83	 83	 1.011028	 0.0	 1	 -30.0	 30.0;
	4869	 4650	 0.009579	 0.383022	 0.0	 83	 83	 83	 1.011028	 0.0	 1	 -30.0	 30.0;
	4869	 4651	 0.009579	 0.383022	 0.0	 83	 83	 83	 1.011028	 0.0	 1	 -30.0	 30.0;
	4869	 12246	 0.009579	 0.383022	 0.0	 83	 83	 83	 1.011028	 0.0	 1	 -30.0	 30.0;
	8880	 12245	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.010158	 0.0	 1	 -30.0	 30.0;
	8880	 7178	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.010158	 0.0	 1	 -30.0	 30.0;
	1612	 8747	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.007099	 0.0	 1	 -30.0	 30.0;
	1612	 8746	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.007099	 0.0	 1	 -30.0	 30.0;
	1612	 8745	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.007099	 0.0	 1	 -30.0	 30.0;
	1612	 8744	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.007099	 0.0	 1	 -30.0	 30.0;
	1612	 4206	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.007099	 0.0	 1	 -30.0	 30.0;
	1612	 8755	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.007099	 0.0	 1	 -30.0	 30.0;
	4466	 12240	 0.004019	 0.160721	 0.0	 197	 197	 197	 1.002751	 0.0	 1	 -30.0	 30.0;
	4466	 5170	 0.004019	 0.160721	 0.0	 197	 197	 197	 0.997027	 0.0	 1	 -30.0	 30.0;
	4466	 5171	 0.004019	 0.160721	 0.0	 197	 197	 197	 0.997027	 0.0	 1	 -30.0	 30.0;
	4466	 5168	 0.004019	 0.160721	 0.0	 197	 197	 197	 0.997027	 0.0	 1	 -30.0	 30.0;
	10044	 5169	 0.010373	 0.414808	 0.0	 77	 77	 77	 1.016656	 0.0	 1	 -30.0	 30.0;
	10044	 12812	 0.010373	 0.414808	 0.0	 77	 77	 77	 1.011392	 0.0	 1	 -30.0	 30.0;
	10044	 5167	 0.010373	 0.414808	 0.0	 77	 77	 77	 1.011392	 0.0	 1	 -30.0	 30.0;
	10044	 5164	 0.010373	 0.414808	 0.0	 77	 77	 77	 1.011392	 0.0	 1	 -30.0	 30.0;
	10044	 5165	 0.010373	 0.414808	 0.0	 77	 77	 77	 1.011392	 0.0	 1	 -30.0	 30.0;
	7181	 5177	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.005009	 0.0	 1	 -30.0	 30.0;
	7181	 5178	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.005009	 0.0	 1	 -30.0	 30.0;
	9773	 12782	 0.009615	 0.384495	 0.0	 83	 83	 83	 1.020687	 0.0	 1	 -30.0	 30.0;
	9773	 12781	 0.009615	 0.384495	 0.0	 83	 83	 83	 1.015549	 0.0	 1	 -30.0	 30.0;
	9773	 12780	 0.009615	 0.384495	 0.0	 83	 83	 83	 1.015549	 0.0	 1	 -30.0	 30.0;
	9773	 12779	 0.009615	 0.384495	 0.0	 83	 83	 83	 1.015549	 0.0	 1	 -30.0	 30.0;
	9773	 12778	 0.009615	 0.384495	 0.0	 83	 83	 83	 1.015549	 0.0	 1	 -30.0	 30.0;
	11466	 12777	 0.008091	 0.323523	 0.0	 98	 98	 98	 1.004404	 0.0	 1	 -30.0	 30.0;
	11466	 8403	 0.008091	 0.323523	 0.0	 98	 98	 98	 0.99875	 0.0	 1	 -30.0	 30.0;
	10984	 364	 0.039062	 1.562012	 0.0	 21	 21	 21	 1.003108	 0.0	 1	 -30.0	 30.0;
	6177	 8396	 0.048077	 1.922476	 0.0	 17	 17	 17	 1.003621	 0.0	 1	 -30.0	 30.0;
	3958	 6601	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.00853	 0.0	 1	 -30.0	 30.0;
	3958	 250	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.00853	 0.0	 1	 -30.0	 30.0;
	3958	 45	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.00853	 0.0	 1	 -30.0	 30.0;
	456	 5702	 0.032468	 1.298295	 0.0	 25	 25	 25	 1.01309	 0.0	 1	 -30.0	 30.0;
	456	 5703	 0.032468	 1.298295	 0.0	 25	 25	 25	 1.007869	 0.0	 1	 -30.0	 30.0;
	449	 6628	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.003276	 0.0	 1	 -30.0	 30.0;
	449	 10117	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.003276	 0.0	 1	 -30.0	 30.0;
	449	 10116	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.003276	 0.0	 1	 -30.0	 30.0;
	449	 10115	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.003276	 0.0	 1	 -30.0	 30.0;
	40	 5697	 0.025773	 1.030606	 0.0	 31	 31	 31	 1.003295	 0.0	 1	 -30.0	 30.0;
	40	 5698	 0.025773	 1.030606	 0.0	 31	 31	 31	 0.997732	 0.0	 1	 -30.0	 30.0;
	8256	 13268	 0.012315	 0.492457	 0.0	 65	 65	 65	 1.003225	 0.0	 1	 -30.0	 30.0;
	8256	 11288	 0.012315	 0.492457	 0.0	 65	 65	 65	 0.997532	 0.0	 1	 -30.0	 30.0;
	8256	 10317	 0.012315	 0.492457	 0.0	 65	 65	 65	 0.997532	 0.0	 1	 -30.0	 30.0;
	8256	 13269	 0.012315	 0.492457	 0.0	 65	 65	 65	 0.997532	 0.0	 1	 -30.0	 30.0;
	12985	 13265	 0.020161	 0.8062	 0.0	 40	 40	 40	 0.994624	 0.0	 1	 -30.0	 30.0;
	12985	 13264	 0.020161	 0.8062	 0.0	 40	 40	 40	 0.98892	 0.0	 1	 -30.0	 30.0;
	12985	 13266	 0.020161	 0.8062	 0.0	 40	 40	 40	 0.98892	 0.0	 1	 -30.0	 30.0;
	9491	 3496	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 0.997131	 0.0	 1	 -30.0	 30.0;
	9491	 3494	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 0.997131	 0.0	 1	 -30.0	 30.0;
	9491	 3495	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 0.997131	 0.0	 1	 -30.0	 30.0;
	6878	 10954	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 0.995055	 0.0	 1	 -30.0	 30.0;
	6878	 13209	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 0.995055	 0.0	 1	 -30.0	 30.0;
	6878	 12556	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 0.995055	 0.0	 1	 -30.0	 30.0;
	1680	 6163	 0.04717	 1.886203	 0.0	 17	 17	 17	 1.002428	 0.0	 1	 -30.0	 30.0;
	999	 6167	 0.01	 0.399875	 0.0	 79	 79	 79	 1.003934	 0.0	 1	 -30.0	 30.0;
	999	 6168	 0.01	 0.399875	 0.0	 79	 79	 79	 0.998152	 0.0	 1	 -30.0	 30.0;
	999	 6165	 0.01	 0.399875	 0.0	 79	 79	 79	 0.998152	 0.0	 1	 -30.0	 30.0;
	999	 6166	 0.01	 0.399875	 0.0	 79	 79	 79	 0.998152	 0.0	 1	 -30.0	 30.0;
	999	 6170	 0.01	 0.399875	 0.0	 79	 79	 79	 0.998152	 0.0	 1	 -30.0	 30.0;
	257	 809	 0.006684	 0.267296	 0.0	 119	 119	 119	 1.003557	 0.0	 1	 -30.0	 30.0;
	257	 11142	 0.006684	 0.267296	 0.0	 119	 119	 119	 0.997824	 0.0	 1	 -30.0	 30.0;
	257	 11141	 0.006684	 0.267296	 0.0	 119	 119	 119	 0.997824	 0.0	 1	 -30.0	 30.0;
	257	 11144	 0.006684	 0.267296	 0.0	 119	 119	 119	 0.997824	 0.0	 1	 -30.0	 30.0;
	257	 11143	 0.006684	 0.267296	 0.0	 119	 119	 119	 0.997824	 0.0	 1	 -30.0	 30.0;
	2633	 9778	 0.018939	 0.757339	 0.0	 42	 42	 42	 1.001686	 0.0	 1	 -30.0	 30.0;
	2633	 9777	 0.018939	 0.757339	 0.0	 42	 42	 42	 0.996106	 0.0	 1	 -30.0	 30.0;
	2633	 8562	 0.018939	 0.757339	 0.0	 42	 42	 42	 0.996106	 0.0	 1	 -30.0	 30.0;
	8327	 2107	 0.01087	 0.434647	 0.0	 73	 73	 73	 1.006804	 0.0	 1	 -30.0	 30.0;
	8327	 9772	 0.01087	 0.434647	 0.0	 73	 73	 73	 1.001171	 0.0	 1	 -30.0	 30.0;
	8327	 9771	 0.01087	 0.434647	 0.0	 73	 73	 73	 1.001171	 0.0	 1	 -30.0	 30.0;
	8327	 2664	 0.01087	 0.434647	 0.0	 73	 73	 73	 1.001171	 0.0	 1	 -30.0	 30.0;
	8327	 2665	 0.01087	 0.434647	 0.0	 73	 73	 73	 1.001171	 0.0	 1	 -30.0	 30.0;
	11213	 2666	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.0043	 0.0	 1	 -30.0	 30.0;
	11213	 2667	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.0043	 0.0	 1	 -30.0	 30.0;
	11213	 1988	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.0043	 0.0	 1	 -30.0	 30.0;
	11213	 2669	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.0043	 0.0	 1	 -30.0	 30.0;
	9731	 4066	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.007249	 0.0	 1	 -30.0	 30.0;
	9731	 4067	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.007249	 0.0	 1	 -30.0	 30.0;
	9731	 4068	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.007249	 0.0	 1	 -30.0	 30.0;
	9731	 4069	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.007249	 0.0	 1	 -30.0	 30.0;
	9731	 12434	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.007249	 0.0	 1	 -30.0	 30.0;
	13271	 11294	 0.000212	 0.008494	 0.0	 3718	 3718	 3718	 1.021812	 0.0	 1	 -30.0	 30.0;
	13271	 814	 0.000212	 0.008494	 0.0	 3718	 3718	 3718	 1.021812	 0.0	 1	 -30.0	 30.0;
	3807	 12433	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.004319	 0.0	 1	 -30.0	 30.0;
	3807	 12430	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.004319	 0.0	 1	 -30.0	 30.0;
	3807	 12431	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.004319	 0.0	 1	 -30.0	 30.0;
	3807	 12428	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.004319	 0.0	 1	 -30.0	 30.0;
	3807	 12429	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.004319	 0.0	 1	 -30.0	 30.0;
	1682	 12440	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.013896	 0.0	 1	 -30.0	 30.0;
	1682	 6654	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.013896	 0.0	 1	 -30.0	 30.0;
	1682	 7967	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.013896	 0.0	 1	 -30.0	 30.0;
	1682	 5864	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.013896	 0.0	 1	 -30.0	 30.0;
	10272	 11510	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.011734	 0.0	 1	 -30.0	 30.0;
	10272	 10930	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.011734	 0.0	 1	 -30.0	 30.0;
	10272	 10927	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.011734	 0.0	 1	 -30.0	 30.0;
	10272	 10928	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.011734	 0.0	 1	 -30.0	 30.0;
	41	 9327	 0.038462	 1.537981	 0.0	 21	 21	 21	 1.003553	 0.0	 1	 -30.0	 30.0;
	4149	 1836	 0.05814	 2.324855	 0.0	 14	 14	 14	 1.000207	 0.0	 1	 -30.0	 30.0;
	5349	 9323	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.999338	 0.0	 1	 -30.0	 30.0;
	5349	 9322	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.999338	 0.0	 1	 -30.0	 30.0;
	5349	 2693	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.999338	 0.0	 1	 -30.0	 30.0;
	5349	 2694	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.999338	 0.0	 1	 -30.0	 30.0;
	340	 2691	 0.039062	 1.562012	 0.0	 21	 21	 21	 1.006031	 0.0	 1	 -30.0	 30.0;
	8019	 3233	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.007887	 0.0	 1	 -30.0	 30.0;
	8019	 3225	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.007887	 0.0	 1	 -30.0	 30.0;
	8019	 2690	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.007887	 0.0	 1	 -30.0	 30.0;
	8019	 2687	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.007887	 0.0	 1	 -30.0	 30.0;
	5457	 2688	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.01053	 0.0	 1	 -30.0	 30.0;
	12079	 346	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 0.998487	 0.0	 1	 -30.0	 30.0;
	12079	 345	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 0.998487	 0.0	 1	 -30.0	 30.0;
	12079	 646	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 0.998487	 0.0	 1	 -30.0	 30.0;
	12079	 649	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 0.998487	 0.0	 1	 -30.0	 30.0;
	10130	 12726	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.006201	 0.0	 1	 -30.0	 30.0;
	10130	 10461	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.006201	 0.0	 1	 -30.0	 30.0;
	10130	 10462	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.006201	 0.0	 1	 -30.0	 30.0;
	5854	 5401	 0.005353	 0.214066	 0.0	 148	 148	 148	 0.998883	 0.0	 1	 -30.0	 30.0;
	5854	 5400	 0.005353	 0.214066	 0.0	 148	 148	 148	 0.993032	 0.0	 1	 -30.0	 30.0;
	5854	 5399	 0.005353	 0.214066	 0.0	 148	 148	 148	 0.993032	 0.0	 1	 -30.0	 30.0;
	5854	 5405	 0.005353	 0.214066	 0.0	 148	 148	 148	 0.993032	 0.0	 1	 -30.0	 30.0;
	5854	 5204	 0.005353	 0.214066	 0.0	 148	 148	 148	 0.993032	 0.0	 1	 -30.0	 30.0;
	5854	 13434	 0.005353	 0.214066	 0.0	 148	 148	 148	 0.993032	 0.0	 1	 -30.0	 30.0;
	5854	 12317	 0.005353	 0.214066	 0.0	 148	 148	 148	 0.993032	 0.0	 1	 -30.0	 30.0;
	2130	 3164	 0.039062	 1.562012	 0.0	 21	 21	 21	 1.021238	 0.0	 1	 -30.0	 30.0;
	5336	 13433	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.005684	 0.0	 1	 -30.0	 30.0;
	5336	 12325	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.005684	 0.0	 1	 -30.0	 30.0;
	5336	 13439	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.005684	 0.0	 1	 -30.0	 30.0;
	5336	 12319	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.005684	 0.0	 1	 -30.0	 30.0;
	5336	 13437	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.005684	 0.0	 1	 -30.0	 30.0;
	4575	 13440	 0.006127	 0.245021	 0.0	 129	 129	 129	 1.004608	 0.0	 1	 -30.0	 30.0;
	4575	 12342	 0.006127	 0.245021	 0.0	 129	 129	 129	 0.998741	 0.0	 1	 -30.0	 30.0;
	4575	 6810	 0.006127	 0.245021	 0.0	 129	 129	 129	 0.998741	 0.0	 1	 -30.0	 30.0;
	4575	 6809	 0.006127	 0.245021	 0.0	 129	 129	 129	 0.998741	 0.0	 1	 -30.0	 30.0;
	4575	 6812	 0.006127	 0.245021	 0.0	 129	 129	 129	 0.998741	 0.0	 1	 -30.0	 30.0;
	4575	 6811	 0.006127	 0.245021	 0.0	 129	 129	 129	 0.998741	 0.0	 1	 -30.0	 30.0;
	2959	 10281	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.009947	 0.0	 1	 -30.0	 30.0;
	6867	 6806	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.005617	 0.0	 1	 -30.0	 30.0;
	6867	 6808	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.005617	 0.0	 1	 -30.0	 30.0;
	6867	 6807	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.005617	 0.0	 1	 -30.0	 30.0;
	6867	 6815	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.005617	 0.0	 1	 -30.0	 30.0;
	6867	 6814	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.005617	 0.0	 1	 -30.0	 30.0;
	4503	 6709	 0.01269	 0.507456	 0.0	 63	 63	 63	 1.000098	 0.0	 1	 -30.0	 30.0;
	4503	 8997	 0.01269	 0.507456	 0.0	 63	 63	 63	 0.994564	 0.0	 1	 -30.0	 30.0;
	4503	 3668	 0.01269	 0.507456	 0.0	 63	 63	 63	 0.994564	 0.0	 1	 -30.0	 30.0;
	4503	 6698	 0.01269	 0.507456	 0.0	 63	 63	 63	 0.994564	 0.0	 1	 -30.0	 30.0;
	2537	 3674	 0.048077	 1.922476	 0.0	 17	 17	 17	 0.998226	 0.0	 1	 -30.0	 30.0;
	9105	 3675	 0.039062	 1.562012	 0.0	 21	 21	 21	 1.010126	 0.0	 1	 -30.0	 30.0;
	8469	 8999	 0.008993	 0.3596	 0.0	 88	 88	 88	 1.005209	 0.0	 1	 -30.0	 30.0;
	8469	 3673	 0.008993	 0.3596	 0.0	 88	 88	 88	 0.999399	 0.0	 1	 -30.0	 30.0;
	8469	 3664	 0.008993	 0.3596	 0.0	 88	 88	 88	 0.999399	 0.0	 1	 -30.0	 30.0;
	8469	 3665	 0.008993	 0.3596	 0.0	 88	 88	 88	 0.999399	 0.0	 1	 -30.0	 30.0;
	8469	 10445	 0.008993	 0.3596	 0.0	 88	 88	 88	 0.999399	 0.0	 1	 -30.0	 30.0;
	8469	 10776	 0.008993	 0.3596	 0.0	 88	 88	 88	 0.999399	 0.0	 1	 -30.0	 30.0;
	6519	 13371	 0.01004	 0.401481	 0.0	 79	 79	 79	 1.00113	 0.0	 1	 -30.0	 30.0;
	6519	 10778	 0.01004	 0.401481	 0.0	 79	 79	 79	 0.995531	 0.0	 1	 -30.0	 30.0;
	6519	 10773	 0.01004	 0.401481	 0.0	 79	 79	 79	 0.995531	 0.0	 1	 -30.0	 30.0;
	6519	 10772	 0.01004	 0.401481	 0.0	 79	 79	 79	 0.995531	 0.0	 1	 -30.0	 30.0;
	6519	 13323	 0.01004	 0.401481	 0.0	 79	 79	 79	 0.995531	 0.0	 1	 -30.0	 30.0;
	6835	 6337	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.01161	 0.0	 1	 -30.0	 30.0;
	6835	 6336	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.01161	 0.0	 1	 -30.0	 30.0;
	6835	 6335	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.01161	 0.0	 1	 -30.0	 30.0;
	6835	 10488	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.01161	 0.0	 1	 -30.0	 30.0;
	6835	 10489	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.01161	 0.0	 1	 -30.0	 30.0;
	1472	 6088	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.007725	 0.0	 1	 -30.0	 30.0;
	1472	 5984	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.007725	 0.0	 1	 -30.0	 30.0;
	1472	 11875	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.007725	 0.0	 1	 -30.0	 30.0;
	1472	 4154	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.007725	 0.0	 1	 -30.0	 30.0;
	13287	 8725	 0.009025	 0.360898	 0.0	 88	 88	 88	 1.002848	 0.0	 1	 -30.0	 30.0;
	13287	 10486	 0.009025	 0.360898	 0.0	 88	 88	 88	 0.997224	 0.0	 1	 -30.0	 30.0;
	13287	 10483	 0.009025	 0.360898	 0.0	 88	 88	 88	 0.997224	 0.0	 1	 -30.0	 30.0;
	13287	 10484	 0.009025	 0.360898	 0.0	 88	 88	 88	 0.997224	 0.0	 1	 -30.0	 30.0;
	2418	 12692	 0.010917	 0.436545	 0.0	 73	 73	 73	 1.000577	 0.0	 1	 -30.0	 30.0;
	2418	 12679	 0.010917	 0.436545	 0.0	 73	 73	 73	 0.994983	 0.0	 1	 -30.0	 30.0;
	2418	 11234	 0.010917	 0.436545	 0.0	 73	 73	 73	 0.994983	 0.0	 1	 -30.0	 30.0;
	2418	 13374	 0.010917	 0.436545	 0.0	 73	 73	 73	 0.994983	 0.0	 1	 -30.0	 30.0;
	2418	 12741	 0.010917	 0.436545	 0.0	 73	 73	 73	 0.994983	 0.0	 1	 -30.0	 30.0;
	5435	 11239	 0.040323	 1.612399	 0.0	 20	 20	 20	 1.008391	 0.0	 1	 -30.0	 30.0;
	6898	 12723	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.012835	 0.0	 1	 -30.0	 30.0;
	6898	 11237	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.012835	 0.0	 1	 -30.0	 30.0;
	6898	 11244	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.012835	 0.0	 1	 -30.0	 30.0;
	1285	 3857	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.006375	 0.0	 1	 -30.0	 30.0;
	1285	 11796	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.006375	 0.0	 1	 -30.0	 30.0;
	1285	 1884	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.006375	 0.0	 1	 -30.0	 30.0;
	1285	 1883	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.006375	 0.0	 1	 -30.0	 30.0;
	1285	 1882	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.006375	 0.0	 1	 -30.0	 30.0;
	5438	 1881	 0.003521	 0.140801	 0.0	 225	 225	 225	 0.998845	 0.0	 1	 -30.0	 30.0;
	5438	 1880	 0.003521	 0.140801	 0.0	 225	 225	 225	 0.998845	 0.0	 1	 -30.0	 30.0;
	5438	 1879	 0.003521	 0.140801	 0.0	 225	 225	 225	 0.998845	 0.0	 1	 -30.0	 30.0;
	5438	 1878	 0.003521	 0.140801	 0.0	 225	 225	 225	 0.998845	 0.0	 1	 -30.0	 30.0;
	5438	 1877	 0.003521	 0.140801	 0.0	 225	 225	 225	 0.998845	 0.0	 1	 -30.0	 30.0;
	5438	 1876	 0.003521	 0.140801	 0.0	 225	 225	 225	 0.998845	 0.0	 1	 -30.0	 30.0;
	5438	 8456	 0.003521	 0.140801	 0.0	 225	 225	 225	 0.998845	 0.0	 1	 -30.0	 30.0;
	12743	 12027	 0.010121	 0.404732	 0.0	 79	 79	 79	 1.01165	 0.0	 1	 -30.0	 30.0;
	12743	 1237	 0.010121	 0.404732	 0.0	 79	 79	 79	 1.006209	 0.0	 1	 -30.0	 30.0;
	12743	 5031	 0.010121	 0.404732	 0.0	 79	 79	 79	 1.006209	 0.0	 1	 -30.0	 30.0;
	12743	 12159	 0.010121	 0.404732	 0.0	 79	 79	 79	 1.006209	 0.0	 1	 -30.0	 30.0;
	12743	 4176	 0.010121	 0.404732	 0.0	 79	 79	 79	 1.006209	 0.0	 1	 -30.0	 30.0;
	1973	 12020	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.01334	 0.0	 1	 -30.0	 30.0;
	11168	 12021	 0.004744	 0.189694	 0.0	 167	 167	 167	 0.998715	 0.0	 1	 -30.0	 30.0;
	11168	 12018	 0.004744	 0.189694	 0.0	 167	 167	 167	 0.993096	 0.0	 1	 -30.0	 30.0;
	11168	 3059	 0.004744	 0.189694	 0.0	 167	 167	 167	 0.993096	 0.0	 1	 -30.0	 30.0;
	3615	 2695	 0.004441	 0.177564	 0.0	 178	 178	 178	 1.005871	 0.0	 1	 -30.0	 30.0;
	3615	 8279	 0.004441	 0.177564	 0.0	 178	 178	 178	 0.999436	 0.0	 1	 -30.0	 30.0;
	3615	 2686	 0.004441	 0.177564	 0.0	 178	 178	 178	 0.999436	 0.0	 1	 -30.0	 30.0;
	3615	 4962	 0.004441	 0.177564	 0.0	 178	 178	 178	 0.999436	 0.0	 1	 -30.0	 30.0;
	3615	 4968	 0.004441	 0.177564	 0.0	 178	 178	 178	 0.999436	 0.0	 1	 -30.0	 30.0;
	13295	 4967	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.005792	 0.0	 1	 -30.0	 30.0;
	13295	 2702	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.005792	 0.0	 1	 -30.0	 30.0;
	4876	 2318	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.006969	 0.0	 1	 -30.0	 30.0;
	4876	 2322	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.006969	 0.0	 1	 -30.0	 30.0;
	4876	 2321	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.006969	 0.0	 1	 -30.0	 30.0;
	4876	 8939	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.006969	 0.0	 1	 -30.0	 30.0;
	4876	 4924	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.006969	 0.0	 1	 -30.0	 30.0;
	4876	 8937	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.006969	 0.0	 1	 -30.0	 30.0;
	4876	 8938	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.006969	 0.0	 1	 -30.0	 30.0;
	8986	 8943	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.011449	 0.0	 1	 -30.0	 30.0;
	8986	 8944	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.011449	 0.0	 1	 -30.0	 30.0;
	8986	 8941	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.011449	 0.0	 1	 -30.0	 30.0;
	8986	 13285	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.011449	 0.0	 1	 -30.0	 30.0;
	8883	 8717	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.01898	 0.0	 1	 -30.0	 30.0;
	8883	 8716	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.01898	 0.0	 1	 -30.0	 30.0;
	8883	 2147	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.01898	 0.0	 1	 -30.0	 30.0;
	1235	 6431	 0.009881	 0.395133	 0.0	 80	 80	 80	 1.004044	 0.0	 1	 -30.0	 30.0;
	1235	 6433	 0.009881	 0.395133	 0.0	 80	 80	 80	 0.998264	 0.0	 1	 -30.0	 30.0;
	1235	 6432	 0.009881	 0.395133	 0.0	 80	 80	 80	 0.998264	 0.0	 1	 -30.0	 30.0;
	1235	 11350	 0.009881	 0.395133	 0.0	 80	 80	 80	 0.998264	 0.0	 1	 -30.0	 30.0;
	1235	 11346	 0.009881	 0.395133	 0.0	 80	 80	 80	 0.998264	 0.0	 1	 -30.0	 30.0;
	12350	 11355	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.006096	 0.0	 1	 -30.0	 30.0;
	7258	 2146	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.011449	 0.0	 1	 -30.0	 30.0;
	7258	 2143	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.011449	 0.0	 1	 -30.0	 30.0;
	7258	 2144	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.011449	 0.0	 1	 -30.0	 30.0;
	7258	 1263	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.011449	 0.0	 1	 -30.0	 30.0;
	5915	 3515	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.015759	 0.0	 1	 -30.0	 30.0;
	5915	 3781	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.015759	 0.0	 1	 -30.0	 30.0;
	5915	 3782	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.015759	 0.0	 1	 -30.0	 30.0;
	5915	 3787	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.015759	 0.0	 1	 -30.0	 30.0;
	5915	 7970	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.015759	 0.0	 1	 -30.0	 30.0;
	7790	 13029	 0.019084	 0.76312	 0.0	 42	 42	 42	 1.002299	 0.0	 1	 -30.0	 30.0;
	7790	 13030	 0.019084	 0.76312	 0.0	 42	 42	 42	 0.996763	 0.0	 1	 -30.0	 30.0;
	7790	 13026	 0.019084	 0.76312	 0.0	 42	 42	 42	 0.996763	 0.0	 1	 -30.0	 30.0;
	7552	 13027	 0.010593	 0.423596	 0.0	 75	 75	 75	 1.002662	 0.0	 1	 -30.0	 30.0;
	7552	 5958	 0.010593	 0.423596	 0.0	 75	 75	 75	 0.996851	 0.0	 1	 -30.0	 30.0;
	7552	 5957	 0.010593	 0.423596	 0.0	 75	 75	 75	 0.996851	 0.0	 1	 -30.0	 30.0;
	7552	 5956	 0.010593	 0.423596	 0.0	 75	 75	 75	 0.996851	 0.0	 1	 -30.0	 30.0;
	7552	 5955	 0.010593	 0.423596	 0.0	 75	 75	 75	 0.996851	 0.0	 1	 -30.0	 30.0;
	4803	 10405	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.002302	 0.0	 1	 -30.0	 30.0;
	4803	 10404	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.002302	 0.0	 1	 -30.0	 30.0;
	4803	 8301	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.002302	 0.0	 1	 -30.0	 30.0;
	4803	 10402	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.002302	 0.0	 1	 -30.0	 30.0;
	4803	 10401	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.002302	 0.0	 1	 -30.0	 30.0;
	6993	 5961	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.007029	 0.0	 1	 -30.0	 30.0;
	6993	 660	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.007029	 0.0	 1	 -30.0	 30.0;
	6993	 12521	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.007029	 0.0	 1	 -30.0	 30.0;
	6993	 12522	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.007029	 0.0	 1	 -30.0	 30.0;
	6993	 12523	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.007029	 0.0	 1	 -30.0	 30.0;
	650	 7070	 0.044643	 1.785156	 0.0	 18	 18	 18	 0.995676	 0.0	 1	 -30.0	 30.0;
	7271	 7981	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.008678	 0.0	 1	 -30.0	 30.0;
	7271	 7979	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.008678	 0.0	 1	 -30.0	 30.0;
	7271	 7452	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.008678	 0.0	 1	 -30.0	 30.0;
	7271	 7988	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.008678	 0.0	 1	 -30.0	 30.0;
	7271	 7989	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.008678	 0.0	 1	 -30.0	 30.0;
	7271	 69	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.008678	 0.0	 1	 -30.0	 30.0;
	7271	 68	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.008678	 0.0	 1	 -30.0	 30.0;
	9031	 7350	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.015263	 0.0	 1	 -30.0	 30.0;
	9031	 7349	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.015263	 0.0	 1	 -30.0	 30.0;
	4865	 7352	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.004302	 0.0	 1	 -30.0	 30.0;
	4865	 6963	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.004302	 0.0	 1	 -30.0	 30.0;
	8177	 3714	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.005823	 0.0	 1	 -30.0	 30.0;
	8177	 3712	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.005823	 0.0	 1	 -30.0	 30.0;
	8177	 7346	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.005823	 0.0	 1	 -30.0	 30.0;
	8489	 7345	 0.055556	 2.221528	 0.0	 15	 15	 15	 0.996402	 0.0	 1	 -30.0	 30.0;
	6995	 336	 0.012755	 0.510045	 0.0	 62	 62	 62	 1.007861	 0.0	 1	 -30.0	 30.0;
	6995	 337	 0.012755	 0.510045	 0.0	 62	 62	 62	 1.00231	 0.0	 1	 -30.0	 30.0;
	6995	 334	 0.012755	 0.510045	 0.0	 62	 62	 62	 1.00231	 0.0	 1	 -30.0	 30.0;
	6995	 12562	 0.012755	 0.510045	 0.0	 62	 62	 62	 1.00231	 0.0	 1	 -30.0	 30.0;
	2965	 6372	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.009877	 0.0	 1	 -30.0	 30.0;
	2965	 6371	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.009877	 0.0	 1	 -30.0	 30.0;
	2965	 6370	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.009877	 0.0	 1	 -30.0	 30.0;
	2965	 6369	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.009877	 0.0	 1	 -30.0	 30.0;
	1756	 338	 0.01269	 0.507456	 0.0	 63	 63	 63	 1.001925	 0.0	 1	 -30.0	 30.0;
	1756	 339	 0.01269	 0.507456	 0.0	 63	 63	 63	 0.996225	 0.0	 1	 -30.0	 30.0;
	1756	 13538	 0.01269	 0.507456	 0.0	 63	 63	 63	 0.996225	 0.0	 1	 -30.0	 30.0;
	1756	 11887	 0.01269	 0.507456	 0.0	 63	 63	 63	 0.996225	 0.0	 1	 -30.0	 30.0;
	3173	 12863	 0.039062	 1.562012	 0.0	 21	 21	 21	 1.008878	 0.0	 1	 -30.0	 30.0;
	7954	 12864	 0.011161	 0.446289	 0.0	 71	 71	 71	 1.001165	 0.0	 1	 -30.0	 30.0;
	7954	 12858	 0.011161	 0.446289	 0.0	 71	 71	 71	 0.995363	 0.0	 1	 -30.0	 30.0;
	7954	 13535	 0.011161	 0.446289	 0.0	 71	 71	 71	 0.995363	 0.0	 1	 -30.0	 30.0;
	7954	 13532	 0.011161	 0.446289	 0.0	 71	 71	 71	 0.995363	 0.0	 1	 -30.0	 30.0;
	7954	 13533	 0.011161	 0.446289	 0.0	 71	 71	 71	 0.995363	 0.0	 1	 -30.0	 30.0;
	1370	 12847	 0.018797	 0.751645	 0.0	 43	 43	 43	 1.004207	 0.0	 1	 -30.0	 30.0;
	1370	 13531	 0.018797	 0.751645	 0.0	 43	 43	 43	 0.998764	 0.0	 1	 -30.0	 30.0;
	1370	 6892	 0.018797	 0.751645	 0.0	 43	 43	 43	 0.998764	 0.0	 1	 -30.0	 30.0;
	12923	 10222	 0.006234	 0.249299	 0.0	 127	 127	 127	 1.009643	 0.0	 1	 -30.0	 30.0;
	12923	 613	 0.006234	 0.249299	 0.0	 127	 127	 127	 1.003323	 0.0	 1	 -30.0	 30.0;
	12923	 6893	 0.006234	 0.249299	 0.0	 127	 127	 127	 1.003323	 0.0	 1	 -30.0	 30.0;
	1156	 8843	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.019287	 0.0	 1	 -30.0	 30.0;
	1156	 8844	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.019287	 0.0	 1	 -30.0	 30.0;
	1156	 8841	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.019287	 0.0	 1	 -30.0	 30.0;
	1156	 8842	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.019287	 0.0	 1	 -30.0	 30.0;
	1156	 12772	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.019287	 0.0	 1	 -30.0	 30.0;
	12143	 4764	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.014355	 0.0	 1	 -30.0	 30.0;
	12143	 165	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.014355	 0.0	 1	 -30.0	 30.0;
	12143	 11805	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.014355	 0.0	 1	 -30.0	 30.0;
	12143	 135	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.014355	 0.0	 1	 -30.0	 30.0;
	12143	 2870	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.014355	 0.0	 1	 -30.0	 30.0;
	12143	 114	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.014355	 0.0	 1	 -30.0	 30.0;
	3480	 9897	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.004936	 0.0	 1	 -30.0	 30.0;
	3480	 9900	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.004936	 0.0	 1	 -30.0	 30.0;
	5377	 13032	 0.012626	 0.504893	 0.0	 63	 63	 63	 1.00684	 0.0	 1	 -30.0	 30.0;
	5377	 13024	 0.012626	 0.504893	 0.0	 63	 63	 63	 1.00129	 0.0	 1	 -30.0	 30.0;
	5377	 6179	 0.012626	 0.504893	 0.0	 63	 63	 63	 1.00129	 0.0	 1	 -30.0	 30.0;
	5377	 6430	 0.012626	 0.504893	 0.0	 63	 63	 63	 1.00129	 0.0	 1	 -30.0	 30.0;
	7407	 6429	 0.015337	 0.613305	 0.0	 52	 52	 52	 1.018686	 0.0	 1	 -30.0	 30.0;
	7407	 6428	 0.015337	 0.613305	 0.0	 52	 52	 52	 1.013588	 0.0	 1	 -30.0	 30.0;
	7407	 6427	 0.015337	 0.613305	 0.0	 52	 52	 52	 1.013588	 0.0	 1	 -30.0	 30.0;
	7714	 4345	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.008519	 0.0	 1	 -30.0	 30.0;
	7714	 4343	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.008519	 0.0	 1	 -30.0	 30.0;
	7714	 5262	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.008519	 0.0	 1	 -30.0	 30.0;
	7714	 5261	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.008519	 0.0	 1	 -30.0	 30.0;
	7714	 4314	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.008519	 0.0	 1	 -30.0	 30.0;
	7714	 5252	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.008519	 0.0	 1	 -30.0	 30.0;
	7353	 839	 0.027174	 1.086617	 0.0	 30	 30	 30	 1.001829	 0.0	 1	 -30.0	 30.0;
	7353	 840	 0.027174	 1.086617	 0.0	 30	 30	 30	 0.996237	 0.0	 1	 -30.0	 30.0;
	6271	 5323	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.009813	 0.0	 1	 -30.0	 30.0;
	6271	 5324	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.009813	 0.0	 1	 -30.0	 30.0;
	6271	 5327	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.009813	 0.0	 1	 -30.0	 30.0;
	6271	 5328	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.009813	 0.0	 1	 -30.0	 30.0;
	6271	 5325	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.009813	 0.0	 1	 -30.0	 30.0;
	6271	 5326	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.009813	 0.0	 1	 -30.0	 30.0;
	1793	 836	 0.010684	 0.427217	 0.0	 74	 74	 74	 0.995406	 0.0	 1	 -30.0	 30.0;
	1793	 837	 0.010684	 0.427217	 0.0	 74	 74	 74	 0.989647	 0.0	 1	 -30.0	 30.0;
	1793	 7824	 0.010684	 0.427217	 0.0	 74	 74	 74	 0.989647	 0.0	 1	 -30.0	 30.0;
	1793	 6665	 0.010684	 0.427217	 0.0	 74	 74	 74	 0.989647	 0.0	 1	 -30.0	 30.0;
	1793	 6673	 0.010684	 0.427217	 0.0	 74	 74	 74	 0.989647	 0.0	 1	 -30.0	 30.0;
	7223	 7825	 0.010121	 0.404732	 0.0	 79	 79	 79	 1.011129	 0.0	 1	 -30.0	 30.0;
	7223	 7820	 0.010121	 0.404732	 0.0	 79	 79	 79	 1.005661	 0.0	 1	 -30.0	 30.0;
	7223	 7819	 0.010121	 0.404732	 0.0	 79	 79	 79	 1.005661	 0.0	 1	 -30.0	 30.0;
	7223	 7822	 0.010121	 0.404732	 0.0	 79	 79	 79	 1.005661	 0.0	 1	 -30.0	 30.0;
	7223	 7821	 0.010121	 0.404732	 0.0	 79	 79	 79	 1.005661	 0.0	 1	 -30.0	 30.0;
	11657	 7476	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.009608	 0.0	 1	 -30.0	 30.0;
	11657	 7477	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.009608	 0.0	 1	 -30.0	 30.0;
	11657	 1401	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.009608	 0.0	 1	 -30.0	 30.0;
	9729	 3997	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.010514	 0.0	 1	 -30.0	 30.0;
	9729	 5163	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.010514	 0.0	 1	 -30.0	 30.0;
	9729	 5159	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.010514	 0.0	 1	 -30.0	 30.0;
	9729	 2198	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.010514	 0.0	 1	 -30.0	 30.0;
	9729	 9862	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.010514	 0.0	 1	 -30.0	 30.0;
	9729	 12915	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.010514	 0.0	 1	 -30.0	 30.0;
	9729	 5143	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.010514	 0.0	 1	 -30.0	 30.0;
	9729	 9870	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.010514	 0.0	 1	 -30.0	 30.0;
	10227	 6141	 0.000212	 0.008494	 0.0	 3718	 3718	 3718	 1.033809	 0.0	 1	 -30.0	 30.0;
	10227	 11909	 0.000212	 0.008494	 0.0	 3718	 3718	 3718	 1.033809	 0.0	 1	 -30.0	 30.0;
	9285	 3013	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.023002	 0.0	 1	 -30.0	 30.0;
	1248	 3015	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.018748	 0.0	 1	 -30.0	 30.0;
	9904	 5359	 0.014535	 0.581214	 0.0	 55	 55	 55	 1.029865	 0.0	 1	 -30.0	 30.0;
	9904	 3011	 0.014535	 0.581214	 0.0	 55	 55	 55	 1.023462	 0.0	 1	 -30.0	 30.0;
	9845	 12986	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.005575	 0.0	 1	 -30.0	 30.0;
	9845	 12984	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.005575	 0.0	 1	 -30.0	 30.0;
	7816	 3012	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.017952	 0.0	 1	 -30.0	 30.0;
	2626	 12993	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.988287	 0.0	 1	 -30.0	 30.0;
	2626	 12994	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.988287	 0.0	 1	 -30.0	 30.0;
	2626	 4926	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.988287	 0.0	 1	 -30.0	 30.0;
	1054	 5060	 0.000531	 0.021225	 0.0	 1787	 1787	 1787	 1.071275	 0.0	 1	 -30.0	 30.0;
	1054	 5059	 0.000531	 0.021225	 0.0	 1787	 1787	 1787	 1.071275	 0.0	 1	 -30.0	 30.0;
	8812	 5058	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 0.995514	 0.0	 1	 -30.0	 30.0;
	8812	 5065	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 0.995514	 0.0	 1	 -30.0	 30.0;
	9419	 5064	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.004959	 0.0	 1	 -30.0	 30.0;
	9419	 5063	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.004959	 0.0	 1	 -30.0	 30.0;
	9419	 5062	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.004959	 0.0	 1	 -30.0	 30.0;
	929	 4932	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.013798	 0.0	 1	 -30.0	 30.0;
	929	 4931	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.013798	 0.0	 1	 -30.0	 30.0;
	929	 1079	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.013798	 0.0	 1	 -30.0	 30.0;
	7355	 12084	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.031633	 0.0	 1	 -30.0	 30.0;
	7355	 12085	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.031633	 0.0	 1	 -30.0	 30.0;
	4754	 1090	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.02899	 0.0	 1	 -30.0	 30.0;
	4754	 11471	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.02899	 0.0	 1	 -30.0	 30.0;
	12640	 1073	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.005352	 0.0	 1	 -30.0	 30.0;
	10889	 6865	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.006368	 0.0	 1	 -30.0	 30.0;
	10889	 11474	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.006368	 0.0	 1	 -30.0	 30.0;
	7239	 11481	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.996372	 0.0	 1	 -30.0	 30.0;
	5893	 11482	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.019827	 0.0	 1	 -30.0	 30.0;
	5893	 8719	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.019827	 0.0	 1	 -30.0	 30.0;
	5893	 3625	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.019827	 0.0	 1	 -30.0	 30.0;
	3390	 6162	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.026009	 0.0	 1	 -30.0	 30.0;
	3390	 6161	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.026009	 0.0	 1	 -30.0	 30.0;
	13014	 3621	 0.006887	 0.275396	 0.0	 115	 115	 115	 0.990478	 0.0	 1	 -30.0	 30.0;
	13014	 3622	 0.006887	 0.275396	 0.0	 115	 115	 115	 0.98327	 0.0	 1	 -30.0	 30.0;
	11341	 3619	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.021717	 0.0	 1	 -30.0	 30.0;
	11341	 3620	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.021717	 0.0	 1	 -30.0	 30.0;
	4230	 11333	 0.000708	 0.02832	 0.0	 1340	 1340	 1340	 1.061078	 0.0	 1	 -30.0	 30.0;
	4230	 11332	 0.000708	 0.02832	 0.0	 1340	 1340	 1340	 1.061078	 0.0	 1	 -30.0	 30.0;
	2724	 4253	 0.000708	 0.02832	 0.0	 1340	 1340	 1340	 1.061049	 0.0	 1	 -30.0	 30.0;
	2724	 4254	 0.000708	 0.02832	 0.0	 1340	 1340	 1340	 1.061049	 0.0	 1	 -30.0	 30.0;
	1580	 12764	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.014526	 0.0	 1	 -30.0	 30.0;
	1580	 12765	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.014526	 0.0	 1	 -30.0	 30.0;
	5506	 10720	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.011624	 0.0	 1	 -30.0	 30.0;
	5506	 10719	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.011624	 0.0	 1	 -30.0	 30.0;
	10725	 10722	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.017259	 0.0	 1	 -30.0	 30.0;
	10725	 10721	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.017259	 0.0	 1	 -30.0	 30.0;
	10725	 10713	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.017259	 0.0	 1	 -30.0	 30.0;
	3950	 10712	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.000028	 0.0	 1	 -30.0	 30.0;
	3950	 3107	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.000028	 0.0	 1	 -30.0	 30.0;
	3950	 3108	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.000028	 0.0	 1	 -30.0	 30.0;
	269	 3109	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.999904	 0.0	 1	 -30.0	 30.0;
	269	 5931	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.999904	 0.0	 1	 -30.0	 30.0;
	269	 3111	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.999904	 0.0	 1	 -30.0	 30.0;
	5113	 3112	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.997275	 0.0	 1	 -30.0	 30.0;
	5917	 3113	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.005853	 0.0	 1	 -30.0	 30.0;
	3069	 5695	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.009328	 0.0	 1	 -30.0	 30.0;
	3069	 4393	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.009328	 0.0	 1	 -30.0	 30.0;
	8790	 3114	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.009286	 0.0	 1	 -30.0	 30.0;
	8790	 7291	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.009286	 0.0	 1	 -30.0	 30.0;
	8790	 10236	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.009286	 0.0	 1	 -30.0	 30.0;
	349	 10378	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.018538	 0.0	 1	 -30.0	 30.0;
	349	 10377	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.018538	 0.0	 1	 -30.0	 30.0;
	9516	 5322	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.018339	 0.0	 1	 -30.0	 30.0;
	9516	 10238	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.018339	 0.0	 1	 -30.0	 30.0;
	13276	 10375	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.019667	 0.0	 1	 -30.0	 30.0;
	13276	 10374	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.019667	 0.0	 1	 -30.0	 30.0;
	355	 10242	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.022088	 0.0	 1	 -30.0	 30.0;
	355	 10241	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.022088	 0.0	 1	 -30.0	 30.0;
	7941	 4618	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.020489	 0.0	 1	 -30.0	 30.0;
	7941	 4619	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.020489	 0.0	 1	 -30.0	 30.0;
	3032	 855	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.014053	 0.0	 1	 -30.0	 30.0;
	3060	 4617	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.001991	 0.0	 1	 -30.0	 30.0;
	5203	 5287	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.01887	 0.0	 1	 -30.0	 30.0;
	5203	 5286	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.01887	 0.0	 1	 -30.0	 30.0;
	12735	 2389	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.014122	 0.0	 1	 -30.0	 30.0;
	12735	 405	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.014122	 0.0	 1	 -30.0	 30.0;
	12735	 406	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.014122	 0.0	 1	 -30.0	 30.0;
	12339	 6406	 0.000531	 0.021225	 0.0	 1787	 1787	 1787	 1.036689	 0.0	 1	 -30.0	 30.0;
	11063	 7372	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.014323	 0.0	 1	 -30.0	 30.0;
	11063	 11529	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.014323	 0.0	 1	 -30.0	 30.0;
	11063	 7370	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.014323	 0.0	 1	 -30.0	 30.0;
	7310	 7369	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.016047	 0.0	 1	 -30.0	 30.0;
	7310	 7376	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.016047	 0.0	 1	 -30.0	 30.0;
	7310	 7375	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.016047	 0.0	 1	 -30.0	 30.0;
	7310	 7374	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.016047	 0.0	 1	 -30.0	 30.0;
	6124	 3838	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.010237	 0.0	 1	 -30.0	 30.0;
	8697	 7379	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.017221	 0.0	 1	 -30.0	 30.0;
	8697	 7378	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.017221	 0.0	 1	 -30.0	 30.0;
	3659	 3934	 0.006812	 0.272394	 0.0	 116	 116	 116	 1.006012	 0.0	 1	 -30.0	 30.0;
	3659	 867	 0.006812	 0.272394	 0.0	 116	 116	 116	 1.000062	 0.0	 1	 -30.0	 30.0;
	7708	 865	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.020068	 0.0	 1	 -30.0	 30.0;
	7708	 5385	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.020068	 0.0	 1	 -30.0	 30.0;
	7708	 864	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.020068	 0.0	 1	 -30.0	 30.0;
	7708	 861	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.020068	 0.0	 1	 -30.0	 30.0;
	7708	 862	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.020068	 0.0	 1	 -30.0	 30.0;
	4311	 4452	 0.000531	 0.021225	 0.0	 1787	 1787	 1787	 1.036461	 0.0	 1	 -30.0	 30.0;
	9193	 874	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.014398	 0.0	 1	 -30.0	 30.0;
	9193	 10363	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.014398	 0.0	 1	 -30.0	 30.0;
	9193	 10348	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.014398	 0.0	 1	 -30.0	 30.0;
	9193	 7847	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.014398	 0.0	 1	 -30.0	 30.0;
	3759	 6774	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.007294	 0.0	 1	 -30.0	 30.0;
	3759	 6785	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.007294	 0.0	 1	 -30.0	 30.0;
	3759	 7848	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.007294	 0.0	 1	 -30.0	 30.0;
	3759	 7851	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.007294	 0.0	 1	 -30.0	 30.0;
	3759	 6789	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.007294	 0.0	 1	 -30.0	 30.0;
	3759	 7842	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.007294	 0.0	 1	 -30.0	 30.0;
	13194	 7841	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.018581	 0.0	 1	 -30.0	 30.0;
	13194	 10034	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.018581	 0.0	 1	 -30.0	 30.0;
	1616	 13052	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.013895	 0.0	 1	 -30.0	 30.0;
	1616	 13053	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.013895	 0.0	 1	 -30.0	 30.0;
	1616	 13054	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.013895	 0.0	 1	 -30.0	 30.0;
	1616	 13047	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.013895	 0.0	 1	 -30.0	 30.0;
	1616	 13048	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.013895	 0.0	 1	 -30.0	 30.0;
	1616	 13049	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.013895	 0.0	 1	 -30.0	 30.0;
	1375	 5352	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.012511	 0.0	 1	 -30.0	 30.0;
	1375	 13057	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.012511	 0.0	 1	 -30.0	 30.0;
	1375	 13058	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.012511	 0.0	 1	 -30.0	 30.0;
	12377	 6456	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.017604	 0.0	 1	 -30.0	 30.0;
	12377	 6455	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.017604	 0.0	 1	 -30.0	 30.0;
	4711	 4197	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.001876	 0.0	 1	 -30.0	 30.0;
	13164	 4195	 0.000531	 0.021225	 0.0	 1787	 1787	 1787	 1.03326	 0.0	 1	 -30.0	 30.0;
	13267	 6452	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.016595	 0.0	 1	 -30.0	 30.0;
	303	 6451	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.008958	 0.0	 1	 -30.0	 30.0;
	10454	 2974	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.027567	 0.0	 1	 -30.0	 30.0;
	10454	 2973	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.027567	 0.0	 1	 -30.0	 30.0;
	10454	 2969	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.027567	 0.0	 1	 -30.0	 30.0;
	10454	 2968	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.027567	 0.0	 1	 -30.0	 30.0;
	10454	 9880	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.027567	 0.0	 1	 -30.0	 30.0;
	3439	 8373	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.027993	 0.0	 1	 -30.0	 30.0;
	3439	 9885	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.027993	 0.0	 1	 -30.0	 30.0;
	3439	 10410	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.027993	 0.0	 1	 -30.0	 30.0;
	3439	 8378	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.027993	 0.0	 1	 -30.0	 30.0;
	3439	 9887	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.027993	 0.0	 1	 -30.0	 30.0;
	5735	 8380	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.020775	 0.0	 1	 -30.0	 30.0;
	5735	 10096	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.020775	 0.0	 1	 -30.0	 30.0;
	5735	 8369	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.020775	 0.0	 1	 -30.0	 30.0;
	7065	 6262	 0.000531	 0.021225	 0.0	 1787	 1787	 1787	 1.036199	 0.0	 1	 -30.0	 30.0;
	7065	 12859	 0.000531	 0.021225	 0.0	 1787	 1787	 1787	 1.036199	 0.0	 1	 -30.0	 30.0;
	7065	 8921	 0.000531	 0.021225	 0.0	 1787	 1787	 1787	 1.036199	 0.0	 1	 -30.0	 30.0;
	11134	 1342	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.021621	 0.0	 1	 -30.0	 30.0;
	11134	 1343	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.021621	 0.0	 1	 -30.0	 30.0;
	11134	 8457	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.021621	 0.0	 1	 -30.0	 30.0;
	11134	 8459	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.021621	 0.0	 1	 -30.0	 30.0;
	11134	 1338	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.021621	 0.0	 1	 -30.0	 30.0;
	11134	 1339	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.021621	 0.0	 1	 -30.0	 30.0;
	11134	 1348	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.021621	 0.0	 1	 -30.0	 30.0;
	7607	 1349	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.986347	 0.0	 1	 -30.0	 30.0;
	4295	 7902	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.999582	 0.0	 1	 -30.0	 30.0;
	4295	 7901	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.999582	 0.0	 1	 -30.0	 30.0;
	12399	 7056	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.013814	 0.0	 1	 -30.0	 30.0;
	9688	 7899	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.00918	 0.0	 1	 -30.0	 30.0;
	11906	 7075	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.021759	 0.0	 1	 -30.0	 30.0;
	11906	 7905	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.021759	 0.0	 1	 -30.0	 30.0;
	12502	 7904	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.00786	 0.0	 1	 -30.0	 30.0;
	12502	 7903	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.00786	 0.0	 1	 -30.0	 30.0;
	12502	 7908	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.00786	 0.0	 1	 -30.0	 30.0;
	13559	 2345	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.03506	 0.0	 1	 -30.0	 30.0;
	12405	 9439	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.035095	 0.0	 1	 -30.0	 30.0;
	12493	 12346	 0.000531	 0.021225	 0.0	 1787	 1787	 1787	 1.045702	 0.0	 1	 -30.0	 30.0;
	12493	 485	 0.000531	 0.021225	 0.0	 1787	 1787	 1787	 1.045702	 0.0	 1	 -30.0	 30.0;
	6525	 12348	 0.000531	 0.021225	 0.0	 1787	 1787	 1787	 1.04939	 0.0	 1	 -30.0	 30.0;
	1635	 4501	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.015794	 0.0	 1	 -30.0	 30.0;
	1635	 4512	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.015794	 0.0	 1	 -30.0	 30.0;
	1635	 904	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.015794	 0.0	 1	 -30.0	 30.0;
	1635	 5668	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.015794	 0.0	 1	 -30.0	 30.0;
	1635	 5670	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.015794	 0.0	 1	 -30.0	 30.0;
	1635	 907	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.015794	 0.0	 1	 -30.0	 30.0;
	6991	 9350	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.015729	 0.0	 1	 -30.0	 30.0;
	6991	 9349	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.015729	 0.0	 1	 -30.0	 30.0;
	6991	 9352	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.015729	 0.0	 1	 -30.0	 30.0;
	6991	 9351	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.015729	 0.0	 1	 -30.0	 30.0;
	6991	 9346	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.015729	 0.0	 1	 -30.0	 30.0;
	6991	 9345	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.015729	 0.0	 1	 -30.0	 30.0;
	6991	 9348	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.015729	 0.0	 1	 -30.0	 30.0;
	6991	 9347	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.015729	 0.0	 1	 -30.0	 30.0;
	10515	 4612	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.021677	 0.0	 1	 -30.0	 30.0;
	6745	 5311	 0.000531	 0.021225	 0.0	 1787	 1787	 1787	 1.048652	 0.0	 1	 -30.0	 30.0;
	6745	 11853	 0.000531	 0.021225	 0.0	 1787	 1787	 1787	 1.048652	 0.0	 1	 -30.0	 30.0;
	12832	 11854	 0.000531	 0.021225	 0.0	 1787	 1787	 1787	 1.049636	 0.0	 1	 -30.0	 30.0;
	12832	 11851	 0.000531	 0.021225	 0.0	 1787	 1787	 1787	 1.049636	 0.0	 1	 -30.0	 30.0;
	13376	 3152	 0.000531	 0.021225	 0.0	 1787	 1787	 1787	 1.050924	 0.0	 1	 -30.0	 30.0;
	3689	 2249	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.99761	 0.0	 1	 -30.0	 30.0;
	3689	 610	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.99761	 0.0	 1	 -30.0	 30.0;
	3689	 2247	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.99761	 0.0	 1	 -30.0	 30.0;
	3689	 2248	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.99761	 0.0	 1	 -30.0	 30.0;
	3689	 2252	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.99761	 0.0	 1	 -30.0	 30.0;
	5511	 2253	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.009317	 0.0	 1	 -30.0	 30.0;
	5511	 12856	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.009317	 0.0	 1	 -30.0	 30.0;
	5511	 8867	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.009317	 0.0	 1	 -30.0	 30.0;
	5511	 8866	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.009317	 0.0	 1	 -30.0	 30.0;
	5511	 9914	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.009317	 0.0	 1	 -30.0	 30.0;
	5511	 8864	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.009317	 0.0	 1	 -30.0	 30.0;
	5511	 12843	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.009317	 0.0	 1	 -30.0	 30.0;
	5511	 12840	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.009317	 0.0	 1	 -30.0	 30.0;
	11269	 8861	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.000207	 0.0	 1	 -30.0	 30.0;
	11269	 8860	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.000207	 0.0	 1	 -30.0	 30.0;
	9582	 8167	 0.000531	 0.021225	 0.0	 1787	 1787	 1787	 1.050391	 0.0	 1	 -30.0	 30.0;
	9582	 11360	 0.000531	 0.021225	 0.0	 1787	 1787	 1787	 1.050391	 0.0	 1	 -30.0	 30.0;
	3212	 11361	 0.000531	 0.021225	 0.0	 1787	 1787	 1787	 1.050989	 0.0	 1	 -30.0	 30.0;
	3212	 11362	 0.000531	 0.021225	 0.0	 1787	 1787	 1787	 1.050989	 0.0	 1	 -30.0	 30.0;
	6069	 11363	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.018821	 0.0	 1	 -30.0	 30.0;
	9994	 1805	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.000404	 0.0	 1	 -30.0	 30.0;
	9994	 11336	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.000404	 0.0	 1	 -30.0	 30.0;
	9994	 1807	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.000404	 0.0	 1	 -30.0	 30.0;
	7863	 1808	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.001243	 0.0	 1	 -30.0	 30.0;
	7863	 1803	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.001243	 0.0	 1	 -30.0	 30.0;
	10552	 11327	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.999161	 0.0	 1	 -30.0	 30.0;
	10552	 6542	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.999161	 0.0	 1	 -30.0	 30.0;
	10552	 6541	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.999161	 0.0	 1	 -30.0	 30.0;
	10552	 12106	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.999161	 0.0	 1	 -30.0	 30.0;
	10552	 6543	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.999161	 0.0	 1	 -30.0	 30.0;
	9298	 12904	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.988425	 0.0	 1	 -30.0	 30.0;
	9298	 6545	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.988425	 0.0	 1	 -30.0	 30.0;
	5046	 3325	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.002306	 0.0	 1	 -30.0	 30.0;
	5046	 3326	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.002306	 0.0	 1	 -30.0	 30.0;
	4215	 3327	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.002332	 0.0	 1	 -30.0	 30.0;
	4215	 3328	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.002332	 0.0	 1	 -30.0	 30.0;
	2033	 8445	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.002303	 0.0	 1	 -30.0	 30.0;
	2033	 10422	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.002303	 0.0	 1	 -30.0	 30.0;
	2634	 8441	 0.013021	 0.520671	 0.0	 61	 61	 61	 1.002567	 0.0	 1	 -30.0	 30.0;
	2634	 10420	 0.013021	 0.520671	 0.0	 61	 61	 61	 0.997547	 0.0	 1	 -30.0	 30.0;
	3475	 10427	 0.005376	 0.214987	 0.0	 147	 147	 147	 1.008205	 0.0	 1	 -30.0	 30.0;
	3475	 10426	 0.005376	 0.214987	 0.0	 147	 147	 147	 1.008205	 0.0	 1	 -30.0	 30.0;
	3475	 10425	 0.005376	 0.214987	 0.0	 147	 147	 147	 1.002391	 0.0	 1	 -30.0	 30.0;
	3475	 10424	 0.005376	 0.214987	 0.0	 147	 147	 147	 1.002391	 0.0	 1	 -30.0	 30.0;
	3475	 10430	 0.005376	 0.214987	 0.0	 147	 147	 147	 1.002391	 0.0	 1	 -30.0	 30.0;
	3475	 10429	 0.005376	 0.214987	 0.0	 147	 147	 147	 1.002391	 0.0	 1	 -30.0	 30.0;
	3475	 4546	 0.005376	 0.214987	 0.0	 147	 147	 147	 1.002391	 0.0	 1	 -30.0	 30.0;
	3475	 4545	 0.005376	 0.214987	 0.0	 147	 147	 147	 1.002391	 0.0	 1	 -30.0	 30.0;
	606	 4548	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.002921	 0.0	 1	 -30.0	 30.0;
	606	 4547	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.002921	 0.0	 1	 -30.0	 30.0;
	606	 4550	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.002921	 0.0	 1	 -30.0	 30.0;
	606	 4549	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.002921	 0.0	 1	 -30.0	 30.0;
	606	 4552	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.002921	 0.0	 1	 -30.0	 30.0;
	606	 4551	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.002921	 0.0	 1	 -30.0	 30.0;
	606	 4554	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.002921	 0.0	 1	 -30.0	 30.0;
	4667	 4553	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.994464	 0.0	 1	 -30.0	 30.0;
	4667	 11110	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.994464	 0.0	 1	 -30.0	 30.0;
	13517	 11111	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.004859	 0.0	 1	 -30.0	 30.0;
	13517	 11108	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.004859	 0.0	 1	 -30.0	 30.0;
	13517	 11109	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.004859	 0.0	 1	 -30.0	 30.0;
	13517	 11106	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.004859	 0.0	 1	 -30.0	 30.0;
	9749	 11107	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.995889	 0.0	 1	 -30.0	 30.0;
	9749	 11104	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.995889	 0.0	 1	 -30.0	 30.0;
	9749	 12747	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.995889	 0.0	 1	 -30.0	 30.0;
	9749	 11102	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.995889	 0.0	 1	 -30.0	 30.0;
	9749	 12742	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.995889	 0.0	 1	 -30.0	 30.0;
	7207	 4025	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.01276	 0.0	 1	 -30.0	 30.0;
	7207	 4024	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.01276	 0.0	 1	 -30.0	 30.0;
	12238	 11229	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.010163	 0.0	 1	 -30.0	 30.0;
	3251	 4022	 0.005241	 0.209578	 0.0	 151	 151	 151	 1.012049	 0.0	 1	 -30.0	 30.0;
	3251	 4029	 0.005241	 0.209578	 0.0	 151	 151	 151	 1.006682	 0.0	 1	 -30.0	 30.0;
	3251	 4028	 0.005241	 0.209578	 0.0	 151	 151	 151	 1.006682	 0.0	 1	 -30.0	 30.0;
	6613	 4027	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.00475	 0.0	 1	 -30.0	 30.0;
	6613	 4026	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.00475	 0.0	 1	 -30.0	 30.0;
	5839	 4021	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.00953	 0.0	 1	 -30.0	 30.0;
	5839	 4020	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.00953	 0.0	 1	 -30.0	 30.0;
	5839	 10653	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.00953	 0.0	 1	 -30.0	 30.0;
	9998	 11289	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.00503	 0.0	 1	 -30.0	 30.0;
	9998	 11309	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.00503	 0.0	 1	 -30.0	 30.0;
	9998	 10656	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.00503	 0.0	 1	 -30.0	 30.0;
	8287	 10657	 0.004587	 0.183429	 0.0	 173	 173	 173	 1.001503	 0.0	 1	 -30.0	 30.0;
	8287	 10658	 0.004587	 0.183429	 0.0	 173	 173	 173	 1.001503	 0.0	 1	 -30.0	 30.0;
	8287	 10659	 0.004587	 0.183429	 0.0	 173	 173	 173	 0.995758	 0.0	 1	 -30.0	 30.0;
	5786	 10660	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.01197	 0.0	 1	 -30.0	 30.0;
	5786	 10648	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.01197	 0.0	 1	 -30.0	 30.0;
	5786	 10649	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.01197	 0.0	 1	 -30.0	 30.0;
	2291	 5612	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.999252	 0.0	 1	 -30.0	 30.0;
	2291	 5611	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.999252	 0.0	 1	 -30.0	 30.0;
	4078	 5614	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.999206	 0.0	 1	 -30.0	 30.0;
	1919	 5613	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.99686	 0.0	 1	 -30.0	 30.0;
	1919	 5608	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.99686	 0.0	 1	 -30.0	 30.0;
	3391	 5607	 0.005981	 0.23916	 0.0	 133	 133	 133	 1.013491	 0.0	 1	 -30.0	 30.0;
	3391	 5610	 0.005981	 0.23916	 0.0	 133	 133	 133	 1.013491	 0.0	 1	 -30.0	 30.0;
	3391	 5609	 0.005981	 0.23916	 0.0	 133	 133	 133	 1.008757	 0.0	 1	 -30.0	 30.0;
	3391	 5606	 0.005981	 0.23916	 0.0	 133	 133	 133	 1.008757	 0.0	 1	 -30.0	 30.0;
	3391	 5605	 0.005981	 0.23916	 0.0	 133	 133	 133	 1.008757	 0.0	 1	 -30.0	 30.0;
	12003	 12168	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.014777	 0.0	 1	 -30.0	 30.0;
	12003	 12169	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.014777	 0.0	 1	 -30.0	 30.0;
	12003	 12166	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.014777	 0.0	 1	 -30.0	 30.0;
	12003	 12167	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.014777	 0.0	 1	 -30.0	 30.0;
	12003	 12172	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.014777	 0.0	 1	 -30.0	 30.0;
	13566	 11203	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.980347	 0.0	 1	 -30.0	 30.0;
	13566	 12170	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.980347	 0.0	 1	 -30.0	 30.0;
	13566	 12171	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.980347	 0.0	 1	 -30.0	 30.0;
	13566	 12163	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.980347	 0.0	 1	 -30.0	 30.0;
	13566	 12164	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.980347	 0.0	 1	 -30.0	 30.0;
	13566	 5057	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.980347	 0.0	 1	 -30.0	 30.0;
	13566	 5056	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.980347	 0.0	 1	 -30.0	 30.0;
	13566	 5055	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.980347	 0.0	 1	 -30.0	 30.0;
	13566	 5054	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.980347	 0.0	 1	 -30.0	 30.0;
	3802	 5053	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.009707	 0.0	 1	 -30.0	 30.0;
	3802	 5052	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.009707	 0.0	 1	 -30.0	 30.0;
	3802	 5051	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.009707	 0.0	 1	 -30.0	 30.0;
	13177	 5050	 0.012019	 0.480619	 0.0	 66	 66	 66	 0.987915	 0.0	 1	 -30.0	 30.0;
	13177	 3316	 0.012019	 0.480619	 0.0	 66	 66	 66	 0.982064	 0.0	 1	 -30.0	 30.0;
	13177	 3311	 0.012019	 0.480619	 0.0	 66	 66	 66	 0.982064	 0.0	 1	 -30.0	 30.0;
	13177	 11621	 0.012019	 0.480619	 0.0	 66	 66	 66	 0.982064	 0.0	 1	 -30.0	 30.0;
	13177	 11622	 0.012019	 0.480619	 0.0	 66	 66	 66	 0.982064	 0.0	 1	 -30.0	 30.0;
	11517	 11623	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.994434	 0.0	 1	 -30.0	 30.0;
	11517	 11624	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.994434	 0.0	 1	 -30.0	 30.0;
	11517	 11617	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.994434	 0.0	 1	 -30.0	 30.0;
	11517	 10151	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.994434	 0.0	 1	 -30.0	 30.0;
	11517	 10164	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.994434	 0.0	 1	 -30.0	 30.0;
	8047	 10178	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.008507	 0.0	 1	 -30.0	 30.0;
	8047	 11625	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.008507	 0.0	 1	 -30.0	 30.0;
	8047	 11626	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.008507	 0.0	 1	 -30.0	 30.0;
	8047	 6567	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.008507	 0.0	 1	 -30.0	 30.0;
	8047	 6566	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.008507	 0.0	 1	 -30.0	 30.0;
	8521	 12070	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.004493	 0.0	 1	 -30.0	 30.0;
	8521	 12069	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.004493	 0.0	 1	 -30.0	 30.0;
	8521	 4449	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.004493	 0.0	 1	 -30.0	 30.0;
	8521	 12071	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.004493	 0.0	 1	 -30.0	 30.0;
	8521	 12074	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.004493	 0.0	 1	 -30.0	 30.0;
	8521	 12073	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.004493	 0.0	 1	 -30.0	 30.0;
	8521	 12076	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.004493	 0.0	 1	 -30.0	 30.0;
	8521	 12075	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.004493	 0.0	 1	 -30.0	 30.0;
	8521	 5009	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.004493	 0.0	 1	 -30.0	 30.0;
	8521	 2963	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.004493	 0.0	 1	 -30.0	 30.0;
	8521	 5007	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.004493	 0.0	 1	 -30.0	 30.0;
	8521	 5008	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.004493	 0.0	 1	 -30.0	 30.0;
	4638	 3763	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.023046	 0.0	 1	 -30.0	 30.0;
	4638	 3297	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.023046	 0.0	 1	 -30.0	 30.0;
	4638	 3298	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.023046	 0.0	 1	 -30.0	 30.0;
	4638	 3299	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.023046	 0.0	 1	 -30.0	 30.0;
	4638	 3306	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.023046	 0.0	 1	 -30.0	 30.0;
	4638	 3307	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.023046	 0.0	 1	 -30.0	 30.0;
	4638	 7844	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.023046	 0.0	 1	 -30.0	 30.0;
	4638	 6773	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.023046	 0.0	 1	 -30.0	 30.0;
	4638	 7846	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.023046	 0.0	 1	 -30.0	 30.0;
	7987	 10558	 0.000212	 0.008494	 0.0	 3718	 3718	 3718	 1.013775	 0.0	 1	 -30.0	 30.0;
	7987	 9152	 0.000212	 0.008494	 0.0	 3718	 3718	 3718	 1.013775	 0.0	 1	 -30.0	 30.0;
	7987	 10555	 0.000212	 0.008494	 0.0	 3718	 3718	 3718	 1.013775	 0.0	 1	 -30.0	 30.0;
	7987	 10556	 0.000212	 0.008494	 0.0	 3718	 3718	 3718	 1.013775	 0.0	 1	 -30.0	 30.0;
	9538	 6398	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.023982	 0.0	 1	 -30.0	 30.0;
	9538	 11227	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.023982	 0.0	 1	 -30.0	 30.0;
	9538	 11231	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.023982	 0.0	 1	 -30.0	 30.0;
	9538	 9974	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.023982	 0.0	 1	 -30.0	 30.0;
	9538	 13500	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.023982	 0.0	 1	 -30.0	 30.0;
	9538	 2858	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.023982	 0.0	 1	 -30.0	 30.0;
	9538	 13502	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.023982	 0.0	 1	 -30.0	 30.0;
	11283	 13505	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.023979	 0.0	 1	 -30.0	 30.0;
	11283	 2871	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.023979	 0.0	 1	 -30.0	 30.0;
	11283	 13507	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.023979	 0.0	 1	 -30.0	 30.0;
	11283	 13506	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.023979	 0.0	 1	 -30.0	 30.0;
	11283	 13497	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.023979	 0.0	 1	 -30.0	 30.0;
	11283	 13496	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.023979	 0.0	 1	 -30.0	 30.0;
	11283	 5928	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.023979	 0.0	 1	 -30.0	 30.0;
	3572	 5929	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.011158	 0.0	 1	 -30.0	 30.0;
	3572	 5930	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.011158	 0.0	 1	 -30.0	 30.0;
	3572	 10622	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.011158	 0.0	 1	 -30.0	 30.0;
	3572	 5932	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.011158	 0.0	 1	 -30.0	 30.0;
	3572	 5933	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.011158	 0.0	 1	 -30.0	 30.0;
	3572	 5934	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.011158	 0.0	 1	 -30.0	 30.0;
	3572	 5935	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.010863	 0.0	 1	 -30.0	 30.0;
	3572	 5936	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.010863	 0.0	 1	 -30.0	 30.0;
	3572	 8323	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.010863	 0.0	 1	 -30.0	 30.0;
	4605	 13009	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.008667	 0.0	 1	 -30.0	 30.0;
	4605	 13008	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.008667	 0.0	 1	 -30.0	 30.0;
	4605	 13007	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.008667	 0.0	 1	 -30.0	 30.0;
	2696	 11167	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.014632	 0.0	 1	 -30.0	 30.0;
	2696	 10627	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.014632	 0.0	 1	 -30.0	 30.0;
	2696	 11172	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.014632	 0.0	 1	 -30.0	 30.0;
	2696	 13062	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.014632	 0.0	 1	 -30.0	 30.0;
	2696	 13066	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.014632	 0.0	 1	 -30.0	 30.0;
	2696	 11174	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.014632	 0.0	 1	 -30.0	 30.0;
	2696	 11175	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.014632	 0.0	 1	 -30.0	 30.0;
	2696	 3104	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.014632	 0.0	 1	 -30.0	 30.0;
	2696	 3103	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.014632	 0.0	 1	 -30.0	 30.0;
	823	 7282	 0.029412	 1.176103	 0.0	 27	 27	 27	 0.997898	 0.0	 1	 -30.0	 30.0;
	823	 7283	 0.029412	 1.176103	 0.0	 27	 27	 27	 0.991389	 0.0	 1	 -30.0	 30.0;
	823	 7286	 0.029412	 1.176103	 0.0	 27	 27	 27	 0.991389	 0.0	 1	 -30.0	 30.0;
	823	 7287	 0.029412	 1.176103	 0.0	 27	 27	 27	 0.991389	 0.0	 1	 -30.0	 30.0;
	823	 7284	 0.029412	 1.176103	 0.0	 27	 27	 27	 0.991389	 0.0	 1	 -30.0	 30.0;
	823	 3226	 0.029412	 1.176103	 0.0	 27	 27	 27	 0.991389	 0.0	 1	 -30.0	 30.0;
	823	 3242	 0.029412	 1.176103	 0.0	 27	 27	 27	 0.991389	 0.0	 1	 -30.0	 30.0;
	823	 3245	 0.029412	 1.176103	 0.0	 27	 27	 27	 0.991389	 0.0	 1	 -30.0	 30.0;
	6350	 773	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.99459	 0.0	 1	 -30.0	 30.0;
	6350	 1791	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.99459	 0.0	 1	 -30.0	 30.0;
	9018	 775	 0.00774	 0.309501	 0.0	 103	 103	 103	 1.011102	 0.0	 1	 -30.0	 30.0;
	9018	 774	 0.00774	 0.309501	 0.0	 103	 103	 103	 1.005775	 0.0	 1	 -30.0	 30.0;
	6895	 769	 0.004433	 0.17725	 0.0	 179	 179	 179	 1.007293	 0.0	 1	 -30.0	 30.0;
	6895	 768	 0.004433	 0.17725	 0.0	 179	 179	 179	 1.007293	 0.0	 1	 -30.0	 30.0;
	6895	 771	 0.004433	 0.17725	 0.0	 179	 179	 179	 1.001638	 0.0	 1	 -30.0	 30.0;
	6895	 770	 0.004433	 0.17725	 0.0	 179	 179	 179	 1.001638	 0.0	 1	 -30.0	 30.0;
	6895	 4781	 0.004433	 0.17725	 0.0	 179	 179	 179	 1.001638	 0.0	 1	 -30.0	 30.0;
	6895	 776	 0.004433	 0.17725	 0.0	 179	 179	 179	 1.001638	 0.0	 1	 -30.0	 30.0;
	7515	 10064	 0.000212	 0.008494	 0.0	 3718	 3718	 3718	 1.002116	 0.0	 1	 -30.0	 30.0;
	7515	 10065	 0.000212	 0.008494	 0.0	 3718	 3718	 3718	 1.002116	 0.0	 1	 -30.0	 30.0;
	5150	 4083	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 0.999658	 0.0	 1	 -30.0	 30.0;
	5150	 11520	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 0.999658	 0.0	 1	 -30.0	 30.0;
	5150	 11536	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 0.999658	 0.0	 1	 -30.0	 30.0;
	1499	 4084	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 0.999761	 0.0	 1	 -30.0	 30.0;
	1499	 4087	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 0.999761	 0.0	 1	 -30.0	 30.0;
	1499	 11649	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 0.999761	 0.0	 1	 -30.0	 30.0;
	13477	 10060	 0.000212	 0.008494	 0.0	 3718	 3718	 3718	 1.011119	 0.0	 1	 -30.0	 30.0;
	13477	 6368	 0.000212	 0.008494	 0.0	 3718	 3718	 3718	 1.011119	 0.0	 1	 -30.0	 30.0;
	13477	 3451	 0.000212	 0.008494	 0.0	 3718	 3718	 3718	 1.011119	 0.0	 1	 -30.0	 30.0;
	13477	 7776	 0.000212	 0.008494	 0.0	 3718	 3718	 3718	 1.011119	 0.0	 1	 -30.0	 30.0;
	8249	 312	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.016091	 0.0	 1	 -30.0	 30.0;
	8249	 311	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.016091	 0.0	 1	 -30.0	 30.0;
	8249	 310	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.016091	 0.0	 1	 -30.0	 30.0;
	8249	 309	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.016091	 0.0	 1	 -30.0	 30.0;
	6575	 308	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.002747	 0.0	 1	 -30.0	 30.0;
	6575	 307	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.002747	 0.0	 1	 -30.0	 30.0;
	13011	 306	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.015999	 0.0	 1	 -30.0	 30.0;
	13011	 305	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.015999	 0.0	 1	 -30.0	 30.0;
	13011	 4434	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.015999	 0.0	 1	 -30.0	 30.0;
	13011	 13512	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.015999	 0.0	 1	 -30.0	 30.0;
	13011	 4432	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.015999	 0.0	 1	 -30.0	 30.0;
	13011	 4433	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.015999	 0.0	 1	 -30.0	 30.0;
	12101	 4430	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.00849	 0.0	 1	 -30.0	 30.0;
	8287	 4431	 0.004587	 0.183429	 0.0	 173	 173	 173	 0.995767	 0.0	 1	 -30.0	 30.0;
	8287	 4428	 0.004587	 0.183429	 0.0	 173	 173	 173	 0.995767	 0.0	 1	 -30.0	 30.0;
	8287	 4429	 0.004587	 0.183429	 0.0	 173	 173	 173	 0.995767	 0.0	 1	 -30.0	 30.0;
	9324	 4426	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.008256	 0.0	 1	 -30.0	 30.0;
	9324	 4427	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.008256	 0.0	 1	 -30.0	 30.0;
	9324	 1189	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.008256	 0.0	 1	 -30.0	 30.0;
	9324	 5330	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.008256	 0.0	 1	 -30.0	 30.0;
	9324	 11498	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.008256	 0.0	 1	 -30.0	 30.0;
	9324	 11497	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.008256	 0.0	 1	 -30.0	 30.0;
	9324	 11500	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.008256	 0.0	 1	 -30.0	 30.0;
	9324	 11499	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.008256	 0.0	 1	 -30.0	 30.0;
	11400	 5990	 0.000212	 0.008494	 0.0	 4466	 4466	 4466	 1.059341	 0.0	 1	 -30.0	 30.0;
	11400	 5989	 0.000212	 0.008494	 0.0	 4466	 4466	 4466	 1.059341	 0.0	 1	 -30.0	 30.0;
	11888	 5988	 0.000212	 0.008494	 0.0	 4466	 4466	 4466	 1.058922	 0.0	 1	 -30.0	 30.0;
	11888	 5987	 0.000212	 0.008494	 0.0	 4466	 4466	 4466	 1.058922	 0.0	 1	 -30.0	 30.0;
	13198	 145	 0.000212	 0.008494	 0.0	 4466	 4466	 4466	 1.06028	 0.0	 1	 -30.0	 30.0;
	13198	 800	 0.000212	 0.008494	 0.0	 4466	 4466	 4466	 1.06028	 0.0	 1	 -30.0	 30.0;
	1373	 147	 0.000212	 0.008494	 0.0	 4466	 4466	 4466	 1.060147	 0.0	 1	 -30.0	 30.0;
	1373	 146	 0.000212	 0.008494	 0.0	 4466	 4466	 4466	 1.060147	 0.0	 1	 -30.0	 30.0;
	7251	 2711	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.011501	 0.0	 1	 -30.0	 30.0;
	7251	 9477	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.011501	 0.0	 1	 -30.0	 30.0;
	5446	 2705	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.006986	 0.0	 1	 -30.0	 30.0;
	5446	 2703	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.006986	 0.0	 1	 -30.0	 30.0;
	4349	 9474	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.99541	 0.0	 1	 -30.0	 30.0;
	4349	 9473	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.99541	 0.0	 1	 -30.0	 30.0;
	4349	 2369	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.99541	 0.0	 1	 -30.0	 30.0;
	4349	 2370	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.99541	 0.0	 1	 -30.0	 30.0;
	4349	 2371	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.99541	 0.0	 1	 -30.0	 30.0;
	665	 10023	 0.003521	 0.140801	 0.0	 225	 225	 225	 0.997229	 0.0	 1	 -30.0	 30.0;
	665	 3910	 0.003521	 0.140801	 0.0	 225	 225	 225	 0.997229	 0.0	 1	 -30.0	 30.0;
	665	 3911	 0.003521	 0.140801	 0.0	 225	 225	 225	 0.997229	 0.0	 1	 -30.0	 30.0;
	665	 3908	 0.003521	 0.140801	 0.0	 225	 225	 225	 0.997229	 0.0	 1	 -30.0	 30.0;
	665	 3909	 0.003521	 0.140801	 0.0	 225	 225	 225	 0.997229	 0.0	 1	 -30.0	 30.0;
	665	 3906	 0.003521	 0.140801	 0.0	 225	 225	 225	 0.997229	 0.0	 1	 -30.0	 30.0;
	665	 3907	 0.003521	 0.140801	 0.0	 225	 225	 225	 0.997229	 0.0	 1	 -30.0	 30.0;
	665	 10538	 0.003521	 0.140801	 0.0	 225	 225	 225	 0.997229	 0.0	 1	 -30.0	 30.0;
	665	 10537	 0.003521	 0.140801	 0.0	 225	 225	 225	 0.997229	 0.0	 1	 -30.0	 30.0;
	1251	 12884	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.008992	 0.0	 1	 -30.0	 30.0;
	1251	 9060	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.008992	 0.0	 1	 -30.0	 30.0;
	1251	 12882	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.008992	 0.0	 1	 -30.0	 30.0;
	1251	 12883	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.008992	 0.0	 1	 -30.0	 30.0;
	1251	 12880	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.008992	 0.0	 1	 -30.0	 30.0;
	1251	 9051	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.008992	 0.0	 1	 -30.0	 30.0;
	12241	 12878	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.023745	 0.0	 1	 -30.0	 30.0;
	12241	 9045	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.023745	 0.0	 1	 -30.0	 30.0;
	12241	 6277	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.023745	 0.0	 1	 -30.0	 30.0;
	12241	 6276	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.023745	 0.0	 1	 -30.0	 30.0;
	12241	 6279	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.023745	 0.0	 1	 -30.0	 30.0;
	12241	 12509	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.023745	 0.0	 1	 -30.0	 30.0;
	3506	 6201	 0.000212	 0.008494	 0.0	 3718	 3718	 3718	 1.032835	 0.0	 1	 -30.0	 30.0;
	3506	 6202	 0.000212	 0.008494	 0.0	 3718	 3718	 3718	 1.032835	 0.0	 1	 -30.0	 30.0;
	3768	 6203	 0.000212	 0.008494	 0.0	 3718	 3718	 3718	 1.032071	 0.0	 1	 -30.0	 30.0;
	3768	 6204	 0.000212	 0.008494	 0.0	 3718	 3718	 3718	 1.032071	 0.0	 1	 -30.0	 30.0;
	7975	 6208	 0.000212	 0.008494	 0.0	 3718	 3718	 3718	 1.008136	 0.0	 1	 -30.0	 30.0;
	7975	 1656	 0.000212	 0.008494	 0.0	 3718	 3718	 3718	 1.008136	 0.0	 1	 -30.0	 30.0;
	1892	 12818	 0.000212	 0.008494	 0.0	 3718	 3718	 3718	 1.008159	 0.0	 1	 -30.0	 30.0;
	1892	 12817	 0.000212	 0.008494	 0.0	 3718	 3718	 3718	 1.008159	 0.0	 1	 -30.0	 30.0;
	13605	 10670	 0.005252	 0.210018	 0.0	 151	 151	 151	 0.997047	 0.0	 1	 -30.0	 30.0;
	13605	 10456	 0.005252	 0.210018	 0.0	 151	 151	 151	 0.997047	 0.0	 1	 -30.0	 30.0;
	13605	 10690	 0.005252	 0.210018	 0.0	 151	 151	 151	 0.991031	 0.0	 1	 -30.0	 30.0;
	13605	 8513	 0.005252	 0.210018	 0.0	 151	 151	 151	 0.991031	 0.0	 1	 -30.0	 30.0;
	13605	 10518	 0.005252	 0.210018	 0.0	 151	 151	 151	 0.991031	 0.0	 1	 -30.0	 30.0;
	13605	 10681	 0.005252	 0.210018	 0.0	 151	 151	 151	 0.991031	 0.0	 1	 -30.0	 30.0;
	13605	 10700	 0.005252	 0.210018	 0.0	 151	 151	 151	 0.991031	 0.0	 1	 -30.0	 30.0;
	13605	 8516	 0.005252	 0.210018	 0.0	 151	 151	 151	 0.991031	 0.0	 1	 -30.0	 30.0;
	3831	 1477	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.005883	 0.0	 1	 -30.0	 30.0;
	3831	 1478	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.005883	 0.0	 1	 -30.0	 30.0;
	3831	 1479	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.005883	 0.0	 1	 -30.0	 30.0;
	13250	 9214	 0.005285	 0.21135	 0.0	 150	 150	 150	 1.007908	 0.0	 1	 -30.0	 30.0;
	13250	 1481	 0.005285	 0.21135	 0.0	 150	 150	 150	 1.002153	 0.0	 1	 -30.0	 30.0;
	13250	 1482	 0.005285	 0.21135	 0.0	 150	 150	 150	 1.002153	 0.0	 1	 -30.0	 30.0;
	13250	 1483	 0.005285	 0.21135	 0.0	 150	 150	 150	 1.002153	 0.0	 1	 -30.0	 30.0;
	1420	 1484	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.007233	 0.0	 1	 -30.0	 30.0;
	1420	 1485	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.007233	 0.0	 1	 -30.0	 30.0;
	1420	 1486	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.007233	 0.0	 1	 -30.0	 30.0;
	4636	 1473	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.008308	 0.0	 1	 -30.0	 30.0;
	4636	 1474	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.008308	 0.0	 1	 -30.0	 30.0;
	4636	 1475	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.008308	 0.0	 1	 -30.0	 30.0;
	4636	 1476	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.008308	 0.0	 1	 -30.0	 30.0;
	4636	 1470	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.008308	 0.0	 1	 -30.0	 30.0;
	4636	 1471	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.008308	 0.0	 1	 -30.0	 30.0;
	5253	 11496	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.008176	 0.0	 1	 -30.0	 30.0;
	5253	 2236	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.008176	 0.0	 1	 -30.0	 30.0;
	5253	 11507	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.008176	 0.0	 1	 -30.0	 30.0;
	5253	 11506	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.008176	 0.0	 1	 -30.0	 30.0;
	5253	 4424	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.008176	 0.0	 1	 -30.0	 30.0;
	5253	 4425	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.008176	 0.0	 1	 -30.0	 30.0;
	5253	 13482	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.008176	 0.0	 1	 -30.0	 30.0;
	5253	 13486	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.008176	 0.0	 1	 -30.0	 30.0;
	5253	 13466	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.008176	 0.0	 1	 -30.0	 30.0;
	5253	 4422	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.008176	 0.0	 1	 -30.0	 30.0;
	1126	 1928	 0.012376	 0.494895	 0.0	 64	 64	 64	 1.007643	 0.0	 1	 -30.0	 30.0;
	1126	 3346	 0.012376	 0.494895	 0.0	 64	 64	 64	 1.002354	 0.0	 1	 -30.0	 30.0;
	5375	 1935	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.01511	 0.0	 1	 -30.0	 30.0;
	5375	 1936	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.01511	 0.0	 1	 -30.0	 30.0;
	5375	 7564	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.01511	 0.0	 1	 -30.0	 30.0;
	2212	 7563	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.010744	 0.0	 1	 -30.0	 30.0;
	2212	 7562	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.010744	 0.0	 1	 -30.0	 30.0;
	7192	 11752	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.005182	 0.0	 1	 -30.0	 30.0;
	7192	 7560	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.005182	 0.0	 1	 -30.0	 30.0;
	7192	 7559	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.005182	 0.0	 1	 -30.0	 30.0;
	7192	 7558	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.005182	 0.0	 1	 -30.0	 30.0;
	7192	 7557	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.005182	 0.0	 1	 -30.0	 30.0;
	7192	 11892	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.005182	 0.0	 1	 -30.0	 30.0;
	7792	 1997	 0.000212	 0.008494	 0.0	 3718	 3718	 3718	 1.014224	 0.0	 1	 -30.0	 30.0;
	10491	 8570	 0.000212	 0.008494	 0.0	 3718	 3718	 3718	 1.01423	 0.0	 1	 -30.0	 30.0;
	5404	 8571	 0.000212	 0.008494	 0.0	 3718	 3718	 3718	 1.01453	 0.0	 1	 -30.0	 30.0;
	7983	 8569	 0.000212	 0.008494	 0.0	 3718	 3718	 3718	 1.014502	 0.0	 1	 -30.0	 30.0;
	13572	 581	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.017389	 0.0	 1	 -30.0	 30.0;
	13572	 575	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.017389	 0.0	 1	 -30.0	 30.0;
	13572	 576	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.017389	 0.0	 1	 -30.0	 30.0;
	13572	 577	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.017389	 0.0	 1	 -30.0	 30.0;
	1768	 7645	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.00697	 0.0	 1	 -30.0	 30.0;
	1768	 7649	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.00697	 0.0	 1	 -30.0	 30.0;
	1768	 7648	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.00697	 0.0	 1	 -30.0	 30.0;
	1574	 9256	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.006962	 0.0	 1	 -30.0	 30.0;
	1574	 9257	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.006962	 0.0	 1	 -30.0	 30.0;
	1574	 9258	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.006962	 0.0	 1	 -30.0	 30.0;
	12142	 7426	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.00696	 0.0	 1	 -30.0	 30.0;
	12142	 9260	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.00696	 0.0	 1	 -30.0	 30.0;
	12142	 9261	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.00696	 0.0	 1	 -30.0	 30.0;
	12250	 2090	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.008008	 0.0	 1	 -30.0	 30.0;
	12250	 2091	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.008008	 0.0	 1	 -30.0	 30.0;
	12250	 2093	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.008008	 0.0	 1	 -30.0	 30.0;
	1100	 5388	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.999237	 0.0	 1	 -30.0	 30.0;
	1100	 11913	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.999237	 0.0	 1	 -30.0	 30.0;
	1100	 11914	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.999237	 0.0	 1	 -30.0	 30.0;
	7576	 9679	 0.000212	 0.008494	 0.0	 3718	 3718	 3718	 1.021823	 0.0	 1	 -30.0	 30.0;
	4529	 11916	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.97527	 0.0	 1	 -30.0	 30.0;
	4529	 13163	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.97527	 0.0	 1	 -30.0	 30.0;
	4529	 11099	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.97527	 0.0	 1	 -30.0	 30.0;
	4529	 11919	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.97527	 0.0	 1	 -30.0	 30.0;
	9274	 10635	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.02372	 0.0	 1	 -30.0	 30.0;
	9274	 10803	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.02372	 0.0	 1	 -30.0	 30.0;
	9274	 10804	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.02372	 0.0	 1	 -30.0	 30.0;
	9274	 3698	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.02372	 0.0	 1	 -30.0	 30.0;
	9274	 3697	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.02372	 0.0	 1	 -30.0	 30.0;
	9274	 3696	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.02372	 0.0	 1	 -30.0	 30.0;
	9274	 3695	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.02372	 0.0	 1	 -30.0	 30.0;
	9274	 3701	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.02372	 0.0	 1	 -30.0	 30.0;
	9274	 3700	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.02372	 0.0	 1	 -30.0	 30.0;
	9274	 3699	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.02372	 0.0	 1	 -30.0	 30.0;
	12839	 1853	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.996937	 0.0	 1	 -30.0	 30.0;
	12839	 5849	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.996937	 0.0	 1	 -30.0	 30.0;
	8404	 1631	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.017715	 0.0	 1	 -30.0	 30.0;
	8404	 8648	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.017715	 0.0	 1	 -30.0	 30.0;
	8404	 8647	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.017715	 0.0	 1	 -30.0	 30.0;
	8404	 4729	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.015542	 0.0	 1	 -30.0	 30.0;
	8404	 4728	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.015542	 0.0	 1	 -30.0	 30.0;
	8404	 4727	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.015542	 0.0	 1	 -30.0	 30.0;
	8404	 4726	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.015542	 0.0	 1	 -30.0	 30.0;
	8404	 4725	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.015542	 0.0	 1	 -30.0	 30.0;
	8404	 4724	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.015542	 0.0	 1	 -30.0	 30.0;
	8404	 4723	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.015542	 0.0	 1	 -30.0	 30.0;
	8404	 4722	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.015542	 0.0	 1	 -30.0	 30.0;
	8404	 10811	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.015542	 0.0	 1	 -30.0	 30.0;
	13274	 6329	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.012806	 0.0	 1	 -30.0	 30.0;
	13274	 6328	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.012806	 0.0	 1	 -30.0	 30.0;
	13274	 6327	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.012806	 0.0	 1	 -30.0	 30.0;
	13274	 6326	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.012806	 0.0	 1	 -30.0	 30.0;
	13274	 6325	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.012806	 0.0	 1	 -30.0	 30.0;
	6011	 5229	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.009982	 0.0	 1	 -30.0	 30.0;
	6011	 5228	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.009982	 0.0	 1	 -30.0	 30.0;
	6011	 5226	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.009982	 0.0	 1	 -30.0	 30.0;
	6011	 5225	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.009982	 0.0	 1	 -30.0	 30.0;
	6011	 11759	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.009982	 0.0	 1	 -30.0	 30.0;
	6011	 11760	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.009982	 0.0	 1	 -30.0	 30.0;
	6011	 2646	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.009982	 0.0	 1	 -30.0	 30.0;
	6011	 11758	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.009982	 0.0	 1	 -30.0	 30.0;
	6011	 11762	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.009982	 0.0	 1	 -30.0	 30.0;
	6011	 11763	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.009982	 0.0	 1	 -30.0	 30.0;
	10526	 8713	 0.000212	 0.008494	 0.0	 3718	 3718	 3718	 1.052995	 0.0	 1	 -30.0	 30.0;
	10526	 8714	 0.000212	 0.008494	 0.0	 3718	 3718	 3718	 1.052995	 0.0	 1	 -30.0	 30.0;
	7834	 8711	 0.000212	 0.008494	 0.0	 3718	 3718	 3718	 1.053262	 0.0	 1	 -30.0	 30.0;
	7834	 8712	 0.000212	 0.008494	 0.0	 3718	 3718	 3718	 1.053262	 0.0	 1	 -30.0	 30.0;
	1748	 1689	 0.000212	 0.008494	 0.0	 3718	 3718	 3718	 1.055552	 0.0	 1	 -30.0	 30.0;
	1748	 10530	 0.000212	 0.008494	 0.0	 3718	 3718	 3718	 1.055552	 0.0	 1	 -30.0	 30.0;
	9437	 6798	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.996988	 0.0	 1	 -30.0	 30.0;
	9437	 6797	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.996988	 0.0	 1	 -30.0	 30.0;
	5960	 6793	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.007213	 0.0	 1	 -30.0	 30.0;
	5960	 6792	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.007213	 0.0	 1	 -30.0	 30.0;
	7462	 6795	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.996634	 0.0	 1	 -30.0	 30.0;
	7462	 6794	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.996634	 0.0	 1	 -30.0	 30.0;
	4776	 6802	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.002795	 0.0	 1	 -30.0	 30.0;
	4776	 6801	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.002795	 0.0	 1	 -30.0	 30.0;
	1902	 13419	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.009263	 0.0	 1	 -30.0	 30.0;
	1902	 6731	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.009263	 0.0	 1	 -30.0	 30.0;
	1902	 12219	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.009263	 0.0	 1	 -30.0	 30.0;
	3998	 12222	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.009695	 0.0	 1	 -30.0	 30.0;
	3998	 13423	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.009695	 0.0	 1	 -30.0	 30.0;
	3998	 13424	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.009695	 0.0	 1	 -30.0	 30.0;
	3998	 13421	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.009695	 0.0	 1	 -30.0	 30.0;
	3998	 10050	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.009695	 0.0	 1	 -30.0	 30.0;
	5810	 13426	 0.003268	 0.130678	 0.0	 242	 242	 242	 0.997548	 0.0	 1	 -30.0	 30.0;
	5810	 13427	 0.003268	 0.130678	 0.0	 242	 242	 242	 0.992409	 0.0	 1	 -30.0	 30.0;
	5810	 3305	 0.003268	 0.130678	 0.0	 242	 242	 242	 0.992409	 0.0	 1	 -30.0	 30.0;
	5810	 3304	 0.003268	 0.130678	 0.0	 242	 242	 242	 0.992409	 0.0	 1	 -30.0	 30.0;
	5810	 3303	 0.003268	 0.130678	 0.0	 242	 242	 242	 0.992409	 0.0	 1	 -30.0	 30.0;
	5810	 3302	 0.003268	 0.130678	 0.0	 242	 242	 242	 0.992409	 0.0	 1	 -30.0	 30.0;
	8243	 3309	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.978538	 0.0	 1	 -30.0	 30.0;
	8243	 3308	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.978538	 0.0	 1	 -30.0	 30.0;
	8243	 6969	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.978538	 0.0	 1	 -30.0	 30.0;
	8243	 6967	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.978538	 0.0	 1	 -30.0	 30.0;
	8243	 5463	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.978538	 0.0	 1	 -30.0	 30.0;
	8243	 6944	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.978538	 0.0	 1	 -30.0	 30.0;
	3889	 9926	 0.005297	 0.211798	 0.0	 150	 150	 150	 1.010342	 0.0	 1	 -30.0	 30.0;
	3889	 5528	 0.005297	 0.211798	 0.0	 150	 150	 150	 1.010342	 0.0	 1	 -30.0	 30.0;
	3889	 9928	 0.005297	 0.211798	 0.0	 150	 150	 150	 1.004656	 0.0	 1	 -30.0	 30.0;
	3889	 9929	 0.005297	 0.211798	 0.0	 150	 150	 150	 1.004656	 0.0	 1	 -30.0	 30.0;
	3889	 9930	 0.005297	 0.211798	 0.0	 150	 150	 150	 1.004656	 0.0	 1	 -30.0	 30.0;
	8087	 11922	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.014926	 0.0	 1	 -30.0	 30.0;
	8087	 9932	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.014926	 0.0	 1	 -30.0	 30.0;
	10282	 9933	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.014966	 0.0	 1	 -30.0	 30.0;
	10282	 9922	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.014966	 0.0	 1	 -30.0	 30.0;
	4682	 9923	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.010242	 0.0	 1	 -30.0	 30.0;
	4682	 2153	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.010242	 0.0	 1	 -30.0	 30.0;
	1944	 2154	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.017484	 0.0	 1	 -30.0	 30.0;
	1944	 13585	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.017484	 0.0	 1	 -30.0	 30.0;
	1944	 13589	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.017484	 0.0	 1	 -30.0	 30.0;
	1944	 13604	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.017484	 0.0	 1	 -30.0	 30.0;
	9262	 2158	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.014014	 0.0	 1	 -30.0	 30.0;
	9262	 2155	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.014014	 0.0	 1	 -30.0	 30.0;
	2016	 2156	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.996597	 0.0	 1	 -30.0	 30.0;
	2424	 62	 0.000212	 0.008494	 0.0	 3718	 3718	 3718	 1.012282	 0.0	 1	 -30.0	 30.0;
	2424	 63	 0.000212	 0.008494	 0.0	 3718	 3718	 3718	 1.012282	 0.0	 1	 -30.0	 30.0;
	13136	 1726	 0.000212	 0.008494	 0.0	 3718	 3718	 3718	 1.012028	 0.0	 1	 -30.0	 30.0;
	13136	 7063	 0.000212	 0.008494	 0.0	 3718	 3718	 3718	 1.012028	 0.0	 1	 -30.0	 30.0;
	2797	 9225	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.015876	 0.0	 1	 -30.0	 30.0;
	1152	 1298	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.996815	 0.0	 1	 -30.0	 30.0;
	1152	 1287	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.996815	 0.0	 1	 -30.0	 30.0;
	1152	 9218	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.996815	 0.0	 1	 -30.0	 30.0;
	1152	 11344	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.996815	 0.0	 1	 -30.0	 30.0;
	6052	 1290	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.001459	 0.0	 1	 -30.0	 30.0;
	6052	 9216	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.001459	 0.0	 1	 -30.0	 30.0;
	2507	 9215	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.997291	 0.0	 1	 -30.0	 30.0;
	1215	 510	 0.000212	 0.008494	 0.0	 3718	 3718	 3718	 1.013208	 0.0	 1	 -30.0	 30.0;
	4360	 3068	 0.000212	 0.008494	 0.0	 3718	 3718	 3718	 1.012326	 0.0	 1	 -30.0	 30.0;
	7051	 508	 0.000212	 0.008494	 0.0	 3718	 3718	 3718	 1.013245	 0.0	 1	 -30.0	 30.0;
	2892	 509	 0.000212	 0.008494	 0.0	 3718	 3718	 3718	 1.012399	 0.0	 1	 -30.0	 30.0;
	5683	 514	 0.000212	 0.008494	 0.0	 3718	 3718	 3718	 1.013272	 0.0	 1	 -30.0	 30.0;
	5500	 3757	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.007977	 0.0	 1	 -30.0	 30.0;
	5500	 3754	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.007977	 0.0	 1	 -30.0	 30.0;
	5500	 11950	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.007977	 0.0	 1	 -30.0	 30.0;
	5981	 1662	 0.007886	 0.315359	 0.0	 101	 101	 101	 0.999304	 0.0	 1	 -30.0	 30.0;
	5981	 1663	 0.007886	 0.315359	 0.0	 101	 101	 101	 0.993609	 0.0	 1	 -30.0	 30.0;
	6416	 13520	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.009959	 0.0	 1	 -30.0	 30.0;
	6416	 4187	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.009959	 0.0	 1	 -30.0	 30.0;
	6416	 13489	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.009959	 0.0	 1	 -30.0	 30.0;
	6416	 4185	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.009959	 0.0	 1	 -30.0	 30.0;
	6416	 4182	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.009959	 0.0	 1	 -30.0	 30.0;
	6416	 4183	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.009959	 0.0	 1	 -30.0	 30.0;
	6416	 1074	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.009959	 0.0	 1	 -30.0	 30.0;
	12849	 8675	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.007062	 0.0	 1	 -30.0	 30.0;
	12849	 8680	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.007062	 0.0	 1	 -30.0	 30.0;
	12849	 8679	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.007062	 0.0	 1	 -30.0	 30.0;
	7414	 2783	 0.003521	 0.140801	 0.0	 225	 225	 225	 0.995036	 0.0	 1	 -30.0	 30.0;
	7414	 2799	 0.003521	 0.140801	 0.0	 225	 225	 225	 0.995036	 0.0	 1	 -30.0	 30.0;
	7414	 2810	 0.003521	 0.140801	 0.0	 225	 225	 225	 0.995036	 0.0	 1	 -30.0	 30.0;
	7414	 12673	 0.003521	 0.140801	 0.0	 225	 225	 225	 0.995036	 0.0	 1	 -30.0	 30.0;
	7414	 2012	 0.003521	 0.140801	 0.0	 225	 225	 225	 0.995036	 0.0	 1	 -30.0	 30.0;
	7414	 2013	 0.003521	 0.140801	 0.0	 225	 225	 225	 0.995036	 0.0	 1	 -30.0	 30.0;
	7414	 2014	 0.003521	 0.140801	 0.0	 225	 225	 225	 0.995036	 0.0	 1	 -30.0	 30.0;
	7414	 12659	 0.003521	 0.140801	 0.0	 225	 225	 225	 0.995036	 0.0	 1	 -30.0	 30.0;
	7414	 2020	 0.003521	 0.140801	 0.0	 225	 225	 225	 0.995036	 0.0	 1	 -30.0	 30.0;
	7414	 12690	 0.003521	 0.140801	 0.0	 225	 225	 225	 0.995036	 0.0	 1	 -30.0	 30.0;
	11183	 8219	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.004973	 0.0	 1	 -30.0	 30.0;
	11183	 8218	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.004973	 0.0	 1	 -30.0	 30.0;
	11183	 8221	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.004973	 0.0	 1	 -30.0	 30.0;
	11183	 8220	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.004973	 0.0	 1	 -30.0	 30.0;
	11183	 8223	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.004973	 0.0	 1	 -30.0	 30.0;
	11183	 8222	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.004973	 0.0	 1	 -30.0	 30.0;
	11183	 8224	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.004973	 0.0	 1	 -30.0	 30.0;
	11183	 4691	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.00545	 0.0	 1	 -30.0	 30.0;
	11183	 4698	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.00545	 0.0	 1	 -30.0	 30.0;
	11183	 4699	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.00545	 0.0	 1	 -30.0	 30.0;
	11183	 5523	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.00545	 0.0	 1	 -30.0	 30.0;
	11183	 12232	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.00545	 0.0	 1	 -30.0	 30.0;
	11183	 5530	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.00545	 0.0	 1	 -30.0	 30.0;
	6064	 749	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.999883	 0.0	 1	 -30.0	 30.0;
	6064	 750	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.999883	 0.0	 1	 -30.0	 30.0;
	6064	 751	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.999883	 0.0	 1	 -30.0	 30.0;
	13405	 10132	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.019382	 0.0	 1	 -30.0	 30.0;
	13405	 6749	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.019382	 0.0	 1	 -30.0	 30.0;
	13405	 10134	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.019382	 0.0	 1	 -30.0	 30.0;
	13405	 10135	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.019382	 0.0	 1	 -30.0	 30.0;
	13405	 3523	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.019382	 0.0	 1	 -30.0	 30.0;
	13405	 8130	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.019382	 0.0	 1	 -30.0	 30.0;
	13405	 3521	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.019382	 0.0	 1	 -30.0	 30.0;
	13405	 3520	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.019382	 0.0	 1	 -30.0	 30.0;
	13405	 3526	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.019382	 0.0	 1	 -30.0	 30.0;
	13405	 3525	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.019382	 0.0	 1	 -30.0	 30.0;
	13405	 3524	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.019382	 0.0	 1	 -30.0	 30.0;
	10182	 7732	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.013776	 0.0	 1	 -30.0	 30.0;
	10182	 11401	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.013776	 0.0	 1	 -30.0	 30.0;
	5234	 5973	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.018757	 0.0	 1	 -30.0	 30.0;
	5234	 4041	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.018757	 0.0	 1	 -30.0	 30.0;
	5312	 4042	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.008125	 0.0	 1	 -30.0	 30.0;
	5312	 4039	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.008125	 0.0	 1	 -30.0	 30.0;
	5312	 4040	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.008125	 0.0	 1	 -30.0	 30.0;
	8652	 4045	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.008578	 0.0	 1	 -30.0	 30.0;
	12476	 13190	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 0.990397	 0.0	 1	 -30.0	 30.0;
	12476	 13189	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 0.990397	 0.0	 1	 -30.0	 30.0;
	12476	 13188	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 0.990397	 0.0	 1	 -30.0	 30.0;
	12299	 4048	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.002469	 0.0	 1	 -30.0	 30.0;
	12299	 11330	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.002469	 0.0	 1	 -30.0	 30.0;
	12511	 12825	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.998862	 0.0	 1	 -30.0	 30.0;
	12511	 11122	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.998862	 0.0	 1	 -30.0	 30.0;
	10737	 11125	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.010853	 0.0	 1	 -30.0	 30.0;
	10737	 11124	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.010853	 0.0	 1	 -30.0	 30.0;
	10737	 11119	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.010853	 0.0	 1	 -30.0	 30.0;
	10737	 11118	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.010853	 0.0	 1	 -30.0	 30.0;
	10944	 11121	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.989334	 0.0	 1	 -30.0	 30.0;
	10944	 11120	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.989334	 0.0	 1	 -30.0	 30.0;
	10944	 11130	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.989334	 0.0	 1	 -30.0	 30.0;
	2581	 11129	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.009184	 0.0	 1	 -30.0	 30.0;
	2581	 7946	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.009184	 0.0	 1	 -30.0	 30.0;
	2581	 12697	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.009184	 0.0	 1	 -30.0	 30.0;
	2581	 3878	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.009184	 0.0	 1	 -30.0	 30.0;
	2581	 12699	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.009184	 0.0	 1	 -30.0	 30.0;
	2581	 12702	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.009184	 0.0	 1	 -30.0	 30.0;
	6778	 12701	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.010864	 0.0	 1	 -30.0	 30.0;
	6778	 12704	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.010864	 0.0	 1	 -30.0	 30.0;
	2454	 3916	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.019687	 0.0	 1	 -30.0	 30.0;
	5112	 12706	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.014538	 0.0	 1	 -30.0	 30.0;
	5112	 12705	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.014538	 0.0	 1	 -30.0	 30.0;
	5112	 5622	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.014538	 0.0	 1	 -30.0	 30.0;
	12744	 5476	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.005347	 0.0	 1	 -30.0	 30.0;
	12744	 7386	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.005347	 0.0	 1	 -30.0	 30.0;
	12744	 12586	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.005347	 0.0	 1	 -30.0	 30.0;
	12744	 12592	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.005347	 0.0	 1	 -30.0	 30.0;
	12744	 12591	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.005347	 0.0	 1	 -30.0	 30.0;
	12744	 12590	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.005347	 0.0	 1	 -30.0	 30.0;
	12744	 12589	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.005347	 0.0	 1	 -30.0	 30.0;
	8065	 5619	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.011409	 0.0	 1	 -30.0	 30.0;
	896	 6593	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.015669	 0.0	 1	 -30.0	 30.0;
	227	 6008	 0.002119	 0.084719	 0.0	 373	 373	 373	 0.991144	 0.0	 1	 -30.0	 30.0;
	227	 8838	 0.002119	 0.084719	 0.0	 373	 373	 373	 0.991144	 0.0	 1	 -30.0	 30.0;
	227	 6006	 0.002119	 0.084719	 0.0	 373	 373	 373	 0.991144	 0.0	 1	 -30.0	 30.0;
	227	 6007	 0.002119	 0.084719	 0.0	 373	 373	 373	 0.991144	 0.0	 1	 -30.0	 30.0;
	227	 8824	 0.002119	 0.084719	 0.0	 373	 373	 373	 0.991144	 0.0	 1	 -30.0	 30.0;
	227	 6005	 0.002119	 0.084719	 0.0	 373	 373	 373	 0.991144	 0.0	 1	 -30.0	 30.0;
	227	 6002	 0.002119	 0.084719	 0.0	 373	 373	 373	 0.991144	 0.0	 1	 -30.0	 30.0;
	227	 6003	 0.002119	 0.084719	 0.0	 373	 373	 373	 0.991144	 0.0	 1	 -30.0	 30.0;
	6400	 5134	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.004944	 0.0	 1	 -30.0	 30.0;
	6400	 12175	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.004944	 0.0	 1	 -30.0	 30.0;
	5691	 5126	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.008895	 0.0	 1	 -30.0	 30.0;
	5691	 5127	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.008895	 0.0	 1	 -30.0	 30.0;
	934	 5128	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.991535	 0.0	 1	 -30.0	 30.0;
	934	 5129	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.991535	 0.0	 1	 -30.0	 30.0;
	934	 5130	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.991535	 0.0	 1	 -30.0	 30.0;
	934	 5131	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.991535	 0.0	 1	 -30.0	 30.0;
	934	 13584	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.991535	 0.0	 1	 -30.0	 30.0;
	934	 5133	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.991535	 0.0	 1	 -30.0	 30.0;
	934	 5122	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.991535	 0.0	 1	 -30.0	 30.0;
	158	 5123	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.011892	 0.0	 1	 -30.0	 30.0;
	3455	 4405	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.012367	 0.0	 1	 -30.0	 30.0;
	3455	 77	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.012367	 0.0	 1	 -30.0	 30.0;
	12568	 454	 0.02451	 0.980086	 0.0	 33	 33	 33	 0.999473	 0.0	 1	 -30.0	 30.0;
	897	 2167	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.013998	 0.0	 1	 -30.0	 30.0;
	897	 9377	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.013998	 0.0	 1	 -30.0	 30.0;
	897	 9376	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.013998	 0.0	 1	 -30.0	 30.0;
	897	 9379	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.013998	 0.0	 1	 -30.0	 30.0;
	897	 9378	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.013998	 0.0	 1	 -30.0	 30.0;
	897	 9384	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.013998	 0.0	 1	 -30.0	 30.0;
	897	 9383	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.013998	 0.0	 1	 -30.0	 30.0;
	897	 2284	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.013998	 0.0	 1	 -30.0	 30.0;
	897	 2285	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.013998	 0.0	 1	 -30.0	 30.0;
	897	 2282	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.013998	 0.0	 1	 -30.0	 30.0;
	897	 2283	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.013998	 0.0	 1	 -30.0	 30.0;
	897	 811	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.013998	 0.0	 1	 -30.0	 30.0;
	12397	 12664	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.00865	 0.0	 1	 -30.0	 30.0;
	12397	 11484	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.00865	 0.0	 1	 -30.0	 30.0;
	1563	 6630	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.014801	 0.0	 1	 -30.0	 30.0;
	1563	 6623	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.014801	 0.0	 1	 -30.0	 30.0;
	1563	 6624	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.014801	 0.0	 1	 -30.0	 30.0;
	10058	 13064	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.010547	 0.0	 1	 -30.0	 30.0;
	10058	 13060	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.010547	 0.0	 1	 -30.0	 30.0;
	10058	 13059	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.010547	 0.0	 1	 -30.0	 30.0;
	10058	 13055	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.010547	 0.0	 1	 -30.0	 30.0;
	10058	 8906	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.010547	 0.0	 1	 -30.0	 30.0;
	10058	 13046	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.010547	 0.0	 1	 -30.0	 30.0;
	10058	 13043	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.010547	 0.0	 1	 -30.0	 30.0;
	10058	 8903	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.010547	 0.0	 1	 -30.0	 30.0;
	10058	 8902	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.010547	 0.0	 1	 -30.0	 30.0;
	10058	 8901	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.010547	 0.0	 1	 -30.0	 30.0;
	8572	 6090	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.009889	 0.0	 1	 -30.0	 30.0;
	8572	 6091	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.009889	 0.0	 1	 -30.0	 30.0;
	4504	 6092	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.00878	 0.0	 1	 -30.0	 30.0;
	7638	 6093	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.016594	 0.0	 1	 -30.0	 30.0;
	7638	 10447	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.016594	 0.0	 1	 -30.0	 30.0;
	7638	 6087	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.016594	 0.0	 1	 -30.0	 30.0;
	7638	 10470	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.016594	 0.0	 1	 -30.0	 30.0;
	4002	 6089	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.007312	 0.0	 1	 -30.0	 30.0;
	4002	 6097	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.007312	 0.0	 1	 -30.0	 30.0;
	4002	 6098	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.007312	 0.0	 1	 -30.0	 30.0;
	4002	 975	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.007312	 0.0	 1	 -30.0	 30.0;
	13455	 7470	 0.000212	 0.008494	 0.0	 3718	 3718	 3718	 1.003058	 0.0	 1	 -30.0	 30.0;
	3083	 977	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.012007	 0.0	 1	 -30.0	 30.0;
	3083	 976	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.012007	 0.0	 1	 -30.0	 30.0;
	3083	 978	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.012007	 0.0	 1	 -30.0	 30.0;
	10309	 3528	 0.002119	 0.084719	 0.0	 373	 373	 373	 0.998279	 0.0	 1	 -30.0	 30.0;
	10309	 3529	 0.002119	 0.084719	 0.0	 373	 373	 373	 0.998279	 0.0	 1	 -30.0	 30.0;
	10309	 3530	 0.002119	 0.084719	 0.0	 373	 373	 373	 0.998279	 0.0	 1	 -30.0	 30.0;
	10309	 8123	 0.002119	 0.084719	 0.0	 373	 373	 373	 0.998279	 0.0	 1	 -30.0	 30.0;
	10309	 8126	 0.002119	 0.084719	 0.0	 373	 373	 373	 0.998279	 0.0	 1	 -30.0	 30.0;
	10309	 10619	 0.002119	 0.084719	 0.0	 373	 373	 373	 0.998279	 0.0	 1	 -30.0	 30.0;
	10008	 7508	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.984973	 0.0	 1	 -30.0	 30.0;
	1268	 4707	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.022564	 0.0	 1	 -30.0	 30.0;
	1268	 10339	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.022564	 0.0	 1	 -30.0	 30.0;
	1268	 516	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.022564	 0.0	 1	 -30.0	 30.0;
	1268	 4702	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.022564	 0.0	 1	 -30.0	 30.0;
	1268	 4690	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.022564	 0.0	 1	 -30.0	 30.0;
	1268	 4694	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.022564	 0.0	 1	 -30.0	 30.0;
	1268	 7512	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.022564	 0.0	 1	 -30.0	 30.0;
	4165	 7513	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.013437	 0.0	 1	 -30.0	 30.0;
	4077	 9475	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.019745	 0.0	 1	 -30.0	 30.0;
	4077	 9476	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.019745	 0.0	 1	 -30.0	 30.0;
	4077	 2708	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.019745	 0.0	 1	 -30.0	 30.0;
	12559	 9478	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.007384	 0.0	 1	 -30.0	 30.0;
	12559	 9479	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.007384	 0.0	 1	 -30.0	 30.0;
	12559	 9480	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.007384	 0.0	 1	 -30.0	 30.0;
	12559	 9481	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.007384	 0.0	 1	 -30.0	 30.0;
	12559	 9482	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.007384	 0.0	 1	 -30.0	 30.0;
	12492	 9471	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.008819	 0.0	 1	 -30.0	 30.0;
	12492	 9472	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.008819	 0.0	 1	 -30.0	 30.0;
	12492	 2841	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.008819	 0.0	 1	 -30.0	 30.0;
	12492	 2840	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.008819	 0.0	 1	 -30.0	 30.0;
	12492	 12738	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.008819	 0.0	 1	 -30.0	 30.0;
	7948	 2838	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.005944	 0.0	 1	 -30.0	 30.0;
	7948	 2845	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.005944	 0.0	 1	 -30.0	 30.0;
	1162	 2844	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.007417	 0.0	 1	 -30.0	 30.0;
	1162	 4200	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.007417	 0.0	 1	 -30.0	 30.0;
	9183	 2842	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.995547	 0.0	 1	 -30.0	 30.0;
	9183	 4166	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.995547	 0.0	 1	 -30.0	 30.0;
	9183	 2836	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.995547	 0.0	 1	 -30.0	 30.0;
	501	 4171	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.007942	 0.0	 1	 -30.0	 30.0;
	501	 207	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.007942	 0.0	 1	 -30.0	 30.0;
	501	 9963	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.007942	 0.0	 1	 -30.0	 30.0;
	3541	 9964	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.007773	 0.0	 1	 -30.0	 30.0;
	3541	 9961	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.007773	 0.0	 1	 -30.0	 30.0;
	12472	 5838	 0.000212	 0.008494	 0.0	 3718	 3718	 3718	 1.00669	 0.0	 1	 -30.0	 30.0;
	13045	 9959	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.012324	 0.0	 1	 -30.0	 30.0;
	13045	 13491	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.012324	 0.0	 1	 -30.0	 30.0;
	13045	 9957	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.012324	 0.0	 1	 -30.0	 30.0;
	13045	 9958	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.012324	 0.0	 1	 -30.0	 30.0;
	9009	 12921	 0.000212	 0.008494	 0.0	 3718	 3718	 3718	 1.00594	 0.0	 1	 -30.0	 30.0;
	9009	 12920	 0.000212	 0.008494	 0.0	 3718	 3718	 3718	 1.00594	 0.0	 1	 -30.0	 30.0;
	9009	 12937	 0.000212	 0.008494	 0.0	 3718	 3718	 3718	 1.00594	 0.0	 1	 -30.0	 30.0;
	9009	 12925	 0.000212	 0.008494	 0.0	 3718	 3718	 3718	 1.00594	 0.0	 1	 -30.0	 30.0;
	3268	 3335	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.011375	 0.0	 1	 -30.0	 30.0;
	3268	 3334	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.011375	 0.0	 1	 -30.0	 30.0;
	3268	 3337	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.011375	 0.0	 1	 -30.0	 30.0;
	3268	 3336	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.011375	 0.0	 1	 -30.0	 30.0;
	3268	 3339	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.011375	 0.0	 1	 -30.0	 30.0;
	4479	 3338	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.000873	 0.0	 1	 -30.0	 30.0;
	4479	 10436	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.000873	 0.0	 1	 -30.0	 30.0;
	3559	 10437	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.010394	 0.0	 1	 -30.0	 30.0;
	3559	 10438	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.010394	 0.0	 1	 -30.0	 30.0;
	4479	 10439	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.000811	 0.0	 1	 -30.0	 30.0;
	4479	 10432	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.000811	 0.0	 1	 -30.0	 30.0;
	213	 8479	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.019841	 0.0	 1	 -30.0	 30.0;
	213	 10434	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.019841	 0.0	 1	 -30.0	 30.0;
	213	 10435	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.019841	 0.0	 1	 -30.0	 30.0;
	213	 3608	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.019841	 0.0	 1	 -30.0	 30.0;
	7396	 10443	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.992269	 0.0	 1	 -30.0	 30.0;
	7396	 9946	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.992269	 0.0	 1	 -30.0	 30.0;
	7396	 3816	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.992269	 0.0	 1	 -30.0	 30.0;
	7396	 3815	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.992269	 0.0	 1	 -30.0	 30.0;
	10564	 3814	 0.028409	 1.136008	 0.0	 28	 28	 28	 1.008318	 0.0	 1	 -30.0	 30.0;
	1744	 3491	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.998258	 0.0	 1	 -30.0	 30.0;
	1744	 3812	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.998258	 0.0	 1	 -30.0	 30.0;
	1744	 3811	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.998258	 0.0	 1	 -30.0	 30.0;
	11080	 3810	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.013576	 0.0	 1	 -30.0	 30.0;
	11080	 3820	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.013576	 0.0	 1	 -30.0	 30.0;
	8460	 13392	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.010244	 0.0	 1	 -30.0	 30.0;
	8460	 6757	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.010244	 0.0	 1	 -30.0	 30.0;
	8460	 6758	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.010244	 0.0	 1	 -30.0	 30.0;
	8460	 13580	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.010244	 0.0	 1	 -30.0	 30.0;
	8460	 13582	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.010244	 0.0	 1	 -30.0	 30.0;
	8460	 6761	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.010244	 0.0	 1	 -30.0	 30.0;
	8460	 6762	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.010244	 0.0	 1	 -30.0	 30.0;
	8460	 6759	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.010244	 0.0	 1	 -30.0	 30.0;
	8460	 6760	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.010244	 0.0	 1	 -30.0	 30.0;
	8460	 6763	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.010244	 0.0	 1	 -30.0	 30.0;
	8460	 9659	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.010244	 0.0	 1	 -30.0	 30.0;
	1252	 4386	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.000067	 0.0	 1	 -30.0	 30.0;
	1252	 4385	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.000067	 0.0	 1	 -30.0	 30.0;
	1252	 4387	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.000067	 0.0	 1	 -30.0	 30.0;
	4031	 1675	 0.000212	 0.008494	 0.0	 3718	 3718	 3718	 1.01776	 0.0	 1	 -30.0	 30.0;
	4031	 276	 0.000212	 0.008494	 0.0	 3718	 3718	 3718	 1.01776	 0.0	 1	 -30.0	 30.0;
	2558	 275	 0.000212	 0.008494	 0.0	 3718	 3718	 3718	 1.017551	 0.0	 1	 -30.0	 30.0;
	2558	 274	 0.000212	 0.008494	 0.0	 3718	 3718	 3718	 1.017551	 0.0	 1	 -30.0	 30.0;
	11442	 273	 0.000212	 0.008494	 0.0	 3718	 3718	 3718	 1.017539	 0.0	 1	 -30.0	 30.0;
	11442	 1661	 0.000212	 0.008494	 0.0	 3718	 3718	 3718	 1.017539	 0.0	 1	 -30.0	 30.0;
	523	 271	 0.000212	 0.008494	 0.0	 3718	 3718	 3718	 1.017942	 0.0	 1	 -30.0	 30.0;
	523	 12968	 0.000212	 0.008494	 0.0	 3718	 3718	 3718	 1.017942	 0.0	 1	 -30.0	 30.0;
	5011	 3065	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.00666	 0.0	 1	 -30.0	 30.0;
	5011	 7531	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.00666	 0.0	 1	 -30.0	 30.0;
	5011	 5657	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.00666	 0.0	 1	 -30.0	 30.0;
	1835	 11454	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.999473	 0.0	 1	 -30.0	 30.0;
	1835	 11455	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.999473	 0.0	 1	 -30.0	 30.0;
	10485	 11456	 0.006812	 0.272394	 0.0	 116	 116	 116	 1.007176	 0.0	 1	 -30.0	 30.0;
	10485	 11457	 0.006812	 0.272394	 0.0	 116	 116	 116	 1.001423	 0.0	 1	 -30.0	 30.0;
	10485	 11458	 0.006812	 0.272394	 0.0	 116	 116	 116	 1.001423	 0.0	 1	 -30.0	 30.0;
	10485	 11459	 0.006812	 0.272394	 0.0	 116	 116	 116	 1.001423	 0.0	 1	 -30.0	 30.0;
	10485	 4901	 0.006812	 0.272394	 0.0	 116	 116	 116	 1.001423	 0.0	 1	 -30.0	 30.0;
	10485	 2289	 0.006812	 0.272394	 0.0	 116	 116	 116	 1.001423	 0.0	 1	 -30.0	 30.0;
	1173	 11419	 0.000212	 0.008494	 0.0	 3718	 3718	 3718	 1.014078	 0.0	 1	 -30.0	 30.0;
	1173	 11418	 0.000212	 0.008494	 0.0	 3718	 3718	 3718	 1.014078	 0.0	 1	 -30.0	 30.0;
	12161	 6254	 0.000212	 0.008494	 0.0	 3718	 3718	 3718	 1.013997	 0.0	 1	 -30.0	 30.0;
	12161	 709	 0.000212	 0.008494	 0.0	 3718	 3718	 3718	 1.013997	 0.0	 1	 -30.0	 30.0;
	5760	 4903	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.010522	 0.0	 1	 -30.0	 30.0;
	5760	 4902	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.010522	 0.0	 1	 -30.0	 30.0;
	8710	 4905	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.00576	 0.0	 1	 -30.0	 30.0;
	8710	 4904	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.00576	 0.0	 1	 -30.0	 30.0;
	11004	 6611	 0.002119	 0.084719	 0.0	 373	 373	 373	 0.985768	 0.0	 1	 -30.0	 30.0;
	11004	 6612	 0.002119	 0.084719	 0.0	 373	 373	 373	 0.985768	 0.0	 1	 -30.0	 30.0;
	11004	 6609	 0.002119	 0.084719	 0.0	 373	 373	 373	 0.985768	 0.0	 1	 -30.0	 30.0;
	11004	 6610	 0.002119	 0.084719	 0.0	 373	 373	 373	 0.985768	 0.0	 1	 -30.0	 30.0;
	11004	 6607	 0.002119	 0.084719	 0.0	 373	 373	 373	 0.985768	 0.0	 1	 -30.0	 30.0;
	11004	 6608	 0.002119	 0.084719	 0.0	 373	 373	 373	 0.985768	 0.0	 1	 -30.0	 30.0;
	11004	 12529	 0.002119	 0.084719	 0.0	 373	 373	 373	 0.985768	 0.0	 1	 -30.0	 30.0;
	11004	 6606	 0.002119	 0.084719	 0.0	 373	 373	 373	 0.985768	 0.0	 1	 -30.0	 30.0;
	3466	 10202	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.004858	 0.0	 1	 -30.0	 30.0;
	3466	 10201	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.004858	 0.0	 1	 -30.0	 30.0;
	2735	 12582	 0.005297	 0.211798	 0.0	 150	 150	 150	 1.001039	 0.0	 1	 -30.0	 30.0;
	2735	 12583	 0.005297	 0.211798	 0.0	 150	 150	 150	 1.001039	 0.0	 1	 -30.0	 30.0;
	2735	 7428	 0.005297	 0.211798	 0.0	 150	 150	 150	 1.001039	 0.0	 1	 -30.0	 30.0;
	2735	 12585	 0.005297	 0.211798	 0.0	 150	 150	 150	 0.995164	 0.0	 1	 -30.0	 30.0;
	2735	 12578	 0.005297	 0.211798	 0.0	 150	 150	 150	 0.995164	 0.0	 1	 -30.0	 30.0;
	2735	 7361	 0.005297	 0.211798	 0.0	 150	 150	 150	 0.995164	 0.0	 1	 -30.0	 30.0;
	2735	 12580	 0.005297	 0.211798	 0.0	 150	 150	 150	 0.995164	 0.0	 1	 -30.0	 30.0;
	2735	 12581	 0.005297	 0.211798	 0.0	 150	 150	 150	 0.995164	 0.0	 1	 -30.0	 30.0;
	2735	 12575	 0.005297	 0.211798	 0.0	 150	 150	 150	 0.995164	 0.0	 1	 -30.0	 30.0;
	2735	 12576	 0.005297	 0.211798	 0.0	 150	 150	 150	 0.995164	 0.0	 1	 -30.0	 30.0;
	2735	 6481	 0.005297	 0.211798	 0.0	 150	 150	 150	 0.995164	 0.0	 1	 -30.0	 30.0;
	2735	 13469	 0.005297	 0.211798	 0.0	 150	 150	 150	 0.995164	 0.0	 1	 -30.0	 30.0;
	1086	 10676	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.014931	 0.0	 1	 -30.0	 30.0;
	1086	 10675	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.014931	 0.0	 1	 -30.0	 30.0;
	1086	 10672	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.014931	 0.0	 1	 -30.0	 30.0;
	1086	 10671	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.014931	 0.0	 1	 -30.0	 30.0;
	1086	 10674	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.014931	 0.0	 1	 -30.0	 30.0;
	1086	 898	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.014931	 0.0	 1	 -30.0	 30.0;
	4953	 10669	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.007499	 0.0	 1	 -30.0	 30.0;
	4953	 10668	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.007499	 0.0	 1	 -30.0	 30.0;
	4953	 3571	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.007499	 0.0	 1	 -30.0	 30.0;
	7062	 8425	 0.019841	 0.793403	 0.0	 40	 40	 40	 1.003966	 0.0	 1	 -30.0	 30.0;
	10933	 3569	 0.005423	 0.216852	 0.0	 146	 146	 146	 0.996526	 0.0	 1	 -30.0	 30.0;
	10933	 3570	 0.005423	 0.216852	 0.0	 146	 146	 146	 0.987742	 0.0	 1	 -30.0	 30.0;
	10933	 3575	 0.005423	 0.216852	 0.0	 146	 146	 146	 0.987742	 0.0	 1	 -30.0	 30.0;
	10933	 8435	 0.005423	 0.216852	 0.0	 146	 146	 146	 0.987742	 0.0	 1	 -30.0	 30.0;
	10933	 8427	 0.005423	 0.216852	 0.0	 146	 146	 146	 0.987742	 0.0	 1	 -30.0	 30.0;
	10933	 8430	 0.005423	 0.216852	 0.0	 146	 146	 146	 0.987742	 0.0	 1	 -30.0	 30.0;
	12094	 8397	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.980186	 0.0	 1	 -30.0	 30.0;
	12094	 8402	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.980186	 0.0	 1	 -30.0	 30.0;
	2953	 7240	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.017742	 0.0	 1	 -30.0	 30.0;
	2953	 9220	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.017742	 0.0	 1	 -30.0	 30.0;
	2953	 9219	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.017742	 0.0	 1	 -30.0	 30.0;
	2953	 10007	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.017742	 0.0	 1	 -30.0	 30.0;
	2953	 7475	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.017742	 0.0	 1	 -30.0	 30.0;
	5913	 9224	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.01761	 0.0	 1	 -30.0	 30.0;
	5913	 10068	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.01761	 0.0	 1	 -30.0	 30.0;
	5913	 9222	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.01761	 0.0	 1	 -30.0	 30.0;
	5913	 1273	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.01761	 0.0	 1	 -30.0	 30.0;
	5913	 9213	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.01761	 0.0	 1	 -30.0	 30.0;
	6061	 3410	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.005176	 0.0	 1	 -30.0	 30.0;
	6061	 12200	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.005176	 0.0	 1	 -30.0	 30.0;
	9916	 13594	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.017597	 0.0	 1	 -30.0	 30.0;
	9916	 13597	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.017597	 0.0	 1	 -30.0	 30.0;
	9916	 7547	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.017597	 0.0	 1	 -30.0	 30.0;
	6839	 13601	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.004984	 0.0	 1	 -30.0	 30.0;
	9289	 2157	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.003139	 0.0	 1	 -30.0	 30.0;
	9289	 13609	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.003139	 0.0	 1	 -30.0	 30.0;
	13408	 2148	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.007086	 0.0	 1	 -30.0	 30.0;
	13408	 2149	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.007086	 0.0	 1	 -30.0	 30.0;
	13408	 9696	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.007086	 0.0	 1	 -30.0	 30.0;
	13408	 9695	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.007086	 0.0	 1	 -30.0	 30.0;
	13408	 9698	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.007086	 0.0	 1	 -30.0	 30.0;
	13408	 9697	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.007086	 0.0	 1	 -30.0	 30.0;
	7811	 9700	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.013653	 0.0	 1	 -30.0	 30.0;
	3376	 9699	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.999657	 0.0	 1	 -30.0	 30.0;
	3376	 9702	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.999657	 0.0	 1	 -30.0	 30.0;
	13583	 7179	 0.002201	 0.088001	 0.0	 359	 359	 359	 1.001304	 0.0	 1	 -30.0	 30.0;
	13583	 7053	 0.002201	 0.088001	 0.0	 359	 359	 359	 0.994637	 0.0	 1	 -30.0	 30.0;
	13583	 7054	 0.002201	 0.088001	 0.0	 359	 359	 359	 0.994637	 0.0	 1	 -30.0	 30.0;
	13583	 515	 0.002201	 0.088001	 0.0	 359	 359	 359	 0.994637	 0.0	 1	 -30.0	 30.0;
	13583	 3078	 0.002201	 0.088001	 0.0	 359	 359	 359	 0.994637	 0.0	 1	 -30.0	 30.0;
	13583	 513	 0.002201	 0.088001	 0.0	 359	 359	 359	 0.994637	 0.0	 1	 -30.0	 30.0;
	13583	 512	 0.002201	 0.088001	 0.0	 359	 359	 359	 0.994637	 0.0	 1	 -30.0	 30.0;
	13583	 511	 0.002201	 0.088001	 0.0	 359	 359	 359	 0.994637	 0.0	 1	 -30.0	 30.0;
	4299	 8274	 0.003425	 0.136943	 0.0	 231	 231	 231	 1.017447	 0.0	 1	 -30.0	 30.0;
	4299	 8275	 0.003425	 0.136943	 0.0	 231	 231	 231	 1.017447	 0.0	 1	 -30.0	 30.0;
	4299	 8276	 0.003425	 0.136943	 0.0	 231	 231	 231	 1.017447	 0.0	 1	 -30.0	 30.0;
	4299	 9182	 0.003425	 0.136943	 0.0	 231	 231	 231	 1.015837	 0.0	 1	 -30.0	 30.0;
	4299	 8278	 0.003425	 0.136943	 0.0	 231	 231	 231	 1.010601	 0.0	 1	 -30.0	 30.0;
	4299	 1231	 0.003425	 0.136943	 0.0	 231	 231	 231	 1.010601	 0.0	 1	 -30.0	 30.0;
	4299	 1230	 0.003425	 0.136943	 0.0	 231	 231	 231	 1.010601	 0.0	 1	 -30.0	 30.0;
	4299	 1232	 0.003425	 0.136943	 0.0	 231	 231	 231	 1.010601	 0.0	 1	 -30.0	 30.0;
	1582	 12127	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.009832	 0.0	 1	 -30.0	 30.0;
	1582	 12126	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.009832	 0.0	 1	 -30.0	 30.0;
	994	 4870	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.013612	 0.0	 1	 -30.0	 30.0;
	994	 12124	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.013612	 0.0	 1	 -30.0	 30.0;
	4114	 12123	 0.046296	 1.851273	 0.0	 18	 18	 18	 1.008844	 0.0	 1	 -30.0	 30.0;
	4114	 12122	 0.046296	 1.851273	 0.0	 18	 18	 18	 1.003788	 0.0	 1	 -30.0	 30.0;
	9263	 12121	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.014036	 0.0	 1	 -30.0	 30.0;
	9263	 3351	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.014036	 0.0	 1	 -30.0	 30.0;
	9263	 5076	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.014036	 0.0	 1	 -30.0	 30.0;
	9263	 5077	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.014036	 0.0	 1	 -30.0	 30.0;
	9263	 5078	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.014036	 0.0	 1	 -30.0	 30.0;
	1206	 5071	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.998104	 0.0	 1	 -30.0	 30.0;
	1206	 5072	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.998104	 0.0	 1	 -30.0	 30.0;
	1206	 5073	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.998104	 0.0	 1	 -30.0	 30.0;
	1206	 5074	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.998104	 0.0	 1	 -30.0	 30.0;
	1206	 5069	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.998104	 0.0	 1	 -30.0	 30.0;
	5709	 5070	 0.012821	 0.51266	 0.0	 62	 62	 62	 1.007739	 0.0	 1	 -30.0	 30.0;
	5709	 7088	 0.012821	 0.51266	 0.0	 62	 62	 62	 1.002444	 0.0	 1	 -30.0	 30.0;
	7157	 9706	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.009513	 0.0	 1	 -30.0	 30.0;
	7157	 1815	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.009513	 0.0	 1	 -30.0	 30.0;
	7157	 7087	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.009513	 0.0	 1	 -30.0	 30.0;
	7157	 7084	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.009513	 0.0	 1	 -30.0	 30.0;
	4528	 7085	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.015825	 0.0	 1	 -30.0	 30.0;
	4528	 7082	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.015825	 0.0	 1	 -30.0	 30.0;
	4528	 7083	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.015825	 0.0	 1	 -30.0	 30.0;
	4528	 7080	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.015825	 0.0	 1	 -30.0	 30.0;
	4528	 7081	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.015825	 0.0	 1	 -30.0	 30.0;
	4528	 528	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.015825	 0.0	 1	 -30.0	 30.0;
	6212	 2137	 0.000212	 0.008494	 0.0	 3718	 3718	 3718	 1.001886	 0.0	 1	 -30.0	 30.0;
	6212	 2136	 0.000212	 0.008494	 0.0	 3718	 3718	 3718	 1.001886	 0.0	 1	 -30.0	 30.0;
	6212	 2135	 0.000212	 0.008494	 0.0	 3718	 3718	 3718	 1.001886	 0.0	 1	 -30.0	 30.0;
	6212	 2138	 0.000212	 0.008494	 0.0	 3718	 3718	 3718	 1.001886	 0.0	 1	 -30.0	 30.0;
	1127	 2540	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.028503	 0.0	 1	 -30.0	 30.0;
	1127	 2577	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.028503	 0.0	 1	 -30.0	 30.0;
	1127	 2543	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.028503	 0.0	 1	 -30.0	 30.0;
	1127	 2571	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.028503	 0.0	 1	 -30.0	 30.0;
	1127	 2534	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.028503	 0.0	 1	 -30.0	 30.0;
	1127	 10172	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.028503	 0.0	 1	 -30.0	 30.0;
	1127	 10171	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.028503	 0.0	 1	 -30.0	 30.0;
	1127	 10174	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.028503	 0.0	 1	 -30.0	 30.0;
	1127	 10173	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.028503	 0.0	 1	 -30.0	 30.0;
	9274	 12656	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.023793	 0.0	 1	 -30.0	 30.0;
	9274	 10210	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.023793	 0.0	 1	 -30.0	 30.0;
	9274	 6631	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.023793	 0.0	 1	 -30.0	 30.0;
	6699	 10232	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.007671	 0.0	 1	 -30.0	 30.0;
	6699	 6621	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.007671	 0.0	 1	 -30.0	 30.0;
	4121	 6622	 0.003876	 0.15499	 0.0	 204	 204	 204	 1.007253	 0.0	 1	 -30.0	 30.0;
	4121	 76	 0.003876	 0.15499	 0.0	 204	 204	 204	 1.001535	 0.0	 1	 -30.0	 30.0;
	4121	 75	 0.003876	 0.15499	 0.0	 204	 204	 204	 1.001535	 0.0	 1	 -30.0	 30.0;
	4121	 74	 0.003876	 0.15499	 0.0	 204	 204	 204	 1.001535	 0.0	 1	 -30.0	 30.0;
	3662	 438	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.007811	 0.0	 1	 -30.0	 30.0;
	3662	 8039	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.007811	 0.0	 1	 -30.0	 30.0;
	3662	 79	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.007811	 0.0	 1	 -30.0	 30.0;
	7321	 78	 0.003788	 0.151468	 0.0	 209	 209	 209	 1.004692	 0.0	 1	 -30.0	 30.0;
	7321	 447	 0.003788	 0.151468	 0.0	 209	 209	 209	 0.997453	 0.0	 1	 -30.0	 30.0;
	7321	 72	 0.003788	 0.151468	 0.0	 209	 209	 209	 0.997453	 0.0	 1	 -30.0	 30.0;
	7321	 71	 0.003788	 0.151468	 0.0	 209	 209	 209	 0.997453	 0.0	 1	 -30.0	 30.0;
	2432	 9681	 0.000212	 0.008494	 0.0	 3718	 3718	 3718	 1.01356	 0.0	 1	 -30.0	 30.0;
	13529	 9682	 0.000212	 0.008494	 0.0	 3718	 3718	 3718	 1.013518	 0.0	 1	 -30.0	 30.0;
	11837	 7995	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.008199	 0.0	 1	 -30.0	 30.0;
	11837	 8386	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.008199	 0.0	 1	 -30.0	 30.0;
	11837	 8000	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.008199	 0.0	 1	 -30.0	 30.0;
	11837	 8001	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.008199	 0.0	 1	 -30.0	 30.0;
	4220	 7998	 0.060976	 2.438262	 0.0	 13	 13	 13	 1.008285	 0.0	 1	 -30.0	 30.0;
	4220	 8442	 0.060976	 2.438262	 0.0	 13	 13	 13	 1.003185	 0.0	 1	 -30.0	 30.0;
	13028	 7992	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.022422	 0.0	 1	 -30.0	 30.0;
	13028	 7993	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.022422	 0.0	 1	 -30.0	 30.0;
	4907	 1440	 0.004621	 0.184785	 0.0	 171	 171	 171	 1.007556	 0.0	 1	 -30.0	 30.0;
	4907	 1439	 0.004621	 0.184785	 0.0	 171	 171	 171	 1.002847	 0.0	 1	 -30.0	 30.0;
	4907	 1442	 0.004621	 0.184785	 0.0	 171	 171	 171	 1.002847	 0.0	 1	 -30.0	 30.0;
	3473	 1441	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.018212	 0.0	 1	 -30.0	 30.0;
	3473	 1436	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.018212	 0.0	 1	 -30.0	 30.0;
	3473	 1435	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.018212	 0.0	 1	 -30.0	 30.0;
	5395	 1438	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.008298	 0.0	 1	 -30.0	 30.0;
	5395	 1437	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.008298	 0.0	 1	 -30.0	 30.0;
	5395	 1434	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.008298	 0.0	 1	 -30.0	 30.0;
	5395	 1433	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.008298	 0.0	 1	 -30.0	 30.0;
	5395	 7505	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.008298	 0.0	 1	 -30.0	 30.0;
	5395	 4709	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.008298	 0.0	 1	 -30.0	 30.0;
	10204	 7507	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.000664	 0.0	 1	 -30.0	 30.0;
	10204	 11723	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.000664	 0.0	 1	 -30.0	 30.0;
	10204	 7501	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.000664	 0.0	 1	 -30.0	 30.0;
	10301	 7502	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.01492	 0.0	 1	 -30.0	 30.0;
	10301	 9028	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.01492	 0.0	 1	 -30.0	 30.0;
	10301	 7504	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.01492	 0.0	 1	 -30.0	 30.0;
	10294	 4733	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.972052	 0.0	 1	 -30.0	 30.0;
	10294	 4738	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.972052	 0.0	 1	 -30.0	 30.0;
	9955	 987	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.010165	 0.0	 1	 -30.0	 30.0;
	9955	 986	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.010165	 0.0	 1	 -30.0	 30.0;
	9955	 985	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.010165	 0.0	 1	 -30.0	 30.0;
	9955	 984	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.010165	 0.0	 1	 -30.0	 30.0;
	3527	 983	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.001827	 0.0	 1	 -30.0	 30.0;
	3527	 982	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.001827	 0.0	 1	 -30.0	 30.0;
	3527	 981	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.001827	 0.0	 1	 -30.0	 30.0;
	1122	 980	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.997809	 0.0	 1	 -30.0	 30.0;
	178	 3558	 0.000212	 0.008494	 0.0	 3718	 3718	 3718	 1.020691	 0.0	 1	 -30.0	 30.0;
	7008	 3557	 0.000212	 0.008494	 0.0	 3718	 3718	 3718	 1.014465	 0.0	 1	 -30.0	 30.0;
	4822	 6879	 0.000212	 0.008494	 0.0	 3718	 3718	 3718	 1.014326	 0.0	 1	 -30.0	 30.0;
	6572	 6880	 0.000212	 0.008494	 0.0	 3718	 3718	 3718	 1.014284	 0.0	 1	 -30.0	 30.0;
	7985	 8956	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.997657	 0.0	 1	 -30.0	 30.0;
	7985	 13363	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.997657	 0.0	 1	 -30.0	 30.0;
	1422	 8954	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.010148	 0.0	 1	 -30.0	 30.0;
	1422	 8955	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.010148	 0.0	 1	 -30.0	 30.0;
	1422	 8952	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.010148	 0.0	 1	 -30.0	 30.0;
	1422	 8953	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.010148	 0.0	 1	 -30.0	 30.0;
	1422	 8962	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.010148	 0.0	 1	 -30.0	 30.0;
	9411	 8963	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.007693	 0.0	 1	 -30.0	 30.0;
	9411	 2329	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.007693	 0.0	 1	 -30.0	 30.0;
	9411	 2328	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.007693	 0.0	 1	 -30.0	 30.0;
	9411	 2331	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.007693	 0.0	 1	 -30.0	 30.0;
	9411	 2330	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.007693	 0.0	 1	 -30.0	 30.0;
	4999	 323	 0.000212	 0.008494	 0.0	 3718	 3718	 3718	 0.995203	 0.0	 1	 -30.0	 30.0;
	4999	 1932	 0.000212	 0.008494	 0.0	 3718	 3718	 3718	 0.995203	 0.0	 1	 -30.0	 30.0;
	3737	 2333	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.008578	 0.0	 1	 -30.0	 30.0;
	3737	 1077	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.008578	 0.0	 1	 -30.0	 30.0;
	3737	 2325	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.008578	 0.0	 1	 -30.0	 30.0;
	3737	 2324	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.008578	 0.0	 1	 -30.0	 30.0;
	4880	 11604	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.999885	 0.0	 1	 -30.0	 30.0;
	4880	 11603	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.999885	 0.0	 1	 -30.0	 30.0;
	7698	 11606	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.007227	 0.0	 1	 -30.0	 30.0;
	7698	 11605	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.007227	 0.0	 1	 -30.0	 30.0;
	7698	 11600	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.007227	 0.0	 1	 -30.0	 30.0;
	326	 13393	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.005811	 0.0	 1	 -30.0	 30.0;
	326	 13395	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.005811	 0.0	 1	 -30.0	 30.0;
	326	 13394	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.005811	 0.0	 1	 -30.0	 30.0;
	326	 13391	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.005811	 0.0	 1	 -30.0	 30.0;
	326	 13390	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.005811	 0.0	 1	 -30.0	 30.0;
	326	 10621	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.005811	 0.0	 1	 -30.0	 30.0;
	326	 10625	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.005811	 0.0	 1	 -30.0	 30.0;
	326	 6298	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.005811	 0.0	 1	 -30.0	 30.0;
	326	 6299	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.005811	 0.0	 1	 -30.0	 30.0;
	326	 8942	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.005811	 0.0	 1	 -30.0	 30.0;
	11931	 448	 0.008224	 0.328845	 0.0	 97	 97	 97	 1.012901	 0.0	 1	 -30.0	 30.0;
	11931	 441	 0.008224	 0.328845	 0.0	 97	 97	 97	 1.007766	 0.0	 1	 -30.0	 30.0;
	2104	 442	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.013881	 0.0	 1	 -30.0	 30.0;
	2104	 4539	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.013881	 0.0	 1	 -30.0	 30.0;
	4848	 4540	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.994225	 0.0	 1	 -30.0	 30.0;
	4848	 11095	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.994225	 0.0	 1	 -30.0	 30.0;
	13214	 12912	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.009807	 0.0	 1	 -30.0	 30.0;
	13214	 2411	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.009807	 0.0	 1	 -30.0	 30.0;
	13214	 12910	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.009807	 0.0	 1	 -30.0	 30.0;
	13214	 9184	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.009807	 0.0	 1	 -30.0	 30.0;
	13214	 12908	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.009807	 0.0	 1	 -30.0	 30.0;
	13214	 12907	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.009807	 0.0	 1	 -30.0	 30.0;
	13214	 12906	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.009807	 0.0	 1	 -30.0	 30.0;
	13214	 12917	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.009807	 0.0	 1	 -30.0	 30.0;
	13214	 12916	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.009807	 0.0	 1	 -30.0	 30.0;
	13214	 5831	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.009807	 0.0	 1	 -30.0	 30.0;
	13214	 5832	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.009807	 0.0	 1	 -30.0	 30.0;
	2348	 4011	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.004739	 0.0	 1	 -30.0	 30.0;
	2348	 10898	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.004739	 0.0	 1	 -30.0	 30.0;
	7867	 10643	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.020131	 0.0	 1	 -30.0	 30.0;
	9172	 7599	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.020177	 0.0	 1	 -30.0	 30.0;
	10335	 7598	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.028958	 0.0	 1	 -30.0	 30.0;
	5899	 9781	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.029771	 0.0	 1	 -30.0	 30.0;
	5899	 4607	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.029771	 0.0	 1	 -30.0	 30.0;
	12622	 1966	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.031766	 0.0	 1	 -30.0	 30.0;
	12622	 1967	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.031766	 0.0	 1	 -30.0	 30.0;
	12622	 6139	 0.000212	 0.008494	 0.0	 3718	 3718	 3718	 1.059942	 0.0	 1	 -30.0	 30.0;
	12622	 6140	 0.000212	 0.008494	 0.0	 3718	 3718	 3718	 1.059942	 0.0	 1	 -30.0	 30.0;
	12622	 6138	 0.000212	 0.008494	 0.0	 3718	 3718	 3718	 1.059942	 0.0	 1	 -30.0	 30.0;
	7765	 3141	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.008128	 0.0	 1	 -30.0	 30.0;
	7765	 3142	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.008128	 0.0	 1	 -30.0	 30.0;
	9820	 3143	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.008223	 0.0	 1	 -30.0	 30.0;
	622	 6663	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.004203	 0.0	 1	 -30.0	 30.0;
	622	 8439	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.004203	 0.0	 1	 -30.0	 30.0;
	622	 1412	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.004203	 0.0	 1	 -30.0	 30.0;
	622	 1413	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.004203	 0.0	 1	 -30.0	 30.0;
	622	 1410	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.004203	 0.0	 1	 -30.0	 30.0;
	622	 1411	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.004203	 0.0	 1	 -30.0	 30.0;
	622	 1416	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.004203	 0.0	 1	 -30.0	 30.0;
	9506	 1417	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.006993	 0.0	 1	 -30.0	 30.0;
	9506	 1414	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.006993	 0.0	 1	 -30.0	 30.0;
	9506	 1415	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.006993	 0.0	 1	 -30.0	 30.0;
	9506	 1407	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.006993	 0.0	 1	 -30.0	 30.0;
	9506	 1408	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.006993	 0.0	 1	 -30.0	 30.0;
	9506	 7333	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.006993	 0.0	 1	 -30.0	 30.0;
	9506	 7966	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.006993	 0.0	 1	 -30.0	 30.0;
	9506	 7965	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.006993	 0.0	 1	 -30.0	 30.0;
	6362	 1521	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.021091	 0.0	 1	 -30.0	 30.0;
	7733	 1517	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.017918	 0.0	 1	 -30.0	 30.0;
	7733	 1518	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.017918	 0.0	 1	 -30.0	 30.0;
	3193	 1519	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.017911	 0.0	 1	 -30.0	 30.0;
	3193	 1520	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.017911	 0.0	 1	 -30.0	 30.0;
	5496	 3641	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.01792	 0.0	 1	 -30.0	 30.0;
	5496	 3642	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.01792	 0.0	 1	 -30.0	 30.0;
	8653	 10311	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.015224	 0.0	 1	 -30.0	 30.0;
	8653	 10742	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.015224	 0.0	 1	 -30.0	 30.0;
	272	 8550	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.025836	 0.0	 1	 -30.0	 30.0;
	272	 8549	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.025836	 0.0	 1	 -30.0	 30.0;
	4883	 8548	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.025538	 0.0	 1	 -30.0	 30.0;
	4883	 8547	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.025538	 0.0	 1	 -30.0	 30.0;
	1467	 8546	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.028159	 0.0	 1	 -30.0	 30.0;
	1467	 8545	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.028159	 0.0	 1	 -30.0	 30.0;
	5005	 8544	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.028094	 0.0	 1	 -30.0	 30.0;
	5005	 9393	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.028094	 0.0	 1	 -30.0	 30.0;
	10000	 12790	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.006418	 0.0	 1	 -30.0	 30.0;
	10000	 12791	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.006418	 0.0	 1	 -30.0	 30.0;
	10000	 12788	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.006418	 0.0	 1	 -30.0	 30.0;
	10000	 12789	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.006418	 0.0	 1	 -30.0	 30.0;
	5569	 11212	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.011493	 0.0	 1	 -30.0	 30.0;
	8176	 11211	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.025506	 0.0	 1	 -30.0	 30.0;
	644	 9890	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.025242	 0.0	 1	 -30.0	 30.0;
	2726	 4144	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.025287	 0.0	 1	 -30.0	 30.0;
	2257	 4143	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.02407	 0.0	 1	 -30.0	 30.0;
	2257	 2734	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.02407	 0.0	 1	 -30.0	 30.0;
	2257	 4141	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.02407	 0.0	 1	 -30.0	 30.0;
	2257	 4140	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.02407	 0.0	 1	 -30.0	 30.0;
	4997	 4139	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.023728	 0.0	 1	 -30.0	 30.0;
	4997	 4138	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.023728	 0.0	 1	 -30.0	 30.0;
	4997	 4137	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.023728	 0.0	 1	 -30.0	 30.0;
	10367	 4136	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.013659	 0.0	 1	 -30.0	 30.0;
	10367	 11803	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.013659	 0.0	 1	 -30.0	 30.0;
	9178	 10753	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.013627	 0.0	 1	 -30.0	 30.0;
	9178	 10754	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.013627	 0.0	 1	 -30.0	 30.0;
	9415	 10755	 0.002119	 0.084719	 0.0	 448	 448	 448	 1.036331	 0.0	 1	 -30.0	 30.0;
	9415	 10756	 0.002119	 0.084719	 0.0	 448	 448	 448	 1.036331	 0.0	 1	 -30.0	 30.0;
	9415	 10337	 0.002119	 0.084719	 0.0	 448	 448	 448	 1.036331	 0.0	 1	 -30.0	 30.0;
	9415	 10750	 0.002119	 0.084719	 0.0	 448	 448	 448	 1.036331	 0.0	 1	 -30.0	 30.0;
	5344	 10343	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.034204	 0.0	 1	 -30.0	 30.0;
	5344	 10752	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.034204	 0.0	 1	 -30.0	 30.0;
	11902	 10328	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.031833	 0.0	 1	 -30.0	 30.0;
	11902	 10747	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.031833	 0.0	 1	 -30.0	 30.0;
	11902	 4665	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.031833	 0.0	 1	 -30.0	 30.0;
	11902	 4664	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.031833	 0.0	 1	 -30.0	 30.0;
	722	 1057	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.010944	 0.0	 1	 -30.0	 30.0;
	722	 4666	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.010944	 0.0	 1	 -30.0	 30.0;
	8960	 4946	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.012933	 0.0	 1	 -30.0	 30.0;
	8960	 4945	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.012933	 0.0	 1	 -30.0	 30.0;
	478	 4663	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.025231	 0.0	 1	 -30.0	 30.0;
	478	 4662	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.025231	 0.0	 1	 -30.0	 30.0;
	945	 4943	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.013183	 0.0	 1	 -30.0	 30.0;
	945	 4942	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.013183	 0.0	 1	 -30.0	 30.0;
	6825	 11219	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.008652	 0.0	 1	 -30.0	 30.0;
	12961	 8806	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.01068	 0.0	 1	 -30.0	 30.0;
	12961	 8807	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.01068	 0.0	 1	 -30.0	 30.0;
	12961	 12519	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.01068	 0.0	 1	 -30.0	 30.0;
	12961	 8809	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.01068	 0.0	 1	 -30.0	 30.0;
	12406	 9279	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.030019	 0.0	 1	 -30.0	 30.0;
	8314	 11220	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.029971	 0.0	 1	 -30.0	 30.0;
	9863	 9280	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.004413	 0.0	 1	 -30.0	 30.0;
	9863	 9075	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.004413	 0.0	 1	 -30.0	 30.0;
	3932	 9088	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.016311	 0.0	 1	 -30.0	 30.0;
	3932	 11225	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.016311	 0.0	 1	 -30.0	 30.0;
	1779	 6405	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.011415	 0.0	 1	 -30.0	 30.0;
	1779	 6408	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.011415	 0.0	 1	 -30.0	 30.0;
	8529	 6407	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.023825	 0.0	 1	 -30.0	 30.0;
	8529	 6402	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.023825	 0.0	 1	 -30.0	 30.0;
	5951	 6401	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.023807	 0.0	 1	 -30.0	 30.0;
	5951	 6404	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.023807	 0.0	 1	 -30.0	 30.0;
	7322	 8839	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.02219	 0.0	 1	 -30.0	 30.0;
	7322	 10748	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.02219	 0.0	 1	 -30.0	 30.0;
	7322	 3647	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.02219	 0.0	 1	 -30.0	 30.0;
	7322	 10253	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.02219	 0.0	 1	 -30.0	 30.0;
	7322	 10254	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.02219	 0.0	 1	 -30.0	 30.0;
	6386	 9785	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.013786	 0.0	 1	 -30.0	 30.0;
	6386	 4652	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.013786	 0.0	 1	 -30.0	 30.0;
	4756	 9751	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.016334	 0.0	 1	 -30.0	 30.0;
	1128	 9753	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.016322	 0.0	 1	 -30.0	 30.0;
	6012	 3655	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.012575	 0.0	 1	 -30.0	 30.0;
	6012	 3186	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.012575	 0.0	 1	 -30.0	 30.0;
	6570	 3137	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.021682	 0.0	 1	 -30.0	 30.0;
	6570	 3136	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.021682	 0.0	 1	 -30.0	 30.0;
	6570	 3135	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.021682	 0.0	 1	 -30.0	 30.0;
	6570	 3134	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.021682	 0.0	 1	 -30.0	 30.0;
	6570	 6048	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.021682	 0.0	 1	 -30.0	 30.0;
	2113	 3656	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.013632	 0.0	 1	 -30.0	 30.0;
	2113	 3651	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.013632	 0.0	 1	 -30.0	 30.0;
	2113	 8885	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.013632	 0.0	 1	 -30.0	 30.0;
	12866	 12500	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.029586	 0.0	 1	 -30.0	 30.0;
	12866	 6976	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.029586	 0.0	 1	 -30.0	 30.0;
	9948	 10269	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.029404	 0.0	 1	 -30.0	 30.0;
	9948	 10270	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.029404	 0.0	 1	 -30.0	 30.0;
	10965	 10267	 0.002119	 0.084719	 0.0	 448	 448	 448	 1.033807	 0.0	 1	 -30.0	 30.0;
	10965	 10268	 0.002119	 0.084719	 0.0	 448	 448	 448	 1.033807	 0.0	 1	 -30.0	 30.0;
	1691	 2179	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.015569	 0.0	 1	 -30.0	 30.0;
	1691	 2178	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.015569	 0.0	 1	 -30.0	 30.0;
	1691	 2177	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.015569	 0.0	 1	 -30.0	 30.0;
	1691	 2176	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.015569	 0.0	 1	 -30.0	 30.0;
	12622	 3094	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.037731	 0.0	 1	 -30.0	 30.0;
	12622	 3096	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.037731	 0.0	 1	 -30.0	 30.0;
	866	 3093	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.027871	 0.0	 1	 -30.0	 30.0;
	866	 3101	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.027871	 0.0	 1	 -30.0	 30.0;
	3429	 3100	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.027928	 0.0	 1	 -30.0	 30.0;
	3429	 13526	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.027928	 0.0	 1	 -30.0	 30.0;
	4472	 3582	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.015316	 0.0	 1	 -30.0	 30.0;
	4472	 3580	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.015316	 0.0	 1	 -30.0	 30.0;
	8588	 12093	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.01369	 0.0	 1	 -30.0	 30.0;
	8588	 10355	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.01369	 0.0	 1	 -30.0	 30.0;
	2750	 13397	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.013791	 0.0	 1	 -30.0	 30.0;
	2750	 13398	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.013791	 0.0	 1	 -30.0	 30.0;
	2750	 13399	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.013791	 0.0	 1	 -30.0	 30.0;
	2750	 13388	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.013791	 0.0	 1	 -30.0	 30.0;
	2750	 13389	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.013791	 0.0	 1	 -30.0	 30.0;
	1425	 6764	 0.002119	 0.084719	 0.0	 373	 373	 373	 0.996464	 0.0	 1	 -30.0	 30.0;
	12051	 7526	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.00607	 0.0	 1	 -30.0	 30.0;
	12051	 7055	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.00607	 0.0	 1	 -30.0	 30.0;
	12051	 7528	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.00607	 0.0	 1	 -30.0	 30.0;
	12051	 7523	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.00607	 0.0	 1	 -30.0	 30.0;
	12051	 7524	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.00607	 0.0	 1	 -30.0	 30.0;
	462	 6765	 0.002119	 0.084719	 0.0	 373	 373	 373	 0.995797	 0.0	 1	 -30.0	 30.0;
	2201	 6422	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.028549	 0.0	 1	 -30.0	 30.0;
	2201	 6417	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.028549	 0.0	 1	 -30.0	 30.0;
	2201	 6418	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.028549	 0.0	 1	 -30.0	 30.0;
	4372	 224	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.010236	 0.0	 1	 -30.0	 30.0;
	4372	 225	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.010236	 0.0	 1	 -30.0	 30.0;
	4372	 222	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.010236	 0.0	 1	 -30.0	 30.0;
	8454	 223	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.018164	 0.0	 1	 -30.0	 30.0;
	8454	 220	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.018164	 0.0	 1	 -30.0	 30.0;
	8454	 221	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.018164	 0.0	 1	 -30.0	 30.0;
	8592	 3061	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.997196	 0.0	 1	 -30.0	 30.0;
	8592	 3062	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.997196	 0.0	 1	 -30.0	 30.0;
	8936	 3063	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.021523	 0.0	 1	 -30.0	 30.0;
	8936	 5660	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.021523	 0.0	 1	 -30.0	 30.0;
	6522	 10195	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.00739	 0.0	 1	 -30.0	 30.0;
	6522	 10194	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.00739	 0.0	 1	 -30.0	 30.0;
	7527	 2440	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.029311	 0.0	 1	 -30.0	 30.0;
	7527	 10192	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.029311	 0.0	 1	 -30.0	 30.0;
	3081	 10198	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.00963	 0.0	 1	 -30.0	 30.0;
	3081	 10197	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.00963	 0.0	 1	 -30.0	 30.0;
	10271	 7628	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.004824	 0.0	 1	 -30.0	 30.0;
	10271	 8017	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.004824	 0.0	 1	 -30.0	 30.0;
	10271	 8021	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.004824	 0.0	 1	 -30.0	 30.0;
	10271	 8022	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.004824	 0.0	 1	 -30.0	 30.0;
	10271	 104	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.004824	 0.0	 1	 -30.0	 30.0;
	2602	 4572	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.00443	 0.0	 1	 -30.0	 30.0;
	2602	 11633	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.00443	 0.0	 1	 -30.0	 30.0;
	11961	 11632	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.010587	 0.0	 1	 -30.0	 30.0;
	11961	 11635	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.010587	 0.0	 1	 -30.0	 30.0;
	3731	 11634	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.010696	 0.0	 1	 -30.0	 30.0;
	3731	 11631	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.010696	 0.0	 1	 -30.0	 30.0;
	10850	 7672	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.002271	 0.0	 1	 -30.0	 30.0;
	10850	 7671	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.002271	 0.0	 1	 -30.0	 30.0;
	10850	 7670	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.002271	 0.0	 1	 -30.0	 30.0;
	3452	 7676	 0.002119	 0.084719	 0.0	 373	 373	 373	 0.996445	 0.0	 1	 -30.0	 30.0;
	3452	 7675	 0.002119	 0.084719	 0.0	 373	 373	 373	 0.996445	 0.0	 1	 -30.0	 30.0;
	23	 11979	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.006948	 0.0	 1	 -30.0	 30.0;
	23	 11978	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.006948	 0.0	 1	 -30.0	 30.0;
	23	 3904	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.006948	 0.0	 1	 -30.0	 30.0;
	23	 11980	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.006948	 0.0	 1	 -30.0	 30.0;
	23	 3914	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.006948	 0.0	 1	 -30.0	 30.0;
	5257	 4047	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.008334	 0.0	 1	 -30.0	 30.0;
	8044	 11325	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.00304	 0.0	 1	 -30.0	 30.0;
	8044	 4049	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.00304	 0.0	 1	 -30.0	 30.0;
	12457	 4043	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.004713	 0.0	 1	 -30.0	 30.0;
	12457	 4044	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.004713	 0.0	 1	 -30.0	 30.0;
	13600	 8444	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.011145	 0.0	 1	 -30.0	 30.0;
	13600	 8151	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.011145	 0.0	 1	 -30.0	 30.0;
	13600	 8154	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.011145	 0.0	 1	 -30.0	 30.0;
	7069	 8153	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.010552	 0.0	 1	 -30.0	 30.0;
	7069	 8148	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.010552	 0.0	 1	 -30.0	 30.0;
	7069	 8147	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.010552	 0.0	 1	 -30.0	 30.0;
	3744	 1534	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.010912	 0.0	 1	 -30.0	 30.0;
	3744	 8149	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.010912	 0.0	 1	 -30.0	 30.0;
	3744	 8146	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.010912	 0.0	 1	 -30.0	 30.0;
	10354	 8145	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.022406	 0.0	 1	 -30.0	 30.0;
	10354	 1586	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.022406	 0.0	 1	 -30.0	 30.0;
	10354	 1587	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.022406	 0.0	 1	 -30.0	 30.0;
	6971	 10476	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.018442	 0.0	 1	 -30.0	 30.0;
	6971	 10475	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.018442	 0.0	 1	 -30.0	 30.0;
	6971	 10474	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.018442	 0.0	 1	 -30.0	 30.0;
	6971	 8665	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.018442	 0.0	 1	 -30.0	 30.0;
	6971	 10472	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.018442	 0.0	 1	 -30.0	 30.0;
	6971	 8658	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.018442	 0.0	 1	 -30.0	 30.0;
	5773	 10480	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.023459	 0.0	 1	 -30.0	 30.0;
	5773	 10479	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.023459	 0.0	 1	 -30.0	 30.0;
	5773	 3365	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.023459	 0.0	 1	 -30.0	 30.0;
	5773	 3366	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.023459	 0.0	 1	 -30.0	 30.0;
	5773	 3367	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.023459	 0.0	 1	 -30.0	 30.0;
	5773	 3368	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.023459	 0.0	 1	 -30.0	 30.0;
	238	 8604	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.010933	 0.0	 1	 -30.0	 30.0;
	238	 8610	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.010933	 0.0	 1	 -30.0	 30.0;
	238	 8609	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.010933	 0.0	 1	 -30.0	 30.0;
	9397	 9232	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.033253	 0.0	 1	 -30.0	 30.0;
	9397	 9233	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.033253	 0.0	 1	 -30.0	 30.0;
	9397	 9230	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.033253	 0.0	 1	 -30.0	 30.0;
	9397	 9231	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.033253	 0.0	 1	 -30.0	 30.0;
	9397	 9228	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.033253	 0.0	 1	 -30.0	 30.0;
	9397	 9229	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.033253	 0.0	 1	 -30.0	 30.0;
	8077	 11924	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.023147	 0.0	 1	 -30.0	 30.0;
	8077	 12758	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.023147	 0.0	 1	 -30.0	 30.0;
	8077	 9237	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.023147	 0.0	 1	 -30.0	 30.0;
	8077	 1335	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.023147	 0.0	 1	 -30.0	 30.0;
	8077	 2651	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.023147	 0.0	 1	 -30.0	 30.0;
	8077	 2650	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.023147	 0.0	 1	 -30.0	 30.0;
	9397	 2653	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.033007	 0.0	 1	 -30.0	 30.0;
	9397	 2652	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.033007	 0.0	 1	 -30.0	 30.0;
	9397	 2655	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.033007	 0.0	 1	 -30.0	 30.0;
	9397	 2654	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.033007	 0.0	 1	 -30.0	 30.0;
	9397	 2657	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.033007	 0.0	 1	 -30.0	 30.0;
	9397	 2656	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.033007	 0.0	 1	 -30.0	 30.0;
	2453	 3611	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.026628	 0.0	 1	 -30.0	 30.0;
	2453	 3610	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.026628	 0.0	 1	 -30.0	 30.0;
	2453	 10764	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.026628	 0.0	 1	 -30.0	 30.0;
	3732	 10765	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.021183	 0.0	 1	 -30.0	 30.0;
	3732	 10762	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.021183	 0.0	 1	 -30.0	 30.0;
	3732	 10763	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.021183	 0.0	 1	 -30.0	 30.0;
	2728	 8731	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.016872	 0.0	 1	 -30.0	 30.0;
	2728	 8732	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.016872	 0.0	 1	 -30.0	 30.0;
	2728	 8733	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.016872	 0.0	 1	 -30.0	 30.0;
	2728	 8734	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.016872	 0.0	 1	 -30.0	 30.0;
	2728	 8735	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.016872	 0.0	 1	 -30.0	 30.0;
	10026	 7228	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.009461	 0.0	 1	 -30.0	 30.0;
	10026	 243	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.009461	 0.0	 1	 -30.0	 30.0;
	10149	 8904	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.006052	 0.0	 1	 -30.0	 30.0;
	10149	 8905	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.006052	 0.0	 1	 -30.0	 30.0;
	10149	 3631	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.006052	 0.0	 1	 -30.0	 30.0;
	10149	 8907	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.006052	 0.0	 1	 -30.0	 30.0;
	31	 8908	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.009987	 0.0	 1	 -30.0	 30.0;
	31	 8909	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.009987	 0.0	 1	 -30.0	 30.0;
	31	 8910	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.009987	 0.0	 1	 -30.0	 30.0;
	31	 8897	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.009987	 0.0	 1	 -30.0	 30.0;
	9736	 8898	 0.002119	 0.084719	 0.0	 373	 373	 373	 0.996492	 0.0	 1	 -30.0	 30.0;
	7609	 3729	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.008807	 0.0	 1	 -30.0	 30.0;
	7609	 3728	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.008807	 0.0	 1	 -30.0	 30.0;
	7869	 12461	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.009947	 0.0	 1	 -30.0	 30.0;
	7869	 12462	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.009947	 0.0	 1	 -30.0	 30.0;
	7869	 12466	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.009947	 0.0	 1	 -30.0	 30.0;
	7869	 12467	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.009947	 0.0	 1	 -30.0	 30.0;
	7869	 12464	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.009947	 0.0	 1	 -30.0	 30.0;
	638	 12465	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.008334	 0.0	 1	 -30.0	 30.0;
	638	 12469	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.008334	 0.0	 1	 -30.0	 30.0;
	638	 12470	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.008334	 0.0	 1	 -30.0	 30.0;
	638	 5901	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.008334	 0.0	 1	 -30.0	 30.0;
	638	 5900	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.008334	 0.0	 1	 -30.0	 30.0;
	11573	 8173	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.00834	 0.0	 1	 -30.0	 30.0;
	11573	 5902	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.00834	 0.0	 1	 -30.0	 30.0;
	11573	 5898	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.00834	 0.0	 1	 -30.0	 30.0;
	11573	 5897	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.00834	 0.0	 1	 -30.0	 30.0;
	11573	 8162	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.00834	 0.0	 1	 -30.0	 30.0;
	7161	 10329	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.021478	 0.0	 1	 -30.0	 30.0;
	7161	 10324	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.021478	 0.0	 1	 -30.0	 30.0;
	7161	 1801	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.021478	 0.0	 1	 -30.0	 30.0;
	7161	 9761	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.021581	 0.0	 1	 -30.0	 30.0;
	7161	 9762	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.021581	 0.0	 1	 -30.0	 30.0;
	7161	 9763	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.021581	 0.0	 1	 -30.0	 30.0;
	7161	 9764	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.021581	 0.0	 1	 -30.0	 30.0;
	7161	 9757	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.021581	 0.0	 1	 -30.0	 30.0;
	7161	 9758	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.021581	 0.0	 1	 -30.0	 30.0;
	5515	 9759	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.020404	 0.0	 1	 -30.0	 30.0;
	5515	 4145	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.020404	 0.0	 1	 -30.0	 30.0;
	5515	 9754	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.020404	 0.0	 1	 -30.0	 30.0;
	5515	 4470	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.020404	 0.0	 1	 -30.0	 30.0;
	5515	 3122	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.020404	 0.0	 1	 -30.0	 30.0;
	5515	 3121	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.020404	 0.0	 1	 -30.0	 30.0;
	5479	 9856	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.010153	 0.0	 1	 -30.0	 30.0;
	582	 4376	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.037212	 0.0	 1	 -30.0	 30.0;
	582	 4379	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.037212	 0.0	 1	 -30.0	 30.0;
	582	 4380	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.037212	 0.0	 1	 -30.0	 30.0;
	582	 4378	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.037212	 0.0	 1	 -30.0	 30.0;
	582	 3095	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.038292	 0.0	 1	 -30.0	 30.0;
	582	 3098	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.038292	 0.0	 1	 -30.0	 30.0;
	582	 3097	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.038292	 0.0	 1	 -30.0	 30.0;
	6850	 9550	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.037103	 0.0	 1	 -30.0	 30.0;
	6850	 9551	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.037103	 0.0	 1	 -30.0	 30.0;
	6850	 3145	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.037103	 0.0	 1	 -30.0	 30.0;
	6850	 9549	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.037103	 0.0	 1	 -30.0	 30.0;
	6850	 9547	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.037103	 0.0	 1	 -30.0	 30.0;
	2716	 4751	 0.002119	 0.084719	 0.0	 448	 448	 448	 1.037889	 0.0	 1	 -30.0	 30.0;
	2716	 1458	 0.002119	 0.084719	 0.0	 448	 448	 448	 1.037889	 0.0	 1	 -30.0	 30.0;
	2716	 4753	 0.002119	 0.084719	 0.0	 448	 448	 448	 1.037889	 0.0	 1	 -30.0	 30.0;
	2716	 1427	 0.002119	 0.084719	 0.0	 448	 448	 448	 1.037889	 0.0	 1	 -30.0	 30.0;
	2716	 4745	 0.002119	 0.084719	 0.0	 448	 448	 448	 1.035865	 0.0	 1	 -30.0	 30.0;
	2716	 11307	 0.002119	 0.084719	 0.0	 448	 448	 448	 1.035865	 0.0	 1	 -30.0	 30.0;
	13230	 11308	 0.002119	 0.084719	 0.0	 448	 448	 448	 1.037898	 0.0	 1	 -30.0	 30.0;
	3921	 11305	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.018989	 0.0	 1	 -30.0	 30.0;
	3921	 849	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.018989	 0.0	 1	 -30.0	 30.0;
	3921	 107	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.018989	 0.0	 1	 -30.0	 30.0;
	9450	 110	 0.002119	 0.084719	 0.0	 448	 448	 448	 1.032859	 0.0	 1	 -30.0	 30.0;
	6840	 11032	 0.000212	 0.008494	 0.0	 3718	 3718	 3718	 1.041634	 0.0	 1	 -30.0	 30.0;
	6840	 12173	 0.000212	 0.008494	 0.0	 3718	 3718	 3718	 1.041634	 0.0	 1	 -30.0	 30.0;
	748	 11312	 0.002119	 0.084719	 0.0	 448	 448	 448	 1.035018	 0.0	 1	 -30.0	 30.0;
	748	 136	 0.002119	 0.084719	 0.0	 448	 448	 448	 1.035018	 0.0	 1	 -30.0	 30.0;
	4092	 10775	 0.002119	 0.084719	 0.0	 448	 448	 448	 1.033659	 0.0	 1	 -30.0	 30.0;
	4092	 3800	 0.002119	 0.084719	 0.0	 448	 448	 448	 1.033659	 0.0	 1	 -30.0	 30.0;
	11254	 1183	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.030671	 0.0	 1	 -30.0	 30.0;
	11254	 1182	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.030671	 0.0	 1	 -30.0	 30.0;
	7543	 11367	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.036532	 0.0	 1	 -30.0	 30.0;
	7543	 11368	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.036532	 0.0	 1	 -30.0	 30.0;
	7543	 11369	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.036532	 0.0	 1	 -30.0	 30.0;
	7543	 11370	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.036532	 0.0	 1	 -30.0	 30.0;
	7543	 11364	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.036532	 0.0	 1	 -30.0	 30.0;
	7543	 5868	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.036532	 0.0	 1	 -30.0	 30.0;
	7543	 4814	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.036532	 0.0	 1	 -30.0	 30.0;
	10219	 8994	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.028791	 0.0	 1	 -30.0	 30.0;
	10219	 10913	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.028791	 0.0	 1	 -30.0	 30.0;
	645	 3671	 0.002119	 0.084719	 0.0	 448	 448	 448	 1.041775	 0.0	 1	 -30.0	 30.0;
	645	 3672	 0.002119	 0.084719	 0.0	 448	 448	 448	 1.041775	 0.0	 1	 -30.0	 30.0;
	4520	 4811	 0.002119	 0.084719	 0.0	 448	 448	 448	 1.037384	 0.0	 1	 -30.0	 30.0;
	4520	 4810	 0.002119	 0.084719	 0.0	 448	 448	 448	 1.037384	 0.0	 1	 -30.0	 30.0;
	4520	 4809	 0.002119	 0.084719	 0.0	 448	 448	 448	 1.037384	 0.0	 1	 -30.0	 30.0;
	4520	 1772	 0.002119	 0.084719	 0.0	 448	 448	 448	 1.037384	 0.0	 1	 -30.0	 30.0;
	4520	 1770	 0.002119	 0.084719	 0.0	 448	 448	 448	 1.037384	 0.0	 1	 -30.0	 30.0;
	4520	 11849	 0.002119	 0.084719	 0.0	 448	 448	 448	 1.037384	 0.0	 1	 -30.0	 30.0;
	645	 11233	 0.002119	 0.084719	 0.0	 448	 448	 448	 1.039417	 0.0	 1	 -30.0	 30.0;
	645	 11236	 0.002119	 0.084719	 0.0	 448	 448	 448	 1.039417	 0.0	 1	 -30.0	 30.0;
	6772	 11235	 0.002119	 0.084719	 0.0	 448	 448	 448	 1.044613	 0.0	 1	 -30.0	 30.0;
	6772	 11238	 0.002119	 0.084719	 0.0	 448	 448	 448	 1.044613	 0.0	 1	 -30.0	 30.0;
	2021	 13383	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.026432	 0.0	 1	 -30.0	 30.0;
	2021	 11240	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.026432	 0.0	 1	 -30.0	 30.0;
	2021	 3217	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.026432	 0.0	 1	 -30.0	 30.0;
	2021	 11242	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.026432	 0.0	 1	 -30.0	 30.0;
	2021	 11241	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.026432	 0.0	 1	 -30.0	 30.0;
	5521	 4163	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.01824	 0.0	 1	 -30.0	 30.0;
	5521	 4164	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.01824	 0.0	 1	 -30.0	 30.0;
	11659	 4161	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.029319	 0.0	 1	 -30.0	 30.0;
	11659	 10442	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.029319	 0.0	 1	 -30.0	 30.0;
	11659	 4159	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.029319	 0.0	 1	 -30.0	 30.0;
	9680	 4160	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.021461	 0.0	 1	 -30.0	 30.0;
	9680	 4157	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.021461	 0.0	 1	 -30.0	 30.0;
	9680	 4158	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.021461	 0.0	 1	 -30.0	 30.0;
	712	 4155	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.025918	 0.0	 1	 -30.0	 30.0;
	712	 4156	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.025918	 0.0	 1	 -30.0	 30.0;
	712	 2482	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.025918	 0.0	 1	 -30.0	 30.0;
	6457	 2435	 0.002119	 0.084719	 0.0	 448	 448	 448	 1.040032	 0.0	 1	 -30.0	 30.0;
	6457	 2436	 0.002119	 0.084719	 0.0	 448	 448	 448	 1.040032	 0.0	 1	 -30.0	 30.0;
	6457	 2437	 0.002119	 0.084719	 0.0	 448	 448	 448	 1.040032	 0.0	 1	 -30.0	 30.0;
	6457	 2438	 0.002119	 0.084719	 0.0	 448	 448	 448	 1.040032	 0.0	 1	 -30.0	 30.0;
	6457	 2439	 0.002119	 0.084719	 0.0	 448	 448	 448	 1.040032	 0.0	 1	 -30.0	 30.0;
	1393	 9585	 0.000212	 0.008494	 0.0	 4466	 4466	 4466	 1.030552	 0.0	 1	 -30.0	 30.0;
	1393	 9584	 0.000212	 0.008494	 0.0	 4466	 4466	 4466	 1.030552	 0.0	 1	 -30.0	 30.0;
	6128	 9579	 0.000212	 0.008494	 0.0	 4466	 4466	 4466	 1.036319	 0.0	 1	 -30.0	 30.0;
	6128	 154	 0.000212	 0.008494	 0.0	 4466	 4466	 4466	 1.036319	 0.0	 1	 -30.0	 30.0;
	8715	 2480	 0.000212	 0.008494	 0.0	 4466	 4466	 4466	 1.055969	 0.0	 1	 -30.0	 30.0;
	8715	 2481	 0.000212	 0.008494	 0.0	 4466	 4466	 4466	 1.055969	 0.0	 1	 -30.0	 30.0;
	10099	 4679	 0.002119	 0.084719	 0.0	 448	 448	 448	 1.039927	 0.0	 1	 -30.0	 30.0;
	10099	 4680	 0.002119	 0.084719	 0.0	 448	 448	 448	 1.039927	 0.0	 1	 -30.0	 30.0;
	13256	 4676	 0.002119	 0.084719	 0.0	 448	 448	 448	 1.037329	 0.0	 1	 -30.0	 30.0;
	13256	 4677	 0.002119	 0.084719	 0.0	 448	 448	 448	 1.037329	 0.0	 1	 -30.0	 30.0;
	13256	 4678	 0.002119	 0.084719	 0.0	 448	 448	 448	 1.037329	 0.0	 1	 -30.0	 30.0;
	10502	 8668	 0.005208	 0.208268	 0.0	 183	 183	 183	 1.0373	 0.0	 1	 -30.0	 30.0;
	10502	 8671	 0.005208	 0.208268	 0.0	 183	 183	 183	 1.0373	 0.0	 1	 -30.0	 30.0;
	9319	 4683	 0.002119	 0.084719	 0.0	 448	 448	 448	 1.03731	 0.0	 1	 -30.0	 30.0;
	9319	 12279	 0.002119	 0.084719	 0.0	 448	 448	 448	 1.03731	 0.0	 1	 -30.0	 30.0;
	9319	 12278	 0.002119	 0.084719	 0.0	 448	 448	 448	 1.03731	 0.0	 1	 -30.0	 30.0;
	9319	 12281	 0.002119	 0.084719	 0.0	 448	 448	 448	 1.03731	 0.0	 1	 -30.0	 30.0;
	2684	 12280	 0.002119	 0.084719	 0.0	 448	 448	 448	 1.037203	 0.0	 1	 -30.0	 30.0;
	2684	 12276	 0.002119	 0.084719	 0.0	 448	 448	 448	 1.037203	 0.0	 1	 -30.0	 30.0;
	2684	 12275	 0.002119	 0.084719	 0.0	 448	 448	 448	 1.037203	 0.0	 1	 -30.0	 30.0;
	6458	 2372	 0.002119	 0.084719	 0.0	 448	 448	 448	 1.037602	 0.0	 1	 -30.0	 30.0;
	6458	 2373	 0.002119	 0.084719	 0.0	 448	 448	 448	 1.037602	 0.0	 1	 -30.0	 30.0;
	6458	 9467	 0.002119	 0.084719	 0.0	 448	 448	 448	 1.037602	 0.0	 1	 -30.0	 30.0;
	6458	 2377	 0.002119	 0.084719	 0.0	 448	 448	 448	 1.037602	 0.0	 1	 -30.0	 30.0;
	6458	 9486	 0.002119	 0.084719	 0.0	 448	 448	 448	 1.037602	 0.0	 1	 -30.0	 30.0;
	853	 4284	 0.002119	 0.084719	 0.0	 448	 448	 448	 1.038861	 0.0	 1	 -30.0	 30.0;
	853	 4286	 0.002119	 0.084719	 0.0	 448	 448	 448	 1.038861	 0.0	 1	 -30.0	 30.0;
	853	 4285	 0.002119	 0.084719	 0.0	 448	 448	 448	 1.038861	 0.0	 1	 -30.0	 30.0;
	853	 4288	 0.002119	 0.084719	 0.0	 448	 448	 448	 1.038861	 0.0	 1	 -30.0	 30.0;
	853	 4287	 0.002119	 0.084719	 0.0	 448	 448	 448	 1.038861	 0.0	 1	 -30.0	 30.0;
	853	 4290	 0.002119	 0.084719	 0.0	 448	 448	 448	 1.038861	 0.0	 1	 -30.0	 30.0;
	6056	 5246	 0.002119	 0.084719	 0.0	 373	 373	 373	 0.99378	 0.0	 1	 -30.0	 30.0;
	6056	 5242	 0.002119	 0.084719	 0.0	 373	 373	 373	 0.99378	 0.0	 1	 -30.0	 30.0;
	6056	 4242	 0.002119	 0.084719	 0.0	 373	 373	 373	 0.99378	 0.0	 1	 -30.0	 30.0;
	1759	 8552	 0.002119	 0.084719	 0.0	 448	 448	 448	 1.033959	 0.0	 1	 -30.0	 30.0;
	6595	 7498	 0.002119	 0.084719	 0.0	 448	 448	 448	 1.036996	 0.0	 1	 -30.0	 30.0;
	6595	 12803	 0.002119	 0.084719	 0.0	 448	 448	 448	 1.036996	 0.0	 1	 -30.0	 30.0;
	4615	 12802	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.016167	 0.0	 1	 -30.0	 30.0;
	284	 12808	 0.002119	 0.084719	 0.0	 448	 448	 448	 1.039078	 0.0	 1	 -30.0	 30.0;
	284	 12807	 0.002119	 0.084719	 0.0	 448	 448	 448	 1.039078	 0.0	 1	 -30.0	 30.0;
	284	 12806	 0.002119	 0.084719	 0.0	 448	 448	 448	 1.039078	 0.0	 1	 -30.0	 30.0;
	13593	 5498	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.015062	 0.0	 1	 -30.0	 30.0;
	13593	 12930	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.015062	 0.0	 1	 -30.0	 30.0;
	2445	 12929	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.003218	 0.0	 1	 -30.0	 30.0;
	2445	 5847	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.003218	 0.0	 1	 -30.0	 30.0;
	11518	 5728	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.036278	 0.0	 1	 -30.0	 30.0;
	11518	 5729	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.036278	 0.0	 1	 -30.0	 30.0;
	11518	 5730	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.036278	 0.0	 1	 -30.0	 30.0;
	11518	 5731	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.036278	 0.0	 1	 -30.0	 30.0;
	12899	 5732	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.030166	 0.0	 1	 -30.0	 30.0;
	7516	 13379	 0.000494	 0.019737	 0.0	 1600	 1600	 1600	 1.031642	 0.0	 1	 -30.0	 30.0;
	7516	 13377	 0.000494	 0.019737	 0.0	 1600	 1600	 1600	 1.021069	 0.0	 1	 -30.0	 30.0;
	7516	 11246	 0.000494	 0.019737	 0.0	 1600	 1600	 1600	 1.021069	 0.0	 1	 -30.0	 30.0;
	1032	 6918	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.00548	 0.0	 1	 -30.0	 30.0;
	1032	 12833	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.00548	 0.0	 1	 -30.0	 30.0;
	8878	 8116	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.018667	 0.0	 1	 -30.0	 30.0;
	8878	 8113	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.018667	 0.0	 1	 -30.0	 30.0;
	13384	 8114	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.008951	 0.0	 1	 -30.0	 30.0;
	13384	 8111	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.008951	 0.0	 1	 -30.0	 30.0;
	1854	 8112	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.008541	 0.0	 1	 -30.0	 30.0;
	1854	 8110	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.008541	 0.0	 1	 -30.0	 30.0;
	8187	 8317	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.015278	 0.0	 1	 -30.0	 30.0;
	8187	 8319	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.015278	 0.0	 1	 -30.0	 30.0;
	8187	 8320	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.015278	 0.0	 1	 -30.0	 30.0;
	5588	 2119	 0.000212	 0.008494	 0.0	 4466	 4466	 4466	 1.037334	 0.0	 1	 -30.0	 30.0;
	12621	 6227	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 0.988424	 0.0	 1	 -30.0	 30.0;
	10332	 7814	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.012948	 0.0	 1	 -30.0	 30.0;
	10398	 1556	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.025893	 0.0	 1	 -30.0	 30.0;
	10398	 1558	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.025893	 0.0	 1	 -30.0	 30.0;
	10398	 1557	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.025893	 0.0	 1	 -30.0	 30.0;
	5767	 6226	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.015251	 0.0	 1	 -30.0	 30.0;
	2967	 5510	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.012008	 0.0	 1	 -30.0	 30.0;
	2967	 5514	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.012008	 0.0	 1	 -30.0	 30.0;
	1197	 1560	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.010751	 0.0	 1	 -30.0	 30.0;
	1197	 7636	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.010751	 0.0	 1	 -30.0	 30.0;
	1197	 7637	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.010751	 0.0	 1	 -30.0	 30.0;
	5945	 12255	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.01432	 0.0	 1	 -30.0	 30.0;
	8520	 5640	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.009467	 0.0	 1	 -30.0	 30.0;
	8520	 5084	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.009467	 0.0	 1	 -30.0	 30.0;
	7273	 4245	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.009457	 0.0	 1	 -30.0	 30.0;
	7273	 12252	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.009457	 0.0	 1	 -30.0	 30.0;
	2221	 4274	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.009453	 0.0	 1	 -30.0	 30.0;
	2221	 5654	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.009453	 0.0	 1	 -30.0	 30.0;
	1035	 12259	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.009453	 0.0	 1	 -30.0	 30.0;
	1035	 5708	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.009453	 0.0	 1	 -30.0	 30.0;
	13619	 5707	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.024548	 0.0	 1	 -30.0	 30.0;
	13619	 5706	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.024548	 0.0	 1	 -30.0	 30.0;
	4951	 1089	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.995167	 0.0	 1	 -30.0	 30.0;
	4951	 1093	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.995167	 0.0	 1	 -30.0	 30.0;
	4951	 1092	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.995167	 0.0	 1	 -30.0	 30.0;
	10569	 5705	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.030285	 0.0	 1	 -30.0	 30.0;
	7880	 5704	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.030279	 0.0	 1	 -30.0	 30.0;
	11998	 6039	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.026775	 0.0	 1	 -30.0	 30.0;
	11998	 6040	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.026775	 0.0	 1	 -30.0	 30.0;
	1729	 2186	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.030363	 0.0	 1	 -30.0	 30.0;
	5749	 7736	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.037534	 0.0	 1	 -30.0	 30.0;
	5997	 1914	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.000306	 0.0	 1	 -30.0	 30.0;
	5997	 1913	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.000306	 0.0	 1	 -30.0	 30.0;
	4280	 9655	 0.000212	 0.008494	 0.0	 4466	 4466	 4466	 1.059014	 0.0	 1	 -30.0	 30.0;
	1634	 9656	 0.000212	 0.008494	 0.0	 4466	 4466	 4466	 1.059006	 0.0	 1	 -30.0	 30.0;
	2938	 9106	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.998143	 0.0	 1	 -30.0	 30.0;
	2938	 9107	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.998143	 0.0	 1	 -30.0	 30.0;
	2938	 9102	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.998143	 0.0	 1	 -30.0	 30.0;
	6463	 6409	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.033803	 0.0	 1	 -30.0	 30.0;
	2293	 5223	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.033762	 0.0	 1	 -30.0	 30.0;
	4802	 846	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.026335	 0.0	 1	 -30.0	 30.0;
	4802	 845	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.026335	 0.0	 1	 -30.0	 30.0;
	4802	 844	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.026335	 0.0	 1	 -30.0	 30.0;
	3374	 2489	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.006944	 0.0	 1	 -30.0	 30.0;
	3374	 2488	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.006944	 0.0	 1	 -30.0	 30.0;
	7738	 8773	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 0.991514	 0.0	 1	 -30.0	 30.0;
	9318	 2490	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.995022	 0.0	 1	 -30.0	 30.0;
	9318	 2487	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.995022	 0.0	 1	 -30.0	 30.0;
	9318	 2486	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.995022	 0.0	 1	 -30.0	 30.0;
	9318	 8576	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.995022	 0.0	 1	 -30.0	 30.0;
	5288	 8577	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.994181	 0.0	 1	 -30.0	 30.0;
	5288	 8578	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.994181	 0.0	 1	 -30.0	 30.0;
	759	 12814	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.005303	 0.0	 1	 -30.0	 30.0;
	759	 12072	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.005303	 0.0	 1	 -30.0	 30.0;
	11688	 1735	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.007359	 0.0	 1	 -30.0	 30.0;
	11688	 1734	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.007359	 0.0	 1	 -30.0	 30.0;
	10391	 13592	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 0.993134	 0.0	 1	 -30.0	 30.0;
	4306	 8581	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.002991	 0.0	 1	 -30.0	 30.0;
	4306	 8582	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.002991	 0.0	 1	 -30.0	 30.0;
	4306	 2006	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.002991	 0.0	 1	 -30.0	 30.0;
	4872	 2005	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.985964	 0.0	 1	 -30.0	 30.0;
	4872	 2004	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.985964	 0.0	 1	 -30.0	 30.0;
	4872	 2003	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.985964	 0.0	 1	 -30.0	 30.0;
	6154	 12855	 0.000212	 0.008494	 0.0	 3718	 3718	 3718	 1.049418	 0.0	 1	 -30.0	 30.0;
	3721	 2001	 0.005208	 0.208268	 0.0	 152	 152	 152	 0.991543	 0.0	 1	 -30.0	 30.0;
	8574	 2000	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.026313	 0.0	 1	 -30.0	 30.0;
	8574	 1999	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.026313	 0.0	 1	 -30.0	 30.0;
	8574	 2011	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.026313	 0.0	 1	 -30.0	 30.0;
	5211	 4710	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.000644	 0.0	 1	 -30.0	 30.0;
	553	 5858	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.027095	 0.0	 1	 -30.0	 30.0;
	553	 5856	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.027095	 0.0	 1	 -30.0	 30.0;
	4921	 1050	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 0.996774	 0.0	 1	 -30.0	 30.0;
	8266	 9818	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.013246	 0.0	 1	 -30.0	 30.0;
	4842	 3913	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.012283	 0.0	 1	 -30.0	 30.0;
	1201	 4240	 0.003098	 0.123877	 0.0	 255	 255	 255	 1.010818	 0.0	 1	 -30.0	 30.0;
	1201	 4239	 0.003098	 0.123877	 0.0	 255	 255	 255	 1.005111	 0.0	 1	 -30.0	 30.0;
	1212	 10453	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.003133	 0.0	 1	 -30.0	 30.0;
	3364	 3903	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.009261	 0.0	 1	 -30.0	 30.0;
	6517	 4234	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.008214	 0.0	 1	 -30.0	 30.0;
	6517	 11806	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.008214	 0.0	 1	 -30.0	 30.0;
	7530	 11886	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.007633	 0.0	 1	 -30.0	 30.0;
	6209	 6420	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.010568	 0.0	 1	 -30.0	 30.0;
	8699	 7338	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.024425	 0.0	 1	 -30.0	 30.0;
	4567	 1218	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.01045	 0.0	 1	 -30.0	 30.0;
	4333	 6421	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.010834	 0.0	 1	 -30.0	 30.0;
	5655	 4162	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.004714	 0.0	 1	 -30.0	 30.0;
	9664	 9074	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.012149	 0.0	 1	 -30.0	 30.0;
	11245	 4152	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.001089	 0.0	 1	 -30.0	 30.0;
	4075	 4151	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.014373	 0.0	 1	 -30.0	 30.0;
	12719	 10362	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.007634	 0.0	 1	 -30.0	 30.0;
	8690	 5406	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.01045	 0.0	 1	 -30.0	 30.0;
	13381	 5245	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.009766	 0.0	 1	 -30.0	 30.0;
	3156	 8740	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.019589	 0.0	 1	 -30.0	 30.0;
	6425	 8741	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.014377	 0.0	 1	 -30.0	 30.0;
	10931	 873	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.01008	 0.0	 1	 -30.0	 30.0;
	9500	 1995	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.014292	 0.0	 1	 -30.0	 30.0;
	3813	 5411	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.009591	 0.0	 1	 -30.0	 30.0;
	327	 10287	 0.007184	 0.287267	 0.0	 110	 110	 110	 1.014694	 0.0	 1	 -30.0	 30.0;
	8557	 5243	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.017021	 0.0	 1	 -30.0	 30.0;
	3690	 2307	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.007694	 0.0	 1	 -30.0	 30.0;
	5502	 7377	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.009279	 0.0	 1	 -30.0	 30.0;
	10128	 3853	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.011716	 0.0	 1	 -30.0	 30.0;
	11904	 12	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.023676	 0.0	 1	 -30.0	 30.0;
	7692	 8451	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.00974	 0.0	 1	 -30.0	 30.0;
	1962	 13655	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.006172	 0.0	 1	 -30.0	 30.0;
	8737	 11889	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.044306	 0.0	 1	 -30.0	 30.0;
	8737	 1940	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.044306	 0.0	 1	 -30.0	 30.0;
	8737	 11897	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.044306	 0.0	 1	 -30.0	 30.0;
	6151	 11898	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.041635	 0.0	 1	 -30.0	 30.0;
	6151	 4858	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.041635	 0.0	 1	 -30.0	 30.0;
	6151	 4857	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.041635	 0.0	 1	 -30.0	 30.0;
	2887	 4856	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.043948	 0.0	 1	 -30.0	 30.0;
	2887	 4855	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.043948	 0.0	 1	 -30.0	 30.0;
	2493	 4862	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.027024	 0.0	 1	 -30.0	 30.0;
	2493	 4861	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.027024	 0.0	 1	 -30.0	 30.0;
	2493	 2047	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.027024	 0.0	 1	 -30.0	 30.0;
	13140	 4859	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.029372	 0.0	 1	 -30.0	 30.0;
	13140	 4864	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.029372	 0.0	 1	 -30.0	 30.0;
	6366	 10250	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.014233	 0.0	 1	 -30.0	 30.0;
	6366	 6017	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.014233	 0.0	 1	 -30.0	 30.0;
	6366	 3127	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.014233	 0.0	 1	 -30.0	 30.0;
	11839	 11408	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.015667	 0.0	 1	 -30.0	 30.0;
	11839	 11409	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.015667	 0.0	 1	 -30.0	 30.0;
	12513	 11410	 0.002495	 0.099769	 0.0	 317	 317	 317	 1.02086	 0.0	 1	 -30.0	 30.0;
	5478	 3130	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.025981	 0.0	 1	 -30.0	 30.0;
	5478	 3128	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.025981	 0.0	 1	 -30.0	 30.0;
	5478	 6023	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.025981	 0.0	 1	 -30.0	 30.0;
	2699	 3123	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.018288	 0.0	 1	 -30.0	 30.0;
	2699	 3124	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.018288	 0.0	 1	 -30.0	 30.0;
	2699	 11406	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.018288	 0.0	 1	 -30.0	 30.0;
	2699	 8803	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.018288	 0.0	 1	 -30.0	 30.0;
	3693	 6358	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.034253	 0.0	 1	 -30.0	 30.0;
	3693	 6357	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.034253	 0.0	 1	 -30.0	 30.0;
	9988	 6352	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.019154	 0.0	 1	 -30.0	 30.0;
	9988	 6351	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.019154	 0.0	 1	 -30.0	 30.0;
	8968	 6354	 0.000708	 0.02832	 0.0	 1340	 1340	 1340	 1.043867	 0.0	 1	 -30.0	 30.0;
	8968	 6353	 0.000708	 0.02832	 0.0	 1340	 1340	 1340	 1.043867	 0.0	 1	 -30.0	 30.0;
	8968	 6361	 0.000708	 0.02832	 0.0	 1340	 1340	 1340	 1.043867	 0.0	 1	 -30.0	 30.0;
	2553	 6360	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.00932	 0.0	 1	 -30.0	 30.0;
	2553	 12965	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.00932	 0.0	 1	 -30.0	 30.0;
	7099	 9522	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.028812	 0.0	 1	 -30.0	 30.0;
	7099	 9513	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.028812	 0.0	 1	 -30.0	 30.0;
	11165	 9515	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.043848	 0.0	 1	 -30.0	 30.0;
	3044	 12969	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.031212	 0.0	 1	 -30.0	 30.0;
	3044	 12970	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.031212	 0.0	 1	 -30.0	 30.0;
	13244	 9523	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.031102	 0.0	 1	 -30.0	 30.0;
	13244	 9525	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.031102	 0.0	 1	 -30.0	 30.0;
	7412	 1750	 0.000531	 0.021225	 0.0	 1787	 1787	 1787	 1.03605	 0.0	 1	 -30.0	 30.0;
	7412	 1751	 0.000531	 0.021225	 0.0	 1787	 1787	 1787	 1.03605	 0.0	 1	 -30.0	 30.0;
	7412	 9294	 0.000531	 0.021225	 0.0	 1787	 1787	 1787	 1.03605	 0.0	 1	 -30.0	 30.0;
	10651	 5889	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.032862	 0.0	 1	 -30.0	 30.0;
	10651	 9540	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.032862	 0.0	 1	 -30.0	 30.0;
	10651	 5887	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.032862	 0.0	 1	 -30.0	 30.0;
	8758	 8090	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.027152	 0.0	 1	 -30.0	 30.0;
	8758	 8088	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.027152	 0.0	 1	 -30.0	 30.0;
	7000	 5884	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.032522	 0.0	 1	 -30.0	 30.0;
	7000	 5883	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.032522	 0.0	 1	 -30.0	 30.0;
	7000	 5882	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.032522	 0.0	 1	 -30.0	 30.0;
	279	 5881	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.02075	 0.0	 1	 -30.0	 30.0;
	7103	 12452	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.020873	 0.0	 1	 -30.0	 30.0;
	5437	 12453	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.020808	 0.0	 1	 -30.0	 30.0;
	7891	 12454	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.015181	 0.0	 1	 -30.0	 30.0;
	10637	 6726	 0.006494	 0.259659	 0.0	 122	 122	 122	 1.014067	 0.0	 1	 -30.0	 30.0;
	7729	 1546	 0.001384	 0.055323	 0.0	 686	 686	 686	 1.034666	 0.0	 1	 -30.0	 30.0;
	7729	 1545	 0.001384	 0.055323	 0.0	 686	 686	 686	 1.027558	 0.0	 1	 -30.0	 30.0;
	7729	 1544	 0.001384	 0.055323	 0.0	 686	 686	 686	 1.027558	 0.0	 1	 -30.0	 30.0;
	7729	 13056	 0.001384	 0.055323	 0.0	 686	 686	 686	 1.027558	 0.0	 1	 -30.0	 30.0;
	7729	 1537	 0.001384	 0.055323	 0.0	 686	 686	 686	 1.027558	 0.0	 1	 -30.0	 30.0;
	7729	 9979	 0.001384	 0.055323	 0.0	 686	 686	 686	 1.027558	 0.0	 1	 -30.0	 30.0;
	7729	 13124	 0.001384	 0.055323	 0.0	 686	 686	 686	 1.027558	 0.0	 1	 -30.0	 30.0;
	7729	 11463	 0.001384	 0.055323	 0.0	 686	 686	 686	 1.027558	 0.0	 1	 -30.0	 30.0;
	7729	 13099	 0.001384	 0.055323	 0.0	 686	 686	 686	 1.027558	 0.0	 1	 -30.0	 30.0;
	7729	 11461	 0.001384	 0.055323	 0.0	 686	 686	 686	 1.027558	 0.0	 1	 -30.0	 30.0;
	7729	 11464	 0.001384	 0.055323	 0.0	 686	 686	 686	 1.027558	 0.0	 1	 -30.0	 30.0;
	1531	 3344	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.040265	 0.0	 1	 -30.0	 30.0;
	1531	 7137	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.040265	 0.0	 1	 -30.0	 30.0;
	2043	 9602	 0.002747	 0.109856	 0.0	 288	 288	 288	 1.029337	 0.0	 1	 -30.0	 30.0;
	2043	 9606	 0.002747	 0.109856	 0.0	 288	 288	 288	 1.021	 0.0	 1	 -30.0	 30.0;
	2043	 9605	 0.002747	 0.109856	 0.0	 288	 288	 288	 1.021	 0.0	 1	 -30.0	 30.0;
	2043	 2500	 0.002747	 0.109856	 0.0	 288	 288	 288	 1.021	 0.0	 1	 -30.0	 30.0;
	2043	 2501	 0.002747	 0.109856	 0.0	 288	 288	 288	 1.021	 0.0	 1	 -30.0	 30.0;
	2043	 2502	 0.002747	 0.109856	 0.0	 288	 288	 288	 1.021	 0.0	 1	 -30.0	 30.0;
	4109	 5366	 0.005353	 0.214066	 0.0	 148	 148	 148	 1.009344	 0.0	 1	 -30.0	 30.0;
	4109	 4939	 0.005353	 0.214066	 0.0	 148	 148	 148	 1.009344	 0.0	 1	 -30.0	 30.0;
	4109	 5365	 0.005353	 0.214066	 0.0	 148	 148	 148	 1.009344	 0.0	 1	 -30.0	 30.0;
	4109	 5362	 0.005353	 0.214066	 0.0	 148	 148	 148	 1.004456	 0.0	 1	 -30.0	 30.0;
	4109	 13207	 0.005353	 0.214066	 0.0	 148	 148	 148	 1.004456	 0.0	 1	 -30.0	 30.0;
	4109	 5360	 0.005353	 0.214066	 0.0	 148	 148	 148	 1.004456	 0.0	 1	 -30.0	 30.0;
	4109	 5361	 0.005353	 0.214066	 0.0	 148	 148	 148	 1.004456	 0.0	 1	 -30.0	 30.0;
	4109	 11084	 0.005353	 0.214066	 0.0	 148	 148	 148	 1.004456	 0.0	 1	 -30.0	 30.0;
	756	 11085	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.006703	 0.0	 1	 -30.0	 30.0;
	756	 11086	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.006703	 0.0	 1	 -30.0	 30.0;
	756	 11087	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.006703	 0.0	 1	 -30.0	 30.0;
	756	 11088	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.006703	 0.0	 1	 -30.0	 30.0;
	7425	 12646	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.026505	 0.0	 1	 -30.0	 30.0;
	7425	 11090	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.026505	 0.0	 1	 -30.0	 30.0;
	12423	 652	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.02312	 0.0	 1	 -30.0	 30.0;
	12423	 651	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.02312	 0.0	 1	 -30.0	 30.0;
	1646	 5455	 0.001873	 0.074883	 0.0	 422	 422	 422	 1.027046	 0.0	 1	 -30.0	 30.0;
	1646	 12010	 0.001873	 0.074883	 0.0	 422	 422	 422	 1.020907	 0.0	 1	 -30.0	 30.0;
	1646	 12011	 0.001873	 0.074883	 0.0	 422	 422	 422	 1.020907	 0.0	 1	 -30.0	 30.0;
	1646	 12009	 0.001873	 0.074883	 0.0	 422	 422	 422	 1.020907	 0.0	 1	 -30.0	 30.0;
	6181	 433	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.025949	 0.0	 1	 -30.0	 30.0;
	6181	 4537	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.025949	 0.0	 1	 -30.0	 30.0;
	6181	 12709	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.025949	 0.0	 1	 -30.0	 30.0;
	6181	 4535	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.025949	 0.0	 1	 -30.0	 30.0;
	6181	 4534	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.025949	 0.0	 1	 -30.0	 30.0;
	6181	 2286	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.026694	 0.0	 1	 -30.0	 30.0;
	6181	 2287	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.026694	 0.0	 1	 -30.0	 30.0;
	8152	 1813	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.005842	 0.0	 1	 -30.0	 30.0;
	177	 1816	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.025876	 0.0	 1	 -30.0	 30.0;
	5140	 5332	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.025539	 0.0	 1	 -30.0	 30.0;
	5140	 5594	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.025539	 0.0	 1	 -30.0	 30.0;
	5140	 5196	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.025539	 0.0	 1	 -30.0	 30.0;
	4559	 11602	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.02756	 0.0	 1	 -30.0	 30.0;
	4559	 11599	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.02756	 0.0	 1	 -30.0	 30.0;
	4559	 5540	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.02756	 0.0	 1	 -30.0	 30.0;
	2461	 1831	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.024287	 0.0	 1	 -30.0	 30.0;
	2461	 11611	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.024287	 0.0	 1	 -30.0	 30.0;
	2461	 5038	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.024287	 0.0	 1	 -30.0	 30.0;
	249	 5746	 0.006494	 0.259659	 0.0	 122	 122	 122	 1.03136	 0.0	 1	 -30.0	 30.0;
	249	 5748	 0.006494	 0.259659	 0.0	 122	 122	 122	 1.025041	 0.0	 1	 -30.0	 30.0;
	249	 5747	 0.006494	 0.259659	 0.0	 122	 122	 122	 1.025041	 0.0	 1	 -30.0	 30.0;
	13278	 12711	 0.006527	 0.261015	 0.0	 121	 121	 121	 1.002931	 0.0	 1	 -30.0	 30.0;
	13278	 12712	 0.006527	 0.261015	 0.0	 121	 121	 121	 0.996669	 0.0	 1	 -30.0	 30.0;
	10745	 12713	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.019055	 0.0	 1	 -30.0	 30.0;
	1146	 12714	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.007266	 0.0	 1	 -30.0	 30.0;
	1146	 12708	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.007266	 0.0	 1	 -30.0	 30.0;
	1861	 7540	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.009862	 0.0	 1	 -30.0	 30.0;
	664	 5629	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.002399	 0.0	 1	 -30.0	 30.0;
	664	 5628	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.002399	 0.0	 1	 -30.0	 30.0;
	10824	 7262	 0.002096	 0.083796	 0.0	 377	 377	 377	 1.003762	 0.0	 1	 -30.0	 30.0;
	11841	 5630	 0.018939	 0.757339	 0.0	 42	 42	 42	 1.006491	 0.0	 1	 -30.0	 30.0;
	8625	 5632	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.014052	 0.0	 1	 -30.0	 30.0;
	4915	 5631	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.010825	 0.0	 1	 -30.0	 30.0;
	4915	 5634	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.010825	 0.0	 1	 -30.0	 30.0;
	13255	 11757	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.020236	 0.0	 1	 -30.0	 30.0;
	13255	 11756	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.020236	 0.0	 1	 -30.0	 30.0;
	13255	 11755	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.020236	 0.0	 1	 -30.0	 30.0;
	9712	 12193	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.003827	 0.0	 1	 -30.0	 30.0;
	9712	 12194	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.003827	 0.0	 1	 -30.0	 30.0;
	8009	 12191	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.014614	 0.0	 1	 -30.0	 30.0;
	8009	 12192	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.014614	 0.0	 1	 -30.0	 30.0;
	11209	 382	 0.002034	 0.081342	 0.0	 389	 389	 389	 1.006628	 0.0	 1	 -30.0	 30.0;
	11209	 381	 0.002034	 0.081342	 0.0	 389	 389	 389	 1.000622	 0.0	 1	 -30.0	 30.0;
	11209	 384	 0.002034	 0.081342	 0.0	 389	 389	 389	 1.000622	 0.0	 1	 -30.0	 30.0;
	1067	 383	 0.002041	 0.081607	 0.0	 387	 387	 387	 1.007282	 0.0	 1	 -30.0	 30.0;
	1067	 378	 0.002041	 0.081607	 0.0	 387	 387	 387	 1.003092	 0.0	 1	 -30.0	 30.0;
	1067	 377	 0.002041	 0.081607	 0.0	 387	 387	 387	 1.003092	 0.0	 1	 -30.0	 30.0;
	604	 5144	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.010345	 0.0	 1	 -30.0	 30.0;
	3795	 12601	 0.002119	 0.084719	 0.0	 448	 448	 448	 1.033336	 0.0	 1	 -30.0	 30.0;
	3795	 12599	 0.002119	 0.084719	 0.0	 448	 448	 448	 1.033336	 0.0	 1	 -30.0	 30.0;
	3795	 12600	 0.002119	 0.084719	 0.0	 448	 448	 448	 1.033336	 0.0	 1	 -30.0	 30.0;
	4283	 5148	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.01495	 0.0	 1	 -30.0	 30.0;
	9037	 5147	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.0178	 0.0	 1	 -30.0	 30.0;
	9037	 5146	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.0178	 0.0	 1	 -30.0	 30.0;
	9037	 5145	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.0178	 0.0	 1	 -30.0	 30.0;
	1219	 5151	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.009281	 0.0	 1	 -30.0	 30.0;
	1219	 1764	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.009281	 0.0	 1	 -30.0	 30.0;
	1219	 11686	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.009281	 0.0	 1	 -30.0	 30.0;
	13202	 11687	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.002838	 0.0	 1	 -30.0	 30.0;
	2132	 2246	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.002513	 0.0	 1	 -30.0	 30.0;
	2132	 11689	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.002513	 0.0	 1	 -30.0	 30.0;
	2132	 11690	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.002513	 0.0	 1	 -30.0	 30.0;
	2132	 11691	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.002513	 0.0	 1	 -30.0	 30.0;
	2132	 11692	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.002513	 0.0	 1	 -30.0	 30.0;
	2132	 11693	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.002513	 0.0	 1	 -30.0	 30.0;
	10240	 11694	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.017093	 0.0	 1	 -30.0	 30.0;
	10240	 11695	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.017093	 0.0	 1	 -30.0	 30.0;
	10240	 4634	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.017093	 0.0	 1	 -30.0	 30.0;
	10240	 4633	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.017093	 0.0	 1	 -30.0	 30.0;
	10240	 930	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.017093	 0.0	 1	 -30.0	 30.0;
	10240	 4635	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.017093	 0.0	 1	 -30.0	 30.0;
	10240	 4630	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.017093	 0.0	 1	 -30.0	 30.0;
	10240	 912	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.017093	 0.0	 1	 -30.0	 30.0;
	10240	 920	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.017093	 0.0	 1	 -30.0	 30.0;
	10240	 4631	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.017093	 0.0	 1	 -30.0	 30.0;
	10240	 4627	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.017093	 0.0	 1	 -30.0	 30.0;
	10240	 4626	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.017093	 0.0	 1	 -30.0	 30.0;
	10240	 11193	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.017093	 0.0	 1	 -30.0	 30.0;
	10240	 11194	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.017093	 0.0	 1	 -30.0	 30.0;
	10240	 11191	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.017093	 0.0	 1	 -30.0	 30.0;
	10240	 13160	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.017093	 0.0	 1	 -30.0	 30.0;
	10240	 11197	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.017093	 0.0	 1	 -30.0	 30.0;
	10240	 11198	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.017093	 0.0	 1	 -30.0	 30.0;
	10240	 11195	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.017093	 0.0	 1	 -30.0	 30.0;
	10240	 11196	 0.005208	 0.208268	 0.0	 152	 152	 152	 1.017093	 0.0	 1	 -30.0	 30.0;
	10118	 2303	 0.001598	 0.063919	 0.0	 495	 495	 495	 1.006298	 0.0	 1	 -30.0	 30.0;
	8355	 13091	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.007157	 0.0	 1	 -30.0	 30.0;
	8355	 9574	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.007157	 0.0	 1	 -30.0	 30.0;
	8355	 9573	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.007157	 0.0	 1	 -30.0	 30.0;
	7506	 8966	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.012046	 0.0	 1	 -30.0	 30.0;
	7506	 8967	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.012046	 0.0	 1	 -30.0	 30.0;
	7506	 8964	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.012046	 0.0	 1	 -30.0	 30.0;
	7506	 8965	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.012046	 0.0	 1	 -30.0	 30.0;
	2597	 13577	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.004111	 0.0	 1	 -30.0	 30.0;
	2597	 156	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.004111	 0.0	 1	 -30.0	 30.0;
	2597	 162	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.004111	 0.0	 1	 -30.0	 30.0;
	2597	 161	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.004111	 0.0	 1	 -30.0	 30.0;
	2597	 6690	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.004111	 0.0	 1	 -30.0	 30.0;
	7288	 6691	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.004111	 0.0	 1	 -30.0	 30.0;
	7288	 13080	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.004111	 0.0	 1	 -30.0	 30.0;
	7288	 6689	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.004111	 0.0	 1	 -30.0	 30.0;
	7288	 3912	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.004111	 0.0	 1	 -30.0	 30.0;
	7288	 13101	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.004111	 0.0	 1	 -30.0	 30.0;
	9966	 7600	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.00414	 0.0	 1	 -30.0	 30.0;
	9966	 6693	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.00414	 0.0	 1	 -30.0	 30.0;
	9966	 13108	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.00414	 0.0	 1	 -30.0	 30.0;
	9966	 6697	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.00414	 0.0	 1	 -30.0	 30.0;
	9966	 13316	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.00414	 0.0	 1	 -30.0	 30.0;
	12355	 8470	 0.002119	 0.084719	 0.0	 373	 373	 373	 0.982596	 0.0	 1	 -30.0	 30.0;
	12355	 8471	 0.002119	 0.084719	 0.0	 373	 373	 373	 0.982596	 0.0	 1	 -30.0	 30.0;
	12355	 10423	 0.002119	 0.084719	 0.0	 373	 373	 373	 0.982596	 0.0	 1	 -30.0	 30.0;
	12355	 8473	 0.002119	 0.084719	 0.0	 373	 373	 373	 0.982596	 0.0	 1	 -30.0	 30.0;
	12355	 8474	 0.002119	 0.084719	 0.0	 373	 373	 373	 0.982596	 0.0	 1	 -30.0	 30.0;
	8579	 13313	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.010156	 0.0	 1	 -30.0	 30.0;
	8579	 11580	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.010156	 0.0	 1	 -30.0	 30.0;
	8298	 13311	 0.003521	 0.140801	 0.0	 270	 270	 270	 1.03642	 0.0	 1	 -30.0	 30.0;
	9266	 13310	 0.003521	 0.140801	 0.0	 225	 225	 225	 0.999915	 0.0	 1	 -30.0	 30.0;
	9266	 6219	 0.003521	 0.140801	 0.0	 225	 225	 225	 0.999915	 0.0	 1	 -30.0	 30.0;
	8919	 6220	 0.003125	 0.124961	 0.0	 253	 253	 253	 1.00568	 0.0	 1	 -30.0	 30.0;
	8919	 6221	 0.003125	 0.124961	 0.0	 253	 253	 253	 0.999654	 0.0	 1	 -30.0	 30.0;
	8919	 10155	 0.003125	 0.124961	 0.0	 253	 253	 253	 0.999654	 0.0	 1	 -30.0	 30.0;
	6145	 6215	 0.003079	 0.123114	 0.0	 257	 257	 257	 1.006057	 0.0	 1	 -30.0	 30.0;
	6145	 8185	 0.003079	 0.123114	 0.0	 257	 257	 257	 1.00004	 0.0	 1	 -30.0	 30.0;
	6145	 8199	 0.003079	 0.123114	 0.0	 257	 257	 257	 1.00004	 0.0	 1	 -30.0	 30.0;
	6984	 6218	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.01016	 0.0	 1	 -30.0	 30.0;
	6984	 6213	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.01016	 0.0	 1	 -30.0	 30.0;
	4689	 3352	 0.002119	 0.084719	 0.0	 373	 373	 373	 0.995148	 0.0	 1	 -30.0	 30.0;
	4689	 9911	 0.002119	 0.084719	 0.0	 373	 373	 373	 0.995148	 0.0	 1	 -30.0	 30.0;
	4689	 9912	 0.002119	 0.084719	 0.0	 373	 373	 373	 0.995148	 0.0	 1	 -30.0	 30.0;
	4689	 9909	 0.002119	 0.084719	 0.0	 373	 373	 373	 0.995148	 0.0	 1	 -30.0	 30.0;
	12229	 11472	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 0.998196	 0.0	 1	 -30.0	 30.0;
	12229	 11477	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 0.998196	 0.0	 1	 -30.0	 30.0;
	9069	 11478	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 0.998227	 0.0	 1	 -30.0	 30.0;
	9069	 11475	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 0.998227	 0.0	 1	 -30.0	 30.0;
	11671	 1083	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 0.998207	 0.0	 1	 -30.0	 30.0;
	11671	 11479	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 0.998207	 0.0	 1	 -30.0	 30.0;
	2742	 11480	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 0.998251	 0.0	 1	 -30.0	 30.0;
	2742	 2434	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 0.998251	 0.0	 1	 -30.0	 30.0;
	13479	 8873	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.0025	 0.0	 1	 -30.0	 30.0;
	13479	 5750	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.0025	 0.0	 1	 -30.0	 30.0;
	6643	 5751	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.011301	 0.0	 1	 -30.0	 30.0;
	2591	 3282	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.002083	 0.0	 1	 -30.0	 30.0;
	2591	 6862	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.002083	 0.0	 1	 -30.0	 30.0;
	2591	 3284	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.002083	 0.0	 1	 -30.0	 30.0;
	2591	 3283	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.002083	 0.0	 1	 -30.0	 30.0;
	4795	 2902	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.009643	 0.0	 1	 -30.0	 30.0;
	4795	 2901	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.009643	 0.0	 1	 -30.0	 30.0;
	4450	 9440	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.002649	 0.0	 1	 -30.0	 30.0;
	4450	 9441	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.002649	 0.0	 1	 -30.0	 30.0;
	4450	 9442	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.002649	 0.0	 1	 -30.0	 30.0;
	4450	 9443	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.002649	 0.0	 1	 -30.0	 30.0;
	4450	 9438	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.002649	 0.0	 1	 -30.0	 30.0;
	5538	 12304	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.008639	 0.0	 1	 -30.0	 30.0;
	5538	 12303	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.008639	 0.0	 1	 -30.0	 30.0;
	5538	 12302	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.008639	 0.0	 1	 -30.0	 30.0;
	5538	 12307	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.008639	 0.0	 1	 -30.0	 30.0;
	1106	 12306	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.013853	 0.0	 1	 -30.0	 30.0;
	12345	 5270	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.002404	 0.0	 1	 -30.0	 30.0;
	12345	 5271	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.002404	 0.0	 1	 -30.0	 30.0;
	12345	 4403	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.002404	 0.0	 1	 -30.0	 30.0;
	12345	 9343	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.002404	 0.0	 1	 -30.0	 30.0;
	60	 5274	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.001752	 0.0	 1	 -30.0	 30.0;
	60	 5275	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.001752	 0.0	 1	 -30.0	 30.0;
	60	 5276	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.001752	 0.0	 1	 -30.0	 30.0;
	60	 5277	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.001752	 0.0	 1	 -30.0	 30.0;
	12345	 5278	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.002404	 0.0	 1	 -30.0	 30.0;
	12345	 5279	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.002404	 0.0	 1	 -30.0	 30.0;
	12345	 11818	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.002404	 0.0	 1	 -30.0	 30.0;
	12345	 11817	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.002404	 0.0	 1	 -30.0	 30.0;
	60	 11820	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.001653	 0.0	 1	 -30.0	 30.0;
	60	 11819	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.001653	 0.0	 1	 -30.0	 30.0;
	60	 11814	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.001653	 0.0	 1	 -30.0	 30.0;
	60	 11813	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.001653	 0.0	 1	 -30.0	 30.0;
	1108	 11816	 0.003521	 0.140801	 0.0	 225	 225	 225	 0.996098	 0.0	 1	 -30.0	 30.0;
	1108	 11815	 0.003521	 0.140801	 0.0	 225	 225	 225	 0.996098	 0.0	 1	 -30.0	 30.0;
	1108	 11811	 0.003521	 0.140801	 0.0	 225	 225	 225	 0.996098	 0.0	 1	 -30.0	 30.0;
	5240	 11810	 0.003521	 0.140801	 0.0	 225	 225	 225	 0.995875	 0.0	 1	 -30.0	 30.0;
	5240	 4772	 0.003521	 0.140801	 0.0	 225	 225	 225	 0.995875	 0.0	 1	 -30.0	 30.0;
	5240	 4773	 0.003521	 0.140801	 0.0	 225	 225	 225	 0.995875	 0.0	 1	 -30.0	 30.0;
	5240	 4770	 0.003521	 0.140801	 0.0	 225	 225	 225	 0.995875	 0.0	 1	 -30.0	 30.0;
	11181	 4771	 0.003521	 0.140801	 0.0	 225	 225	 225	 0.9995	 0.0	 1	 -30.0	 30.0;
	9338	 4774	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.001046	 0.0	 1	 -30.0	 30.0;
	9338	 1577	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.001046	 0.0	 1	 -30.0	 30.0;
	8959	 481	 0.002119	 0.084719	 0.0	 373	 373	 373	 0.994019	 0.0	 1	 -30.0	 30.0;
	8959	 480	 0.002119	 0.084719	 0.0	 373	 373	 373	 0.994019	 0.0	 1	 -30.0	 30.0;
	8959	 483	 0.002119	 0.084719	 0.0	 373	 373	 373	 0.994019	 0.0	 1	 -30.0	 30.0;
	8959	 482	 0.002119	 0.084719	 0.0	 373	 373	 373	 0.994019	 0.0	 1	 -30.0	 30.0;
	13350	 12140	 0.002119	 0.084719	 0.0	 373	 373	 373	 0.992995	 0.0	 1	 -30.0	 30.0;
	13350	 12139	 0.002119	 0.084719	 0.0	 373	 373	 373	 0.992995	 0.0	 1	 -30.0	 30.0;
	13350	 12138	 0.002119	 0.084719	 0.0	 373	 373	 373	 0.992995	 0.0	 1	 -30.0	 30.0;
	13350	 12137	 0.002119	 0.084719	 0.0	 373	 373	 373	 0.992995	 0.0	 1	 -30.0	 30.0;
	10040	 12136	 0.002119	 0.084719	 0.0	 373	 373	 373	 0.997453	 0.0	 1	 -30.0	 30.0;
	10040	 12135	 0.002119	 0.084719	 0.0	 373	 373	 373	 0.997453	 0.0	 1	 -30.0	 30.0;
	10040	 12134	 0.002119	 0.084719	 0.0	 373	 373	 373	 0.997453	 0.0	 1	 -30.0	 30.0;
	10040	 12133	 0.002119	 0.084719	 0.0	 373	 373	 373	 0.997453	 0.0	 1	 -30.0	 30.0;
	7864	 12132	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.013451	 0.0	 1	 -30.0	 30.0;
	7864	 12131	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.013451	 0.0	 1	 -30.0	 30.0;
	7864	 5089	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.013451	 0.0	 1	 -30.0	 30.0;
	7864	 5090	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.013451	 0.0	 1	 -30.0	 30.0;
	21	 5091	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.011752	 0.0	 1	 -30.0	 30.0;
	21	 5092	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.011752	 0.0	 1	 -30.0	 30.0;
	21	 5085	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.011752	 0.0	 1	 -30.0	 30.0;
	21	 5086	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.011752	 0.0	 1	 -30.0	 30.0;
	6523	 4695	 0.000825	 0.032971	 0.0	 958	 958	 958	 1.003138	 0.0	 1	 -30.0	 30.0;
	6523	 4696	 0.000825	 0.032971	 0.0	 958	 958	 958	 0.995103	 0.0	 1	 -30.0	 30.0;
	6523	 4693	 0.000825	 0.032971	 0.0	 958	 958	 958	 0.995103	 0.0	 1	 -30.0	 30.0;
	13304	 5082	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.013258	 0.0	 1	 -30.0	 30.0;
	13304	 12652	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.013258	 0.0	 1	 -30.0	 30.0;
	13304	 12651	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.013258	 0.0	 1	 -30.0	 30.0;
	13304	 12654	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.013258	 0.0	 1	 -30.0	 30.0;
	2211	 12653	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.013227	 0.0	 1	 -30.0	 30.0;
	2211	 12648	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.013227	 0.0	 1	 -30.0	 30.0;
	2211	 12647	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.013227	 0.0	 1	 -30.0	 30.0;
	2211	 12650	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.013227	 0.0	 1	 -30.0	 30.0;
	8283	 11259	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.01231	 0.0	 1	 -30.0	 30.0;
	8283	 11256	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.01231	 0.0	 1	 -30.0	 30.0;
	10793	 11028	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.014528	 0.0	 1	 -30.0	 30.0;
	10793	 4455	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.014528	 0.0	 1	 -30.0	 30.0;
	2588	 4454	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.014699	 0.0	 1	 -30.0	 30.0;
	2588	 4457	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.014699	 0.0	 1	 -30.0	 30.0;
	2588	 4456	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.014699	 0.0	 1	 -30.0	 30.0;
	6461	 4451	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.014941	 0.0	 1	 -30.0	 30.0;
	6461	 7183	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.014941	 0.0	 1	 -30.0	 30.0;
	6461	 4453	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.014941	 0.0	 1	 -30.0	 30.0;
	6461	 7200	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.014941	 0.0	 1	 -30.0	 30.0;
	6461	 4461	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.014941	 0.0	 1	 -30.0	 30.0;
	3844	 4460	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.004844	 0.0	 1	 -30.0	 30.0;
	3844	 9586	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.004844	 0.0	 1	 -30.0	 30.0;
	3844	 9587	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.004844	 0.0	 1	 -30.0	 30.0;
	9760	 9588	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.021581	 0.0	 1	 -30.0	 30.0;
	9760	 9589	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.021581	 0.0	 1	 -30.0	 30.0;
	9760	 9590	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.021581	 0.0	 1	 -30.0	 30.0;
	9760	 9591	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.021581	 0.0	 1	 -30.0	 30.0;
	4687	 11133	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.013516	 0.0	 1	 -30.0	 30.0;
	4687	 11132	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.013516	 0.0	 1	 -30.0	 30.0;
	4687	 11137	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.013516	 0.0	 1	 -30.0	 30.0;
	4687	 12869	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.013516	 0.0	 1	 -30.0	 30.0;
	7308	 4053	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.016404	 0.0	 1	 -30.0	 30.0;
	7308	 4054	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.016404	 0.0	 1	 -30.0	 30.0;
	7308	 11345	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.016404	 0.0	 1	 -30.0	 30.0;
	7308	 4056	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.016404	 0.0	 1	 -30.0	 30.0;
	12703	 4057	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.005292	 0.0	 1	 -30.0	 30.0;
	12703	 4058	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.005292	 0.0	 1	 -30.0	 30.0;
	12703	 4059	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.005292	 0.0	 1	 -30.0	 30.0;
	12703	 4060	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.005292	 0.0	 1	 -30.0	 30.0;
	12703	 4061	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.005292	 0.0	 1	 -30.0	 30.0;
	12703	 4062	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.005292	 0.0	 1	 -30.0	 30.0;
	1867	 6454	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.002241	 0.0	 1	 -30.0	 30.0;
	1867	 10080	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.002241	 0.0	 1	 -30.0	 30.0;
	1867	 10077	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.002241	 0.0	 1	 -30.0	 30.0;
	1867	 10078	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.002241	 0.0	 1	 -30.0	 30.0;
	1867	 10075	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.002241	 0.0	 1	 -30.0	 30.0;
	1867	 10076	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.002241	 0.0	 1	 -30.0	 30.0;
	1188	 10073	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.001755	 0.0	 1	 -30.0	 30.0;
	2837	 10074	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.001755	 0.0	 1	 -30.0	 30.0;
	6600	 6471	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.008075	 0.0	 1	 -30.0	 30.0;
	6600	 10084	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.008075	 0.0	 1	 -30.0	 30.0;
	5509	 3456	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.018347	 0.0	 1	 -30.0	 30.0;
	9332	 4580	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.027388	 0.0	 1	 -30.0	 30.0;
	9332	 4577	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.027388	 0.0	 1	 -30.0	 30.0;
	9332	 4578	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.027388	 0.0	 1	 -30.0	 30.0;
	9332	 6391	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.027388	 0.0	 1	 -30.0	 30.0;
	9332	 4576	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.027388	 0.0	 1	 -30.0	 30.0;
	5443	 5207	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.007133	 0.0	 1	 -30.0	 30.0;
	5443	 5208	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.007133	 0.0	 1	 -30.0	 30.0;
	12823	 4585	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.004586	 0.0	 1	 -30.0	 30.0;
	12823	 654	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.004586	 0.0	 1	 -30.0	 30.0;
	12823	 10143	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.004586	 0.0	 1	 -30.0	 30.0;
	12823	 10142	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.004586	 0.0	 1	 -30.0	 30.0;
	12823	 10141	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.004586	 0.0	 1	 -30.0	 30.0;
	9524	 86	 0.001377	 0.055049	 0.0	 574	 574	 574	 1.006083	 0.0	 1	 -30.0	 30.0;
	9524	 88	 0.001377	 0.055049	 0.0	 574	 574	 574	 0.998959	 0.0	 1	 -30.0	 30.0;
	9524	 87	 0.001377	 0.055049	 0.0	 574	 574	 574	 0.998959	 0.0	 1	 -30.0	 30.0;
	1934	 11714	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.01208	 0.0	 1	 -30.0	 30.0;
	1934	 11713	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.01208	 0.0	 1	 -30.0	 30.0;
	1934	 6996	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.01208	 0.0	 1	 -30.0	 30.0;
	1623	 11717	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 0.999681	 0.0	 1	 -30.0	 30.0;
	1623	 4655	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 0.999681	 0.0	 1	 -30.0	 30.0;
	1623	 4656	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 0.999681	 0.0	 1	 -30.0	 30.0;
	3102	 4657	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.003271	 0.0	 1	 -30.0	 30.0;
	3102	 4658	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.003271	 0.0	 1	 -30.0	 30.0;
	3102	 1002	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.003271	 0.0	 1	 -30.0	 30.0;
	13472	 12610	 0.003521	 0.140801	 0.0	 225	 225	 225	 0.994842	 0.0	 1	 -30.0	 30.0;
	13472	 12607	 0.003521	 0.140801	 0.0	 225	 225	 225	 0.994842	 0.0	 1	 -30.0	 30.0;
	3722	 3017	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.004816	 0.0	 1	 -30.0	 30.0;
	3722	 3021	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.004816	 0.0	 1	 -30.0	 30.0;
	3722	 3022	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.004816	 0.0	 1	 -30.0	 30.0;
	3722	 2533	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.004816	 0.0	 1	 -30.0	 30.0;
	3722	 2572	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.004816	 0.0	 1	 -30.0	 30.0;
	3722	 2573	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.004816	 0.0	 1	 -30.0	 30.0;
	6695	 12334	 0.003521	 0.140801	 0.0	 225	 225	 225	 0.994421	 0.0	 1	 -30.0	 30.0;
	6695	 12333	 0.003521	 0.140801	 0.0	 225	 225	 225	 0.994421	 0.0	 1	 -30.0	 30.0;
	6695	 12332	 0.003521	 0.140801	 0.0	 225	 225	 225	 0.994421	 0.0	 1	 -30.0	 30.0;
	6695	 6055	 0.003521	 0.140801	 0.0	 225	 225	 225	 0.994421	 0.0	 1	 -30.0	 30.0;
	6695	 12330	 0.003521	 0.140801	 0.0	 225	 225	 225	 0.994421	 0.0	 1	 -30.0	 30.0;
	2484	 12338	 0.003521	 0.140801	 0.0	 225	 225	 225	 0.998191	 0.0	 1	 -30.0	 30.0;
	2484	 12337	 0.003521	 0.140801	 0.0	 225	 225	 225	 0.998191	 0.0	 1	 -30.0	 30.0;
	8104	 5305	 0.003521	 0.140801	 0.0	 225	 225	 225	 0.998244	 0.0	 1	 -30.0	 30.0;
	8104	 5306	 0.003521	 0.140801	 0.0	 225	 225	 225	 0.998244	 0.0	 1	 -30.0	 30.0;
	5995	 5307	 0.003521	 0.140801	 0.0	 225	 225	 225	 0.998295	 0.0	 1	 -30.0	 30.0;
	5995	 5308	 0.003521	 0.140801	 0.0	 225	 225	 225	 0.998295	 0.0	 1	 -30.0	 30.0;
	5807	 5301	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.011449	 0.0	 1	 -30.0	 30.0;
	434	 5302	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.018797	 0.0	 1	 -30.0	 30.0;
	4038	 5303	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.009509	 0.0	 1	 -30.0	 30.0;
	4038	 5304	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.009509	 0.0	 1	 -30.0	 30.0;
	11153	 5309	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.008338	 0.0	 1	 -30.0	 30.0;
	11153	 5310	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.008338	 0.0	 1	 -30.0	 30.0;
	2494	 1812	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.008688	 0.0	 1	 -30.0	 30.0;
	2494	 2446	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.008688	 0.0	 1	 -30.0	 30.0;
	2494	 2447	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.008688	 0.0	 1	 -30.0	 30.0;
	2494	 2448	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.008688	 0.0	 1	 -30.0	 30.0;
	12643	 2991	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.008601	 0.0	 1	 -30.0	 30.0;
	12643	 8537	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.008601	 0.0	 1	 -30.0	 30.0;
	12643	 5013	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.008601	 0.0	 1	 -30.0	 30.0;
	12643	 5012	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.008601	 0.0	 1	 -30.0	 30.0;
	9899	 5018	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.008554	 0.0	 1	 -30.0	 30.0;
	9899	 5017	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.008554	 0.0	 1	 -30.0	 30.0;
	9899	 11568	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.008554	 0.0	 1	 -30.0	 30.0;
	9899	 11569	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.008554	 0.0	 1	 -30.0	 30.0;
	1299	 13425	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.014838	 0.0	 1	 -30.0	 30.0;
	201	 5769	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.014043	 0.0	 1	 -30.0	 30.0;
	201	 5772	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.014043	 0.0	 1	 -30.0	 30.0;
	201	 13525	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.014043	 0.0	 1	 -30.0	 30.0;
	8254	 5770	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.007223	 0.0	 1	 -30.0	 30.0;
	8254	 5771	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.007223	 0.0	 1	 -30.0	 30.0;
	8254	 13345	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.007223	 0.0	 1	 -30.0	 30.0;
	8254	 7391	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.007223	 0.0	 1	 -30.0	 30.0;
	8254	 11352	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.007223	 0.0	 1	 -30.0	 30.0;
	8254	 11351	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.007223	 0.0	 1	 -30.0	 30.0;
	13132	 351	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.011871	 0.0	 1	 -30.0	 30.0;
	13132	 2097	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.011871	 0.0	 1	 -30.0	 30.0;
	10632	 3167	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.002423	 0.0	 1	 -30.0	 30.0;
	10632	 3168	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.002423	 0.0	 1	 -30.0	 30.0;
	10632	 3169	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.002423	 0.0	 1	 -30.0	 30.0;
	5819	 11353	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.004868	 0.0	 1	 -30.0	 30.0;
	5819	 11348	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.004868	 0.0	 1	 -30.0	 30.0;
	3080	 11347	 0.003521	 0.140801	 0.0	 225	 225	 225	 0.994284	 0.0	 1	 -30.0	 30.0;
	12002	 7020	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.013556	 0.0	 1	 -30.0	 30.0;
	12002	 8702	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.013556	 0.0	 1	 -30.0	 30.0;
	12002	 8701	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.013556	 0.0	 1	 -30.0	 30.0;
	12002	 11946	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.013556	 0.0	 1	 -30.0	 30.0;
	1931	 8707	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.013589	 0.0	 1	 -30.0	 30.0;
	1931	 8706	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.013589	 0.0	 1	 -30.0	 30.0;
	1931	 11962	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.013589	 0.0	 1	 -30.0	 30.0;
	1931	 11959	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.013589	 0.0	 1	 -30.0	 30.0;
	11316	 10985	 0.002119	 0.084719	 0.0	 373	 373	 373	 0.992901	 0.0	 1	 -30.0	 30.0;
	11316	 11894	 0.002119	 0.084719	 0.0	 373	 373	 373	 0.992901	 0.0	 1	 -30.0	 30.0;
	11316	 3418	 0.002119	 0.084719	 0.0	 373	 373	 373	 0.992901	 0.0	 1	 -30.0	 30.0;
	11316	 3419	 0.002119	 0.084719	 0.0	 373	 373	 373	 0.992901	 0.0	 1	 -30.0	 30.0;
	13596	 3058	 0.004448	 0.17788	 0.0	 178	 178	 178	 1.008199	 0.0	 1	 -30.0	 30.0;
	13596	 11838	 0.004448	 0.17788	 0.0	 178	 178	 178	 1.002232	 0.0	 1	 -30.0	 30.0;
	8	 3414	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.01052	 0.0	 1	 -30.0	 30.0;
	8	 3415	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.01052	 0.0	 1	 -30.0	 30.0;
	8	 3416	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.01052	 0.0	 1	 -30.0	 30.0;
	8	 7544	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.01052	 0.0	 1	 -30.0	 30.0;
	8	 3412	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.01052	 0.0	 1	 -30.0	 30.0;
	8	 8598	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.01052	 0.0	 1	 -30.0	 30.0;
	8	 10522	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.01052	 0.0	 1	 -30.0	 30.0;
	8	 10521	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.01052	 0.0	 1	 -30.0	 30.0;
	8	 9189	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.010533	 0.0	 1	 -30.0	 30.0;
	8	 9188	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.010533	 0.0	 1	 -30.0	 30.0;
	8	 9191	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.010533	 0.0	 1	 -30.0	 30.0;
	8	 9190	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.010533	 0.0	 1	 -30.0	 30.0;
	2601	 6910	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.013761	 0.0	 1	 -30.0	 30.0;
	2601	 6909	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.013761	 0.0	 1	 -30.0	 30.0;
	2769	 4791	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.026719	 0.0	 1	 -30.0	 30.0;
	2769	 4792	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.026719	 0.0	 1	 -30.0	 30.0;
	2769	 619	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.026719	 0.0	 1	 -30.0	 30.0;
	6024	 4602	 0.002119	 0.084719	 0.0	 373	 373	 373	 0.990176	 0.0	 1	 -30.0	 30.0;
	6024	 4603	 0.002119	 0.084719	 0.0	 373	 373	 373	 0.990176	 0.0	 1	 -30.0	 30.0;
	6024	 4604	 0.002119	 0.084719	 0.0	 373	 373	 373	 0.990176	 0.0	 1	 -30.0	 30.0;
	6024	 4598	 0.002119	 0.084719	 0.0	 373	 373	 373	 0.990176	 0.0	 1	 -30.0	 30.0;
	6024	 765	 0.002119	 0.084719	 0.0	 373	 373	 373	 0.990176	 0.0	 1	 -30.0	 30.0;
	1181	 6193	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.001706	 0.0	 1	 -30.0	 30.0;
	1181	 6194	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.001706	 0.0	 1	 -30.0	 30.0;
	4706	 615	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.007969	 0.0	 1	 -30.0	 30.0;
	4706	 614	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.007969	 0.0	 1	 -30.0	 30.0;
	280	 7163	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.012443	 0.0	 1	 -30.0	 30.0;
	12715	 11670	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.004291	 0.0	 1	 -30.0	 30.0;
	12715	 11669	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.004291	 0.0	 1	 -30.0	 30.0;
	12715	 11668	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.004291	 0.0	 1	 -30.0	 30.0;
	12715	 11667	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.004291	 0.0	 1	 -30.0	 30.0;
	12715	 11666	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.004291	 0.0	 1	 -30.0	 30.0;
	8448	 8308	 0.002119	 0.084719	 0.0	 373	 373	 373	 0.983598	 0.0	 1	 -30.0	 30.0;
	8448	 8125	 0.002119	 0.084719	 0.0	 373	 373	 373	 0.983598	 0.0	 1	 -30.0	 30.0;
	8448	 8128	 0.002119	 0.084719	 0.0	 373	 373	 373	 0.983598	 0.0	 1	 -30.0	 30.0;
	8448	 8127	 0.002119	 0.084719	 0.0	 373	 373	 373	 0.983598	 0.0	 1	 -30.0	 30.0;
	3796	 9141	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.006074	 0.0	 1	 -30.0	 30.0;
	3796	 9142	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.006074	 0.0	 1	 -30.0	 30.0;
	12029	 1389	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.009288	 0.0	 1	 -30.0	 30.0;
	12029	 1390	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.009288	 0.0	 1	 -30.0	 30.0;
	12029	 1391	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.009288	 0.0	 1	 -30.0	 30.0;
	12148	 196	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.00721	 0.0	 1	 -30.0	 30.0;
	12148	 5886	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.00721	 0.0	 1	 -30.0	 30.0;
	12148	 5885	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.00721	 0.0	 1	 -30.0	 30.0;
	12148	 5880	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.00721	 0.0	 1	 -30.0	 30.0;
	7406	 9137	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.004828	 0.0	 1	 -30.0	 30.0;
	7406	 2513	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.004828	 0.0	 1	 -30.0	 30.0;
	7406	 2190	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.004828	 0.0	 1	 -30.0	 30.0;
	4794	 2515	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.004847	 0.0	 1	 -30.0	 30.0;
	4794	 2514	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.004847	 0.0	 1	 -30.0	 30.0;
	4794	 2516	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.004847	 0.0	 1	 -30.0	 30.0;
	1008	 12455	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.02838	 0.0	 1	 -30.0	 30.0;
	1008	 6719	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.02838	 0.0	 1	 -30.0	 30.0;
	1008	 6721	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.02838	 0.0	 1	 -30.0	 30.0;
	1008	 12447	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.02838	 0.0	 1	 -30.0	 30.0;
	5296	 2518	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.012026	 0.0	 1	 -30.0	 30.0;
	5296	 8639	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.012026	 0.0	 1	 -30.0	 30.0;
	5296	 11570	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.012026	 0.0	 1	 -30.0	 30.0;
	5827	 5371	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.00294	 0.0	 1	 -30.0	 30.0;
	5827	 5370	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.00294	 0.0	 1	 -30.0	 30.0;
	5827	 5369	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.00294	 0.0	 1	 -30.0	 30.0;
	5827	 5368	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.00294	 0.0	 1	 -30.0	 30.0;
	3380	 4888	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.008763	 0.0	 1	 -30.0	 30.0;
	3380	 4887	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.008763	 0.0	 1	 -30.0	 30.0;
	4204	 1840	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.013933	 0.0	 1	 -30.0	 30.0;
	4204	 11564	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.013933	 0.0	 1	 -30.0	 30.0;
	4204	 8911	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.013933	 0.0	 1	 -30.0	 30.0;
	12047	 13095	 0.003587	 0.143427	 0.0	 221	 221	 221	 1.001823	 0.0	 1	 -30.0	 30.0;
	12047	 2082	 0.003587	 0.143427	 0.0	 221	 221	 221	 1.001823	 0.0	 1	 -30.0	 30.0;
	12047	 9570	 0.003587	 0.143427	 0.0	 221	 221	 221	 0.995326	 0.0	 1	 -30.0	 30.0;
	12047	 2088	 0.003587	 0.143427	 0.0	 221	 221	 221	 0.995326	 0.0	 1	 -30.0	 30.0;
	12047	 2087	 0.003587	 0.143427	 0.0	 221	 221	 221	 0.995326	 0.0	 1	 -30.0	 30.0;
	10091	 2086	 0.003571	 0.142812	 0.0	 222	 222	 222	 1.00179	 0.0	 1	 -30.0	 30.0;
	10091	 2085	 0.003571	 0.142812	 0.0	 222	 222	 222	 1.00179	 0.0	 1	 -30.0	 30.0;
	10091	 2078	 0.003571	 0.142812	 0.0	 222	 222	 222	 0.995275	 0.0	 1	 -30.0	 30.0;
	10091	 2077	 0.003571	 0.142812	 0.0	 222	 222	 222	 0.995275	 0.0	 1	 -30.0	 30.0;
	10091	 10107	 0.003571	 0.142812	 0.0	 222	 222	 222	 0.995275	 0.0	 1	 -30.0	 30.0;
	13003	 6498	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.007585	 0.0	 1	 -30.0	 30.0;
	13003	 3219	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.007585	 0.0	 1	 -30.0	 30.0;
	13003	 3220	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.007585	 0.0	 1	 -30.0	 30.0;
	13003	 3213	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.007585	 0.0	 1	 -30.0	 30.0;
	5096	 3214	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.007584	 0.0	 1	 -30.0	 30.0;
	5096	 3215	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.007584	 0.0	 1	 -30.0	 30.0;
	5096	 3216	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.007584	 0.0	 1	 -30.0	 30.0;
	5096	 3210	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.007584	 0.0	 1	 -30.0	 30.0;
	7583	 6557	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.00868	 0.0	 1	 -30.0	 30.0;
	7583	 13093	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.00868	 0.0	 1	 -30.0	 30.0;
	7583	 3487	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.00868	 0.0	 1	 -30.0	 30.0;
	5643	 3490	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.008681	 0.0	 1	 -30.0	 30.0;
	5643	 3489	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.008681	 0.0	 1	 -30.0	 30.0;
	5643	 3485	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.008681	 0.0	 1	 -30.0	 30.0;
	1233	 11416	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.006861	 0.0	 1	 -30.0	 30.0;
	1233	 684	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.006861	 0.0	 1	 -30.0	 30.0;
	1233	 11414	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.006861	 0.0	 1	 -30.0	 30.0;
	1233	 11411	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.006861	 0.0	 1	 -30.0	 30.0;
	1233	 11412	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.006861	 0.0	 1	 -30.0	 30.0;
	6626	 7110	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.007481	 0.0	 1	 -30.0	 30.0;
	6626	 3720	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.007481	 0.0	 1	 -30.0	 30.0;
	6626	 3717	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.007481	 0.0	 1	 -30.0	 30.0;
	6626	 3718	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.007481	 0.0	 1	 -30.0	 30.0;
	13645	 9616	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.000671	 0.0	 1	 -30.0	 30.0;
	8229	 9617	 0.003521	 0.140801	 0.0	 225	 225	 225	 0.99286	 0.0	 1	 -30.0	 30.0;
	8229	 9618	 0.003521	 0.140801	 0.0	 225	 225	 225	 0.99286	 0.0	 1	 -30.0	 30.0;
	5139	 9619	 0.003521	 0.140801	 0.0	 225	 225	 225	 0.992942	 0.0	 1	 -30.0	 30.0;
	5139	 9622	 0.003521	 0.140801	 0.0	 225	 225	 225	 0.992942	 0.0	 1	 -30.0	 30.0;
	11505	 9623	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.0116	 0.0	 1	 -30.0	 30.0;
	11505	 2982	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.0116	 0.0	 1	 -30.0	 30.0;
	11505	 2981	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.0116	 0.0	 1	 -30.0	 30.0;
	9307	 2980	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.005249	 0.0	 1	 -30.0	 30.0;
	9307	 2979	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.005249	 0.0	 1	 -30.0	 30.0;
	9307	 2978	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.005249	 0.0	 1	 -30.0	 30.0;
	9841	 12525	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.003642	 0.0	 1	 -30.0	 30.0;
	9841	 12526	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.003642	 0.0	 1	 -30.0	 30.0;
	9841	 7113	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.003642	 0.0	 1	 -30.0	 30.0;
	13325	 2984	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.011161	 0.0	 1	 -30.0	 30.0;
	11938	 12518	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.011192	 0.0	 1	 -30.0	 30.0;
	11938	 9283	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.011192	 0.0	 1	 -30.0	 30.0;
	11938	 7719	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.009361	 0.0	 1	 -30.0	 30.0;
	11938	 7722	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.009361	 0.0	 1	 -30.0	 30.0;
	11938	 7721	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.009361	 0.0	 1	 -30.0	 30.0;
	11938	 7717	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.009361	 0.0	 1	 -30.0	 30.0;
	11938	 7716	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.009361	 0.0	 1	 -30.0	 30.0;
	11938	 5978	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.009361	 0.0	 1	 -30.0	 30.0;
	1555	 4207	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.000657	 0.0	 1	 -30.0	 30.0;
	1555	 4214	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.000657	 0.0	 1	 -30.0	 30.0;
	1555	 12152	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.000657	 0.0	 1	 -30.0	 30.0;
	1555	 10809	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.000657	 0.0	 1	 -30.0	 30.0;
	12889	 4481	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.012234	 0.0	 1	 -30.0	 30.0;
	11830	 4484	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.010846	 0.0	 1	 -30.0	 30.0;
	13503	 9033	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.008933	 0.0	 1	 -30.0	 30.0;
	13503	 9034	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.008933	 0.0	 1	 -30.0	 30.0;
	6845	 732	 0.002119	 0.084719	 0.0	 373	 373	 373	 0.991864	 0.0	 1	 -30.0	 30.0;
	6845	 730	 0.002119	 0.084719	 0.0	 373	 373	 373	 0.991864	 0.0	 1	 -30.0	 30.0;
	6845	 731	 0.002119	 0.084719	 0.0	 373	 373	 373	 0.991864	 0.0	 1	 -30.0	 30.0;
	6845	 734	 0.002119	 0.084719	 0.0	 373	 373	 373	 0.991864	 0.0	 1	 -30.0	 30.0;
	6845	 4982	 0.002119	 0.084719	 0.0	 373	 373	 373	 0.991864	 0.0	 1	 -30.0	 30.0;
	11349	 4963	 0.003521	 0.140801	 0.0	 225	 225	 225	 0.991519	 0.0	 1	 -30.0	 30.0;
	11349	 5342	 0.003521	 0.140801	 0.0	 225	 225	 225	 0.991519	 0.0	 1	 -30.0	 30.0;
	11349	 5382	 0.003521	 0.140801	 0.0	 225	 225	 225	 0.991519	 0.0	 1	 -30.0	 30.0;
	11349	 4964	 0.003521	 0.140801	 0.0	 225	 225	 225	 0.991519	 0.0	 1	 -30.0	 30.0;
	11901	 3585	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.011258	 0.0	 1	 -30.0	 30.0;
	11901	 3586	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.011258	 0.0	 1	 -30.0	 30.0;
	4368	 3587	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.011551	 0.0	 1	 -30.0	 30.0;
	4368	 3588	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.011551	 0.0	 1	 -30.0	 30.0;
	4368	 2934	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.011551	 0.0	 1	 -30.0	 30.0;
	8500	 4958	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.004896	 0.0	 1	 -30.0	 30.0;
	8500	 5676	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.004896	 0.0	 1	 -30.0	 30.0;
	3876	 11530	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.004751	 0.0	 1	 -30.0	 30.0;
	3876	 11527	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.004751	 0.0	 1	 -30.0	 30.0;
	3876	 11528	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.004751	 0.0	 1	 -30.0	 30.0;
	3876	 11525	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.004746	 0.0	 1	 -30.0	 30.0;
	3876	 11526	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.004746	 0.0	 1	 -30.0	 30.0;
	3876	 11523	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.004746	 0.0	 1	 -30.0	 30.0;
	3876	 11524	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.004746	 0.0	 1	 -30.0	 30.0;
	3876	 1367	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.004746	 0.0	 1	 -30.0	 30.0;
	3876	 5830	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.004928	 0.0	 1	 -30.0	 30.0;
	3876	 13386	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.004928	 0.0	 1	 -30.0	 30.0;
	3876	 13385	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.004928	 0.0	 1	 -30.0	 30.0;
	3876	 13387	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.004928	 0.0	 1	 -30.0	 30.0;
	3876	 13633	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.004749	 0.0	 1	 -30.0	 30.0;
	3876	 13487	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.004749	 0.0	 1	 -30.0	 30.0;
	3876	 13648	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.004749	 0.0	 1	 -30.0	 30.0;
	3876	 6014	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.004749	 0.0	 1	 -30.0	 30.0;
	3876	 5999	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.004749	 0.0	 1	 -30.0	 30.0;
	3876	 1	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.004729	 0.0	 1	 -30.0	 30.0;
	3876	 4458	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.004729	 0.0	 1	 -30.0	 30.0;
	3876	 11023	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.004729	 0.0	 1	 -30.0	 30.0;
	3876	 12116	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.004729	 0.0	 1	 -30.0	 30.0;
	3876	 11025	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.004729	 0.0	 1	 -30.0	 30.0;
	1015	 11204	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.014683	 0.0	 1	 -30.0	 30.0;
	1015	 11201	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.014683	 0.0	 1	 -30.0	 30.0;
	12395	 6877	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.013169	 0.0	 1	 -30.0	 30.0;
	12395	 6876	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.013169	 0.0	 1	 -30.0	 30.0;
	12395	 6875	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.013169	 0.0	 1	 -30.0	 30.0;
	12395	 12095	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.013169	 0.0	 1	 -30.0	 30.0;
	1395	 2811	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.013854	 0.0	 1	 -30.0	 30.0;
	1395	 6280	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.013854	 0.0	 1	 -30.0	 30.0;
	1395	 8424	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.013854	 0.0	 1	 -30.0	 30.0;
	1395	 8423	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.013854	 0.0	 1	 -30.0	 30.0;
	6133	 858	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.014584	 0.0	 1	 -30.0	 30.0;
	6133	 10908	 0.000708	 0.02832	 0.0	 1116	 1116	 1116	 1.014584	 0.0	 1	 -30.0	 30.0;
	2403	 2606	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.00802	 0.0	 1	 -30.0	 30.0;
	2403	 2607	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.00802	 0.0	 1	 -30.0	 30.0;
	2403	 12727	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.0066	 0.0	 1	 -30.0	 30.0;
	2403	 396	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.0066	 0.0	 1	 -30.0	 30.0;
	2403	 8143	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.0066	 0.0	 1	 -30.0	 30.0;
	2403	 6121	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.0066	 0.0	 1	 -30.0	 30.0;
	8264	 7079	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.010644	 0.0	 1	 -30.0	 30.0;
	8264	 12517	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.010644	 0.0	 1	 -30.0	 30.0;
	3187	 4843	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.016068	 0.0	 1	 -30.0	 30.0;
	3187	 4844	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.016068	 0.0	 1	 -30.0	 30.0;
	3187	 4845	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.016068	 0.0	 1	 -30.0	 30.0;
	3187	 4846	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.016068	 0.0	 1	 -30.0	 30.0;
	3187	 4847	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.016068	 0.0	 1	 -30.0	 30.0;
	3187	 4837	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.016068	 0.0	 1	 -30.0	 30.0;
	3187	 1955	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.016068	 0.0	 1	 -30.0	 30.0;
	3187	 9984	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.016068	 0.0	 1	 -30.0	 30.0;
	3187	 3074	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.018397	 0.0	 1	 -30.0	 30.0;
	3187	 3072	 0.000531	 0.021225	 0.0	 1488	 1488	 1488	 1.018397	 0.0	 1	 -30.0	 30.0;
	10536	 6985	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.012036	 0.0	 1	 -30.0	 30.0;
	10536	 6987	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.012036	 0.0	 1	 -30.0	 30.0;
	10536	 12505	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.012036	 0.0	 1	 -30.0	 30.0;
	10536	 12506	 0.002119	 0.084719	 0.0	 373	 373	 373	 1.012036	 0.0	 1	 -30.0	 30.0;
	12737	 5468	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.007774	 0.0	 1	 -30.0	 30.0;
	12737	 5467	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.007774	 0.0	 1	 -30.0	 30.0;
	12737	 5466	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.007774	 0.0	 1	 -30.0	 30.0;
	12737	 4181	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.007774	 0.0	 1	 -30.0	 30.0;
	1404	 12025	 0.003521	 0.140801	 0.0	 225	 225	 225	 1.005553	 0.0	 1	 -30.0	 30.0;
	6538	 781	 0.0	 0.04332	 0.0	 730	 730	 730	 1.013449	 0.0	 1	 -30.0	 30.0;
	6538	 781	 0.0	 0.04332	 0.0	 730	 730	 730	 1.013449	 0.0	 1	 -30.0	 30.0;
	1161	 13143	 0.0	 0.05435	 0.0	 582	 582	 582	 1.020422	 0.0	 1	 -30.0	 30.0;
	1161	 12001	 0.0	 0.05435	 0.0	 582	 582	 582	 1.020422	 0.0	 1	 -30.0	 30.0;
	1161	 6747	 0.0	 0.05435	 0.0	 582	 582	 582	 1.020362	 0.0	 1	 -30.0	 30.0;
	7260	 6831	 0.0	 0.0505	 0.0	 626	 626	 626	 0.997208	 0.0	 1	 -30.0	 30.0;
	7260	 10963	 0.0	 0.104	 0.0	 304	 304	 304	 1.01095	 0.0	 1	 -30.0	 30.0;
	7260	 12393	 0.0	 0.104	 0.0	 365	 365	 365	 1.011333	 0.0	 1	 -30.0	 30.0;
	7260	 6305	 0.0	 0.104	 0.0	 365	 365	 365	 1.011333	 0.0	 1	 -30.0	 30.0;
	7260	 11539	 0.0	 0.104	 0.0	 304	 304	 304	 1.01095	 0.0	 1	 -30.0	 30.0;
	7260	 12678	 0.0	 0.104	 0.0	 365	 365	 365	 1.011333	 0.0	 1	 -30.0	 30.0;
	7260	 13010	 0.0	 0.104	 0.0	 365	 365	 365	 1.011333	 0.0	 1	 -30.0	 30.0;
	7260	 9204	 0.0	 0.104	 0.0	 304	 304	 304	 1.01095	 0.0	 1	 -30.0	 30.0;
	11	 12266	 0.0	 0.05667	 0.0	 558	 558	 558	 1.007055	 0.0	 1	 -30.0	 30.0;
	11	 3201	 0.0	 0.05667	 0.0	 558	 558	 558	 1.007055	 0.0	 1	 -30.0	 30.0;
	11	 8816	 0.0	 0.04545	 0.0	 695	 695	 695	 1.006593	 0.0	 1	 -30.0	 30.0;
	6831	 9937	 0.0	 0.104	 0.0	 304	 304	 304	 1.038514	 0.0	 1	 -30.0	 30.0;
	6831	 8290	 0.0	 0.104	 0.0	 304	 304	 304	 1.038514	 0.0	 1	 -30.0	 30.0;
	12420	 12815	 0.0	 0.28571	 0.0	 111	 111	 111	 1.0109	 0.0	 1	 -30.0	 30.0;
	6019	 7473	 0.0	 0.6	 0.0	 53	 53	 53	 1.044077	 0.0	 1	 -30.0	 30.0;
	6019	 1903	 0.0	 2.85714	 0.0	 12	 12	 12	 1.000888	 0.0	 1	 -30.0	 30.0;
	6019	 5982	 0.0	 2.85714	 0.0	 12	 12	 12	 1.000888	 0.0	 1	 -30.0	 30.0;
	6019	 13165	 0.0	 2.85714	 0.0	 12	 12	 12	 1.000888	 0.0	 1	 -30.0	 30.0;
	6019	 10186	 0.0	 2.85714	 0.0	 12	 12	 12	 1.000888	 0.0	 1	 -30.0	 30.0;
	6019	 5162	 0.0	 1.2	 0.0	 27	 27	 27	 1.043041	 0.0	 1	 -30.0	 30.0;
	6019	 10466	 0.0	 1.2	 0.0	 27	 27	 27	 1.043041	 0.0	 1	 -30.0	 30.0;
	6019	 8493	 0.0	 2.57143	 0.0	 13	 13	 13	 1.044066	 0.0	 1	 -30.0	 30.0;
	6019	 324	 0.0	 2.57143	 0.0	 13	 13	 13	 1.043911	 0.0	 1	 -30.0	 30.0;
	6019	 13131	 0.0	 0.6	 0.0	 53	 53	 53	 1.044077	 0.0	 1	 -30.0	 30.0;
	11918	 4614	 0.0	 0.36	 0.0	 88	 88	 88	 1.004596	 0.0	 1	 -30.0	 30.0;
	10797	 12441	 0.0	 0.775	 0.0	 41	 41	 41	 1.035164	 0.0	 1	 -30.0	 30.0;
	10797	 7639	 0.0	 0.797	 0.0	 40	 40	 40	 1.035183	 0.0	 1	 -30.0	 30.0;
	10797	 11768	 0.0	 0.20567	 0.0	 154	 154	 154	 1.001194	 0.0	 1	 -30.0	 30.0;
	10797	 2906	 0.0	 0.80867	 0.0	 40	 40	 40	 1.000505	 0.0	 1	 -30.0	 30.0;
	12089	 9292	 0.0	 0.3	 0.0	 106	 106	 106	 1.002898	 0.0	 1	 -30.0	 30.0;
	12089	 10428	 0.0	 0.3	 0.0	 106	 106	 106	 1.002898	 0.0	 1	 -30.0	 30.0;
	12089	 2048	 0.0	 0.4	 0.0	 79	 79	 79	 1.002952	 0.0	 1	 -30.0	 30.0;
	9313	 9146	 0.0	 0.044	 0.0	 718	 718	 718	 0.954853	 0.0	 1	 -30.0	 30.0;
	9313	 9146	 0.0	 0.044	 0.0	 718	 718	 718	 0.954853	 0.0	 1	 -30.0	 30.0;
	9313	 6491	 0.0	 0.06667	 0.0	 474	 474	 474	 0.959366	 0.0	 1	 -30.0	 30.0;
	9313	 7535	 0.0	 0.06667	 0.0	 474	 474	 474	 0.959366	 0.0	 1	 -30.0	 30.0;
	9313	 12865	 0.0	 0.06	 0.0	 527	 527	 527	 0.958638	 0.0	 1	 -30.0	 30.0;
	9640	 3760	 0.0	 0.047975	 0.0	 659	 659	 659	 0.950169	 0.0	 1	 -30.0	 30.0;
	9640	 3760	 0.0	 0.047975	 0.0	 659	 659	 659	 0.950169	 0.0	 1	 -30.0	 30.0;
	9640	 8501	 0.0	 0.037831	 0.0	 835	 835	 835	 0.953808	 0.0	 1	 -30.0	 30.0;
	9640	 8501	 0.0	 0.037831	 0.0	 835	 835	 835	 0.953808	 0.0	 1	 -30.0	 30.0;
	8364	 7550	 0.0	 0.045294	 0.0	 698	 698	 698	 0.982613	 0.0	 1	 -30.0	 30.0;
	8364	 7550	 0.0	 0.045294	 0.0	 698	 698	 698	 0.982613	 0.0	 1	 -30.0	 30.0;
	8364	 4263	 0.0	 0.04563	 0.0	 693	 693	 693	 0.965755	 0.0	 1	 -30.0	 30.0;
	8364	 4263	 0.0	 0.04563	 0.0	 693	 693	 693	 0.965755	 0.0	 1	 -30.0	 30.0;
	5348	 4970	 0.0	 0.047975	 0.0	 659	 659	 659	 0.954185	 0.0	 1	 -30.0	 30.0;
	5348	 4970	 0.0	 0.047975	 0.0	 659	 659	 659	 0.954185	 0.0	 1	 -30.0	 30.0;
	5348	 9576	 0.0	 0.049246	 0.0	 642	 642	 642	 0.947234	 0.0	 1	 -30.0	 30.0;
	5348	 9576	 0.0	 0.049246	 0.0	 642	 642	 642	 0.947234	 0.0	 1	 -30.0	 30.0;
	5348	 13191	 0.0	 0.04444	 0.0	 711	 711	 711	 0.988749	 0.0	 1	 -30.0	 30.0;
	5348	 7327	 0.0	 0.04444	 0.0	 711	 711	 711	 0.988749	 0.0	 1	 -30.0	 30.0;
	5348	 2069	 0.0	 0.04138	 0.0	 764	 764	 764	 0.988661	 0.0	 1	 -30.0	 30.0;
	12365	 11707	 0.0	 0.049246	 0.0	 642	 642	 642	 0.940146	 0.0	 1	 -30.0	 30.0;
	12365	 11707	 0.0	 0.049246	 0.0	 642	 642	 642	 0.940146	 0.0	 1	 -30.0	 30.0;
	13005	 9058	 0.0	 0.046721	 0.0	 677	 677	 677	 0.955135	 0.0	 1	 -30.0	 30.0;
	13005	 7788	 0.0	 0.047975	 0.0	 659	 659	 659	 0.959446	 0.0	 1	 -30.0	 30.0;
	9147	 6616	 0.0	 0.06667	 0.0	 474	 474	 474	 1.008237	 0.0	 1	 -30.0	 30.0;
	9147	 7643	 0.0	 0.06667	 0.0	 474	 474	 474	 1.04988	 0.0	 1	 -30.0	 30.0;
	9147	 13002	 0.0	 0.06	 0.0	 527	 527	 527	 1.049514	 0.0	 1	 -30.0	 30.0;
	1187	 10353	 0.0	 0.047974	 0.0	 659	 659	 659	 0.954972	 0.0	 1	 -30.0	 30.0;
	1187	 10353	 0.0	 0.047974	 0.0	 659	 659	 659	 0.954972	 0.0	 1	 -30.0	 30.0;
	3237	 8887	 0.0	 0.26718	 0.0	 119	 119	 119	 1.005967	 0.0	 1	 -30.0	 30.0;
	3237	 10784	 0.0	 0.26542	 0.0	 120	 120	 120	 1.005975	 0.0	 1	 -30.0	 30.0;
	3237	 5542	 0.0	 0.26542	 0.0	 120	 120	 120	 1.005975	 0.0	 1	 -30.0	 30.0;
	3237	 11509	 0.0	 0.17674	 0.0	 179	 179	 179	 1.00828	 0.0	 1	 -30.0	 30.0;
	4389	 9395	 0.0	 0.16	 0.0	 198	 198	 198	 1.007486	 0.0	 1	 -30.0	 30.0;
	3730	 11944	 0.0	 0.049246	 0.0	 642	 642	 642	 0.946864	 0.0	 1	 -30.0	 30.0;
	3730	 11944	 0.0	 0.049246	 0.0	 642	 642	 642	 0.946864	 0.0	 1	 -30.0	 30.0;
	3730	 8037	 0.0	 0.047975	 0.0	 659	 659	 659	 0.950137	 0.0	 1	 -30.0	 30.0;
	3730	 8037	 0.0	 0.047975	 0.0	 659	 659	 659	 0.950137	 0.0	 1	 -30.0	 30.0;
	10667	 6585	 0.0	 0.09487	 0.0	 333	 333	 333	 1.045129	 0.0	 1	 -30.0	 30.0;
	10667	 1868	 0.0	 0.09487	 0.0	 333	 333	 333	 1.045129	 0.0	 1	 -30.0	 30.0;
	10667	 10239	 0.0	 0.10625	 0.0	 298	 298	 298	 1.045245	 0.0	 1	 -30.0	 30.0;
	10667	 10932	 0.0	 0.06486	 0.0	 488	 488	 488	 1.045356	 0.0	 1	 -30.0	 30.0;
	10667	 12983	 0.0	 0.06486	 0.0	 488	 488	 488	 1.045356	 0.0	 1	 -30.0	 30.0;
	11896	 13511	 0.0	 0.047975	 0.0	 659	 659	 659	 0.94413	 0.0	 1	 -30.0	 30.0;
	11896	 13511	 0.0	 0.047975	 0.0	 659	 659	 659	 0.94413	 0.0	 1	 -30.0	 30.0;
	1187	 9113	 0.0	 0.045482	 0.0	 695	 695	 695	 0.959865	 0.0	 1	 -30.0	 30.0;
	1187	 9113	 0.0	 0.045482	 0.0	 695	 695	 695	 0.959865	 0.0	 1	 -30.0	 30.0;
	2273	 1828	 0.0	 0.048	 0.0	 659	 659	 659	 0.987462	 0.0	 1	 -30.0	 30.0;
	2273	 1828	 0.0	 0.048	 0.0	 659	 659	 659	 0.987462	 0.0	 1	 -30.0	 30.0;
	2273	 5556	 0.0	 0.047975	 0.0	 659	 659	 659	 0.945067	 0.0	 1	 -30.0	 30.0;
	2273	 5556	 0.0	 0.047975	 0.0	 659	 659	 659	 0.945067	 0.0	 1	 -30.0	 30.0;
	5861	 2565	 0.0	 0.049041	 0.0	 645	 645	 645	 0.942257	 0.0	 1	 -30.0	 30.0;
	5861	 2565	 0.0	 0.049041	 0.0	 645	 645	 645	 0.942257	 0.0	 1	 -30.0	 30.0;
	5861	 6308	 0.0	 0.047975	 0.0	 659	 659	 659	 0.947317	 0.0	 1	 -30.0	 30.0;
	5861	 6308	 0.0	 0.047975	 0.0	 659	 659	 659	 0.947317	 0.0	 1	 -30.0	 30.0;
	5861	 5343	 0.0	 0.04444	 0.0	 711	 711	 711	 1.000571	 0.0	 1	 -30.0	 30.0;
	5861	 3369	 0.0	 0.04444	 0.0	 711	 711	 711	 1.000571	 0.0	 1	 -30.0	 30.0;
	5861	 7593	 0.0	 0.04138	 0.0	 764	 764	 764	 1.000464	 0.0	 1	 -30.0	 30.0;
	12845	 12328	 0.0	 0.049246	 0.0	 642	 642	 642	 0.940793	 0.0	 1	 -30.0	 30.0;
	12845	 12328	 0.0	 0.049246	 0.0	 642	 642	 642	 0.940793	 0.0	 1	 -30.0	 30.0;
	2609	 6292	 0.0	 0.047975	 0.0	 659	 659	 659	 0.945337	 0.0	 1	 -30.0	 30.0;
	2609	 6292	 0.0	 0.047975	 0.0	 659	 659	 659	 0.945337	 0.0	 1	 -30.0	 30.0;
	2609	 7466	 0.0	 0.049246	 0.0	 642	 642	 642	 0.952901	 0.0	 1	 -30.0	 30.0;
	2609	 7466	 0.0	 0.049246	 0.0	 642	 642	 642	 0.952901	 0.0	 1	 -30.0	 30.0;
	940	 473	 0.0	 0.05533	 0.0	 571	 571	 571	 0.953216	 0.0	 1	 -30.0	 30.0;
	940	 473	 0.0	 0.05533	 0.0	 571	 571	 571	 0.953216	 0.0	 1	 -30.0	 30.0;
	940	 473	 0.0	 0.05533	 0.0	 571	 571	 571	 0.953216	 0.0	 1	 -30.0	 30.0;
	940	 473	 0.0	 0.05533	 0.0	 571	 571	 571	 0.953216	 0.0	 1	 -30.0	 30.0;
	2889	 5314	 0.0	 0.0735	 0.0	 430	 430	 430	 1.049171	 0.0	 1	 -30.0	 30.0;
	2889	 365	 0.0	 0.07581	 0.0	 417	 417	 417	 1.051303	 0.0	 1	 -30.0	 30.0;
	7166	 11587	 0.0	 0.047975	 0.0	 659	 659	 659	 0.944506	 0.0	 1	 -30.0	 30.0;
	7166	 11587	 0.0	 0.047975	 0.0	 659	 659	 659	 0.944506	 0.0	 1	 -30.0	 30.0;
	10066	 12178	 0.0	 0.2	 0.0	 158	 158	 158	 1.010856	 0.0	 1	 -30.0	 30.0;
	10066	 12401	 0.0	 0.096	 0.0	 330	 330	 330	 1.003951	 0.0	 1	 -30.0	 30.0;
	10066	 11257	 0.0	 0.19355	 0.0	 164	 164	 164	 1.00542	 0.0	 1	 -30.0	 30.0;
	13458	 9855	 0.0	 1.5	 0.0	 22	 22	 22	 1.00524	 0.0	 1	 -30.0	 30.0;
	13458	 11177	 0.0	 1.2	 0.0	 27	 27	 27	 1.003544	 0.0	 1	 -30.0	 30.0;
	13458	 10012	 0.0	 1.2	 0.0	 27	 27	 27	 1.003544	 0.0	 1	 -30.0	 30.0;
	13458	 12358	 0.0	 0.72	 0.0	 44	 44	 44	 1.003756	 0.0	 1	 -30.0	 30.0;
	13458	 8933	 0.0	 0.72	 0.0	 44	 44	 44	 1.001332	 0.0	 1	 -30.0	 30.0;
	13453	 786	 0.0	 0.33333	 0.0	 95	 95	 95	 1.00436	 0.0	 1	 -30.0	 30.0;
	13453	 2852	 0.0	 0.33333	 0.0	 95	 95	 95	 1.004412	 0.0	 1	 -30.0	 30.0;
	13453	 7949	 0.0	 0.33333	 0.0	 95	 95	 95	 1.002165	 0.0	 1	 -30.0	 30.0;
	6535	 7449	 0.0	 0.04407	 0.0	 717	 717	 717	 1.016847	 0.0	 1	 -30.0	 30.0;
	6535	 6836	 0.0	 0.04407	 0.0	 717	 717	 717	 1.016847	 0.0	 1	 -30.0	 30.0;
	6535	 1085	 0.0	 0.04127	 0.0	 766	 766	 766	 1.016745	 0.0	 1	 -30.0	 30.0;
	11937	 2260	 0.0	 0.07869	 0.0	 402	 402	 402	 1.049981	 0.0	 1	 -30.0	 30.0;
	11937	 5965	 0.0	 0.07737	 0.0	 409	 409	 409	 1.049567	 0.0	 1	 -30.0	 30.0;
	7206	 1124	 0.0	 0.0505	 0.0	 626	 626	 626	 0.926937	 0.0	 1	 -30.0	 30.0;
	7206	 1124	 0.0	 0.0505	 0.0	 626	 626	 626	 0.926937	 0.0	 1	 -30.0	 30.0;
	7206	 1124	 0.0	 0.0505	 0.0	 626	 626	 626	 0.926937	 0.0	 1	 -30.0	 30.0;
	1760	 8352	 0.0	 0.3175	 0.0	 100	 100	 100	 1.004459	 0.0	 1	 -30.0	 30.0;
	1760	 7257	 0.0	 0.3175	 0.0	 100	 100	 100	 1.004459	 0.0	 1	 -30.0	 30.0;
	1760	 1959	 0.0	 0.3175	 0.0	 100	 100	 100	 1.004543	 0.0	 1	 -30.0	 30.0;
	10858	 10094	 0.0	 0.04407	 0.0	 717	 717	 717	 1.016852	 0.0	 1	 -30.0	 30.0;
	10858	 2759	 0.0	 0.04407	 0.0	 717	 717	 717	 1.016852	 0.0	 1	 -30.0	 30.0;
	10858	 8388	 0.0	 0.04127	 0.0	 766	 766	 766	 1.016749	 0.0	 1	 -30.0	 30.0;
	10858	 12291	 0.0	 0.04407	 0.0	 717	 717	 717	 1.016852	 0.0	 1	 -30.0	 30.0;
	10858	 7662	 0.0	 0.04407	 0.0	 717	 717	 717	 1.016852	 0.0	 1	 -30.0	 30.0;
	10858	 12248	 0.0	 0.04127	 0.0	 766	 766	 766	 1.016749	 0.0	 1	 -30.0	 30.0;
	12809	 6783	 0.0	 0.048	 0.0	 659	 659	 659	 0.934758	 0.0	 1	 -30.0	 30.0;
	12809	 6783	 0.0	 0.04563	 0.0	 693	 693	 693	 0.944487	 0.0	 1	 -30.0	 30.0;
	12809	 2042	 0.0	 0.049141	 0.0	 643	 643	 643	 0.926102	 0.0	 1	 -30.0	 30.0;
	12809	 2042	 0.0	 0.049141	 0.0	 643	 643	 643	 0.926102	 0.0	 1	 -30.0	 30.0;
	11052	 1007	 0.0	 0.6	 0.0	 53	 53	 53	 0.999671	 0.0	 1	 -30.0	 30.0;
	6706	 10973	 0.0	 0.075	 0.0	 422	 422	 422	 1.004981	 0.0	 1	 -30.0	 30.0;
	12292	 5742	 0.0	 0.044	 0.0	 718	 718	 718	 1.069583	 0.0	 1	 -30.0	 30.0;
	9036	 3682	 0.0	 0.72	 0.0	 44	 44	 44	 0.999922	 0.0	 1	 -30.0	 30.0;
	9036	 11967	 0.0	 2.57143	 0.0	 13	 13	 13	 0.999699	 0.0	 1	 -30.0	 30.0;
	9036	 10052	 0.0	 2.57143	 0.0	 13	 13	 13	 0.999699	 0.0	 1	 -30.0	 30.0;
	9036	 4337	 0.0	 0.57143	 0.0	 56	 56	 56	 0.999727	 0.0	 1	 -30.0	 30.0;
	9036	 8881	 0.0	 1.28571	 0.0	 25	 25	 25	 0.999625	 0.0	 1	 -30.0	 30.0;
	9036	 10757	 0.0	 1.28571	 0.0	 25	 25	 25	 0.999625	 0.0	 1	 -30.0	 30.0;
	9036	 9168	 0.0	 2.85714	 0.0	 12	 12	 12	 0.99887	 0.0	 1	 -30.0	 30.0;
	9036	 1004	 0.0	 2.85714	 0.0	 12	 12	 12	 0.998989	 0.0	 1	 -30.0	 30.0;
	9036	 2784	 0.0	 2.4	 0.0	 14	 14	 14	 0.999025	 0.0	 1	 -30.0	 30.0;
	12897	 6527	 0.0	 0.03908	 0.0	 809	 809	 809	 0.959402	 0.0	 1	 -30.0	 30.0;
	12897	 1822	 0.0	 0.03908	 0.0	 809	 809	 809	 0.959402	 0.0	 1	 -30.0	 30.0;
	12897	 9871	 0.0	 0.03908	 0.0	 809	 809	 809	 0.959226	 0.0	 1	 -30.0	 30.0;
	9026	 151	 0.0	 0.02908	 0.0	 1087	 1087	 1087	 1.006767	 0.0	 1	 -30.0	 30.0;
	9026	 11856	 0.0	 0.02908	 0.0	 1087	 1087	 1087	 1.006641	 0.0	 1	 -30.0	 30.0;
	11710	 4353	 0.0	 0.13618	 0.0	 232	 232	 232	 1.000365	 0.0	 1	 -30.0	 30.0;
	11710	 9628	 0.0	 0.13047	 0.0	 243	 243	 243	 1.000356	 0.0	 1	 -30.0	 30.0;
	11710	 3593	 0.0	 0.13163	 0.0	 240	 240	 240	 1.000327	 0.0	 1	 -30.0	 30.0;
	10277	 9024	 0.0	 0.02908	 0.0	 1087	 1087	 1087	 1.002347	 0.0	 1	 -30.0	 30.0;
	2152	 8433	 0.0	 0.25714	 0.0	 123	 123	 123	 0.998938	 0.0	 1	 -30.0	 30.0;
	2152	 9552	 0.0	 0.45	 0.0	 71	 71	 71	 0.999062	 0.0	 1	 -30.0	 30.0;
	2152	 13075	 0.0	 6.0	 0.0	 6	 6	 6	 0.998562	 0.0	 1	 -30.0	 30.0;
	2152	 315	 0.0	 6.0	 0.0	 6	 6	 6	 0.998562	 0.0	 1	 -30.0	 30.0;
	2683	 5044	 0.0	 0.067933	 0.0	 465	 465	 465	 0.956303	 0.0	 1	 -30.0	 30.0;
	2683	 5044	 0.0	 0.067933	 0.0	 465	 465	 465	 0.956303	 0.0	 1	 -30.0	 30.0;
	2683	 5044	 0.0	 0.047975	 0.0	 659	 659	 659	 0.932939	 0.0	 1	 -30.0	 30.0;
	2226	 7487	 0.0	 0.1978	 0.0	 160	 160	 160	 1.006462	 0.0	 1	 -30.0	 30.0;
	4867	 8193	 0.0	 0.232	 0.0	 137	 137	 137	 1.003527	 0.0	 1	 -30.0	 30.0;
	6791	 8385	 0.0	 0.51429	 0.0	 62	 62	 62	 1.000793	 0.0	 1	 -30.0	 30.0;
	6791	 11281	 0.0	 0.9	 0.0	 36	 36	 36	 1.000918	 0.0	 1	 -30.0	 30.0;
	5266	 6132	 0.0	 0.58065	 0.0	 55	 55	 55	 1.003186	 0.0	 1	 -30.0	 30.0;
	7868	 9722	 0.0	 0.07095	 0.0	 446	 446	 446	 1.041895	 0.0	 1	 -30.0	 30.0;
	7868	 10825	 0.0	 0.07095	 0.0	 446	 446	 446	 1.041895	 0.0	 1	 -30.0	 30.0;
	10758	 2912	 0.0	 0.18462	 0.0	 172	 172	 172	 1.004094	 0.0	 1	 -30.0	 30.0;
	10758	 11502	 0.0	 0.36667	 0.0	 87	 87	 87	 1.00425	 0.0	 1	 -30.0	 30.0;
	8508	 10368	 0.0	 0.08	 0.0	 395	 395	 395	 0.995908	 0.0	 1	 -30.0	 30.0;
	7720	 7255	 0.0	 0.046721	 0.0	 677	 677	 677	 0.940126	 0.0	 1	 -30.0	 30.0;
	7720	 8846	 0.0	 0.06722	 0.0	 470	 470	 470	 0.95944	 0.0	 1	 -30.0	 30.0;
	7720	 9972	 0.0	 0.06722	 0.0	 470	 470	 470	 0.95944	 0.0	 1	 -30.0	 30.0;
	10885	 13630	 0.0	 0.070733	 0.0	 447	 447	 447	 0.929076	 0.0	 1	 -30.0	 30.0;
	10885	 13630	 0.0	 0.07187	 0.0	 440	 440	 440	 0.949888	 0.0	 1	 -30.0	 30.0;
	10885	 2990	 0.0	 0.06667	 0.0	 474	 474	 474	 0.958813	 0.0	 1	 -30.0	 30.0;
	11555	 6383	 0.0	 0.34286	 0.0	 93	 93	 93	 1.003452	 0.0	 1	 -30.0	 30.0;
	11555	 7250	 0.0	 0.72	 0.0	 44	 44	 44	 1.003928	 0.0	 1	 -30.0	 30.0;
	11555	 10409	 0.0	 1.904818	 0.0	 17	 17	 17	 1.000924	 0.0	 1	 -30.0	 30.0;
	11555	 6009	 0.0	 3.0	 0.0	 11	 11	 11	 1.000311	 0.0	 1	 -30.0	 30.0;
	11555	 432	 0.0	 3.0	 0.0	 11	 11	 11	 1.000311	 0.0	 1	 -30.0	 30.0;
	7255	 4208	 0.0	 0.07217	 0.0	 438	 438	 438	 1.00268	 0.0	 1	 -30.0	 30.0;
	10397	 7340	 0.0	 0.06111	 0.0	 517	 517	 517	 1.103098	 0.0	 1	 -30.0	 30.0;
	6771	 6171	 0.0	 0.44444	 0.0	 72	 72	 72	 1.005159	 0.0	 1	 -30.0	 30.0;
	6771	 4235	 0.0	 0.44444	 0.0	 72	 72	 72	 1.005159	 0.0	 1	 -30.0	 30.0;
	6771	 13447	 0.0	 0.44444	 0.0	 72	 72	 72	 1.005159	 0.0	 1	 -30.0	 30.0;
	13258	 1551	 0.0	 0.049246	 0.0	 642	 642	 642	 0.933179	 0.0	 1	 -30.0	 30.0;
	13258	 1551	 0.0	 0.049246	 0.0	 642	 642	 642	 0.933179	 0.0	 1	 -30.0	 30.0;
	13258	 1551	 0.0	 0.049246	 0.0	 642	 642	 642	 0.933179	 0.0	 1	 -30.0	 30.0;
	10601	 5397	 0.0	 0.21315	 0.0	 149	 149	 149	 1.000795	 0.0	 1	 -30.0	 30.0;
	10601	 3432	 0.0	 0.21315	 0.0	 149	 149	 149	 1.000795	 0.0	 1	 -30.0	 30.0;
	10601	 12687	 0.0	 0.21315	 0.0	 149	 149	 149	 1.000629	 0.0	 1	 -30.0	 30.0;
	8778	 9735	 0.0	 0.0505	 0.0	 626	 626	 626	 0.937597	 0.0	 1	 -30.0	 30.0;
	8778	 9735	 0.0	 0.0505	 0.0	 626	 626	 626	 0.937597	 0.0	 1	 -30.0	 30.0;
	8778	 6152	 0.0	 0.046807	 0.0	 675	 675	 675	 0.954913	 0.0	 1	 -30.0	 30.0;
	8778	 6152	 0.0	 0.046807	 0.0	 675	 675	 675	 0.954913	 0.0	 1	 -30.0	 30.0;
	8778	 4408	 0.0	 0.049246	 0.0	 642	 642	 642	 0.944387	 0.0	 1	 -30.0	 30.0;
	8778	 4408	 0.0	 0.049246	 0.0	 642	 642	 642	 0.944387	 0.0	 1	 -30.0	 30.0;
	6700	 3920	 0.0	 0.047975	 0.0	 659	 659	 659	 0.943562	 0.0	 1	 -30.0	 30.0;
	6700	 3920	 0.0	 0.047975	 0.0	 659	 659	 659	 0.943562	 0.0	 1	 -30.0	 30.0;
	6700	 13624	 0.0	 0.0505	 0.0	 626	 626	 626	 0.940759	 0.0	 1	 -30.0	 30.0;
	6700	 13624	 0.0	 0.0505	 0.0	 626	 626	 626	 0.940759	 0.0	 1	 -30.0	 30.0;
	3808	 4320	 0.0	 0.047975	 0.0	 659	 659	 659	 0.946595	 0.0	 1	 -30.0	 30.0;
	3808	 4320	 0.0	 0.047975	 0.0	 659	 659	 659	 0.946595	 0.0	 1	 -30.0	 30.0;
	3808	 4320	 0.0	 0.047975	 0.0	 659	 659	 659	 0.946595	 0.0	 1	 -30.0	 30.0;
	3808	 4320	 0.0	 0.047975	 0.0	 659	 659	 659	 0.946595	 0.0	 1	 -30.0	 30.0;
	9735	 7857	 0.0	 0.5	 0.0	 64	 64	 64	 1.003651	 0.0	 1	 -30.0	 30.0;
	9735	 6784	 0.0	 0.5	 0.0	 64	 64	 64	 1.003651	 0.0	 1	 -30.0	 30.0;
	9735	 1469	 0.0	 0.848	 0.0	 38	 38	 38	 1.003056	 0.0	 1	 -30.0	 30.0;
	9735	 2397	 0.0	 0.848	 0.0	 38	 38	 38	 1.003056	 0.0	 1	 -30.0	 30.0;
	3370	 2645	 0.0	 0.3	 0.0	 106	 106	 106	 1.000521	 0.0	 1	 -30.0	 30.0;
	3370	 9466	 0.0	 0.58065	 0.0	 55	 55	 55	 1.00095	 0.0	 1	 -30.0	 30.0;
	3370	 9223	 0.0	 3.6	 0.0	 9	 9	 9	 1.000776	 0.0	 1	 -30.0	 30.0;
	4565	 12657	 0.0	 2.57143	 0.0	 13	 13	 13	 1.000314	 0.0	 1	 -30.0	 30.0;
	4565	 4643	 0.0	 1.38462	 0.0	 23	 23	 23	 1.000888	 0.0	 1	 -30.0	 30.0;
	4565	 10010	 0.0	 1.38462	 0.0	 23	 23	 23	 1.000888	 0.0	 1	 -30.0	 30.0;
	4565	 11945	 0.0	 1.38462	 0.0	 23	 23	 23	 1.000888	 0.0	 1	 -30.0	 30.0;
	4565	 7768	 0.0	 1.2	 0.0	 27	 27	 27	 1.005163	 0.0	 1	 -30.0	 30.0;
	4565	 2278	 0.0	 2.85714	 0.0	 12	 12	 12	 1.000282	 0.0	 1	 -30.0	 30.0;
	4565	 10693	 0.0	 2.57143	 0.0	 13	 13	 13	 1.000314	 0.0	 1	 -30.0	 30.0;
	4565	 6942	 0.0	 2.57143	 0.0	 13	 13	 13	 1.001212	 0.0	 1	 -30.0	 30.0;
	12068	 1594	 0.0	 0.2	 0.0	 158	 158	 158	 1.005297	 0.0	 1	 -30.0	 30.0;
	12068	 2603	 0.0	 0.2	 0.0	 158	 158	 158	 1.005297	 0.0	 1	 -30.0	 30.0;
	12068	 7921	 0.0	 0.64	 0.0	 50	 50	 50	 1.009116	 0.0	 1	 -30.0	 30.0;
	12068	 7009	 0.0	 0.64	 0.0	 50	 50	 50	 1.008576	 0.0	 1	 -30.0	 30.0;
	12251	 13090	 0.0	 0.04407	 0.0	 717	 717	 717	 1.014872	 0.0	 1	 -30.0	 30.0;
	12251	 11492	 0.0	 0.04407	 0.0	 717	 717	 717	 1.014872	 0.0	 1	 -30.0	 30.0;
	12251	 3179	 0.0	 0.04127	 0.0	 766	 766	 766	 1.01484	 0.0	 1	 -30.0	 30.0;
	12251	 1150	 0.0	 0.04407	 0.0	 717	 717	 717	 1.014872	 0.0	 1	 -30.0	 30.0;
	12251	 9364	 0.0	 0.04407	 0.0	 717	 717	 717	 1.014872	 0.0	 1	 -30.0	 30.0;
	12251	 7489	 0.0	 0.04127	 0.0	 766	 766	 766	 1.01484	 0.0	 1	 -30.0	 30.0;
	11740	 12873	 0.0	 0.4375	 0.0	 73	 73	 73	 1.001373	 0.0	 1	 -30.0	 30.0;
	11740	 7213	 0.0	 0.4375	 0.0	 73	 73	 73	 1.001373	 0.0	 1	 -30.0	 30.0;
	11740	 11138	 0.0	 0.20635	 0.0	 154	 154	 154	 1.000822	 0.0	 1	 -30.0	 30.0;
	11740	 10006	 0.0	 0.20635	 0.0	 154	 154	 154	 1.000822	 0.0	 1	 -30.0	 30.0;
	11740	 958	 0.0	 0.20635	 0.0	 154	 154	 154	 1.000822	 0.0	 1	 -30.0	 30.0;
	11740	 13550	 0.0	 0.20635	 0.0	 154	 154	 154	 1.000822	 0.0	 1	 -30.0	 30.0;
	11740	 8141	 0.0	 0.4127	 0.0	 77	 77	 77	 1.001174	 0.0	 1	 -30.0	 30.0;
	11740	 7068	 0.0	 0.4127	 0.0	 77	 77	 77	 1.001174	 0.0	 1	 -30.0	 30.0;
	11740	 12375	 0.0	 0.05778	 0.0	 547	 547	 547	 1.000444	 0.0	 1	 -30.0	 30.0;
	3973	 10061	 0.0	 0.05643	 0.0	 560	 560	 560	 0.97594	 0.0	 1	 -30.0	 30.0;
	3973	 10061	 0.0	 0.040627	 0.0	 778	 778	 778	 0.996982	 0.0	 1	 -30.0	 30.0;
	3973	 3178	 0.0	 0.0565	 0.0	 560	 560	 560	 1.047506	 0.0	 1	 -30.0	 30.0;
	3973	 8499	 0.0	 0.0565	 0.0	 560	 560	 560	 1.047506	 0.0	 1	 -30.0	 30.0;
	3973	 10473	 0.0	 0.0565	 0.0	 560	 560	 560	 1.047506	 0.0	 1	 -30.0	 30.0;
	3973	 2106	 0.0	 0.0565	 0.0	 560	 560	 560	 1.047506	 0.0	 1	 -30.0	 30.0;
	12660	 12989	 0.0	 0.25714	 0.0	 123	 123	 123	 1.004944	 0.0	 1	 -30.0	 30.0;
	12660	 717	 0.0	 0.36	 0.0	 88	 88	 88	 1.004784	 0.0	 1	 -30.0	 30.0;
	12660	 2268	 0.0	 0.58065	 0.0	 55	 55	 55	 1.004857	 0.0	 1	 -30.0	 30.0;
	1280	 6199	 0.0	 0.31579	 0.0	 101	 101	 101	 1.003857	 0.0	 1	 -30.0	 30.0;
	6755	 2223	 0.0	 0.32024	 0.0	 99	 99	 99	 1.013741	 0.0	 1	 -30.0	 30.0;
	6755	 8157	 0.0	 0.32024	 0.0	 99	 99	 99	 1.013741	 0.0	 1	 -30.0	 30.0;
	6755	 13549	 0.0	 0.32024	 0.0	 99	 99	 99	 1.013741	 0.0	 1	 -30.0	 30.0;
	3841	 602	 0.0	 0.049246	 0.0	 642	 642	 642	 0.949121	 0.0	 1	 -30.0	 30.0;
	3841	 602	 0.0	 0.049246	 0.0	 642	 642	 642	 0.949121	 0.0	 1	 -30.0	 30.0;
	602	 12189	 0.0	 0.6	 0.0	 53	 53	 53	 1.007356	 0.0	 1	 -30.0	 30.0;
	602	 3880	 0.0	 0.6	 0.0	 53	 53	 53	 1.007356	 0.0	 1	 -30.0	 30.0;
	602	 1907	 0.0	 0.6	 0.0	 53	 53	 53	 1.007356	 0.0	 1	 -30.0	 30.0;
	602	 4196	 0.0	 2.4	 0.0	 14	 14	 14	 1.001354	 0.0	 1	 -30.0	 30.0;
	602	 6130	 0.0	 2.4	 0.0	 14	 14	 14	 1.001354	 0.0	 1	 -30.0	 30.0;
	6504	 1526	 0.0	 0.476	 0.0	 67	 67	 67	 1.044767	 0.0	 1	 -30.0	 30.0;
	6504	 4823	 0.0	 0.476	 0.0	 67	 67	 67	 1.044767	 0.0	 1	 -30.0	 30.0;
	10586	 6038	 0.0	 0.06	 0.0	 527	 527	 527	 0.999935	 0.0	 1	 -30.0	 30.0;
	10586	 3926	 0.0	 0.06	 0.0	 527	 527	 527	 1.00054	 0.0	 1	 -30.0	 30.0;
	10586	 12367	 0.0	 0.06	 0.0	 527	 527	 527	 0.999935	 0.0	 1	 -30.0	 30.0;
	1297	 5818	 0.0	 0.092641	 0.0	 341	 341	 341	 0.954139	 0.0	 1	 -30.0	 30.0;
	1297	 5818	 0.0	 0.092641	 0.0	 341	 341	 341	 0.954139	 0.0	 1	 -30.0	 30.0;
	1297	 5818	 0.0	 0.05415	 0.0	 584	 584	 584	 0.957465	 0.0	 1	 -30.0	 30.0;
	1297	 12199	 0.0	 0.05478	 0.0	 577	 577	 577	 1.000751	 0.0	 1	 -30.0	 30.0;
	1297	 6822	 0.0	 0.05478	 0.0	 577	 577	 577	 1.000751	 0.0	 1	 -30.0	 30.0;
	12110	 2567	 0.0	 0.044468	 0.0	 711	 711	 711	 0.960487	 0.0	 1	 -30.0	 30.0;
	12110	 2567	 0.0	 0.044468	 0.0	 711	 711	 711	 0.960487	 0.0	 1	 -30.0	 30.0;
	12110	 9195	 0.0	 0.05439	 0.0	 581	 581	 581	 0.999891	 0.0	 1	 -30.0	 30.0;
	12110	 3939	 0.0	 0.05439	 0.0	 581	 581	 581	 0.999891	 0.0	 1	 -30.0	 30.0;
	6037	 5202	 0.0	 0.28806	 0.0	 110	 110	 110	 1.004211	 0.0	 1	 -30.0	 30.0;
	6037	 552	 0.0	 0.28806	 0.0	 110	 110	 110	 1.004211	 0.0	 1	 -30.0	 30.0;
	10259	 4423	 0.0	 4.5	 0.0	 8	 8	 8	 0.999295	 0.0	 1	 -30.0	 30.0;
	10259	 8010	 0.0	 0.72	 0.0	 44	 44	 44	 1.000103	 0.0	 1	 -30.0	 30.0;
	10259	 6200	 0.0	 1.44	 0.0	 22	 22	 22	 0.999879	 0.0	 1	 -30.0	 30.0;
	10259	 6864	 0.0	 4.5	 0.0	 8	 8	 8	 0.999295	 0.0	 1	 -30.0	 30.0;
	10259	 8654	 0.0	 4.5	 0.0	 8	 8	 8	 0.999295	 0.0	 1	 -30.0	 30.0;
	10259	 7261	 0.0	 4.5	 0.0	 8	 8	 8	 0.999295	 0.0	 1	 -30.0	 30.0;
	10259	 9413	 0.0	 4.5	 0.0	 8	 8	 8	 0.999295	 0.0	 1	 -30.0	 30.0;
	10259	 2341	 0.0	 4.5	 0.0	 8	 8	 8	 0.999295	 0.0	 1	 -30.0	 30.0;
	10259	 13551	 0.0	 4.5	 0.0	 8	 8	 8	 0.999295	 0.0	 1	 -30.0	 30.0;
	10259	 11440	 0.0	 4.5	 0.0	 8	 8	 8	 0.999295	 0.0	 1	 -30.0	 30.0;
	10259	 8916	 0.0	 4.5	 0.0	 8	 8	 8	 0.999295	 0.0	 1	 -30.0	 30.0;
	10259	 6314	 0.0	 4.5	 0.0	 8	 8	 8	 0.999295	 0.0	 1	 -30.0	 30.0;
	10259	 8122	 0.0	 4.5	 0.0	 8	 8	 8	 0.999295	 0.0	 1	 -30.0	 30.0;
	10259	 12748	 0.0	 4.5	 0.0	 8	 8	 8	 0.999295	 0.0	 1	 -30.0	 30.0;
	10259	 11311	 0.0	 3.6	 0.0	 9	 9	 9	 0.997684	 0.0	 1	 -30.0	 30.0;
	10259	 4488	 0.0	 3.6	 0.0	 9	 9	 9	 0.997684	 0.0	 1	 -30.0	 30.0;
	10259	 9748	 0.0	 3.6	 0.0	 9	 9	 9	 0.997684	 0.0	 1	 -30.0	 30.0;
	2096	 1642	 0.0	 0.72	 0.0	 44	 44	 44	 1.001132	 0.0	 1	 -30.0	 30.0;
	12975	 10988	 0.0	 0.047975	 0.0	 659	 659	 659	 0.939465	 0.0	 1	 -30.0	 30.0;
	12975	 10988	 0.0	 0.047975	 0.0	 659	 659	 659	 0.939465	 0.0	 1	 -30.0	 30.0;
	12975	 10988	 0.0	 0.047975	 0.0	 659	 659	 659	 0.939465	 0.0	 1	 -30.0	 30.0;
	10988	 94	 0.0	 0.375	 0.0	 85	 85	 85	 1.00764	 0.0	 1	 -30.0	 30.0;
	1579	 9166	 0.0	 0.4969	 0.0	 64	 64	 64	 1.001278	 0.0	 1	 -30.0	 30.0;
	6966	 7416	 0.0	 0.37826	 0.0	 84	 84	 84	 1.001164	 0.0	 1	 -30.0	 30.0;
	6966	 12816	 0.0	 0.37826	 0.0	 84	 84	 84	 1.001164	 0.0	 1	 -30.0	 30.0;
	6966	 270	 0.0	 0.37826	 0.0	 84	 84	 84	 1.001164	 0.0	 1	 -30.0	 30.0;
	484	 12499	 0.0	 0.72	 0.0	 44	 44	 44	 1.007465	 0.0	 1	 -30.0	 30.0;
	2188	 2721	 0.0	 0.69231	 0.0	 46	 46	 46	 1.006393	 0.0	 1	 -30.0	 30.0;
	10975	 7879	 0.0	 0.047975	 0.0	 659	 659	 659	 0.953084	 0.0	 1	 -30.0	 30.0;
	10975	 7879	 0.0	 0.047975	 0.0	 659	 659	 659	 0.953084	 0.0	 1	 -30.0	 30.0;
	10975	 7879	 0.0	 0.047975	 0.0	 659	 659	 659	 0.953084	 0.0	 1	 -30.0	 30.0;
	10975	 4085	 0.0	 2.57143	 0.0	 13	 13	 13	 0.999195	 0.0	 1	 -30.0	 30.0;
	10975	 11859	 0.0	 2.57143	 0.0	 13	 13	 13	 0.999195	 0.0	 1	 -30.0	 30.0;
	10975	 1329	 0.0	 2.57143	 0.0	 13	 13	 13	 0.999195	 0.0	 1	 -30.0	 30.0;
	10975	 9804	 0.0	 0.72	 0.0	 44	 44	 44	 0.999	 0.0	 1	 -30.0	 30.0;
	10975	 9638	 0.0	 0.72	 0.0	 44	 44	 44	 0.999	 0.0	 1	 -30.0	 30.0;
	2037	 8559	 0.0	 0.16	 0.0	 198	 198	 198	 0.999995	 0.0	 1	 -30.0	 30.0;
	2037	 13200	 0.0	 0.16	 0.0	 198	 198	 198	 0.999995	 0.0	 1	 -30.0	 30.0;
	2824	 11990	 0.0	 0.48	 0.0	 66	 66	 66	 1.003518	 0.0	 1	 -30.0	 30.0;
	2824	 3371	 0.0	 0.48	 0.0	 66	 66	 66	 1.003518	 0.0	 1	 -30.0	 30.0;
	10109	 779	 0.0	 0.48	 0.0	 66	 66	 66	 0.997126	 0.0	 1	 -30.0	 30.0;
	10109	 8980	 0.0	 0.48	 0.0	 66	 66	 66	 0.997126	 0.0	 1	 -30.0	 30.0;
	215	 8514	 0.0	 0.06556	 0.0	 482	 482	 482	 0.953866	 0.0	 1	 -30.0	 30.0;
	215	 8514	 0.0	 0.0472	 0.0	 670	 670	 670	 0.955722	 0.0	 1	 -30.0	 30.0;
	215	 13218	 0.0	 0.07873	 0.0	 402	 402	 402	 0.960191	 0.0	 1	 -30.0	 30.0;
	215	 7751	 0.0	 0.07873	 0.0	 402	 402	 402	 0.960191	 0.0	 1	 -30.0	 30.0;
	215	 5964	 0.0	 0.07873	 0.0	 402	 402	 402	 0.960191	 0.0	 1	 -30.0	 30.0;
	215	 12050	 0.0	 0.07873	 0.0	 402	 402	 402	 0.960191	 0.0	 1	 -30.0	 30.0;
	7953	 9965	 0.0	 0.075233	 0.0	 420	 420	 420	 0.934284	 0.0	 1	 -30.0	 30.0;
	7953	 9965	 0.0	 0.043977	 0.0	 719	 719	 719	 0.941255	 0.0	 1	 -30.0	 30.0;
	7953	 9965	 0.0	 0.043977	 0.0	 719	 719	 719	 0.941255	 0.0	 1	 -30.0	 30.0;
	7953	 9965	 0.0	 0.043977	 0.0	 719	 719	 719	 0.941255	 0.0	 1	 -30.0	 30.0;
	10274	 746	 0.0	 0.6	 0.0	 53	 53	 53	 1.005532	 0.0	 1	 -30.0	 30.0;
	10274	 13112	 0.0	 0.6	 0.0	 53	 53	 53	 1.005865	 0.0	 1	 -30.0	 30.0;
	10490	 10955	 0.0	 0.047783	 0.0	 662	 662	 662	 0.944157	 0.0	 1	 -30.0	 30.0;
	10490	 10955	 0.0	 0.046807	 0.0	 675	 675	 675	 0.944034	 0.0	 1	 -30.0	 30.0;
	11742	 6042	 0.0	 0.071122	 0.0	 445	 445	 445	 0.940129	 0.0	 1	 -30.0	 30.0;
	11742	 6042	 0.0	 0.071122	 0.0	 445	 445	 445	 0.940129	 0.0	 1	 -30.0	 30.0;
	11742	 6042	 0.0	 0.07796	 0.0	 406	 406	 406	 0.938946	 0.0	 1	 -30.0	 30.0;
	11742	 6042	 0.0	 0.07796	 0.0	 406	 406	 406	 0.938946	 0.0	 1	 -30.0	 30.0;
	1569	 8488	 0.0	 0.78261	 0.0	 41	 41	 41	 1.005671	 0.0	 1	 -30.0	 30.0;
	1569	 6192	 0.0	 0.5	 0.0	 64	 64	 64	 1.00581	 0.0	 1	 -30.0	 30.0;
	1569	 4796	 0.0	 0.58065	 0.0	 55	 55	 55	 1.005662	 0.0	 1	 -30.0	 30.0;
	1119	 9504	 0.0	 0.17857	 0.0	 177	 177	 177	 1.041054	 0.0	 1	 -30.0	 30.0;
	1119	 11630	 0.0	 0.17857	 0.0	 177	 177	 177	 1.041054	 0.0	 1	 -30.0	 30.0;
	1119	 2237	 0.0	 0.17857	 0.0	 177	 177	 177	 1.041054	 0.0	 1	 -30.0	 30.0;
	2589	 10783	 0.0	 0.13139	 0.0	 241	 241	 241	 1.008548	 0.0	 1	 -30.0	 30.0;
	2765	 10814	 0.0	 0.064	 0.0	 494	 494	 494	 1.057613	 0.0	 1	 -30.0	 30.0;
	2765	 5576	 0.0	 0.064	 0.0	 494	 494	 494	 1.057613	 0.0	 1	 -30.0	 30.0;
	2765	 7381	 0.0	 0.064	 0.0	 494	 494	 494	 1.057613	 0.0	 1	 -30.0	 30.0;
	10781	 2428	 0.0	 0.18462	 0.0	 172	 172	 172	 1.022911	 0.0	 1	 -30.0	 30.0;
	10781	 6680	 0.0	 0.18462	 0.0	 172	 172	 172	 1.022911	 0.0	 1	 -30.0	 30.0;
	10781	 11935	 0.0	 0.18462	 0.0	 172	 172	 172	 1.022911	 0.0	 1	 -30.0	 30.0;
	8624	 4124	 0.0	 0.046721	 0.0	 677	 677	 677	 0.953764	 0.0	 1	 -30.0	 30.0;
	4124	 2131	 0.0	 0.26714	 0.0	 119	 119	 119	 1.032058	 0.0	 1	 -30.0	 30.0;
	4124	 3968	 0.0	 0.26714	 0.0	 119	 119	 119	 1.032058	 0.0	 1	 -30.0	 30.0;
	4124	 12398	 0.0	 0.26714	 0.0	 119	 119	 119	 1.032058	 0.0	 1	 -30.0	 30.0;
	4124	 296	 0.0	 0.16422	 0.0	 193	 193	 193	 1.024502	 0.0	 1	 -30.0	 30.0;
	4124	 4917	 0.0	 0.14687	 0.0	 216	 216	 216	 1.024545	 0.0	 1	 -30.0	 30.0;
	4124	 2933	 0.0	 0.29375	 0.0	 108	 108	 108	 1.024756	 0.0	 1	 -30.0	 30.0;
	7292	 12829	 0.0	 0.15856	 0.0	 200	 200	 200	 1.091237	 0.0	 1	 -30.0	 30.0;
	7292	 10298	 0.0	 0.15856	 0.0	 200	 200	 200	 1.091237	 0.0	 1	 -30.0	 30.0;
	9639	 10376	 0.0	 0.14697	 0.0	 215	 215	 215	 1.106586	 0.0	 1	 -30.0	 30.0;
	4017	 7556	 0.0	 0.11733	 0.0	 270	 270	 270	 1.049659	 0.0	 1	 -30.0	 30.0;
	4017	 8644	 0.0	 0.11733	 0.0	 270	 270	 270	 1.049659	 0.0	 1	 -30.0	 30.0;
	4017	 400	 0.0	 0.11733	 0.0	 270	 270	 270	 1.049659	 0.0	 1	 -30.0	 30.0;
	10018	 8485	 0.0	 0.047975	 0.0	 659	 659	 659	 0.934634	 0.0	 1	 -30.0	 30.0;
	10018	 278	 0.0	 0.02519	 0.0	 1254	 1254	 1254	 0.993885	 0.0	 1	 -30.0	 30.0;
	10018	 12579	 0.0	 0.02519	 0.0	 1254	 1254	 1254	 0.993885	 0.0	 1	 -30.0	 30.0;
	191	 3200	 0.0	 0.046721	 0.0	 677	 677	 677	 0.955214	 0.0	 1	 -30.0	 30.0;
	3200	 3738	 0.0	 0.35294	 0.0	 90	 90	 90	 1.005834	 0.0	 1	 -30.0	 30.0;
	2762	 7705	 0.0	 0.18138	 0.0	 175	 175	 175	 1.00027	 0.0	 1	 -30.0	 30.0;
	2762	 5826	 0.0	 0.37167	 0.0	 85	 85	 85	 1.000451	 0.0	 1	 -30.0	 30.0;
	11766	 2215	 0.0	 0.18369	 0.0	 172	 172	 172	 1.002293	 0.0	 1	 -30.0	 30.0;
	11766	 10295	 0.0	 0.18369	 0.0	 172	 172	 172	 1.002293	 0.0	 1	 -30.0	 30.0;
	11766	 12949	 0.0	 0.18462	 0.0	 172	 172	 172	 1.002308	 0.0	 1	 -30.0	 30.0;
	7883	 2270	 0.0	 0.48	 0.0	 66	 66	 66	 1.002552	 0.0	 1	 -30.0	 30.0;
	13168	 8413	 0.0	 0.24	 0.0	 132	 132	 132	 1.005389	 0.0	 1	 -30.0	 30.0;
	2477	 13	 0.0	 0.046721	 0.0	 677	 677	 677	 0.915966	 0.0	 1	 -30.0	 30.0;
	2477	 7743	 0.0	 0.06667	 0.0	 474	 474	 474	 0.998525	 0.0	 1	 -30.0	 30.0;
	2477	 12287	 0.0	 0.06667	 0.0	 474	 474	 474	 0.998525	 0.0	 1	 -30.0	 30.0;
	2477	 539	 0.0	 0.06667	 0.0	 474	 474	 474	 0.998558	 0.0	 1	 -30.0	 30.0;
	2477	 8830	 0.0	 0.06667	 0.0	 474	 474	 474	 0.998558	 0.0	 1	 -30.0	 30.0;
	9769	 2071	 0.0	 0.13491	 0.0	 235	 235	 235	 0.972785	 0.0	 1	 -30.0	 30.0;
	9769	 294	 0.0	 0.13491	 0.0	 235	 235	 235	 0.972785	 0.0	 1	 -30.0	 30.0;
	3045	 3562	 0.0	 0.08407	 0.0	 376	 376	 376	 0.94294	 0.0	 1	 -30.0	 30.0;
	3045	 3562	 0.0	 0.08407	 0.0	 376	 376	 376	 0.94294	 0.0	 1	 -30.0	 30.0;
	3045	 3562	 0.0	 0.08407	 0.0	 376	 376	 376	 0.94294	 0.0	 1	 -30.0	 30.0;
	7209	 8808	 0.0	 0.050122	 0.0	 631	 631	 631	 0.921038	 0.0	 1	 -30.0	 30.0;
	7209	 8808	 0.0	 0.050122	 0.0	 631	 631	 631	 0.921038	 0.0	 1	 -30.0	 30.0;
	7209	 5233	 0.0	 0.047176	 0.0	 670	 670	 670	 0.93698	 0.0	 1	 -30.0	 30.0;
	7209	 5233	 0.0	 0.047176	 0.0	 670	 670	 670	 0.93698	 0.0	 1	 -30.0	 30.0;
	7769	 8166	 0.0	 0.046721	 0.0	 677	 677	 677	 0.935115	 0.0	 1	 -30.0	 30.0;
	7769	 6958	 0.0	 0.046721	 0.0	 677	 677	 677	 0.949484	 0.0	 1	 -30.0	 30.0;
	11188	 10433	 0.0	 1.28571	 0.0	 25	 25	 25	 1.00172	 0.0	 1	 -30.0	 30.0;
	11188	 10237	 0.0	 3.6	 0.0	 9	 9	 9	 1.000963	 0.0	 1	 -30.0	 30.0;
	11188	 5000	 0.0	 3.6	 0.0	 9	 9	 9	 1.000963	 0.0	 1	 -30.0	 30.0;
	3317	 3315	 0.0	 0.053184	 0.0	 594	 594	 594	 0.921665	 0.0	 1	 -30.0	 30.0;
	3317	 3315	 0.0	 0.053184	 0.0	 594	 594	 594	 0.921665	 0.0	 1	 -30.0	 30.0;
	3317	 3315	 0.0	 0.053184	 0.0	 594	 594	 594	 0.921665	 0.0	 1	 -30.0	 30.0;
	2704	 11970	 0.0	 0.46	 0.0	 69	 69	 69	 1.000449	 0.0	 1	 -30.0	 30.0;
	2704	 11329	 0.0	 0.46	 0.0	 69	 69	 69	 1.000449	 0.0	 1	 -30.0	 30.0;
	9369	 7577	 0.0	 0.47727	 0.0	 67	 67	 67	 1.011462	 0.0	 1	 -30.0	 30.0;
	9369	 12966	 0.0	 0.47727	 0.0	 67	 67	 67	 1.011462	 0.0	 1	 -30.0	 30.0;
	9369	 1245	 0.0	 0.47727	 0.0	 67	 67	 67	 1.011462	 0.0	 1	 -30.0	 30.0;
	6730	 12658	 0.0	 0.203316	 0.0	 156	 156	 156	 1.088237	 0.0	 1	 -30.0	 30.0;
	6730	 5484	 0.0	 0.203316	 0.0	 156	 156	 156	 1.088237	 0.0	 1	 -30.0	 30.0;
	6730	 9975	 0.0	 0.230069	 0.0	 138	 138	 138	 1.088163	 0.0	 1	 -30.0	 30.0;
	6730	 12736	 0.0	 0.230069	 0.0	 138	 138	 138	 1.088163	 0.0	 1	 -30.0	 30.0;
	8166	 3294	 0.0	 0.05072	 0.0	 623	 623	 623	 1.044425	 0.0	 1	 -30.0	 30.0;
	6958	 10211	 0.0	 0.05072	 0.0	 623	 623	 623	 1.039783	 0.0	 1	 -30.0	 30.0;
	6958	 12204	 0.0	 0.03627	 0.0	 871	 871	 871	 1.038345	 0.0	 1	 -30.0	 30.0;
	5533	 10951	 0.0	 0.1975	 0.0	 160	 160	 160	 1.035836	 0.0	 1	 -30.0	 30.0;
	5533	 9836	 0.0	 0.61222	 0.0	 52	 52	 52	 1.03548	 0.0	 1	 -30.0	 30.0;
	1652	 12608	 0.0	 0.0505	 0.0	 626	 626	 626	 0.935308	 0.0	 1	 -30.0	 30.0;
	1652	 12608	 0.0	 0.0505	 0.0	 626	 626	 626	 0.935308	 0.0	 1	 -30.0	 30.0;
	11647	 12154	 0.0	 0.119999	 0.0	 264	 264	 264	 0.929754	 0.0	 1	 -30.0	 30.0;
	11647	 12154	 0.0	 0.119999	 0.0	 264	 264	 264	 0.929754	 0.0	 1	 -30.0	 30.0;
	10880	 10276	 0.0	 0.877958	 0.0	 36	 36	 36	 1.044843	 0.0	 1	 -30.0	 30.0;
	10880	 9151	 0.0	 0.877958	 0.0	 36	 36	 36	 1.044843	 0.0	 1	 -30.0	 30.0;
	10880	 3848	 0.0	 0.877958	 0.0	 36	 36	 36	 1.044843	 0.0	 1	 -30.0	 30.0;
	10777	 4704	 0.0	 0.114122	 0.0	 277	 277	 277	 1.05908	 0.0	 1	 -30.0	 30.0;
	10777	 8060	 0.0	 0.114122	 0.0	 277	 277	 277	 1.05908	 0.0	 1	 -30.0	 30.0;
	639	 11020	 0.0	 1.366834	 0.0	 24	 24	 24	 1.002255	 0.0	 1	 -30.0	 30.0;
	639	 10114	 0.0	 1.366834	 0.0	 24	 24	 24	 1.002255	 0.0	 1	 -30.0	 30.0;
	639	 13617	 0.0	 1.366834	 0.0	 24	 24	 24	 1.002255	 0.0	 1	 -30.0	 30.0;
	5985	 4331	 0.0	 0.19048	 0.0	 166	 166	 166	 1.00432	 0.0	 1	 -30.0	 30.0;
	5985	 3567	 0.0	 0.19048	 0.0	 166	 166	 166	 1.00432	 0.0	 1	 -30.0	 30.0;
	6395	 6396	 0.0	 0.074556	 0.0	 424	 424	 424	 0.942552	 0.0	 1	 -30.0	 30.0;
	6395	 6396	 0.0	 0.074556	 0.0	 424	 424	 424	 0.942552	 0.0	 1	 -30.0	 30.0;
	6395	 6396	 0.0	 0.074556	 0.0	 424	 424	 424	 0.942552	 0.0	 1	 -30.0	 30.0;
	6395	 6396	 0.0	 0.078311	 0.0	 404	 404	 404	 0.941811	 0.0	 1	 -30.0	 30.0;
	13337	 7710	 0.0	 0.04602	 0.0	 687	 687	 687	 0.948826	 0.0	 1	 -30.0	 30.0;
	13337	 7710	 0.0	 0.08441	 0.0	 375	 375	 375	 0.953818	 0.0	 1	 -30.0	 30.0;
	5684	 7641	 0.0	 0.2685	 0.0	 118	 118	 118	 0.999855	 0.0	 1	 -30.0	 30.0;
	5684	 1059	 0.0	 0.2685	 0.0	 118	 118	 118	 0.999855	 0.0	 1	 -30.0	 30.0;
	5684	 4267	 0.0	 0.2685	 0.0	 118	 118	 118	 0.999855	 0.0	 1	 -30.0	 30.0;
	5684	 13195	 0.0	 0.2685	 0.0	 118	 118	 118	 0.999855	 0.0	 1	 -30.0	 30.0;
	12215	 8023	 0.0	 0.24895	 0.0	 127	 127	 127	 1.043206	 0.0	 1	 -30.0	 30.0;
	12215	 13096	 0.0	 0.24895	 0.0	 127	 127	 127	 1.043206	 0.0	 1	 -30.0	 30.0;
	598	 13159	 0.0	 1.5	 0.0	 22	 22	 22	 1.000288	 0.0	 1	 -30.0	 30.0;
	11683	 3184	 0.0	 0.375	 0.0	 85	 85	 85	 1.001588	 0.0	 1	 -30.0	 30.0;
	11683	 2122	 0.0	 0.375	 0.0	 85	 85	 85	 1.001588	 0.0	 1	 -30.0	 30.0;
	11683	 10501	 0.0	 0.375	 0.0	 85	 85	 85	 1.001588	 0.0	 1	 -30.0	 30.0;
	1942	 11059	 0.0	 0.2	 0.0	 158	 158	 158	 1.001002	 0.0	 1	 -30.0	 30.0;
	1942	 9995	 0.0	 0.2	 0.0	 158	 158	 158	 1.001002	 0.0	 1	 -30.0	 30.0;
	1942	 4775	 0.0	 0.2	 0.0	 158	 158	 158	 1.001002	 0.0	 1	 -30.0	 30.0;
	1942	 7329	 0.0	 0.24	 0.0	 132	 132	 132	 1.001052	 0.0	 1	 -30.0	 30.0;
	2748	 12569	 0.0	 0.06561	 0.0	 482	 482	 482	 0.952731	 0.0	 1	 -30.0	 30.0;
	2748	 12569	 0.0	 0.07333	 0.0	 431	 431	 431	 0.952342	 0.0	 1	 -30.0	 30.0;
	2748	 5418	 0.0	 0.8	 0.0	 40	 40	 40	 0.999778	 0.0	 1	 -30.0	 30.0;
	6270	 10057	 0.0	 0.16667	 0.0	 190	 190	 190	 0.999878	 0.0	 1	 -30.0	 30.0;
	6270	 5645	 0.0	 0.16667	 0.0	 190	 190	 190	 0.999878	 0.0	 1	 -30.0	 30.0;
	6270	 3686	 0.0	 0.16667	 0.0	 190	 190	 190	 0.999878	 0.0	 1	 -30.0	 30.0;
	2162	 8728	 0.0	 0.049246	 0.0	 642	 642	 642	 0.946587	 0.0	 1	 -30.0	 30.0;
	2162	 8728	 0.0	 0.049246	 0.0	 642	 642	 642	 0.946587	 0.0	 1	 -30.0	 30.0;
	13050	 2566	 0.0	 0.2	 0.0	 158	 158	 158	 1.000358	 0.0	 1	 -30.0	 30.0;
	8641	 8930	 0.0	 0.047975	 0.0	 659	 659	 659	 0.948254	 0.0	 1	 -30.0	 30.0;
	8641	 8930	 0.0	 0.082076	 0.0	 385	 385	 385	 0.938336	 0.0	 1	 -30.0	 30.0;
	8641	 8930	 0.0	 0.047975	 0.0	 659	 659	 659	 0.948254	 0.0	 1	 -30.0	 30.0;
	4474	 13087	 0.0	 0.56833	 0.0	 56	 56	 56	 1.000658	 0.0	 1	 -30.0	 30.0;
	4474	 3488	 0.0	 0.56833	 0.0	 56	 56	 56	 1.000658	 0.0	 1	 -30.0	 30.0;
	7119	 7430	 0.0	 0.3125	 0.0	 102	 102	 102	 1.000861	 0.0	 1	 -30.0	 30.0;
	7119	 5494	 0.0	 0.3125	 0.0	 102	 102	 102	 1.000861	 0.0	 1	 -30.0	 30.0;
	8539	 8896	 0.0	 0.34483	 0.0	 92	 92	 92	 1.001408	 0.0	 1	 -30.0	 30.0;
	8539	 7052	 0.0	 0.34276	 0.0	 93	 93	 93	 1.001407	 0.0	 1	 -30.0	 30.0;
	8026	 9927	 0.0	 0.076827	 0.0	 412	 412	 412	 0.958258	 0.0	 1	 -30.0	 30.0;
	8026	 9927	 0.0	 0.049734	 0.0	 636	 636	 636	 0.934397	 0.0	 1	 -30.0	 30.0;
	8026	 51	 0.0	 0.06477	 0.0	 488	 488	 488	 0.952478	 0.0	 1	 -30.0	 30.0;
	8026	 1821	 0.0	 0.06477	 0.0	 488	 488	 488	 0.952478	 0.0	 1	 -30.0	 30.0;
	8026	 10177	 0.0	 0.06477	 0.0	 488	 488	 488	 0.952478	 0.0	 1	 -30.0	 30.0;
	2129	 8449	 0.0	 0.0808	 0.0	 391	 391	 391	 0.974141	 0.0	 1	 -30.0	 30.0;
	2129	 8449	 0.0	 0.073292	 0.0	 431	 431	 431	 0.933547	 0.0	 1	 -30.0	 30.0;
	2129	 8449	 0.0	 0.08451	 0.0	 374	 374	 374	 0.948635	 0.0	 1	 -30.0	 30.0;
	2129	 8449	 0.0	 0.073292	 0.0	 431	 431	 431	 0.933547	 0.0	 1	 -30.0	 30.0;
	2129	 4261	 0.0	 0.04444	 0.0	 711	 711	 711	 0.987595	 0.0	 1	 -30.0	 30.0;
	2129	 299	 0.0	 0.04444	 0.0	 711	 711	 711	 0.987595	 0.0	 1	 -30.0	 30.0;
	2129	 8561	 0.0	 0.04138	 0.0	 764	 764	 764	 0.987505	 0.0	 1	 -30.0	 30.0;
	10819	 2860	 0.0	 0.047975	 0.0	 659	 659	 659	 0.936384	 0.0	 1	 -30.0	 30.0;
	10819	 2860	 0.0	 0.047975	 0.0	 659	 659	 659	 0.936384	 0.0	 1	 -30.0	 30.0;
	4820	 8179	 0.0	 0.1156	 0.0	 274	 274	 274	 0.957383	 0.0	 1	 -30.0	 30.0;
	4820	 2717	 0.0	 0.1156	 0.0	 274	 274	 274	 0.957327	 0.0	 1	 -30.0	 30.0;
	4820	 5905	 0.0	 0.1156	 0.0	 274	 274	 274	 0.957177	 0.0	 1	 -30.0	 30.0;
	11964	 4983	 0.0	 0.96	 0.0	 33	 33	 33	 1.000142	 0.0	 1	 -30.0	 30.0;
	5820	 671	 0.0	 0.44643	 0.0	 71	 71	 71	 1.006575	 0.0	 1	 -30.0	 30.0;
	5820	 1180	 0.0	 0.44643	 0.0	 71	 71	 71	 1.006575	 0.0	 1	 -30.0	 30.0;
	5820	 12558	 0.0	 1.24627	 0.0	 26	 26	 26	 1.008042	 0.0	 1	 -30.0	 30.0;
	4	 8857	 0.0	 0.48	 0.0	 66	 66	 66	 1.004449	 0.0	 1	 -30.0	 30.0;
	4	 572	 0.0	 0.48	 0.0	 66	 66	 66	 1.004449	 0.0	 1	 -30.0	 30.0;
	4	 2460	 0.0	 0.24	 0.0	 132	 132	 132	 1.004638	 0.0	 1	 -30.0	 30.0;
	4	 7777	 0.0	 0.24	 0.0	 132	 132	 132	 1.007068	 0.0	 1	 -30.0	 30.0;
	12356	 3385	 0.0	 0.60364	 0.0	 53	 53	 53	 1.002099	 0.0	 1	 -30.0	 30.0;
	12356	 8837	 0.0	 0.60061	 0.0	 53	 53	 53	 1.002095	 0.0	 1	 -30.0	 30.0;
	12356	 10945	 0.0	 0.776	 0.0	 41	 41	 41	 1.00235	 0.0	 1	 -30.0	 30.0;
	767	 9227	 0.0	 0.24773	 0.0	 128	 128	 128	 1.001528	 0.0	 1	 -30.0	 30.0;
	767	 8121	 0.0	 0.24773	 0.0	 128	 128	 128	 1.001528	 0.0	 1	 -30.0	 30.0;
	767	 2831	 0.0	 0.24773	 0.0	 128	 128	 128	 1.001082	 0.0	 1	 -30.0	 30.0;
	9300	 10156	 0.0	 0.06667	 0.0	 474	 474	 474	 1.042646	 0.0	 1	 -30.0	 30.0;
	9300	 9054	 0.0	 0.06667	 0.0	 474	 474	 474	 1.042646	 0.0	 1	 -30.0	 30.0;
	3507	 331	 0.0	 0.24	 0.0	 132	 132	 132	 1.006117	 0.0	 1	 -30.0	 30.0;
	3507	 5716	 0.0	 0.24	 0.0	 132	 132	 132	 1.006117	 0.0	 1	 -30.0	 30.0;
	5088	 5574	 0.0	 0.070727	 0.0	 447	 447	 447	 0.953559	 0.0	 1	 -30.0	 30.0;
	5088	 5574	 0.0	 0.072561	 0.0	 436	 436	 436	 0.953467	 0.0	 1	 -30.0	 30.0;
	7658	 6649	 0.0	 0.895631	 0.0	 36	 36	 36	 1.002677	 0.0	 1	 -30.0	 30.0;
	7658	 11850	 0.0	 0.895631	 0.0	 36	 36	 36	 1.002677	 0.0	 1	 -30.0	 30.0;
	7658	 258	 0.0	 0.895631	 0.0	 36	 36	 36	 1.002677	 0.0	 1	 -30.0	 30.0;
	7658	 6952	 0.0	 0.895631	 0.0	 36	 36	 36	 1.002677	 0.0	 1	 -30.0	 30.0;
	7658	 10940	 0.0	 0.20778	 0.0	 153	 153	 153	 1.010413	 0.0	 1	 -30.0	 30.0;
	5363	 4918	 0.0	 0.25	 0.0	 127	 127	 127	 1.0252	 0.0	 1	 -30.0	 30.0;
	5363	 13222	 0.0	 0.25	 0.0	 127	 127	 127	 1.0252	 0.0	 1	 -30.0	 30.0;
	3513	 7707	 0.0	 0.18462	 0.0	 172	 172	 172	 1.002954	 0.0	 1	 -30.0	 30.0;
	3513	 559	 0.0	 0.18462	 0.0	 172	 172	 172	 1.002954	 0.0	 1	 -30.0	 30.0;
	10067	 10572	 0.0	 0.047975	 0.0	 659	 659	 659	 0.94873	 0.0	 1	 -30.0	 30.0;
	10067	 10572	 0.0	 0.047975	 0.0	 659	 659	 659	 0.94873	 0.0	 1	 -30.0	 30.0;
	10067	 12603	 0.0	 0.06154	 0.0	 514	 514	 514	 0.989901	 0.0	 1	 -30.0	 30.0;
	10067	 11665	 0.0	 0.06154	 0.0	 514	 514	 514	 0.989901	 0.0	 1	 -30.0	 30.0;
	2629	 3948	 0.0	 0.16	 0.0	 198	 198	 198	 1.003023	 0.0	 1	 -30.0	 30.0;
	2629	 13238	 0.0	 0.16	 0.0	 198	 198	 198	 1.003023	 0.0	 1	 -30.0	 30.0;
	8462	 8252	 0.0	 0.07575	 0.0	 417	 417	 417	 0.93962	 0.0	 1	 -30.0	 30.0;
	8462	 8252	 0.0	 0.049246	 0.0	 642	 642	 642	 0.949671	 0.0	 1	 -30.0	 30.0;
	8462	 8252	 0.0	 0.044468	 0.0	 711	 711	 711	 0.9877	 0.0	 1	 -30.0	 30.0;
	8462	 9049	 0.0	 0.04444	 0.0	 711	 711	 711	 0.987095	 0.0	 1	 -30.0	 30.0;
	8462	 12775	 0.0	 0.04444	 0.0	 711	 711	 711	 0.987095	 0.0	 1	 -30.0	 30.0;
	8462	 8635	 0.0	 0.04138	 0.0	 764	 764	 764	 0.987064	 0.0	 1	 -30.0	 30.0;
	10673	 10153	 0.0	 0.082076	 0.0	 385	 385	 385	 0.930061	 0.0	 1	 -30.0	 30.0;
	10673	 10153	 0.0	 0.046721	 0.0	 677	 677	 677	 0.94135	 0.0	 1	 -30.0	 30.0;
	7680	 1985	 0.0	 0.19045	 0.0	 166	 166	 166	 1.001671	 0.0	 1	 -30.0	 30.0;
	7680	 954	 0.0	 0.19478	 0.0	 163	 163	 163	 1.001623	 0.0	 1	 -30.0	 30.0;
	931	 10557	 0.0	 1.0	 0.0	 32	 32	 32	 1.025593	 0.0	 1	 -30.0	 30.0;
	931	 5384	 0.0	 1.0	 0.0	 32	 32	 32	 1.025593	 0.0	 1	 -30.0	 30.0;
	931	 7186	 0.0	 1.0	 0.0	 32	 32	 32	 1.025593	 0.0	 1	 -30.0	 30.0;
	931	 9554	 0.0	 1.0	 0.0	 32	 32	 32	 1.025425	 0.0	 1	 -30.0	 30.0;
	10266	 8584	 0.0	 0.073292	 0.0	 431	 431	 431	 0.934869	 0.0	 1	 -30.0	 30.0;
	10266	 8584	 0.0	 0.07618	 0.0	 415	 415	 415	 0.959473	 0.0	 1	 -30.0	 30.0;
	474	 25	 0.0	 0.034784	 0.0	 909	 909	 909	 0.957864	 0.0	 1	 -30.0	 30.0;
	474	 25	 0.0	 0.041737	 0.0	 757	 757	 757	 0.956293	 0.0	 1	 -30.0	 30.0;
	474	 1264	 0.0	 0.04762	 0.0	 664	 664	 664	 0.95327	 0.0	 1	 -30.0	 30.0;
	474	 10554	 0.0	 0.04762	 0.0	 664	 664	 664	 0.953224	 0.0	 1	 -30.0	 30.0;
	474	 8483	 0.0	 0.04762	 0.0	 664	 664	 664	 0.953224	 0.0	 1	 -30.0	 30.0;
	474	 12688	 0.0	 0.04762	 0.0	 664	 664	 664	 0.953224	 0.0	 1	 -30.0	 30.0;
	474	 4202	 0.0	 0.04762	 0.0	 664	 664	 664	 0.953224	 0.0	 1	 -30.0	 30.0;
	474	 2308	 0.0	 0.04762	 0.0	 664	 664	 664	 0.953239	 0.0	 1	 -30.0	 30.0;
	1036	 1510	 0.0	 0.0842	 0.0	 376	 376	 376	 0.953022	 0.0	 1	 -30.0	 30.0;
	1036	 1510	 0.0	 0.0842	 0.0	 376	 376	 376	 0.953022	 0.0	 1	 -30.0	 30.0;
	1036	 8453	 0.0	 0.04321	 0.0	 732	 732	 732	 0.995668	 0.0	 1	 -30.0	 30.0;
	4116	 5403	 0.0	 0.048	 0.0	 659	 659	 659	 0.933396	 0.0	 1	 -30.0	 30.0;
	4116	 5403	 0.0	 0.048	 0.0	 659	 659	 659	 0.933396	 0.0	 1	 -30.0	 30.0;
	4116	 5403	 0.0	 0.048	 0.0	 659	 659	 659	 0.933396	 0.0	 1	 -30.0	 30.0;
	4116	 5403	 0.0	 0.048	 0.0	 659	 659	 659	 0.933396	 0.0	 1	 -30.0	 30.0;
	5743	 11594	 0.0	 0.080704	 0.0	 392	 392	 392	 0.954038	 0.0	 1	 -30.0	 30.0;
	5743	 7750	 0.0	 0.07222	 0.0	 438	 438	 438	 0.978163	 0.0	 1	 -30.0	 30.0;
	5743	 2430	 0.0	 0.07222	 0.0	 438	 438	 438	 0.978163	 0.0	 1	 -30.0	 30.0;
	3198	 3713	 0.0	 0.033909	 0.0	 932	 932	 932	 0.967952	 0.0	 1	 -30.0	 30.0;
	3198	 1138	 0.0	 0.04444	 0.0	 711	 711	 711	 0.974445	 0.0	 1	 -30.0	 30.0;
	3198	 11987	 0.0	 0.04444	 0.0	 711	 711	 711	 0.974445	 0.0	 1	 -30.0	 30.0;
	3198	 4517	 0.0	 0.04444	 0.0	 711	 711	 711	 0.974445	 0.0	 1	 -30.0	 30.0;
	3198	 9889	 0.0	 0.04444	 0.0	 711	 711	 711	 0.974559	 0.0	 1	 -30.0	 30.0;
	8751	 9253	 0.0	 0.075925	 0.0	 417	 417	 417	 0.93144	 0.0	 1	 -30.0	 30.0;
	8751	 9253	 0.0	 0.075925	 0.0	 417	 417	 417	 0.93144	 0.0	 1	 -30.0	 30.0;
	8751	 9253	 0.0	 0.08451	 0.0	 374	 374	 374	 0.965009	 0.0	 1	 -30.0	 30.0;
	10807	 1644	 0.0	 0.62069	 0.0	 51	 51	 51	 1.005972	 0.0	 1	 -30.0	 30.0;
	10807	 9853	 0.0	 0.62069	 0.0	 51	 51	 51	 1.005972	 0.0	 1	 -30.0	 30.0;
	7569	 7677	 0.0	 0.40909	 0.0	 78	 78	 78	 1.002044	 0.0	 1	 -30.0	 30.0;
	11594	 916	 0.0	 0.07111	 0.0	 445	 445	 445	 1.044775	 0.0	 1	 -30.0	 30.0;
	12098	 1562	 0.0	 2.4	 0.0	 14	 14	 14	 1.000117	 0.0	 1	 -30.0	 30.0;
	12098	 13312	 0.0	 2.4	 0.0	 14	 14	 14	 1.000117	 0.0	 1	 -30.0	 30.0;
	12098	 10580	 0.0	 8.0	 0.0	 4	 4	 4	 0.999937	 0.0	 1	 -30.0	 30.0;
	12098	 1488	 0.0	 8.0	 0.0	 4	 4	 4	 0.999937	 0.0	 1	 -30.0	 30.0;
	12098	 13193	 0.0	 8.0	 0.0	 4	 4	 4	 0.999937	 0.0	 1	 -30.0	 30.0;
	12098	 2139	 0.0	 0.16	 0.0	 198	 198	 198	 1.002204	 0.0	 1	 -30.0	 30.0;
	13473	 8052	 0.0	 0.082076	 0.0	 385	 385	 385	 0.935732	 0.0	 1	 -30.0	 30.0;
	13473	 8052	 0.0	 0.046721	 0.0	 677	 677	 677	 0.951774	 0.0	 1	 -30.0	 30.0;
	13473	 8052	 0.0	 0.046721	 0.0	 677	 677	 677	 0.951774	 0.0	 1	 -30.0	 30.0;
	10828	 13514	 0.0	 0.30121	 0.0	 105	 105	 105	 1.000845	 0.0	 1	 -30.0	 30.0;
	10828	 3236	 0.0	 0.30121	 0.0	 105	 105	 105	 1.000845	 0.0	 1	 -30.0	 30.0;
	10828	 8555	 0.0	 0.30121	 0.0	 105	 105	 105	 1.000845	 0.0	 1	 -30.0	 30.0;
	10828	 7568	 0.0	 0.30121	 0.0	 105	 105	 105	 1.000845	 0.0	 1	 -30.0	 30.0;
	7800	 8138	 0.0	 0.046417	 0.0	 681	 681	 681	 0.948978	 0.0	 1	 -30.0	 30.0;
	7800	 8138	 0.0	 0.046417	 0.0	 681	 681	 681	 0.948978	 0.0	 1	 -30.0	 30.0;
	9507	 4668	 0.0	 0.28571	 0.0	 111	 111	 111	 0.999929	 0.0	 1	 -30.0	 30.0;
	9507	 3499	 0.0	 0.28571	 0.0	 111	 111	 111	 0.999929	 0.0	 1	 -30.0	 30.0;
	9507	 11920	 0.0	 0.28571	 0.0	 111	 111	 111	 0.999929	 0.0	 1	 -30.0	 30.0;
	9507	 12946	 0.0	 0.28571	 0.0	 111	 111	 111	 0.999929	 0.0	 1	 -30.0	 30.0;
	9507	 7585	 0.0	 0.28571	 0.0	 111	 111	 111	 0.999929	 0.0	 1	 -30.0	 30.0;
	9507	 6563	 0.0	 0.28571	 0.0	 111	 111	 111	 0.999929	 0.0	 1	 -30.0	 30.0;
	7448	 6558	 0.0	 0.077314	 0.0	 409	 409	 409	 0.951427	 0.0	 1	 -30.0	 30.0;
	7448	 6558	 0.0	 0.04639	 0.0	 681	 681	 681	 0.952285	 0.0	 1	 -30.0	 30.0;
	7448	 13590	 0.0	 0.09286	 0.0	 341	 341	 341	 0.996551	 0.0	 1	 -30.0	 30.0;
	7448	 1845	 0.0	 0.09286	 0.0	 341	 341	 341	 0.996551	 0.0	 1	 -30.0	 30.0;
	7448	 7148	 0.0	 0.09286	 0.0	 341	 341	 341	 0.996551	 0.0	 1	 -30.0	 30.0;
	7448	 11170	 0.0	 0.09286	 0.0	 341	 341	 341	 0.996551	 0.0	 1	 -30.0	 30.0;
	7448	 8394	 0.0	 0.09286	 0.0	 341	 341	 341	 0.996551	 0.0	 1	 -30.0	 30.0;
	7448	 1010	 0.0	 0.09286	 0.0	 341	 341	 341	 0.996551	 0.0	 1	 -30.0	 30.0;
	1608	 2180	 0.0	 0.06219	 0.0	 508	 508	 508	 0.972683	 0.0	 1	 -30.0	 30.0;
	1608	 5158	 0.0	 0.06219	 0.0	 508	 508	 508	 0.972715	 0.0	 1	 -30.0	 30.0;
	1608	 9457	 0.0	 0.06219	 0.0	 508	 508	 508	 0.972774	 0.0	 1	 -30.0	 30.0;
	1608	 6871	 0.0	 0.06219	 0.0	 508	 508	 508	 0.972774	 0.0	 1	 -30.0	 30.0;
	1608	 5281	 0.0	 0.06219	 0.0	 508	 508	 508	 0.97225	 0.0	 1	 -30.0	 30.0;
	13612	 13493	 0.0	 0.03226	 0.0	 980	 980	 980	 0.99893	 0.0	 1	 -30.0	 30.0;
	13612	 3797	 0.0	 0.03226	 0.0	 980	 980	 980	 0.99893	 0.0	 1	 -30.0	 30.0;
	4624	 2227	 0.0	 0.046721	 0.0	 677	 677	 677	 0.959854	 0.0	 1	 -30.0	 30.0;
	466	 11158	 0.0	 2.49125	 0.0	 13	 13	 13	 1.043188	 0.0	 1	 -30.0	 30.0;
	466	 12285	 0.0	 2.49125	 0.0	 13	 13	 13	 1.043188	 0.0	 1	 -30.0	 30.0;
	466	 3842	 0.0	 2.49125	 0.0	 13	 13	 13	 1.043188	 0.0	 1	 -30.0	 30.0;
	11262	 8656	 0.0	 0.6	 0.0	 53	 53	 53	 1.005315	 0.0	 1	 -30.0	 30.0;
	11262	 4259	 0.0	 0.8	 0.0	 40	 40	 40	 1.005104	 0.0	 1	 -30.0	 30.0;
	11262	 695	 0.0	 0.8	 0.0	 40	 40	 40	 1.005104	 0.0	 1	 -30.0	 30.0;
	11262	 10678	 0.0	 0.54545	 0.0	 58	 58	 58	 1.004859	 0.0	 1	 -30.0	 30.0;
	7090	 8299	 0.0	 0.6	 0.0	 53	 53	 53	 1.006265	 0.0	 1	 -30.0	 30.0;
	3669	 1049	 0.0	 0.071508	 0.0	 442	 442	 442	 0.951095	 0.0	 1	 -30.0	 30.0;
	3669	 1049	 0.0	 0.071508	 0.0	 442	 442	 442	 0.951095	 0.0	 1	 -30.0	 30.0;
	3669	 1049	 0.0	 0.042907	 0.0	 737	 737	 737	 0.954937	 0.0	 1	 -30.0	 30.0;
	3669	 1049	 0.0	 0.042907	 0.0	 737	 737	 737	 0.954937	 0.0	 1	 -30.0	 30.0;
	8874	 8346	 0.0	 0.079232	 0.0	 399	 399	 399	 0.914664	 0.0	 1	 -30.0	 30.0;
	3203	 9902	 0.0	 0.12702	 0.0	 249	 249	 249	 1.025478	 0.0	 1	 -30.0	 30.0;
	3203	 11953	 0.0	 0.12702	 0.0	 249	 249	 249	 1.025478	 0.0	 1	 -30.0	 30.0;
	3203	 8091	 0.0	 0.12702	 0.0	 249	 249	 249	 1.025478	 0.0	 1	 -30.0	 30.0;
	3203	 3872	 0.0	 1.37	 0.0	 24	 24	 24	 1.028419	 0.0	 1	 -30.0	 30.0;
	741	 3082	 0.0	 0.15385	 0.0	 206	 206	 206	 1.038547	 0.0	 1	 -30.0	 30.0;
	741	 12286	 0.0	 0.15385	 0.0	 206	 206	 206	 1.038547	 0.0	 1	 -30.0	 30.0;
	3443	 10835	 0.0	 0.18095	 0.0	 175	 175	 175	 1.000216	 0.0	 1	 -30.0	 30.0;
	3443	 2506	 0.0	 0.18095	 0.0	 175	 175	 175	 1.000216	 0.0	 1	 -30.0	 30.0;
	8738	 7243	 0.0	 1.27867	 0.0	 25	 25	 25	 1.002702	 0.0	 1	 -30.0	 30.0;
	8738	 2357	 0.0	 1.27867	 0.0	 25	 25	 25	 1.002702	 0.0	 1	 -30.0	 30.0;
	8738	 10650	 0.0	 1.27867	 0.0	 25	 25	 25	 1.002702	 0.0	 1	 -30.0	 30.0;
	2175	 11789	 0.0	 1.176401	 0.0	 27	 27	 27	 1.005041	 0.0	 1	 -30.0	 30.0;
	2175	 4237	 0.0	 1.05	 0.0	 31	 31	 31	 1.005856	 0.0	 1	 -30.0	 30.0;
	2175	 7918	 0.0	 1.05	 0.0	 31	 31	 31	 1.005856	 0.0	 1	 -30.0	 30.0;
	2175	 7066	 0.0	 1.05	 0.0	 31	 31	 31	 1.005856	 0.0	 1	 -30.0	 30.0;
	2175	 8893	 0.0	 1.05	 0.0	 31	 31	 31	 1.005856	 0.0	 1	 -30.0	 30.0;
	2175	 13556	 0.0	 1.05	 0.0	 31	 31	 31	 1.005856	 0.0	 1	 -30.0	 30.0;
	2175	 12616	 0.0	 1.176401	 0.0	 27	 27	 27	 1.005041	 0.0	 1	 -30.0	 30.0;
	2175	 7877	 0.0	 1.176401	 0.0	 27	 27	 27	 1.005041	 0.0	 1	 -30.0	 30.0;
	2175	 5408	 0.0	 1.176401	 0.0	 27	 27	 27	 1.005041	 0.0	 1	 -30.0	 30.0;
	2175	 132	 0.0	 1.176401	 0.0	 27	 27	 27	 1.005041	 0.0	 1	 -30.0	 30.0;
	2175	 7267	 0.0	 1.176401	 0.0	 27	 27	 27	 1.005041	 0.0	 1	 -30.0	 30.0;
	2175	 5111	 0.0	 1.176401	 0.0	 27	 27	 27	 1.005041	 0.0	 1	 -30.0	 30.0;
	8892	 2175	 0.0	 0.045483	 0.0	 695	 695	 695	 0.986891	 0.0	 1	 -30.0	 30.0;
	11184	 11684	 0.0	 0.045483	 0.0	 695	 695	 695	 0.947104	 0.0	 1	 -30.0	 30.0;
	11184	 11684	 0.0	 0.045483	 0.0	 695	 695	 695	 0.947104	 0.0	 1	 -30.0	 30.0;
	8119	 7642	 0.0	 0.045483	 0.0	 695	 695	 695	 0.966173	 0.0	 1	 -30.0	 30.0;
	402	 5679	 0.0	 1.18254	 0.0	 27	 27	 27	 1.004821	 0.0	 1	 -30.0	 30.0;
	402	 325	 0.0	 1.18571	 0.0	 27	 27	 27	 1.004818	 0.0	 1	 -30.0	 30.0;
	402	 12060	 0.0	 1.19048	 0.0	 27	 27	 27	 1.004812	 0.0	 1	 -30.0	 30.0;
	12408	 4748	 0.0	 0.047975	 0.0	 659	 659	 659	 0.94083	 0.0	 1	 -30.0	 30.0;
	12408	 4748	 0.0	 0.047975	 0.0	 659	 659	 659	 0.94083	 0.0	 1	 -30.0	 30.0;
	5949	 11282	 0.0	 0.044262	 0.0	 714	 714	 714	 0.968661	 0.0	 1	 -30.0	 30.0;
	10314	 12421	 0.0	 1.125913	 0.0	 29	 29	 29	 1.000754	 0.0	 1	 -30.0	 30.0;
	10314	 13270	 0.0	 1.125913	 0.0	 29	 29	 29	 1.000754	 0.0	 1	 -30.0	 30.0;
	1056	 11900	 0.0	 0.4	 0.0	 79	 79	 79	 1.005458	 0.0	 1	 -30.0	 30.0;
	1056	 10994	 0.0	 0.4	 0.0	 79	 79	 79	 1.005458	 0.0	 1	 -30.0	 30.0;
	1056	 9110	 0.0	 0.4	 0.0	 79	 79	 79	 1.005458	 0.0	 1	 -30.0	 30.0;
	11432	 12896	 0.0	 0.42067	 0.0	 76	 76	 76	 1.00888	 0.0	 1	 -30.0	 30.0;
	11432	 13643	 0.0	 0.42067	 0.0	 76	 76	 76	 1.00888	 0.0	 1	 -30.0	 30.0;
	11432	 3929	 0.0	 0.42067	 0.0	 76	 76	 76	 1.00888	 0.0	 1	 -30.0	 30.0;
	11432	 6359	 0.0	 0.42067	 0.0	 76	 76	 76	 1.00888	 0.0	 1	 -30.0	 30.0;
	11432	 10971	 0.0	 0.631	 0.0	 51	 51	 51	 1.008513	 0.0	 1	 -30.0	 30.0;
	11432	 2816	 0.0	 0.631	 0.0	 51	 51	 51	 1.008513	 0.0	 1	 -30.0	 30.0;
	11432	 8163	 0.0	 0.631	 0.0	 51	 51	 51	 1.008513	 0.0	 1	 -30.0	 30.0;
	1178	 5061	 0.0	 0.85714	 0.0	 37	 37	 37	 1.00156	 0.0	 1	 -30.0	 30.0;
	1178	 6939	 0.0	 0.85714	 0.0	 37	 37	 37	 1.00156	 0.0	 1	 -30.0	 30.0;
	1178	 1640	 0.0	 0.85714	 0.0	 37	 37	 37	 1.00156	 0.0	 1	 -30.0	 30.0;
	1178	 13212	 0.0	 1.5	 0.0	 22	 22	 22	 1.001548	 0.0	 1	 -30.0	 30.0;
	1178	 12277	 0.0	 1.5	 0.0	 22	 22	 22	 1.001548	 0.0	 1	 -30.0	 30.0;
	1178	 10285	 0.0	 1.5	 0.0	 22	 22	 22	 1.001548	 0.0	 1	 -30.0	 30.0;
	1178	 12359	 0.0	 1.5	 0.0	 22	 22	 22	 1.001548	 0.0	 1	 -30.0	 30.0;
	12974	 4392	 0.0	 0.20773	 0.0	 153	 153	 153	 1.001877	 0.0	 1	 -30.0	 30.0;
	12974	 10938	 0.0	 0.2875	 0.0	 110	 110	 110	 1.00111	 0.0	 1	 -30.0	 30.0;
	12974	 13037	 0.0	 0.329628	 0.0	 96	 96	 96	 0.960985	 0.0	 1	 -30.0	 30.0;
	12974	 8393	 0.0	 0.346109	 0.0	 92	 92	 92	 0.961259	 0.0	 1	 -30.0	 30.0;
	10003	 7742	 0.0	 0.36	 0.0	 88	 88	 88	 1.001685	 0.0	 1	 -30.0	 30.0;
	4739	 927	 0.0	 0.2	 0.0	 158	 158	 158	 1.00555	 0.0	 1	 -30.0	 30.0;
	4739	 8436	 0.0	 0.2	 0.0	 158	 158	 158	 1.00555	 0.0	 1	 -30.0	 30.0;
	4739	 10302	 0.0	 0.22222	 0.0	 143	 143	 143	 1.005623	 0.0	 1	 -30.0	 30.0;
	519	 6686	 0.0	 0.23538	 0.0	 135	 135	 135	 1.003504	 0.0	 1	 -30.0	 30.0;
	519	 11581	 0.0	 0.23538	 0.0	 135	 135	 135	 1.003504	 0.0	 1	 -30.0	 30.0;
	1064	 4526	 0.0	 0.0971	 0.0	 326	 326	 326	 1.01076	 0.0	 1	 -30.0	 30.0;
	1064	 7149	 0.0	 0.0971	 0.0	 326	 326	 326	 1.01076	 0.0	 1	 -30.0	 30.0;
	2885	 3392	 0.0	 0.047975	 0.0	 659	 659	 659	 0.950379	 0.0	 1	 -30.0	 30.0;
	2885	 3392	 0.0	 0.047975	 0.0	 659	 659	 659	 0.950379	 0.0	 1	 -30.0	 30.0;
	2885	 3392	 0.0	 0.047975	 0.0	 659	 659	 659	 0.950379	 0.0	 1	 -30.0	 30.0;
	5794	 13634	 0.0	 0.046721	 0.0	 677	 677	 677	 0.941514	 0.0	 1	 -30.0	 30.0;
	5794	 13634	 0.0	 0.046721	 0.0	 677	 677	 677	 0.941514	 0.0	 1	 -30.0	 30.0;
	5794	 10588	 0.0	 0.13846	 0.0	 229	 229	 229	 0.98726	 0.0	 1	 -30.0	 30.0;
	5794	 4786	 0.0	 0.13846	 0.0	 229	 229	 229	 0.98726	 0.0	 1	 -30.0	 30.0;
	5794	 5681	 0.0	 0.13846	 0.0	 229	 229	 229	 0.98726	 0.0	 1	 -30.0	 30.0;
	5794	 13338	 0.0	 0.13846	 0.0	 229	 229	 229	 0.98726	 0.0	 1	 -30.0	 30.0;
	4804	 5313	 0.0	 0.047975	 0.0	 659	 659	 659	 0.937784	 0.0	 1	 -30.0	 30.0;
	4804	 5313	 0.0	 0.047975	 0.0	 659	 659	 659	 0.937784	 0.0	 1	 -30.0	 30.0;
	4804	 11047	 0.0	 0.07143	 0.0	 443	 443	 443	 0.987013	 0.0	 1	 -30.0	 30.0;
	4804	 6584	 0.0	 0.07143	 0.0	 443	 443	 443	 0.987013	 0.0	 1	 -30.0	 30.0;
	2752	 7439	 0.0	 0.0505	 0.0	 626	 626	 626	 0.915592	 0.0	 1	 -30.0	 30.0;
	2752	 7439	 0.0	 0.0505	 0.0	 626	 626	 626	 0.915592	 0.0	 1	 -30.0	 30.0;
	2752	 7439	 0.0	 0.0505	 0.0	 626	 626	 626	 0.915592	 0.0	 1	 -30.0	 30.0;
	4417	 12572	 0.0	 0.06	 0.0	 527	 527	 527	 0.987895	 0.0	 1	 -30.0	 30.0;
	4417	 7170	 0.0	 0.06	 0.0	 527	 527	 527	 0.987895	 0.0	 1	 -30.0	 30.0;
	3088	 7681	 0.0	 0.06452	 0.0	 490	 490	 490	 0.986513	 0.0	 1	 -30.0	 30.0;
	3088	 9553	 0.0	 0.06452	 0.0	 490	 490	 490	 0.986513	 0.0	 1	 -30.0	 30.0;
	3088	 12625	 0.0	 0.06452	 0.0	 490	 490	 490	 0.986513	 0.0	 1	 -30.0	 30.0;
	11928	 12438	 0.0	 0.070313	 0.0	 450	 450	 450	 0.971656	 0.0	 1	 -30.0	 30.0;
	13288	 12730	 0.0	 0.13333	 0.0	 237	 237	 237	 1.006815	 0.0	 1	 -30.0	 30.0;
	10089	 5464	 0.0	 0.08	 0.0	 395	 395	 395	 1.001392	 0.0	 1	 -30.0	 30.0;
	9548	 283	 0.0	 1.2	 0.0	 27	 27	 27	 1.002586	 0.0	 1	 -30.0	 30.0;
	9548	 8476	 0.0	 1.2	 0.0	 27	 27	 27	 1.002586	 0.0	 1	 -30.0	 30.0;
	10582	 6072	 0.0	 0.70588	 0.0	 45	 45	 45	 1.003916	 0.0	 1	 -30.0	 30.0;
	10582	 11584	 0.0	 0.70588	 0.0	 45	 45	 45	 1.003916	 0.0	 1	 -30.0	 30.0;
	10582	 13082	 0.0	 1.09091	 0.0	 29	 29	 29	 1.003824	 0.0	 1	 -30.0	 30.0;
	10582	 1238	 0.0	 1.09091	 0.0	 29	 29	 29	 1.003824	 0.0	 1	 -30.0	 30.0;
	10582	 9693	 0.0	 0.8	 0.0	 40	 40	 40	 1.003682	 0.0	 1	 -30.0	 30.0;
	10582	 12555	 0.0	 0.8	 0.0	 40	 40	 40	 1.003682	 0.0	 1	 -30.0	 30.0;
	8876	 11549	 0.0	 0.08	 0.0	 395	 395	 395	 1.002784	 0.0	 1	 -30.0	 30.0;
	8165	 11641	 0.0	 0.8	 0.0	 40	 40	 40	 1.004718	 0.0	 1	 -30.0	 30.0;
	8165	 13226	 0.0	 0.8	 0.0	 40	 40	 40	 1.004718	 0.0	 1	 -30.0	 30.0;
	8165	 5289	 0.0	 0.8	 0.0	 40	 40	 40	 1.004718	 0.0	 1	 -30.0	 30.0;
	8165	 6994	 0.0	 1.2	 0.0	 27	 27	 27	 1.00468	 0.0	 1	 -30.0	 30.0;
	8165	 8595	 0.0	 1.2	 0.0	 27	 27	 27	 1.00468	 0.0	 1	 -30.0	 30.0;
	8165	 621	 0.0	 1.2	 0.0	 27	 27	 27	 1.00468	 0.0	 1	 -30.0	 30.0;
	10549	 2994	 0.0	 0.18462	 0.0	 172	 172	 172	 1.00459	 0.0	 1	 -30.0	 30.0;
	10549	 4190	 0.0	 0.18462	 0.0	 172	 172	 172	 1.00459	 0.0	 1	 -30.0	 30.0;
	10549	 9461	 0.0	 0.18462	 0.0	 172	 172	 172	 1.00459	 0.0	 1	 -30.0	 30.0;
	10441	 42	 0.0	 0.4	 0.0	 79	 79	 79	 1.001976	 0.0	 1	 -30.0	 30.0;
	12564	 10365	 0.0	 0.375	 0.0	 85	 85	 85	 1.000295	 0.0	 1	 -30.0	 30.0;
	12564	 1961	 0.0	 0.375	 0.0	 85	 85	 85	 1.000295	 0.0	 1	 -30.0	 30.0;
	12564	 10598	 0.0	 0.66667	 0.0	 48	 48	 48	 1.000528	 0.0	 1	 -30.0	 30.0;
	11754	 8202	 0.0	 0.16	 0.0	 198	 198	 198	 1.000721	 0.0	 1	 -30.0	 30.0;
	6753	 13407	 0.0	 0.26667	 0.0	 119	 119	 119	 1.004335	 0.0	 1	 -30.0	 30.0;
	3253	 9906	 0.0	 0.06857	 0.0	 461	 461	 461	 0.998577	 0.0	 1	 -30.0	 30.0;
	4050	 10652	 0.0	 0.24	 0.0	 132	 132	 132	 1.000492	 0.0	 1	 -30.0	 30.0;
	4050	 11273	 0.0	 0.24	 0.0	 132	 132	 132	 1.000492	 0.0	 1	 -30.0	 30.0;
	4050	 9016	 0.0	 0.24	 0.0	 132	 132	 132	 1.000492	 0.0	 1	 -30.0	 30.0;
	4050	 8776	 0.0	 0.24	 0.0	 132	 132	 132	 1.000492	 0.0	 1	 -30.0	 30.0;
	7185	 8709	 0.0	 0.26667	 0.0	 119	 119	 119	 1.001292	 0.0	 1	 -30.0	 30.0;
];

% INFO    : === Translation Options ===
% INFO    : Phase Angle Bound:           30.0 (deg.)
% INFO    : Line Capacity Model:         ub
% INFO    : Gen Active Cost Model:       stat
% INFO    : Setting Flat Start
% INFO    : Line Capacity PAB:           15.0 (deg.)
% INFO    : 
% INFO    : === Generator Classification Notes ===
% INFO    : PEL    54  -     1.64
% INFO    : SYNC   3   -     0.00
% INFO    : NUC    42  -     5.49
% INFO    : COW    1161 -    49.35
% INFO    : NG     2832 -    43.52
% INFO    : 
% INFO    : === Generator Active Cost Stat Model Notes ===
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.9542284239 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.1437131932 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.0233004285 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 51.4632620904 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.5083037149 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.8085397508 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.0157144584 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.5676422651 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 32.1203157366 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.6619622666 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 10.4819310784 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.6696381626 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.4008970819 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.031116676 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.2423780863 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 50.3391548392 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 52.8250189689 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.3771783703 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.8321865728 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.1283791112 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.3160940645 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.1625509335 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 18.0803744821 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.3365209535 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 50.1307981013 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.6761744459 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 36.1966360323 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.8606644593 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.2102999327 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 35.6954479709 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.0147502172 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.9553372099 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 16.7373746391 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.8862351621 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.0576664192 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.6413991713 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.069067874 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.7203007684 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.9401269026 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.2008560294 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 32.8797431995 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 34.5676644735 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 50.4884859484 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.5054493593 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.75607779923 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.9278618552 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.6419262548 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 13.5521846897 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.9174495946 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.2210927396 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.129151586 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.3493086127 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.9469723133 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.060698636 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.2940410141 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 32.3167374176 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 32.0221373055 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.7250187611 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.652507479 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.1023932759 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.3612154697 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.1859398116 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 56.2556082134 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.1184187874 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.9424491251 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 54.9160106717 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.8410727312 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.268096497 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.360233447 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.4823039996 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.6125259868 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 36.6739794902 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.346832554 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 9.85091081593 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.9616333406 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 47.8794051483 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.6822949858 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.9558455404 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.8150551188 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.3950290504 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.6481140029 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.6879580977 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.0883301952 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.5209641244 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.2442556393 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 55.0060296817 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 56.5577917248 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.8022045138 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.1158861467 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 13.523819853 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 9.54132398568 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.8951049933 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.5313066009 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 21.243375493 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.1325963302 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.4694616802 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.1880838037 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.7973740889 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 2.8070335644 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 38.3307948686 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 15.7973225386 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 37.691260578 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.092772369 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.0226592849 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.2062087691 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.6790035638 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 18.0855316193 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.2291548667 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.2334439151 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.7803476974 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 47.2662017778 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 21.6980227572 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.002466226 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.9615947162 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 21.2570997184 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.5662988414 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.9607357351 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.7810547765 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.1915300616 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.8223561033 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.9623977928 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.8025427368 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.0372711996 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 10.8033166472 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.8845822639 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.5916680406 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.3897297351 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.0242431632 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.776800952 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.7065519644 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.2552392061 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 33.3308031408 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.3347393243 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 19.1659270356 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.6076002675 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 52.2806673429 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.3466895665 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 31.5099252204 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.7098922625 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.0013402983 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.81721212427 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.3077053597 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.72747996257 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 31.8444513556 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.0508559499 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 31.2012239454 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.1677920256 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 55.8532395047 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.0740429734 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.7024832212 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.8294404683 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.2326322327 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.8933544831 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 19.1597602423 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 52.7337560279 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 12.5614034156 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.6571059502 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.4949725481 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 5.8446930816 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.2087922102 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 13.3884234705 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 50.7992532638 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 61.3984898806 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.2188167891 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.3647342795 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.7912472794 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.2362812617 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 15.2624069699 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.0935836668 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.0260183371 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.2105897406 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.4976945876 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.809831312 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.1317721409 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 8.72444954816 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.0338130701 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.9049887578 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.783499606 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.21260991027 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.1333093113 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.8313957517 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.0268039626 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.2987170562 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.611809948 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 14.3505413726 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.7064404757 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.6776742529 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.3058472282 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.6275953772 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 40.0281201095 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.2390149418 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 51.8678918417 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 14.5733951757 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.4446242415 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.2247221216 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.4876083804 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.282317135 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.1985631058 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.1565308526 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 49.0439257286 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.0156478789 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 14.3727724494 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.0476331236 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 51.920078463 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 6.10346271476 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 57.5432237195 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 17.4733665187 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 14.7615566009 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.1758186419 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.009602749 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.791906052 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.0681289729 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 14.9291459323 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.2490044584 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.4507505418 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.884487453 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.5485407623 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.0903550769 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.4071800464 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 52.0614959088 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.1898327264 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.7784520674 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.7866514282 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.8751725836 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 16.9369521913 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.43253754971 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.2645260495 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.0834734331 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.8706701847 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 56.7027876415 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.1544640529 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.1307600654 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.6637689611 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.634181516 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.4176818603 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.7426340419 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.265853756 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.0192936198 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 33.5763873987 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.7765032693 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.346986423 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.3111183119 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.1689693931 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.6416913965 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.2401617632 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 35.042468321 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.2846866474 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 13.8384815209 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.5095954288 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.5925184673 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.736732573 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.4017013255 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.0128892964 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.787371319 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.0521969694 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.877911381 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 21.755558687 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.4295550796 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.1384365697 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.6199808226 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.4970654652 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.5944869297 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.6564583238 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 15.0491046453 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.9626220321 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.3476122593 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 57.2729009358 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.161472528 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.7653838135 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 18.7815018138 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.2580058103 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 15.578131683 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 48.9554928294 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 13.2914868686 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.692644473 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 14.1535769698 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.6853261497 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.9250911473 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 34.5952917038 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.299697839 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.3048225099 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.1555310298 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.1002216983 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 57.1353059116 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.4313745438 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.8944202509 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.1626896652 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.9401710863 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 32.2903188131 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.8181240858 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 9.36035488361 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.6546524701 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.7135380142 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 47.6994462267 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.0565037489 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.2483455589 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 63.2660482277 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 12.3510110584 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 14.7685067748 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.8085613048 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.7634349512 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.3049599034 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.2932730583 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 19.0666520405 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.9848896814 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.6633869661 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.206883893 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.3458568231 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.4318015523 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 13.8878275574 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.3026718286 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.2876089547 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.8943742897 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.6564801488 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 48.8581175271 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.366357759 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 48.722000591 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.0988485386 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.5134470802 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 17.6673944134 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 17.0937508105 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.3423836726 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 49.1271149008 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.512461034 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.1319792429 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 13.5771780674 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.775363005 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.1098014954 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.669703395 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.6751433994 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.1919507804 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 13.648759694 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.7736133355 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 9.47809997173 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.6909280903 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.9749693644 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.0052126658 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 62.1735168768 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 48.7625914265 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 59.6062300738 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 15.1293899571 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.4783620973 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 31.4434691673 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 36.1228721321 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.2788717217 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 13.2786609869 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.182735938 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 32.83336421 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.5792364347 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.969604688 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.7130329474 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 4.15679728294 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.7243545945 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 21.2395668677 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.7164459951 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.9182618354 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.6443173032 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.7039226417 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.5998706967 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 51.9962748433 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 13.0085317488 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.0026509025 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 12.4374543818 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 110.853208384 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.4133338409 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.7531673838 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 17.867625326 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 18.0346064021 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.3275990554 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.8814750243 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.7969432704 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.1523483423 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 53.4143831169 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 49.2284823955 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.2676331638 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.9132091697 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.2959899259 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.7737154652 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 12.3981014735 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.2215259031 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 14.1282231342 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.1389640024 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.0692906143 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 55.8740110349 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 10.8097569976 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 49.6370709896 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.4445913405 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.9862284308 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.4224360432 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.9180536445 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.1421242181 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.122423151 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.7277738136 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.0552592489 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 17.3319656678 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.2038529799 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.9244163432 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.5220040624 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.0873579757 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.769189697 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.2549022315 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.263039896 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.4587708786 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.5537353058 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.4479151787 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.097177463 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.5829317809 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 48.1219893047 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.1100090951 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.9265030344 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 15.769341375 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.4283596707 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 16.5533320462 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.9477105114 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.5983825759 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.84024431 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.1149299277 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.0203200264 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.0617301895 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.206919741 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.6141819886 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.2440007092 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.0245078588 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.0539526084 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 51.8742943122 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 33.2194856592 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.5667527587 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.7611927204 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.7617747246 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 12.9925689512 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.9174732926 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.5988325272 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.7334480657 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 14.5600401551 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.5247403197 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.2768102235 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.9602066884 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 53.9876076622 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.2235951471 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.1717084846 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.4878867202 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 17.4721426856 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.4414197859 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.8000051453 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.1636945066 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.7644128406 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.1913854944 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 16.9573998495 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 50.3292246763 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.2089530107 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.2937098297 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 15.4582027876 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.5807999983 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 11.2818597123 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.5433954147 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.0759354951 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 68.4661931997 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.5269003996 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.3401608104 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 54.155566538 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.1710099975 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.1951578101 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.6213382751 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.4829359297 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.9138746001 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 57.9766608233 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.5002975706 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.6268239399 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.2211152116 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.5069743577 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.8664518173 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.1919625843 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.3619073322 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.1074031276 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 8.06905079915 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.5026665024 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.6217411336 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.0479015333 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.6860458353 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.5646926669 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.0412371126 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.525293347 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.1095800925 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.5936070735 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.861109226 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 11.3309068164 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.801898997 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.6937303453 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.4833482005 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.5158176408 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 12.0650321928 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.7064190828 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 50.8242250887 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.4625968886 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.665876414 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.7755464892 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.70915237743 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.3700327607 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 15.9786706689 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.5881383334 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.1034340408 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.4274709546 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.7783642336 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 119.109749334 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 51.2681912712 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.2006040214 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 50.5106861507 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.0170241076 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 6.67166589584 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.8472514702 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.8957374629 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 19.431491859 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.1067504934 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.3972235059 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 37.6280305599 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.9937197616 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.8139184277 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 49.7850585622 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.4414465061 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.6699418881 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.9676618247 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.0070332907 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 50.3057815552 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 37.0148550519 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 16.2279639773 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.4997564923 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.9602201507 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.3963517228 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.7087757687 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 46.6470774869 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 16.4707962219 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.732637999 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 34.735313539 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.6758446227 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 52.4809654986 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 49.3182731476 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.8555634498 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.6494260031 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.31576515796 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 48.0167344366 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.2150491548 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.687334631 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.7281487692 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.7581439374 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 18.9495122193 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 49.1836160245 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.5399895591 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 47.762304246 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.5502236717 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 52.1133652694 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.5151930025 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.10329310945 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.2571814939 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.3968743201 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 16.2534782818 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.9964847987 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 57.7080309228 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 18.9824980797 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 31.7118538083 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 16.5151572873 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.6369300875 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.7227526884 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.7826837304 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 14.6870770364 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.9191139667 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.6110679915 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.5427099704 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.8649774704 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.5457250624 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.3751213283 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.9790432551 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.7829501066 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.6715054906 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.1582211175 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.6996364679 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 33.986152854 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.6523634614 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.3353189009 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.2894352935 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 108.599818951 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.1345381752 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.7735754785 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.1931829974 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.2422708821 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.631695148 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.2684044046 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.2233433007 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.6537907075 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.5562517147 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 13.4259027847 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.9939231998 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.1463604613 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 34.5693074951 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.4852107462 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.1731759892 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 49.8714401002 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.5103268003 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.7333384083 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 21.9670951161 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 50.9220431111 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 50.6873870015 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.343743379 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.2723730074 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.6866469525 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.2777979191 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.0822568174 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.1000333242 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 17.6165646291 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.9752775019 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.36129401102 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.0870715013 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.6608186406 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 33.2358270778 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 10.8646918246 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.3427541378 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 18.637625021 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.0424740874 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.1951618955 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.5473675461 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 57.3655567639 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.0607340315 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.8305387098 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.7692056059 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.2979066978 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 61.4748502349 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 34.6113175769 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.088773965 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.2825448838 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 17.1187195706 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.491373254 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.5434472176 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.7770561995 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.3507657301 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 52.1307542363 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.2363155053 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.44792107 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 13.6144134574 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.036382989 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.8137088521 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.7878102663 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 16.7592382766 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.117903966 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 13.1114208567 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.0562580315 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.8406446648 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.8015804013 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.0101665286 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.160879292 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.9418552171 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.0853333084 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.028574414 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.0115123618 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.0354317728 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.8498651734 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 21.0108468674 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.4850708911 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.5578049946 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.7364078265 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.5917989455 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.5903419891 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.4597068156 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.1986375836 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.4513678497 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.1127588326 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.1943657428 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.3390906968 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 40.0830554563 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 32.7281526052 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.6276227288 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 50.4347852249 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 51.431062376 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.2493417734 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.4433993313 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.7895643003 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.0943992656 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.181396155 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.240032995 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 0.971474386549 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.2276530361 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 31.3469469254 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 5.93159652659 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.4504216077 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.1344460552 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 49.0726857988 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 36.867788519 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.4190308078 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.610392689 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 59.2171700667 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.4827334177 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.5712842789 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.2477139047 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 32.0154262924 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.8619598265 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.0401270525 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 66.7925244959 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 15.2718246483 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.4255557417 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 11.7679914024 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.1618595308 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.7574840917 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 36.9131295203 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.373449154 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 53.7406688078 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 19.5995611561 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 14.5114958326 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 49.6373737178 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.0046767172 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.3663932999 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 35.004496895 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.8783052362 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.7807012263 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.5189173285 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 18.6421808115 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.1401727436 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.9186219992 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.8966188428 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 49.0836937188 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.6752593562 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 47.6985764476 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.8095953109 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.1118653937 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.7257693286 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 51.0675089492 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 47.5282443967 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.7815085987 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.0026515738 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.0742477172 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.4150673545 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.8003354015 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.3342263545 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.3374044979 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 16.9824027896 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.4972532682 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.5632230371 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.5187404556 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 10.1190159655 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.2253708654 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.7982075505 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.9450963982 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.0990969108 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.65300570767 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.6451065588 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.1727764693 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.5053978788 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.2700590556 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 47.8497697378 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.9446018236 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 14.6528098435 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.4665244364 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.105229204 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.0105217369 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.2216712997 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.2821280289 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.7181054392 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 14.1436857137 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.0493703498 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.7731720969 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.0402492591 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.4227622303 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.9523525693 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 55.920901303 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.0641400695 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.1030665591 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 58.2758486241 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 99.6995964652 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.7306741215 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 16.739718364 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.3138957022 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.3752492361 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 58.4842455591 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 21.5520683426 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.2799582461 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 32.1318753766 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 109.2631414 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.5352904446 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 46.946185283 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.5290652853 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 14.0319102553 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.8668366332 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.7349547473 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.8316558376 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.7804398003 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 2.54777384576 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.8410161579 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.6448730248 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.5719922288 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 15.5247752761 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.6295020255 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 34.2474705139 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 8.25414620423 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.1372357246 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 7.1892583373 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.6082293527 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 14.3656105394 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.7832967984 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.0880569279 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.6395197403 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.4798108142 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.5039224326 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.4152329943 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.6668602398 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 32.3055014784 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.5289124985 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.8480954965 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.550344556 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.8702152391 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.4836322874 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.1211137172 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.4818623736 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 116.393960932 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.9294375108 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.751088192 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.456134218 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.8056325684 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.523744229 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.38276737876 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.3662122014 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.2306900744 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.9570163808 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 35.9391113396 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 42.9393126036 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 35.2637320029 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 31.7551800009 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 35.2749231886 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 14.1412610881 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.2239930292 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.2855431673 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.2642555467 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 38.7453967297 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.2439245012 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 15.036404513 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.9211198585 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.1427249831 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.2965026992 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.8047330463 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.8014010499 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.2291460876 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.12724795 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 34.6412998226 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.8821514259 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.4660255553 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 34.042057051 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 51.3636160039 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.6445821032 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.5628396971 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 16.2841904045 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.2040345906 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 50.3029719118 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 51.3965773307 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.8522650981 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.7906509574 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.8438478289 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 54.865460514 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 32.4358319689 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.0969908068 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.9918452896 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.6283712364 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.7479026956 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 17.1498504678 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.791353311 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.4516728268 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.3035807675 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.3258600394 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.8551401797 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.7533485769 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.1765851153 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.1070356287 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.7581114084 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.6989988921 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.7601149314 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 50.9002969108 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.7222537651 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 41.2850997737 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.1456311248 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.7121543703 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 52.4979760058 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.943245858 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.2040919042 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.2586272802 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 39.1719577431 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.4377809551 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 49.8549155169 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.9274532817 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.72354579236 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.3360121083 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.9668112572 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.5040359993 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.0450682307 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 36.425278919 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.031292151 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.2510686418 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.1515699894 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 31.4747925809 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 15.7182342146 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.986777113 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.8518335251 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 15.7938174148 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.86635642 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 12.4033226033 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 21.5493324469 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.7634617084 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.9665656768 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.7466133 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 51.641235791 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.1945496739 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 19.8373284293 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.8887234475 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 16.949659585 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.8407075089 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 19.3891083587 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 48.6169604362 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.5360445554 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.4910326458 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.4246887948 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.1700871994 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.6530658846 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 10.1089812461 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 11.3107221686 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.9510581496 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.8626166531 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.2332972225 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 14.5314162674 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.9681043145 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.4729793236 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 12.3879681333 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 56.8003517831 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.1324079172 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.8377551609 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.6836891289 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.9605735425 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 50.9669017806 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 0.641498661013 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 48.555352752 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 16.4498840038 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.7842571032 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.3886472812 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.4194227005 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 35.2450679253 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.7135723514 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 19.4610091087 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 35.9050039214 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.4272462289 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.4483772555 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.1716701088 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.5880111801 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.0195703856 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 16.7082057222 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 48.7150439935 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.3042835281 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 35.9407613785 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.9939801545 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.1896652157 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.9601718486 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.9772738513 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.031710387 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.7484185172 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.9583112456 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.6554345444 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.9685281349 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.3655634867 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.7529473582 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 16.8141187401 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 46.5971342132 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.8343762542 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.9633187674 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.92417114 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.4386358552 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.6739446824 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.9299877305 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.508035142 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.4131316035 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.1247084247 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.0420544368 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.125150835 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.3408682953 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.44310577391 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.5731976702 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.9976261233 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.2019389504 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.367213359 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.3432770885 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.1923478712 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 16.9520044987 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.7471185573 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.5941778899 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.9156666901 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.3843386608 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 16.9150701246 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.4659494107 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 127.322258356 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.4625971587 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.1127377661 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.6542128313 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.3954265422 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.1562252013 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.5125805457 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 53.7739886659 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.1319765955 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.9966401273 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.3821597342 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.2121478383 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.0242111554 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 19.190151617 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.9337390104 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.1034486921 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 16.4443541822 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 21.3161548001 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.3551229138 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.2207179257 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 33.935614034 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.5098370308 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.1061713822 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.1021947735 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 52.5832133247 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.1468373438 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 32.4597069381 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.9598894931 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.0699350924 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.8499406724 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.5766600726 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.8503080502 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 16.1146100996 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 48.5376746977 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.3943864478 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.2646996469 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.4721247926 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.1322794975 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.9966525503 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 11.0180714236 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.7942260804 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.9492363911 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.1297819797 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.511384277 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.3288569169 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.1573321502 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.6818106216 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 50.4522139035 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.7248125838 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.8952671851 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.7995803022 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.8685001561 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 50.7451521675 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.5397966779 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.8547788833 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.0374465694 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.4531371436 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.9806692545 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.0429194675 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 19.8516751229 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.0851284963 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.5397473267 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.5878471859 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 112.485421093 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.7673095134 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 17.7101995172 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.3042636279 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 9.42291851575 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.7974306811 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 16.2664057729 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.4010145017 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.7679925389 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.6135357303 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.1948837782 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.6980937477 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.7650004554 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.5312167887 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.8909638315 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.1578869093 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 21.9289028075 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.3739758812 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 11.4728396887 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.687540647 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.1281746508 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.0730742863 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.8810391635 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 48.8126888641 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.2380439928 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 8.0397846275 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.5011073156 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.2062062414 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.9595166026 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.5715745179 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 58.0130855228 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 37.2742536774 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.4345509919 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.9457885044 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.0887351302 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 65.6634184725 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.9889228727 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.9034234153 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.2000011037 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.7942397416 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.4626840186 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 51.5920956605 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.0797289615 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.5889763991 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.3404518906 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.682756075 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.1471864007 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.3080150563 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.0661105059 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.7107619824 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 38.9941530409 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.1441551426 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.9362474616 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.3114049084 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 14.7768867226 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.301674748 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.6521585305 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 60.4242867613 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.1789883514 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.3302105703 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.8587644362 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.1461011378 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 19.6840832256 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.013784017 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.6540259638 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.03472207 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 49.396458124 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.1258264842 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.3817994562 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.3216876077 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 49.3553867747 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.9149132985 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 48.8311861508 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.69361872 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 14.2727582919 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 130.268892691 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 16.6366278732 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.4332024388 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 21.4196294866 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.3493355347 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.4370184716 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.2312157568 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 110.864272598 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.966131621 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 31.5463840615 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 31.9018776734 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.6670420638 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.6926286889 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.9181067144 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 10.044041444 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.6623051281 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 19.7189943762 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.9919101841 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.0565159649 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 50.4595300627 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.3937010822 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.9853492372 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.0614804945 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.2641698997 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.4432853948 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.5667081405 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 34.5257010479 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.8053603165 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.6126388048 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.5414987841 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 21.1739112278 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 10.3702960932 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.8027723354 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.0443402266 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.6855909522 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.2094238429 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.9438720995 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.4360508146 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.0256727362 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.1660564468 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.8779522522 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.8824889639 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.7085917214 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.7733003015 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 16.4412660739 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 48.8990993564 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.0831032184 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 10.3316286732 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 11.7223284694 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.1551917101 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.5011339466 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.8955673994 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 8.30178634053 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.3837446193 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.7912105973 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.6566378125 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.3213043746 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.998865046 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.4088456662 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.4146324788 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.0617059395 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.9707756883 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.053164874 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 6.67054498709 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 47.4085525229 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.5077709138 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 49.3498595871 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.1851022892 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.2038461859 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.560583844 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.1305597452 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.0740662932 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 54.8250424615 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.0315951651 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.8873233713 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 34.8233639413 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.8760072019 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 17.48907359 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.4949595701 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.5908742522 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.7983825681 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.9072639385 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.8768835855 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.389806327 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.4986790235 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.1713211894 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.4926140261 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.1068126735 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.6269578994 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.050067961 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 51.8458705523 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.1488387679 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.3154594384 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 4.11519737468 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.6794537289 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.0609294238 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 21.627866657 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 12.3735248696 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.8662824373 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 116.322399712 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.1223580866 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.919516699 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 31.0501156034 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 16.114911532 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.5261978284 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.2309524016 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.1519159353 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 36.514165741 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.0767035759 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.689585328 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.6335564373 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.5015366862 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.8414331825 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 56.2614757779 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.3671598847 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.6374342906 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 60.4526974879 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.3591106434 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 15.5838867644 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.9957476628 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.6988985381 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.854846348 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 123.640236304 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.8607018477 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 53.4894464382 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 16.4760652028 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.3910174937 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.4124008156 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.5556313888 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.6390350622 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.0767435224 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.9217546315 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.2288110892 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.4385297603 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 62.1674747179 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 71.9947123101 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 31.8134604176 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.27662578 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.4989787457 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.1964580462 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.5847166813 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.1018398526 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.5104745519 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.0519886213 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 12.8638285132 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.7821006274 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.936443756 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.8358874184 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 53.8308911859 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 52.0761881985 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.1715229206 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 14.6436603663 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 16.1765466224 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.8842161941 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.2617774266 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.4831811214 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.6721729669 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 19.4793968524 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.1165427856 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.7094298776 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.4183479637 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 16.1670975537 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.2368032077 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.2490739497 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 15.7038569929 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.0979347123 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 59.3131456111 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.5878442171 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 49.155728113 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.4444266255 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.6353013936 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.2125328672 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.733038592 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 32.8973530611 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.6043197464 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.6738168011 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.5259002809 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 19.3512067986 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 49.5495163055 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.4297241805 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.3278432706 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.5544799758 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 61.8185252248 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.8426603058 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.1750865452 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.1240487217 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.7252588582 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.0696355281 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.6980547606 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 19.4829054394 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.449092279 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.0615510258 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.8789291419 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.0567311032 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 19.3343897491 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.0533809511 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.4129357239 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.1942266992 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.70565741 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.6226562045 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.8420678777 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 15.0760707247 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 50.6709506942 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.4718377947 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.1026681496 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.0617963679 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.65814081 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.1736963728 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.4963530212 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.415168481 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.7997299195 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.0483928297 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.0475822554 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.8597529864 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.3995518315 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 58.7996343688 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.8433216456 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.8008650489 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.1108800358 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.8893073633 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.5555509913 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.3163367115 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.0970531243 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.6950324194 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.930459352 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.8610953244 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.8715483162 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 33.2222109532 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.1514660615 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.2230207005 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 50.3871126448 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.0828572234 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 54.5451632809 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.9937155227 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.235272106 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.5173173045 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.0769797398 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.4173477649 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.0706751481 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.2525144433 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.9644238993 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 57.8174994299 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.8407170253 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.1255702948 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.7538770733 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.7598821888 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.1658311358 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.516077591 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.4641360076 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 21.5372967827 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.8955493718 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.26808937 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.371358109 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.7278314306 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.164729762 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 0.854904061891 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.384235058 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.9579674929 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.604815397 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.4408508315 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.2839901261 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.8454048588 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.8843366251 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 66.1839751931 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.7806518409 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.1120929674 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 51.5120268902 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.7410634432 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.0941152248 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.2349928248 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.3979228373 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.1863149413 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.2957546555 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.9989030182 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.0688943527 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.3150982837 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.97798851 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.4966030736 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.7774741867 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.4681119817 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.96622244258 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.2052962677 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.9641177881 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.5124232637 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.8934892972 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 14.2104675986 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.3398021702 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.300485928 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 31.3672225685 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 31.9190892612 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.3268484618 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.8937848217 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 124.9281268 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.7010620128 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.0023483512 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 15.0811302653 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.1914939585 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.7887949804 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 12.6760940335 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 47.056165331 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 21.0066080717 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.0127124848 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.6951037151 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.1858404703 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.1864606906 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 17.6003587665 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 38.7762963158 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.8295023202 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.3727033785 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 16.4996060448 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.2685908879 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 51.1214909681 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.6238289801 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 50.5682394023 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.9814206622 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 31.1595277968 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.6474201155 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 54.0634637389 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 62.459123755 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 32.853424735 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 21.6553167421 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 19.6839129334 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.7164301832 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 11.4144026257 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 56.3404130213 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 15.9011085636 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.0606152761 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.389938799 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 16.4176891694 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.768884681 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.0106109127 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.0690950653 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.6779752853 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.697928119 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.4226849146 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.1596663515 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.2568278562 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.8793797181 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.4540662621 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.2369986742 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.5721969737 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.6356343745 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 14.9708068913 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.0012201057 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 32.2447937158 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.9732278797 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.8577076692 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.5714943216 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.8307961616 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.5558582568 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.0947934412 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 52.5657365185 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 32.2156947631 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.1469734648 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.5419019486 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.2705627565 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 11.9572499168 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.9509868955 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.4541515322 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.4538015242 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.320441375 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.0469408311 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.681365076 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 101.952094881 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.0964477134 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 48.6478931051 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.1758002417 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.7852377909 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.0712691401 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.6647539093 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.461566201 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.0752114105 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.0291674084 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.132398441 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.2331397401 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.6737472032 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 13.8446645905 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.2994037338 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.185665116 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.1755598177 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.2567472826 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 15.6615520252 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.1523290492 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.0286324835 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.2248405064 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.3452050378 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.1976302056 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.1160493232 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 50.7297880733 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 16.7552830734 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.6099713329 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.4435411343 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.0219370739 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.0715183626 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 52.3229283401 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 11.8007256436 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.2949463719 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.5813744952 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.7747491373 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 53.2093180414 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.2909093122 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.3502405443 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.7324774592 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 1.10436462205 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.319414307 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.6810293147 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.555052562 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 33.6897558089 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.2930502932 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 16.8791334952 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.8626758441 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.9990695172 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.9495808907 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.5230419151 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 36.338078245 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.98832106739 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 52.0774362068 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.5161776963 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.0406389582 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.9414856958 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 16.147128109 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.614263923 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.0981195441 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.0491638693 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.6268936965 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 35.2748393226 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.9332313945 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 33.961063845 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.6929487394 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.7989149478 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.6724901712 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.7408029174 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.5838446198 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.0694448273 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.1909425223 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.9816897901 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 49.4278953724 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 21.9918159768 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.453094268 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.9722060305 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.0213624273 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.5544694125 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.1340360737 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.2220600798 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.6517750227 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.3275853531 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.2830720258 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.0852853156 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.2937236095 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.4137731909 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 21.1616050762 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.5139386845 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.6182632324 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 50.8288968824 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.5127688398 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.6802531692 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.1800041029 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.5139967324 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.7994234817 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 34.5853287541 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 50.2845445619 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.3857758669 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.7862072348 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.9125499708 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.7567186375 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.3434542218 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.0182077907 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.4866282614 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.9268633102 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.1654568142 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 58.7815382153 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.110477047 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.8563636264 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.279318566 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 12.8674510744 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 109.084090041 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.3015845884 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.3180724895 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.4882069681 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.7389713982 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.0810797318 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.9811489314 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.396013452 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 7.72446193868 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.4933769991 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.4892525181 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 51.0007610624 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.9390702041 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 18.4075358105 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.0610655291 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.0285632946 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.5430894629 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.8637659733 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.272993347 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 53.9585248683 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.7628126998 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.3349132447 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.7466533705 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 47.7103574576 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 37.8249794217 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 49.7711073935 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.2496450578 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.244468996 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.3799965 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 49.5704762011 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 38.8271609716 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 120.473344192 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.5692767899 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.0133104551 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.6122539592 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.9435720507 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.5559969511 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.906831408 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 50.9046703403 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.0535800327 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.7292992964 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 15.3575941765 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.7193888367 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.1119674197 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 16.1469617566 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.1015163676 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.7736180975 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.120949073 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.7295069528 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.4341578497 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.3675095317 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.6717246669 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.9835632215 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 40.4358165124 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 16.8006510482 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.1826497833 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 12.2591562688 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 49.4137681307 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.6667204987 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.0023443994 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.1557536731 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.6186024494 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 19.6440378508 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 43.5068982471 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 4.78459154003 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.8906777743 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.1778058465 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.0735473724 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.4113458862 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.8896613342 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.1907327792 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 34.4025436862 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 57.8706718487 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.6556082111 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.9436367115 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 56.1449098053 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 113.509838313 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 47.1465902075 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.0011854777 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.909730571 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.0917279391 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.4409454995 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.3739984119 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 50.5671369953 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 53.6468920925 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 10.0775112376 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.9059362771 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 112.567749127 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.5324555819 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.4332966498 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 43.5636007695 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.0549906176 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.3402975616 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.4763517443 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.0460116945 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.90862170068 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.8046171165 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.6077921135 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.0727974473 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.9376187478 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 38.1203234961 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.2337908584 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.1443820937 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.3510987272 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.5292980311 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.9775038099 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.0591623228 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 18.7097573202 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 56.6054640675 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.7271045976 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.7879942554 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 18.94909303 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.6776708317 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 47.5077243036 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.1723616038 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.4862756391 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.6886463564 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.1452098247 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.9179626494 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.3956954385 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.9260452432 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.6704192931 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.2510814627 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 33.362784922 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.1762270748 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.359443091 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 31.2350256484 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.6703761854 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.7787555965 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 54.7920254435 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 122.094379706 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.0142658493 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.6573340278 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.6572724047 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 18.4794800256 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.2800466827 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.3408561932 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 105.315053688 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.7479408919 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.5977616853 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.2798245341 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.2549391968 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 8.83841820243 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.7632690538 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.3722692945 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.5368573208 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 3.65969462342 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.7010615551 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.4322120453 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.6852284681 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.9974912497 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.9786472223 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 32.4160132068 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 11.1979472876 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 10.7734837717 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.0026891022 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.4054785196 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 57.8388434398 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 19.6302923433 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.2001748252 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.0935298186 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 54.3816140982 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 107.830203952 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.8352444609 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.7362122265 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.0961558238 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 48.5095841906 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.2449144477 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.6776034142 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 45.1136045406 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.2832781406 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 13.1179792176 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 47.1372203417 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.0478189817 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.2341557333 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.2862261435 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 48.5787624726 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.430695709 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 32.3180664329 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.631845727 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 15.7130090887 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.3505109801 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.9026193966 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.0979112677 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.888159097 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.51713915127 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 38.3055917153 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 31.6604748681 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.4609136087 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 55.135559341 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 50.7683259902 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.6153264345 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.6819573194 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.8936594332 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.8320602717 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.8543877278 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 14.106055264 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.178996897 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.4614319037 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 12.8335557723 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.7953490178 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 13.7191540776 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.706773781 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 49.7837114071 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 49.6179206631 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.9225106167 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.695751839 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 8.16118217143 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 12.8422281193 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.9570183132 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 52.8876846256 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 47.9222507027 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.66786314764 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.1595557094 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.0009539857 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.4983095281 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.618680626 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.9076736839 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.2889375361 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.4331365077 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 52.0643935553 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 13.5336355693 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.2970075442 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.1331048639 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.2693537554 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.3382321417 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.7472212622 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 52.5402202849 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.4881857562 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 19.5128394044 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 50.048259749 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 37.9502799377 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.99043356396 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 32.3485858051 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 15.8707412322 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.8202973245 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 21.635159824 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.8746889774 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.2333974452 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.6110437938 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.9283331423 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.1388563361 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.5783077869 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 16.4709859306 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.1373690192 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.141056256 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.1705731802 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.1185009485 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 33.0258885589 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.1339203458 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.8526271814 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 14.4666168821 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 59.1765750571 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.8633626948 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.8382966239 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.3309428474 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.5675017934 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.2472827476 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.0798471392 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.3361946487 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 33.3434771951 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.1839812441 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 54.1877276806 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.5169005379 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 31.149363578 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.6280648628 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.7752192076 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.8938043029 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.2467145215 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 55.4165403869 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.4488556765 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.703211787 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 51.3429924683 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.2502745103 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.7189785974 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.7706759096 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.3612604475 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.7396243235 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 14.2465337664 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 31.0696857416 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.2162948295 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.9512535195 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 55.0876525785 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.7934704947 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 38.9750675361 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.9884786487 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 40.0510076576 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.8763892266 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 15.3234665367 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 14.4908534595 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.2656490807 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.0103791068 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.1604883798 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 53.6602129523 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.7952057125 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 9.77202323587 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.3229772577 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 53.9556832154 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.2104774217 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.6522925192 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.8055880977 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.9557159962 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.6101334113 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 11.6542368123 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.1628549346 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.7669101955 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.353313223 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 14.6201694045 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.4700434984 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.3831686789 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 16.7662600667 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.8515831573 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.7389428234 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.2096321396 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.3444515294 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.7046451007 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 40.6498203127 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 18.6838688652 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.7607154524 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.0623901054 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 2.3095174811 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.148067034 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.92632089607 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 34.1884757666 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 17.9272591053 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 57.4533604102 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 15.7363598993 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.3136500557 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.915251848 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 21.1220235412 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 19.7765008594 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.159131034 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.7867102033 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.1067556634 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.088881973 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.6915355706 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 36.6375104079 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.6214214103 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 4.61646124979 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 49.1317924415 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.5291040485 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.0357562546 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 34.0083004334 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.1047156881 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.4617175287 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.6114202144 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.926741566 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.1811887739 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 32.4668369265 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.5172335963 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 19.2013232872 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.2862970653 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.6302935447 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.6871475854 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.8022006435 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.9838163271 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.7190576458 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.574217397 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.3119577271 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.2598278023 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 49.5157517562 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 47.8660698366 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 1.31814306075 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 18.3647139397 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.9768753089 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 32.926517685 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.6887273673 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.0383715759 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.881510868 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 31.2442189159 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.2348414721 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.136631649 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 31.9159826472 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.0122784345 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.3803501513 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.4985742073 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.9946189384 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.6783242795 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 53.5132442562 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.4557935137 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.0065993009 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.3266922445 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.0751048823 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.5646244496 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 13.8772424732 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.1392621911 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.8818513594 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 16.9575505012 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 56.7498244217 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 21.7860433535 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 53.3149297128 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.8998140701 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.4029153038 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 9.19121957891 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 42.3444680951 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.3900366624 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 13.3863260404 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 16.2080171068 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.7977055899 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.0767686441 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.6133895737 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.5943787848 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.8330749002 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.8273272339 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 31.6072038295 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.8123918861 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 49.857083338 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.400376121 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.9796335251 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.5036063809 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 49.1529676536 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.0124638953 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 48.3183334411 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.2901153926 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.2892337888 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.0746757778 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.2427250182 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.5536873331 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.3526648725 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.2402060266 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.9228036819 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.5435999997 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.595805767 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.2835501017 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 32.476075196 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 4.18510764423 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.9443481654 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.7319749787 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.926948478 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 59.6257240068 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.3910659595 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.2341432165 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.5211320465 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.998973601 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.8384682476 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 19.9590548296 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.3222302944 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.2352433219 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.7229782733 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 54.820773419 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.713271626 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.196950538 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.9353306823 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.1197860251 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.8498170662 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 33.5126703713 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.7707367002 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.3462472395 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.6231595384 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.704727856 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.5512227217 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 37.3919703351 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 16.7986528057 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.145129991 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 48.5026051849 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 33.4323380971 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.0913522159 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.4695520574 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.2344896145 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.9795068912 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.6155837571 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.0723527775 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.3765117275 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 14.8174462248 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.001766796 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.3452650161 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.0739097075 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.6696387803 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.5709239202 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 49.7047452594 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.9319872769 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.7071139039 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.845939816 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 47.0057731818 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.3220177351 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.4231315768 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.3920580578 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 32.3788079962 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.954829544 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.5131555737 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 12.4322269216 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.4831430965 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 15.7726120943 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 19.8528069708 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.3524984846 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.8246703648 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 18.2275424985 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.7918753474 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.7109276718 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 31.7933858913 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.3771609382 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.7874873022 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.8186979164 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 12.4426383843 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.0715832839 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 13.6097031494 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 18.5018699679 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.9019686789 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.5228503684 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 50.2664889195 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.2869463787 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.0848134149 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.4914531393 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 17.0734627029 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.9998881703 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 12.6433878035 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.8628858981 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 120.37096722 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 15.6699372671 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 15.3180336593 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.8006291806 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.0578905732 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 50.8975023862 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.1734570315 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.2584471637 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.4513603191 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 14.787590786 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 53.6010416493 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.9826386428 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.6282193569 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.7170258781 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.822232258 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.5332718054 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.4835055913 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 56.0211783858 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.9884823882 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.2890434092 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 50.5218528681 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.7017234208 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.6258434852 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.2277763701 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.7555013983 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.2659195183 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.1815725503 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.4620207896 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.4355857564 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.1049533011 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.4819299829 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 8.10907610656 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.8432924053 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.5987753357 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.003345548 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 18.0401482163 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.4672395981 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.1580840793 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 47.0177560933 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 51.291340232 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 49.3724569687 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.6093194177 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.4529420447 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 34.3792317874 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.6265071631 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 31.717379908 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.8192427262 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.8791204224 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.1981092303 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.2565796333 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 16.1905044202 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.2954544512 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.406490632 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.8826720219 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.2769192318 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.2882995753 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 108.853565215 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.1206903302 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.4678911608 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 31.2315151564 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.5300852101 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.4372872815 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.6504175685 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.631201238 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 13.1134513291 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.0979493862 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.5733556284 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.7723379683 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.9939611499 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.6084506237 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.8174536848 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.922188207 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.5891351676 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.2237202269 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.4440437885 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.0548395928 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 14.9809569674 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 57.8445861352 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.188731086 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.3137125989 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.3999909193 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 34.0677756916 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 15.4073798224 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.0810684369 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 48.4823664603 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.5136083107 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 7.55253074162 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 10.70536157 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.7779234778 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 47.1046889546 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.3312232671 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.9619778271 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 50.9573512964 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 55.1009960041 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 66.8745970389 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.9962756712 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.9909994376 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 17.4857906991 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 49.3334751955 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.2331749757 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.8681482886 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.5907710648 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.4961325945 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.4625635329 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.4900959271 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 15.043009827 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.1807177447 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.5415318912 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.4451901591 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.7637198881 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.1686158293 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.1837719295 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 13.1525989117 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.266961779 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.4227480234 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.6816092313 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 49.6051641391 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.0716637501 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.5435880272 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.1212301709 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.0702642359 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.411852969 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.8554707851 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.9682446193 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.631097246 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.1663120479 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.4855102859 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.4612525432 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.4844041214 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.7201044934 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 15.8796245387 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 13.3955631851 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 19.0266993977 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 16.3558097083 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 47.2989087986 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.9188834738 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.7629089885 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 52.1917910848 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.3889044408 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.8075115896 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.5056200163 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 15.4437954319 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.3935052658 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 65.1547267786 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 21.4885020384 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.4629740269 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 60.8182827035 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 31.4319273717 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.2516925558 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.9240628436 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.3213625377 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.7678135357 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.5956642238 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 13.6893302023 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.0949977195 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.9902592352 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 54.0103981231 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 14.9713710297 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.8119364353 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.8547268856 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.2869836142 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 13.0262216386 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.2067008051 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.3239416357 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.9714340187 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.8520400041 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.8687919141 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.5016030991 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 34.2138069352 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 35.6307621285 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.6468627434 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.1890895463 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.5634068216 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.8644082049 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.390826845 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.6389415936 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 57.1033025544 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.6165306175 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.7877683862 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.5881968156 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.9855601375 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.7436362269 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.7065885443 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 14.9209188447 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.9792869307 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.9829945429 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.555323521 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 15.8112804576 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.3586665092 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.2202366249 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.8517020226 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.6251757913 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.5973406713 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.0527863553 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.6369025676 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.7098623015 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.1544642497 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.9171155788 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 16.1112689617 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.6824269414 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.1564345503 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.2784872718 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.7486283976 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.7024398449 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.343339685 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 38.6921033638 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.6824704369 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.0510183913 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.6703671191 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.123256256 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 16.3275003109 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.5922753923 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.623835003 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.348037894 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.948178177 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 18.9476493271 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 48.3715560174 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.214193676 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.3399849123 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.1639127861 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 18.5149013796 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.7743803118 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 16.2738176006 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.4320817141 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.9762152427 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 92.3341107224 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 37.6668976048 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.0793858128 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.9730574046 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 13.108069443 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 15.8184661156 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 54.5956475686 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 16.3374783913 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 49.6051602256 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.7520048031 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 107.894826319 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.9813111554 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 32.4580211504 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.3320689082 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.4740346706 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 53.4707779608 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.2651419967 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.9161918468 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.855323534 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 36.8437301061 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.308534373 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.4811482788 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.5029901145 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.3572621559 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.1853143993 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 8.80370329279 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 18.101174634 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.8702228639 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 15.0969783606 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.1933795801 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 114.565377343 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.6550658591 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 14.319507004 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 3.55095240957 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.0965798968 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.2971696227 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.7678753501 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.0454687714 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.2104593216 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.4123226755 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.6543400894 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.791182176 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.584765296 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.8386455585 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 36.6822799155 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 18.9714336287 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 13.3926895192 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.6315217118 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 19.1190185047 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.670795145 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.6152030149 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.7738387772 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 51.5603490413 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.5125915352 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 19.9924617537 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.7359909148 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.72583300051 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.5620446326 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.1156935333 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.6075853721 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 32.4729281301 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.5949287705 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.497608977 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.0586493248 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.4175800298 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.501129734 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 21.7050419744 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.7044874424 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.0122980605 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 10.2757340503 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 36.8911498674 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.8703327947 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.5599341775 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.4945261864 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 19.1297221752 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.8846995873 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 47.9426095289 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 32.5600759736 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.0051738291 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.3148963933 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 48.4404765611 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 51.7235598412 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.200587681 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.5592120243 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.8061496469 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 97.4383947266 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.9086685199 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.6092985687 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.8614577231 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.7351171712 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.0213622571 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.6472431222 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.3400564415 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.712122014 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.1420360475 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.6323395471 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 9.36536831776 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.3878477817 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.236444617 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 40.6630535331 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.9467446303 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.0399207771 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.4880349252 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.6584179011 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.6535040435 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.184507054 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 42.4523132919 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.4047282743 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.5834550629 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.8978089438 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.9095961209 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.5719065071 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.0818812116 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 33.956919525 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.8522409221 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.3189458153 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.7102022375 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.3465575735 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.4683353153 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.316207905 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.2297328212 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 18.0928419153 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.0821856988 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.0337531206 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 56.858561346 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.7085063083 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 55.1775646619 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.9251975676 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.3769534943 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.3444682588 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.9138030961 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.3799659653 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.4844424528 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.873541211 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.2903514709 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.6121321286 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.9127727709 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.3864211398 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.6195732862 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.6165571864 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.3858998341 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.8108651549 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.6646818346 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.6148085078 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.2859235062 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.918674018 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.0202099359 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.5383526664 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.4755919774 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.631359612 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.0643948172 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 55.5001379651 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 17.4831394333 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.6042039626 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.5148953629 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 32.7009240465 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.986181387 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.4013434562 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.3251750157 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.0090466673 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.8122137975 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.6972688637 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 17.2043154419 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 48.5523656769 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.1896209664 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.5793362808 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.2295633575 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.5329675134 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.8850912464 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 41.8171499582 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.221910914 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.8950126339 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 53.6946983503 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.5266252877 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.854918439 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.5921261898 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.9008079661 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 49.2233294759 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.6874399086 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 58.8253891296 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.5155952451 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.2987038229 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 16.3691488276 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.7835877755 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 21.5032312393 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 11.9552728311 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 19.1352692195 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.5402601973 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.777366375 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.2891700853 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.4500693719 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.1266696832 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.9925410553 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.0247373673 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.3002584632 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.7146671713 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.706634508 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.3184430467 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 34.6435457316 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 15.0878446711 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 15.6680914685 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 54.5595145994 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 48.0551940578 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.1586547376 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.4279145562 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.7264687057 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.8988378777 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.1827793114 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.2227531624 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.2534186638 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 31.4060701209 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.7935097607 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.3757897598 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.0029998447 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.0596542711 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 47.3997869038 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.5563594858 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.6564252038 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.9492638885 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.336257493 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 34.4767921715 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.0754749148 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.1763455328 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.0285248055 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.6361035076 0
% INFO    : Updated Generator Cost: SYNC - 0.0 1.0 0.0 -> 0 0.0 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.3994956583 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 21.5655706871 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.322829639 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.8704885059 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 19.3380332192 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 50.5827426756 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.6663528581 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.301183049 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.7496025536 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 47.0896943346 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 15.9366548475 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.7979471849 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.4331119116 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.9295801452 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 8.95900299713 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.3863139407 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.0082869404 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.2570557111 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 13.6501119508 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.2493747477 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.7728021996 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.8466204605 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.580751114 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.3188807927 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.3437978179 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 48.4674451273 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 108.159045577 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.6081701915 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.1181385422 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 11.9866282822 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.1888034217 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.470226211 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.8805610225 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.4585843356 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.8297637797 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 59.3909277506 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.6523839607 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 2.89667858867 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.9056045985 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 52.305082559 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.5627033828 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.6444860297 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 19.9299660121 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.1074945734 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.745293007 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.0117709758 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.5985828713 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.0365043518 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.3902660682 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 11.6500939126 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.6120389276 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.8181634793 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 14.3898445221 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.5182451005 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.5536284634 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 15.0128942744 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.3706518661 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.1517583566 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 49.9973273733 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.71122702 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.8637372593 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 10.8963686514 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 16.7656625446 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.3215631822 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.6041589596 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.0647322454 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.6556791813 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.5926610233 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.129613991 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.7530028682 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 49.7019287012 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.4956104311 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 49.7669808018 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.0150525442 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.1258716018 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.7484175663 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.3904678063 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 19.9605774717 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.5935297038 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.714900613 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.2292658227 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.2464744633 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 31.1640067985 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.1746942737 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.5049170828 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 32.3823038265 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 21.526458791 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.3456554635 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.8205429176 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 53.1359458376 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.6811348427 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 12.53874317 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.7700143032 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.471452374 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.871596121 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.7009521566 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 18.4841743066 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.1398353025 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.2705287071 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.2732960495 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.288732812 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.6771119849 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.2374287422 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 48.5892384823 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.0843721754 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.1859169462 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.3320740151 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.789689502 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.4539156378 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 19.4638244388 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 54.7192553778 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 34.0179813868 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.3423138894 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.1511409736 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 16.069259265 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.3769458411 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 35.2326802497 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 16.2142608019 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 43.2609086266 0
% INFO    : Updated Generator Cost: SYNC - 0.0 1.0 0.0 -> 0 0.0 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 111.80869447 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.8116580992 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.4158906558 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.7907469932 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 11.9150513371 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.7242349347 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.3702998569 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.2222534898 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.1770118532 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.0316659253 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.0160561208 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 47.0457207929 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.320961434 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.3202288639 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 19.539069948 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.3150718412 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.7689208048 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.2127712081 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 3.61708311031 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.6403092605 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 9.37787108948 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 13.8377705835 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 53.7170309803 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.8218082418 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.5265081304 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.9522285836 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.8956259381 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 40.8011472809 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.674946921 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 11.1630720857 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.9034784325 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.1003321541 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.9305362957 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 34.8851775296 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.3771205943 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 48.2036015837 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.5840992594 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 112.437698759 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 15.1871990406 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.8643020501 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 57.7959500214 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 12.0919620672 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.6238253846 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 35.3980820337 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.3362446928 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 49.7181157816 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.0490541566 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.4212104897 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.8212906972 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.7931196089 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.9294892564 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 32.315550093 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 11.0106387038 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 35.6249433385 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.7891385664 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.9123259913 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 18.2742080022 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 61.8614364254 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.654737291 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.0160883141 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.1521035078 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.7393315314 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 19.3554418828 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.8107704301 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.9871678168 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 35.4047882753 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.8326253238 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.638968162 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 18.2346420301 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.9583473342 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.7757176215 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.879601283 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 13.9646907266 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 55.9666761062 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 18.0554308502 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.4363089086 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.0230532767 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.8258859316 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 49.3082881416 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 49.2529196885 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.78418052444 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.2178893611 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.1688905344 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.5569122833 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 18.0923226774 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 52.6389622153 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.9993610975 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.8961047471 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.949003031 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 18.7779296054 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.9461058666 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.084559007 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.3284532511 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.0272704798 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 21.6569284607 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.1989471184 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 19.7054069288 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.1525530073 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.4006857196 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.5184412517 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 52.7864039696 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.0472635613 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 31.779772293 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 19.7525428983 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.6981557755 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.7137820203 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.8354375624 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.8406111428 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 10.5184993983 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.0314778516 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.482813064 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 109.252242049 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.0529775273 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.9805655543 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.0893692363 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.0560671198 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.5584968951 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 7.53027303464 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.3716927536 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.7954089845 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.6048800102 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.80646668 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.146348712 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.7481867765 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 33.5273277937 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.320518719 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.0901929296 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 50.3670492324 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.7854529222 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 60.1950975266 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.3225974322 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.7837289834 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.231912814 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 18.8185498817 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.2014879786 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 31.0917682419 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.1016815348 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.4414540105 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 113.165154556 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.0196688187 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.4266026286 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.8964966425 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.9105003632 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.7649783365 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.1511167345 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 32.0162024744 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.5419347401 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 48.7143939556 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.8169089195 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.042031868 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.623662346 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.5353784113 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.7679588187 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 65.9866544393 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 13.5542246577 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 34.5216029199 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.8640942479 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.8439548008 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 50.2369679456 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.02834395389 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.2733755987 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.3509792158 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 16.1417092756 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 110.653032042 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 2.80098056493 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.8077880547 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.0583034051 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.8020755833 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.5774244695 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.1449146967 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 19.8505461477 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.5925406123 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.6123724068 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 47.8400135545 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 38.1769085799 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.6209888959 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.0992849983 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 32.0296385729 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.9820117237 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 43.7127844194 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.2447350955 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 12.9257585038 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.8249561071 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 48.2099377023 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.6674000682 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.5037416692 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.7983159729 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.7944731805 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.372159671 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.1645679238 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.9934483579 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 10.1721021969 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 15.6824729208 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.4667233185 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.5239204071 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.2029445434 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 50.0993506793 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.153408567 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 8.94979867804 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.5766666162 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.3514424454 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 11.1583222479 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.5347977445 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 31.1045577193 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.7483630998 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 32.8889254705 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.0590677138 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.9770116652 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.3608808554 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 55.9590792841 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.2276685499 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.3608376523 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.8564074691 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.4393309811 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.7201621807 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.1137656467 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.7527786727 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.4789514826 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.8642277456 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.448099492 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.0133058939 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 9.69866640669 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.3673265996 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.6430043539 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.7923708394 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.0100010051 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 34.6875979828 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.6200771715 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.8276005576 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.9043783036 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.0839089623 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.449693881 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 52.60161974 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.2131554467 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.7322375897 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.1940304068 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 53.7195227708 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.5602157916 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.0448918355 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.1816653004 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.0266988025 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.2023036601 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.6158892973 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.9004509333 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.8275101082 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 16.9653423039 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.3417491738 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 117.717965674 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.5154523 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.6931887652 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.2472858383 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.8598535852 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.8466250979 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.6191956515 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 50.6123936685 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.0829959843 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.2641080598 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 9.74663286115 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 7.95875329743 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 123.517407605 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 18.7056556679 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.7853807536 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.2369462385 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 47.8626449963 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.8143921931 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.4127901847 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.7310389394 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.7118632462 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.8187160887 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 31.2623508591 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 8.37772784622 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.2686291132 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.6622182374 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 49.8633541894 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 52.0187470014 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 5.39980737359 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 1.85633943352 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.9126484013 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 37.8326037632 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 3.62990490487 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.0157523131 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 55.9364986451 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 52.3535116525 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.3366184341 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.9412744727 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.8101568854 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 34.4175272271 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 56.344109401 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 123.442991219 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 33.4802756869 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 39.4760587628 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.8571704105 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.7345995684 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 108.644421418 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.0782448011 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.9635576803 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.8675117039 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 47.5185516609 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.0754997723 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.6000050684 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.3188683102 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.7176584868 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 9.73313212301 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.7798120245 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.4780092795 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.6502542369 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.1796264873 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.6222187926 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.175771081 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.2742509228 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 4.49956125406 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 48.1279140889 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.2226905391 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 8.9728967957 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 55.8556124734 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.3396805035 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.9650809468 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.0405671896 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.8556819962 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.239197048 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.8630695165 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 19.9182970714 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.6983269175 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.1595843773 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.7489872358 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.6556635857 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.6342419838 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.012696387 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.2823295619 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 16.4941555597 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 50.1743561527 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 55.913982413 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.4242003717 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.2980812004 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.5915336662 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.4545439848 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.0194948117 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.3542631999 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.6383697343 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.8687975135 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.6861813719 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 21.0517586657 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 31.4062316607 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.1475619218 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.679803752 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.6083028624 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.4212583288 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.521466673 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 58.3159405973 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.4869494603 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.1896782451 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.9681152621 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.7514353213 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 33.3902674545 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.6255337411 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.1295649228 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.4102958086 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 12.6847790282 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.1975175957 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.9646677733 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 13.5739744113 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.2076861944 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.1249236143 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.0550221928 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 19.6892941722 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.8676691082 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.2532668298 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 33.056298125 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 12.6253250396 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 58.0149441179 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.6671403484 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.2011126995 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.4822731162 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 64.7873135654 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 6.483007517 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.0476187985 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.5487594491 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.6530855769 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.5425556328 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.1530762257 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 33.0293868099 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.4001804983 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 53.1721005353 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 54.292749817 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.290597876 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 110.208229755 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.806627083 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.2435428622 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 11.7735318787 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 47.6193787887 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 13.5444930032 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.0208609437 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.3923088589 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.5378844385 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.0444546274 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.8005386497 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.4785583812 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.3476746901 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 31.3196607832 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.7643286502 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.1625962374 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 49.6846461226 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.099337014 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.7035472788 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.294307151 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.8017084768 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 38.8833072992 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 51.3680881946 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.5653627147 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 16.6939569346 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.5126590894 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.7430141192 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.8795175379 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.0208124389 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.3498453152 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 18.5656751872 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.5775339223 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.8766608684 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.9574515554 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 53.4789908115 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.7510471365 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.1027864102 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.5159386916 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.6212776508 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.4564013591 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.3375576091 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 47.554576133 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.970684188 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 15.0214217549 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.0532472919 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.8150002475 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.0063655988 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.4000186515 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.64943370182 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.1089389888 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.0426157516 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.6572584035 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 18.7675512779 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.0159532372 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.1749409149 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.5346531119 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 58.8634658016 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.2189466403 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.1733149342 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.2301582651 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.1662629027 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 58.590306153 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.2425290384 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.7865199258 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.9346327053 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.4025872865 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.8027681885 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.4817582194 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.4955946343 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 16.3827007832 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.6156801645 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 19.3274461529 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 15.1881935534 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 50.4495051726 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 21.6478388626 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.6587459897 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.1081374319 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.2966090131 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.3439757732 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.1923353459 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.2094502853 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 6.45798218117 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.4642357041 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 15.3929954714 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 16.8423151263 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.6587562407 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.5918481278 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 33.9727093505 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.9743174618 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 16.099137117 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.7350135946 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 53.0377797762 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 14.2816879343 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.9232240102 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.9204666905 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.0001277101 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 11.0026753444 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.7710084464 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.4078846948 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 17.6819505049 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.0278394658 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.4236368877 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 56.8022795733 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.1650633959 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.9717254727 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.425665389 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.4038120496 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.6189629637 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.4837882922 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.6732881007 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 59.1913299013 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.5994804853 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.6010344221 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.8549359317 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 34.7709845303 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 40.8829953422 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.0930865043 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.0528168402 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 17.0728783311 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.9473116677 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.1969244335 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.3769857877 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.2847637145 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 19.2337936504 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.3042493606 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.2164026601 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 15.0395480786 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.1259232635 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.8892691202 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.4689136578 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 19.1369554644 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 13.5796222123 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.3279092791 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.4428894749 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.8791253093 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 112.664057645 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 54.0281734697 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.6910989034 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 13.3726286503 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 47.9840554308 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.1016817634 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 36.6858286533 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.1664203034 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.5939287281 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.3019143513 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 50.1750055451 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.2359969712 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 14.8741282388 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.5589855563 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.3189742505 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 94.8557683582 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.3219067376 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 73.5869768063 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 21.9915453865 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.8356712229 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.5982024412 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 48.864017479 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.4106194813 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.7676126489 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.0764733013 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 37.2539692177 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.6593481023 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 11.3430144948 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.2910156961 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.5164370393 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.81878693 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.1122651907 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.8634304242 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.5114895418 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 18.7843006033 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 34.480591174 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.2399747127 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.3243886654 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.5597676104 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.2259744236 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.8257014669 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.5366484712 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.1412898082 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.2277975022 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.11536765 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.8467337571 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.167415006 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.0482621813 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.2414664408 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.3537067353 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 15.0216623313 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.2134061164 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.8075227644 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 9.61965914344 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.9513459805 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.7270802817 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 34.7491792483 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 49.7077274517 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.5752980687 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.5760610712 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.7153105608 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.3334804482 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.5908249042 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.1551135182 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.1979742157 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.2048971686 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 7.48621799265 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.9945134636 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.8295349078 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.996815683 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 32.6364903016 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.307638069 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.768126092 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.19112531 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.1352887569 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.6866565225 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.7484745014 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.2998458403 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.3667468808 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.3001388494 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.2841682163 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.2220850764 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.7319253398 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.1438090476 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.7327404904 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.3890209219 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.4158125371 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 16.2081961287 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.2645504372 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.3546804717 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.4273195341 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.6550299868 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.0674608522 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.9825736688 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.596962096 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.2252977404 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 47.7124733109 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.9185266754 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 40.8307712924 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.5915947178 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.8484173245 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.7834390525 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.1344633264 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.8179072354 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.4776129519 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.7941009454 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 47.6782886442 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.8316002677 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.5945022587 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 12.5346214282 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.9215087403 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 105.993979844 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 14.2469589621 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.8515074264 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.9387454108 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.008943345 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.0898981711 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 9.11231303672 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.8073804743 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 0.0429635356524 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 34.7099954972 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.453214643 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.4075012214 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.855425278 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.5326918524 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.8528548958 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.7424497767 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 48.1632315315 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 49.211042521 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.40166532772 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 10.6268482313 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.8362966375 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.3209657968 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.1609156419 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.3164513945 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.3111534868 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.1421172062 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.1939387906 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.1624541269 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.2237849022 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.2258350098 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.6805627215 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.234455554 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.8003549094 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.5793558973 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.9242820324 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 51.9129631138 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 49.6986525604 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.5883446588 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.9638276901 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 52.3260184414 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.6452775196 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.650540269 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.0376823072 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.0564472312 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.1939612216 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.9056069675 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.125172668 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.649607053 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.1314617158 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.0758393903 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.5454608344 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.6379167795 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 6.05136686231 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 49.2784780275 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 10.6238278559 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 15.0104206983 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.7196236594 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.9856572777 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.1175503689 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 8.46442229634 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 21.3299223223 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.548949573 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.8749213958 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 15.4259566025 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 15.0259501085 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 33.6538318965 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.8720341984 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 11.9726403072 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.8118446552 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.0030109599 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.6527155332 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 15.7112468647 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 15.1545640703 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.8576144068 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.6780992947 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.7179240956 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.0030648362 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.7783281937 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 12.8103733525 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.4447977043 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.5736851719 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 5.37423249384 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 5.97285505247 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.3464954513 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 63.3133215153 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 33.7553397636 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.8133810827 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.1480724378 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.7758830613 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 13.9101435264 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.9913077325 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 8.47344150233 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.0798945183 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.3696318706 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.2753538549 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 18.1272380226 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.7780429018 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 32.3472493792 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.0348217409 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.4113542479 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 111.805479944 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.7081914398 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.0459931314 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.6961498367 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 16.1495688658 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.1530634113 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.1406365912 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 114.742346223 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.052305159 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.1152308293 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.2356394623 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.4998995176 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.087578073 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.5779919198 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.1217994709 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.8591232597 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.3466483185 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.8971488737 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 64.6753006402 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.5979712994 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 3.1306142802 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.986687264 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.3902462752 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 61.742459089 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.9184458043 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.059681509 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 18.3586165432 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 37.0058215627 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 31.4516264729 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.8859410054 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.7359723132 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 18.0453053339 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.934259037 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 11.6745797981 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.1166800642 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.4121927986 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 31.2556543707 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.7770461895 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.9337377321 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.3278933827 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.1921822837 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 5.87244843889 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 9.58533717519 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.4194185738 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.4243382916 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.4732716924 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.6035889488 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.0047046517 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.8304039951 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.0104030333 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.6254961961 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.6342661266 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 8.03757126458 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 32.8017413695 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.8011007631 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.5660772714 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.4911629196 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.6888376053 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.1449907444 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.2122073166 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.0234514689 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.2715987822 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.0528272025 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.0800615276 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.2873303499 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 14.2908933598 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.7090805638 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.5319240408 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.6521863213 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.8742848899 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 33.5542780609 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 51.0538955589 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.4359055339 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.5016971228 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.9742335792 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.2576988767 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.0111235567 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 16.0708409965 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.5523596847 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.6652831289 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.8902888453 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.3739067211 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.0716472851 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.947700439 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.8760335398 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.5444416172 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 18.6208813766 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.9936863879 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.7540163836 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.2807901593 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.7630700076 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.6424974093 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.7338594728 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.2356406979 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 14.3544065811 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.9704522388 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.526454466 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 34.1587461702 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.819041355 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.5164540435 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.8050564235 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.3468732754 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 49.2761325463 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.9828759192 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.2130630012 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 47.0478207789 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.0939108113 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.9378040392 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.9564996547 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.3705696167 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.9876035127 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.6511359462 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.1348295563 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.6575503986 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 101.618429459 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 9.61614148218 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.9295722489 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.6490015969 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.0076232305 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.8692170008 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.9615409268 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 52.086324687 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.4048339403 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 52.7039294397 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.7811524987 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.4859795834 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.2418052559 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.234661311 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.0488624468 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.5273869264 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 21.5858552764 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 37.2010966909 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.1316402392 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 18.292536527 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.7473453368 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.4548167215 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 121.874424014 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.1731855608 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 8.61564807868 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.986587076 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.135448466 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.1859417827 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 21.6322468683 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.7295608024 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 57.8218546262 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.6133675401 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.1693162109 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 47.9388918717 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.6931171466 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.5416698934 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 19.3507660523 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 15.622916565 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.1527065568 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.0815751681 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 35.7267710923 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.4544603592 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 9.34196546057 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 16.9822646658 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 32.6580397181 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.2968244099 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 5.3754993269 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.080894377 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.7890884203 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 14.9015395474 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.968586084 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.5162479526 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 33.9911980408 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.4255609667 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.5284680776 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.2216353922 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.5901344601 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.0074488837 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 12.582198519 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.3955231089 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.8280696551 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.2868678761 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.1182636287 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 13.5364962774 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.3806735749 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.4195158785 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.3659250526 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.2947278568 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.6131778642 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 51.0590299508 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 48.2075348663 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.5790764467 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.9852797758 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.6138454846 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.490967197 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.8498557077 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.5065521243 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 52.9403659507 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.0273837449 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.2393186582 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.6199100388 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.8413447875 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.1304189925 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.3570384172 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.0732813493 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.9487607419 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.4136760558 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.081500208 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.3895495257 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.6381909785 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.6805919329 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.2372256871 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 50.8805739414 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.3803104999 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.5845627089 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.3901943717 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 19.3556120686 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.4555514576 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 66.2580237132 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 52.1651744414 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 47.3598579945 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 10.5050278643 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 57.6124529553 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.112194568 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 38.554038918 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.1594740512 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.6070402285 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.53773922829 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.3812152695 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 31.3294764551 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 12.0162460533 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.5300495788 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 50.3735870492 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.0049587356 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.9771134393 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 60.3748899713 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.1483475345 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 31.3949527781 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 12.2497735671 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.7531750557 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.0869304901 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.7065134168 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 47.8598114913 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.0369348534 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.3537449669 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 44.570664472 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 36.1945151436 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.93032317 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 33.8493262147 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.7885974574 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.3142195339 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 42.3399149387 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 12.6820840363 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.0973101805 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 31.303083582 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.6979893834 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 50.3199866788 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.0363540423 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.6353958001 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.1548074533 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.7138836104 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.2187495572 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 34.5705174207 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.5752833382 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.7223007174 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.3028855773 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.5027782081 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.8890437511 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.0927739292 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.9304991359 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.1307858856 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 39.424830372 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.0112336928 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.6211848626 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.5797951775 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.9296532471 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.1174506764 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.9880571105 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.3742746287 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.2640997599 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 54.8321082981 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 17.7588652344 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.0064573375 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.92013238577 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 39.8718126451 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.7941306661 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 15.311208621 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 12.271657954 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.2096315368 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.9635301774 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.5928158062 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.6741756033 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 13.7430910075 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 14.055014175 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.0250532613 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 62.1401089259 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 47.098580783 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.8262928453 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.4355911999 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.5560045333 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.3378627871 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 55.1995105663 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.5766557546 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.3713468128 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.9588810931 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 34.2868799369 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.0775946617 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 36.8150685711 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 124.566458644 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.6342278004 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.8981249458 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.444296541 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 49.7066580236 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 60.5017775128 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 61.5042238589 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.8650646732 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.5102657877 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.2377915304 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.7936979598 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.7706550164 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.4795775898 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 57.8577292439 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.9549781462 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 31.3489129824 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.7796580144 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.4214124067 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.3425554445 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.1669406231 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.2688439636 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.6338738195 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.2661376972 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.8227375046 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.0782612429 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 60.0315133949 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.666756252 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.7379386193 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.514609928 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.5129279107 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 35.6029191568 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.327456709 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.7278689021 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 47.6434220986 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 41.0469841584 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 63.2102396257 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.1601494115 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.3474111695 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.7692054915 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.7606648784 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.4059924999 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.3249230398 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.3907964285 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 34.2146292481 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.69877487209 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 52.4401566639 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 50.075724869 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 121.899606052 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.2083801546 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 19.8579984187 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.655636025 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.2794246453 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.3781976751 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.0962247507 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.577990569 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 35.6288255092 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.2425979159 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.7717782298 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 47.3102903052 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.9148487684 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.1207800971 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.4538328688 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.8076896732 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.7525391532 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.9370128012 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.1178796194 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 107.694614026 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 33.1803592764 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.5964829867 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.2556742363 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.9104733926 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.5275774903 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.6493135979 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.0813329603 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.9631793287 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 50.044808404 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 6.52330201568 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.9657310953 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 21.8438394746 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.6672856119 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.4958180352 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 34.7087653874 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.5805831118 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.851718402 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.8619970787 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.37705301 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 40.1016074029 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.4694433869 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.5790825446 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.0475834457 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.822102604 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.6259567837 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.8615151147 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 47.2044948744 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.3441402533 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.5395889261 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.4548615016 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.5642627649 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 51.227731922 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.1360808655 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.6053658732 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.5444498108 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.6966857643 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.2890382345 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 51.8385503551 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.0771390775 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.4582976387 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.3426375139 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.2132865875 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.2639811713 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.6899500571 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.0571001875 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.5767138477 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.2810776714 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.1951012126 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 9.43128211079 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.5960530464 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.0170466722 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.3717021789 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.6699544483 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.8190878574 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.2451529982 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.1223479619 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 11.1500664477 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 57.4079906565 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.1368358255 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 18.929668798 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.277271339 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.3053396279 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.1521420134 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.1388909163 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.7837900397 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 49.8734383308 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.9373695728 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 36.1773825078 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.9951961238 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.9012292657 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 32.0657477601 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.0017606356 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.6434490326 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.9171074655 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 16.3138838031 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 32.772959006 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.2027631284 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.7686389293 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.6174051685 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.1123785016 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 8.31851512791 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 8.52174266645 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.8939158489 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.104325325 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 16.4738787576 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 5.79148892816 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.8000125665 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 37.2693141683 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 11.7590775155 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 37.3936764645 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 44.7270741094 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 11.1398135657 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 14.832612681 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.2920325058 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.2070389738 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.8337126034 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.3167951752 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.5382807803 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.8825429758 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.1596235379 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 21.8460407983 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 16.7678209793 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.3905678602 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.0099841315 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 13.5786157466 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.0511355426 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.1587602489 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 106.896165346 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.5220200823 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 33.9114151946 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.78585616969 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.2908682673 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.9532176984 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 18.5374820173 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.1527977014 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 114.431967633 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.2741302761 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.0320226437 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.80823438649 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 1.2111780297 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.9686550756 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.5134293076 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.3395843924 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.9737810825 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.1052462696 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.4054437505 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.1107457784 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.297488893 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.2050558182 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.2818999356 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.6487342881 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.6387967194 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.9108725143 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.9224720336 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.6846871062 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 5.47832401041 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 35.9399273829 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.7833659006 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.6565673303 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 19.3571414969 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.980714898 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.4190346207 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 21.4804016103 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.995987154 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 41.3689721096 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 40.5393102112 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.1311018354 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.1218626213 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 34.1127996829 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.4687205378 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 13.2020189332 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.7622055394 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.3715388695 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.6990361074 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.6093009762 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 5.91830654064 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.5028269678 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 17.902326947 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 50.274166394 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 89.6396483216 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 52.5811725983 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.8932029645 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.0984070773 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.2455811417 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.1280219732 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.9391529049 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 51.1377039244 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.7423726656 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.0535084012 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.438285609 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.6215309934 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.8052559383 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.9126775725 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.0921028014 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.9077248634 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.2858113522 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.0381176876 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.3868108989 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.7676866179 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 11.6909740658 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.1953102527 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.5970232315 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 32.7690055811 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 19.9805062749 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.1165311618 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.5945902211 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.5413364302 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 21.1668376475 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.5694261565 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 12.8787447356 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 31.6423919792 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.1843136139 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.9439416918 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.2045387313 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 14.9290837783 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 15.6884746239 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.5926302615 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.165528492 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.0203509502 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 50.1488852699 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 51.8045565295 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.8251231474 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.3233356782 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.8384607248 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 36.9130448675 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 49.4643440544 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.8497264116 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.3194339752 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.2123047111 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 19.894088059 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 57.0271579022 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.2778714524 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.6680676488 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.6836301873 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.1534506643 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.4606475651 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.4634270027 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 19.8824099134 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.3454277305 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.7800354387 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.693457131 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 5.03858645656 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.2762735304 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.852291702 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.4087357191 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.122826013 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.6008356847 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.0317151578 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.3471228552 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 17.8234451034 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.7924669259 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.5295862805 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.6041274219 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.7555238229 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 12.1812290977 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 4.57260767142 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 15.7839842101 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.4710535041 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.9377009355 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.0729399165 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.2068060583 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.8341276927 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.1095433742 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 110.060071429 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.1365903503 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 42.6210994295 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 58.1134566521 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.9656154535 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 31.3771782711 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 53.0974270408 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.8850779069 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 52.566940814 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 36.2900187761 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.1988558071 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.1683616588 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.0995681831 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.6628834674 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.866736008 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.8630344453 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 10.9388663563 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.1189173458 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.7034211142 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.6507020637 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 52.3992963779 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 41.7703550278 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 17.5405278374 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.853438126 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 99.8048157631 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 34.0045054451 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 31.3394927039 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.3802612665 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.1205347403 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.3242471869 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 100.487877018 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.3438579872 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 13.9594088376 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.0582590302 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.7795952063 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.3422674139 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.6241496489 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 50.8320726315 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.9926209699 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.4888056341 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.8613971415 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.2321100165 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 16.1278294938 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.1382102213 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.7670302839 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.6075942487 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.9243495769 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.3041664346 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 19.7229070824 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 31.969545371 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.6276434424 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.8939932146 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.1378326996 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.4821905322 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 16.2294495865 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.4053516371 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 68.4682545232 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 16.0539516211 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 21.3643839739 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.0931299078 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.6786054561 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.6193915244 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.4266250735 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.9044749945 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 18.334848464 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 13.3280556369 0
% INFO    : Updated Generator Cost: SYNC - 0.0 1.0 0.0 -> 0 0.0 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.4496009795 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 9.95563678461 0
% INFO    : 
% INFO    : === Generator Bounds Update Notes ===
% INFO    : 
% INFO    : === Base KV Replacement Notes ===
% INFO    : 
% INFO    : === Transformer Setting Replacement Notes ===
% WARNING : Branch 11825-2422 connects two different voltage levels (154.0, 6.3), changing tap ratio 0.0 => 1.0
% WARNING : Branch 11825-7731 connects two different voltage levels (154.0, 6.3), changing tap ratio 0.0 => 1.0
% WARNING : Branch 11825-1599 connects two different voltage levels (154.0, 6.3), changing tap ratio 0.0 => 1.0
% WARNING : Branch 11825-9830 connects two different voltage levels (154.0, 6.3), changing tap ratio 0.0 => 1.0
% WARNING : Branch 11825-7962 connects two different voltage levels (154.0, 6.3), changing tap ratio 0.0 => 1.0
% WARNING : Branch 11825-11903 connects two different voltage levels (154.0, 6.3), changing tap ratio 0.0 => 1.0
% WARNING : Branch 11825-12507 connects two different voltage levels (154.0, 0.4), changing tap ratio 0.0 => 1.0
% WARNING : Branch 11825-3894 connects two different voltage levels (154.0, 6.3), changing tap ratio 0.0 => 1.0
% WARNING : Branch 11825-8359 connects two different voltage levels (154.0, 6.3), changing tap ratio 0.0 => 1.0
% WARNING : Branch 11825-5658 connects two different voltage levels (154.0, 6.3), changing tap ratio 0.0 => 1.0
% WARNING : Branch 11825-423 connects two different voltage levels (154.0, 6.3), changing tap ratio 0.0 => 1.0
% WARNING : Branch 11825-2192 connects two different voltage levels (154.0, 6.3), changing tap ratio 0.0 => 1.0
% WARNING : Branch 11825-4611 connects two different voltage levels (154.0, 6.3), changing tap ratio 0.0 => 1.0
% WARNING : Branch 11825-2526 connects two different voltage levels (154.0, 0.4), changing tap ratio 0.0 => 1.0
% WARNING : Branch 9103-4746 connects two different voltage levels (154.0, 6.3), changing tap ratio 0.0 => 1.0
% WARNING : Branch 9103-10613 connects two different voltage levels (154.0, 0.4), changing tap ratio 0.0 => 1.0
% WARNING : Branch 214-1048 connects two different voltage levels (154.0, 11.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 214-5254 connects two different voltage levels (154.0, 11.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 214-8246 connects two different voltage levels (154.0, 11.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 214-3360 connects two different voltage levels (154.0, 11.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 214-6347 connects two different voltage levels (154.0, 11.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 214-11781 connects two different voltage levels (154.0, 11.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 214-3348 connects two different voltage levels (154.0, 11.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 214-13510 connects two different voltage levels (154.0, 11.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 214-9797 connects two different voltage levels (154.0, 11.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 214-5210 connects two different voltage levels (154.0, 11.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 214-9728 connects two different voltage levels (154.0, 11.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 214-635 connects two different voltage levels (154.0, 11.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 214-12541 connects two different voltage levels (154.0, 11.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 214-11393 connects two different voltage levels (154.0, 11.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 214-9056 connects two different voltage levels (154.0, 6.3), changing tap ratio 0.0 => 1.0
% WARNING : Branch 214-4009 connects two different voltage levels (154.0, 11.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 214-12221 connects two different voltage levels (154.0, 11.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 214-392 connects two different voltage levels (154.0, 6.3), changing tap ratio 0.0 => 1.0
% WARNING : Branch 214-9421 connects two different voltage levels (154.0, 6.3), changing tap ratio 0.0 => 1.0
% WARNING : Branch 214-10829 connects two different voltage levels (154.0, 6.3), changing tap ratio 0.0 => 1.0
% WARNING : Branch 214-1088 connects two different voltage levels (154.0, 11.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 214-8764 connects two different voltage levels (154.0, 11.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 214-5333 connects two different voltage levels (154.0, 11.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 214-9997 connects two different voltage levels (154.0, 11.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2042-10452 connects two different voltage levels (154.0, 11.5), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2042-5116 connects two different voltage levels (154.0, 11.5), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2042-12383 connects two different voltage levels (154.0, 11.5), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2042-7114 connects two different voltage levels (154.0, 11.5), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2042-10891 connects two different voltage levels (154.0, 11.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2042-8033 connects two different voltage levels (154.0, 11.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2042-2712 connects two different voltage levels (154.0, 11.5), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7827-5316 connects two different voltage levels (154.0, 6.3), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7119-332 connects two different voltage levels (154.0, 6.3), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7119-1421 connects two different voltage levels (154.0, 6.3), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7119-6717 connects two different voltage levels (154.0, 6.3), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4116-6272 connects two different voltage levels (400.0, 11.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4116-11672 connects two different voltage levels (400.0, 11.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 10180-111 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 10180-111 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3549-10458 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3549-10458 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3549-10458 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 11653-10859 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 11653-10859 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 11653-10859 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 414-12283 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 414-12283 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2972-13068 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2972-13068 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8698-6348 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8698-6348 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8720-6779 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8720-6779 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8720-6779 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Transformer 6316-971 has a phase shift of -0.305565, changing tap ratio 0.0 => 1.0
% WARNING : Transformer 6316-2611 has a phase shift of 0.305565, changing tap ratio 0.0 => 1.0
% WARNING : Branch 12721-7418 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3750-5578 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3750-5578 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 11493-4381 connects two different voltage levels (220.0, 150.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2593-1142 connects two different voltage levels (220.0, 150.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 11493-9970 connects two different voltage levels (220.0, 150.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7602-1142 connects two different voltage levels (220.0, 150.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2044-1142 connects two different voltage levels (220.0, 150.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7602-9831 connects two different voltage levels (220.0, 150.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7602-12273 connects two different voltage levels (220.0, 150.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7602-3510 connects two different voltage levels (220.0, 150.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7602-6844 connects two different voltage levels (220.0, 150.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7602-6590 connects two different voltage levels (220.0, 150.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2044-9831 connects two different voltage levels (220.0, 150.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2044-12273 connects two different voltage levels (220.0, 150.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 11493-8395 connects two different voltage levels (220.0, 150.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2044-3510 connects two different voltage levels (220.0, 150.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2044-6844 connects two different voltage levels (220.0, 150.0), changing tap ratio 0.0 => 1.0
% WARNING : Transformer 8510-11012 has a phase shift of -0.428189, changing tap ratio 0.0 => 1.0
% WARNING : Transformer 3049-8729 has a phase shift of 0.304578, changing tap ratio 0.0 => 1.0
% WARNING : Branch 4589-12971 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4589-12971 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1248-2267 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6446-1542 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6446-1542 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 11423-5014 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2035-1873 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2035-1873 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2035-1873 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8749-5414 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8749-5414 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 46-2346 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 9002-6629 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 9002-6629 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8399-9418 connects two different voltage levels (220.0, 150.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8399-9418 connects two different voltage levels (220.0, 150.0), changing tap ratio 0.0 => 1.0
% WARNING : Transformer 6503-565 has a phase shift of 0.432244, changing tap ratio 0.0 => 1.0
% WARNING : Branch 6000-217 connects two different voltage levels (380.0, 150.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6000-217 connects two different voltage levels (380.0, 150.0), changing tap ratio 0.0 => 1.0
% WARNING : Transformer 1788-1140 has a phase shift of 0.024998, changing tap ratio 0.0 => 1.0
% WARNING : Transformer 1788-1140 has a phase shift of 0.024998, changing tap ratio 0.0 => 1.0
% WARNING : Branch 10838-9099 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8035-9099 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 11812-9099 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 12474-9099 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 91-9099 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 10349-9099 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 12274-9099 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1789-9099 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 10838-11009 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8035-11009 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 10349-11009 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1789-11009 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7867-3932 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 9172-3932 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 9153-3773 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 9153-1645 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 9153-4860 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 131-707 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 12474-707 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 11732-707 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3895-707 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 131-9072 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 12474-9072 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 11732-9072 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3895-9072 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 10335-5899 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 10335-1467 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 10335-5005 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 10335-5923 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 10335-1752 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 10335-644 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 10335-2726 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 10335-5344 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 10335-2264 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 10335-4342 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 10335-1684 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 12622-5899 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 272-5899 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4883-5899 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7997-5899 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6414-5899 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 12406-5899 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8314-5899 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 9085-5899 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 376-7699 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6032-7699 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3603-7699 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2174-7699 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7131-7699 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 13017-7699 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6550-7699 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 964-7699 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 13282-7699 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 12961-12536 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3288-260 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2382-260 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5152-260 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 131-11302 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 10838-11302 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8035-11302 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 11812-11302 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 12474-11302 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 91-11302 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 11732-11302 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 12274-11302 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3895-11302 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 12622-1467 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 12622-5005 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 12622-5923 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 12622-1752 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 12622-644 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 12622-2726 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 12622-5344 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 12622-2264 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 12622-4342 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 12622-1684 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 9636-7765 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 13354-7765 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 9506-7765 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1172-7765 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5569-7765 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8176-7765 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6825-7765 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 10957-7765 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 9636-9820 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 9636-7733 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 9636-3193 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 9636-6386 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 13354-9820 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 13354-7733 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 13354-3193 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 13354-6386 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 9506-9820 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1172-9820 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5569-9820 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8176-9820 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6825-9820 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 10957-9820 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Transformer 622-7915 has a phase shift of 0.41413, changing tap ratio 0.0 => 1.0
% WARNING : Transformer 9506-3170 has a phase shift of 0.41413, changing tap ratio 0.0 => 1.0
% WARNING : Branch 9506-7733 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 9506-3193 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 9506-6386 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2872-13213 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7278-13213 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2872-10921 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7278-10921 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6362-3932 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 13454-3746 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 13454-12363 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 13454-5547 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 131-13629 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 131-8267 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 131-4147 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 131-11448 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 131-2359 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 131-366 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 131-1535 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 131-5183 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 131-7014 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 131-12720 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 131-9401 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 131-2256 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 131-1566 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 131-5754 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1172-7733 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5569-7733 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8176-7733 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6825-7733 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 10957-7733 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1172-3193 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5569-3193 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8176-3193 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6825-3193 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 10957-3193 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 10838-13629 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 10838-8267 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 10838-4147 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 10838-11448 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 10838-2359 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 10838-366 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 10838-9823 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 10838-6896 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 10838-10979 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 10838-1535 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 10838-5183 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 10838-7014 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 10838-12720 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 10838-7916 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 10838-3743 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 10838-9401 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 10838-4717 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 10838-2256 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8035-13629 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8035-8267 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8035-4147 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8035-11448 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8035-2359 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8035-366 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8035-9823 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8035-6896 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8035-10979 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8035-1535 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8035-5183 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8035-7014 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8035-12720 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8035-7916 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8035-3743 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8035-9401 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8035-4717 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8035-2256 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8653-3932 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 272-1467 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 272-5005 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 272-5923 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 272-1752 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 272-644 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 272-2726 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 272-5344 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 272-2264 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 272-4342 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 272-1684 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4883-1467 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4883-5005 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4883-5923 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4883-1752 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4883-644 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4883-2726 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4883-5344 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4883-2264 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4883-4342 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4883-1684 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7997-1467 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6414-1467 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 12406-1467 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8314-1467 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 9085-1467 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7997-5005 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6414-5005 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 12406-5005 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8314-5005 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 9085-5005 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3464-1758 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2872-1758 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7278-1758 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1172-6386 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2872-9140 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2872-141 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7278-9140 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7278-141 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3288-4180 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2382-4180 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5152-4180 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7454-3986 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7454-12363 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2586-3986 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2586-12363 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7997-5923 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6414-5923 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 12406-5923 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8314-5923 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 9085-5923 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7997-1752 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6414-1752 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 12406-1752 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8314-1752 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 9085-1752 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7997-644 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7997-2726 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7997-5344 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7997-2264 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7997-4342 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7997-1684 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5569-6386 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8176-6386 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 11812-13629 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 12474-13629 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 11732-13629 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 10349-13629 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 12274-13629 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1789-13629 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 11812-8267 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 12474-8267 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 11732-8267 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 10349-8267 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 12274-8267 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1789-8267 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 11812-4147 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 12474-4147 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 11732-4147 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 10349-4147 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 12274-4147 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1789-4147 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6414-644 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 12406-644 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8314-644 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 9085-644 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6414-2726 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 12406-2726 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8314-2726 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 9085-2726 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 10367-4860 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 10367-8960 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 10367-1779 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 10367-6012 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 9178-4860 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 9178-8960 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 9178-1779 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 9178-6012 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6414-5344 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 12406-5344 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8314-5344 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 9085-5344 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 11812-11448 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 11812-2359 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 11812-366 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 11812-917 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 11812-4995 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 11812-1535 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 11812-5183 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 11812-7014 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 11812-12720 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 11812-7916 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 11812-3743 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 11812-9401 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 11812-2256 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 11812-7691 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 11812-6065 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 12474-11448 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 12474-2359 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 12474-366 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 12474-1535 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 12474-5183 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 12474-7014 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 12474-12720 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 12474-7916 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 12474-3743 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 12474-9401 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 12474-2256 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 12474-1566 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 12474-5754 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 12474-7691 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 12474-6065 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6414-2264 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6414-4342 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6414-1684 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 12406-2264 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8314-2264 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 9085-2264 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 722-4860 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 722-8960 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 722-1779 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 722-6012 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 12406-4342 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8314-4342 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 9085-4342 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 12406-1684 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8314-1684 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 9085-1684 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 478-4860 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8529-4860 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5951-4860 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 478-8960 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8529-8960 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5951-8960 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 91-11448 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 11732-11448 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 10349-11448 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 12274-11448 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3895-11448 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1789-11448 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 91-2359 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 11732-2359 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 10349-2359 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 12274-2359 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3895-2359 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1789-2359 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 478-3932 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 478-1779 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 478-6012 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 10349-8608 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1789-8608 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 10349-4055 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1789-4055 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 91-366 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 91-1535 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 91-5183 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 91-7014 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 91-12720 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 91-7916 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 91-3743 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 91-9401 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 91-2256 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 91-1566 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 91-5754 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 11732-366 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 12274-366 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3895-366 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1789-366 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 10349-8156 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 10349-6030 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6825-6386 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 12274-917 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 12274-4995 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 11732-1535 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 11732-5183 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 11732-7014 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 11732-12720 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 11732-7916 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 11732-3743 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 11732-9401 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 11732-2256 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 11732-1566 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 11732-5754 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 10349-12043 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1789-12043 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 10349-9823 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1789-9823 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 10349-6896 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 10349-10979 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 10349-5183 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 10349-7916 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 10349-3743 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 10349-4717 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 10349-2256 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 10349-7691 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 10349-6065 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1789-6896 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1789-10979 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 12274-1535 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 12274-5183 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 12274-7014 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 12274-12720 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 12274-7916 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 12274-3743 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 12274-9401 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 12274-2256 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 12274-7691 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 12274-6065 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3895-1535 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1789-1535 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3895-5183 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1789-5183 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3895-7014 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3895-12720 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3895-7916 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3895-3743 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3895-9401 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3895-2256 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3895-1566 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3895-5754 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1789-7014 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1789-12720 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1789-7916 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1789-3743 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1789-4717 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1789-2256 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1789-7691 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1789-6065 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8529-1779 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5951-1779 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8529-6012 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5951-6012 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 10957-6386 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3043-5297 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2376-4127 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2354-4127 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7451-4127 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2265-4127 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 12109-4127 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2376-9057 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 9661-11453 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 10358-80 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3462-7437 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3462-7437 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2376-587 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2376-7275 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2376-1611 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6804-2393 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6804-5190 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 10358-2314 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 10358-12360 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 10358-13555 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5633-3742 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1025-3742 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3417-3742 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 9661-6301 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 9661-3085 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2354-3879 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2354-8543 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4172-2393 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 11636-3742 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2948-3742 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 10879-3742 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 9048-3742 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7451-3879 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7451-8543 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2265-3879 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2265-8543 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6796-8189 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3026-8189 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4172-8189 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 9156-8189 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4172-5190 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 9661-3817 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 9661-7035 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 9661-11123 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 9156-584 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 12109-3879 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 12109-8543 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 12918-7095 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5993-7095 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 10087-7095 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8361-7095 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 9091-4168 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5557-9394 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3447-9394 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3260-9394 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6117-10372 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8691-10372 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2728-10372 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4506-11358 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 13547-11358 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1649-3636 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 10400-3636 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1983-11136 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1983-7018 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 12051-11136 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 12051-7018 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4556-4168 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1723-4168 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1771-4168 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7818-4168 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7012-4168 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8784-4168 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 10047-4168 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7835-6099 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 10846-7216 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5557-228 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3447-228 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3260-228 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5557-6735 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8870-6735 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3447-6735 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3260-6735 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4570-6735 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4506-10015 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4506-10225 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 12918-7494 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5993-7494 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1649-7018 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1649-13016 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1649-2365 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 10904-6104 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8870-6104 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 10904-12768 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 10904-9268 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 10904-5095 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 10904-7630 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 10904-12875 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 10904-5550 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 10904-5687 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 10904-11156 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4685-10914 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 9641-10914 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1149-10914 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6597-10914 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 10087-7494 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8361-7494 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3566-3503 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6522-462 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3081-462 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2602-462 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5257-462 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 10026-462 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 13547-239 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8870-12768 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8870-1246 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4570-1246 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1872-6099 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5394-6099 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 9641-9245 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1149-9245 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6597-9245 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1723-8592 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6522-8592 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3081-8592 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2602-8592 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5257-8592 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 10026-8592 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8870-10093 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4570-10093 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6522-8936 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3081-8936 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2602-8936 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5257-8936 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 10026-8936 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6522-7527 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6522-11961 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6522-3731 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6522-12457 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3081-7527 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2602-7527 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5257-7527 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 10026-7527 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3081-11961 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3081-3731 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3081-12457 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1179-9396 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8361-9396 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 10846-9396 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6598-8996 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 13441-8996 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 12362-8996 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1820-3742 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1820-185 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 10196-12543 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6598-4735 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 13441-4735 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 12362-4735 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6598-444 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 13441-444 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 12362-444 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 12850-11860 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2525-11860 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 909-11860 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2114-11860 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6916-11860 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1149-10055 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1149-10493 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 10196-2779 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 854-8044 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 854-3171 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 13539-6637 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 11674-6637 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 13539-2431 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 11674-2431 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2602-11961 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2602-3731 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2602-12457 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5257-11961 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 10026-11961 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5257-3731 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 10026-3731 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 10846-793 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 12850-8677 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 12850-9658 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 12850-1626 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2525-8677 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2525-9658 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2525-1626 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5784-8044 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5784-10203 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3229-8044 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3229-3171 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6598-6259 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 13441-6259 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 12362-6259 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5257-12457 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4685-4749 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 13539-996 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 13539-10794 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 13539-6683 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 490-8044 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 680-8044 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 148-8044 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 9278-8044 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 909-8677 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 909-9658 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 909-1626 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2114-8677 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6916-8677 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 10196-6981 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 10026-12457 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8870-9268 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4685-9268 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 118-10055 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 118-10493 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8870-3748 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4570-3748 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8870-5095 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8616-8260 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6117-12560 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6117-11208 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8691-12560 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8691-11208 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2114-9658 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6916-9658 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2114-1626 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2728-12560 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2728-11208 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8870-7630 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8870-12875 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8870-5550 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8870-5687 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8870-11156 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8616-3171 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 10400-7018 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 11674-996 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 10846-996 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 10846-5661 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 10400-13016 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6597-10055 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6597-10493 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 13547-12769 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 13547-8118 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 490-10203 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 680-10203 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 11674-10794 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 11674-6683 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 10400-2365 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6916-1626 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 148-3171 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 9278-3171 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 12987-12396 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 12987-9924 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2716-13230 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2716-4092 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2716-645 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2716-712 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 748-13230 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2684-13230 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 795-12063 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 10162-12063 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7574-9680 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7574-6056 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 9460-9680 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 9460-6056 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 12151-12396 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 12151-9924 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3115-11366 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6458-3921 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 9450-4092 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 748-4092 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 748-645 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 748-712 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6457-4092 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2684-4092 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2684-645 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6458-5521 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6973-277 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2684-712 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8715-11366 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6973-11046 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 795-11046 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 10162-11046 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6458-4615 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5273-313 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 284-313 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3291-12396 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3291-9924 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 739-12396 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 739-9924 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2509-10997 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Transformer 806-7319 has a phase shift of 0.19252, changing tap ratio 0.0 => 1.0
% WARNING : Transformer 4435-8929 has a phase shift of 0.108521, changing tap ratio 0.0 => 1.0
% WARNING : Transformer 10630-6586 has a phase shift of -0.036236, changing tap ratio 0.0 => 1.0
% WARNING : Transformer 13583-82 has a phase shift of -0.086984, changing tap ratio 0.0 => 1.0
% WARNING : Transformer 1086-3185 has a phase shift of -0.146705, changing tap ratio 0.0 => 1.0
% WARNING : Transformer 10933-5386 has a phase shift of 0.085905, changing tap ratio 0.0 => 1.0
% WARNING : Branch 12345-60 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 11008-3901 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2040-9145 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6805-9145 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 9356-5651 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4318-6737 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4318-6716 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 13169-1379 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5421-1379 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8011-1379 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 11162-5015 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5572-933 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 317-933 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7104-933 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6805-10689 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5421-10689 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8011-10689 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2040-3601 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5572-1363 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5572-611 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 374-12450 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 12364-12450 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1597-12450 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6653-4669 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 530-11541 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8923-6644 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1405-6644 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6246-12361 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6246-8216 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 12187-12361 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3952-12361 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 3952-8216 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1597-488 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 317-4669 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7104-4669 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7601-6887 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7601-5153 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 11162-12209 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 13061-13263 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 13061-4463 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 11162-3967 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4911-4104 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4911-7423 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 12364-8031 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2040-2121 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2040-7741 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 374-10265 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 11162-9811 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 13061-9811 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 10360-10265 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1597-10265 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 11162-4972 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 13061-4972 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1597-843 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 13061-8020 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5525-7483 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 733-7483 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5525-561 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 733-3208 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 12852-3208 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 733-2802 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 12852-2802 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 733-2754 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 12852-2754 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 733-561 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 733-7843 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1405-11590 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1405-13563 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 12852-561 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 12852-5555 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 12852-7843 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 9356-7690 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 12364-4850 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4243-3694 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4911-10131 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4318-12597 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1597-10697 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1597-399 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1597-9019 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4243-5555 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 11162-4325 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 11162-5867 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 13061-8240 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8472-3667 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8472-5950 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7104-246 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7104-9654 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 9356-5867 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7104-5298 connects two different voltage levels (380.0, 220.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 8480-1022 connects two different voltage levels (220.0, 150.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6514-219 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 6514-8607 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4227-504 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4227-504 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4227-504 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 4491-12490 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7786-4358 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 12298-12644 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 12298-12644 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 967-11127 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 967-11127 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 10005-11663 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 10005-11663 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7125-11014 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 9828-7611 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 11733-9765 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 11733-9765 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 13546-2444 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 13546-2444 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5434-8201 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5434-8201 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 11413-7033 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 11413-7033 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2505-5079 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2505-5079 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7184-868 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 7184-67 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 11007-1568 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 11007-1568 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5511-11269 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5511-11269 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5511-11269 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 5511-11269 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1011-2798 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 1011-2532 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2095-7010 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Branch 2095-7010 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% WARNING : Transformer 10322-13504 has a phase shift of 0.199334, changing tap ratio 0.0 => 1.0
% WARNING : Branch 5799-1351 connects two different voltage levels (220.0, 110.0), changing tap ratio 0.0 => 1.0
% INFO    : 
% INFO    : === Line Capacity UB Model Notes ===
% INFO    : Updated Thermal Rating: on line 7519-4482 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5104
% INFO    : Updated Thermal Rating: on line 7519-11823 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4259
% INFO    : Updated Thermal Rating: on line 3073-4516 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4974
% INFO    : Updated Thermal Rating: on line 3073-4706 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5678
% INFO    : Updated Thermal Rating: on line 5157-1032 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2013
% INFO    : Updated Thermal Rating: on line 5157-6653 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1860
% INFO    : Updated Thermal Rating: on line 628-7896 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 55004
% INFO    : Updated Thermal Rating: on line 628-6592 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 56085
% INFO    : Updated Thermal Rating: on line 11792-10888 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1870
% INFO    : Updated Thermal Rating: on line 11792-4609 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1907
% INFO    : Updated Thermal Rating: on line 6573-10888 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1946
% INFO    : Updated Thermal Rating: on line 6573-4609 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1733
% INFO    : Updated Thermal Rating: on line 782-13300 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1711
% INFO    : Updated Thermal Rating: on line 782-1186 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1707
% INFO    : Updated Thermal Rating: on line 11715-924 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1743
% INFO    : Updated Thermal Rating: on line 11715-12182 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1785
% INFO    : Updated Thermal Rating: on line 10257-2582 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2891
% INFO    : Updated Thermal Rating: on line 10257-9363 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3851
% INFO    : Updated Thermal Rating: on line 7595-11501 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2198
% INFO    : Updated Thermal Rating: on line 7595-11390 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1968
% INFO    : Updated Thermal Rating: on line 6873-1806 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12367
% INFO    : Updated Thermal Rating: on line 6873-11151 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12131
% INFO    : Updated Thermal Rating: on line 11949-1806 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10398
% INFO    : Updated Thermal Rating: on line 11949-1269 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10081
% INFO    : Updated Thermal Rating: on line 2623-3359 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22560
% INFO    : Updated Thermal Rating: on line 2623-11159 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11969
% INFO    : Updated Thermal Rating: on line 3020-3359 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23027
% INFO    : Updated Thermal Rating: on line 3020-12995 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12243
% INFO    : Updated Thermal Rating: on line 9670-3359 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4551
% INFO    : Updated Thermal Rating: on line 9670-2360 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5317
% INFO    : Updated Thermal Rating: on line 8390-3359 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26146
% INFO    : Updated Thermal Rating: on line 8390-11515 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20335
% INFO    : Updated Thermal Rating: on line 12630-3359 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6424
% INFO    : Updated Thermal Rating: on line 12630-11515 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20703
% INFO    : Updated Thermal Rating: on line 3340-3359 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6872
% INFO    : Updated Thermal Rating: on line 3340-3953 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6500
% INFO    : Updated Thermal Rating: on line 7444-8848 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7699
% INFO    : Updated Thermal Rating: on line 7444-5026 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6278
% INFO    : Updated Thermal Rating: on line 11055-8848 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4506
% INFO    : Updated Thermal Rating: on line 11055-13067 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3909
% INFO    : Updated Thermal Rating: on line 9857-13125 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6746
% INFO    : Updated Thermal Rating: on line 9857-12598 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6153
% INFO    : Updated Thermal Rating: on line 7256-7011 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10073
% INFO    : Updated Thermal Rating: on line 7256-11232 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10284
% INFO    : Updated Thermal Rating: on line 12732-9895 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5953
% INFO    : Updated Thermal Rating: on line 12732-4416 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5927
% INFO    : Updated Thermal Rating: on line 4494-7011 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3890
% INFO    : Updated Thermal Rating: on line 4494-10481 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3600
% INFO    : Updated Thermal Rating: on line 7913-9895 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5777
% INFO    : Updated Thermal Rating: on line 7913-1269 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6597
% INFO    : Updated Thermal Rating: on line 3258-10043 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 799
% INFO    : Updated Thermal Rating: on line 3258-8238 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 249
% INFO    : Updated Thermal Rating: on line 697-10043 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 410
% INFO    : Updated Thermal Rating: on line 697-11841 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 248
% INFO    : Updated Thermal Rating: on line 11629-10942 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 28833
% INFO    : Updated Thermal Rating: on line 11629-13171 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 29367
% INFO    : Updated Thermal Rating: on line 9089-11260 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7943
% INFO    : Updated Thermal Rating: on line 9089-7609 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8235
% INFO    : Updated Thermal Rating: on line 13119-3581 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2423
% INFO    : Updated Thermal Rating: on line 13119-6381 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1799
% INFO    : Updated Thermal Rating: on line 5075-13106 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1617
% INFO    : Updated Thermal Rating: on line 5075-9503 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 774
% INFO    : Updated Thermal Rating: on line 11048-10312 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1485
% INFO    : Updated Thermal Rating: on line 11048-3185 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1570
% INFO    : Updated Thermal Rating: on line 1538-4109 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 608
% INFO    : Updated Thermal Rating: on line 1538-3721 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 619
% INFO    : Updated Thermal Rating: on line 5803-4109 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 632
% INFO    : Updated Thermal Rating: on line 5803-3721 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 644
% INFO    : Updated Thermal Rating: on line 189-4268 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4401
% INFO    : Updated Thermal Rating: on line 189-11488 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4403
% INFO    : Updated Thermal Rating: on line 7384-1009 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5671
% INFO    : Updated Thermal Rating: on line 7384-11547 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5562
% INFO    : Updated Thermal Rating: on line 11070-1009 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6006
% INFO    : Updated Thermal Rating: on line 11070-11547 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6115
% INFO    : Updated Thermal Rating: on line 2061-6603 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2736
% INFO    : Updated Thermal Rating: on line 2061-9733 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 451
% INFO    : Updated Thermal Rating: on line 9502-7241 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10550
% INFO    : Updated Thermal Rating: on line 9502-8865 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10798
% INFO    : Updated Thermal Rating: on line 12336-13321 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2469
% INFO    : Updated Thermal Rating: on line 12336-494 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2462
% INFO    : Updated Thermal Rating: on line 13540-11971 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 32406
% INFO    : Updated Thermal Rating: on line 13540-330 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 32924
% INFO    : Updated Thermal Rating: on line 8250-622 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17103
% INFO    : Updated Thermal Rating: on line 8250-8646 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10974
% INFO    : Updated Thermal Rating: on line 5656-9506 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16838
% INFO    : Updated Thermal Rating: on line 5656-7003 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11835
% INFO    : Updated Thermal Rating: on line 8767-13151 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2154
% INFO    : Updated Thermal Rating: on line 8767-256 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1300
% INFO    : Updated Thermal Rating: on line 11952-7565 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3079
% INFO    : Updated Thermal Rating: on line 11952-8750 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3138
% INFO    : Updated Thermal Rating: on line 13220-7565 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3205
% INFO    : Updated Thermal Rating: on line 13220-8750 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3270
% INFO    : Updated Thermal Rating: on line 10465-10831 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1410
% INFO    : Updated Thermal Rating: on line 8079-10358 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12075
% INFO    : Updated Thermal Rating: on line 8079-8404 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10398
% INFO    : Updated Thermal Rating: on line 7197-5524 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5063
% INFO    : Updated Thermal Rating: on line 7197-11931 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4739
% INFO    : Updated Thermal Rating: on line 1721-12153 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2929
% INFO    : Updated Thermal Rating: on line 1721-10744 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2071
% INFO    : Updated Thermal Rating: on line 8400-850 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9198
% INFO    : Updated Thermal Rating: on line 8400-8575 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1597
% INFO    : Updated Thermal Rating: on line 9020-2201 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7076
% INFO    : Updated Thermal Rating: on line 9020-2350 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12606
% INFO    : Updated Thermal Rating: on line 6435-2201 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7221
% INFO    : Updated Thermal Rating: on line 6435-3448 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12360
% INFO    : Updated Thermal Rating: on line 3223-4642 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3761
% INFO    : Updated Thermal Rating: on line 3223-9919 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1923
% INFO    : Updated Thermal Rating: on line 7755-4642 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3692
% INFO    : Updated Thermal Rating: on line 7755-9919 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1888
% INFO    : Updated Thermal Rating: on line 4129-4642 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3014
% INFO    : Updated Thermal Rating: on line 4129-3715 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3618
% INFO    : Updated Thermal Rating: on line 5471-7106 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1495
% INFO    : Updated Thermal Rating: on line 5471-5434 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 767
% INFO    : Updated Thermal Rating: on line 8834-12770 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6133
% INFO    : Updated Thermal Rating: on line 8834-10744 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8694
% INFO    : Updated Thermal Rating: on line 7831-1467 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2308
% INFO    : Updated Thermal Rating: on line 7831-5173 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1587
% INFO    : Updated Thermal Rating: on line 10033-5005 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2193
% INFO    : Updated Thermal Rating: on line 10033-7387 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1324
% INFO    : Updated Thermal Rating: on line 9789-9848 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3952
% INFO    : Updated Thermal Rating: on line 9789-430 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3581
% INFO    : Updated Thermal Rating: on line 2916-1094 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1511
% INFO    : Updated Thermal Rating: on line 2916-2869 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1646
% INFO    : Updated Thermal Rating: on line 4142-3925 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2082
% INFO    : Updated Thermal Rating: on line 4142-2245 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1269
% INFO    : Updated Thermal Rating: on line 123-12854 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17442
% INFO    : Updated Thermal Rating: on line 123-12369 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12048
% INFO    : Updated Thermal Rating: on line 10806-12854 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17833
% INFO    : Updated Thermal Rating: on line 10806-1112 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12329
% INFO    : Updated Thermal Rating: on line 12593-9027 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 645
% INFO    : Updated Thermal Rating: on line 12593-455 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1067
% INFO    : Updated Thermal Rating: on line 3745-10922 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7342
% INFO    : Updated Thermal Rating: on line 3745-1898 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6631
% INFO    : Updated Thermal Rating: on line 6938-7640 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5881
% INFO    : Updated Thermal Rating: on line 6938-4543 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5341
% INFO    : Updated Thermal Rating: on line 4229-2024 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1528
% INFO    : Updated Thermal Rating: on line 4229-9388 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3609
% INFO    : Updated Thermal Rating: on line 5543-13575 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1604
% INFO    : Updated Thermal Rating: on line 5543-9388 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3545
% INFO    : Updated Thermal Rating: on line 2764-10638 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20667
% INFO    : Updated Thermal Rating: on line 2764-10338 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19249
% INFO    : Updated Thermal Rating: on line 7963-10638 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19656
% INFO    : Updated Thermal Rating: on line 7963-10338 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17204
% INFO    : Updated Thermal Rating: on line 5383-4802 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2208
% INFO    : Updated Thermal Rating: on line 5383-8035 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2163
% INFO    : Updated Thermal Rating: on line 663-204 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4327
% INFO    : Updated Thermal Rating: on line 663-6973 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4285
% INFO    : Updated Thermal Rating: on line 11598-204 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4412
% INFO    : Updated Thermal Rating: on line 11598-6973 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4367
% INFO    : Updated Thermal Rating: on line 2983-2257 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14299
% INFO    : Updated Thermal Rating: on line 2983-10869 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14299
% INFO    : Updated Thermal Rating: on line 411-4997 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14626
% INFO    : Updated Thermal Rating: on line 411-10869 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14626
% INFO    : Updated Thermal Rating: on line 8649-12423 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5342
% INFO    : Updated Thermal Rating: on line 8649-1165 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4669
% INFO    : Updated Thermal Rating: on line 13485-12423 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5451
% INFO    : Updated Thermal Rating: on line 13485-1165 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5041
% INFO    : Updated Thermal Rating: on line 2363-2209 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1360
% INFO    : Updated Thermal Rating: on line 2363-11249 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2464
% INFO    : Updated Thermal Rating: on line 3314-10019 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1279
% INFO    : Updated Thermal Rating: on line 3314-879 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1583
% INFO    : Updated Thermal Rating: on line 12347-10227 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11656
% INFO    : Updated Thermal Rating: on line 12347-2517 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1977
% INFO    : Updated Thermal Rating: on line 1326-10227 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11912
% INFO    : Updated Thermal Rating: on line 1326-2517 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2018
% INFO    : Updated Thermal Rating: on line 9864-13169 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2518
% INFO    : Updated Thermal Rating: on line 9864-5959 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3048
% INFO    : Updated Thermal Rating: on line 4830-13169 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2471
% INFO    : Updated Thermal Rating: on line 4830-5959 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3113
% INFO    : Updated Thermal Rating: on line 12318-6464 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2298
% INFO    : Updated Thermal Rating: on line 12318-7516 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2755
% INFO    : Updated Thermal Rating: on line 11537-8566 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2256
% INFO    : Updated Thermal Rating: on line 11537-7516 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2816
% INFO    : Updated Thermal Rating: on line 13343-12066 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 116559
% INFO    : Updated Thermal Rating: on line 3313-12066 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 116559
% INFO    : Updated Thermal Rating: on line 1196-218 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 856
% INFO    : Updated Thermal Rating: on line 1196-3002 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 294
% INFO    : Updated Thermal Rating: on line 780-8041 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4672
% INFO    : Updated Thermal Rating: on line 780-6114 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4777
% INFO    : Updated Thermal Rating: on line 5179-3568 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5180
% INFO    : Updated Thermal Rating: on line 5179-3085 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5280
% INFO    : Updated Thermal Rating: on line 1666-7897 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4745
% INFO    : Updated Thermal Rating: on line 1666-6301 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4657
% INFO    : Updated Thermal Rating: on line 12861-4782 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 40746
% INFO    : Updated Thermal Rating: on line 12861-6207 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 40230
% INFO    : Updated Thermal Rating: on line 7212-4782 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 38340
% INFO    : Updated Thermal Rating: on line 7212-11151 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 41334
% INFO    : Updated Thermal Rating: on line 9869-8041 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 42374
% INFO    : Updated Thermal Rating: on line 9869-6207 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 42946
% INFO    : Updated Thermal Rating: on line 6015-3568 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8245
% INFO    : Updated Thermal Rating: on line 6015-1131 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8896
% INFO    : Updated Thermal Rating: on line 10035-7897 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11227
% INFO    : Updated Thermal Rating: on line 10035-1910 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11454
% INFO    : Updated Thermal Rating: on line 9951-1939 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4597
% INFO    : Updated Thermal Rating: on line 9951-557 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4921
% INFO    : Updated Thermal Rating: on line 8771-8041 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6021
% INFO    : Updated Thermal Rating: on line 8771-12272 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5207
% INFO    : Updated Thermal Rating: on line 8284-4782 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13736
% INFO    : Updated Thermal Rating: on line 8284-13171 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11908
% INFO    : Updated Thermal Rating: on line 4891-7738 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 876
% INFO    : Updated Thermal Rating: on line 4891-9177 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 878
% INFO    : Updated Thermal Rating: on line 7982-7738 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 933
% INFO    : Updated Thermal Rating: on line 7982-2109 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 869
% INFO    : Updated Thermal Rating: on line 10181-2611 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 10181-11398 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 13331-7738 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 771
% INFO    : Updated Thermal Rating: on line 13331-4629 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 748
% INFO    : Updated Thermal Rating: on line 11042-971 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 675
% INFO    : Updated Thermal Rating: on line 11042-9307 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 706
% INFO    : Updated Thermal Rating: on line 5320-12300 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6495
% INFO    : Updated Thermal Rating: on line 5320-9117 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7573
% INFO    : Updated Thermal Rating: on line 10275-2399 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 45395
% INFO    : Updated Thermal Rating: on line 10275-10873 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 87206
% INFO    : Updated Thermal Rating: on line 11545-3592 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5526
% INFO    : Updated Thermal Rating: on line 11545-10322 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4102
% INFO    : Updated Thermal Rating: on line 8859-13646 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2880
% INFO    : Updated Thermal Rating: on line 4222-12258 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3632
% INFO    : Updated Thermal Rating: on line 1576-13646 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2499
% INFO    : Updated Thermal Rating: on line 1576-1624 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2860
% INFO    : Updated Thermal Rating: on line 5947-9710 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11263
% INFO    : Updated Thermal Rating: on line 5947-10727 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7741
% INFO    : Updated Thermal Rating: on line 3661-11493 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1280
% INFO    : Updated Thermal Rating: on line 3661-11925 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1257
% INFO    : Updated Thermal Rating: on line 5848-5338 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3417
% INFO    : Updated Thermal Rating: on line 5848-13272 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2576
% INFO    : Updated Thermal Rating: on line 8440-4914 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 68669
% INFO    : Updated Thermal Rating: on line 6339-5430 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3060
% INFO    : Updated Thermal Rating: on line 6339-9813 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10250
% INFO    : Updated Thermal Rating: on line 3407-2782 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 912
% INFO    : Updated Thermal Rating: on line 3407-13262 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 844
% INFO    : Updated Thermal Rating: on line 11656-11688 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4343
% INFO    : Updated Thermal Rating: on line 11656-9434 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3770
% INFO    : Updated Thermal Rating: on line 9621-11688 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4450
% INFO    : Updated Thermal Rating: on line 9621-9162 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3922
% INFO    : Updated Thermal Rating: on line 9337-8152 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1046
% INFO    : Updated Thermal Rating: on line 9337-11977 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1056
% INFO    : Updated Thermal Rating: on line 9790-640 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6733
% INFO    : Updated Thermal Rating: on line 9790-4131 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6456
% INFO    : Updated Thermal Rating: on line 7596-13576 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 902
% INFO    : Updated Thermal Rating: on line 7596-11009 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 886
% INFO    : Updated Thermal Rating: on line 4467-8002 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1765
% INFO    : Updated Thermal Rating: on line 4467-4131 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1274
% INFO    : Updated Thermal Rating: on line 386-13576 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2635
% INFO    : Updated Thermal Rating: on line 386-9823 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2350
% INFO    : Updated Thermal Rating: on line 10827-13576 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1944
% INFO    : Updated Thermal Rating: on line 10827-6896 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2097
% INFO    : Updated Thermal Rating: on line 8613-13576 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6782
% INFO    : Updated Thermal Rating: on line 8613-4717 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6672
% INFO    : Updated Thermal Rating: on line 2868-6889 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 105381
% INFO    : Updated Thermal Rating: on line 2868-7065 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 105381
% INFO    : Updated Thermal Rating: on line 2031-372 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1056
% INFO    : Updated Thermal Rating: on line 2031-8334 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 703
% INFO    : Updated Thermal Rating: on line 4223-372 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1381
% INFO    : Updated Thermal Rating: on line 4223-4491 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 920
% INFO    : Updated Thermal Rating: on line 7174-6169 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3048
% INFO    : Updated Thermal Rating: on line 7174-10838 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3541
% INFO    : Updated Thermal Rating: on line 3739-3750 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1202
% INFO    : Updated Thermal Rating: on line 3739-13415 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1119
% INFO    : Updated Thermal Rating: on line 2999-3750 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1692
% INFO    : Updated Thermal Rating: on line 2999-2132 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1739
% INFO    : Updated Thermal Rating: on line 12353-7021 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5360
% INFO    : Updated Thermal Rating: on line 12353-8085 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4727
% INFO    : Updated Thermal Rating: on line 8372-9726 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2216
% INFO    : Updated Thermal Rating: on line 8372-5972 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2079
% INFO    : Updated Thermal Rating: on line 4977-2449 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5127
% INFO    : Updated Thermal Rating: on line 4977-9117 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7737
% INFO    : Updated Thermal Rating: on line 11807-9193 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 678
% INFO    : Updated Thermal Rating: on line 11807-13362 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1893
% INFO    : Updated Thermal Rating: on line 7367-2297 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6369
% INFO    : Updated Thermal Rating: on line 7367-13504 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6488
% INFO    : Updated Thermal Rating: on line 13361-210 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1152
% INFO    : Updated Thermal Rating: on line 13361-8579 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1247
% INFO    : Updated Thermal Rating: on line 8856-11596 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 797
% INFO    : Updated Thermal Rating: on line 8856-10943 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 848
% INFO    : Updated Thermal Rating: on line 12165-8452 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4189
% INFO    : Updated Thermal Rating: on line 12165-10718 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1729
% INFO    : Updated Thermal Rating: on line 991-210 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1367
% INFO    : Updated Thermal Rating: on line 991-8264 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1394
% INFO    : Updated Thermal Rating: on line 10687-7078 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4679
% INFO    : Updated Thermal Rating: on line 10687-1766 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4591
% INFO    : Updated Thermal Rating: on line 13494-6000 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2625
% INFO    : Updated Thermal Rating: on line 13494-9558 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2515
% INFO    : Updated Thermal Rating: on line 3322-4944 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4354
% INFO    : Updated Thermal Rating: on line 3322-6366 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4242
% INFO    : Updated Thermal Rating: on line 6082-13221 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3868
% INFO    : Updated Thermal Rating: on line 6082-11561 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2002
% INFO    : Updated Thermal Rating: on line 12539-2263 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5427
% INFO    : Updated Thermal Rating: on line 12539-3777 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5895
% INFO    : Updated Thermal Rating: on line 12308-11016 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23689
% INFO    : Updated Thermal Rating: on line 12308-9194 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19614
% INFO    : Updated Thermal Rating: on line 10168-3267 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1191
% INFO    : Updated Thermal Rating: on line 10168-10943 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1132
% INFO    : Updated Thermal Rating: on line 460-12666 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2960
% INFO    : Updated Thermal Rating: on line 460-1925 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2904
% INFO    : Updated Thermal Rating: on line 11384-10686 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1982
% INFO    : Updated Thermal Rating: on line 11384-11561 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6487
% INFO    : Updated Thermal Rating: on line 5551-2914 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 794
% INFO    : Updated Thermal Rating: on line 5551-12265 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1578
% INFO    : Updated Thermal Rating: on line 1418-8986 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2166
% INFO    : Updated Thermal Rating: on line 1418-4609 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2336
% INFO    : Updated Thermal Rating: on line 5389-12666 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7357
% INFO    : Updated Thermal Rating: on line 5389-1255 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6358
% INFO    : Updated Thermal Rating: on line 4132-10934 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3133
% INFO    : Updated Thermal Rating: on line 4132-3129 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1629
% INFO    : Updated Thermal Rating: on line 2817-992 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10214
% INFO    : Updated Thermal Rating: on line 2817-8261 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10212
% INFO    : Updated Thermal Rating: on line 7950-6182 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6497
% INFO    : Updated Thermal Rating: on line 7950-9582 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2894
% INFO    : Updated Thermal Rating: on line 8170-2362 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3132
% INFO    : Updated Thermal Rating: on line 8170-8003 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3248
% INFO    : Updated Thermal Rating: on line 11189-10774 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2492
% INFO    : Updated Thermal Rating: on line 11189-8008 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2267
% INFO    : Updated Thermal Rating: on line 9620-2145 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3467
% INFO    : Updated Thermal Rating: on line 9620-12632 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2349
% INFO    : Updated Thermal Rating: on line 12114-3721 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 778
% INFO    : Updated Thermal Rating: on line 12114-6284 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 801
% INFO    : Updated Thermal Rating: on line 3244-10774 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2960
% INFO    : Updated Thermal Rating: on line 3244-3272 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2969
% INFO    : Updated Thermal Rating: on line 6020-494 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2209
% INFO    : Updated Thermal Rating: on line 6020-8891 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4048
% INFO    : Updated Thermal Rating: on line 12682-7713 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 29729
% INFO    : Updated Thermal Rating: on line 11711-7713 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 29329
% INFO    : Updated Thermal Rating: on line 1504-884 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2989
% INFO    : Updated Thermal Rating: on line 1504-5821 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3028
% INFO    : Updated Thermal Rating: on line 3381-12919 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 564
% INFO    : Updated Thermal Rating: on line 3381-879 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1153
% INFO    : Updated Thermal Rating: on line 7853-6824 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2583
% INFO    : Updated Thermal Rating: on line 7853-5972 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2686
% INFO    : Updated Thermal Rating: on line 8048-4231 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 481
% INFO    : Updated Thermal Rating: on line 8048-174 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 517
% INFO    : Updated Thermal Rating: on line 1392-4231 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1109
% INFO    : Updated Thermal Rating: on line 1392-3084 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 648
% INFO    : Updated Thermal Rating: on line 9306-524 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1800
% INFO    : Updated Thermal Rating: on line 9306-11008 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1034
% INFO    : Updated Thermal Rating: on line 12771-10677 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5426
% INFO    : Updated Thermal Rating: on line 12771-11249 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3865
% INFO    : Updated Thermal Rating: on line 6857-524 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6140
% INFO    : Updated Thermal Rating: on line 6857-9037 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17774
% INFO    : Updated Thermal Rating: on line 8995-524 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6245
% INFO    : Updated Thermal Rating: on line 8995-9037 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17398
% INFO    : Updated Thermal Rating: on line 4390-4711 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 494
% INFO    : Updated Thermal Rating: on line 4390-2245 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4874
% INFO    : Updated Thermal Rating: on line 993-10347 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4169
% INFO    : Updated Thermal Rating: on line 993-10709 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6247
% INFO    : Updated Thermal Rating: on line 826-10347 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4089
% INFO    : Updated Thermal Rating: on line 826-10709 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6371
% INFO    : Updated Thermal Rating: on line 3394-4877 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4610
% INFO    : Updated Thermal Rating: on line 3394-12158 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2771
% INFO    : Updated Thermal Rating: on line 9489-4877 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4713
% INFO    : Updated Thermal Rating: on line 9489-12158 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2830
% INFO    : Updated Thermal Rating: on line 9708-13164 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2622
% INFO    : Updated Thermal Rating: on line 9708-4642 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3076
% INFO    : Updated Thermal Rating: on line 9498-13164 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3129
% INFO    : Updated Thermal Rating: on line 9498-3715 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6077
% INFO    : Updated Thermal Rating: on line 12196-10919 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2117
% INFO    : Updated Thermal Rating: on line 12196-5789 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3584
% INFO    : Updated Thermal Rating: on line 535-11908 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2336
% INFO    : Updated Thermal Rating: on line 535-140 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2201
% INFO    : Updated Thermal Rating: on line 7945-1076 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2649
% INFO    : Updated Thermal Rating: on line 7945-12534 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2090
% INFO    : Updated Thermal Rating: on line 9005-892 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 37509
% INFO    : Updated Thermal Rating: on line 9005-1766 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 34262
% INFO    : Updated Thermal Rating: on line 12416-8601 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3026
% INFO    : Updated Thermal Rating: on line 12416-10021 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3403
% INFO    : Updated Thermal Rating: on line 9221-8601 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2973
% INFO    : Updated Thermal Rating: on line 9221-10021 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3475
% INFO    : Updated Thermal Rating: on line 8515-2315 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 116559
% INFO    : Updated Thermal Rating: on line 6403-6614 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4435
% INFO    : Updated Thermal Rating: on line 6403-9117 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4517
% INFO    : Updated Thermal Rating: on line 9514-6056 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4216
% INFO    : Updated Thermal Rating: on line 9514-7101 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4305
% INFO    : Updated Thermal Rating: on line 1452-6056 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3812
% INFO    : Updated Thermal Rating: on line 1452-7101 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3741
% INFO    : Updated Thermal Rating: on line 5682-5452 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1870
% INFO    : Updated Thermal Rating: on line 5682-11733 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 594
% INFO    : Updated Thermal Rating: on line 4825-2456 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5018
% INFO    : Updated Thermal Rating: on line 4825-11561 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3580
% INFO    : Updated Thermal Rating: on line 13359-326 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7480
% INFO    : Updated Thermal Rating: on line 13359-12737 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8706
% INFO    : Updated Thermal Rating: on line 624-11012 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26451
% INFO    : Updated Thermal Rating: on line 624-8261 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24227
% INFO    : Updated Thermal Rating: on line 7026-7780 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26034
% INFO    : Updated Thermal Rating: on line 7026-6366 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23508
% INFO    : Updated Thermal Rating: on line 4755-4357 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2956
% INFO    : Updated Thermal Rating: on line 4755-3462 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3285
% INFO    : Updated Thermal Rating: on line 10662-5711 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1042
% INFO    : Updated Thermal Rating: on line 10662-7437 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1131
% INFO    : Updated Thermal Rating: on line 7214-4357 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4021
% INFO    : Updated Thermal Rating: on line 7214-6268 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4699
% INFO    : Updated Thermal Rating: on line 8164-5711 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1150
% INFO    : Updated Thermal Rating: on line 8164-8677 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1057
% INFO    : Updated Thermal Rating: on line 12629-4357 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3766
% INFO    : Updated Thermal Rating: on line 12629-4831 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3753
% INFO    : Updated Thermal Rating: on line 7840-4357 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3696
% INFO    : Updated Thermal Rating: on line 7840-4831 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4052
% INFO    : Updated Thermal Rating: on line 11317-5711 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3791
% INFO    : Updated Thermal Rating: on line 11317-11518 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3864
% INFO    : Updated Thermal Rating: on line 3240-5711 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3946
% INFO    : Updated Thermal Rating: on line 3240-11518 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3515
% INFO    : Updated Thermal Rating: on line 1135-5711 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14104
% INFO    : Updated Thermal Rating: on line 1135-7516 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14411
% INFO    : Updated Thermal Rating: on line 2781-5711 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14745
% INFO    : Updated Thermal Rating: on line 2781-7516 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13009
% INFO    : Updated Thermal Rating: on line 6505-5711 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12353
% INFO    : Updated Thermal Rating: on line 6505-7516 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12591
% INFO    : Updated Thermal Rating: on line 12092-5711 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 12092-5740 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 2757-11750 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2980
% INFO    : Updated Thermal Rating: on line 2757-10922 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2925
% INFO    : Updated Thermal Rating: on line 5460-404 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 588
% INFO    : Updated Thermal Rating: on line 5460-13262 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 545
% INFO    : Updated Thermal Rating: on line 7572-3427 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6219
% INFO    : Updated Thermal Rating: on line 7572-9194 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19226
% INFO    : Updated Thermal Rating: on line 11268-11750 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3159
% INFO    : Updated Thermal Rating: on line 11268-3389 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1071
% INFO    : Updated Thermal Rating: on line 7272-3049 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6642
% INFO    : Updated Thermal Rating: on line 7272-2493 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6733
% INFO    : Updated Thermal Rating: on line 11286-3049 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5548
% INFO    : Updated Thermal Rating: on line 11286-2409 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4721
% INFO    : Updated Thermal Rating: on line 6560-6485 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 730
% INFO    : Updated Thermal Rating: on line 6560-12261 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 938
% INFO    : Updated Thermal Rating: on line 13149-2024 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1560
% INFO    : Updated Thermal Rating: on line 13149-13575 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1511
% INFO    : Updated Thermal Rating: on line 9609-249 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3976
% INFO    : Updated Thermal Rating: on line 9609-8612 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4036
% INFO    : Updated Thermal Rating: on line 12837-249 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4110
% INFO    : Updated Thermal Rating: on line 12837-8612 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4190
% INFO    : Updated Thermal Rating: on line 11653-10180 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1457
% INFO    : Updated Thermal Rating: on line 11653-10180 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1484
% INFO    : Updated Thermal Rating: on line 111-1302 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 351
% INFO    : Updated Thermal Rating: on line 111-2235 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 779
% INFO    : Updated Thermal Rating: on line 6531-5081 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 809
% INFO    : Updated Thermal Rating: on line 10859-5081 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 222
% INFO    : Updated Thermal Rating: on line 5081-7553 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 322
% INFO    : Updated Thermal Rating: on line 8666-8494 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 254
% INFO    : Updated Thermal Rating: on line 11001-9689 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 582
% INFO    : Updated Thermal Rating: on line 9689-11001 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 572
% INFO    : Updated Thermal Rating: on line 6310-3549 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 567
% INFO    : Updated Thermal Rating: on line 7106-6310 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on line 10458-2358 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 769
% INFO    : Updated Thermal Rating: on line 10458-2358 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 775
% INFO    : Updated Thermal Rating: on line 2358-11001 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 282
% INFO    : Updated Thermal Rating: on line 2358-11001 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 277
% INFO    : Updated Thermal Rating: on line 2358-8780 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 515
% INFO    : Updated Thermal Rating: on line 1302-6531 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 911
% INFO    : Updated Thermal Rating: on line 3549-8241 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10075
% INFO    : Updated Thermal Rating: on line 3549-8241 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11148
% INFO    : Updated Thermal Rating: on line 3549-2972 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 875
% INFO    : Updated Thermal Rating: on line 8720-3549 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 915
% INFO    : Updated Thermal Rating: on line 8720-3549 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 899
% INFO    : Updated Thermal Rating: on line 2421-10458 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 346
% INFO    : Updated Thermal Rating: on line 10458-5586 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 271
% INFO    : Updated Thermal Rating: on line 12153-10717 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2504
% INFO    : Updated Thermal Rating: on line 2209-12153 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3356
% INFO    : Updated Thermal Rating: on line 12153-850 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1651
% INFO    : Updated Thermal Rating: on line 11653-2972 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 923
% INFO    : Updated Thermal Rating: on line 11653-8698 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 467
% INFO    : Updated Thermal Rating: on line 10859-13562 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 762
% INFO    : Updated Thermal Rating: on line 10859-3783 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 293
% INFO    : Updated Thermal Rating: on line 10859-3783 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 288
% INFO    : Updated Thermal Rating: on line 10859-1184 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 549
% INFO    : Updated Thermal Rating: on line 10859-1302 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 399
% INFO    : Updated Thermal Rating: on line 7106-10559 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1190
% INFO    : Updated Thermal Rating: on line 7106-8720 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 292
% INFO    : Updated Thermal Rating: on line 12213-8666 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 316
% INFO    : Updated Thermal Rating: on line 2530-12344 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1926
% INFO    : Updated Thermal Rating: on line 6827-2530 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 361
% INFO    : Updated Thermal Rating: on line 5477-2421 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 411
% INFO    : Updated Thermal Rating: on line 13562-2235 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 353
% INFO    : Updated Thermal Rating: on line 8780-13068 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 549
% INFO    : Updated Thermal Rating: on line 4150-7553 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 789
% INFO    : Updated Thermal Rating: on line 13157-4150 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 526
% INFO    : Updated Thermal Rating: on line 9286-12283 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2686
% INFO    : Updated Thermal Rating: on line 6779-9286 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1218
% INFO    : Updated Thermal Rating: on line 6672-2361 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 222
% INFO    : Updated Thermal Rating: on line 6779-6672 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1207
% INFO    : Updated Thermal Rating: on line 12283-11915 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1030
% INFO    : Updated Thermal Rating: on line 12283-11915 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1108
% INFO    : Updated Thermal Rating: on line 2209-5117 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8126
% INFO    : Updated Thermal Rating: on line 10559-414 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 433
% INFO    : Updated Thermal Rating: on line 10559-414 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 385
% INFO    : Updated Thermal Rating: on line 414-8698 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1814
% INFO    : Updated Thermal Rating: on line 8720-414 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3238
% INFO    : Updated Thermal Rating: on line 10560-3783 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 201
% INFO    : Updated Thermal Rating: on line 6348-10560 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 439
% INFO    : Updated Thermal Rating: on line 10559-119 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1643
% INFO    : Updated Thermal Rating: on line 1076-119 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1158
% INFO    : Updated Thermal Rating: on line 12344-4935 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 221
% INFO    : Updated Thermal Rating: on line 3658-4935 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 563
% INFO    : Updated Thermal Rating: on line 1184-13068 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 359
% INFO    : Updated Thermal Rating: on line 10482-2361 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 524
% INFO    : Updated Thermal Rating: on line 5586-6827 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 286
% INFO    : Updated Thermal Rating: on line 13157-12213 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 739
% INFO    : Updated Thermal Rating: on line 11915-5477 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 783
% INFO    : Updated Thermal Rating: on line 50-7481 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1153
% INFO    : Updated Thermal Rating: on line 10482-7481 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1114
% INFO    : Updated Thermal Rating: on line 119-8720 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 492
% INFO    : Updated Thermal Rating: on line 119-8720 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 501
% INFO    : Updated Thermal Rating: on line 6779-5477 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1247
% INFO    : Updated Thermal Rating: on line 1409-11040 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 459
% INFO    : Updated Thermal Rating: on line 1409-8152 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2105
% INFO    : Updated Thermal Rating: on line 2043-6999 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 764
% INFO    : Updated Thermal Rating: on line 2043-13576 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 456
% INFO    : Updated Thermal Rating: on line 2594-7565 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2763
% INFO    : Updated Thermal Rating: on line 2594-11750 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1857
% INFO    : Updated Thermal Rating: on line 4109-756 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1149
% INFO    : Updated Thermal Rating: on line 4109-756 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1128
% INFO    : Updated Thermal Rating: on line 4109-11112 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1206
% INFO    : Updated Thermal Rating: on line 4109-404 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1275
% INFO    : Updated Thermal Rating: on line 4109-2461 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 310
% INFO    : Updated Thermal Rating: on line 4109-2461 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 305
% INFO    : Updated Thermal Rating: on line 7565-3133 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1236
% INFO    : Updated Thermal Rating: on line 7565-6866 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10645
% INFO    : Updated Thermal Rating: on line 7565-8236 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1507
% INFO    : Updated Thermal Rating: on line 1929-6866 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1457
% INFO    : Updated Thermal Rating: on line 11180-6999 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 886
% INFO    : Updated Thermal Rating: on line 11180-13576 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 402
% INFO    : Updated Thermal Rating: on line 11180-13576 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 434
% INFO    : Updated Thermal Rating: on line 11180-164 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1077
% INFO    : Updated Thermal Rating: on line 11180-4559 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1688
% INFO    : Updated Thermal Rating: on line 11180-2461 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 858
% INFO    : Updated Thermal Rating: on line 5617-2883 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 513
% INFO    : Updated Thermal Rating: on line 5617-8736 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 434
% INFO    : Updated Thermal Rating: on line 7417-2611 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 454
% INFO    : Updated Thermal Rating: on line 7417-8152 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1014
% INFO    : Updated Thermal Rating: on line 6999-13576 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 541
% INFO    : Updated Thermal Rating: on line 6999-164 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3036
% INFO    : Updated Thermal Rating: on line 11040-9874 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 402
% INFO    : Updated Thermal Rating: on line 11040-9874 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 410
% INFO    : Updated Thermal Rating: on line 11040-8736 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 538
% INFO    : Updated Thermal Rating: on line 11040-8736 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 549
% INFO    : Updated Thermal Rating: on line 11040-813 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 888
% INFO    : Updated Thermal Rating: on line 7425-13576 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 683
% INFO    : Updated Thermal Rating: on line 7425-177 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1639
% INFO    : Updated Thermal Rating: on line 12423-4778 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2233
% INFO    : Updated Thermal Rating: on line 12423-4778 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1973
% INFO    : Updated Thermal Rating: on line 12423-4219 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4732
% INFO    : Updated Thermal Rating: on line 12423-3969 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1743
% INFO    : Updated Thermal Rating: on line 1646-5450 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22677
% INFO    : Updated Thermal Rating: on line 1646-5450 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 35119
% INFO    : Updated Thermal Rating: on line 11112-404 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23943
% INFO    : Updated Thermal Rating: on line 8760-5140 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1606
% INFO    : Updated Thermal Rating: on line 8760-5140 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1576
% INFO    : Updated Thermal Rating: on line 2611-6181 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 975
% INFO    : Updated Thermal Rating: on line 2611-6181 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1052
% INFO    : Updated Thermal Rating: on line 2611-5376 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 441
% INFO    : Updated Thermal Rating: on line 2782-404 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 838
% INFO    : Updated Thermal Rating: on line 8152-5376 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 850
% INFO    : Updated Thermal Rating: on line 8152-813 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 524
% INFO    : Updated Thermal Rating: on line 4219-1353 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3233
% INFO    : Updated Thermal Rating: on line 13576-479 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1224
% INFO    : Updated Thermal Rating: on line 13576-479 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1201
% INFO    : Updated Thermal Rating: on line 13576-177 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1019
% INFO    : Updated Thermal Rating: on line 2883-8736 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2216
% INFO    : Updated Thermal Rating: on line 479-5450 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 376
% INFO    : Updated Thermal Rating: on line 479-5450 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 381
% INFO    : Updated Thermal Rating: on line 8236-11750 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5690
% INFO    : Updated Thermal Rating: on line 3969-11750 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1507
% INFO    : Updated Thermal Rating: on line 1353-11750 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1539
% INFO    : Updated Thermal Rating: on line 5140-672 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2121
% INFO    : Updated Thermal Rating: on line 5140-672 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2080
% INFO    : Updated Thermal Rating: on line 8509-8736 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 283
% INFO    : Updated Thermal Rating: on line 8509-8736 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 278
% INFO    : Updated Thermal Rating: on line 446-404 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 601
% INFO    : Updated Thermal Rating: on line 446-404 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 613
% INFO    : Updated Thermal Rating: on line 4559-2461 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1163
% INFO    : Updated Thermal Rating: on line 5711-249 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 467
% INFO    : Updated Thermal Rating: on line 5711-249 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 459
% INFO    : Updated Thermal Rating: on line 2723-10043 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 690
% INFO    : Updated Thermal Rating: on line 11775-12394 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 368
% INFO    : Updated Thermal Rating: on line 11775-5793 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 497
% INFO    : Updated Thermal Rating: on line 8315-3750 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 570
% INFO    : Updated Thermal Rating: on line 1058-8142 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 532
% INFO    : Updated Thermal Rating: on line 218-8142 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 246
% INFO    : Updated Thermal Rating: on line 8142-10533 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 269
% INFO    : Updated Thermal Rating: on line 13106-8657 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 218
% INFO    : Updated Thermal Rating: on line 13106-9368 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 144
% INFO    : Updated Thermal Rating: on line 4476-13106 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 346
% INFO    : Updated Thermal Rating: on line 4940-7549 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1381
% INFO    : Updated Thermal Rating: on line 4940-3440 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2193
% INFO    : Updated Thermal Rating: on line 7549-11388 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 502
% INFO    : Updated Thermal Rating: on line 3440-4836 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 215
% INFO    : Updated Thermal Rating: on line 11973-6342 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1372
% INFO    : Updated Thermal Rating: on line 6342-12033 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1396
% INFO    : Updated Thermal Rating: on line 11973-7034 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1147
% INFO    : Updated Thermal Rating: on line 7034-7169 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1129
% INFO    : Updated Thermal Rating: on line 109-10356 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1670
% INFO    : Updated Thermal Rating: on line 10356-8071 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1644
% INFO    : Updated Thermal Rating: on line 11973-9284 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 715
% INFO    : Updated Thermal Rating: on line 11973-9284 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 725
% INFO    : Updated Thermal Rating: on line 109-11973 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2009
% INFO    : Updated Thermal Rating: on line 8071-11973 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 630
% INFO    : Updated Thermal Rating: on line 8981-9284 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1020
% INFO    : Updated Thermal Rating: on line 8594-9284 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 256
% INFO    : Updated Thermal Rating: on line 5578-9284 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 204
% INFO    : Updated Thermal Rating: on line 3312-9284 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 402
% INFO    : Updated Thermal Rating: on line 9284-755 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 280
% INFO    : Updated Thermal Rating: on line 6982-9284 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 171
% INFO    : Updated Thermal Rating: on line 10639-3604 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2239
% INFO    : Updated Thermal Rating: on line 8611-8981 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1073
% INFO    : Updated Thermal Rating: on line 12735-8611 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 263
% INFO    : Updated Thermal Rating: on line 12735-8071 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 333
% INFO    : Updated Thermal Rating: on line 3659-12735 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 402
% INFO    : Updated Thermal Rating: on line 8311-12735 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 603
% INFO    : Updated Thermal Rating: on line 6443-4836 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1766
% INFO    : Updated Thermal Rating: on line 6443-1728 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 145
% INFO    : Updated Thermal Rating: on line 6443-5108 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 256
% INFO    : Updated Thermal Rating: on line 6443-193 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 296
% INFO    : Updated Thermal Rating: on line 10834-4836 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 182
% INFO    : Updated Thermal Rating: on line 11388-4836 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 324
% INFO    : Updated Thermal Rating: on line 4179-5603 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 353
% INFO    : Updated Thermal Rating: on line 1375-5603 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 517
% INFO    : Updated Thermal Rating: on line 5519-788 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1008
% INFO    : Updated Thermal Rating: on line 788-4492 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 565
% INFO    : Updated Thermal Rating: on line 788-8742 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 310
% INFO    : Updated Thermal Rating: on line 4018-788 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 464
% INFO    : Updated Thermal Rating: on line 1797-6603 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 464
% INFO    : Updated Thermal Rating: on line 1797-6100 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 417
% INFO    : Updated Thermal Rating: on line 3163-12374 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 819
% INFO    : Updated Thermal Rating: on line 12374-11018 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 795
% INFO    : Updated Thermal Rating: on line 7290-10533 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 419
% INFO    : Updated Thermal Rating: on line 4645-7290 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 851
% INFO    : Updated Thermal Rating: on line 7411-6603 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 522
% INFO    : Updated Thermal Rating: on line 251-1058 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 350
% INFO    : Updated Thermal Rating: on line 12033-2738 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 663
% INFO    : Updated Thermal Rating: on line 1375-10286 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2192
% INFO    : Updated Thermal Rating: on line 10286-11018 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 525
% INFO    : Updated Thermal Rating: on line 9827-8117 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1420
% INFO    : Updated Thermal Rating: on line 9827-5067 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 773
% INFO    : Updated Thermal Rating: on line 8117-7411 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1283
% INFO    : Updated Thermal Rating: on line 5519-7418 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 321
% INFO    : Updated Thermal Rating: on line 24-1728 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 349
% INFO    : Updated Thermal Rating: on line 24-10834 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 204
% INFO    : Updated Thermal Rating: on line 8786-24 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 313
% INFO    : Updated Thermal Rating: on line 24-12828 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 245
% INFO    : Updated Thermal Rating: on line 2498-12905 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 396
% INFO    : Updated Thermal Rating: on line 12905-5793 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 845
% INFO    : Updated Thermal Rating: on line 10639-8195 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1915
% INFO    : Updated Thermal Rating: on line 1021-9078 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1778
% INFO    : Updated Thermal Rating: on line 9078-13644 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1122
% INFO    : Updated Thermal Rating: on line 9078-1827 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 650
% INFO    : Updated Thermal Rating: on line 9078-3138 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 474
% INFO    : Updated Thermal Rating: on line 1728-1021 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 731
% INFO    : Updated Thermal Rating: on line 13644-6445 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1738
% INFO    : Updated Thermal Rating: on line 11306-13644 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 378
% INFO    : Updated Thermal Rating: on line 2127-1375 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1635
% INFO    : Updated Thermal Rating: on line 6393-2127 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1167
% INFO    : Updated Thermal Rating: on line 5110-4258 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 363
% INFO    : Updated Thermal Rating: on line 4258-6982 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 628
% INFO    : Updated Thermal Rating: on line 11322-9657 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 29428
% INFO    : Updated Thermal Rating: on line 1360-11322 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8049
% INFO    : Updated Thermal Rating: on line 11217-6803 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1459
% INFO    : Updated Thermal Rating: on line 6803-10688 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7038
% INFO    : Updated Thermal Rating: on line 9414-1600 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1812
% INFO    : Updated Thermal Rating: on line 9414-7154 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 463
% INFO    : Updated Thermal Rating: on line 7016-3955 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 307
% INFO    : Updated Thermal Rating: on line 3766-7016 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 200
% INFO    : Updated Thermal Rating: on line 4313-4582 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 622
% INFO    : Updated Thermal Rating: on line 4313-6393 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 452
% INFO    : Updated Thermal Rating: on line 12339-5338 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2616
% INFO    : Updated Thermal Rating: on line 10677-12339 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2553
% INFO    : Updated Thermal Rating: on line 8657-13227 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 232
% INFO    : Updated Thermal Rating: on line 1331-3955 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1555
% INFO    : Updated Thermal Rating: on line 3955-1970 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 193
% INFO    : Updated Thermal Rating: on line 1331-5161 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 345
% INFO    : Updated Thermal Rating: on line 11063-7227 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4172
% INFO    : Updated Thermal Rating: on line 1827-12394 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 365
% INFO    : Updated Thermal Rating: on line 10213-10834 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 850
% INFO    : Updated Thermal Rating: on line 4711-3925 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 817
% INFO    : Updated Thermal Rating: on line 8594-7597 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 987
% INFO    : Updated Thermal Rating: on line 6124-9027 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 880
% INFO    : Updated Thermal Rating: on line 9027-9578 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 599
% INFO    : Updated Thermal Rating: on line 11217-7154 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1348
% INFO    : Updated Thermal Rating: on line 10440-12377 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12190
% INFO    : Updated Thermal Rating: on line 5793-10440 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1727
% INFO    : Updated Thermal Rating: on line 10440-2822 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3804
% INFO    : Updated Thermal Rating: on line 1600-7310 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 530
% INFO    : Updated Thermal Rating: on line 7310-6100 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 212
% INFO    : Updated Thermal Rating: on line 7310-1769 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 212
% INFO    : Updated Thermal Rating: on line 7310-10688 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 174
% INFO    : Updated Thermal Rating: on line 7310-8822 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23509
% INFO    : Updated Thermal Rating: on line 7310-10070 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 327
% INFO    : Updated Thermal Rating: on line 2470-6124 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 459
% INFO    : Updated Thermal Rating: on line 8697-6100 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6209
% INFO    : Updated Thermal Rating: on line 8697-6100 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4497
% INFO    : Updated Thermal Rating: on line 4973-1360 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1412
% INFO    : Updated Thermal Rating: on line 4973-1360 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1390
% INFO    : Updated Thermal Rating: on line 3659-8311 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 507
% INFO    : Updated Thermal Rating: on line 7418-3659 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1091
% INFO    : Updated Thermal Rating: on line 3659-10098 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1196
% INFO    : Updated Thermal Rating: on line 7708-524 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2088
% INFO    : Updated Thermal Rating: on line 9783-4311 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 45507
% INFO    : Updated Thermal Rating: on line 9193-1360 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 358
% INFO    : Updated Thermal Rating: on line 9193-7227 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2709
% INFO    : Updated Thermal Rating: on line 10688-9647 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 611
% INFO    : Updated Thermal Rating: on line 9647-1375 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 431
% INFO    : Updated Thermal Rating: on line 12721-3750 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 362
% INFO    : Updated Thermal Rating: on line 7227-12721 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 427
% INFO    : Updated Thermal Rating: on line 11018-8245 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 865
% INFO    : Updated Thermal Rating: on line 8347-8245 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11017
% INFO    : Updated Thermal Rating: on line 4674-218 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 347
% INFO    : Updated Thermal Rating: on line 2738-6770 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 374
% INFO    : Updated Thermal Rating: on line 4255-3759 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6218
% INFO    : Updated Thermal Rating: on line 3759-4485 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2008
% INFO    : Updated Thermal Rating: on line 10517-4597 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 429
% INFO    : Updated Thermal Rating: on line 10517-2070 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 468
% INFO    : Updated Thermal Rating: on line 4582-5663 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 400
% INFO    : Updated Thermal Rating: on line 1958-2498 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 420
% INFO    : Updated Thermal Rating: on line 4645-251 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 749
% INFO    : Updated Thermal Rating: on line 13154-4674 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 221
% INFO    : Updated Thermal Rating: on line 13154-833 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 290
% INFO    : Updated Thermal Rating: on line 8069-10604 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 372
% INFO    : Updated Thermal Rating: on line 7226-8069 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 285
% INFO    : Updated Thermal Rating: on line 10533-5578 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 178
% INFO    : Updated Thermal Rating: on line 7633-4492 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 265
% INFO    : Updated Thermal Rating: on line 7169-11821 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2732
% INFO    : Updated Thermal Rating: on line 11821-7597 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 683
% INFO    : Updated Thermal Rating: on line 7633-2723 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 345
% INFO    : Updated Thermal Rating: on line 10875-10136 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 599
% INFO    : Updated Thermal Rating: on line 11388-10136 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 583
% INFO    : Updated Thermal Rating: on line 12377-12394 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 561
% INFO    : Updated Thermal Rating: on line 12377-12394 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 670
% INFO    : Updated Thermal Rating: on line 12394-10028 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 578
% INFO    : Updated Thermal Rating: on line 5067-13194 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4263
% INFO    : Updated Thermal Rating: on line 4276-13194 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5691
% INFO    : Updated Thermal Rating: on line 3138-6445 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 706
% INFO    : Updated Thermal Rating: on line 9326-3138 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 628
% INFO    : Updated Thermal Rating: on line 2054-8025 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2640
% INFO    : Updated Thermal Rating: on line 6100-8025 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2021
% INFO    : Updated Thermal Rating: on line 5067-6685 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1738
% INFO    : Updated Thermal Rating: on line 6685-6100 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1219
% INFO    : Updated Thermal Rating: on line 9578-5067 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 572
% INFO    : Updated Thermal Rating: on line 2054-4276 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2921
% INFO    : Updated Thermal Rating: on line 9724-6100 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1289
% INFO    : Updated Thermal Rating: on line 9724-9368 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 283
% INFO    : Updated Thermal Rating: on line 9724-13267 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 665
% INFO    : Updated Thermal Rating: on line 9724-2692 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2441
% INFO    : Updated Thermal Rating: on line 9724-10070 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 561
% INFO    : Updated Thermal Rating: on line 44-10213 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1206
% INFO    : Updated Thermal Rating: on line 1360-9657 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10435
% INFO    : Updated Thermal Rating: on line 1360-9657 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12556
% INFO    : Updated Thermal Rating: on line 7227-9657 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 792
% INFO    : Updated Thermal Rating: on line 9657-1616 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1281
% INFO    : Updated Thermal Rating: on line 524-9657 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 443
% INFO    : Updated Thermal Rating: on line 524-9657 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 410
% INFO    : Updated Thermal Rating: on line 5338-7701 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1715
% INFO    : Updated Thermal Rating: on line 10604-5578 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 295
% INFO    : Updated Thermal Rating: on line 8742-3163 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1688
% INFO    : Updated Thermal Rating: on line 13227-13267 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 609
% INFO    : Updated Thermal Rating: on line 44-5108 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 692
% INFO    : Updated Thermal Rating: on line 1970-1536 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 431
% INFO    : Updated Thermal Rating: on line 303-2470 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 538
% INFO    : Updated Thermal Rating: on line 8879-1769 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 799
% INFO    : Updated Thermal Rating: on line 3750-4255 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 293
% INFO    : Updated Thermal Rating: on line 5578-7226 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2287
% INFO    : Updated Thermal Rating: on line 7226-755 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 527
% INFO    : Updated Thermal Rating: on line 5110-5578 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1018
% INFO    : Updated Thermal Rating: on line 5578-3312 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 596
% INFO    : Updated Thermal Rating: on line 833-5578 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 400
% INFO    : Updated Thermal Rating: on line 6770-8786 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 589
% INFO    : Updated Thermal Rating: on line 3264-7633 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 182
% INFO    : Updated Thermal Rating: on line 8822-3264 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 372
% INFO    : Updated Thermal Rating: on line 3264-4018 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 378
% INFO    : Updated Thermal Rating: on line 7870-10079 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on line 5161-7870 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 406
% INFO    : Updated Thermal Rating: on line 4231-4476 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1059
% INFO    : Updated Thermal Rating: on line 7227-4255 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 653
% INFO    : Updated Thermal Rating: on line 1616-4255 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 423
% INFO    : Updated Thermal Rating: on line 3840-4255 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5399
% INFO    : Updated Thermal Rating: on line 11279-4255 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 524
% INFO    : Updated Thermal Rating: on line 10688-5663 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 955
% INFO    : Updated Thermal Rating: on line 1211-10688 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1383
% INFO    : Updated Thermal Rating: on line 3766-10688 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 802
% INFO    : Updated Thermal Rating: on line 10688-6393 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 351
% INFO    : Updated Thermal Rating: on line 11097-4179 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2007
% INFO    : Updated Thermal Rating: on line 1536-11097 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12413
% INFO    : Updated Thermal Rating: on line 5663-11097 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1099
% INFO    : Updated Thermal Rating: on line 5663-4179 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1734
% INFO    : Updated Thermal Rating: on line 10079-4179 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 236
% INFO    : Updated Thermal Rating: on line 1536-7191 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13528
% INFO    : Updated Thermal Rating: on line 1536-6516 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1651
% INFO    : Updated Thermal Rating: on line 6413-5663 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1325
% INFO    : Updated Thermal Rating: on line 6413-5663 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1425
% INFO    : Updated Thermal Rating: on line 6413-335 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21136
% INFO    : Updated Thermal Rating: on line 6413-8879 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11787
% INFO    : Updated Thermal Rating: on line 5663-6516 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1169
% INFO    : Updated Thermal Rating: on line 13567-7191 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14970
% INFO    : Updated Thermal Rating: on line 335-13567 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12458
% INFO    : Updated Thermal Rating: on line 13567-3766 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1675
% INFO    : Updated Thermal Rating: on line 8879-3826 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3705
% INFO    : Updated Thermal Rating: on line 3766-8879 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2422
% INFO    : Updated Thermal Rating: on line 3766-3826 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2448
% INFO    : Updated Thermal Rating: on line 1211-3766 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1003
% INFO    : Updated Thermal Rating: on line 10387-7701 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5334
% INFO    : Updated Thermal Rating: on line 7701-8195 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1873
% INFO    : Updated Thermal Rating: on line 2057-8855 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2790
% INFO    : Updated Thermal Rating: on line 11018-2057 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1186
% INFO    : Updated Thermal Rating: on line 8347-2057 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1206
% INFO    : Updated Thermal Rating: on line 193-10028 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on line 12828-7597 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 543
% INFO    : Updated Thermal Rating: on line 9651-1958 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 318
% INFO    : Updated Thermal Rating: on line 9651-2070 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 267
% INFO    : Updated Thermal Rating: on line 4444-11306 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 536
% INFO    : Updated Thermal Rating: on line 6770-4444 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 464
% INFO    : Updated Thermal Rating: on line 303-7633 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 547
% INFO    : Updated Thermal Rating: on line 1375-8855 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 324
% INFO    : Updated Thermal Rating: on line 13641-12377 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 661
% INFO    : Updated Thermal Rating: on line 11279-4711 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7321
% INFO    : Updated Thermal Rating: on line 11279-4711 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6937
% INFO    : Updated Thermal Rating: on line 10255-2023 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1745
% INFO    : Updated Thermal Rating: on line 2023-8855 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 471
% INFO    : Updated Thermal Rating: on line 10255-7418 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 261
% INFO    : Updated Thermal Rating: on line 4597-5793 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 980
% INFO    : Updated Thermal Rating: on line 13641-5793 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1004
% INFO    : Updated Thermal Rating: on line 7418-10098 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13702
% INFO    : Updated Thermal Rating: on line 11279-6390 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7743
% INFO    : Updated Thermal Rating: on line 11279-4485 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 595
% INFO    : Updated Thermal Rating: on line 9783-8195 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1367
% INFO    : Updated Thermal Rating: on line 2822-10875 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4160
% INFO    : Updated Thermal Rating: on line 13164-8195 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4006
% INFO    : Updated Thermal Rating: on line 4597-13641 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1240
% INFO    : Updated Thermal Rating: on line 10875-13641 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1655
% INFO    : Updated Thermal Rating: on line 2070-11388 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 210
% INFO    : Updated Thermal Rating: on line 2692-13267 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 977
% INFO    : Updated Thermal Rating: on line 9326-6708 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 634
% INFO    : Updated Thermal Rating: on line 11018-8855 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 973
% INFO    : Updated Thermal Rating: on line 8855-6708 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 384
% INFO    : Updated Thermal Rating: on line 4482-962 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3480
% INFO    : Updated Thermal Rating: on line 3183-7221 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1371
% INFO    : Updated Thermal Rating: on line 2593-3359 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 521
% INFO    : Updated Thermal Rating: on line 3359-2044 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 415
% INFO    : Updated Thermal Rating: on line 8848-9981 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6748
% INFO    : Updated Thermal Rating: on line 8848-3239 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2793
% INFO    : Updated Thermal Rating: on line 8848-10523 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5970
% INFO    : Updated Thermal Rating: on line 8848-9186 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3355
% INFO    : Updated Thermal Rating: on line 4381-13586 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8992
% INFO    : Updated Thermal Rating: on line 4381-5114 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8
% INFO    : Updated Thermal Rating: on line 4381-1350 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 337
% INFO    : Updated Thermal Rating: on line 4381-342 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on line 4381-9970 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 339
% INFO    : Updated Thermal Rating: on line 4381-13254 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2595
% INFO    : Updated Thermal Rating: on line 4381-8395 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16
% INFO    : Updated Thermal Rating: on line 13586-1350 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 56
% INFO    : Updated Thermal Rating: on line 13586-9970 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 53
% INFO    : Updated Thermal Rating: on line 13586-13254 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 446
% INFO    : Updated Thermal Rating: on line 7727-2304 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8142
% INFO    : Updated Thermal Rating: on line 7727-1668 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2766
% INFO    : Updated Thermal Rating: on line 7727-13402 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9657
% INFO    : Updated Thermal Rating: on line 7727-11873 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9284
% INFO    : Updated Thermal Rating: on line 5114-3277 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 199
% INFO    : Updated Thermal Rating: on line 3277-6494 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 9970-3277 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5
% INFO    : Updated Thermal Rating: on line 11058-3277 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 29
% INFO    : Updated Thermal Rating: on line 6499-3277 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 162
% INFO    : Updated Thermal Rating: on line 12273-3277 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on line 10883-3277 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 30
% INFO    : Updated Thermal Rating: on line 412-3277 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 354
% INFO    : Updated Thermal Rating: on line 3510-3277 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8
% INFO    : Updated Thermal Rating: on line 6844-3277 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1068
% INFO    : Updated Thermal Rating: on line 6590-3277 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 121
% INFO    : Updated Thermal Rating: on line 5114-8135 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 6724-5114 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 94
% INFO    : Updated Thermal Rating: on line 342-5114 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 305
% INFO    : Updated Thermal Rating: on line 9970-5114 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 37
% INFO    : Updated Thermal Rating: on line 11058-5114 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17
% INFO    : Updated Thermal Rating: on line 6499-5114 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 192
% INFO    : Updated Thermal Rating: on line 12273-5114 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on line 10883-5114 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on line 412-5114 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18
% INFO    : Updated Thermal Rating: on line 8395-5114 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11
% INFO    : Updated Thermal Rating: on line 3510-5114 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8
% INFO    : Updated Thermal Rating: on line 6844-5114 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 37
% INFO    : Updated Thermal Rating: on line 6590-5114 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1038
% INFO    : Updated Thermal Rating: on line 8135-6724 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1545
% INFO    : Updated Thermal Rating: on line 6494-6724 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1544
% INFO    : Updated Thermal Rating: on line 7221-4112 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 76679
% INFO    : Updated Thermal Rating: on line 7221-962 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2897
% INFO    : Updated Thermal Rating: on line 7221-1491 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 68410
% INFO    : Updated Thermal Rating: on line 7221-962 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3401
% INFO    : Updated Thermal Rating: on line 2593-7602 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12
% INFO    : Updated Thermal Rating: on line 2593-2044 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 239
% INFO    : Updated Thermal Rating: on line 2304-11382 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9780
% INFO    : Updated Thermal Rating: on line 2304-3618 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6432
% INFO    : Updated Thermal Rating: on line 13402-11382 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8942
% INFO    : Updated Thermal Rating: on line 13402-129 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6915
% INFO    : Updated Thermal Rating: on line 4826-962 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4217
% INFO    : Updated Thermal Rating: on line 4826-12707 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3079
% INFO    : Updated Thermal Rating: on line 12707-1937 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 78577
% INFO    : Updated Thermal Rating: on line 12707-11873 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4498
% INFO    : Updated Thermal Rating: on line 1668-2394 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 73144
% INFO    : Updated Thermal Rating: on line 1668-10304 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10190
% INFO    : Updated Thermal Rating: on line 1282-11382 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5849
% INFO    : Updated Thermal Rating: on line 2985-11382 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5744
% INFO    : Updated Thermal Rating: on line 2985-8729 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18181
% INFO    : Updated Thermal Rating: on line 2985-9186 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2134
% INFO    : Updated Thermal Rating: on line 1282-11382 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6140
% INFO    : Updated Thermal Rating: on line 9805-11873 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12692
% INFO    : Updated Thermal Rating: on line 342-6724 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1428
% INFO    : Updated Thermal Rating: on line 3500-9186 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10893
% INFO    : Updated Thermal Rating: on line 1350-5137 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 1350-13254 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 310
% INFO    : Updated Thermal Rating: on line 5137-4174 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 780
% INFO    : Updated Thermal Rating: on line 342-9970 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 32
% INFO    : Updated Thermal Rating: on line 342-8395 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10
% INFO    : Updated Thermal Rating: on line 13254-9970 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 63
% INFO    : Updated Thermal Rating: on line 8395-9970 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2682
% INFO    : Updated Thermal Rating: on line 962-5712 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10293
% INFO    : Updated Thermal Rating: on line 962-10304 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2505
% INFO    : Updated Thermal Rating: on line 962-13656 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 48391
% INFO    : Updated Thermal Rating: on line 962-11702 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 49913
% INFO    : Updated Thermal Rating: on line 962-9098 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 57093
% INFO    : Updated Thermal Rating: on line 962-7884 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3253
% INFO    : Updated Thermal Rating: on line 962-61 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 39828
% INFO    : Updated Thermal Rating: on line 1142-4784 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 11058-1142 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5
% INFO    : Updated Thermal Rating: on line 9831-1142 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 63
% INFO    : Updated Thermal Rating: on line 12273-1142 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 254
% INFO    : Updated Thermal Rating: on line 3510-1142 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 104
% INFO    : Updated Thermal Rating: on line 6844-1142 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14
% INFO    : Updated Thermal Rating: on line 6590-1142 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13
% INFO    : Updated Thermal Rating: on line 7884-3238 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14737
% INFO    : Updated Thermal Rating: on line 7884-11179 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3554
% INFO    : Updated Thermal Rating: on line 13254-3070 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 5402-8729 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15425
% INFO    : Updated Thermal Rating: on line 8371-8729 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15130
% INFO    : Updated Thermal Rating: on line 10366-10981 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 11058-10366 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 331
% INFO    : Updated Thermal Rating: on line 6499-10366 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5
% INFO    : Updated Thermal Rating: on line 10366-9831 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 431
% INFO    : Updated Thermal Rating: on line 412-10366 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on line 10366-2298 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 56
% INFO    : Updated Thermal Rating: on line 10981-2298 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1189
% INFO    : Updated Thermal Rating: on line 12041-12038 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9918
% INFO    : Updated Thermal Rating: on line 12041-11382 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6320
% INFO    : Updated Thermal Rating: on line 13341-11382 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6197
% INFO    : Updated Thermal Rating: on line 11058-6499 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 41
% INFO    : Updated Thermal Rating: on line 11058-9831 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 817
% INFO    : Updated Thermal Rating: on line 11058-12273 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 53
% INFO    : Updated Thermal Rating: on line 11058-10883 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 28
% INFO    : Updated Thermal Rating: on line 11058-412 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 35
% INFO    : Updated Thermal Rating: on line 3510-11058 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9
% INFO    : Updated Thermal Rating: on line 6844-11058 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 492
% INFO    : Updated Thermal Rating: on line 6590-11058 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17
% INFO    : Updated Thermal Rating: on line 11058-2298 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 307
% INFO    : Updated Thermal Rating: on line 6499-9831 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12
% INFO    : Updated Thermal Rating: on line 6499-12273 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5
% INFO    : Updated Thermal Rating: on line 6499-10883 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 652
% INFO    : Updated Thermal Rating: on line 6499-412 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 723
% INFO    : Updated Thermal Rating: on line 3510-6499 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on line 6844-6499 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26
% INFO    : Updated Thermal Rating: on line 6590-6499 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 714
% INFO    : Updated Thermal Rating: on line 6499-2298 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on line 7602-2044 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1817
% INFO    : Updated Thermal Rating: on line 12038-7626 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4526
% INFO    : Updated Thermal Rating: on line 12038-11382 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3935
% INFO    : Updated Thermal Rating: on line 9831-1354 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 12273-9831 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1017
% INFO    : Updated Thermal Rating: on line 10883-9831 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9
% INFO    : Updated Thermal Rating: on line 412-9831 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13
% INFO    : Updated Thermal Rating: on line 3510-9831 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 51
% INFO    : Updated Thermal Rating: on line 6844-9831 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14
% INFO    : Updated Thermal Rating: on line 6590-9831 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on line 2298-9831 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 195
% INFO    : Updated Thermal Rating: on line 7626-2254 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3513
% INFO    : Updated Thermal Rating: on line 12273-2191 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 10883-12273 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on line 3510-12273 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 246
% INFO    : Updated Thermal Rating: on line 6844-12273 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 47
% INFO    : Updated Thermal Rating: on line 6590-12273 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 35
% INFO    : Updated Thermal Rating: on line 11382-3239 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4051
% INFO    : Updated Thermal Rating: on line 10883-412 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 509
% INFO    : Updated Thermal Rating: on line 10883-4174 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 520
% INFO    : Updated Thermal Rating: on line 6844-10883 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12
% INFO    : Updated Thermal Rating: on line 6590-10883 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15
% INFO    : Updated Thermal Rating: on line 10883-2298 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 432
% INFO    : Updated Thermal Rating: on line 412-4174 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 547
% INFO    : Updated Thermal Rating: on line 6844-412 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on line 6590-412 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9
% INFO    : Updated Thermal Rating: on line 412-2298 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 424
% INFO    : Updated Thermal Rating: on line 2254-8510 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8673
% INFO    : Updated Thermal Rating: on line 10304-13103 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17783
% INFO    : Updated Thermal Rating: on line 8395-12108 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 471-9098 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142990
% INFO    : Updated Thermal Rating: on line 6844-3510 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 217
% INFO    : Updated Thermal Rating: on line 3510-6590 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 269
% INFO    : Updated Thermal Rating: on line 6844-6590 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 970
% INFO    : Updated Thermal Rating: on line 2298-6473 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 12971-3259 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 473
% INFO    : Updated Thermal Rating: on line 929-3259 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 412
% INFO    : Updated Thermal Rating: on line 6446-5892 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 874
% INFO    : Updated Thermal Rating: on line 5892-11019 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6129
% INFO    : Updated Thermal Rating: on line 5892-8749 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 892
% INFO    : Updated Thermal Rating: on line 5892-8749 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 910
% INFO    : Updated Thermal Rating: on line 10227-2900 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1931
% INFO    : Updated Thermal Rating: on line 10227-2900 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2123
% INFO    : Updated Thermal Rating: on line 10227-2900 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1895
% INFO    : Updated Thermal Rating: on line 2145-10227 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1306
% INFO    : Updated Thermal Rating: on line 2145-10227 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1174
% INFO    : Updated Thermal Rating: on line 2145-10227 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1198
% INFO    : Updated Thermal Rating: on line 8032-1164 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1148
% INFO    : Updated Thermal Rating: on line 8032-3008 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 227
% INFO    : Updated Thermal Rating: on line 2305-4806 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1034
% INFO    : Updated Thermal Rating: on line 4806-8823 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 863
% INFO    : Updated Thermal Rating: on line 5561-6684 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 437
% INFO    : Updated Thermal Rating: on line 10396-5561 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1076
% INFO    : Updated Thermal Rating: on line 2035-4589 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 433
% INFO    : Updated Thermal Rating: on line 2035-4589 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 442
% INFO    : Updated Thermal Rating: on line 4589-12640 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1334
% INFO    : Updated Thermal Rating: on line 4589-10889 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2097
% INFO    : Updated Thermal Rating: on line 4589-7538 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 920
% INFO    : Updated Thermal Rating: on line 4589-1292 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 318
% INFO    : Updated Thermal Rating: on line 12971-5532 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 338
% INFO    : Updated Thermal Rating: on line 12971-4992 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3718
% INFO    : Updated Thermal Rating: on line 12971-9566 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1348
% INFO    : Updated Thermal Rating: on line 12971-11748 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1969
% INFO    : Updated Thermal Rating: on line 12971-1037 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1440
% INFO    : Updated Thermal Rating: on line 12971-6848 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2370
% INFO    : Updated Thermal Rating: on line 12971-3676 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 757
% INFO    : Updated Thermal Rating: on line 4201-7895 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2168
% INFO    : Updated Thermal Rating: on line 5373-4201 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 964
% INFO    : Updated Thermal Rating: on line 8818-4224 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 354
% INFO    : Updated Thermal Rating: on line 8818-1740 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 284
% INFO    : Updated Thermal Rating: on line 1384-4853 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 308
% INFO    : Updated Thermal Rating: on line 10215-4853 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2182
% INFO    : Updated Thermal Rating: on line 13420-8567 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 505
% INFO    : Updated Thermal Rating: on line 13420-2099 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 473
% INFO    : Updated Thermal Rating: on line 13420-10947 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 390
% INFO    : Updated Thermal Rating: on line 7589-13420 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 429
% INFO    : Updated Thermal Rating: on line 13420-503 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1404
% INFO    : Updated Thermal Rating: on line 13470-11054 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 190
% INFO    : Updated Thermal Rating: on line 10947-11054 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1278
% INFO    : Updated Thermal Rating: on line 10947-11054 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1256
% INFO    : Updated Thermal Rating: on line 5318-11054 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 603
% INFO    : Updated Thermal Rating: on line 11054-6936 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2947
% INFO    : Updated Thermal Rating: on line 6629-11054 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 233
% INFO    : Updated Thermal Rating: on line 6629-11054 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 252
% INFO    : Updated Thermal Rating: on line 7337-11054 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1475
% INFO    : Updated Thermal Rating: on line 6703-7885 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6673
% INFO    : Updated Thermal Rating: on line 7885-3706 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1012
% INFO    : Updated Thermal Rating: on line 1037-11926 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 238
% INFO    : Updated Thermal Rating: on line 1037-11926 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 233
% INFO    : Updated Thermal Rating: on line 8682-11926 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 439
% INFO    : Updated Thermal Rating: on line 8682-11926 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 447
% INFO    : Updated Thermal Rating: on line 9872-12389 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 687
% INFO    : Updated Thermal Rating: on line 6788-9872 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 313
% INFO    : Updated Thermal Rating: on line 9872-13113 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3273
% INFO    : Updated Thermal Rating: on line 500-2673 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 216
% INFO    : Updated Thermal Rating: on line 6143-500 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1576
% INFO    : Updated Thermal Rating: on line 5184-56 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1778
% INFO    : Updated Thermal Rating: on line 56-1284 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 369
% INFO    : Updated Thermal Rating: on line 56-2267 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1063
% INFO    : Updated Thermal Rating: on line 13072-5184 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 472
% INFO    : Updated Thermal Rating: on line 9130-2400 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 244
% INFO    : Updated Thermal Rating: on line 2400-8054 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 238
% INFO    : Updated Thermal Rating: on line 3834-7401 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 735
% INFO    : Updated Thermal Rating: on line 7401-1292 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1430
% INFO    : Updated Thermal Rating: on line 2028-13653 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 35373
% INFO    : Updated Thermal Rating: on line 6883-2028 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1469
% INFO    : Updated Thermal Rating: on line 6883-2028 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1490
% INFO    : Updated Thermal Rating: on line 13653-5429 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 313
% INFO    : Updated Thermal Rating: on line 13653-11192 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 602
% INFO    : Updated Thermal Rating: on line 13653-10958 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 256
% INFO    : Updated Thermal Rating: on line 670-5241 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1052
% INFO    : Updated Thermal Rating: on line 10751-670 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10216
% INFO    : Updated Thermal Rating: on line 2419-2305 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 636
% INFO    : Updated Thermal Rating: on line 8688-5087 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 704
% INFO    : Updated Thermal Rating: on line 5087-10725 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 551
% INFO    : Updated Thermal Rating: on line 7895-6750 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 226
% INFO    : Updated Thermal Rating: on line 7895-6750 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 222
% INFO    : Updated Thermal Rating: on line 6750-10524 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 528
% INFO    : Updated Thermal Rating: on line 6750-12031 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 885
% INFO    : Updated Thermal Rating: on line 3835-6750 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 991
% INFO    : Updated Thermal Rating: on line 3835-6750 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1024
% INFO    : Updated Thermal Rating: on line 3454-7619 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 215
% INFO    : Updated Thermal Rating: on line 8790-7619 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 464
% INFO    : Updated Thermal Rating: on line 7589-8567 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 816
% INFO    : Updated Thermal Rating: on line 9285-2035 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 574
% INFO    : Updated Thermal Rating: on line 9285-2035 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 563
% INFO    : Updated Thermal Rating: on line 704-6273 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 425
% INFO    : Updated Thermal Rating: on line 13276-6273 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1697
% INFO    : Updated Thermal Rating: on line 929-5532 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1005
% INFO    : Updated Thermal Rating: on line 7618-5318 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 443
% INFO    : Updated Thermal Rating: on line 11426-7618 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1248
% INFO    : Updated Thermal Rating: on line 4992-3974 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 788
% INFO    : Updated Thermal Rating: on line 12254-3207 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1649
% INFO    : Updated Thermal Rating: on line 3207-5414 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1917
% INFO    : Updated Thermal Rating: on line 12316-2133 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 588
% INFO    : Updated Thermal Rating: on line 10920-12316 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 488
% INFO    : Updated Thermal Rating: on line 13321-3581 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2343
% INFO    : Updated Thermal Rating: on line 13321-3581 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2300
% INFO    : Updated Thermal Rating: on line 5373-7895 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3646
% INFO    : Updated Thermal Rating: on line 7895-2339 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 888
% INFO    : Updated Thermal Rating: on line 1643-1248 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 671
% INFO    : Updated Thermal Rating: on line 1643-1248 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 682
% INFO    : Updated Thermal Rating: on line 4107-1248 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 910
% INFO    : Updated Thermal Rating: on line 969-1248 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 429
% INFO    : Updated Thermal Rating: on line 6446-8749 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 626
% INFO    : Updated Thermal Rating: on line 13205-1542 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 258
% INFO    : Updated Thermal Rating: on line 13205-1542 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 256
% INFO    : Updated Thermal Rating: on line 1542-6267 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1087
% INFO    : Updated Thermal Rating: on line 1542-12445 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 748
% INFO    : Updated Thermal Rating: on line 1542-5669 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 267
% INFO    : Updated Thermal Rating: on line 1542-827 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 258
% INFO    : Updated Thermal Rating: on line 1542-1243 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 324
% INFO    : Updated Thermal Rating: on line 4186-13205 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 428
% INFO    : Updated Thermal Rating: on line 13109-4186 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 257
% INFO    : Updated Thermal Rating: on line 4186-3008 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 206
% INFO    : Updated Thermal Rating: on line 9516-4186 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4443
% INFO    : Updated Thermal Rating: on line 2888-4186 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2127
% INFO    : Updated Thermal Rating: on line 2888-4186 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2158
% INFO    : Updated Thermal Rating: on line 620-4186 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 996
% INFO    : Updated Thermal Rating: on line 2879-10925 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 654
% INFO    : Updated Thermal Rating: on line 2009-2879 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 876
% INFO    : Updated Thermal Rating: on line 2879-12615 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 991
% INFO    : Updated Thermal Rating: on line 4993-13570 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 124
% INFO    : Updated Thermal Rating: on line 13570-1328 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 214
% INFO    : Updated Thermal Rating: on line 13570-2823 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 276
% INFO    : Updated Thermal Rating: on line 4986-12249 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 337
% INFO    : Updated Thermal Rating: on line 12249-8102 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4573
% INFO    : Updated Thermal Rating: on line 1249-10766 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 270
% INFO    : Updated Thermal Rating: on line 1249-12030 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 658
% INFO    : Updated Thermal Rating: on line 6684-10725 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 394
% INFO    : Updated Thermal Rating: on line 3008-13205 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 352
% INFO    : Updated Thermal Rating: on line 3120-13205 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 323
% INFO    : Updated Thermal Rating: on line 1164-10414 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 337
% INFO    : Updated Thermal Rating: on line 10414-12254 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 335
% INFO    : Updated Thermal Rating: on line 10414-5974 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 664
% INFO    : Updated Thermal Rating: on line 5834-2346 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1298
% INFO    : Updated Thermal Rating: on line 11341-5834 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2533
% INFO    : Updated Thermal Rating: on line 11068-1054 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1330
% INFO    : Updated Thermal Rating: on line 10919-11068 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1805
% INFO    : Updated Thermal Rating: on line 13146-8672 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 324
% INFO    : Updated Thermal Rating: on line 13146-8672 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 330
% INFO    : Updated Thermal Rating: on line 8672-4319 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 399
% INFO    : Updated Thermal Rating: on line 8672-9445 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1531
% INFO    : Updated Thermal Rating: on line 8672-9445 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1360
% INFO    : Updated Thermal Rating: on line 1328-8672 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 419
% INFO    : Updated Thermal Rating: on line 8672-7355 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1045
% INFO    : Updated Thermal Rating: on line 8672-7355 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1059
% INFO    : Updated Thermal Rating: on line 4023-8672 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 134
% INFO    : Updated Thermal Rating: on line 3711-2475 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 966
% INFO    : Updated Thermal Rating: on line 3711-6883 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1427
% INFO    : Updated Thermal Rating: on line 5019-2900 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1196
% INFO    : Updated Thermal Rating: on line 5019-10919 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1033
% INFO    : Updated Thermal Rating: on line 6742-2355 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1115
% INFO    : Updated Thermal Rating: on line 6742-2475 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 627
% INFO    : Updated Thermal Rating: on line 6742-2475 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 639
% INFO    : Updated Thermal Rating: on line 6742-2401 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 656
% INFO    : Updated Thermal Rating: on line 6742-137 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1402
% INFO    : Updated Thermal Rating: on line 6742-298 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 797
% INFO    : Updated Thermal Rating: on line 12254-8213 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1295
% INFO    : Updated Thermal Rating: on line 10766-12254 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 265
% INFO    : Updated Thermal Rating: on line 10766-12254 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 262
% INFO    : Updated Thermal Rating: on line 12254-5414 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1914
% INFO    : Updated Thermal Rating: on line 13072-11429 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1275
% INFO    : Updated Thermal Rating: on line 10725-13072 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 894
% INFO    : Updated Thermal Rating: on line 10725-13072 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 911
% INFO    : Updated Thermal Rating: on line 9904-6075 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11201
% INFO    : Updated Thermal Rating: on line 7874-10614 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 549
% INFO    : Updated Thermal Rating: on line 5506-7874 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 338
% INFO    : Updated Thermal Rating: on line 11200-8129 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 464
% INFO    : Updated Thermal Rating: on line 11200-12693 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 379
% INFO    : Updated Thermal Rating: on line 6703-4558 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 696
% INFO    : Updated Thermal Rating: on line 6703-6143 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 282
% INFO    : Updated Thermal Rating: on line 6703-6143 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 287
% INFO    : Updated Thermal Rating: on line 1864-4947 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2005
% INFO    : Updated Thermal Rating: on line 4947-3957 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2095
% INFO    : Updated Thermal Rating: on line 4122-2261 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4204
% INFO    : Updated Thermal Rating: on line 704-4122 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 751
% INFO    : Updated Thermal Rating: on line 2145-13321 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3207
% INFO    : Updated Thermal Rating: on line 2145-13321 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3147
% INFO    : Updated Thermal Rating: on line 13321-6075 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1689
% INFO    : Updated Thermal Rating: on line 7175-4001 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 330
% INFO    : Updated Thermal Rating: on line 1580-7175 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1514
% INFO    : Updated Thermal Rating: on line 4065-10381 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 455
% INFO    : Updated Thermal Rating: on line 10029-4065 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 728
% INFO    : Updated Thermal Rating: on line 9868-8688 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1217
% INFO    : Updated Thermal Rating: on line 2806-13470 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 474
% INFO    : Updated Thermal Rating: on line 11304-13470 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3418
% INFO    : Updated Thermal Rating: on line 13470-6629 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 663
% INFO    : Updated Thermal Rating: on line 298-2355 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3429
% INFO    : Updated Thermal Rating: on line 9130-10925 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 255
% INFO    : Updated Thermal Rating: on line 6788-2099 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 611
% INFO    : Updated Thermal Rating: on line 1565-10381 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4965
% INFO    : Updated Thermal Rating: on line 2396-13146 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 868
% INFO    : Updated Thermal Rating: on line 13616-7940 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 302
% INFO    : Updated Thermal Rating: on line 7429-7940 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1222
% INFO    : Updated Thermal Rating: on line 8054-7940 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 190
% INFO    : Updated Thermal Rating: on line 11423-1862 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52855
% INFO    : Updated Thermal Rating: on line 5014-3060 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4180
% INFO    : Updated Thermal Rating: on line 3533-2261 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3080
% INFO    : Updated Thermal Rating: on line 2261-8093 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 827
% INFO    : Updated Thermal Rating: on line 13276-2261 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 683
% INFO    : Updated Thermal Rating: on line 3533-5893 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11302
% INFO    : Updated Thermal Rating: on line 13276-3533 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 724
% INFO    : Updated Thermal Rating: on line 2626-2806 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1804
% INFO    : Updated Thermal Rating: on line 3678-7956 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 600
% INFO    : Updated Thermal Rating: on line 3120-7956 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 849
% INFO    : Updated Thermal Rating: on line 13342-5373 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 966
% INFO    : Updated Thermal Rating: on line 704-9652 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 310
% INFO    : Updated Thermal Rating: on line 704-9652 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 316
% INFO    : Updated Thermal Rating: on line 704-9652 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 322
% INFO    : Updated Thermal Rating: on line 704-7536 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 617
% INFO    : Updated Thermal Rating: on line 704-4787 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 221
% INFO    : Updated Thermal Rating: on line 704-5893 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 635
% INFO    : Updated Thermal Rating: on line 704-7941 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 981
% INFO    : Updated Thermal Rating: on line 704-7941 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1058
% INFO    : Updated Thermal Rating: on line 704-13185 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 295
% INFO    : Updated Thermal Rating: on line 9652-5647 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 320
% INFO    : Updated Thermal Rating: on line 9652-5203 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 186
% INFO    : Updated Thermal Rating: on line 10919-13151 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24246
% INFO    : Updated Thermal Rating: on line 10919-13151 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19243
% INFO    : Updated Thermal Rating: on line 1784-573 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 773
% INFO    : Updated Thermal Rating: on line 1784-349 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2577
% INFO    : Updated Thermal Rating: on line 1784-349 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2281
% INFO    : Updated Thermal Rating: on line 1784-5136 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4167
% INFO    : Updated Thermal Rating: on line 1784-817 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 408
% INFO    : Updated Thermal Rating: on line 3151-4224 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2406
% INFO    : Updated Thermal Rating: on line 2475-6883 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 656
% INFO    : Updated Thermal Rating: on line 1384-13616 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 305
% INFO    : Updated Thermal Rating: on line 13616-11135 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 390
% INFO    : Updated Thermal Rating: on line 13616-7429 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 307
% INFO    : Updated Thermal Rating: on line 11794-7030 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2476
% INFO    : Updated Thermal Rating: on line 11794-9130 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1000
% INFO    : Updated Thermal Rating: on line 12314-4986 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 968
% INFO    : Updated Thermal Rating: on line 8682-12314 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 689
% INFO    : Updated Thermal Rating: on line 11192-13281 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 236
% INFO    : Updated Thermal Rating: on line 506-13281 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 574
% INFO    : Updated Thermal Rating: on line 6819-10524 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 470
% INFO    : Updated Thermal Rating: on line 4993-9845 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 101
% INFO    : Updated Thermal Rating: on line 4477-4993 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 474
% INFO    : Updated Thermal Rating: on line 4993-95 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 232
% INFO    : Updated Thermal Rating: on line 1873-8072 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 727
% INFO    : Updated Thermal Rating: on line 8072-8263 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 654
% INFO    : Updated Thermal Rating: on line 10342-7920 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 335
% INFO    : Updated Thermal Rating: on line 10766-7920 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 335
% INFO    : Updated Thermal Rating: on line 10607-10342 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1660
% INFO    : Updated Thermal Rating: on line 5917-10607 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1618
% INFO    : Updated Thermal Rating: on line 12340-3957 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 286
% INFO    : Updated Thermal Rating: on line 5429-12340 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 297
% INFO    : Updated Thermal Rating: on line 7589-3232 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 877
% INFO    : Updated Thermal Rating: on line 3232-11426 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 645
% INFO    : Updated Thermal Rating: on line 3079-7612 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4668
% INFO    : Updated Thermal Rating: on line 3069-7612 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4051
% INFO    : Updated Thermal Rating: on line 8971-5554 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 960
% INFO    : Updated Thermal Rating: on line 8971-5554 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 943
% INFO    : Updated Thermal Rating: on line 5554-5506 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5639
% INFO    : Updated Thermal Rating: on line 6267-641 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1852
% INFO    : Updated Thermal Rating: on line 4329-11808 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 977
% INFO    : Updated Thermal Rating: on line 13276-11808 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1054
% INFO    : Updated Thermal Rating: on line 863-12031 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 298
% INFO    : Updated Thermal Rating: on line 863-3740 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 419
% INFO    : Updated Thermal Rating: on line 3836-1226 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1582
% INFO    : Updated Thermal Rating: on line 506-3836 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 383
% INFO    : Updated Thermal Rating: on line 2401-1226 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4272
% INFO    : Updated Thermal Rating: on line 2401-137 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1479
% INFO    : Updated Thermal Rating: on line 2401-12891 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 449
% INFO    : Updated Thermal Rating: on line 2401-5717 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 416
% INFO    : Updated Thermal Rating: on line 2401-1918 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 336
% INFO    : Updated Thermal Rating: on line 5647-5203 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 451
% INFO    : Updated Thermal Rating: on line 4001-2673 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1664
% INFO    : Updated Thermal Rating: on line 10947-12943 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 667
% INFO    : Updated Thermal Rating: on line 10947-12545 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2223
% INFO    : Updated Thermal Rating: on line 3834-573 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 344
% INFO    : Updated Thermal Rating: on line 3834-8812 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 382
% INFO    : Updated Thermal Rating: on line 3834-12618 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 460
% INFO    : Updated Thermal Rating: on line 3834-2745 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 439
% INFO    : Updated Thermal Rating: on line 3834-10184 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 755
% INFO    : Updated Thermal Rating: on line 124-355 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2884
% INFO    : Updated Thermal Rating: on line 1243-124 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1355
% INFO    : Updated Thermal Rating: on line 3420-46 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4137
% INFO    : Updated Thermal Rating: on line 11341-2931 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4048
% INFO    : Updated Thermal Rating: on line 11341-2931 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3606
% INFO    : Updated Thermal Rating: on line 13109-3678 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 485
% INFO    : Updated Thermal Rating: on line 2396-11739 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 469
% INFO    : Updated Thermal Rating: on line 5181-3454 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 592
% INFO    : Updated Thermal Rating: on line 1565-5181 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 251
% INFO    : Updated Thermal Rating: on line 1677-9791 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2905
% INFO    : Updated Thermal Rating: on line 4536-9791 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3303
% INFO    : Updated Thermal Rating: on line 4536-9791 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3365
% INFO    : Updated Thermal Rating: on line 1873-834 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 399
% INFO    : Updated Thermal Rating: on line 834-10342 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 413
% INFO    : Updated Thermal Rating: on line 6374-5485 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4574
% INFO    : Updated Thermal Rating: on line 5485-5620 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1071
% INFO    : Updated Thermal Rating: on line 2673-8086 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 344
% INFO    : Updated Thermal Rating: on line 13014-8086 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on line 11304-8024 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3350
% INFO    : Updated Thermal Rating: on line 8858-11304 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 448
% INFO    : Updated Thermal Rating: on line 13276-7536 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1207
% INFO    : Updated Thermal Rating: on line 10614-28 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 479
% INFO    : Updated Thermal Rating: on line 9845-12392 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1262
% INFO    : Updated Thermal Rating: on line 2547-9845 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 289
% INFO    : Updated Thermal Rating: on line 4319-10695 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 446
% INFO    : Updated Thermal Rating: on line 3974-1677 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 602
% INFO    : Updated Thermal Rating: on line 1677-5506 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 902
% INFO    : Updated Thermal Rating: on line 1677-3032 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 418
% INFO    : Updated Thermal Rating: on line 1677-3032 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 411
% INFO    : Updated Thermal Rating: on line 1873-43 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 223
% INFO    : Updated Thermal Rating: on line 43-10261 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 337
% INFO    : Updated Thermal Rating: on line 43-929 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 252
% INFO    : Updated Thermal Rating: on line 8263-43 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 578
% INFO    : Updated Thermal Rating: on line 10342-5346 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1182
% INFO    : Updated Thermal Rating: on line 5917-5346 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1908
% INFO    : Updated Thermal Rating: on line 1384-1590 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 583
% INFO    : Updated Thermal Rating: on line 5248-12392 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 379
% INFO    : Updated Thermal Rating: on line 6819-11057 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 260
% INFO    : Updated Thermal Rating: on line 1832-6111 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 804
% INFO    : Updated Thermal Rating: on line 6111-4477 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 442
% INFO    : Updated Thermal Rating: on line 6111-1580 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 251
% INFO    : Updated Thermal Rating: on line 6111-1580 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 256
% INFO    : Updated Thermal Rating: on line 5113-6111 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 478
% INFO    : Updated Thermal Rating: on line 9725-7694 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3001
% INFO    : Updated Thermal Rating: on line 9725-6143 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 756
% INFO    : Updated Thermal Rating: on line 641-12445 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1555
% INFO    : Updated Thermal Rating: on line 4277-6863 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 845
% INFO    : Updated Thermal Rating: on line 4277-3989 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 861
% INFO    : Updated Thermal Rating: on line 7694-4277 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1920
% INFO    : Updated Thermal Rating: on line 7153-4277 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3867
% INFO    : Updated Thermal Rating: on line 5093-1832 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on line 7435-5093 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 323
% INFO    : Updated Thermal Rating: on line 11429-6833 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1332
% INFO    : Updated Thermal Rating: on line 6833-2267 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 322
% INFO    : Updated Thermal Rating: on line 7355-9445 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2913
% INFO    : Updated Thermal Rating: on line 9445-9055 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 615
% INFO    : Updated Thermal Rating: on line 10751-11135 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 233
% INFO    : Updated Thermal Rating: on line 8024-6629 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2484
% INFO    : Updated Thermal Rating: on line 28-2544 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 804
% INFO    : Updated Thermal Rating: on line 28-4542 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1514
% INFO    : Updated Thermal Rating: on line 28-8739 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 387
% INFO    : Updated Thermal Rating: on line 4558-2544 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 324
% INFO    : Updated Thermal Rating: on line 4542-2168 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 633
% INFO    : Updated Thermal Rating: on line 8682-2168 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 212
% INFO    : Updated Thermal Rating: on line 7537-817 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10647
% INFO    : Updated Thermal Rating: on line 832-9055 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 499
% INFO    : Updated Thermal Rating: on line 832-7435 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 285
% INFO    : Updated Thermal Rating: on line 5943-832 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 321
% INFO    : Updated Thermal Rating: on line 5241-4787 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2011
% INFO    : Updated Thermal Rating: on line 2419-7816 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1064
% INFO    : Updated Thermal Rating: on line 2419-7816 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 950
% INFO    : Updated Thermal Rating: on line 2419-13185 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 195
% INFO    : Updated Thermal Rating: on line 3706-3707 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 730
% INFO    : Updated Thermal Rating: on line 2035-1643 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2244
% INFO    : Updated Thermal Rating: on line 2035-1643 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2204
% INFO    : Updated Thermal Rating: on line 2035-46 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1504
% INFO    : Updated Thermal Rating: on line 2035-46 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1477
% INFO    : Updated Thermal Rating: on line 1873-10342 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 410
% INFO    : Updated Thermal Rating: on line 3069-1873 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2122
% INFO    : Updated Thermal Rating: on line 9375-1873 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 964
% INFO    : Updated Thermal Rating: on line 503-12943 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 670
% INFO    : Updated Thermal Rating: on line 1284-7760 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2555
% INFO    : Updated Thermal Rating: on line 8213-5974 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 601
% INFO    : Updated Thermal Rating: on line 8258-8619 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2623
% INFO    : Updated Thermal Rating: on line 8258-743 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 697
% INFO    : Updated Thermal Rating: on line 10980-13342 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1362
% INFO    : Updated Thermal Rating: on line 8835-5644 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 281
% INFO    : Updated Thermal Rating: on line 5774-8835 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1430
% INFO    : Updated Thermal Rating: on line 170-7589 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1194
% INFO    : Updated Thermal Rating: on line 10261-929 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 494
% INFO    : Updated Thermal Rating: on line 10342-5172 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 649
% INFO    : Updated Thermal Rating: on line 5172-6309 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 568
% INFO    : Updated Thermal Rating: on line 1005-5644 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 321
% INFO    : Updated Thermal Rating: on line 8619-4221 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1649
% INFO    : Updated Thermal Rating: on line 8619-4221 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1620
% INFO    : Updated Thermal Rating: on line 9594-8172 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1350
% INFO    : Updated Thermal Rating: on line 8172-11429 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 470
% INFO    : Updated Thermal Rating: on line 8331-6515 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 514
% INFO    : Updated Thermal Rating: on line 6515-2339 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 427
% INFO    : Updated Thermal Rating: on line 5318-3767 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 368
% INFO    : Updated Thermal Rating: on line 3767-13014 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 536
% INFO    : Updated Thermal Rating: on line 7030-7239 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 954
% INFO    : Updated Thermal Rating: on line 6894-4936 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 381
% INFO    : Updated Thermal Rating: on line 4936-1590 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 656
% INFO    : Updated Thermal Rating: on line 4991-10342 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1543
% INFO    : Updated Thermal Rating: on line 10342-12030 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 466
% INFO    : Updated Thermal Rating: on line 10342-4833 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 860
% INFO    : Updated Thermal Rating: on line 4536-8971 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1563
% INFO    : Updated Thermal Rating: on line 4536-8971 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1592
% INFO    : Updated Thermal Rating: on line 4329-226 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 345
% INFO    : Updated Thermal Rating: on line 13276-4329 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 547
% INFO    : Updated Thermal Rating: on line 3478-9130 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1359
% INFO    : Updated Thermal Rating: on line 3478-4587 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2223
% INFO    : Updated Thermal Rating: on line 9052-942 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 345
% INFO    : Updated Thermal Rating: on line 942-6300 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 183
% INFO    : Updated Thermal Rating: on line 8790-942 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 278
% INFO    : Updated Thermal Rating: on line 95-2547 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 211
% INFO    : Updated Thermal Rating: on line 1565-1864 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 313
% INFO    : Updated Thermal Rating: on line 12991-1864 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 284
% INFO    : Updated Thermal Rating: on line 1864-762 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 320
% INFO    : Updated Thermal Rating: on line 3151-7429 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1757
% INFO    : Updated Thermal Rating: on line 5414-13356 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 877
% INFO    : Updated Thermal Rating: on line 13356-9309 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 490
% INFO    : Updated Thermal Rating: on line 10666-170 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 726
% INFO    : Updated Thermal Rating: on line 573-5136 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 975
% INFO    : Updated Thermal Rating: on line 10215-10751 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 173
% INFO    : Updated Thermal Rating: on line 10751-3918 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1747
% INFO    : Updated Thermal Rating: on line 10751-3918 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1716
% INFO    : Updated Thermal Rating: on line 10751-3918 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1405
% INFO    : Updated Thermal Rating: on line 3221-10751 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 195
% INFO    : Updated Thermal Rating: on line 13014-5248 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 398
% INFO    : Updated Thermal Rating: on line 2640-7816 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 933
% INFO    : Updated Thermal Rating: on line 2640-7816 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 917
% INFO    : Updated Thermal Rating: on line 5203-7816 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 890
% INFO    : Updated Thermal Rating: on line 9546-13276 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1242
% INFO    : Updated Thermal Rating: on line 9546-11101 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2258
% INFO    : Updated Thermal Rating: on line 1328-11739 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2067
% INFO    : Updated Thermal Rating: on line 8129-2626 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 984
% INFO    : Updated Thermal Rating: on line 2267-10816 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1012
% INFO    : Updated Thermal Rating: on line 10816-10980 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 622
% INFO    : Updated Thermal Rating: on line 2673-2626 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 364
% INFO    : Updated Thermal Rating: on line 2673-2626 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 418
% INFO    : Updated Thermal Rating: on line 2626-8858 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11816
% INFO    : Updated Thermal Rating: on line 3405-1792 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1084
% INFO    : Updated Thermal Rating: on line 8682-3405 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 582
% INFO    : Updated Thermal Rating: on line 1328-4023 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1414
% INFO    : Updated Thermal Rating: on line 2384-2145 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4355
% INFO    : Updated Thermal Rating: on line 2384-5852 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13785
% INFO    : Updated Thermal Rating: on line 11341-13523 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2571
% INFO    : Updated Thermal Rating: on line 11341-13523 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2526
% INFO    : Updated Thermal Rating: on line 10766-2709 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 481
% INFO    : Updated Thermal Rating: on line 355-10766 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 718
% INFO    : Updated Thermal Rating: on line 5669-10766 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 463
% INFO    : Updated Thermal Rating: on line 12258-13646 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8731
% INFO    : Updated Thermal Rating: on line 12830-13646 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1592
% INFO    : Updated Thermal Rating: on line 13646-4230 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 40234
% INFO    : Updated Thermal Rating: on line 13646-2724 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 39394
% INFO    : Updated Thermal Rating: on line 8812-13522 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 895
% INFO    : Updated Thermal Rating: on line 8812-13522 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 947
% INFO    : Updated Thermal Rating: on line 13522-9419 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3976
% INFO    : Updated Thermal Rating: on line 13522-7538 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 381
% INFO    : Updated Thermal Rating: on line 2673-3989 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 309
% INFO    : Updated Thermal Rating: on line 2673-13014 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 125
% INFO    : Updated Thermal Rating: on line 2673-95 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 204
% INFO    : Updated Thermal Rating: on line 12258-1054 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4141
% INFO    : Updated Thermal Rating: on line 8812-9419 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1447
% INFO    : Updated Thermal Rating: on line 8812-5205 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 783
% INFO    : Updated Thermal Rating: on line 8812-817 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 450
% INFO    : Updated Thermal Rating: on line 8812-10184 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 753
% INFO    : Updated Thermal Rating: on line 9419-9002 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 817
% INFO    : Updated Thermal Rating: on line 5852-2900 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1437
% INFO    : Updated Thermal Rating: on line 8749-2745 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 994
% INFO    : Updated Thermal Rating: on line 8749-2745 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1202
% INFO    : Updated Thermal Rating: on line 5414-4754 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 262
% INFO    : Updated Thermal Rating: on line 2709-5414 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 482
% INFO    : Updated Thermal Rating: on line 5414-10029 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 555
% INFO    : Updated Thermal Rating: on line 9868-10307 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1495
% INFO    : Updated Thermal Rating: on line 9868-10307 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1524
% INFO    : Updated Thermal Rating: on line 9868-6309 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 559
% INFO    : Updated Thermal Rating: on line 9868-6309 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 567
% INFO    : Updated Thermal Rating: on line 4833-9868 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1711
% INFO    : Updated Thermal Rating: on line 12903-6863 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 350
% INFO    : Updated Thermal Rating: on line 12903-1580 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 370
% INFO    : Updated Thermal Rating: on line 12903-9837 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 752
% INFO    : Updated Thermal Rating: on line 4023-4788 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 717
% INFO    : Updated Thermal Rating: on line 4788-2823 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 272
% INFO    : Updated Thermal Rating: on line 1565-4754 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 749
% INFO    : Updated Thermal Rating: on line 10307-6214 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1610
% INFO    : Updated Thermal Rating: on line 5917-6214 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5293
% INFO    : Updated Thermal Rating: on line 3254-9130 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1261
% INFO    : Updated Thermal Rating: on line 3254-9130 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1240
% INFO    : Updated Thermal Rating: on line 4587-9130 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1113
% INFO    : Updated Thermal Rating: on line 9130-10215 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 159
% INFO    : Updated Thermal Rating: on line 3950-9130 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1413
% INFO    : Updated Thermal Rating: on line 9130-269 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1694
% INFO    : Updated Thermal Rating: on line 9130-6894 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 272
% INFO    : Updated Thermal Rating: on line 5620-1005 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 514
% INFO    : Updated Thermal Rating: on line 1792-12179 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2974
% INFO    : Updated Thermal Rating: on line 12640-1862 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1385
% INFO    : Updated Thermal Rating: on line 1037-9566 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1027
% INFO    : Updated Thermal Rating: on line 1037-11748 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1079
% INFO    : Updated Thermal Rating: on line 6143-3707 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 473
% INFO    : Updated Thermal Rating: on line 2346-2730 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 320
% INFO    : Updated Thermal Rating: on line 8682-2730 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 798
% INFO    : Updated Thermal Rating: on line 13014-6936 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 325
% INFO    : Updated Thermal Rating: on line 7239-3254 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2248
% INFO    : Updated Thermal Rating: on line 12179-9205 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1071
% INFO    : Updated Thermal Rating: on line 12389-12693 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 234
% INFO    : Updated Thermal Rating: on line 7760-2267 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 345
% INFO    : Updated Thermal Rating: on line 9052-12891 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 813
% INFO    : Updated Thermal Rating: on line 10725-9594 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1273
% INFO    : Updated Thermal Rating: on line 10725-743 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2623
% INFO    : Updated Thermal Rating: on line 8331-8300 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 470
% INFO    : Updated Thermal Rating: on line 3740-8300 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 336
% INFO    : Updated Thermal Rating: on line 6300-13021 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2220
% INFO    : Updated Thermal Rating: on line 1565-13021 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1414
% INFO    : Updated Thermal Rating: on line 1565-13021 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1389
% INFO    : Updated Thermal Rating: on line 1565-12991 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2826
% INFO    : Updated Thermal Rating: on line 6075-12830 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1846
% INFO    : Updated Thermal Rating: on line 1708-12830 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1790
% INFO    : Updated Thermal Rating: on line 12389-493 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 275
% INFO    : Updated Thermal Rating: on line 12389-13113 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 692
% INFO    : Updated Thermal Rating: on line 1037-9205 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 364
% INFO    : Updated Thermal Rating: on line 10215-6526 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 248
% INFO    : Updated Thermal Rating: on line 1918-6526 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 251
% INFO    : Updated Thermal Rating: on line 6374-6526 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 254
% INFO    : Updated Thermal Rating: on line 5917-4991 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1650
% INFO    : Updated Thermal Rating: on line 10228-6143 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2628
% INFO    : Updated Thermal Rating: on line 10228-796 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23331
% INFO    : Updated Thermal Rating: on line 3918-11974 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 673
% INFO    : Updated Thermal Rating: on line 11974-6374 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 347
% INFO    : Updated Thermal Rating: on line 5717-10972 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1302
% INFO    : Updated Thermal Rating: on line 10972-2009 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 816
% INFO    : Updated Thermal Rating: on line 13276-5893 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 612
% INFO    : Updated Thermal Rating: on line 8739-493 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 654
% INFO    : Updated Thermal Rating: on line 5506-493 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 513
% INFO    : Updated Thermal Rating: on line 10215-3221 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1053
% INFO    : Updated Thermal Rating: on line 2339-3835 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 243
% INFO    : Updated Thermal Rating: on line 2133-4979 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1390
% INFO    : Updated Thermal Rating: on line 4221-13241 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1574
% INFO    : Updated Thermal Rating: on line 13241-1874 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2185
% INFO    : Updated Thermal Rating: on line 13156-10666 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 346
% INFO    : Updated Thermal Rating: on line 13156-6788 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 401
% INFO    : Updated Thermal Rating: on line 46-3390 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 533
% INFO    : Updated Thermal Rating: on line 2640-5203 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 486
% INFO    : Updated Thermal Rating: on line 8054-3151 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 170
% INFO    : Updated Thermal Rating: on line 226-10695 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 240
% INFO    : Updated Thermal Rating: on line 4979-5113 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2498
% INFO    : Updated Thermal Rating: on line 5113-5774 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2943
% INFO    : Updated Thermal Rating: on line 6309-10396 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 565
% INFO    : Updated Thermal Rating: on line 3060-13156 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 256
% INFO    : Updated Thermal Rating: on line 3079-3069 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2891
% INFO    : Updated Thermal Rating: on line 4221-1874 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6071
% INFO    : Updated Thermal Rating: on line 4221-5379 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4801
% INFO    : Updated Thermal Rating: on line 4221-1678 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4891
% INFO    : Updated Thermal Rating: on line 5852-1708 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2977
% INFO    : Updated Thermal Rating: on line 4107-46 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 546
% INFO    : Updated Thermal Rating: on line 969-46 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1104
% INFO    : Updated Thermal Rating: on line 2346-8682 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 207
% INFO    : Updated Thermal Rating: on line 8790-138 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1199
% INFO    : Updated Thermal Rating: on line 138-12615 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 250
% INFO    : Updated Thermal Rating: on line 7941-1740 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 217
% INFO    : Updated Thermal Rating: on line 2228-1862 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3160
% INFO    : Updated Thermal Rating: on line 8102-421 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 232
% INFO    : Updated Thermal Rating: on line 9309-421 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 369
% INFO    : Updated Thermal Rating: on line 7153-796 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 30716
% INFO    : Updated Thermal Rating: on line 8093-4413 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 409
% INFO    : Updated Thermal Rating: on line 762-1466 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2471
% INFO    : Updated Thermal Rating: on line 1466-10958 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 385
% INFO    : Updated Thermal Rating: on line 3069-4712 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1795
% INFO    : Updated Thermal Rating: on line 2598-10184 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 50020
% INFO    : Updated Thermal Rating: on line 10920-9837 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 793
% INFO    : Updated Thermal Rating: on line 2888-9516 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4071
% INFO    : Updated Thermal Rating: on line 13185-13276 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 489
% INFO    : Updated Thermal Rating: on line 13185-13276 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 527
% INFO    : Updated Thermal Rating: on line 11101-13276 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 787
% INFO    : Updated Thermal Rating: on line 827-355 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2218
% INFO    : Updated Thermal Rating: on line 6848-11057 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 340
% INFO    : Updated Thermal Rating: on line 3676-1333 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 479
% INFO    : Updated Thermal Rating: on line 4413-5943 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 191
% INFO    : Updated Thermal Rating: on line 7337-12545 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2534
% INFO    : Updated Thermal Rating: on line 2888-620 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1377
% INFO    : Updated Thermal Rating: on line 13185-10692 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3153
% INFO    : Updated Thermal Rating: on line 3882-10692 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2150
% INFO    : Updated Thermal Rating: on line 8823-3882 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 881
% INFO    : Updated Thermal Rating: on line 5379-9375 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2875
% INFO    : Updated Thermal Rating: on line 1678-4712 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2825
% INFO    : Updated Thermal Rating: on line 950-3596 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2143
% INFO    : Updated Thermal Rating: on line 950-2747 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2185
% INFO    : Updated Thermal Rating: on line 12838-9543 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2312
% INFO    : Updated Thermal Rating: on line 12838-10574 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 544
% INFO    : Updated Thermal Rating: on line 12838-2219 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 729
% INFO    : Updated Thermal Rating: on line 12838-4516 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5143
% INFO    : Updated Thermal Rating: on line 7928-1603 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1117
% INFO    : Updated Thermal Rating: on line 1140-7928 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 621
% INFO    : Updated Thermal Rating: on line 2181-10574 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2923
% INFO    : Updated Thermal Rating: on line 2181-2857 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3120
% INFO    : Updated Thermal Rating: on line 1806-2225 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3592
% INFO    : Updated Thermal Rating: on line 1806-8041 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5745
% INFO    : Updated Thermal Rating: on line 6975-8723 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9222
% INFO    : Updated Thermal Rating: on line 6975-3222 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4558
% INFO    : Updated Thermal Rating: on line 6975-9267 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20838
% INFO    : Updated Thermal Rating: on line 4783-3764 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1581
% INFO    : Updated Thermal Rating: on line 4783-1094 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1414
% INFO    : Updated Thermal Rating: on line 4783-9469 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2140
% INFO    : Updated Thermal Rating: on line 6484-6678 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 838
% INFO    : Updated Thermal Rating: on line 6484-6129 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7592
% INFO    : Updated Thermal Rating: on line 9895-13180 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2547
% INFO    : Updated Thermal Rating: on line 9895-8041 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1782
% INFO    : Updated Thermal Rating: on line 7914-527 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2695
% INFO    : Updated Thermal Rating: on line 5808-210 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2685
% INFO    : Updated Thermal Rating: on line 5808-6533 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2069
% INFO    : Updated Thermal Rating: on line 5808-11908 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2756
% INFO    : Updated Thermal Rating: on line 1613-6185 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11579
% INFO    : Updated Thermal Rating: on line 1613-3591 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9422
% INFO    : Updated Thermal Rating: on line 2956-6173 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2763
% INFO    : Updated Thermal Rating: on line 2956-4399 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1385
% INFO    : Updated Thermal Rating: on line 6660-8723 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1397
% INFO    : Updated Thermal Rating: on line 6660-8723 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1235
% INFO    : Updated Thermal Rating: on line 6660-1001 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6268
% INFO    : Updated Thermal Rating: on line 6660-3110 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 471
% INFO    : Updated Thermal Rating: on line 10942-5115 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3906
% INFO    : Updated Thermal Rating: on line 10942-4782 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10104
% INFO    : Updated Thermal Rating: on line 10942-322 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15988
% INFO    : Updated Thermal Rating: on line 11260-3596 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1301
% INFO    : Updated Thermal Rating: on line 11260-3222 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1029
% INFO    : Updated Thermal Rating: on line 13548-2098 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2570
% INFO    : Updated Thermal Rating: on line 13548-7897 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3351
% INFO    : Updated Thermal Rating: on line 13548-1327 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2414
% INFO    : Updated Thermal Rating: on line 2873-1094 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2550
% INFO    : Updated Thermal Rating: on line 2873-2736 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 59909
% INFO    : Updated Thermal Rating: on line 2873-9543 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2865
% INFO    : Updated Thermal Rating: on line 13180-12939 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1241
% INFO    : Updated Thermal Rating: on line 13180-4782 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1867
% INFO    : Updated Thermal Rating: on line 10140-9424 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 457
% INFO    : Updated Thermal Rating: on line 10140-13286 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3069
% INFO    : Updated Thermal Rating: on line 10140-8505 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 519
% INFO    : Updated Thermal Rating: on line 10140-8505 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 509
% INFO    : Updated Thermal Rating: on line 10140-10574 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 748
% INFO    : Updated Thermal Rating: on line 10140-10574 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 764
% INFO    : Updated Thermal Rating: on line 10140-4525 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1142
% INFO    : Updated Thermal Rating: on line 10140-1527 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 933
% INFO    : Updated Thermal Rating: on line 2098-4975 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6187
% INFO    : Updated Thermal Rating: on line 2098-1160 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4748
% INFO    : Updated Thermal Rating: on line 7748-9424 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1025
% INFO    : Updated Thermal Rating: on line 7748-2219 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9180
% INFO    : Updated Thermal Rating: on line 4382-5115 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1330
% INFO    : Updated Thermal Rating: on line 4382-10861 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7678
% INFO    : Updated Thermal Rating: on line 4382-4399 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9627
% INFO    : Updated Thermal Rating: on line 4382-4399 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9457
% INFO    : Updated Thermal Rating: on line 4382-1194 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5475
% INFO    : Updated Thermal Rating: on line 8506-11417 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8326
% INFO    : Updated Thermal Rating: on line 8506-11016 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 632
% INFO    : Updated Thermal Rating: on line 8506-7646 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2861
% INFO    : Updated Thermal Rating: on line 8482-4525 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 974
% INFO    : Updated Thermal Rating: on line 8482-3267 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 885
% INFO    : Updated Thermal Rating: on line 5115-8041 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2502
% INFO    : Updated Thermal Rating: on line 5115-10861 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1376
% INFO    : Updated Thermal Rating: on line 5115-1194 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1479
% INFO    : Updated Thermal Rating: on line 3596-8723 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2214
% INFO    : Updated Thermal Rating: on line 3596-2747 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1174
% INFO    : Updated Thermal Rating: on line 3596-8422 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5654
% INFO    : Updated Thermal Rating: on line 3596-3243 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1861
% INFO    : Updated Thermal Rating: on line 3596-1992 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5963
% INFO    : Updated Thermal Rating: on line 3596-2290 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1544
% INFO    : Updated Thermal Rating: on line 3596-1327 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2248
% INFO    : Updated Thermal Rating: on line 217-11971 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 993
% INFO    : Updated Thermal Rating: on line 1603-10234 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1262
% INFO    : Updated Thermal Rating: on line 10234-217 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5581
% INFO    : Updated Thermal Rating: on line 3764-6185 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2496
% INFO    : Updated Thermal Rating: on line 7231-12939 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5512
% INFO    : Updated Thermal Rating: on line 7231-1638 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7038
% INFO    : Updated Thermal Rating: on line 4303-9424 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1896
% INFO    : Updated Thermal Rating: on line 4303-4525 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 387
% INFO    : Updated Thermal Rating: on line 4303-210 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13417
% INFO    : Updated Thermal Rating: on line 4303-210 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11907
% INFO    : Updated Thermal Rating: on line 2116-8695 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4997
% INFO    : Updated Thermal Rating: on line 2116-683 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1057
% INFO    : Updated Thermal Rating: on line 2116-11596 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12495
% INFO    : Updated Thermal Rating: on line 8695-9424 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2889
% INFO    : Updated Thermal Rating: on line 12322-6129 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 998
% INFO    : Updated Thermal Rating: on line 12322-6533 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3300
% INFO    : Updated Thermal Rating: on line 9424-7621 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1470
% INFO    : Updated Thermal Rating: on line 9424-7621 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on line 1378-6283 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3964
% INFO    : Updated Thermal Rating: on line 9824-6678 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3014
% INFO    : Updated Thermal Rating: on line 9824-6129 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1088
% INFO    : Updated Thermal Rating: on line 2966-1327 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 79720
% INFO    : Updated Thermal Rating: on line 8723-2747 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1420
% INFO    : Updated Thermal Rating: on line 10923-6375 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4336
% INFO    : Updated Thermal Rating: on line 10923-341 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1662
% INFO    : Updated Thermal Rating: on line 2971-2263 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2397
% INFO    : Updated Thermal Rating: on line 2971-4399 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7858
% INFO    : Updated Thermal Rating: on line 13286-9776 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4966
% INFO    : Updated Thermal Rating: on line 13286-5238 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 882
% INFO    : Updated Thermal Rating: on line 13286-5238 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 957
% INFO    : Updated Thermal Rating: on line 6678-8601 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4576
% INFO    : Updated Thermal Rating: on line 6678-8601 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4489
% INFO    : Updated Thermal Rating: on line 4441-8108 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3819
% INFO    : Updated Thermal Rating: on line 4441-5688 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1539
% INFO    : Updated Thermal Rating: on line 6283-5006 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10971
% INFO    : Updated Thermal Rating: on line 6283-4525 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4384
% INFO    : Updated Thermal Rating: on line 11563-8505 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2067
% INFO    : Updated Thermal Rating: on line 11563-192 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1019
% INFO    : Updated Thermal Rating: on line 2225-4782 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6022
% INFO    : Updated Thermal Rating: on line 2225-6173 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3217
% INFO    : Updated Thermal Rating: on line 2225-6173 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3229
% INFO    : Updated Thermal Rating: on line 5238-7897 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2013
% INFO    : Updated Thermal Rating: on line 5238-10574 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1174
% INFO    : Updated Thermal Rating: on line 5238-5688 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3323
% INFO    : Updated Thermal Rating: on line 5238-5501 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2063
% INFO    : Updated Thermal Rating: on line 2747-10574 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 843
% INFO    : Updated Thermal Rating: on line 2747-566 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 780
% INFO    : Updated Thermal Rating: on line 2747-5209 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1060
% INFO    : Updated Thermal Rating: on line 2747-5209 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1040
% INFO    : Updated Thermal Rating: on line 2747-3427 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1312
% INFO    : Updated Thermal Rating: on line 2747-3427 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1366
% INFO    : Updated Thermal Rating: on line 683-4525 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 667
% INFO    : Updated Thermal Rating: on line 1736-8505 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3223
% INFO    : Updated Thermal Rating: on line 1736-8505 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2976
% INFO    : Updated Thermal Rating: on line 1736-4375 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2339
% INFO    : Updated Thermal Rating: on line 1736-3670 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2524
% INFO    : Updated Thermal Rating: on line 3884-4525 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1810
% INFO    : Updated Thermal Rating: on line 3884-3267 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 665
% INFO    : Updated Thermal Rating: on line 2917-7646 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 58632
% INFO    : Updated Thermal Rating: on line 8505-10574 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 682
% INFO    : Updated Thermal Rating: on line 8505-13000 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1061
% INFO    : Updated Thermal Rating: on line 2736-5841 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1510
% INFO    : Updated Thermal Rating: on line 5006-4525 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6623
% INFO    : Updated Thermal Rating: on line 8108-852 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1497
% INFO    : Updated Thermal Rating: on line 4782-322 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9854
% INFO    : Updated Thermal Rating: on line 3568-4210 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 783
% INFO    : Updated Thermal Rating: on line 3568-852 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7678
% INFO    : Updated Thermal Rating: on line 3568-1527 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1406
% INFO    : Updated Thermal Rating: on line 1939-6173 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1266
% INFO    : Updated Thermal Rating: on line 9543-6185 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1687
% INFO    : Updated Thermal Rating: on line 4210-4525 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 806
% INFO    : Updated Thermal Rating: on line 192-10574 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4066
% INFO    : Updated Thermal Rating: on line 8399-9469 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1941
% INFO    : Updated Thermal Rating: on line 8399-9469 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1907
% INFO    : Updated Thermal Rating: on line 9469-5841 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1245
% INFO    : Updated Thermal Rating: on line 6503-9418 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 850
% INFO    : Updated Thermal Rating: on line 9418-6503 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 762
% INFO    : Updated Thermal Rating: on line 11661-6129 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1864
% INFO    : Updated Thermal Rating: on line 11661-6129 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1829
% INFO    : Updated Thermal Rating: on line 10574-7152 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2389
% INFO    : Updated Thermal Rating: on line 10574-7152 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2321
% INFO    : Updated Thermal Rating: on line 10574-5501 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2369
% INFO    : Updated Thermal Rating: on line 6375-10934 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1303
% INFO    : Updated Thermal Rating: on line 6375-7621 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1731
% INFO    : Updated Thermal Rating: on line 11335-2030 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2140
% INFO    : Updated Thermal Rating: on line 11335-3427 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3074
% INFO    : Updated Thermal Rating: on line 2030-11016 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8814
% INFO    : Updated Thermal Rating: on line 4525-527 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2219
% INFO    : Updated Thermal Rating: on line 4525-9022 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1571
% INFO    : Updated Thermal Rating: on line 4975-7152 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2302
% INFO    : Updated Thermal Rating: on line 7152-3222 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1253
% INFO    : Updated Thermal Rating: on line 7152-7036 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4365
% INFO    : Updated Thermal Rating: on line 1527-1160 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2796
% INFO    : Updated Thermal Rating: on line 8693-4269 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 47664
% INFO    : Updated Thermal Rating: on line 6185-3670 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1197
% INFO    : Updated Thermal Rating: on line 4831-4399 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1418
% INFO    : Updated Thermal Rating: on line 4831-4269 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5162
% INFO    : Updated Thermal Rating: on line 3222-9267 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5439
% INFO    : Updated Thermal Rating: on line 11596-3267 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1643
% INFO    : Updated Thermal Rating: on line 8422-3243 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2793
% INFO    : Updated Thermal Rating: on line 6000-4269 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3010
% INFO    : Updated Thermal Rating: on line 7078-1638 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1962
% INFO    : Updated Thermal Rating: on line 6129-10127 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4048
% INFO    : Updated Thermal Rating: on line 6129-4468 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1276
% INFO    : Updated Thermal Rating: on line 11417-9956 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1681
% INFO    : Updated Thermal Rating: on line 11016-9956 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1126
% INFO    : Updated Thermal Rating: on line 11016-3427 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1665
% INFO    : Updated Thermal Rating: on line 3267-4468 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3041
% INFO    : Updated Thermal Rating: on line 2857-1001 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3139
% INFO    : Updated Thermal Rating: on line 966-566 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2263
% INFO    : Updated Thermal Rating: on line 966-566 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1980
% INFO    : Updated Thermal Rating: on line 4399-2362 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2733
% INFO    : Updated Thermal Rating: on line 3110-1042 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5275
% INFO    : Updated Thermal Rating: on line 3110-1788 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2071
% INFO    : Updated Thermal Rating: on line 566-7646 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3562
% INFO    : Updated Thermal Rating: on line 1042-1788 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3558
% INFO    : Updated Thermal Rating: on line 1992-2073 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1200
% INFO    : Updated Thermal Rating: on line 341-4516 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3677
% INFO    : Updated Thermal Rating: on line 10127-8601 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 871
% INFO    : Updated Thermal Rating: on line 9022-13000 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3025
% INFO    : Updated Thermal Rating: on line 2073-3427 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1823
% INFO    : Updated Thermal Rating: on line 3427-2290 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1209
% INFO    : Updated Thermal Rating: on line 1032-11688 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10026
% INFO    : Updated Thermal Rating: on line 8878-13384 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2758
% INFO    : Updated Thermal Rating: on line 8878-13619 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4503
% INFO    : Updated Thermal Rating: on line 8878-553 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2078
% INFO    : Updated Thermal Rating: on line 13384-10332 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2128
% INFO    : Updated Thermal Rating: on line 13384-759 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2178
% INFO    : Updated Thermal Rating: on line 8895-12621 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 350
% INFO    : Updated Thermal Rating: on line 8895-8762 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 574
% INFO    : Updated Thermal Rating: on line 1854-5027 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1726
% INFO    : Updated Thermal Rating: on line 1854-8750 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3523
% INFO    : Updated Thermal Rating: on line 1854-10774 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3800
% INFO    : Updated Thermal Rating: on line 10332-11703 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4163
% INFO    : Updated Thermal Rating: on line 11703-4797 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1487
% INFO    : Updated Thermal Rating: on line 11703-6154 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5234
% INFO    : Updated Thermal Rating: on line 204-8187 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2130
% INFO    : Updated Thermal Rating: on line 8187-6169 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5269
% INFO    : Updated Thermal Rating: on line 553-5588 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5534
% INFO    : Updated Thermal Rating: on line 12621-4921 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1188
% INFO    : Updated Thermal Rating: on line 10332-3538 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3353
% INFO    : Updated Thermal Rating: on line 10332-553 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1726
% INFO    : Updated Thermal Rating: on line 8762-9318 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2077
% INFO    : Updated Thermal Rating: on line 8762-9318 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2110
% INFO    : Updated Thermal Rating: on line 8762-5288 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 401
% INFO    : Updated Thermal Rating: on line 8762-10391 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 550
% INFO    : Updated Thermal Rating: on line 8762-4921 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 372
% INFO    : Updated Thermal Rating: on line 10398-4797 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5683
% INFO    : Updated Thermal Rating: on line 10398-4797 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4423
% INFO    : Updated Thermal Rating: on line 10398-8750 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1189
% INFO    : Updated Thermal Rating: on line 3538-5767 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18794
% INFO    : Updated Thermal Rating: on line 3538-2967 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19133
% INFO    : Updated Thermal Rating: on line 8750-12186 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 67071
% INFO    : Updated Thermal Rating: on line 8750-1197 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 65679
% INFO    : Updated Thermal Rating: on line 9122-5945 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2903
% INFO    : Updated Thermal Rating: on line 8750-8520 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 43013
% INFO    : Updated Thermal Rating: on line 8750-7273 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52184
% INFO    : Updated Thermal Rating: on line 8750-2221 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 46891
% INFO    : Updated Thermal Rating: on line 8750-1035 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 47593
% INFO    : Updated Thermal Rating: on line 5288-821 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4377
% INFO    : Updated Thermal Rating: on line 5288-4951 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4436
% INFO    : Updated Thermal Rating: on line 553-10569 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 37435
% INFO    : Updated Thermal Rating: on line 553-7880 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 37784
% INFO    : Updated Thermal Rating: on line 553-11998 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 38703
% INFO    : Updated Thermal Rating: on line 4802-1729 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14635
% INFO    : Updated Thermal Rating: on line 204-5749 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10732
% INFO    : Updated Thermal Rating: on line 204-2952 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9468
% INFO    : Updated Thermal Rating: on line 5211-5997 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2262
% INFO    : Updated Thermal Rating: on line 5211-3723 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2220
% INFO    : Updated Thermal Rating: on line 4797-4280 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 72079
% INFO    : Updated Thermal Rating: on line 4797-1634 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 69424
% INFO    : Updated Thermal Rating: on line 5211-2938 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4621
% INFO    : Updated Thermal Rating: on line 4802-6463 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 40168
% INFO    : Updated Thermal Rating: on line 4802-2293 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 41134
% INFO    : Updated Thermal Rating: on line 5027-4802 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 647
% INFO    : Updated Thermal Rating: on line 4802-8574 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12207
% INFO    : Updated Thermal Rating: on line 4802-553 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3612
% INFO    : Updated Thermal Rating: on line 436-5211 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 578
% INFO    : Updated Thermal Rating: on line 436-10221 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2976
% INFO    : Updated Thermal Rating: on line 436-5211 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 589
% INFO    : Updated Thermal Rating: on line 436-4921 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1649
% INFO    : Updated Thermal Rating: on line 204-6154 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1269
% INFO    : Updated Thermal Rating: on line 3374-9122 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1489
% INFO    : Updated Thermal Rating: on line 3374-11688 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1846
% INFO    : Updated Thermal Rating: on line 4797-6169 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1534
% INFO    : Updated Thermal Rating: on line 4797-6154 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1626
% INFO    : Updated Thermal Rating: on line 9122-759 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1869
% INFO    : Updated Thermal Rating: on line 9122-12785 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1681
% INFO    : Updated Thermal Rating: on line 9122-3538 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1435
% INFO    : Updated Thermal Rating: on line 7738-4872 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 540
% INFO    : Updated Thermal Rating: on line 7738-4872 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 551
% INFO    : Updated Thermal Rating: on line 5288-291 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 592
% INFO    : Updated Thermal Rating: on line 5288-7312 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 554
% INFO    : Updated Thermal Rating: on line 11688-12785 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1932
% INFO    : Updated Thermal Rating: on line 10391-3721 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 250
% INFO    : Updated Thermal Rating: on line 4306-12785 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3976
% INFO    : Updated Thermal Rating: on line 4306-10774 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1825
% INFO    : Updated Thermal Rating: on line 291-5211 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 444
% INFO    : Updated Thermal Rating: on line 291-5211 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 453
% INFO    : Updated Thermal Rating: on line 12785-6154 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 488
% INFO    : Updated Thermal Rating: on line 4872-3721 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 460
% INFO    : Updated Thermal Rating: on line 4872-3721 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 470
% INFO    : Updated Thermal Rating: on line 8750-10774 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3280
% INFO    : Updated Thermal Rating: on line 8750-10774 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3473
% INFO    : Updated Thermal Rating: on line 3721-7312 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 205
% INFO    : Updated Thermal Rating: on line 718-10221 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10571
% INFO    : Updated Thermal Rating: on line 10221-4921 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3350
% INFO    : Updated Thermal Rating: on line 5531-13443 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18210
% INFO    : Updated Thermal Rating: on line 439-13443 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11213
% INFO    : Updated Thermal Rating: on line 3806-7655 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7266
% INFO    : Updated Thermal Rating: on line 3806-10208 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7122
% INFO    : Updated Thermal Rating: on line 5531-3806 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7209
% INFO    : Updated Thermal Rating: on line 7655-8407 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 77598
% INFO    : Updated Thermal Rating: on line 10208-12057 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 77598
% INFO    : Updated Thermal Rating: on line 1167-8407 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3711
% INFO    : Updated Thermal Rating: on line 1167-12057 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3308
% INFO    : Updated Thermal Rating: on line 5531-10545 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18617
% INFO    : Updated Thermal Rating: on line 9099-11009 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 9099-11009 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 263
% INFO    : Updated Thermal Rating: on line 13629-9099 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 9099-8267 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 9099-4147 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 11448-9099 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 2359-9099 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 8608-9099 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12
% INFO    : Updated Thermal Rating: on line 4055-9099 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12
% INFO    : Updated Thermal Rating: on line 8156-9099 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on line 6030-9099 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on line 917-9099 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 4995-9099 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 9099-12407 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 12043-9099 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23
% INFO    : Updated Thermal Rating: on line 9823-9099 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 49
% INFO    : Updated Thermal Rating: on line 6896-9099 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26
% INFO    : Updated Thermal Rating: on line 10979-9099 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 28
% INFO    : Updated Thermal Rating: on line 1535-9099 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 5183-9099 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 34
% INFO    : Updated Thermal Rating: on line 7916-9099 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16
% INFO    : Updated Thermal Rating: on line 3743-9099 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15
% INFO    : Updated Thermal Rating: on line 4717-9099 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16
% INFO    : Updated Thermal Rating: on line 4717-9099 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 559
% INFO    : Updated Thermal Rating: on line 9099-2256 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11
% INFO    : Updated Thermal Rating: on line 9099-2256 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 762
% INFO    : Updated Thermal Rating: on line 7691-9099 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 6065-9099 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 13629-11009 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 11009-8267 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 11009-4147 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 11448-11009 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 2359-11009 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 8608-11009 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on line 4055-11009 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on line 8156-11009 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 6030-11009 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 917-11009 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 4995-11009 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 11009-12407 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 12043-11009 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12
% INFO    : Updated Thermal Rating: on line 9823-11009 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23
% INFO    : Updated Thermal Rating: on line 6896-11009 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15
% INFO    : Updated Thermal Rating: on line 10979-11009 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13
% INFO    : Updated Thermal Rating: on line 5183-11009 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17
% INFO    : Updated Thermal Rating: on line 7916-11009 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8
% INFO    : Updated Thermal Rating: on line 3743-11009 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on line 4717-11009 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on line 11009-2256 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 821
% INFO    : Updated Thermal Rating: on line 11009-2256 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5
% INFO    : Updated Thermal Rating: on line 7691-11009 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 6065-11009 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 7867-6362 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5671
% INFO    : Updated Thermal Rating: on line 7867-8653 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2689
% INFO    : Updated Thermal Rating: on line 9172-6362 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5021
% INFO    : Updated Thermal Rating: on line 9172-8653 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2747
% INFO    : Updated Thermal Rating: on line 7867-9172 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142
% INFO    : Updated Thermal Rating: on line 7867-6362 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 51
% INFO    : Updated Thermal Rating: on line 7867-8653 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 53
% INFO    : Updated Thermal Rating: on line 478-7867 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22
% INFO    : Updated Thermal Rating: on line 9172-6362 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 50
% INFO    : Updated Thermal Rating: on line 9172-8653 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 51
% INFO    : Updated Thermal Rating: on line 478-9172 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22
% INFO    : Updated Thermal Rating: on line 6587-5003 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6768
% INFO    : Updated Thermal Rating: on line 6587-2275 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8250
% INFO    : Updated Thermal Rating: on line 9153-11186 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6913
% INFO    : Updated Thermal Rating: on line 9153-5003 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 105
% INFO    : Updated Thermal Rating: on line 9153-11186 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 103
% INFO    : Updated Thermal Rating: on line 9153-9673 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8425
% INFO    : Updated Thermal Rating: on line 6562-880 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9212
% INFO    : Updated Thermal Rating: on line 5912-6562 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1918
% INFO    : Updated Thermal Rating: on line 707-9072 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 707-9072 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 232
% INFO    : Updated Thermal Rating: on line 707-11302 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on line 707-9140 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1474
% INFO    : Updated Thermal Rating: on line 707-7014 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 707-12720 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 707-9401 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11
% INFO    : Updated Thermal Rating: on line 707-1566 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 84
% INFO    : Updated Thermal Rating: on line 707-5754 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 66
% INFO    : Updated Thermal Rating: on line 707-5754 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 763
% INFO    : Updated Thermal Rating: on line 9072-11302 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8
% INFO    : Updated Thermal Rating: on line 9072-141 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1803
% INFO    : Updated Thermal Rating: on line 9072-7014 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 9072-12720 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 9072-9401 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12
% INFO    : Updated Thermal Rating: on line 9072-1566 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 79
% INFO    : Updated Thermal Rating: on line 9072-1566 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 749
% INFO    : Updated Thermal Rating: on line 9072-5754 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 73
% INFO    : Updated Thermal Rating: on line 5482-11721 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7205
% INFO    : Updated Thermal Rating: on line 3229-11721 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4403
% INFO    : Updated Thermal Rating: on line 4798-8075 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7697
% INFO    : Updated Thermal Rating: on line 5993-8075 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6564
% INFO    : Updated Thermal Rating: on line 6510-5482 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 29
% INFO    : Updated Thermal Rating: on line 3603-5482 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27
% INFO    : Updated Thermal Rating: on line 1665-5482 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 91
% INFO    : Updated Thermal Rating: on line 4490-5482 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16
% INFO    : Updated Thermal Rating: on line 2872-5482 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14476
% INFO    : Updated Thermal Rating: on line 7278-5482 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 116
% INFO    : Updated Thermal Rating: on line 13017-5482 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on line 10335-12622 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13
% INFO    : Updated Thermal Rating: on line 10335-272 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15
% INFO    : Updated Thermal Rating: on line 10335-4883 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15
% INFO    : Updated Thermal Rating: on line 7997-10335 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on line 10335-6414 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5
% INFO    : Updated Thermal Rating: on line 10335-12406 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4399
% INFO    : Updated Thermal Rating: on line 10335-12406 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10
% INFO    : Updated Thermal Rating: on line 10335-8314 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10
% INFO    : Updated Thermal Rating: on line 10335-9085 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on line 10335-6868 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2389
% INFO    : Updated Thermal Rating: on line 10335-13020 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2343
% INFO    : Updated Thermal Rating: on line 10335-8314 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4482
% INFO    : Updated Thermal Rating: on line 5899-1467 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24
% INFO    : Updated Thermal Rating: on line 5899-1467 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 629
% INFO    : Updated Thermal Rating: on line 5899-5005 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20
% INFO    : Updated Thermal Rating: on line 5899-5923 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 5899-1752 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 656
% INFO    : Updated Thermal Rating: on line 5899-1752 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 5899-644 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21
% INFO    : Updated Thermal Rating: on line 5899-2726 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22
% INFO    : Updated Thermal Rating: on line 5899-418 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2329
% INFO    : Updated Thermal Rating: on line 5899-5344 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 28
% INFO    : Updated Thermal Rating: on line 5899-2264 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on line 5899-4342 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on line 5899-1684 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on line 5899-5005 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 638
% INFO    : Updated Thermal Rating: on line 5899-5923 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 669
% INFO    : Updated Thermal Rating: on line 5899-8634 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2074
% INFO    : Updated Thermal Rating: on line 7074-11117 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6016
% INFO    : Updated Thermal Rating: on line 7074-1752 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1020
% INFO    : Updated Thermal Rating: on line 11117-2637 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12843
% INFO    : Updated Thermal Rating: on line 6964-549 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6108
% INFO    : Updated Thermal Rating: on line 6964-644 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3283
% INFO    : Updated Thermal Rating: on line 549-2637 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13061
% INFO    : Updated Thermal Rating: on line 12866-6188 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17899
% INFO    : Updated Thermal Rating: on line 12866-6188 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17601
% INFO    : Updated Thermal Rating: on line 10280-1533 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16638
% INFO    : Updated Thermal Rating: on line 10280-10514 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16976
% INFO    : Updated Thermal Rating: on line 1533-2174 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9124
% INFO    : Updated Thermal Rating: on line 10514-8313 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9308
% INFO    : Updated Thermal Rating: on line 10280-13454 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11473
% INFO    : Updated Thermal Rating: on line 10280-1771 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7170
% INFO    : Updated Thermal Rating: on line 10280-9732 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11273
% INFO    : Updated Thermal Rating: on line 7699-3986 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4077
% INFO    : Updated Thermal Rating: on line 7699-3746 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1405
% INFO    : Updated Thermal Rating: on line 7699-5547 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16692
% INFO    : Updated Thermal Rating: on line 7699-3746 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1521
% INFO    : Updated Thermal Rating: on line 7699-5547 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17008
% INFO    : Updated Thermal Rating: on line 376-6032 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on line 376-6510 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6113
% INFO    : Updated Thermal Rating: on line 376-3603 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 64
% INFO    : Updated Thermal Rating: on line 376-2174 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on line 7131-376 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on line 13017-376 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 376-6550 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on line 964-376 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13
% INFO    : Updated Thermal Rating: on line 1651-376 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3321
% INFO    : Updated Thermal Rating: on line 13282-376 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 41
% INFO    : Updated Thermal Rating: on line 6032-3603 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 63
% INFO    : Updated Thermal Rating: on line 6032-3603 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6244
% INFO    : Updated Thermal Rating: on line 6032-2174 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on line 7131-6032 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on line 13017-6032 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 6032-13432 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14022
% INFO    : Updated Thermal Rating: on line 6032-6550 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on line 964-6032 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14
% INFO    : Updated Thermal Rating: on line 13282-6032 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 40
% INFO    : Updated Thermal Rating: on line 11793-2977 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1867
% INFO    : Updated Thermal Rating: on line 385-8316 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1624
% INFO    : Updated Thermal Rating: on line 385-12536 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4059
% INFO    : Updated Thermal Rating: on line 8316-10603 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5991
% INFO    : Updated Thermal Rating: on line 12536-2935 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3984
% INFO    : Updated Thermal Rating: on line 2935-3932 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1406
% INFO    : Updated Thermal Rating: on line 6510-3603 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 6510-3603 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 138
% INFO    : Updated Thermal Rating: on line 1665-6510 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 36
% INFO    : Updated Thermal Rating: on line 4490-6510 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 40
% INFO    : Updated Thermal Rating: on line 2872-6510 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2465
% INFO    : Updated Thermal Rating: on line 7278-6510 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 36
% INFO    : Updated Thermal Rating: on line 13017-6510 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4757
% INFO    : Updated Thermal Rating: on line 13017-6510 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10
% INFO    : Updated Thermal Rating: on line 2897-6510 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9373
% INFO    : Updated Thermal Rating: on line 1665-3603 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 33
% INFO    : Updated Thermal Rating: on line 4490-3603 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 38
% INFO    : Updated Thermal Rating: on line 3603-2174 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 7278-3603 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 34
% INFO    : Updated Thermal Rating: on line 7278-3603 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2509
% INFO    : Updated Thermal Rating: on line 7131-3603 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 13017-3603 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 13017-3603 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11
% INFO    : Updated Thermal Rating: on line 13017-3603 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4857
% INFO    : Updated Thermal Rating: on line 6550-3603 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 964-3603 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on line 1670-3603 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9218
% INFO    : Updated Thermal Rating: on line 13282-3603 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17
% INFO    : Updated Thermal Rating: on line 260-4180 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 80
% INFO    : Updated Thermal Rating: on line 260-3119 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3554
% INFO    : Updated Thermal Rating: on line 2774-4180 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 170
% INFO    : Updated Thermal Rating: on line 2774-3119 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3610
% INFO    : Updated Thermal Rating: on line 5912-10382 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 89920
% INFO    : Updated Thermal Rating: on line 5912-6823 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 66966
% INFO    : Updated Thermal Rating: on line 11448-11302 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 2359-11302 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 366-11302 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 11302-1535 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 11302-1535 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 710
% INFO    : Updated Thermal Rating: on line 7014-11302 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on line 12720-11302 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on line 11302-9401 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 154
% INFO    : Updated Thermal Rating: on line 1566-11302 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19
% INFO    : Updated Thermal Rating: on line 5754-11302 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17
% INFO    : Updated Thermal Rating: on line 11302-9401 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11515
% INFO    : Updated Thermal Rating: on line 272-12622 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8
% INFO    : Updated Thermal Rating: on line 4883-12622 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on line 7997-12622 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 12622-6414 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 12406-12622 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24
% INFO    : Updated Thermal Rating: on line 8314-12622 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24
% INFO    : Updated Thermal Rating: on line 9085-12622 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 12866-12622 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14910
% INFO    : Updated Thermal Rating: on line 12866-12622 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15262
% INFO    : Updated Thermal Rating: on line 11263-5667 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17789
% INFO    : Updated Thermal Rating: on line 9820-7765 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 745
% INFO    : Updated Thermal Rating: on line 9820-7765 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 38
% INFO    : Updated Thermal Rating: on line 9820-7765 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 760
% INFO    : Updated Thermal Rating: on line 7733-7765 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5
% INFO    : Updated Thermal Rating: on line 3193-7765 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on line 7765-6386 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15
% INFO    : Updated Thermal Rating: on line 11447-9820 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2337
% INFO    : Updated Thermal Rating: on line 945-11447 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4898
% INFO    : Updated Thermal Rating: on line 10905-9820 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2388
% INFO    : Updated Thermal Rating: on line 945-10905 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4809
% INFO    : Updated Thermal Rating: on line 13354-9636 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 90
% INFO    : Updated Thermal Rating: on line 9506-9636 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on line 1172-9636 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10
% INFO    : Updated Thermal Rating: on line 9636-5569 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on line 9636-8176 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8
% INFO    : Updated Thermal Rating: on line 6825-9636 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 10957-9636 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23
% INFO    : Updated Thermal Rating: on line 9636-5569 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3180
% INFO    : Updated Thermal Rating: on line 10957-9636 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4769
% INFO    : Updated Thermal Rating: on line 6570-9636 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4977
% INFO    : Updated Thermal Rating: on line 9506-13354 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on line 1172-13354 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11
% INFO    : Updated Thermal Rating: on line 13354-8176 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3745
% INFO    : Updated Thermal Rating: on line 13354-5569 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10
% INFO    : Updated Thermal Rating: on line 13354-8176 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9
% INFO    : Updated Thermal Rating: on line 6825-13354 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 10957-13354 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26
% INFO    : Updated Thermal Rating: on line 7733-9820 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 737
% INFO    : Updated Thermal Rating: on line 7733-9820 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24
% INFO    : Updated Thermal Rating: on line 3193-9820 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26
% INFO    : Updated Thermal Rating: on line 9820-10603 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1403
% INFO    : Updated Thermal Rating: on line 9820-6386 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 71
% INFO    : Updated Thermal Rating: on line 3193-9820 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 753
% INFO    : Updated Thermal Rating: on line 9820-6102 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1378
% INFO    : Updated Thermal Rating: on line 13306-9820 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1687
% INFO    : Updated Thermal Rating: on line 11905-2741 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12855
% INFO    : Updated Thermal Rating: on line 11905-2741 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13867
% INFO    : Updated Thermal Rating: on line 7915-5569 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15058
% INFO    : Updated Thermal Rating: on line 3170-8176 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14783
% INFO    : Updated Thermal Rating: on line 9863-622 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12578
% INFO    : Updated Thermal Rating: on line 9506-1172 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11
% INFO    : Updated Thermal Rating: on line 6825-9506 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 105
% INFO    : Updated Thermal Rating: on line 8391-9506 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12827
% INFO    : Updated Thermal Rating: on line 9506-10957 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on line 687-4490 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2191
% INFO    : Updated Thermal Rating: on line 687-1550 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17313
% INFO    : Updated Thermal Rating: on line 10313-4490 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2150
% INFO    : Updated Thermal Rating: on line 10313-10000 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17600
% INFO    : Updated Thermal Rating: on line 1665-4798 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8165
% INFO    : Updated Thermal Rating: on line 1665-4307 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7779
% INFO    : Updated Thermal Rating: on line 7278-4307 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13310
% INFO    : Updated Thermal Rating: on line 1665-4490 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13
% INFO    : Updated Thermal Rating: on line 7278-1665 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 62
% INFO    : Updated Thermal Rating: on line 13017-1665 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on line 12197-4490 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4540
% INFO    : Updated Thermal Rating: on line 13017-12197 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21012
% INFO    : Updated Thermal Rating: on line 13536-4490 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4637
% INFO    : Updated Thermal Rating: on line 13017-13536 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21581
% INFO    : Updated Thermal Rating: on line 7278-4490 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19
% INFO    : Updated Thermal Rating: on line 13017-4490 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 115
% INFO    : Updated Thermal Rating: on line 7162-906 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21883
% INFO    : Updated Thermal Rating: on line 12866-7162 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24427
% INFO    : Updated Thermal Rating: on line 2272-9667 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23684
% INFO    : Updated Thermal Rating: on line 12866-2272 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23875
% INFO    : Updated Thermal Rating: on line 906-6344 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4653
% INFO    : Updated Thermal Rating: on line 9667-3353 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4749
% INFO    : Updated Thermal Rating: on line 6362-6344 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13350
% INFO    : Updated Thermal Rating: on line 6362-3353 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14381
% INFO    : Updated Thermal Rating: on line 1758-13213 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4124
% INFO    : Updated Thermal Rating: on line 13213-9140 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5547
% INFO    : Updated Thermal Rating: on line 1758-10921 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4206
% INFO    : Updated Thermal Rating: on line 10921-141 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6552
% INFO    : Updated Thermal Rating: on line 1758-2554 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4296
% INFO    : Updated Thermal Rating: on line 2554-9140 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6224
% INFO    : Updated Thermal Rating: on line 13213-10921 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 87
% INFO    : Updated Thermal Rating: on line 1758-13213 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 39
% INFO    : Updated Thermal Rating: on line 13213-9140 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 34
% INFO    : Updated Thermal Rating: on line 13213-141 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 50
% INFO    : Updated Thermal Rating: on line 1758-10921 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 36
% INFO    : Updated Thermal Rating: on line 10921-9140 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 35
% INFO    : Updated Thermal Rating: on line 10921-141 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 47
% INFO    : Updated Thermal Rating: on line 6362-5353 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14974
% INFO    : Updated Thermal Rating: on line 5353-9567 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5136
% INFO    : Updated Thermal Rating: on line 10699-8993 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4966
% INFO    : Updated Thermal Rating: on line 8993-2264 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3211
% INFO    : Updated Thermal Rating: on line 6362-2342 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2301
% INFO    : Updated Thermal Rating: on line 2342-722 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2435
% INFO    : Updated Thermal Rating: on line 6362-8975 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2259
% INFO    : Updated Thermal Rating: on line 8975-11650 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2488
% INFO    : Updated Thermal Rating: on line 6362-8653 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27
% INFO    : Updated Thermal Rating: on line 478-6362 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 44
% INFO    : Updated Thermal Rating: on line 6362-866 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6270
% INFO    : Updated Thermal Rating: on line 7322-6362 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12639
% INFO    : Updated Thermal Rating: on line 6362-3429 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6152
% INFO    : Updated Thermal Rating: on line 1167-3932 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 701
% INFO    : Updated Thermal Rating: on line 1167-3932 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 689
% INFO    : Updated Thermal Rating: on line 10699-556 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14904
% INFO    : Updated Thermal Rating: on line 439-556 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10591
% INFO    : Updated Thermal Rating: on line 9732-10899 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3974
% INFO    : Updated Thermal Rating: on line 13454-2749 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4055
% INFO    : Updated Thermal Rating: on line 8313-6380 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4439
% INFO    : Updated Thermal Rating: on line 2174-2648 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4540
% INFO    : Updated Thermal Rating: on line 7131-2174 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17
% INFO    : Updated Thermal Rating: on line 13017-2174 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 6550-2174 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 68
% INFO    : Updated Thermal Rating: on line 964-2174 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 39
% INFO    : Updated Thermal Rating: on line 13282-2174 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24
% INFO    : Updated Thermal Rating: on line 7767-4900 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25805
% INFO    : Updated Thermal Rating: on line 11732-4900 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14203
% INFO    : Updated Thermal Rating: on line 131-10838 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 131-8035 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 5912-131 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4742
% INFO    : Updated Thermal Rating: on line 11812-131 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on line 12474-131 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22
% INFO    : Updated Thermal Rating: on line 91-131 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11
% INFO    : Updated Thermal Rating: on line 11732-131 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52
% INFO    : Updated Thermal Rating: on line 12274-131 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on line 3895-131 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26
% INFO    : Updated Thermal Rating: on line 1789-131 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 919-131 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3995
% INFO    : Updated Thermal Rating: on line 1747-2648 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17527
% INFO    : Updated Thermal Rating: on line 6550-6380 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17922
% INFO    : Updated Thermal Rating: on line 7454-5003 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7627
% INFO    : Updated Thermal Rating: on line 2586-11186 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7793
% INFO    : Updated Thermal Rating: on line 5003-11186 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 128
% INFO    : Updated Thermal Rating: on line 7733-3193 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 7733-3193 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 109
% INFO    : Updated Thermal Rating: on line 7733-5496 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 39724
% INFO    : Updated Thermal Rating: on line 7733-6386 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 43
% INFO    : Updated Thermal Rating: on line 3193-6386 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 41
% INFO    : Updated Thermal Rating: on line 752-10995 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 28598
% INFO    : Updated Thermal Rating: on line 7211-752 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6115
% INFO    : Updated Thermal Rating: on line 2739-2055 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 30821
% INFO    : Updated Thermal Rating: on line 3504-2739 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6257
% INFO    : Updated Thermal Rating: on line 8269-5671 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7893
% INFO    : Updated Thermal Rating: on line 10838-8269 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 30551
% INFO    : Updated Thermal Rating: on line 5671-7845 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13619
% INFO    : Updated Thermal Rating: on line 7845-3052 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 38340
% INFO    : Updated Thermal Rating: on line 3052-4721 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15513
% INFO    : Updated Thermal Rating: on line 4721-8765 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 87440
% INFO    : Updated Thermal Rating: on line 91-8765 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4111
% INFO    : Updated Thermal Rating: on line 10838-8035 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 10838-8035 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 73
% INFO    : Updated Thermal Rating: on line 11812-10838 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 12474-10838 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 91-10838 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19
% INFO    : Updated Thermal Rating: on line 11732-10838 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on line 10349-10838 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 12274-10838 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 3895-10838 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on line 1789-10838 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 32
% INFO    : Updated Thermal Rating: on line 11812-8035 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 12474-8035 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 91-8035 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17
% INFO    : Updated Thermal Rating: on line 11732-8035 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on line 10349-8035 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 12274-8035 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 3895-8035 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on line 1789-8035 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3685
% INFO    : Updated Thermal Rating: on line 1789-8035 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 30
% INFO    : Updated Thermal Rating: on line 8888-8653 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21235
% INFO    : Updated Thermal Rating: on line 699-8653 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18849
% INFO    : Updated Thermal Rating: on line 478-8653 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20
% INFO    : Updated Thermal Rating: on line 9465-2160 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1658
% INFO    : Updated Thermal Rating: on line 6102-9465 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5335
% INFO    : Updated Thermal Rating: on line 2160-3932 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1434
% INFO    : Updated Thermal Rating: on line 3775-9492 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9748
% INFO    : Updated Thermal Rating: on line 3775-9492 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9572
% INFO    : Updated Thermal Rating: on line 272-6868 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 48391
% INFO    : Updated Thermal Rating: on line 6868-2257 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8337
% INFO    : Updated Thermal Rating: on line 4883-13020 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 47664
% INFO    : Updated Thermal Rating: on line 13020-4997 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8516
% INFO    : Updated Thermal Rating: on line 272-4883 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 45
% INFO    : Updated Thermal Rating: on line 7997-272 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 272-6414 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 272-12406 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9
% INFO    : Updated Thermal Rating: on line 272-8314 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8
% INFO    : Updated Thermal Rating: on line 9085-272 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 7997-4883 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 4883-6414 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 4883-12406 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9
% INFO    : Updated Thermal Rating: on line 4883-8314 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9
% INFO    : Updated Thermal Rating: on line 9085-4883 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 1467-5005 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 1467-5005 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 165
% INFO    : Updated Thermal Rating: on line 1467-5923 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 1467-1752 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 1467-644 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9
% INFO    : Updated Thermal Rating: on line 1467-2726 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10
% INFO    : Updated Thermal Rating: on line 5344-1467 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 32
% INFO    : Updated Thermal Rating: on line 1467-2264 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 4342-1467 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 1684-1467 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 5005-5923 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 5005-1752 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 5005-644 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8
% INFO    : Updated Thermal Rating: on line 5005-2726 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8
% INFO    : Updated Thermal Rating: on line 5344-5005 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 31
% INFO    : Updated Thermal Rating: on line 5005-2264 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 4342-5005 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 1684-5005 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 11272-2055 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 149739
% INFO    : Updated Thermal Rating: on line 11272-4941 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11943
% INFO    : Updated Thermal Rating: on line 4767-10995 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 136820
% INFO    : Updated Thermal Rating: on line 4767-10496 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11727
% INFO    : Updated Thermal Rating: on line 1758-9140 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 48
% INFO    : Updated Thermal Rating: on line 1758-141 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 72
% INFO    : Updated Thermal Rating: on line 2019-3464 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 149
% INFO    : Updated Thermal Rating: on line 3498-3464 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9499
% INFO    : Updated Thermal Rating: on line 6250-3464 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10271
% INFO    : Updated Thermal Rating: on line 1172-353 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3148
% INFO    : Updated Thermal Rating: on line 1172-3252 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5636
% INFO    : Updated Thermal Rating: on line 1172-5569 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 1172-8176 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 6825-1172 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8
% INFO    : Updated Thermal Rating: on line 12961-1172 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9859
% INFO    : Updated Thermal Rating: on line 10957-1172 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 61
% INFO    : Updated Thermal Rating: on line 1172-13309 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3215
% INFO    : Updated Thermal Rating: on line 13441-13309 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4888
% INFO    : Updated Thermal Rating: on line 6598-353 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4801
% INFO    : Updated Thermal Rating: on line 2872-7278 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 147
% INFO    : Updated Thermal Rating: on line 2872-2019 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3446
% INFO    : Updated Thermal Rating: on line 7278-9595 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3487
% INFO    : Updated Thermal Rating: on line 13017-7278 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on line 1550-797 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14241
% INFO    : Updated Thermal Rating: on line 2019-1550 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8845
% INFO    : Updated Thermal Rating: on line 1550-1649 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 42870
% INFO    : Updated Thermal Rating: on line 10000-880 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13933
% INFO    : Updated Thermal Rating: on line 12309-10000 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8539
% INFO    : Updated Thermal Rating: on line 10000-10400 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8124
% INFO    : Updated Thermal Rating: on line 9140-141 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 123
% INFO    : Updated Thermal Rating: on line 4180-3119 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7910
% INFO    : Updated Thermal Rating: on line 4180-11169 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5429
% INFO    : Updated Thermal Rating: on line 4262-9176 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5523
% INFO    : Updated Thermal Rating: on line 3119-9176 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7760
% INFO    : Updated Thermal Rating: on line 13017-7131 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 100
% INFO    : Updated Thermal Rating: on line 7131-4762 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6081
% INFO    : Updated Thermal Rating: on line 7131-6550 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14
% INFO    : Updated Thermal Rating: on line 7131-964 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 54
% INFO    : Updated Thermal Rating: on line 7131-13282 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26
% INFO    : Updated Thermal Rating: on line 439-10545 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12118
% INFO    : Updated Thermal Rating: on line 3025-5912 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 47664
% INFO    : Updated Thermal Rating: on line 5912-797 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1636
% INFO    : Updated Thermal Rating: on line 5912-12274 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2016
% INFO    : Updated Thermal Rating: on line 5912-2741 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5824
% INFO    : Updated Thermal Rating: on line 5912-12274 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1978
% INFO    : Updated Thermal Rating: on line 5912-9744 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3690
% INFO    : Updated Thermal Rating: on line 3025-4398 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18500
% INFO    : Updated Thermal Rating: on line 11824-7454 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4121
% INFO    : Updated Thermal Rating: on line 11824-722 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6691
% INFO    : Updated Thermal Rating: on line 8922-2586 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4202
% INFO    : Updated Thermal Rating: on line 8922-11650 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6833
% INFO    : Updated Thermal Rating: on line 7454-2586 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 7454-2586 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 139
% INFO    : Updated Thermal Rating: on line 7454-5380 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 92545
% INFO    : Updated Thermal Rating: on line 964-7454 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6272
% INFO    : Updated Thermal Rating: on line 5939-2586 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6388
% INFO    : Updated Thermal Rating: on line 357-1752 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1041
% INFO    : Updated Thermal Rating: on line 357-644 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3346
% INFO    : Updated Thermal Rating: on line 4507-3773 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3989
% INFO    : Updated Thermal Rating: on line 4507-10991 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1814
% INFO    : Updated Thermal Rating: on line 6740-1645 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3558
% INFO    : Updated Thermal Rating: on line 6740-9023 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1849
% INFO    : Updated Thermal Rating: on line 12951-11169 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1256
% INFO    : Updated Thermal Rating: on line 1696-4262 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 1696-4262 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5136
% INFO    : Updated Thermal Rating: on line 12951-1696 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1185
% INFO    : Updated Thermal Rating: on line 1752-8468 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10874
% INFO    : Updated Thermal Rating: on line 1752-8468 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10702
% INFO    : Updated Thermal Rating: on line 5923-1752 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 5923-1752 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 168
% INFO    : Updated Thermal Rating: on line 5923-644 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11
% INFO    : Updated Thermal Rating: on line 5923-2726 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11
% INFO    : Updated Thermal Rating: on line 5344-5923 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 5923-2264 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 74
% INFO    : Updated Thermal Rating: on line 4342-5923 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 783
% INFO    : Updated Thermal Rating: on line 4342-5923 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13
% INFO    : Updated Thermal Rating: on line 1684-5923 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15
% INFO    : Updated Thermal Rating: on line 5923-2801 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15063
% INFO    : Updated Thermal Rating: on line 1752-644 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10
% INFO    : Updated Thermal Rating: on line 1752-2726 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12
% INFO    : Updated Thermal Rating: on line 5344-1752 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on line 1752-2264 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 75
% INFO    : Updated Thermal Rating: on line 4342-1752 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14
% INFO    : Updated Thermal Rating: on line 1684-1752 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 769
% INFO    : Updated Thermal Rating: on line 1684-1752 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16
% INFO    : Updated Thermal Rating: on line 1752-2772 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14789
% INFO    : Updated Thermal Rating: on line 3773-1645 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 99
% INFO    : Updated Thermal Rating: on line 4860-3773 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 56
% INFO    : Updated Thermal Rating: on line 4860-1645 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 72
% INFO    : Updated Thermal Rating: on line 2382-6053 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6829
% INFO    : Updated Thermal Rating: on line 12058-6053 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4653
% INFO    : Updated Thermal Rating: on line 2382-3288 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 72
% INFO    : Updated Thermal Rating: on line 5152-3288 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 71
% INFO    : Updated Thermal Rating: on line 5152-3288 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6701
% INFO    : Updated Thermal Rating: on line 12058-3288 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5022
% INFO    : Updated Thermal Rating: on line 2382-5152 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 2382-5152 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 128
% INFO    : Updated Thermal Rating: on line 2382-8683 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 89920
% INFO    : Updated Thermal Rating: on line 11902-2382 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26583
% INFO    : Updated Thermal Rating: on line 5152-11391 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 92545
% INFO    : Updated Thermal Rating: on line 6595-8683 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4189
% INFO    : Updated Thermal Rating: on line 6595-11391 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4269
% INFO    : Updated Thermal Rating: on line 10899-1366 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 33686
% INFO    : Updated Thermal Rating: on line 10147-10603 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7330
% INFO    : Updated Thermal Rating: on line 13375-6102 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7478
% INFO    : Updated Thermal Rating: on line 12961-8888 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5187
% INFO    : Updated Thermal Rating: on line 10957-3252 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5552
% INFO    : Updated Thermal Rating: on line 10957-699 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5447
% INFO    : Updated Thermal Rating: on line 7997-9085 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 54276
% INFO    : Updated Thermal Rating: on line 7997-6414 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 31
% INFO    : Updated Thermal Rating: on line 7997-12406 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 7997-8314 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 7997-9085 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 111
% INFO    : Updated Thermal Rating: on line 5569-8176 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 133
% INFO    : Updated Thermal Rating: on line 10957-5569 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 10957-8176 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 13629-8158 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 530
% INFO    : Updated Thermal Rating: on line 13629-8158 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 399
% INFO    : Updated Thermal Rating: on line 13629-8267 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 73
% INFO    : Updated Thermal Rating: on line 13629-4147 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 73
% INFO    : Updated Thermal Rating: on line 13629-6581 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 13629-11448 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10
% INFO    : Updated Thermal Rating: on line 13629-2359 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10
% INFO    : Updated Thermal Rating: on line 13629-8608 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 13629-4055 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 13629-8156 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on line 13629-6030 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on line 13629-917 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10
% INFO    : Updated Thermal Rating: on line 13629-4995 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10
% INFO    : Updated Thermal Rating: on line 13629-12407 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on line 12043-13629 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 9823-13629 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 13629-6896 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 13629-10979 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 13629-1535 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8
% INFO    : Updated Thermal Rating: on line 5183-13629 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11
% INFO    : Updated Thermal Rating: on line 7916-13629 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on line 3743-13629 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on line 13629-2256 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2135
% INFO    : Updated Thermal Rating: on line 13629-2256 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 47
% INFO    : Updated Thermal Rating: on line 13629-7691 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23
% INFO    : Updated Thermal Rating: on line 13629-6065 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27
% INFO    : Updated Thermal Rating: on line 13629-2256 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2178
% INFO    : Updated Thermal Rating: on line 7548-8045 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20953
% INFO    : Updated Thermal Rating: on line 7548-6386 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21506
% INFO    : Updated Thermal Rating: on line 9492-2123 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1886
% INFO    : Updated Thermal Rating: on line 8267-4147 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 8267-4147 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 124
% INFO    : Updated Thermal Rating: on line 6581-8267 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 11448-8267 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on line 2359-8267 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on line 8608-8267 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on line 4055-8267 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on line 8156-8267 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10
% INFO    : Updated Thermal Rating: on line 6030-8267 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11
% INFO    : Updated Thermal Rating: on line 917-8267 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13
% INFO    : Updated Thermal Rating: on line 4995-8267 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14
% INFO    : Updated Thermal Rating: on line 12407-8267 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10
% INFO    : Updated Thermal Rating: on line 12043-8267 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 9823-8267 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 6896-8267 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 10979-8267 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 1535-8267 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5
% INFO    : Updated Thermal Rating: on line 5183-8267 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on line 7916-8267 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 3743-8267 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 4717-8267 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 8267-2256 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 30
% INFO    : Updated Thermal Rating: on line 7691-8267 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 35
% INFO    : Updated Thermal Rating: on line 6065-8267 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 45
% INFO    : Updated Thermal Rating: on line 6581-4147 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 11448-4147 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on line 2359-4147 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on line 8608-4147 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on line 4055-4147 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 8156-4147 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9
% INFO    : Updated Thermal Rating: on line 6030-4147 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10
% INFO    : Updated Thermal Rating: on line 917-4147 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13
% INFO    : Updated Thermal Rating: on line 4995-4147 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14
% INFO    : Updated Thermal Rating: on line 12407-4147 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9
% INFO    : Updated Thermal Rating: on line 12043-4147 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 9823-4147 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 6896-4147 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 10979-4147 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 1535-4147 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on line 5183-4147 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on line 7916-4147 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 3743-4147 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 4147-2256 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 32
% INFO    : Updated Thermal Rating: on line 7691-4147 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 34
% INFO    : Updated Thermal Rating: on line 6065-4147 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 40
% INFO    : Updated Thermal Rating: on line 6065-4147 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1186
% INFO    : Updated Thermal Rating: on line 9492-7042 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2528
% INFO    : Updated Thermal Rating: on line 7042-7108 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3233
% INFO    : Updated Thermal Rating: on line 9492-4338 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2897
% INFO    : Updated Thermal Rating: on line 9492-4338 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2481
% INFO    : Updated Thermal Rating: on line 4338-7108 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2858
% INFO    : Updated Thermal Rating: on line 644-2726 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 644-2726 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 134
% INFO    : Updated Thermal Rating: on line 5344-644 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10
% INFO    : Updated Thermal Rating: on line 2264-644 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 34
% INFO    : Updated Thermal Rating: on line 4342-644 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 1684-644 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 11263-644 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3032
% INFO    : Updated Thermal Rating: on line 5344-2726 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10
% INFO    : Updated Thermal Rating: on line 2264-2726 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 38
% INFO    : Updated Thermal Rating: on line 4342-2726 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 1684-2726 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on line 9595-3498 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17471
% INFO    : Updated Thermal Rating: on line 12309-6250 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17095
% INFO    : Updated Thermal Rating: on line 2281-4941 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 57093
% INFO    : Updated Thermal Rating: on line 8094-10496 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 61641
% INFO    : Updated Thermal Rating: on line 10367-9178 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157864
% INFO    : Updated Thermal Rating: on line 10367-9178 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 63
% INFO    : Updated Thermal Rating: on line 10367-722 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 28
% INFO    : Updated Thermal Rating: on line 10367-6355 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15576
% INFO    : Updated Thermal Rating: on line 10367-478 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 8529-10367 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 5951-10367 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 9178-722 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 28
% INFO    : Updated Thermal Rating: on line 9178-3605 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9696
% INFO    : Updated Thermal Rating: on line 9178-478 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 8529-9178 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 5951-9178 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 5344-418 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3072
% INFO    : Updated Thermal Rating: on line 5344-10864 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3132
% INFO    : Updated Thermal Rating: on line 475-10864 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6926
% INFO    : Updated Thermal Rating: on line 475-8634 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6170
% INFO    : Updated Thermal Rating: on line 9415-5344 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4516
% INFO    : Updated Thermal Rating: on line 5344-2264 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5
% INFO    : Updated Thermal Rating: on line 4342-5344 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14
% INFO    : Updated Thermal Rating: on line 1684-5344 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13
% INFO    : Updated Thermal Rating: on line 5344-475 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 231
% INFO    : Updated Thermal Rating: on line 12058-9673 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19031
% INFO    : Updated Thermal Rating: on line 12058-2275 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18707
% INFO    : Updated Thermal Rating: on line 4398-7767 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15175
% INFO    : Updated Thermal Rating: on line 8285-8566 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 59111
% INFO    : Updated Thermal Rating: on line 6581-6464 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 60231
% INFO    : Updated Thermal Rating: on line 6581-8608 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on line 6581-4055 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on line 6581-8156 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9
% INFO    : Updated Thermal Rating: on line 6581-6030 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9
% INFO    : Updated Thermal Rating: on line 6581-917 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18
% INFO    : Updated Thermal Rating: on line 6581-4995 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15
% INFO    : Updated Thermal Rating: on line 6581-12407 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 30
% INFO    : Updated Thermal Rating: on line 12043-6581 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 9823-6581 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 6581-2256 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 6581-7691 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on line 6581-6065 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on line 8566-12407 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 722
% INFO    : Updated Thermal Rating: on line 6464-12407 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 737
% INFO    : Updated Thermal Rating: on line 11812-12474 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 11812-12474 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 39
% INFO    : Updated Thermal Rating: on line 10786-11812 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 50711
% INFO    : Updated Thermal Rating: on line 91-11812 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 11732-11812 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12
% INFO    : Updated Thermal Rating: on line 10349-11812 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 12274-11812 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 48
% INFO    : Updated Thermal Rating: on line 3895-11812 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 1789-11812 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 8094-12474 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 49913
% INFO    : Updated Thermal Rating: on line 91-12474 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on line 11732-12474 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 42
% INFO    : Updated Thermal Rating: on line 12274-12474 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 35
% INFO    : Updated Thermal Rating: on line 3895-12474 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on line 1789-12474 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 11616-10786 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13672
% INFO    : Updated Thermal Rating: on line 12129-2281 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14752
% INFO    : Updated Thermal Rating: on line 12269-6414 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10463
% INFO    : Updated Thermal Rating: on line 478-12269 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18217
% INFO    : Updated Thermal Rating: on line 7393-6414 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10673
% INFO    : Updated Thermal Rating: on line 3019-7393 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18643
% INFO    : Updated Thermal Rating: on line 12406-6414 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 8314-6414 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 9085-6414 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 28
% INFO    : Updated Thermal Rating: on line 4342-2264 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8
% INFO    : Updated Thermal Rating: on line 1684-2264 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on line 2264-8468 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3790
% INFO    : Updated Thermal Rating: on line 3986-12363 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1329
% INFO    : Updated Thermal Rating: on line 935-10379 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 101
% INFO    : Updated Thermal Rating: on line 935-12951 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 87
% INFO    : Updated Thermal Rating: on line 935-12951 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1690
% INFO    : Updated Thermal Rating: on line 10379-12951 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 89
% INFO    : Updated Thermal Rating: on line 10379-12951 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1820
% INFO    : Updated Thermal Rating: on line 722-3393 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19989
% INFO    : Updated Thermal Rating: on line 478-722 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 8529-722 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5
% INFO    : Updated Thermal Rating: on line 5951-722 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on line 11650-5812 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19632
% INFO    : Updated Thermal Rating: on line 11650-6355 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19275
% INFO    : Updated Thermal Rating: on line 11650-5809 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142990
% INFO    : Updated Thermal Rating: on line 10991-9023 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 10991-9023 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 68
% INFO    : Updated Thermal Rating: on line 8960-10991 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 674
% INFO    : Updated Thermal Rating: on line 6196-10991 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1189
% INFO    : Updated Thermal Rating: on line 2313-9023 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1210
% INFO    : Updated Thermal Rating: on line 10899-3393 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11319
% INFO    : Updated Thermal Rating: on line 2749-5812 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11560
% INFO    : Updated Thermal Rating: on line 6598-3605 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2763
% INFO    : Updated Thermal Rating: on line 4342-1684 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 4342-1684 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 127
% INFO    : Updated Thermal Rating: on line 4342-12614 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13496
% INFO    : Updated Thermal Rating: on line 4860-8960 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 4860-8960 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 99
% INFO    : Updated Thermal Rating: on line 4860-12951 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2690
% INFO    : Updated Thermal Rating: on line 4860-1779 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on line 3119-4860 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1170
% INFO    : Updated Thermal Rating: on line 6012-4860 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21
% INFO    : Updated Thermal Rating: on line 8960-12951 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2743
% INFO    : Updated Thermal Rating: on line 8960-1779 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on line 6012-8960 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22
% INFO    : Updated Thermal Rating: on line 11448-2359 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 11448-2359 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 47
% INFO    : Updated Thermal Rating: on line 366-11448 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 11448-8156 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 11448-6030 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 11448-917 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 11448-4995 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 11448-12407 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 6896-11448 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 10979-11448 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 11448-1535 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27
% INFO    : Updated Thermal Rating: on line 11448-1535 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1896
% INFO    : Updated Thermal Rating: on line 5183-11448 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on line 11448-7014 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on line 11448-12720 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on line 7916-11448 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 7916-11448 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 964
% INFO    : Updated Thermal Rating: on line 3743-11448 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 11448-9401 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 11448-2256 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27
% INFO    : Updated Thermal Rating: on line 11448-7691 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 11448-6065 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 366-2359 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 2359-8156 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 2359-6030 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 2359-917 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 2359-4995 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 2359-12407 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 6896-2359 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 10979-2359 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 2359-1535 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 33
% INFO    : Updated Thermal Rating: on line 5183-2359 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on line 2359-7014 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 2359-12720 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on line 7916-2359 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 3743-2359 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 3743-2359 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 975
% INFO    : Updated Thermal Rating: on line 2359-9401 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 2359-2256 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24
% INFO    : Updated Thermal Rating: on line 2359-7691 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 2359-6065 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 5951-3019 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6746
% INFO    : Updated Thermal Rating: on line 8529-478 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 68
% INFO    : Updated Thermal Rating: on line 8529-478 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6621
% INFO    : Updated Thermal Rating: on line 5951-478 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 77
% INFO    : Updated Thermal Rating: on line 11448-2256 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 836
% INFO    : Updated Thermal Rating: on line 945-8045 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9496
% INFO    : Updated Thermal Rating: on line 945-6386 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9696
% INFO    : Updated Thermal Rating: on line 945-2113 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23815
% INFO    : Updated Thermal Rating: on line 8608-4055 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 176
% INFO    : Updated Thermal Rating: on line 8608-8156 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 44
% INFO    : Updated Thermal Rating: on line 8608-8156 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 860
% INFO    : Updated Thermal Rating: on line 8608-6030 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 41
% INFO    : Updated Thermal Rating: on line 917-8608 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13
% INFO    : Updated Thermal Rating: on line 4995-8608 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13
% INFO    : Updated Thermal Rating: on line 8608-12407 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14
% INFO    : Updated Thermal Rating: on line 12043-8608 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23
% INFO    : Updated Thermal Rating: on line 9823-8608 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 42
% INFO    : Updated Thermal Rating: on line 6896-8608 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 10979-8608 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 5183-8608 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 7916-8608 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 3743-8608 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 4717-8608 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12
% INFO    : Updated Thermal Rating: on line 8608-2256 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 8608-7691 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9
% INFO    : Updated Thermal Rating: on line 8608-6065 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11
% INFO    : Updated Thermal Rating: on line 4055-8156 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 35
% INFO    : Updated Thermal Rating: on line 4055-6030 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 39
% INFO    : Updated Thermal Rating: on line 4055-6030 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 878
% INFO    : Updated Thermal Rating: on line 917-4055 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13
% INFO    : Updated Thermal Rating: on line 4995-4055 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11
% INFO    : Updated Thermal Rating: on line 4055-12407 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13
% INFO    : Updated Thermal Rating: on line 12043-4055 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22
% INFO    : Updated Thermal Rating: on line 9823-4055 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 40
% INFO    : Updated Thermal Rating: on line 6896-4055 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 10979-4055 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 5183-4055 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 7916-4055 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 4717-4055 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12
% INFO    : Updated Thermal Rating: on line 4055-2256 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 4055-7691 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9
% INFO    : Updated Thermal Rating: on line 4055-6065 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11
% INFO    : Updated Thermal Rating: on line 13017-10967 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4020
% INFO    : Updated Thermal Rating: on line 13017-6550 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 13017-964 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9
% INFO    : Updated Thermal Rating: on line 13017-13282 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5
% INFO    : Updated Thermal Rating: on line 13017-2182 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3946
% INFO    : Updated Thermal Rating: on line 12151-2182 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13480
% INFO    : Updated Thermal Rating: on line 3291-10967 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2243
% INFO    : Updated Thermal Rating: on line 11732-91 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22
% INFO    : Updated Thermal Rating: on line 91-12274 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 91-3895 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 28
% INFO    : Updated Thermal Rating: on line 1789-91 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on line 366-469 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1071
% INFO    : Updated Thermal Rating: on line 366-1535 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 5183-366 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 366-7014 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 28
% INFO    : Updated Thermal Rating: on line 366-12720 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 28
% INFO    : Updated Thermal Rating: on line 366-12720 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 889
% INFO    : Updated Thermal Rating: on line 7916-366 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 3743-366 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 366-9401 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on line 366-2256 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 366-1566 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 366-5754 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 91-3895 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3127
% INFO    : Updated Thermal Rating: on line 10917-11296 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7523
% INFO    : Updated Thermal Rating: on line 7916-10917 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1131
% INFO    : Updated Thermal Rating: on line 11296-5666 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1827
% INFO    : Updated Thermal Rating: on line 5666-6288 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3390
% INFO    : Updated Thermal Rating: on line 6288-5792 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8983
% INFO    : Updated Thermal Rating: on line 5792-4871 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3528
% INFO    : Updated Thermal Rating: on line 4871-469 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20179
% INFO    : Updated Thermal Rating: on line 10288-10446 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9872
% INFO    : Updated Thermal Rating: on line 10288-10446 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10673
% INFO    : Updated Thermal Rating: on line 6550-1061 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18322
% INFO    : Updated Thermal Rating: on line 10047-1061 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8200
% INFO    : Updated Thermal Rating: on line 1747-3657 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16364
% INFO    : Updated Thermal Rating: on line 10047-3657 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8178
% INFO    : Updated Thermal Rating: on line 8156-6030 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 8156-6030 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 118
% INFO    : Updated Thermal Rating: on line 917-8156 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 34
% INFO    : Updated Thermal Rating: on line 917-8156 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1407
% INFO    : Updated Thermal Rating: on line 4995-8156 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 34
% INFO    : Updated Thermal Rating: on line 8156-12407 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 29
% INFO    : Updated Thermal Rating: on line 6495-8156 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11488
% INFO    : Updated Thermal Rating: on line 12043-8156 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on line 9823-8156 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12
% INFO    : Updated Thermal Rating: on line 6896-8156 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 10979-8156 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 1535-8156 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 5183-8156 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 4717-8156 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 8156-2256 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 8156-7691 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26
% INFO    : Updated Thermal Rating: on line 8156-6065 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 31
% INFO    : Updated Thermal Rating: on line 917-6030 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 35
% INFO    : Updated Thermal Rating: on line 4995-6030 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 35
% INFO    : Updated Thermal Rating: on line 6030-12407 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 32
% INFO    : Updated Thermal Rating: on line 9067-6030 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11247
% INFO    : Updated Thermal Rating: on line 12043-6030 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on line 9823-6030 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11
% INFO    : Updated Thermal Rating: on line 6896-6030 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 10979-6030 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 1535-6030 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 5183-6030 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 4717-6030 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 6030-2256 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 6030-7691 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27
% INFO    : Updated Thermal Rating: on line 6030-7691 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1733
% INFO    : Updated Thermal Rating: on line 6030-6065 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 33
% INFO    : Updated Thermal Rating: on line 6825-8391 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8135
% INFO    : Updated Thermal Rating: on line 6825-5257 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8315
% INFO    : Updated Thermal Rating: on line 5250-9863 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7991
% INFO    : Updated Thermal Rating: on line 5250-887 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8493
% INFO    : Updated Thermal Rating: on line 6825-10957 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 9492-10446 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3331
% INFO    : Updated Thermal Rating: on line 10446-909 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3798
% INFO    : Updated Thermal Rating: on line 9492-10446 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3267
% INFO    : Updated Thermal Rating: on line 10446-909 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3876
% INFO    : Updated Thermal Rating: on line 917-4995 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 917-4995 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 121
% INFO    : Updated Thermal Rating: on line 917-12407 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 69
% INFO    : Updated Thermal Rating: on line 917-12407 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1520
% INFO    : Updated Thermal Rating: on line 12043-917 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 9823-917 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on line 917-1535 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 5183-917 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 4717-917 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 917-2256 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on line 917-7691 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25
% INFO    : Updated Thermal Rating: on line 917-6065 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 30
% INFO    : Updated Thermal Rating: on line 4995-12407 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 67
% INFO    : Updated Thermal Rating: on line 4995-12407 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1492
% INFO    : Updated Thermal Rating: on line 12043-4995 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 9823-4995 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on line 4995-1535 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 5183-4995 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 4717-4995 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 4995-2256 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on line 4995-7691 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25
% INFO    : Updated Thermal Rating: on line 4995-6065 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 29
% INFO    : Updated Thermal Rating: on line 12043-12407 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 9823-12407 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on line 1535-12407 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 5183-12407 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 4717-12407 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 12407-2256 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 7691-12407 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20
% INFO    : Updated Thermal Rating: on line 6065-12407 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24
% INFO    : Updated Thermal Rating: on line 11732-12274 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9
% INFO    : Updated Thermal Rating: on line 11732-3895 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21
% INFO    : Updated Thermal Rating: on line 11732-1789 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 11732-9866 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8819
% INFO    : Updated Thermal Rating: on line 3498-7835 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24012
% INFO    : Updated Thermal Rating: on line 12043-9823 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 12043-9823 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 188
% INFO    : Updated Thermal Rating: on line 12043-6896 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9
% INFO    : Updated Thermal Rating: on line 12043-10979 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8
% INFO    : Updated Thermal Rating: on line 12043-10979 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 569
% INFO    : Updated Thermal Rating: on line 5183-12043 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 7916-12043 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 3743-12043 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 12043-4717 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 56
% INFO    : Updated Thermal Rating: on line 12043-2256 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 12043-7691 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 12043-6065 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 9823-6896 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14
% INFO    : Updated Thermal Rating: on line 9823-10979 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15
% INFO    : Updated Thermal Rating: on line 5183-9823 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5
% INFO    : Updated Thermal Rating: on line 7916-9823 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 3743-9823 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 9823-4717 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 99
% INFO    : Updated Thermal Rating: on line 9823-2256 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 9823-7691 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 9823-6065 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 7108-10349 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6031
% INFO    : Updated Thermal Rating: on line 1789-10349 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1884
% INFO    : Updated Thermal Rating: on line 1789-10349 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12
% INFO    : Updated Thermal Rating: on line 7245-7922 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6787
% INFO    : Updated Thermal Rating: on line 7245-8379 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4536
% INFO    : Updated Thermal Rating: on line 12406-12866 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9050
% INFO    : Updated Thermal Rating: on line 8314-12866 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8898
% INFO    : Updated Thermal Rating: on line 12406-8314 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 38
% INFO    : Updated Thermal Rating: on line 9085-12406 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 9085-8314 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 6896-10979 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 6896-10979 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 133
% INFO    : Updated Thermal Rating: on line 5183-6896 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16
% INFO    : Updated Thermal Rating: on line 7916-6896 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11
% INFO    : Updated Thermal Rating: on line 3743-6896 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12
% INFO    : Updated Thermal Rating: on line 3743-6896 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 413
% INFO    : Updated Thermal Rating: on line 4717-6896 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27
% INFO    : Updated Thermal Rating: on line 6896-2256 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5
% INFO    : Updated Thermal Rating: on line 5183-10979 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15
% INFO    : Updated Thermal Rating: on line 7916-10979 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13
% INFO    : Updated Thermal Rating: on line 3743-10979 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12
% INFO    : Updated Thermal Rating: on line 4717-10979 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25
% INFO    : Updated Thermal Rating: on line 10979-2256 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5
% INFO    : Updated Thermal Rating: on line 7922-2780 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 29997
% INFO    : Updated Thermal Rating: on line 12129-12274 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16832
% INFO    : Updated Thermal Rating: on line 1535-8158 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 53713
% INFO    : Updated Thermal Rating: on line 11616-12274 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14883
% INFO    : Updated Thermal Rating: on line 6949-11804 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 29439
% INFO    : Updated Thermal Rating: on line 6949-12274 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157153
% INFO    : Updated Thermal Rating: on line 3477-2478 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7689
% INFO    : Updated Thermal Rating: on line 3477-1535 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 55676
% INFO    : Updated Thermal Rating: on line 13127-4828 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7858
% INFO    : Updated Thermal Rating: on line 1535-13127 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 56662
% INFO    : Updated Thermal Rating: on line 12274-2780 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157153
% INFO    : Updated Thermal Rating: on line 11804-7124 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2870
% INFO    : Updated Thermal Rating: on line 2478-3613 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 681
% INFO    : Updated Thermal Rating: on line 4828-12870 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 696
% INFO    : Updated Thermal Rating: on line 3895-12274 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 1789-12274 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 5183-1535 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 7014-1535 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 12720-1535 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 7916-1535 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 3743-1535 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 1535-9401 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 1535-2256 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10
% INFO    : Updated Thermal Rating: on line 166-1535 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25926
% INFO    : Updated Thermal Rating: on line 1535-7691 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 1535-6065 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 2123-1522 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20817
% INFO    : Updated Thermal Rating: on line 7124-7022 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7096
% INFO    : Updated Thermal Rating: on line 3613-13629 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1670
% INFO    : Updated Thermal Rating: on line 12870-13629 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1480
% INFO    : Updated Thermal Rating: on line 8379-1522 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7258
% INFO    : Updated Thermal Rating: on line 7022-2123 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21235
% INFO    : Updated Thermal Rating: on line 5183-7014 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 5183-12720 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 7916-5183 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 39
% INFO    : Updated Thermal Rating: on line 3743-5183 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 39
% INFO    : Updated Thermal Rating: on line 3743-5183 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1175
% INFO    : Updated Thermal Rating: on line 5183-4717 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on line 5183-2256 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 34
% INFO    : Updated Thermal Rating: on line 5183-7691 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 5183-6065 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 6656-9032 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6437
% INFO    : Updated Thermal Rating: on line 12987-9032 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7585
% INFO    : Updated Thermal Rating: on line 3895-6447 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6585
% INFO    : Updated Thermal Rating: on line 12987-6447 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7750
% INFO    : Updated Thermal Rating: on line 6656-10903 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4274
% INFO    : Updated Thermal Rating: on line 9866-6656 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8855
% INFO    : Updated Thermal Rating: on line 3504-6656 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8510
% INFO    : Updated Thermal Rating: on line 3895-8234 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4906
% INFO    : Updated Thermal Rating: on line 1789-3895 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 7211-3895 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8387
% INFO    : Updated Thermal Rating: on line 919-3895 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8545
% INFO    : Updated Thermal Rating: on line 7014-12720 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 187958
% INFO    : Updated Thermal Rating: on line 7014-12720 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 123
% INFO    : Updated Thermal Rating: on line 7916-7014 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 3743-7014 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 7014-9401 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9
% INFO    : Updated Thermal Rating: on line 7014-2256 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 7014-1566 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 7014-5754 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 7916-12720 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 3743-12720 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 12720-9401 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9
% INFO    : Updated Thermal Rating: on line 12720-2256 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 12720-1566 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 12720-5754 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 6933-8234 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9837
% INFO    : Updated Thermal Rating: on line 4218-10903 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9806
% INFO    : Updated Thermal Rating: on line 4762-13432 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 55112
% INFO    : Updated Thermal Rating: on line 13282-4762 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3963
% INFO    : Updated Thermal Rating: on line 7916-3743 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 187958
% INFO    : Updated Thermal Rating: on line 7916-3743 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 172
% INFO    : Updated Thermal Rating: on line 7916-4717 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 7916-2256 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13
% INFO    : Updated Thermal Rating: on line 7916-7691 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 7916-6065 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 3743-4717 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 3743-2256 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11
% INFO    : Updated Thermal Rating: on line 3743-7691 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 3743-6065 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 9401-2256 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 1566-9401 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 33
% INFO    : Updated Thermal Rating: on line 5754-9401 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 28
% INFO    : Updated Thermal Rating: on line 4717-2256 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 4717-7691 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 4717-6065 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on line 7691-2256 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9
% INFO    : Updated Thermal Rating: on line 6065-2256 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10
% INFO    : Updated Thermal Rating: on line 6196-1779 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1497
% INFO    : Updated Thermal Rating: on line 2313-1779 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1523
% INFO    : Updated Thermal Rating: on line 6012-1779 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 64
% INFO    : Updated Thermal Rating: on line 8529-5951 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 8529-5951 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 164
% INFO    : Updated Thermal Rating: on line 8529-12058 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2307
% INFO    : Updated Thermal Rating: on line 5951-12058 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2043
% INFO    : Updated Thermal Rating: on line 2741-6180 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9083
% INFO    : Updated Thermal Rating: on line 1566-5754 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 1566-5754 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 198
% INFO    : Updated Thermal Rating: on line 1566-8815 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15646
% INFO    : Updated Thermal Rating: on line 8815-12039 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2414
% INFO    : Updated Thermal Rating: on line 12039-6478 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2294
% INFO    : Updated Thermal Rating: on line 6478-10573 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2462
% INFO    : Updated Thermal Rating: on line 10573-166 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2237
% INFO    : Updated Thermal Rating: on line 1747-2897 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7518
% INFO    : Updated Thermal Rating: on line 964-6550 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 34
% INFO    : Updated Thermal Rating: on line 6550-1670 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7500
% INFO    : Updated Thermal Rating: on line 13282-6550 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 32
% INFO    : Updated Thermal Rating: on line 3746-12363 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 3746-12363 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2360
% INFO    : Updated Thermal Rating: on line 12363-5547 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1586
% INFO    : Updated Thermal Rating: on line 964-1651 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7780
% INFO    : Updated Thermal Rating: on line 5939-13282 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6980
% INFO    : Updated Thermal Rating: on line 964-13282 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 67
% INFO    : Updated Thermal Rating: on line 4756-2897 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 51343
% INFO    : Updated Thermal Rating: on line 1128-1670 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 48391
% INFO    : Updated Thermal Rating: on line 6012-6196 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 66310
% INFO    : Updated Thermal Rating: on line 6012-2313 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 67437
% INFO    : Updated Thermal Rating: on line 7691-6065 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 7691-6065 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 127
% INFO    : Updated Thermal Rating: on line 12684-3043 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 41748
% INFO    : Updated Thermal Rating: on line 12684-10965 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 327
% INFO    : Updated Thermal Rating: on line 12684-10965 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 46486
% INFO    : Updated Thermal Rating: on line 9948-3043 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 33415
% INFO    : Updated Thermal Rating: on line 9948-3043 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 29418
% INFO    : Updated Thermal Rating: on line 89-9948 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 37037
% INFO    : Updated Thermal Rating: on line 89-9948 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 38808
% INFO    : Updated Thermal Rating: on line 3043-10965 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22065
% INFO    : Updated Thermal Rating: on line 89-3635 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16473
% INFO    : Updated Thermal Rating: on line 89-3635 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16228
% INFO    : Updated Thermal Rating: on line 89-11659 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9843
% INFO    : Updated Thermal Rating: on line 89-11659 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9703
% INFO    : Updated Thermal Rating: on line 10965-6385 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 191
% INFO    : Updated Thermal Rating: on line 10965-6385 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 30710
% INFO    : Updated Thermal Rating: on line 10965-6385 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 31479
% INFO    : Updated Thermal Rating: on line 6385-6595 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1824
% INFO    : Updated Thermal Rating: on line 6385-284 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7900
% INFO    : Updated Thermal Rating: on line 5297-2962 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 187958
% INFO    : Updated Thermal Rating: on line 5297-2962 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 290
% INFO    : Updated Thermal Rating: on line 5297-313 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1517
% INFO    : Updated Thermal Rating: on line 2962-313 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1492
% INFO    : Updated Thermal Rating: on line 4127-9057 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21
% INFO    : Updated Thermal Rating: on line 4127-587 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 33
% INFO    : Updated Thermal Rating: on line 4127-7275 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 34
% INFO    : Updated Thermal Rating: on line 1611-4127 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 86
% INFO    : Updated Thermal Rating: on line 4127-587 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1867
% INFO    : Updated Thermal Rating: on line 4127-2319 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3246
% INFO    : Updated Thermal Rating: on line 3879-4127 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 45
% INFO    : Updated Thermal Rating: on line 4127-8543 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 97
% INFO    : Updated Thermal Rating: on line 5470-8061 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157153
% INFO    : Updated Thermal Rating: on line 5470-1355 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9159
% INFO    : Updated Thermal Rating: on line 5470-1355 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 110
% INFO    : Updated Thermal Rating: on line 5470-9499 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 113
% INFO    : Updated Thermal Rating: on line 9156-5470 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142
% INFO    : Updated Thermal Rating: on line 9156-5470 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 159
% INFO    : Updated Thermal Rating: on line 6804-8061 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12461
% INFO    : Updated Thermal Rating: on line 9156-8061 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14709
% INFO    : Updated Thermal Rating: on line 9057-587 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2264
% INFO    : Updated Thermal Rating: on line 9057-587 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26
% INFO    : Updated Thermal Rating: on line 7275-9057 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 39
% INFO    : Updated Thermal Rating: on line 1611-9057 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 146
% INFO    : Updated Thermal Rating: on line 1611-9057 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2449
% INFO    : Updated Thermal Rating: on line 6301-11453 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22
% INFO    : Updated Thermal Rating: on line 3085-11453 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23
% INFO    : Updated Thermal Rating: on line 3085-11453 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 802
% INFO    : Updated Thermal Rating: on line 3817-11453 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5739
% INFO    : Updated Thermal Rating: on line 3817-11453 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 191
% INFO    : Updated Thermal Rating: on line 7035-11453 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17
% INFO    : Updated Thermal Rating: on line 11123-11453 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15
% INFO    : Updated Thermal Rating: on line 80-587 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1275
% INFO    : Updated Thermal Rating: on line 2314-80 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22
% INFO    : Updated Thermal Rating: on line 80-12360 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 90
% INFO    : Updated Thermal Rating: on line 80-13555 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1669
% INFO    : Updated Thermal Rating: on line 80-13555 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 173
% INFO    : Updated Thermal Rating: on line 7437-1170 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1137
% INFO    : Updated Thermal Rating: on line 7456-7437 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 777
% INFO    : Updated Thermal Rating: on line 7437-12202 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3215
% INFO    : Updated Thermal Rating: on line 3278-7437 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 839
% INFO    : Updated Thermal Rating: on line 6046-3462 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2314
% INFO    : Updated Thermal Rating: on line 6046-3462 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2361
% INFO    : Updated Thermal Rating: on line 9156-1355 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 122
% INFO    : Updated Thermal Rating: on line 9156-1355 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12464
% INFO    : Updated Thermal Rating: on line 10358-2376 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1492
% INFO    : Updated Thermal Rating: on line 6207-2376 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 895
% INFO    : Updated Thermal Rating: on line 9898-2376 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5422
% INFO    : Updated Thermal Rating: on line 7275-5802 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3167
% INFO    : Updated Thermal Rating: on line 1611-5802 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4173
% INFO    : Updated Thermal Rating: on line 1209-5802 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9702
% INFO    : Updated Thermal Rating: on line 10358-2376 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1433
% INFO    : Updated Thermal Rating: on line 1620-2376 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5203
% INFO    : Updated Thermal Rating: on line 10196-2376 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1088
% INFO    : Updated Thermal Rating: on line 10308-587 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20155
% INFO    : Updated Thermal Rating: on line 13436-587 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21833
% INFO    : Updated Thermal Rating: on line 7275-587 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 78
% INFO    : Updated Thermal Rating: on line 1611-587 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 104
% INFO    : Updated Thermal Rating: on line 3772-1177 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 3772-1177 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 170
% INFO    : Updated Thermal Rating: on line 7892-3772 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12
% INFO    : Updated Thermal Rating: on line 5412-3772 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11
% INFO    : Updated Thermal Rating: on line 6108-3772 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 35
% INFO    : Updated Thermal Rating: on line 4839-3772 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 32
% INFO    : Updated Thermal Rating: on line 13476-3772 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 104
% INFO    : Updated Thermal Rating: on line 3772-10879 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3806
% INFO    : Updated Thermal Rating: on line 3772-6046 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2608
% INFO    : Updated Thermal Rating: on line 3772-9048 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2616
% INFO    : Updated Thermal Rating: on line 7892-1177 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13
% INFO    : Updated Thermal Rating: on line 5412-1177 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12
% INFO    : Updated Thermal Rating: on line 6108-1177 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 32
% INFO    : Updated Thermal Rating: on line 4839-1177 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 34
% INFO    : Updated Thermal Rating: on line 13476-1177 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7110
% INFO    : Updated Thermal Rating: on line 13476-1177 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 95
% INFO    : Updated Thermal Rating: on line 6916-1177 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10201
% INFO    : Updated Thermal Rating: on line 487-6804 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12603
% INFO    : Updated Thermal Rating: on line 4172-6804 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 86
% INFO    : Updated Thermal Rating: on line 2314-5524 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 235
% INFO    : Updated Thermal Rating: on line 2314-6301 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 648
% INFO    : Updated Thermal Rating: on line 2314-12360 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1259
% INFO    : Updated Thermal Rating: on line 2314-12360 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 36
% INFO    : Updated Thermal Rating: on line 2314-13555 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 68
% INFO    : Updated Thermal Rating: on line 10358-11151 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1961
% INFO    : Updated Thermal Rating: on line 5524-3085 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 636
% INFO    : Updated Thermal Rating: on line 5524-13555 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1128
% INFO    : Updated Thermal Rating: on line 10358-6207 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2289
% INFO    : Updated Thermal Rating: on line 12064-7805 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 12064-7805 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 166
% INFO    : Updated Thermal Rating: on line 4740-12064 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3209
% INFO    : Updated Thermal Rating: on line 12064-7244 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 55
% INFO    : Updated Thermal Rating: on line 12064-7244 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4863
% INFO    : Updated Thermal Rating: on line 12064-13259 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20
% INFO    : Updated Thermal Rating: on line 12064-7096 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 64
% INFO    : Updated Thermal Rating: on line 12064-8694 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 69
% INFO    : Updated Thermal Rating: on line 8694-7805 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4458
% INFO    : Updated Thermal Rating: on line 7805-7244 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5015
% INFO    : Updated Thermal Rating: on line 7805-7244 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 64
% INFO    : Updated Thermal Rating: on line 7805-13259 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21
% INFO    : Updated Thermal Rating: on line 7805-7096 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 74
% INFO    : Updated Thermal Rating: on line 7805-8694 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 67
% INFO    : Updated Thermal Rating: on line 10503-11644 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14441
% INFO    : Updated Thermal Rating: on line 5633-1025 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23
% INFO    : Updated Thermal Rating: on line 5633-3417 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17
% INFO    : Updated Thermal Rating: on line 5633-11636 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 38
% INFO    : Updated Thermal Rating: on line 5633-11636 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2997
% INFO    : Updated Thermal Rating: on line 5633-2948 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 41
% INFO    : Updated Thermal Rating: on line 5633-10879 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 57
% INFO    : Updated Thermal Rating: on line 5633-9048 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 117
% INFO    : Updated Thermal Rating: on line 5633-9048 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8939
% INFO    : Updated Thermal Rating: on line 11698-949 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3551
% INFO    : Updated Thermal Rating: on line 11698-4819 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1711
% INFO    : Updated Thermal Rating: on line 1025-3417 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 1025-3417 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 102
% INFO    : Updated Thermal Rating: on line 2265-1025 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7700
% INFO    : Updated Thermal Rating: on line 1025-11636 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 60
% INFO    : Updated Thermal Rating: on line 1025-2948 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52
% INFO    : Updated Thermal Rating: on line 1025-11644 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21405
% INFO    : Updated Thermal Rating: on line 1025-10879 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on line 13259-1025 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5364
% INFO    : Updated Thermal Rating: on line 9048-1025 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12
% INFO    : Updated Thermal Rating: on line 1432-11698 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7388
% INFO    : Updated Thermal Rating: on line 3636-11698 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 667
% INFO    : Updated Thermal Rating: on line 4328-3417 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22466
% INFO    : Updated Thermal Rating: on line 1691-3417 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21999
% INFO    : Updated Thermal Rating: on line 3417-11636 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 44
% INFO    : Updated Thermal Rating: on line 3417-11636 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3615
% INFO    : Updated Thermal Rating: on line 3417-2948 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 44
% INFO    : Updated Thermal Rating: on line 3417-10879 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5
% INFO    : Updated Thermal Rating: on line 4172-3417 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5785
% INFO    : Updated Thermal Rating: on line 9048-3417 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8
% INFO    : Updated Thermal Rating: on line 2354-6180 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2009
% INFO    : Updated Thermal Rating: on line 2948-9744 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3958
% INFO    : Updated Thermal Rating: on line 7892-5412 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 7892-5412 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 211
% INFO    : Updated Thermal Rating: on line 6108-7892 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 50
% INFO    : Updated Thermal Rating: on line 6108-7892 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3624
% INFO    : Updated Thermal Rating: on line 4839-7892 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 51
% INFO    : Updated Thermal Rating: on line 13476-7892 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13
% INFO    : Updated Thermal Rating: on line 6108-5412 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 50
% INFO    : Updated Thermal Rating: on line 4839-5412 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 55
% INFO    : Updated Thermal Rating: on line 13476-5412 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13
% INFO    : Updated Thermal Rating: on line 5412-6046 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8058
% INFO    : Updated Thermal Rating: on line 6301-3085 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 65
% INFO    : Updated Thermal Rating: on line 3817-6301 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 905
% INFO    : Updated Thermal Rating: on line 3817-6301 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15
% INFO    : Updated Thermal Rating: on line 6301-7035 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19
% INFO    : Updated Thermal Rating: on line 6301-11123 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19
% INFO    : Updated Thermal Rating: on line 3817-3085 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16
% INFO    : Updated Thermal Rating: on line 3085-7035 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21
% INFO    : Updated Thermal Rating: on line 3085-11123 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22
% INFO    : Updated Thermal Rating: on line 12733-3576 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 220
% INFO    : Updated Thermal Rating: on line 12733-2600 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17618
% INFO    : Updated Thermal Rating: on line 3576-13196 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17975
% INFO    : Updated Thermal Rating: on line 2354-7451 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 58
% INFO    : Updated Thermal Rating: on line 2354-2265 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3684
% INFO    : Updated Thermal Rating: on line 2354-2265 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 54
% INFO    : Updated Thermal Rating: on line 2354-2843 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2209
% INFO    : Updated Thermal Rating: on line 12109-2354 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14
% INFO    : Updated Thermal Rating: on line 2393-949 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3549
% INFO    : Updated Thermal Rating: on line 2393-5190 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 72
% INFO    : Updated Thermal Rating: on line 3742-5190 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3691
% INFO    : Updated Thermal Rating: on line 5633-11636 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2838
% INFO    : Updated Thermal Rating: on line 5633-10879 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3320
% INFO    : Updated Thermal Rating: on line 6108-4839 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 6108-4839 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 161
% INFO    : Updated Thermal Rating: on line 6108-13476 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 35
% INFO    : Updated Thermal Rating: on line 4839-13476 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 36
% INFO    : Updated Thermal Rating: on line 8836-4839 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2290
% INFO    : Updated Thermal Rating: on line 13171-4839 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1380
% INFO    : Updated Thermal Rating: on line 7451-2265 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 7451-2265 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 138
% INFO    : Updated Thermal Rating: on line 7451-2843 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4755
% INFO    : Updated Thermal Rating: on line 12109-7451 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 39
% INFO    : Updated Thermal Rating: on line 12109-2265 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 33
% INFO    : Updated Thermal Rating: on line 12566-13196 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1429
% INFO    : Updated Thermal Rating: on line 12566-4819 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6186
% INFO    : Updated Thermal Rating: on line 3038-10308 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 150
% INFO    : Updated Thermal Rating: on line 3038-13436 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 147
% INFO    : Updated Thermal Rating: on line 1611-3038 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17303
% INFO    : Updated Thermal Rating: on line 10308-13436 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 154
% INFO    : Updated Thermal Rating: on line 13259-9898 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2285
% INFO    : Updated Thermal Rating: on line 4172-1620 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2681
% INFO    : Updated Thermal Rating: on line 11636-2948 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 11636-2948 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 183
% INFO    : Updated Thermal Rating: on line 11636-10879 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11
% INFO    : Updated Thermal Rating: on line 9048-11636 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21
% INFO    : Updated Thermal Rating: on line 2948-10879 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13
% INFO    : Updated Thermal Rating: on line 9048-2948 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23
% INFO    : Updated Thermal Rating: on line 1131-7035 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4972
% INFO    : Updated Thermal Rating: on line 7341-1131 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9029
% INFO    : Updated Thermal Rating: on line 10504-1131 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8889
% INFO    : Updated Thermal Rating: on line 7609-1131 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1934
% INFO    : Updated Thermal Rating: on line 4740-6207 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2418
% INFO    : Updated Thermal Rating: on line 1340-6207 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27846
% INFO    : Updated Thermal Rating: on line 8777-1910 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11250
% INFO    : Updated Thermal Rating: on line 1688-1910 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10115
% INFO    : Updated Thermal Rating: on line 1910-11123 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5659
% INFO    : Updated Thermal Rating: on line 2620-11151 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 28379
% INFO    : Updated Thermal Rating: on line 1611-7275 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 153
% INFO    : Updated Thermal Rating: on line 12360-7275 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1361
% INFO    : Updated Thermal Rating: on line 13476-9156 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4267
% INFO    : Updated Thermal Rating: on line 6114-7096 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157153
% INFO    : Updated Thermal Rating: on line 4740-9661 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12874
% INFO    : Updated Thermal Rating: on line 9156-9499 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 132
% INFO    : Updated Thermal Rating: on line 9156-9499 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8180
% INFO    : Updated Thermal Rating: on line 9194-12202 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2694
% INFO    : Updated Thermal Rating: on line 9194-1170 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2941
% INFO    : Updated Thermal Rating: on line 6796-3026 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 6796-3026 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 75
% INFO    : Updated Thermal Rating: on line 6796-4172 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9967
% INFO    : Updated Thermal Rating: on line 6796-4172 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 80
% INFO    : Updated Thermal Rating: on line 6796-9156 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 43
% INFO    : Updated Thermal Rating: on line 3026-4172 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 82
% INFO    : Updated Thermal Rating: on line 3026-9156 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2737
% INFO    : Updated Thermal Rating: on line 3026-9156 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 42
% INFO    : Updated Thermal Rating: on line 487-13259 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6615
% INFO    : Updated Thermal Rating: on line 584-8189 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2153
% INFO    : Updated Thermal Rating: on line 5190-949 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2071
% INFO    : Updated Thermal Rating: on line 3879-13196 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5329
% INFO    : Updated Thermal Rating: on line 9898-2843 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8258
% INFO    : Updated Thermal Rating: on line 12109-2843 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14124
% INFO    : Updated Thermal Rating: on line 8543-2600 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2276
% INFO    : Updated Thermal Rating: on line 2843-1894 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13375
% INFO    : Updated Thermal Rating: on line 9048-10879 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 127
% INFO    : Updated Thermal Rating: on line 7244-4172 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3756
% INFO    : Updated Thermal Rating: on line 7244-13259 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 240
% INFO    : Updated Thermal Rating: on line 7244-13259 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3604
% INFO    : Updated Thermal Rating: on line 7244-7096 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26
% INFO    : Updated Thermal Rating: on line 7244-8694 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23
% INFO    : Updated Thermal Rating: on line 9156-4172 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 49
% INFO    : Updated Thermal Rating: on line 1820-4172 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12855
% INFO    : Updated Thermal Rating: on line 13259-7096 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9
% INFO    : Updated Thermal Rating: on line 13259-8694 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9
% INFO    : Updated Thermal Rating: on line 3817-7035 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11
% INFO    : Updated Thermal Rating: on line 3817-11123 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12
% INFO    : Updated Thermal Rating: on line 7035-11123 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 7035-11123 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 227
% INFO    : Updated Thermal Rating: on line 7096-8694 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 7096-8694 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 161
% INFO    : Updated Thermal Rating: on line 11387-2319 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13537
% INFO    : Updated Thermal Rating: on line 8543-11387 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5735
% INFO    : Updated Thermal Rating: on line 2319-9426 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 45102
% INFO    : Updated Thermal Rating: on line 9571-2319 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 264
% INFO    : Updated Thermal Rating: on line 12360-13555 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 12360-13555 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 241
% INFO    : Updated Thermal Rating: on line 3879-8543 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 56
% INFO    : Updated Thermal Rating: on line 12271-12622 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3396
% INFO    : Updated Thermal Rating: on line 9567-12622 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3467
% INFO    : Updated Thermal Rating: on line 7123-6414 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6995
% INFO    : Updated Thermal Rating: on line 6414-9450 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3015
% INFO    : Updated Thermal Rating: on line 9745-6414 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7135
% INFO    : Updated Thermal Rating: on line 6414-1759 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2277
% INFO    : Updated Thermal Rating: on line 9567-12271 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 9567-12271 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 282
% INFO    : Updated Thermal Rating: on line 9567-7123 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5560
% INFO    : Updated Thermal Rating: on line 12271-9745 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5465
% INFO    : Updated Thermal Rating: on line 7123-9745 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 7123-9745 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 407
% INFO    : Updated Thermal Rating: on line 866-7123 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6090
% INFO    : Updated Thermal Rating: on line 3429-9745 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6196
% INFO    : Updated Thermal Rating: on line 866-3429 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 866-3429 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 488
% INFO    : Updated Thermal Rating: on line 4472-673 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21143
% INFO    : Updated Thermal Rating: on line 8588-2750 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 32102
% INFO    : Updated Thermal Rating: on line 7095-7494 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 139
% INFO    : Updated Thermal Rating: on line 7095-7494 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1899
% INFO    : Updated Thermal Rating: on line 9978-7095 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 785
% INFO    : Updated Thermal Rating: on line 3460-7095 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 703
% INFO    : Updated Thermal Rating: on line 7095-700 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2997
% INFO    : Updated Thermal Rating: on line 6245-8592 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1736
% INFO    : Updated Thermal Rating: on line 3497-6245 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1152
% INFO    : Updated Thermal Rating: on line 6245-12457 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14273
% INFO    : Updated Thermal Rating: on line 6245-12457 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14510
% INFO    : Updated Thermal Rating: on line 4556-9091 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15
% INFO    : Updated Thermal Rating: on line 9091-1723 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23
% INFO    : Updated Thermal Rating: on line 1771-9091 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24
% INFO    : Updated Thermal Rating: on line 7818-9091 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26
% INFO    : Updated Thermal Rating: on line 7012-9091 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 31
% INFO    : Updated Thermal Rating: on line 8784-9091 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 33
% INFO    : Updated Thermal Rating: on line 8784-9091 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3738
% INFO    : Updated Thermal Rating: on line 10047-9091 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 33
% INFO    : Updated Thermal Rating: on line 7818-9091 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2460
% INFO    : Updated Thermal Rating: on line 7472-10836 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 134762
% INFO    : Updated Thermal Rating: on line 6735-7472 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3352
% INFO    : Updated Thermal Rating: on line 7472-13600 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 100039
% INFO    : Updated Thermal Rating: on line 6735-9394 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3854
% INFO    : Updated Thermal Rating: on line 9394-228 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22
% INFO    : Updated Thermal Rating: on line 6735-9394 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22
% INFO    : Updated Thermal Rating: on line 7624-2750 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 35618
% INFO    : Updated Thermal Rating: on line 2312-673 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 48510
% INFO    : Updated Thermal Rating: on line 12086-673 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2838
% INFO    : Updated Thermal Rating: on line 12086-673 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2787
% INFO    : Updated Thermal Rating: on line 673-1209 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 844
% INFO    : Updated Thermal Rating: on line 11874-2750 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22316
% INFO    : Updated Thermal Rating: on line 10015-2750 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4218
% INFO    : Updated Thermal Rating: on line 10015-2750 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4121
% INFO    : Updated Thermal Rating: on line 2027-2750 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1661
% INFO    : Updated Thermal Rating: on line 1664-3793 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 124
% INFO    : Updated Thermal Rating: on line 568-1664 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10528
% INFO    : Updated Thermal Rating: on line 568-3793 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10723
% INFO    : Updated Thermal Rating: on line 8260-7011 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2498
% INFO    : Updated Thermal Rating: on line 8260-7011 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2804
% INFO    : Updated Thermal Rating: on line 2150-7011 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22903
% INFO    : Updated Thermal Rating: on line 6036-7011 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23392
% INFO    : Updated Thermal Rating: on line 12560-11092 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12380
% INFO    : Updated Thermal Rating: on line 6561-10372 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23826
% INFO    : Updated Thermal Rating: on line 12560-10372 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 58
% INFO    : Updated Thermal Rating: on line 11208-10372 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 30
% INFO    : Updated Thermal Rating: on line 11358-10015 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13
% INFO    : Updated Thermal Rating: on line 11358-239 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23
% INFO    : Updated Thermal Rating: on line 10225-11358 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 92
% INFO    : Updated Thermal Rating: on line 11358-3751 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1011
% INFO    : Updated Thermal Rating: on line 12769-11358 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12
% INFO    : Updated Thermal Rating: on line 8118-11358 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11
% INFO    : Updated Thermal Rating: on line 11358-7766 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2750
% INFO    : Updated Thermal Rating: on line 3636-7018 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 61
% INFO    : Updated Thermal Rating: on line 3636-13016 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 46
% INFO    : Updated Thermal Rating: on line 2365-3636 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 62
% INFO    : Updated Thermal Rating: on line 9625-3636 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 739
% INFO    : Updated Thermal Rating: on line 10196-2605 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 125947
% INFO    : Updated Thermal Rating: on line 7527-6511 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 41734
% INFO    : Updated Thermal Rating: on line 1425-9736 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 227
% INFO    : Updated Thermal Rating: on line 1425-3452 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5017
% INFO    : Updated Thermal Rating: on line 1950-13449 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 170
% INFO    : Updated Thermal Rating: on line 1950-3452 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4990
% INFO    : Updated Thermal Rating: on line 8659-831 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 40229
% INFO    : Updated Thermal Rating: on line 8659-10149 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15386
% INFO    : Updated Thermal Rating: on line 7126-831 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 43585
% INFO    : Updated Thermal Rating: on line 7126-3731 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5594
% INFO    : Updated Thermal Rating: on line 6564-1723 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5194
% INFO    : Updated Thermal Rating: on line 3227-831 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3234
% INFO    : Updated Thermal Rating: on line 9245-831 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6433
% INFO    : Updated Thermal Rating: on line 831-6591 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14275
% INFO    : Updated Thermal Rating: on line 5394-1983 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9199
% INFO    : Updated Thermal Rating: on line 10400-1983 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3387
% INFO    : Updated Thermal Rating: on line 4734-1983 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3967
% INFO    : Updated Thermal Rating: on line 4506-4734 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18941
% INFO    : Updated Thermal Rating: on line 1983-12051 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 1983-12051 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 72
% INFO    : Updated Thermal Rating: on line 1872-12051 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9318
% INFO    : Updated Thermal Rating: on line 9978-4168 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4600
% INFO    : Updated Thermal Rating: on line 2638-4168 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4698
% INFO    : Updated Thermal Rating: on line 10576-7018 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2791
% INFO    : Updated Thermal Rating: on line 7155-4506 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16041
% INFO    : Updated Thermal Rating: on line 11867-4506 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15881
% INFO    : Updated Thermal Rating: on line 1872-7835 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 108
% INFO    : Updated Thermal Rating: on line 1872-7835 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11428
% INFO    : Updated Thermal Rating: on line 5394-7835 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 107
% INFO    : Updated Thermal Rating: on line 12294-13042 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 186
% INFO    : Updated Thermal Rating: on line 12294-228 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 123
% INFO    : Updated Thermal Rating: on line 6735-12294 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10872
% INFO    : Updated Thermal Rating: on line 13042-228 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 134
% INFO    : Updated Thermal Rating: on line 6735-13042 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11088
% INFO    : Updated Thermal Rating: on line 12698-7216 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4404
% INFO    : Updated Thermal Rating: on line 12698-996 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4865
% INFO    : Updated Thermal Rating: on line 10914-7216 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4252
% INFO    : Updated Thermal Rating: on line 7216-9396 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 127
% INFO    : Updated Thermal Rating: on line 7216-1648 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 87286
% INFO    : Updated Thermal Rating: on line 7216-5806 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 77250
% INFO    : Updated Thermal Rating: on line 7216-3804 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3285
% INFO    : Updated Thermal Rating: on line 7216-793 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 88
% INFO    : Updated Thermal Rating: on line 7216-996 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 97
% INFO    : Updated Thermal Rating: on line 7216-5661 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 93
% INFO    : Updated Thermal Rating: on line 7216-8211 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 114188
% INFO    : Updated Thermal Rating: on line 3486-228 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17129
% INFO    : Updated Thermal Rating: on line 6735-3486 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2678
% INFO    : Updated Thermal Rating: on line 3881-3486 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6948
% INFO    : Updated Thermal Rating: on line 4233-228 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16554
% INFO    : Updated Thermal Rating: on line 6735-4233 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2728
% INFO    : Updated Thermal Rating: on line 3881-4233 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7489
% INFO    : Updated Thermal Rating: on line 6735-228 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 75
% INFO    : Updated Thermal Rating: on line 6735-1246 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 51
% INFO    : Updated Thermal Rating: on line 6735-10093 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 69
% INFO    : Updated Thermal Rating: on line 6735-3748 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 32
% INFO    : Updated Thermal Rating: on line 6735-4956 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4283
% INFO    : Updated Thermal Rating: on line 12086-6981 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 800
% INFO    : Updated Thermal Rating: on line 12086-9444 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2499
% INFO    : Updated Thermal Rating: on line 10225-10015 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 94
% INFO    : Updated Thermal Rating: on line 10225-10015 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 556
% INFO    : Updated Thermal Rating: on line 10015-13635 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2545
% INFO    : Updated Thermal Rating: on line 4506-1820 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1642
% INFO    : Updated Thermal Rating: on line 4506-9278 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1476
% INFO    : Updated Thermal Rating: on line 4506-1820 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1744
% INFO    : Updated Thermal Rating: on line 4506-13547 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1429
% INFO    : Updated Thermal Rating: on line 10400-4506 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2760
% INFO    : Updated Thermal Rating: on line 4506-148 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1539
% INFO    : Updated Thermal Rating: on line 3227-2839 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5406
% INFO    : Updated Thermal Rating: on line 3227-13598 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14299
% INFO    : Updated Thermal Rating: on line 3227-3982 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13990
% INFO    : Updated Thermal Rating: on line 3227-10055 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5972
% INFO    : Updated Thermal Rating: on line 3227-10045 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5510
% INFO    : Updated Thermal Rating: on line 3227-4841 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2565
% INFO    : Updated Thermal Rating: on line 3227-10493 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5366
% INFO    : Updated Thermal Rating: on line 9468-118 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11436
% INFO    : Updated Thermal Rating: on line 9468-1149 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 33771
% INFO    : Updated Thermal Rating: on line 13539-4244 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18906
% INFO    : Updated Thermal Rating: on line 13539-4244 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19249
% INFO    : Updated Thermal Rating: on line 5541-7990 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3286
% INFO    : Updated Thermal Rating: on line 5541-11324 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3151
% INFO    : Updated Thermal Rating: on line 2771-7990 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3355
% INFO    : Updated Thermal Rating: on line 2771-13521 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3220
% INFO    : Updated Thermal Rating: on line 5541-2771 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 176
% INFO    : Updated Thermal Rating: on line 5541-11324 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9
% INFO    : Updated Thermal Rating: on line 5541-13521 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 31
% INFO    : Updated Thermal Rating: on line 992-5541 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13
% INFO    : Updated Thermal Rating: on line 5541-11314 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19
% INFO    : Updated Thermal Rating: on line 5541-6768 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13
% INFO    : Updated Thermal Rating: on line 2771-11324 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9
% INFO    : Updated Thermal Rating: on line 2771-13521 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 35
% INFO    : Updated Thermal Rating: on line 992-2771 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13
% INFO    : Updated Thermal Rating: on line 2771-11314 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19
% INFO    : Updated Thermal Rating: on line 2771-6768 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15
% INFO    : Updated Thermal Rating: on line 700-13243 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1434
% INFO    : Updated Thermal Rating: on line 700-13243 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1062
% INFO    : Updated Thermal Rating: on line 10203-13243 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 872
% INFO    : Updated Thermal Rating: on line 7494-13243 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3170
% INFO    : Updated Thermal Rating: on line 4593-13243 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 940
% INFO    : Updated Thermal Rating: on line 12918-5993 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 122
% INFO    : Updated Thermal Rating: on line 10087-12918 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25
% INFO    : Updated Thermal Rating: on line 8361-12918 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 32
% INFO    : Updated Thermal Rating: on line 8361-12918 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2258
% INFO    : Updated Thermal Rating: on line 3229-12918 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3439
% INFO    : Updated Thermal Rating: on line 490-12918 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2444
% INFO    : Updated Thermal Rating: on line 10087-5993 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23
% INFO    : Updated Thermal Rating: on line 10087-5993 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1985
% INFO    : Updated Thermal Rating: on line 8361-5993 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 35
% INFO    : Updated Thermal Rating: on line 680-5993 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2638
% INFO    : Updated Thermal Rating: on line 10400-1649 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 35
% INFO    : Updated Thermal Rating: on line 10400-1649 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9468
% INFO    : Updated Thermal Rating: on line 1626-6080 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2385
% INFO    : Updated Thermal Rating: on line 6080-3278 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 459
% INFO    : Updated Thermal Rating: on line 10734-5459 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8416
% INFO    : Updated Thermal Rating: on line 10734-239 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7435
% INFO    : Updated Thermal Rating: on line 10734-7766 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2740
% INFO    : Updated Thermal Rating: on line 1195-5459 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9029
% INFO    : Updated Thermal Rating: on line 1195-239 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8158
% INFO    : Updated Thermal Rating: on line 1195-7766 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2846
% INFO    : Updated Thermal Rating: on line 5459-7573 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 43458
% INFO    : Updated Thermal Rating: on line 5459-1924 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 39503
% INFO    : Updated Thermal Rating: on line 5459-10749 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 128848
% INFO    : Updated Thermal Rating: on line 5459-1225 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 123896
% INFO    : Updated Thermal Rating: on line 12769-5459 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 43808
% INFO    : Updated Thermal Rating: on line 8118-5459 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 43428
% INFO    : Updated Thermal Rating: on line 959-6104 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1972
% INFO    : Updated Thermal Rating: on line 6104-12768 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 81
% INFO    : Updated Thermal Rating: on line 6104-9268 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 36
% INFO    : Updated Thermal Rating: on line 6104-5095 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18
% INFO    : Updated Thermal Rating: on line 6104-7630 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16
% INFO    : Updated Thermal Rating: on line 6104-12875 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 43
% INFO    : Updated Thermal Rating: on line 5550-6104 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16
% INFO    : Updated Thermal Rating: on line 5687-6104 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16
% INFO    : Updated Thermal Rating: on line 6104-11156 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18
% INFO    : Updated Thermal Rating: on line 6104-11156 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1119
% INFO    : Updated Thermal Rating: on line 10904-8870 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26
% INFO    : Updated Thermal Rating: on line 10904-8870 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5437
% INFO    : Updated Thermal Rating: on line 6561-10188 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 256
% INFO    : Updated Thermal Rating: on line 22-6561 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4385
% INFO    : Updated Thermal Rating: on line 5227-6561 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4472
% INFO    : Updated Thermal Rating: on line 6561-12560 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4311
% INFO    : Updated Thermal Rating: on line 6561-12560 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4385
% INFO    : Updated Thermal Rating: on line 959-12875 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5970
% INFO    : Updated Thermal Rating: on line 10914-9245 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3035
% INFO    : Updated Thermal Rating: on line 10914-7486 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1247
% INFO    : Updated Thermal Rating: on line 10914-1136 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1110
% INFO    : Updated Thermal Rating: on line 10914-4749 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 105
% INFO    : Updated Thermal Rating: on line 10914-9268 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52
% INFO    : Updated Thermal Rating: on line 10914-9245 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 98
% INFO    : Updated Thermal Rating: on line 10914-8458 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3074
% INFO    : Updated Thermal Rating: on line 10914-4749 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1582
% INFO    : Updated Thermal Rating: on line 12475-10271 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8178
% INFO    : Updated Thermal Rating: on line 12475-1149 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13669
% INFO    : Updated Thermal Rating: on line 12475-1605 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13372
% INFO    : Updated Thermal Rating: on line 12475-2728 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2934
% INFO    : Updated Thermal Rating: on line 3503-12560 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2359
% INFO    : Updated Thermal Rating: on line 3503-4305 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2553
% INFO    : Updated Thermal Rating: on line 462-8592 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 83
% INFO    : Updated Thermal Rating: on line 462-8592 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1376
% INFO    : Updated Thermal Rating: on line 462-7521 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20196
% INFO    : Updated Thermal Rating: on line 462-8936 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21
% INFO    : Updated Thermal Rating: on line 462-7527 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on line 462-11961 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 49
% INFO    : Updated Thermal Rating: on line 462-3731 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 47
% INFO    : Updated Thermal Rating: on line 12457-462 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 28
% INFO    : Updated Thermal Rating: on line 996-462 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2144
% INFO    : Updated Thermal Rating: on line 11205-9944 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2334
% INFO    : Updated Thermal Rating: on line 11205-9944 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2381
% INFO    : Updated Thermal Rating: on line 6855-7527 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 155017
% INFO    : Updated Thermal Rating: on line 928-7527 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 100595
% INFO    : Updated Thermal Rating: on line 5214-10026 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4490
% INFO    : Updated Thermal Rating: on line 5214-7818 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11595
% INFO    : Updated Thermal Rating: on line 2427-4556 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11523
% INFO    : Updated Thermal Rating: on line 2427-1723 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13188
% INFO    : Updated Thermal Rating: on line 2427-7818 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11350
% INFO    : Updated Thermal Rating: on line 4556-1723 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 53
% INFO    : Updated Thermal Rating: on line 1771-4556 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 82
% INFO    : Updated Thermal Rating: on line 4556-7818 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 42
% INFO    : Updated Thermal Rating: on line 4556-7012 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 39
% INFO    : Updated Thermal Rating: on line 8784-4556 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11
% INFO    : Updated Thermal Rating: on line 10047-4556 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12
% INFO    : Updated Thermal Rating: on line 12769-239 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 78
% INFO    : Updated Thermal Rating: on line 8118-239 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 83
% INFO    : Updated Thermal Rating: on line 13547-2201 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8255
% INFO    : Updated Thermal Rating: on line 13547-2201 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8380
% INFO    : Updated Thermal Rating: on line 12768-11310 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 35865
% INFO    : Updated Thermal Rating: on line 9268-12768 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22
% INFO    : Updated Thermal Rating: on line 5095-12768 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11
% INFO    : Updated Thermal Rating: on line 12768-7630 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9
% INFO    : Updated Thermal Rating: on line 12768-12875 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27
% INFO    : Updated Thermal Rating: on line 5550-12768 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10
% INFO    : Updated Thermal Rating: on line 5687-12768 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11
% INFO    : Updated Thermal Rating: on line 11156-12768 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11
% INFO    : Updated Thermal Rating: on line 1246-13179 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 56662
% INFO    : Updated Thermal Rating: on line 10093-1246 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 84
% INFO    : Updated Thermal Rating: on line 1246-3748 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10
% INFO    : Updated Thermal Rating: on line 4372-13179 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14444
% INFO    : Updated Thermal Rating: on line 10093-11310 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4953
% INFO    : Updated Thermal Rating: on line 10093-13179 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6036
% INFO    : Updated Thermal Rating: on line 8454-3748 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2982
% INFO    : Updated Thermal Rating: on line 784-2886 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10042
% INFO    : Updated Thermal Rating: on line 784-4956 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2633
% INFO    : Updated Thermal Rating: on line 10188-12560 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9857
% INFO    : Updated Thermal Rating: on line 10188-4305 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1262
% INFO    : Updated Thermal Rating: on line 11136-6099 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8871
% INFO    : Updated Thermal Rating: on line 11676-3799 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9047
% INFO    : Updated Thermal Rating: on line 2365-11676 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1327
% INFO    : Updated Thermal Rating: on line 11205-1136 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7606
% INFO    : Updated Thermal Rating: on line 11205-8603 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9047
% INFO    : Updated Thermal Rating: on line 3460-11205 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3500
% INFO    : Updated Thermal Rating: on line 11205-7486 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7439
% INFO    : Updated Thermal Rating: on line 2638-11205 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3832
% INFO    : Updated Thermal Rating: on line 9268-3870 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8742
% INFO    : Updated Thermal Rating: on line 3870-12875 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4808
% INFO    : Updated Thermal Rating: on line 13249-10728 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 60345
% INFO    : Updated Thermal Rating: on line 13249-11674 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6506
% INFO    : Updated Thermal Rating: on line 7818-10728 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 61361
% INFO    : Updated Thermal Rating: on line 10962-8592 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 134762
% INFO    : Updated Thermal Rating: on line 1865-8592 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 101652
% INFO    : Updated Thermal Rating: on line 6021-8592 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 91231
% INFO    : Updated Thermal Rating: on line 8936-8592 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14
% INFO    : Updated Thermal Rating: on line 7527-8592 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on line 8592-11961 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16
% INFO    : Updated Thermal Rating: on line 8592-3731 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19
% INFO    : Updated Thermal Rating: on line 122-8592 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2004
% INFO    : Updated Thermal Rating: on line 12457-8592 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 28
% INFO    : Updated Thermal Rating: on line 6683-8592 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1846
% INFO    : Updated Thermal Rating: on line 3153-8592 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1242
% INFO    : Updated Thermal Rating: on line 10794-8592 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1812
% INFO    : Updated Thermal Rating: on line 1771-1723 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 48
% INFO    : Updated Thermal Rating: on line 23-1723 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7867
% INFO    : Updated Thermal Rating: on line 7818-1723 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 54
% INFO    : Updated Thermal Rating: on line 7012-1723 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 53
% INFO    : Updated Thermal Rating: on line 8784-1723 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14
% INFO    : Updated Thermal Rating: on line 10047-1723 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14
% INFO    : Updated Thermal Rating: on line 7818-1723 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6955
% INFO    : Updated Thermal Rating: on line 23-1723 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7166
% INFO    : Updated Thermal Rating: on line 3382-3748 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4044
% INFO    : Updated Thermal Rating: on line 3382-12875 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2241
% INFO    : Updated Thermal Rating: on line 7330-4570 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20547
% INFO    : Updated Thermal Rating: on line 7330-9013 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18011
% INFO    : Updated Thermal Rating: on line 7330-13631 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11374
% INFO    : Updated Thermal Rating: on line 10093-3748 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14
% INFO    : Updated Thermal Rating: on line 10093-12875 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2133
% INFO    : Updated Thermal Rating: on line 10093-4956 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5213
% INFO    : Updated Thermal Rating: on line 7527-8936 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5
% INFO    : Updated Thermal Rating: on line 7527-8936 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 808
% INFO    : Updated Thermal Rating: on line 8936-11961 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24
% INFO    : Updated Thermal Rating: on line 8936-11961 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 564
% INFO    : Updated Thermal Rating: on line 8936-3731 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21
% INFO    : Updated Thermal Rating: on line 12457-8936 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19
% INFO    : Updated Thermal Rating: on line 3081-6522 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on line 3081-6522 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3610
% INFO    : Updated Thermal Rating: on line 6522-2602 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25
% INFO    : Updated Thermal Rating: on line 6522-5257 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 6522-10026 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20
% INFO    : Updated Thermal Rating: on line 12854-2602 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2453
% INFO    : Updated Thermal Rating: on line 22-5227 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 22-5227 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25
% INFO    : Updated Thermal Rating: on line 22-2886 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 79
% INFO    : Updated Thermal Rating: on line 3881-22 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 48
% INFO    : Updated Thermal Rating: on line 10203-22 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 42
% INFO    : Updated Thermal Rating: on line 4593-22 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 34
% INFO    : Updated Thermal Rating: on line 22-12980 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4377
% INFO    : Updated Thermal Rating: on line 5227-2886 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20
% INFO    : Updated Thermal Rating: on line 3881-5227 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 60
% INFO    : Updated Thermal Rating: on line 10203-5227 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 40
% INFO    : Updated Thermal Rating: on line 4593-5227 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 70
% INFO    : Updated Thermal Rating: on line 4593-5227 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2398
% INFO    : Updated Thermal Rating: on line 2977-8996 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1941
% INFO    : Updated Thermal Rating: on line 1771-7818 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 46
% INFO    : Updated Thermal Rating: on line 1771-7012 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 55
% INFO    : Updated Thermal Rating: on line 1771-8784 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 29
% INFO    : Updated Thermal Rating: on line 1771-10047 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 29
% INFO    : Updated Thermal Rating: on line 1771-7818 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3454
% INFO    : Updated Thermal Rating: on line 5686-2525 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 80755
% INFO    : Updated Thermal Rating: on line 909-5686 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4825
% INFO    : Updated Thermal Rating: on line 6916-5686 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4154
% INFO    : Updated Thermal Rating: on line 909-5686 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4927
% INFO    : Updated Thermal Rating: on line 6916-5686 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3841
% INFO    : Updated Thermal Rating: on line 3497-7527 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1318
% INFO    : Updated Thermal Rating: on line 7527-11961 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 7527-3731 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 12457-7527 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15
% INFO    : Updated Thermal Rating: on line 3081-2602 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 3081-5257 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 49
% INFO    : Updated Thermal Rating: on line 3081-887 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3713
% INFO    : Updated Thermal Rating: on line 3081-10026 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18
% INFO    : Updated Thermal Rating: on line 3081-10026 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2884
% INFO    : Updated Thermal Rating: on line 6598-3081 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2605
% INFO    : Updated Thermal Rating: on line 3081-6051 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4794
% INFO    : Updated Thermal Rating: on line 3081-2602 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1437
% INFO    : Updated Thermal Rating: on line 3081-11534 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23215
% INFO    : Updated Thermal Rating: on line 7151-10045 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17924
% INFO    : Updated Thermal Rating: on line 5095-7151 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3392
% INFO    : Updated Thermal Rating: on line 3452-7151 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11800
% INFO    : Updated Thermal Rating: on line 2839-10045 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 119
% INFO    : Updated Thermal Rating: on line 7235-2839 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 81
% INFO    : Updated Thermal Rating: on line 2839-3425 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10902
% INFO    : Updated Thermal Rating: on line 3452-2839 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 114
% INFO    : Updated Thermal Rating: on line 7235-10045 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 93
% INFO    : Updated Thermal Rating: on line 10045-5195 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11119
% INFO    : Updated Thermal Rating: on line 3452-10045 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 132
% INFO    : Updated Thermal Rating: on line 7235-8228 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2487
% INFO    : Updated Thermal Rating: on line 3819-9396 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2619
% INFO    : Updated Thermal Rating: on line 793-9396 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 49
% INFO    : Updated Thermal Rating: on line 793-9396 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2894
% INFO    : Updated Thermal Rating: on line 9396-6496 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9455
% INFO    : Updated Thermal Rating: on line 996-9396 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 40
% INFO    : Updated Thermal Rating: on line 5661-9396 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 33
% INFO    : Updated Thermal Rating: on line 10610-9396 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11517
% INFO    : Updated Thermal Rating: on line 1179-1605 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15622
% INFO    : Updated Thermal Rating: on line 8361-1179 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 64
% INFO    : Updated Thermal Rating: on line 1179-10846 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10405
% INFO    : Updated Thermal Rating: on line 10087-8361 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 125
% INFO    : Updated Thermal Rating: on line 10087-2728 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10893
% INFO    : Updated Thermal Rating: on line 4030-13521 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 36999
% INFO    : Updated Thermal Rating: on line 4030-13521 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 36155
% INFO    : Updated Thermal Rating: on line 4030-13521 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 35383
% INFO    : Updated Thermal Rating: on line 4735-8996 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11
% INFO    : Updated Thermal Rating: on line 444-8996 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 41
% INFO    : Updated Thermal Rating: on line 6259-8996 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 74
% INFO    : Updated Thermal Rating: on line 6259-8996 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1302
% INFO    : Updated Thermal Rating: on line 5946-3742 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 405
% INFO    : Updated Thermal Rating: on line 7609-5946 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 295
% INFO    : Updated Thermal Rating: on line 5946-7456 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 452
% INFO    : Updated Thermal Rating: on line 185-3742 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 121
% INFO    : Updated Thermal Rating: on line 13016-3742 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 508
% INFO    : Updated Thermal Rating: on line 185-3742 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3128
% INFO    : Updated Thermal Rating: on line 1820-8836 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2247
% INFO    : Updated Thermal Rating: on line 6916-1820 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1614
% INFO    : Updated Thermal Rating: on line 12543-6981 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1152
% INFO    : Updated Thermal Rating: on line 7766-12543 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1825
% INFO    : Updated Thermal Rating: on line 12543-2779 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 35
% INFO    : Updated Thermal Rating: on line 12543-6981 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 137
% INFO    : Updated Thermal Rating: on line 444-4735 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 31
% INFO    : Updated Thermal Rating: on line 4735-6259 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 56
% INFO    : Updated Thermal Rating: on line 4735-2128 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1586
% INFO    : Updated Thermal Rating: on line 9641-1149 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 77
% INFO    : Updated Thermal Rating: on line 9641-2791 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 31461
% INFO    : Updated Thermal Rating: on line 9641-6117 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3334
% INFO    : Updated Thermal Rating: on line 9641-6597 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 55
% INFO    : Updated Thermal Rating: on line 6079-3229 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 29393
% INFO    : Updated Thermal Rating: on line 6079-148 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3566
% INFO    : Updated Thermal Rating: on line 3497-444 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1425
% INFO    : Updated Thermal Rating: on line 444-6259 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142
% INFO    : Updated Thermal Rating: on line 444-2536 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4223
% INFO    : Updated Thermal Rating: on line 8677-11860 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 114
% INFO    : Updated Thermal Rating: on line 8677-11860 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1203
% INFO    : Updated Thermal Rating: on line 11860-9658 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 63
% INFO    : Updated Thermal Rating: on line 11860-9658 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1223
% INFO    : Updated Thermal Rating: on line 1626-11860 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 31
% INFO    : Updated Thermal Rating: on line 118-1149 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 97
% INFO    : Updated Thermal Rating: on line 1149-6597 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 117
% INFO    : Updated Thermal Rating: on line 568-870 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13633
% INFO    : Updated Thermal Rating: on line 11136-1431 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6256
% INFO    : Updated Thermal Rating: on line 11136-7018 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 30
% INFO    : Updated Thermal Rating: on line 9625-11136 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1371
% INFO    : Updated Thermal Rating: on line 2779-1209 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 55
% INFO    : Updated Thermal Rating: on line 2779-2027 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157
% INFO    : Updated Thermal Rating: on line 2779-2027 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1608
% INFO    : Updated Thermal Rating: on line 2779-3751 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1663
% INFO    : Updated Thermal Rating: on line 2779-6981 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on line 6965-8677 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1363
% INFO    : Updated Thermal Rating: on line 6965-545 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 236
% INFO    : Updated Thermal Rating: on line 10229-5661 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7112
% INFO    : Updated Thermal Rating: on line 5557-4944 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7523
% INFO    : Updated Thermal Rating: on line 5557-490 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12434
% INFO    : Updated Thermal Rating: on line 7488-3881 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4552
% INFO    : Updated Thermal Rating: on line 5557-3447 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 34
% INFO    : Updated Thermal Rating: on line 5557-3260 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 34
% INFO    : Updated Thermal Rating: on line 3546-10045 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 166
% INFO    : Updated Thermal Rating: on line 5710-3546 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 162
% INFO    : Updated Thermal Rating: on line 5710-10045 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 153
% INFO    : Updated Thermal Rating: on line 854-3229 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 100
% INFO    : Updated Thermal Rating: on line 854-148 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 89
% INFO    : Updated Thermal Rating: on line 854-148 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9284
% INFO    : Updated Thermal Rating: on line 854-9278 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 83
% INFO    : Updated Thermal Rating: on line 5394-1872 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 5394-1872 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 122
% INFO    : Updated Thermal Rating: on line 7216-3421 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 76660
% INFO    : Updated Thermal Rating: on line 10610-7216 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7657
% INFO    : Updated Thermal Rating: on line 6637-2431 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 6637-2431 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 49
% INFO    : Updated Thermal Rating: on line 793-6637 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3920
% INFO    : Updated Thermal Rating: on line 996-6637 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 51
% INFO    : Updated Thermal Rating: on line 10794-6637 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 48
% INFO    : Updated Thermal Rating: on line 6683-6637 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 38
% INFO    : Updated Thermal Rating: on line 122-2431 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 919
% INFO    : Updated Thermal Rating: on line 996-2431 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 51
% INFO    : Updated Thermal Rating: on line 10794-2431 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 40
% INFO    : Updated Thermal Rating: on line 6683-2431 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 45
% INFO    : Updated Thermal Rating: on line 5394-3229 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3187
% INFO    : Updated Thermal Rating: on line 5257-2602 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on line 2602-10026 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12
% INFO    : Updated Thermal Rating: on line 11961-3731 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 61
% INFO    : Updated Thermal Rating: on line 11961-3731 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 12457-11961 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9
% INFO    : Updated Thermal Rating: on line 5661-11961 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1863
% INFO    : Updated Thermal Rating: on line 13280-11961 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4681
% INFO    : Updated Thermal Rating: on line 12457-3731 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8
% INFO    : Updated Thermal Rating: on line 5364-2602 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21329
% INFO    : Updated Thermal Rating: on line 7756-2602 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12425
% INFO    : Updated Thermal Rating: on line 5562-2602 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8430
% INFO    : Updated Thermal Rating: on line 1609-2602 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22049
% INFO    : Updated Thermal Rating: on line 8890-2602 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19511
% INFO    : Updated Thermal Rating: on line 6776-2536 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8137
% INFO    : Updated Thermal Rating: on line 9268-10850 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11824
% INFO    : Updated Thermal Rating: on line 9268-2718 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11886
% INFO    : Updated Thermal Rating: on line 3819-996 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3992
% INFO    : Updated Thermal Rating: on line 793-996 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52
% INFO    : Updated Thermal Rating: on line 793-5661 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 57
% INFO    : Updated Thermal Rating: on line 793-5661 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4184
% INFO    : Updated Thermal Rating: on line 12850-2525 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 31
% INFO    : Updated Thermal Rating: on line 12850-909 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5796
% INFO    : Updated Thermal Rating: on line 12850-909 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 62
% INFO    : Updated Thermal Rating: on line 12850-2114 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 80
% INFO    : Updated Thermal Rating: on line 12850-2114 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5285
% INFO    : Updated Thermal Rating: on line 12850-6916 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14
% INFO    : Updated Thermal Rating: on line 2114-6268 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2179
% INFO    : Updated Thermal Rating: on line 6916-6268 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2267
% INFO    : Updated Thermal Rating: on line 909-2525 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 40
% INFO    : Updated Thermal Rating: on line 2114-2525 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25
% INFO    : Updated Thermal Rating: on line 6916-2525 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 47
% INFO    : Updated Thermal Rating: on line 13539-23 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14703
% INFO    : Updated Thermal Rating: on line 13539-23 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15881
% INFO    : Updated Thermal Rating: on line 7818-7012 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 33
% INFO    : Updated Thermal Rating: on line 8784-7818 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23
% INFO    : Updated Thermal Rating: on line 10047-7818 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 28
% INFO    : Updated Thermal Rating: on line 8784-7012 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18
% INFO    : Updated Thermal Rating: on line 10047-7012 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19
% INFO    : Updated Thermal Rating: on line 7818-7012 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 131160
% INFO    : Updated Thermal Rating: on line 490-5784 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 86
% INFO    : Updated Thermal Rating: on line 680-5784 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 87
% INFO    : Updated Thermal Rating: on line 680-5784 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5057
% INFO    : Updated Thermal Rating: on line 5784-148 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3896
% INFO    : Updated Thermal Rating: on line 2728-8361 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6115
% INFO    : Updated Thermal Rating: on line 148-3229 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 55
% INFO    : Updated Thermal Rating: on line 9278-3229 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 62
% INFO    : Updated Thermal Rating: on line 6259-2128 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1904
% INFO    : Updated Thermal Rating: on line 6259-2128 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2173
% INFO    : Updated Thermal Rating: on line 6259-2536 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3069
% INFO    : Updated Thermal Rating: on line 6259-2536 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2672
% INFO    : Updated Thermal Rating: on line 1431-7018 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1389
% INFO    : Updated Thermal Rating: on line 568-1431 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 571
% INFO    : Updated Thermal Rating: on line 2027-1209 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 231
% INFO    : Updated Thermal Rating: on line 2027-1209 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1028
% INFO    : Updated Thermal Rating: on line 5257-11534 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4651
% INFO    : Updated Thermal Rating: on line 5257-10026 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9
% INFO    : Updated Thermal Rating: on line 2778-6496 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2117
% INFO    : Updated Thermal Rating: on line 2886-2778 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1889
% INFO    : Updated Thermal Rating: on line 9268-4749 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 70
% INFO    : Updated Thermal Rating: on line 11208-4749 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1352
% INFO    : Updated Thermal Rating: on line 3897-5562 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 29005
% INFO    : Updated Thermal Rating: on line 3897-13539 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26336
% INFO    : Updated Thermal Rating: on line 2791-13539 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13496
% INFO    : Updated Thermal Rating: on line 2556-2791 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16231
% INFO    : Updated Thermal Rating: on line 13539-11674 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 30
% INFO    : Updated Thermal Rating: on line 13539-10846 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7924
% INFO    : Updated Thermal Rating: on line 8044-3881 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2501
% INFO    : Updated Thermal Rating: on line 8044-568 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1505
% INFO    : Updated Thermal Rating: on line 8044-10203 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23
% INFO    : Updated Thermal Rating: on line 8044-3171 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13
% INFO    : Updated Thermal Rating: on line 13339-9658 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1245
% INFO    : Updated Thermal Rating: on line 909-2114 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 39
% INFO    : Updated Thermal Rating: on line 6916-909 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14
% INFO    : Updated Thermal Rating: on line 8677-9658 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 36
% INFO    : Updated Thermal Rating: on line 8677-545 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1003
% INFO    : Updated Thermal Rating: on line 1626-8677 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 105
% INFO    : Updated Thermal Rating: on line 1626-8677 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1464
% INFO    : Updated Thermal Rating: on line 13547-10196 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9632
% INFO    : Updated Thermal Rating: on line 73-3452 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8495
% INFO    : Updated Thermal Rating: on line 73-8685 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6583
% INFO    : Updated Thermal Rating: on line 9268-5095 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5
% INFO    : Updated Thermal Rating: on line 9268-7630 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5
% INFO    : Updated Thermal Rating: on line 9268-12875 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 97
% INFO    : Updated Thermal Rating: on line 5550-9268 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5
% INFO    : Updated Thermal Rating: on line 5687-9268 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5
% INFO    : Updated Thermal Rating: on line 5710-9268 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8500
% INFO    : Updated Thermal Rating: on line 9268-2854 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 113
% INFO    : Updated Thermal Rating: on line 9268-2854 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6362
% INFO    : Updated Thermal Rating: on line 9268-11156 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on line 9268-11156 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 109
% INFO    : Updated Thermal Rating: on line 9268-11156 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2370
% INFO    : Updated Thermal Rating: on line 9571-2027 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4276
% INFO    : Updated Thermal Rating: on line 9571-2027 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4365
% INFO    : Updated Thermal Rating: on line 4956-7069 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3835
% INFO    : Updated Thermal Rating: on line 2886-3744 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1914
% INFO    : Updated Thermal Rating: on line 12560-10354 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1760
% INFO    : Updated Thermal Rating: on line 9013-6971 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 59336
% INFO    : Updated Thermal Rating: on line 4944-5773 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 62725
% INFO    : Updated Thermal Rating: on line 4944-8353 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 66966
% INFO    : Updated Thermal Rating: on line 12875-238 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1902
% INFO    : Updated Thermal Rating: on line 12000-8077 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16041
% INFO    : Updated Thermal Rating: on line 2728-9397 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5366
% INFO    : Updated Thermal Rating: on line 12000-2453 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17169
% INFO    : Updated Thermal Rating: on line 9013-3732 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16904
% INFO    : Updated Thermal Rating: on line 8784-10047 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 8784-10047 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 77
% INFO    : Updated Thermal Rating: on line 8784-7818 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1444
% INFO    : Updated Thermal Rating: on line 10225-6981 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 734
% INFO    : Updated Thermal Rating: on line 118-7121 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12453
% INFO    : Updated Thermal Rating: on line 118-6597 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52
% INFO    : Updated Thermal Rating: on line 3748-4305 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15930
% INFO    : Updated Thermal Rating: on line 3748-4305 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14564
% INFO    : Updated Thermal Rating: on line 7235-3985 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3591
% INFO    : Updated Thermal Rating: on line 5550-7235 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1317
% INFO    : Updated Thermal Rating: on line 5687-7235 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1343
% INFO    : Updated Thermal Rating: on line 8685-7235 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7490
% INFO    : Updated Thermal Rating: on line 7235-3452 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 72
% INFO    : Updated Thermal Rating: on line 5095-7630 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 94
% INFO    : Updated Thermal Rating: on line 5095-12875 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on line 5550-5095 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 85
% INFO    : Updated Thermal Rating: on line 5687-5095 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 84
% INFO    : Updated Thermal Rating: on line 5095-6591 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1767
% INFO    : Updated Thermal Rating: on line 11156-5095 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 81
% INFO    : Updated Thermal Rating: on line 9487-5364 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6059
% INFO    : Updated Thermal Rating: on line 9487-12671 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13839
% INFO    : Updated Thermal Rating: on line 9487-7121 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5946
% INFO    : Updated Thermal Rating: on line 9487-7869 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10286
% INFO    : Updated Thermal Rating: on line 6824-8260 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2104
% INFO    : Updated Thermal Rating: on line 10082-8260 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2289
% INFO    : Updated Thermal Rating: on line 3171-8260 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1421
% INFO    : Updated Thermal Rating: on line 9726-8260 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1977
% INFO    : Updated Thermal Rating: on line 13614-8260 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2432
% INFO    : Updated Thermal Rating: on line 3171-8260 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 95
% INFO    : Updated Thermal Rating: on line 8616-7990 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3601
% INFO    : Updated Thermal Rating: on line 13547-7990 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2007
% INFO    : Updated Thermal Rating: on line 5413-13521 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11576
% INFO    : Updated Thermal Rating: on line 680-5413 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6000
% INFO    : Updated Thermal Rating: on line 379-11324 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11834
% INFO    : Updated Thermal Rating: on line 490-379 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5890
% INFO    : Updated Thermal Rating: on line 11324-13521 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 11324-13521 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 31
% INFO    : Updated Thermal Rating: on line 992-11324 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 91
% INFO    : Updated Thermal Rating: on line 11314-11324 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 46
% INFO    : Updated Thermal Rating: on line 5515-11324 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14684
% INFO    : Updated Thermal Rating: on line 6768-11324 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 53
% INFO    : Updated Thermal Rating: on line 3260-13521 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9517
% INFO    : Updated Thermal Rating: on line 992-13521 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 42
% INFO    : Updated Thermal Rating: on line 992-13521 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8306
% INFO    : Updated Thermal Rating: on line 11314-13521 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 50
% INFO    : Updated Thermal Rating: on line 7161-13521 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14423
% INFO    : Updated Thermal Rating: on line 6768-13521 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 36
% INFO    : Updated Thermal Rating: on line 9978-11546 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1805
% INFO    : Updated Thermal Rating: on line 3460-176 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1842
% INFO    : Updated Thermal Rating: on line 6117-8691 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 6117-8691 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 87
% INFO    : Updated Thermal Rating: on line 6117-2728 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52
% INFO    : Updated Thermal Rating: on line 8691-2728 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 45
% INFO    : Updated Thermal Rating: on line 8691-4570 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8315
% INFO    : Updated Thermal Rating: on line 1626-9658 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16
% INFO    : Updated Thermal Rating: on line 1626-9658 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 874
% INFO    : Updated Thermal Rating: on line 6916-2114 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13
% INFO    : Updated Thermal Rating: on line 2886-11546 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1987
% INFO    : Updated Thermal Rating: on line 2886-176 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2065
% INFO    : Updated Thermal Rating: on line 3881-2886 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 36
% INFO    : Updated Thermal Rating: on line 10203-2886 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 62
% INFO    : Updated Thermal Rating: on line 4593-2886 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27
% INFO    : Updated Thermal Rating: on line 11208-12560 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 43
% INFO    : Updated Thermal Rating: on line 4944-2728 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8825
% INFO    : Updated Thermal Rating: on line 9013-2728 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8800
% INFO    : Updated Thermal Rating: on line 3985-7630 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8887
% INFO    : Updated Thermal Rating: on line 11156-3985 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4447
% INFO    : Updated Thermal Rating: on line 7630-12875 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on line 5550-7630 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 28
% INFO    : Updated Thermal Rating: on line 5687-7630 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 32
% INFO    : Updated Thermal Rating: on line 11156-7630 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 93
% INFO    : Updated Thermal Rating: on line 13631-8870 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 44210
% INFO    : Updated Thermal Rating: on line 12000-8870 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6457
% INFO    : Updated Thermal Rating: on line 5550-12875 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on line 5687-12875 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on line 5710-12875 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2522
% INFO    : Updated Thermal Rating: on line 11156-12875 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on line 4570-8870 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 30
% INFO    : Updated Thermal Rating: on line 979-8870 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11116
% INFO    : Updated Thermal Rating: on line 8616-13547 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3417
% INFO    : Updated Thermal Rating: on line 3447-3260 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 3447-3260 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 69
% INFO    : Updated Thermal Rating: on line 3447-12000 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14015
% INFO    : Updated Thermal Rating: on line 11208-4305 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8408
% INFO    : Updated Thermal Rating: on line 5550-5687 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 133
% INFO    : Updated Thermal Rating: on line 5550-11156 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 33
% INFO    : Updated Thermal Rating: on line 5687-11156 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 34
% INFO    : Updated Thermal Rating: on line 9444-7018 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1330
% INFO    : Updated Thermal Rating: on line 13635-7018 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1358
% INFO    : Updated Thermal Rating: on line 13016-7018 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 89
% INFO    : Updated Thermal Rating: on line 2365-7018 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 81
% INFO    : Updated Thermal Rating: on line 2365-7018 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1566
% INFO    : Updated Thermal Rating: on line 9625-7018 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1668
% INFO    : Updated Thermal Rating: on line 4841-31 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11761
% INFO    : Updated Thermal Rating: on line 2602-2556 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18930
% INFO    : Updated Thermal Rating: on line 1609-6597 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5082
% INFO    : Updated Thermal Rating: on line 8890-9108 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 38340
% INFO    : Updated Thermal Rating: on line 996-5661 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 70
% INFO    : Updated Thermal Rating: on line 996-10794 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 41
% INFO    : Updated Thermal Rating: on line 996-6683 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 43
% INFO    : Updated Thermal Rating: on line 5661-3153 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4341
% INFO    : Updated Thermal Rating: on line 7766-9726 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 694
% INFO    : Updated Thermal Rating: on line 979-3566 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13633
% INFO    : Updated Thermal Rating: on line 4685-979 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20285
% INFO    : Updated Thermal Rating: on line 6683-772 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27397
% INFO    : Updated Thermal Rating: on line 10794-4895 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 28081
% INFO    : Updated Thermal Rating: on line 9444-13016 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6227
% INFO    : Updated Thermal Rating: on line 13635-13016 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5514
% INFO    : Updated Thermal Rating: on line 2365-13016 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 28
% INFO    : Updated Thermal Rating: on line 680-12000 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5460
% INFO    : Updated Thermal Rating: on line 8305-9013 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5573
% INFO    : Updated Thermal Rating: on line 1149-6597 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14489
% INFO    : Updated Thermal Rating: on line 12769-8118 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 125
% INFO    : Updated Thermal Rating: on line 11436-4685 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4543
% INFO    : Updated Thermal Rating: on line 8305-9278 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3109
% INFO    : Updated Thermal Rating: on line 3881-10203 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 61
% INFO    : Updated Thermal Rating: on line 3881-10203 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2628
% INFO    : Updated Thermal Rating: on line 3881-4593 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 77
% INFO    : Updated Thermal Rating: on line 3881-4593 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2834
% INFO    : Updated Thermal Rating: on line 490-680 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 107
% INFO    : Updated Thermal Rating: on line 3425-13449 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 39147
% INFO    : Updated Thermal Rating: on line 3452-3425 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 30016
% INFO    : Updated Thermal Rating: on line 5195-9736 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16229
% INFO    : Updated Thermal Rating: on line 3452-5195 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 30857
% INFO    : Updated Thermal Rating: on line 992-11314 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 65
% INFO    : Updated Thermal Rating: on line 992-6768 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 71
% INFO    : Updated Thermal Rating: on line 10203-4593 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 60
% INFO    : Updated Thermal Rating: on line 10203-12980 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5867
% INFO    : Updated Thermal Rating: on line 8685-3452 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3762
% INFO    : Updated Thermal Rating: on line 10055-10493 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 119
% INFO    : Updated Thermal Rating: on line 7766-2890 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10959
% INFO    : Updated Thermal Rating: on line 11156-2854 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 120
% INFO    : Updated Thermal Rating: on line 11156-2854 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2933
% INFO    : Updated Thermal Rating: on line 7818-11573 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 101421
% INFO    : Updated Thermal Rating: on line 7818-638 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 104769
% INFO    : Updated Thermal Rating: on line 11674-10846 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4950
% INFO    : Updated Thermal Rating: on line 11436-7869 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16551
% INFO    : Updated Thermal Rating: on line 11436-12671 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11747
% INFO    : Updated Thermal Rating: on line 5515-11314 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15537
% INFO    : Updated Thermal Rating: on line 11314-6768 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 83
% INFO    : Updated Thermal Rating: on line 11571-13614 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 41671
% INFO    : Updated Thermal Rating: on line 13035-13614 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 57781
% INFO    : Updated Thermal Rating: on line 10794-6683 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 51
% INFO    : Updated Thermal Rating: on line 2128-2536 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 842
% INFO    : Updated Thermal Rating: on line 6598-13441 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 6598-13441 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 80
% INFO    : Updated Thermal Rating: on line 6598-12362 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26
% INFO    : Updated Thermal Rating: on line 13441-2323 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4984
% INFO    : Updated Thermal Rating: on line 13441-12362 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20
% INFO    : Updated Thermal Rating: on line 2323-12362 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7899
% INFO    : Updated Thermal Rating: on line 6051-12362 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8077
% INFO    : Updated Thermal Rating: on line 10610-12872 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27479
% INFO    : Updated Thermal Rating: on line 7161-6768 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 89920
% INFO    : Updated Thermal Rating: on line 568-3171 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 736
% INFO    : Updated Thermal Rating: on line 5479-9571 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 44476
% INFO    : Updated Thermal Rating: on line 148-9278 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 148-9278 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112
% INFO    : Updated Thermal Rating: on line 12987-12151 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on line 12987-4498 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20681
% INFO    : Updated Thermal Rating: on line 12987-1823 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22293
% INFO    : Updated Thermal Rating: on line 12987-6933 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3435
% INFO    : Updated Thermal Rating: on line 12987-4218 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3502
% INFO    : Updated Thermal Rating: on line 3291-12987 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21
% INFO    : Updated Thermal Rating: on line 3291-12987 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2202
% INFO    : Updated Thermal Rating: on line 739-12987 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22
% INFO    : Updated Thermal Rating: on line 739-12987 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2162
% INFO    : Updated Thermal Rating: on line 582-6840 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8354
% INFO    : Updated Thermal Rating: on line 582-7757 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2787
% INFO    : Updated Thermal Rating: on line 582-6704 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3537
% INFO    : Updated Thermal Rating: on line 582-6840 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8534
% INFO    : Updated Thermal Rating: on line 582-3839 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2735
% INFO    : Updated Thermal Rating: on line 582-1320 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3818
% INFO    : Updated Thermal Rating: on line 11659-6850 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2005
% INFO    : Updated Thermal Rating: on line 11659-6850 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1967
% INFO    : Updated Thermal Rating: on line 712-10235 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1859
% INFO    : Updated Thermal Rating: on line 712-10235 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1673
% INFO    : Updated Thermal Rating: on line 12052-1224 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 896
% INFO    : Updated Thermal Rating: on line 12052-1224 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 881
% INFO    : Updated Thermal Rating: on line 6106-2716 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5635
% INFO    : Updated Thermal Rating: on line 748-2716 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 48
% INFO    : Updated Thermal Rating: on line 748-2716 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6357
% INFO    : Updated Thermal Rating: on line 748-2716 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6222
% INFO    : Updated Thermal Rating: on line 9319-2716 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 28342
% INFO    : Updated Thermal Rating: on line 2684-2716 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27
% INFO    : Updated Thermal Rating: on line 4092-13230 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 34
% INFO    : Updated Thermal Rating: on line 4092-13230 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1657
% INFO    : Updated Thermal Rating: on line 645-13230 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 37
% INFO    : Updated Thermal Rating: on line 645-13230 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 955
% INFO    : Updated Thermal Rating: on line 712-13230 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18
% INFO    : Updated Thermal Rating: on line 11046-12063 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1786
% INFO    : Updated Thermal Rating: on line 11046-12063 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 47
% INFO    : Updated Thermal Rating: on line 11046-12063 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1819
% INFO    : Updated Thermal Rating: on line 7632-10638 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 76
% INFO    : Updated Thermal Rating: on line 6973-7632 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2121
% INFO    : Updated Thermal Rating: on line 7632-6704 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 73
% INFO    : Updated Thermal Rating: on line 7632-6704 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4675
% INFO    : Updated Thermal Rating: on line 7632-12335 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 71
% INFO    : Updated Thermal Rating: on line 5154-7632 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10
% INFO    : Updated Thermal Rating: on line 3988-7632 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on line 7574-9460 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 187958
% INFO    : Updated Thermal Rating: on line 7574-9460 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 129
% INFO    : Updated Thermal Rating: on line 3536-7574 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27059
% INFO    : Updated Thermal Rating: on line 6285-7574 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27628
% INFO    : Updated Thermal Rating: on line 702-9460 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 28037
% INFO    : Updated Thermal Rating: on line 1964-9460 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 28673
% INFO    : Updated Thermal Rating: on line 11659-3536 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2602
% INFO    : Updated Thermal Rating: on line 6285-1393 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5356
% INFO    : Updated Thermal Rating: on line 11659-702 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2655
% INFO    : Updated Thermal Rating: on line 1964-6128 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5260
% INFO    : Updated Thermal Rating: on line 3291-12151 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 35
% INFO    : Updated Thermal Rating: on line 3291-12151 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2347
% INFO    : Updated Thermal Rating: on line 739-12151 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 34
% INFO    : Updated Thermal Rating: on line 8715-3115 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 50
% INFO    : Updated Thermal Rating: on line 8715-3115 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10110
% INFO    : Updated Thermal Rating: on line 8715-3115 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10300
% INFO    : Updated Thermal Rating: on line 5154-3115 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2562
% INFO    : Updated Thermal Rating: on line 3988-3115 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2616
% INFO    : Updated Thermal Rating: on line 12223-2049 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 851
% INFO    : Updated Thermal Rating: on line 4639-2049 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 837
% INFO    : Updated Thermal Rating: on line 11046-2049 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 831
% INFO    : Updated Thermal Rating: on line 11366-2049 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1817
% INFO    : Updated Thermal Rating: on line 11366-2049 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1786
% INFO    : Updated Thermal Rating: on line 10997-2049 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 726
% INFO    : Updated Thermal Rating: on line 5521-3921 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 150
% INFO    : Updated Thermal Rating: on line 5521-3921 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1705
% INFO    : Updated Thermal Rating: on line 5521-3921 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1673
% INFO    : Updated Thermal Rating: on line 3921-4615 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 30
% INFO    : Updated Thermal Rating: on line 3921-4615 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1170
% INFO    : Updated Thermal Rating: on line 3921-4615 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1149
% INFO    : Updated Thermal Rating: on line 9450-748 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3089
% INFO    : Updated Thermal Rating: on line 9450-6457 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 86
% INFO    : Updated Thermal Rating: on line 1393-6840 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3700
% INFO    : Updated Thermal Rating: on line 6128-6840 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3779
% INFO    : Updated Thermal Rating: on line 3106-571 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 48875
% INFO    : Updated Thermal Rating: on line 3106-6933 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 38
% INFO    : Updated Thermal Rating: on line 3106-4218 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 39
% INFO    : Updated Thermal Rating: on line 739-3106 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 84
% INFO    : Updated Thermal Rating: on line 571-6933 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3847
% INFO    : Updated Thermal Rating: on line 739-571 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7391
% INFO    : Updated Thermal Rating: on line 4520-748 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1432
% INFO    : Updated Thermal Rating: on line 748-10099 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1987
% INFO    : Updated Thermal Rating: on line 748-2684 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18
% INFO    : Updated Thermal Rating: on line 1759-748 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4702
% INFO    : Updated Thermal Rating: on line 4092-1987 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on line 4092-645 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10
% INFO    : Updated Thermal Rating: on line 4092-645 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 616
% INFO    : Updated Thermal Rating: on line 4092-712 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 30
% INFO    : Updated Thermal Rating: on line 4092-712 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 476
% INFO    : Updated Thermal Rating: on line 4092-4615 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 287
% INFO    : Updated Thermal Rating: on line 4092-4615 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 309
% INFO    : Updated Thermal Rating: on line 9680-6596 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1064
% INFO    : Updated Thermal Rating: on line 6596-1224 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2036
% INFO    : Updated Thermal Rating: on line 3960-10997 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1665
% INFO    : Updated Thermal Rating: on line 3960-10997 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1694
% INFO    : Updated Thermal Rating: on line 10638-6704 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 76
% INFO    : Updated Thermal Rating: on line 10638-12335 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 66
% INFO    : Updated Thermal Rating: on line 10638-12335 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3144
% INFO    : Updated Thermal Rating: on line 10638-1320 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3204
% INFO    : Updated Thermal Rating: on line 5154-10638 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9
% INFO    : Updated Thermal Rating: on line 3988-10638 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on line 712-1987 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 804
% INFO    : Updated Thermal Rating: on line 11254-7543 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 122
% INFO    : Updated Thermal Rating: on line 11254-10219 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 109
% INFO    : Updated Thermal Rating: on line 11254-10219 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4649
% INFO    : Updated Thermal Rating: on line 11254-6772 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 156
% INFO    : Updated Thermal Rating: on line 6595-11254 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1726
% INFO    : Updated Thermal Rating: on line 7757-3988 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5518
% INFO    : Updated Thermal Rating: on line 3839-5154 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5634
% INFO    : Updated Thermal Rating: on line 7543-10219 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 164
% INFO    : Updated Thermal Rating: on line 7543-6772 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 241
% INFO    : Updated Thermal Rating: on line 7543-6772 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4467
% INFO    : Updated Thermal Rating: on line 3291-7543 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2152
% INFO    : Updated Thermal Rating: on line 6595-7543 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1497
% INFO    : Updated Thermal Rating: on line 10219-6772 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27
% INFO    : Updated Thermal Rating: on line 853-10219 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2173
% INFO    : Updated Thermal Rating: on line 739-10219 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2324
% INFO    : Updated Thermal Rating: on line 12223-9924 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 704
% INFO    : Updated Thermal Rating: on line 4639-9924 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 717
% INFO    : Updated Thermal Rating: on line 645-712 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 60
% INFO    : Updated Thermal Rating: on line 4520-11659 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 945
% INFO    : Updated Thermal Rating: on line 4520-727 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1095
% INFO    : Updated Thermal Rating: on line 4520-2684 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3568
% INFO    : Updated Thermal Rating: on line 13256-6772 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1231
% INFO    : Updated Thermal Rating: on line 5724-2021 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10184
% INFO    : Updated Thermal Rating: on line 7666-2021 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10371
% INFO    : Updated Thermal Rating: on line 5521-4615 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 148
% INFO    : Updated Thermal Rating: on line 5521-4615 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2727
% INFO    : Updated Thermal Rating: on line 5521-4615 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2679
% INFO    : Updated Thermal Rating: on line 11659-727 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7528
% INFO    : Updated Thermal Rating: on line 6056-9680 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 161
% INFO    : Updated Thermal Rating: on line 6056-9680 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 475
% INFO    : Updated Thermal Rating: on line 6056-9680 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 483
% INFO    : Updated Thermal Rating: on line 9680-1224 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 816
% INFO    : Updated Thermal Rating: on line 11046-277 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 164
% INFO    : Updated Thermal Rating: on line 11046-277 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2791
% INFO    : Updated Thermal Rating: on line 11046-277 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2743
% INFO    : Updated Thermal Rating: on line 6457-10099 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6282
% INFO    : Updated Thermal Rating: on line 6458-6457 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3005
% INFO    : Updated Thermal Rating: on line 1393-6128 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142
% INFO    : Updated Thermal Rating: on line 13256-1393 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 69
% INFO    : Updated Thermal Rating: on line 10502-1393 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18
% INFO    : Updated Thermal Rating: on line 10502-1393 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4856
% INFO    : Updated Thermal Rating: on line 1393-5154 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1811
% INFO    : Updated Thermal Rating: on line 13256-6128 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 62
% INFO    : Updated Thermal Rating: on line 13256-6128 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4765
% INFO    : Updated Thermal Rating: on line 10502-6128 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16
% INFO    : Updated Thermal Rating: on line 6128-3988 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1849
% INFO    : Updated Thermal Rating: on line 3291-8715 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1949
% INFO    : Updated Thermal Rating: on line 739-8715 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1913
% INFO    : Updated Thermal Rating: on line 13256-10502 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 187958
% INFO    : Updated Thermal Rating: on line 13256-10502 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 177
% INFO    : Updated Thermal Rating: on line 13256-3988 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2561
% INFO    : Updated Thermal Rating: on line 853-13256 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4439
% INFO    : Updated Thermal Rating: on line 13256-5273 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3224
% INFO    : Updated Thermal Rating: on line 13256-6595 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 974
% INFO    : Updated Thermal Rating: on line 10502-5154 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2614
% INFO    : Updated Thermal Rating: on line 10502-6595 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 956
% INFO    : Updated Thermal Rating: on line 10502-284 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1530
% INFO    : Updated Thermal Rating: on line 6933-4218 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 120
% INFO    : Updated Thermal Rating: on line 739-6933 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22
% INFO    : Updated Thermal Rating: on line 2509-6933 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3888
% INFO    : Updated Thermal Rating: on line 6973-4218 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1910
% INFO    : Updated Thermal Rating: on line 3291-4218 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2379
% INFO    : Updated Thermal Rating: on line 739-4218 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21
% INFO    : Updated Thermal Rating: on line 2512-8132 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1742
% INFO    : Updated Thermal Rating: on line 6973-12335 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1419
% INFO    : Updated Thermal Rating: on line 6973-5154 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2076
% INFO    : Updated Thermal Rating: on line 6973-3988 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2039
% INFO    : Updated Thermal Rating: on line 6973-2509 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3262
% INFO    : Updated Thermal Rating: on line 6973-5724 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6346
% INFO    : Updated Thermal Rating: on line 6973-7666 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6235
% INFO    : Updated Thermal Rating: on line 11046-10997 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 493
% INFO    : Updated Thermal Rating: on line 6704-12335 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 6704-12335 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 79
% INFO    : Updated Thermal Rating: on line 5154-6704 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14
% INFO    : Updated Thermal Rating: on line 3988-6704 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on line 5154-12335 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14
% INFO    : Updated Thermal Rating: on line 3988-12335 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5
% INFO    : Updated Thermal Rating: on line 2684-6458 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1109
% INFO    : Updated Thermal Rating: on line 5154-3988 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 224
% INFO    : Updated Thermal Rating: on line 6595-6458 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5691
% INFO    : Updated Thermal Rating: on line 6595-6458 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5799
% INFO    : Updated Thermal Rating: on line 5273-284 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 91
% INFO    : Updated Thermal Rating: on line 5273-284 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2947
% INFO    : Updated Thermal Rating: on line 3291-739 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 3291-739 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 117
% INFO    : Updated Thermal Rating: on line 12396-9924 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 44
% INFO    : Updated Thermal Rating: on line 12396-9924 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 942
% INFO    : Updated Thermal Rating: on line 12396-9924 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 873
% INFO    : Updated Thermal Rating: on line 6595-284 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1842
% INFO    : Updated Thermal Rating: on line 795-10162 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 95
% INFO    : Updated Thermal Rating: on line 5724-795 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 45958
% INFO    : Updated Thermal Rating: on line 7666-10162 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 46629
% INFO    : Updated Thermal Rating: on line 7187-13593 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 393
% INFO    : Updated Thermal Rating: on line 11834-7187 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 485
% INFO    : Updated Thermal Rating: on line 7296-13593 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 400
% INFO    : Updated Thermal Rating: on line 11834-7296 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 493
% INFO    : Updated Thermal Rating: on line 3869-9774 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 738
% INFO    : Updated Thermal Rating: on line 9774-1978 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 673
% INFO    : Updated Thermal Rating: on line 9202-8058 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 751
% INFO    : Updated Thermal Rating: on line 8058-10723 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 918
% INFO    : Updated Thermal Rating: on line 6549-9825 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 614
% INFO    : Updated Thermal Rating: on line 9825-11940 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1305
% INFO    : Updated Thermal Rating: on line 6442-7230 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 552
% INFO    : Updated Thermal Rating: on line 1978-7230 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 579
% INFO    : Updated Thermal Rating: on line 8295-6549 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 608
% INFO    : Updated Thermal Rating: on line 3632-968 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4312
% INFO    : Updated Thermal Rating: on line 968-7795 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1130
% INFO    : Updated Thermal Rating: on line 6442-3869 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 941
% INFO    : Updated Thermal Rating: on line 6442-9202 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 926
% INFO    : Updated Thermal Rating: on line 13593-5994 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 76483
% INFO    : Updated Thermal Rating: on line 6988-5994 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 668
% INFO    : Updated Thermal Rating: on line 9637-5994 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 612
% INFO    : Updated Thermal Rating: on line 13593-7165 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 725
% INFO    : Updated Thermal Rating: on line 13593-7165 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 737
% INFO    : Updated Thermal Rating: on line 2445-1003 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 916
% INFO    : Updated Thermal Rating: on line 2445-9624 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 407
% INFO    : Updated Thermal Rating: on line 10419-2445 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1552
% INFO    : Updated Thermal Rating: on line 6467-2445 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1574
% INFO    : Updated Thermal Rating: on line 8612-11275 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1877
% INFO    : Updated Thermal Rating: on line 8612-11275 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2027
% INFO    : Updated Thermal Rating: on line 1003-6442 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 436
% INFO    : Updated Thermal Rating: on line 6442-1687 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 993
% INFO    : Updated Thermal Rating: on line 9624-6442 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 553
% INFO    : Updated Thermal Rating: on line 6442-10119 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1288
% INFO    : Updated Thermal Rating: on line 10723-1978 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1196
% INFO    : Updated Thermal Rating: on line 10119-1687 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3340
% INFO    : Updated Thermal Rating: on line 6988-12899 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 502
% INFO    : Updated Thermal Rating: on line 10855-9637 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 509
% INFO    : Updated Thermal Rating: on line 7165-893 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 567
% INFO    : Updated Thermal Rating: on line 7165-5862 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 610
% INFO    : Updated Thermal Rating: on line 7165-6625 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 36920
% INFO    : Updated Thermal Rating: on line 7165-2262 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 37289
% INFO    : Updated Thermal Rating: on line 13369-12899 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 300
% INFO    : Updated Thermal Rating: on line 893-302 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 798
% INFO    : Updated Thermal Rating: on line 5862-302 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 812
% INFO    : Updated Thermal Rating: on line 3289-10419 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 882
% INFO    : Updated Thermal Rating: on line 7795-6467 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 894
% INFO    : Updated Thermal Rating: on line 7516-12260 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1132
% INFO    : Updated Thermal Rating: on line 7516-10027 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1149
% INFO    : Updated Thermal Rating: on line 7120-11940 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 479
% INFO    : Updated Thermal Rating: on line 13369-10855 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 76483
% INFO    : Updated Thermal Rating: on line 9006-8612 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1097
% INFO    : Updated Thermal Rating: on line 9006-8612 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1113
% INFO    : Updated Thermal Rating: on line 12260-9006 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4990
% INFO    : Updated Thermal Rating: on line 10027-9006 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5081
% INFO    : Updated Thermal Rating: on line 3632-3289 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 962
% INFO    : Updated Thermal Rating: on line 7120-3632 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1457
% INFO    : Updated Thermal Rating: on line 7120-3632 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1477
% INFO    : Updated Thermal Rating: on line 10027-6702 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 133194
% INFO    : Updated Thermal Rating: on line 12260-6702 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 128186
% INFO    : Updated Thermal Rating: on line 8295-7120 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5281
% INFO    : Updated Thermal Rating: on line 302-8295 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 604
% INFO    : Updated Thermal Rating: on line 302-8295 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 563
% INFO    : Updated Thermal Rating: on line 9829-7120 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1411
% INFO    : Updated Thermal Rating: on line 302-9829 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1055
% INFO    : Updated Thermal Rating: on line 737-7120 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1514
% INFO    : Updated Thermal Rating: on line 302-737 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1147
% INFO    : Updated Thermal Rating: on line 8266-4567 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 691
% INFO    : Updated Thermal Rating: on line 8266-10128 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 457
% INFO    : Updated Thermal Rating: on line 8266-8557 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 364
% INFO    : Updated Thermal Rating: on line 6172-9494 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1908
% INFO    : Updated Thermal Rating: on line 6172-538 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 35675
% INFO    : Updated Thermal Rating: on line 6172-538 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 35810
% INFO    : Updated Thermal Rating: on line 6172-4072 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 577
% INFO    : Updated Thermal Rating: on line 6172-6615 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1828
% INFO    : Updated Thermal Rating: on line 13305-13201 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1194
% INFO    : Updated Thermal Rating: on line 13305-7936 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 814
% INFO    : Updated Thermal Rating: on line 1615-2539 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2818
% INFO    : Updated Thermal Rating: on line 1615-7453 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2200
% INFO    : Updated Thermal Rating: on line 8420-11585 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5837
% INFO    : Updated Thermal Rating: on line 4842-2932 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 697
% INFO    : Updated Thermal Rating: on line 4842-6286 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 296
% INFO    : Updated Thermal Rating: on line 1201-10931 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 885
% INFO    : Updated Thermal Rating: on line 1201-2391 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 427
% INFO    : Updated Thermal Rating: on line 13201-3261 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1904
% INFO    : Updated Thermal Rating: on line 1212-1965 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1038
% INFO    : Updated Thermal Rating: on line 1212-3690 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 694
% INFO    : Updated Thermal Rating: on line 3364-3690 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 491
% INFO    : Updated Thermal Rating: on line 3364-3204 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 371
% INFO    : Updated Thermal Rating: on line 3364-3204 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 365
% INFO    : Updated Thermal Rating: on line 6517-3204 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 982
% INFO    : Updated Thermal Rating: on line 6517-3204 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1000
% INFO    : Updated Thermal Rating: on line 8174-3813 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 758
% INFO    : Updated Thermal Rating: on line 8174-2315 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 535
% INFO    : Updated Thermal Rating: on line 8161-2539 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5764
% INFO    : Updated Thermal Rating: on line 11298-11245 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1485
% INFO    : Updated Thermal Rating: on line 11298-6286 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1069
% INFO    : Updated Thermal Rating: on line 11298-6286 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1050
% INFO    : Updated Thermal Rating: on line 7530-6286 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5534
% INFO    : Updated Thermal Rating: on line 9727-9500 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9952
% INFO    : Updated Thermal Rating: on line 9727-7453 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2606
% INFO    : Updated Thermal Rating: on line 9727-8871 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1826
% INFO    : Updated Thermal Rating: on line 9727-13640 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5709
% INFO    : Updated Thermal Rating: on line 9494-4072 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 858
% INFO    : Updated Thermal Rating: on line 9494-13365 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 758
% INFO    : Updated Thermal Rating: on line 2337-8699 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10330
% INFO    : Updated Thermal Rating: on line 2337-428 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3773
% INFO    : Updated Thermal Rating: on line 2337-6191 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1811
% INFO    : Updated Thermal Rating: on line 6209-4567 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2476
% INFO    : Updated Thermal Rating: on line 6209-944 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2957
% INFO    : Updated Thermal Rating: on line 6209-10128 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 494
% INFO    : Updated Thermal Rating: on line 7828-12468 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1156
% INFO    : Updated Thermal Rating: on line 7828-11956 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 627
% INFO    : Updated Thermal Rating: on line 7828-4072 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 315
% INFO    : Updated Thermal Rating: on line 10911-11956 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1242
% INFO    : Updated Thermal Rating: on line 10911-1965 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1778
% INFO    : Updated Thermal Rating: on line 10911-1962 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 469
% INFO    : Updated Thermal Rating: on line 4567-948 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 581
% INFO    : Updated Thermal Rating: on line 4567-944 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9369
% INFO    : Updated Thermal Rating: on line 948-10739 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8585
% INFO    : Updated Thermal Rating: on line 6086-11053 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 897
% INFO    : Updated Thermal Rating: on line 6086-9989 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3029
% INFO    : Updated Thermal Rating: on line 6086-6744 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1016
% INFO    : Updated Thermal Rating: on line 4333-8312 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 870
% INFO    : Updated Thermal Rating: on line 4333-11053 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 777
% INFO    : Updated Thermal Rating: on line 5655-7468 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 657
% INFO    : Updated Thermal Rating: on line 5655-3690 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 351
% INFO    : Updated Thermal Rating: on line 9664-2045 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 882
% INFO    : Updated Thermal Rating: on line 9664-6744 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 814
% INFO    : Updated Thermal Rating: on line 4075-8690 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1077
% INFO    : Updated Thermal Rating: on line 120-9526 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1277
% INFO    : Updated Thermal Rating: on line 120-6744 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 771
% INFO    : Updated Thermal Rating: on line 12468-10931 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 954
% INFO    : Updated Thermal Rating: on line 12468-2391 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2180
% INFO    : Updated Thermal Rating: on line 12468-2391 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2222
% INFO    : Updated Thermal Rating: on line 12468-10247 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2740
% INFO    : Updated Thermal Rating: on line 9526-11053 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1869
% INFO    : Updated Thermal Rating: on line 9493-7453 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2269
% INFO    : Updated Thermal Rating: on line 12719-3690 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1795
% INFO    : Updated Thermal Rating: on line 12719-7692 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1210
% INFO    : Updated Thermal Rating: on line 8690-6286 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 771
% INFO    : Updated Thermal Rating: on line 8690-6286 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 758
% INFO    : Updated Thermal Rating: on line 8690-5502 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1229
% INFO    : Updated Thermal Rating: on line 2045-3449 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4533
% INFO    : Updated Thermal Rating: on line 2045-13365 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8403
% INFO    : Updated Thermal Rating: on line 10869-6191 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2381
% INFO    : Updated Thermal Rating: on line 10869-2539 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2422
% INFO    : Updated Thermal Rating: on line 2932-7936 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 616
% INFO    : Updated Thermal Rating: on line 2932-11036 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 285
% INFO    : Updated Thermal Rating: on line 2932-327 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2995
% INFO    : Updated Thermal Rating: on line 2932-327 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2851
% INFO    : Updated Thermal Rating: on line 428-6191 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4123
% INFO    : Updated Thermal Rating: on line 1909-11956 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 39340
% INFO    : Updated Thermal Rating: on line 8312-3261 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1272
% INFO    : Updated Thermal Rating: on line 8312-11585 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 617
% INFO    : Updated Thermal Rating: on line 6191-7978 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1795
% INFO    : Updated Thermal Rating: on line 6191-11904 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18555
% INFO    : Updated Thermal Rating: on line 3261-9353 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1340
% INFO    : Updated Thermal Rating: on line 3261-6919 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2757
% INFO    : Updated Thermal Rating: on line 13381-12066 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1596
% INFO    : Updated Thermal Rating: on line 6286-11036 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 646
% INFO    : Updated Thermal Rating: on line 6286-7468 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 289
% INFO    : Updated Thermal Rating: on line 7978-8871 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5059
% INFO    : Updated Thermal Rating: on line 11053-3654 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5428
% INFO    : Updated Thermal Rating: on line 1065-6744 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 696
% INFO    : Updated Thermal Rating: on line 1065-194 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2002
% INFO    : Updated Thermal Rating: on line 3156-8871 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12492
% INFO    : Updated Thermal Rating: on line 6425-6744 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1582
% INFO    : Updated Thermal Rating: on line 6425-6744 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1616
% INFO    : Updated Thermal Rating: on line 6425-6744 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3126
% INFO    : Updated Thermal Rating: on line 9989-6744 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2434
% INFO    : Updated Thermal Rating: on line 2353-6744 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1105
% INFO    : Updated Thermal Rating: on line 4072-12066 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 925
% INFO    : Updated Thermal Rating: on line 4072-1962 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 658
% INFO    : Updated Thermal Rating: on line 9500-13640 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 61747
% INFO    : Updated Thermal Rating: on line 2391-3813 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 333
% INFO    : Updated Thermal Rating: on line 2391-2315 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6721
% INFO    : Updated Thermal Rating: on line 5788-3690 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2365
% INFO    : Updated Thermal Rating: on line 9353-6919 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1743
% INFO    : Updated Thermal Rating: on line 327-8557 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 745
% INFO    : Updated Thermal Rating: on line 327-3005 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 335
% INFO    : Updated Thermal Rating: on line 5502-7692 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1442
% INFO    : Updated Thermal Rating: on line 6919-3005 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 859
% INFO    : Updated Thermal Rating: on line 3204-12066 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1427
% INFO    : Updated Thermal Rating: on line 3204-12066 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1455
% INFO    : Updated Thermal Rating: on line 3204-6744 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 558
% INFO    : Updated Thermal Rating: on line 3204-6744 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 570
% INFO    : Updated Thermal Rating: on line 6744-194 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 482
% INFO    : Updated Thermal Rating: on line 2315-6615 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2818
% INFO    : Updated Thermal Rating: on line 9598-1833 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1631
% INFO    : Updated Thermal Rating: on line 9598-2381 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1230
% INFO    : Updated Thermal Rating: on line 9598-6027 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1300
% INFO    : Updated Thermal Rating: on line 6915-6230 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1610
% INFO    : Updated Thermal Rating: on line 6230-10840 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8057
% INFO    : Updated Thermal Rating: on line 6230-8556 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1250
% INFO    : Updated Thermal Rating: on line 2105-6230 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4156
% INFO    : Updated Thermal Rating: on line 6230-11657 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11190
% INFO    : Updated Thermal Rating: on line 6230-11657 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11000
% INFO    : Updated Thermal Rating: on line 3205-403 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14703
% INFO    : Updated Thermal Rating: on line 3205-7360 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10463
% INFO    : Updated Thermal Rating: on line 5504-7037 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3419
% INFO    : Updated Thermal Rating: on line 5504-9105 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 943
% INFO    : Updated Thermal Rating: on line 8722-12834 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5114
% INFO    : Updated Thermal Rating: on line 8722-290 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1369
% INFO    : Updated Thermal Rating: on line 8722-5149 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 740
% INFO    : Updated Thermal Rating: on line 8722-2025 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1067
% INFO    : Updated Thermal Rating: on line 8722-8144 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 395
% INFO    : Updated Thermal Rating: on line 8722-7253 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2193
% INFO    : Updated Thermal Rating: on line 8722-3372 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2167
% INFO    : Updated Thermal Rating: on line 6617-4257 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23296
% INFO    : Updated Thermal Rating: on line 6617-10130 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4041
% INFO    : Updated Thermal Rating: on line 8288-8640 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1197
% INFO    : Updated Thermal Rating: on line 8288-8801 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1507
% INFO    : Updated Thermal Rating: on line 7580-12019 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26594
% INFO    : Updated Thermal Rating: on line 12019-9729 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12676
% INFO    : Updated Thermal Rating: on line 4522-10455 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8116
% INFO    : Updated Thermal Rating: on line 4522-8972 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3780
% INFO    : Updated Thermal Rating: on line 4522-8972 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3861
% INFO    : Updated Thermal Rating: on line 10866-4522 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12252
% INFO    : Updated Thermal Rating: on line 7580-9448 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 31096
% INFO    : Updated Thermal Rating: on line 3375-2340 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 41388
% INFO    : Updated Thermal Rating: on line 3375-401 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8026
% INFO    : Updated Thermal Rating: on line 6915-12143 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1712
% INFO    : Updated Thermal Rating: on line 8410-1975 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 533
% INFO    : Updated Thermal Rating: on line 8410-9114 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1425
% INFO    : Updated Thermal Rating: on line 8410-5778 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1045
% INFO    : Updated Thermal Rating: on line 8410-6867 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1697
% INFO    : Updated Thermal Rating: on line 11809-6293 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15598
% INFO    : Updated Thermal Rating: on line 10837-6293 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17534
% INFO    : Updated Thermal Rating: on line 1388-1303 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1024
% INFO    : Updated Thermal Rating: on line 1303-6472 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2231
% INFO    : Updated Thermal Rating: on line 11503-9648 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 624
% INFO    : Updated Thermal Rating: on line 11503-8144 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2003
% INFO    : Updated Thermal Rating: on line 12645-5358 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1436
% INFO    : Updated Thermal Rating: on line 12645-11469 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6356
% INFO    : Updated Thermal Rating: on line 4198-12948 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4153
% INFO    : Updated Thermal Rating: on line 4198-5103 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3354
% INFO    : Updated Thermal Rating: on line 12305-5358 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2211
% INFO    : Updated Thermal Rating: on line 12305-5358 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2256
% INFO    : Updated Thermal Rating: on line 12305-10085 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6776
% INFO    : Updated Thermal Rating: on line 12305-9686 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2952
% INFO    : Updated Thermal Rating: on line 2317-2672 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3683
% INFO    : Updated Thermal Rating: on line 2672-11725 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4498
% INFO    : Updated Thermal Rating: on line 2672-11725 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4587
% INFO    : Updated Thermal Rating: on line 2672-6828 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13186
% INFO    : Updated Thermal Rating: on line 1030-9509 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3316
% INFO    : Updated Thermal Rating: on line 1030-5566 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 841
% INFO    : Updated Thermal Rating: on line 3116-9822 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1110
% INFO    : Updated Thermal Rating: on line 3116-6962 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1770
% INFO    : Updated Thermal Rating: on line 11187-9509 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1434
% INFO    : Updated Thermal Rating: on line 11187-9886 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 894
% INFO    : Updated Thermal Rating: on line 11187-10340 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 289
% INFO    : Updated Thermal Rating: on line 11187-12082 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6593
% INFO    : Updated Thermal Rating: on line 11187-12082 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6473
% INFO    : Updated Thermal Rating: on line 1388-3599 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2883
% INFO    : Updated Thermal Rating: on line 3599-10105 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2864
% INFO    : Updated Thermal Rating: on line 4478-4248 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8627
% INFO    : Updated Thermal Rating: on line 4478-11469 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3865
% INFO    : Updated Thermal Rating: on line 7896-2714 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7118
% INFO    : Updated Thermal Rating: on line 7896-2130 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1223
% INFO    : Updated Thermal Rating: on line 7896-1810 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8552
% INFO    : Updated Thermal Rating: on line 10888-6271 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1903
% INFO    : Updated Thermal Rating: on line 10888-6271 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1868
% INFO    : Updated Thermal Rating: on line 10888-6271 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1931
% INFO    : Updated Thermal Rating: on line 10888-6271 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2083
% INFO    : Updated Thermal Rating: on line 3354-8661 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 867
% INFO    : Updated Thermal Rating: on line 3191-8661 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3276
% INFO    : Updated Thermal Rating: on line 5604-1680 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1044
% INFO    : Updated Thermal Rating: on line 5604-10130 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5357
% INFO    : Updated Thermal Rating: on line 5604-10130 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4739
% INFO    : Updated Thermal Rating: on line 5604-2537 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 421
% INFO    : Updated Thermal Rating: on line 2317-4418 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7988
% INFO    : Updated Thermal Rating: on line 6059-4929 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4304
% INFO    : Updated Thermal Rating: on line 6059-4929 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5056
% INFO    : Updated Thermal Rating: on line 6059-7041 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 835
% INFO    : Updated Thermal Rating: on line 6059-10176 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1706
% INFO    : Updated Thermal Rating: on line 9739-7610 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9272
% INFO    : Updated Thermal Rating: on line 9739-6027 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3074
% INFO    : Updated Thermal Rating: on line 9739-6027 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3016
% INFO    : Updated Thermal Rating: on line 7118-745 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1875
% INFO    : Updated Thermal Rating: on line 13552-745 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13059
% INFO    : Updated Thermal Rating: on line 9886-6960 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1098
% INFO    : Updated Thermal Rating: on line 6960-10230 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 812
% INFO    : Updated Thermal Rating: on line 6960-6294 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2825
% INFO    : Updated Thermal Rating: on line 1388-10105 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1322
% INFO    : Updated Thermal Rating: on line 1388-10506 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 872
% INFO    : Updated Thermal Rating: on line 1388-10506 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 891
% INFO    : Updated Thermal Rating: on line 12544-1388 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1854
% INFO    : Updated Thermal Rating: on line 1388-3905 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 578
% INFO    : Updated Thermal Rating: on line 1388-205 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1211
% INFO    : Updated Thermal Rating: on line 1388-570 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1013
% INFO    : Updated Thermal Rating: on line 1388-570 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 896
% INFO    : Updated Thermal Rating: on line 5387-13117 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8387
% INFO    : Updated Thermal Rating: on line 5387-13117 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12492
% INFO    : Updated Thermal Rating: on line 5387-13117 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12784
% INFO    : Updated Thermal Rating: on line 5387-2029 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 698
% INFO    : Updated Thermal Rating: on line 2306-1524 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1039
% INFO    : Updated Thermal Rating: on line 2306-9878 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 686
% INFO    : Updated Thermal Rating: on line 12613-9746 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1429
% INFO    : Updated Thermal Rating: on line 12613-10844 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1085
% INFO    : Updated Thermal Rating: on line 11948-2940 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6637
% INFO    : Updated Thermal Rating: on line 6470-2940 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3924
% INFO    : Updated Thermal Rating: on line 4530-4189 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9690
% INFO    : Updated Thermal Rating: on line 4530-13271 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3594
% INFO    : Updated Thermal Rating: on line 3545-10628 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 604
% INFO    : Updated Thermal Rating: on line 3545-7193 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 886
% INFO    : Updated Thermal Rating: on line 4446-3545 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2522
% INFO    : Updated Thermal Rating: on line 6137-6365 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7026
% INFO    : Updated Thermal Rating: on line 6137-8556 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2795
% INFO    : Updated Thermal Rating: on line 53-8622 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5067
% INFO    : Updated Thermal Rating: on line 53-2965 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2435
% INFO    : Updated Thermal Rating: on line 9185-13349 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1668
% INFO    : Updated Thermal Rating: on line 9185-13349 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1244
% INFO    : Updated Thermal Rating: on line 9185-3807 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 523
% INFO    : Updated Thermal Rating: on line 9185-7582 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 905
% INFO    : Updated Thermal Rating: on line 1301-1682 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 263
% INFO    : Updated Thermal Rating: on line 1301-1908 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2112
% INFO    : Updated Thermal Rating: on line 12834-2015 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2894
% INFO    : Updated Thermal Rating: on line 1029-6829 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1448
% INFO    : Updated Thermal Rating: on line 1029-5263 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1976
% INFO    : Updated Thermal Rating: on line 12004-5573 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2602
% INFO    : Updated Thermal Rating: on line 12004-3230 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1680
% INFO    : Updated Thermal Rating: on line 12004-456 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1931
% INFO    : Updated Thermal Rating: on line 12004-10680 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5592
% INFO    : Updated Thermal Rating: on line 12004-10680 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5497
% INFO    : Updated Thermal Rating: on line 12004-9505 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4783
% INFO    : Updated Thermal Rating: on line 12004-7826 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3837
% INFO    : Updated Thermal Rating: on line 12004-1156 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1458
% INFO    : Updated Thermal Rating: on line 290-12668 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2756
% INFO    : Updated Thermal Rating: on line 4623-7770 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2039
% INFO    : Updated Thermal Rating: on line 4623-3958 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 754
% INFO    : Updated Thermal Rating: on line 4623-3958 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 741
% INFO    : Updated Thermal Rating: on line 4623-2130 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1483
% INFO    : Updated Thermal Rating: on line 4623-1625 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1623
% INFO    : Updated Thermal Rating: on line 4623-1625 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1658
% INFO    : Updated Thermal Rating: on line 3279-5001 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6640
% INFO    : Updated Thermal Rating: on line 3279-7745 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5582
% INFO    : Updated Thermal Rating: on line 6821-1567 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2374
% INFO    : Updated Thermal Rating: on line 6821-4089 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4919
% INFO    : Updated Thermal Rating: on line 2064-3531 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1135
% INFO    : Updated Thermal Rating: on line 2064-701 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2414
% INFO    : Updated Thermal Rating: on line 2064-701 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2466
% INFO    : Updated Thermal Rating: on line 2064-12079 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2419
% INFO    : Updated Thermal Rating: on line 2064-4503 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1531
% INFO    : Updated Thermal Rating: on line 2064-13287 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1650
% INFO    : Updated Thermal Rating: on line 4418-6529 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3617
% INFO    : Updated Thermal Rating: on line 6529-2134 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9950
% INFO    : Updated Thermal Rating: on line 1692-1026 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10265
% INFO    : Updated Thermal Rating: on line 1755-1026 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 944
% INFO    : Updated Thermal Rating: on line 5124-13135 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4628
% INFO    : Updated Thermal Rating: on line 5124-12668 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2225
% INFO    : Updated Thermal Rating: on line 9299-9908 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 71587
% INFO    : Updated Thermal Rating: on line 9446-9299 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 60477
% INFO    : Updated Thermal Rating: on line 11501-3189 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3823
% INFO    : Updated Thermal Rating: on line 11501-3189 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3655
% INFO    : Updated Thermal Rating: on line 6242-10547 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1679
% INFO    : Updated Thermal Rating: on line 6242-6828 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13035
% INFO    : Updated Thermal Rating: on line 6211-2732 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3747
% INFO    : Updated Thermal Rating: on line 6211-9226 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1354
% INFO    : Updated Thermal Rating: on line 905-6399 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 895
% INFO    : Updated Thermal Rating: on line 905-1157 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 589
% INFO    : Updated Thermal Rating: on line 4268-10105 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2107
% INFO    : Updated Thermal Rating: on line 4268-10105 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2067
% INFO    : Updated Thermal Rating: on line 7259-7193 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5181
% INFO    : Updated Thermal Rating: on line 7259-7193 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5289
% INFO    : Updated Thermal Rating: on line 3786-8475 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1826
% INFO    : Updated Thermal Rating: on line 3786-2775 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2543
% INFO    : Updated Thermal Rating: on line 3786-5833 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1095
% INFO    : Updated Thermal Rating: on line 3786-1543 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 947
% INFO    : Updated Thermal Rating: on line 3786-1543 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1022
% INFO    : Updated Thermal Rating: on line 3786-1156 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1120
% INFO    : Updated Thermal Rating: on line 6115-9734 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1849
% INFO    : Updated Thermal Rating: on line 6115-10704 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15031
% INFO    : Updated Thermal Rating: on line 2557-9993 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6224
% INFO    : Updated Thermal Rating: on line 2557-5778 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7103
% INFO    : Updated Thermal Rating: on line 2557-5778 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7261
% INFO    : Updated Thermal Rating: on line 6841-9431 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5655
% INFO    : Updated Thermal Rating: on line 6841-760 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2044
% INFO    : Updated Thermal Rating: on line 6841-875 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 980
% INFO    : Updated Thermal Rating: on line 6841-4803 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 358
% INFO    : Updated Thermal Rating: on line 8978-10984 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1756
% INFO    : Updated Thermal Rating: on line 8978-4149 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1795
% INFO    : Updated Thermal Rating: on line 2059-3354 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 480
% INFO    : Updated Thermal Rating: on line 7404-7479 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5999
% INFO    : Updated Thermal Rating: on line 7479-340 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3029
% INFO    : Updated Thermal Rating: on line 5823-6224 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3610
% INFO    : Updated Thermal Rating: on line 5823-9844 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4064
% INFO    : Updated Thermal Rating: on line 5823-8419 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24666
% INFO    : Updated Thermal Rating: on line 5823-8419 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21853
% INFO    : Updated Thermal Rating: on line 1377-2214 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2939
% INFO    : Updated Thermal Rating: on line 1377-6743 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4755
% INFO    : Updated Thermal Rating: on line 1377-4003 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7380
% INFO    : Updated Thermal Rating: on line 1377-4003 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4848
% INFO    : Updated Thermal Rating: on line 2280-12048 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24216
% INFO    : Updated Thermal Rating: on line 2280-5895 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 32573
% INFO    : Updated Thermal Rating: on line 8383-6365 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2448
% INFO    : Updated Thermal Rating: on line 8383-7640 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5444
% INFO    : Updated Thermal Rating: on line 13625-1996 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 104253
% INFO    : Updated Thermal Rating: on line 13625-1996 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 110496
% INFO    : Updated Thermal Rating: on line 13625-9649 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11548
% INFO    : Updated Thermal Rating: on line 13625-9986 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14708
% INFO    : Updated Thermal Rating: on line 13625-19 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21494
% INFO    : Updated Thermal Rating: on line 631-8970 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1373
% INFO    : Updated Thermal Rating: on line 4323-8970 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1567
% INFO    : Updated Thermal Rating: on line 2036-946 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 55271
% INFO    : Updated Thermal Rating: on line 946-9986 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 49903
% INFO    : Updated Thermal Rating: on line 6462-7911 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3315
% INFO    : Updated Thermal Rating: on line 6462-7911 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3470
% INFO    : Updated Thermal Rating: on line 6462-5966 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 82471
% INFO    : Updated Thermal Rating: on line 8184-1370 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1713
% INFO    : Updated Thermal Rating: on line 8184-13134 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7996
% INFO    : Updated Thermal Rating: on line 6312-11645 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1702
% INFO    : Updated Thermal Rating: on line 9878-11645 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3471
% INFO    : Updated Thermal Rating: on line 6662-2775 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1999
% INFO    : Updated Thermal Rating: on line 6662-3864 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11456
% INFO    : Updated Thermal Rating: on line 6662-5833 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5592
% INFO    : Updated Thermal Rating: on line 6662-5198 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4363
% INFO    : Updated Thermal Rating: on line 10992-7037 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1856
% INFO    : Updated Thermal Rating: on line 10992-4173 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2457
% INFO    : Updated Thermal Rating: on line 10992-4173 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2414
% INFO    : Updated Thermal Rating: on line 10992-6367 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1345
% INFO    : Updated Thermal Rating: on line 10992-1814 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3421
% INFO    : Updated Thermal Rating: on line 10992-286 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5450
% INFO    : Updated Thermal Rating: on line 10992-4937 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3377
% INFO    : Updated Thermal Rating: on line 10992-9448 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2972
% INFO    : Updated Thermal Rating: on line 7876-5919 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7394
% INFO    : Updated Thermal Rating: on line 7876-1147 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 393
% INFO    : Updated Thermal Rating: on line 7876-4466 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 458
% INFO    : Updated Thermal Rating: on line 7876-1756 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 723
% INFO    : Updated Thermal Rating: on line 3457-7382 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1052
% INFO    : Updated Thermal Rating: on line 3457-3958 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3575
% INFO    : Updated Thermal Rating: on line 3457-3958 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3270
% INFO    : Updated Thermal Rating: on line 3457-257 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1415
% INFO    : Updated Thermal Rating: on line 13307-7294 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4911
% INFO    : Updated Thermal Rating: on line 13307-656 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1038
% INFO    : Updated Thermal Rating: on line 7041-3643 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1387
% INFO    : Updated Thermal Rating: on line 3643-9362 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2303
% INFO    : Updated Thermal Rating: on line 2949-6682 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2588
% INFO    : Updated Thermal Rating: on line 2949-6733 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10303
% INFO    : Updated Thermal Rating: on line 5272-407 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1322
% INFO    : Updated Thermal Rating: on line 5272-6790 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2431
% INFO    : Updated Thermal Rating: on line 5272-6790 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2388
% INFO    : Updated Thermal Rating: on line 2214-847 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4009
% INFO    : Updated Thermal Rating: on line 2214-13478 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5144
% INFO    : Updated Thermal Rating: on line 4789-10464 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3451
% INFO    : Updated Thermal Rating: on line 4789-7118 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1464
% INFO    : Updated Thermal Rating: on line 4789-7118 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1490
% INFO    : Updated Thermal Rating: on line 4789-6026 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2782
% INFO    : Updated Thermal Rating: on line 11809-1018 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3578
% INFO    : Updated Thermal Rating: on line 11809-10051 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13271
% INFO    : Updated Thermal Rating: on line 11809-11469 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5792
% INFO    : Updated Thermal Rating: on line 407-10780 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1299
% INFO    : Updated Thermal Rating: on line 1709-12300 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4024
% INFO    : Updated Thermal Rating: on line 1709-2449 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7271
% INFO    : Updated Thermal Rating: on line 1709-4420 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5104
% INFO    : Updated Thermal Rating: on line 1709-1543 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2080
% INFO    : Updated Thermal Rating: on line 5206-2731 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1701
% INFO    : Updated Thermal Rating: on line 5206-2140 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 972
% INFO    : Updated Thermal Rating: on line 1996-5285 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22904
% INFO    : Updated Thermal Rating: on line 1996-9986 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20247
% INFO    : Updated Thermal Rating: on line 1996-4544 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24553
% INFO    : Updated Thermal Rating: on line 1996-8663 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14593
% INFO    : Updated Thermal Rating: on line 6472-4268 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3376
% INFO    : Updated Thermal Rating: on line 6472-3492 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1860
% INFO    : Updated Thermal Rating: on line 10312-7542 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2767
% INFO    : Updated Thermal Rating: on line 352-12118 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3650
% INFO    : Updated Thermal Rating: on line 352-5001 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7127
% INFO    : Updated Thermal Rating: on line 4189-11083 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1903
% INFO    : Updated Thermal Rating: on line 4189-6322 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1724
% INFO    : Updated Thermal Rating: on line 4189-6322 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1692
% INFO    : Updated Thermal Rating: on line 4268-3492 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1237
% INFO    : Updated Thermal Rating: on line 4268-3492 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1336
% INFO    : Updated Thermal Rating: on line 5507-5001 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4036
% INFO    : Updated Thermal Rating: on line 5507-1399 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4700
% INFO    : Updated Thermal Rating: on line 1311-5766 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2595
% INFO    : Updated Thermal Rating: on line 1311-10929 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12430
% INFO    : Updated Thermal Rating: on line 3461-2125 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1026
% INFO    : Updated Thermal Rating: on line 3461-11213 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1874
% INFO    : Updated Thermal Rating: on line 3461-4865 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7317
% INFO    : Updated Thermal Rating: on line 3461-4865 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7660
% INFO    : Updated Thermal Rating: on line 2343-5766 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6618
% INFO    : Updated Thermal Rating: on line 2343-2504 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9291
% INFO    : Updated Thermal Rating: on line 4173-706 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3704
% INFO    : Updated Thermal Rating: on line 4173-706 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2966
% INFO    : Updated Thermal Rating: on line 706-12040 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4432
% INFO    : Updated Thermal Rating: on line 2707-706 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 906
% INFO    : Updated Thermal Rating: on line 7171-706 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3231
% INFO    : Updated Thermal Rating: on line 8585-706 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2595
% INFO    : Updated Thermal Rating: on line 7854-706 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5854
% INFO    : Updated Thermal Rating: on line 5198-9891 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 106663
% INFO    : Updated Thermal Rating: on line 1908-7037 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2377
% INFO    : Updated Thermal Rating: on line 1227-7037 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 29067
% INFO    : Updated Thermal Rating: on line 1227-7037 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 28567
% INFO    : Updated Thermal Rating: on line 8272-3531 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1837
% INFO    : Updated Thermal Rating: on line 3905-3531 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1929
% INFO    : Updated Thermal Rating: on line 3905-3531 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2220
% INFO    : Updated Thermal Rating: on line 3905-3531 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2267
% INFO    : Updated Thermal Rating: on line 3531-13287 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4294
% INFO    : Updated Thermal Rating: on line 1692-1755 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 522
% INFO    : Updated Thermal Rating: on line 1692-8177 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 628
% INFO    : Updated Thermal Rating: on line 9993-1386 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5387
% INFO    : Updated Thermal Rating: on line 9993-1591 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11091
% INFO    : Updated Thermal Rating: on line 9603-1543 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4227
% INFO    : Updated Thermal Rating: on line 9603-5915 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2123
% INFO    : Updated Thermal Rating: on line 253-6238 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6083
% INFO    : Updated Thermal Rating: on line 10547-6238 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6375
% INFO    : Updated Thermal Rating: on line 6743-5854 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4078
% INFO    : Updated Thermal Rating: on line 11069-9042 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 33347
% INFO    : Updated Thermal Rating: on line 11069-12048 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26429
% INFO    : Updated Thermal Rating: on line 10866-11069 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13292
% INFO    : Updated Thermal Rating: on line 9175-1460 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4752
% INFO    : Updated Thermal Rating: on line 9175-4415 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3181
% INFO    : Updated Thermal Rating: on line 205-7770 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3697
% INFO    : Updated Thermal Rating: on line 9039-10126 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27867
% INFO    : Updated Thermal Rating: on line 9039-10126 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25162
% INFO    : Updated Thermal Rating: on line 9039-11868 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 41215
% INFO    : Updated Thermal Rating: on line 9039-11868 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 42222
% INFO    : Updated Thermal Rating: on line 2288-7118 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3447
% INFO    : Updated Thermal Rating: on line 2288-8982 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1340
% INFO    : Updated Thermal Rating: on line 11764-2036 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18438
% INFO    : Updated Thermal Rating: on line 11764-9649 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20508
% INFO    : Updated Thermal Rating: on line 11764-12820 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9625
% INFO    : Updated Thermal Rating: on line 1567-9646 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1812
% INFO    : Updated Thermal Rating: on line 9431-760 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2353
% INFO    : Updated Thermal Rating: on line 9431-760 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2309
% INFO    : Updated Thermal Rating: on line 2630-9431 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1960
% INFO    : Updated Thermal Rating: on line 9431-9858 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1947
% INFO    : Updated Thermal Rating: on line 1612-2943 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2818
% INFO    : Updated Thermal Rating: on line 6177-2943 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 733
% INFO    : Updated Thermal Rating: on line 4173-297 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 49864
% INFO    : Updated Thermal Rating: on line 4173-427 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15638
% INFO    : Updated Thermal Rating: on line 701-13545 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3072
% INFO    : Updated Thermal Rating: on line 1625-13545 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 640
% INFO    : Updated Thermal Rating: on line 4596-9509 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 830
% INFO    : Updated Thermal Rating: on line 5566-9509 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1096
% INFO    : Updated Thermal Rating: on line 9509-8799 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1629
% INFO    : Updated Thermal Rating: on line 9509-10844 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 600
% INFO    : Updated Thermal Rating: on line 112-3007 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10113
% INFO    : Updated Thermal Rating: on line 112-10032 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6507
% INFO    : Updated Thermal Rating: on line 10450-9734 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2423
% INFO    : Updated Thermal Rating: on line 5419-5041 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1635
% INFO    : Updated Thermal Rating: on line 5419-13240 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2993
% INFO    : Updated Thermal Rating: on line 5419-13240 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2935
% INFO    : Updated Thermal Rating: on line 8272-4089 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6989
% INFO    : Updated Thermal Rating: on line 4929-9362 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 552
% INFO    : Updated Thermal Rating: on line 4929-2171 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1311
% INFO    : Updated Thermal Rating: on line 4929-4705 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 543
% INFO    : Updated Thermal Rating: on line 4929-4803 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2039
% INFO    : Updated Thermal Rating: on line 1009-4869 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2803
% INFO    : Updated Thermal Rating: on line 1009-11083 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1345
% INFO    : Updated Thermal Rating: on line 1009-5263 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2405
% INFO    : Updated Thermal Rating: on line 1009-5263 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2356
% INFO    : Updated Thermal Rating: on line 10220-8692 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5704
% INFO    : Updated Thermal Rating: on line 10220-8692 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2606
% INFO    : Updated Thermal Rating: on line 10220-1368 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2922
% INFO    : Updated Thermal Rating: on line 10220-7790 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1945
% INFO    : Updated Thermal Rating: on line 10220-3480 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1997
% INFO    : Updated Thermal Rating: on line 5646-7404 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4579
% INFO    : Updated Thermal Rating: on line 5646-340 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1842
% INFO    : Updated Thermal Rating: on line 1457-390 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 401
% INFO    : Updated Thermal Rating: on line 1457-10130 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 387
% INFO    : Updated Thermal Rating: on line 1457-2537 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2083
% INFO    : Updated Thermal Rating: on line 1457-245 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2123
% INFO    : Updated Thermal Rating: on line 1315-5566 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1167
% INFO    : Updated Thermal Rating: on line 1315-11213 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 481
% INFO    : Updated Thermal Rating: on line 9746-7463 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1778
% INFO    : Updated Thermal Rating: on line 8018-10464 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2217
% INFO    : Updated Thermal Rating: on line 6367-2707 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4781
% INFO    : Updated Thermal Rating: on line 6367-2707 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4879
% INFO    : Updated Thermal Rating: on line 6367-9448 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 945
% INFO    : Updated Thermal Rating: on line 13233-1203 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20189
% INFO    : Updated Thermal Rating: on line 13233-1203 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20572
% INFO    : Updated Thermal Rating: on line 13233-9883 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1025
% INFO    : Updated Thermal Rating: on line 8692-4149 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 822
% INFO    : Updated Thermal Rating: on line 8692-13367 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1320
% INFO    : Updated Thermal Rating: on line 6340-900 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4037
% INFO    : Updated Thermal Rating: on line 6340-900 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4120
% INFO    : Updated Thermal Rating: on line 6340-847 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5216
% INFO    : Updated Thermal Rating: on line 6340-6519 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2562
% INFO    : Updated Thermal Rating: on line 6340-1163 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5398
% INFO    : Updated Thermal Rating: on line 5358-10085 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4167
% INFO    : Updated Thermal Rating: on line 5358-11469 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1297
% INFO    : Updated Thermal Rating: on line 5358-13224 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1994
% INFO    : Updated Thermal Rating: on line 5358-13224 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1957
% INFO    : Updated Thermal Rating: on line 5349-6045 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1511
% INFO    : Updated Thermal Rating: on line 6045-11168 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4769
% INFO    : Updated Thermal Rating: on line 2352-4419 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26592
% INFO    : Updated Thermal Rating: on line 2352-11725 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9073
% INFO    : Updated Thermal Rating: on line 7241-205 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2171
% INFO    : Updated Thermal Rating: on line 2794-8640 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 633
% INFO    : Updated Thermal Rating: on line 2794-11738 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 755
% INFO    : Updated Thermal Rating: on line 10870-11116 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6843
% INFO    : Updated Thermal Rating: on line 10870-5566 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 976
% INFO    : Updated Thermal Rating: on line 10870-6294 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7276
% INFO    : Updated Thermal Rating: on line 10870-1358 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9758
% INFO    : Updated Thermal Rating: on line 5107-5595 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15658
% INFO    : Updated Thermal Rating: on line 1911-5595 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15364
% INFO    : Updated Thermal Rating: on line 5595-8005 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 54724
% INFO    : Updated Thermal Rating: on line 7813-1227 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4521
% INFO    : Updated Thermal Rating: on line 7813-4937 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4283
% INFO    : Updated Thermal Rating: on line 5919-13367 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1296
% INFO    : Updated Thermal Rating: on line 3046-696 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 678
% INFO    : Updated Thermal Rating: on line 3046-9114 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4714
% INFO    : Updated Thermal Rating: on line 8377-12040 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4823
% INFO    : Updated Thermal Rating: on line 4003-4412 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1863
% INFO    : Updated Thermal Rating: on line 4003-900 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10720
% INFO    : Updated Thermal Rating: on line 4003-900 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10939
% INFO    : Updated Thermal Rating: on line 4003-7382 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1666
% INFO    : Updated Thermal Rating: on line 10506-3958 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5550
% INFO    : Updated Thermal Rating: on line 10506-3958 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5667
% INFO    : Updated Thermal Rating: on line 10371-5568 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27343
% INFO    : Updated Thermal Rating: on line 10371-9773 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24957
% INFO    : Updated Thermal Rating: on line 10371-13271 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1076
% INFO    : Updated Thermal Rating: on line 10371-7407 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3587
% INFO    : Updated Thermal Rating: on line 8401-10126 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5766
% INFO    : Updated Thermal Rating: on line 8401-10032 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4430
% INFO    : Updated Thermal Rating: on line 10578-9731 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1667
% INFO    : Updated Thermal Rating: on line 10578-12923 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 549
% INFO    : Updated Thermal Rating: on line 8019-7294 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2919
% INFO    : Updated Thermal Rating: on line 11267-7294 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2020
% INFO    : Updated Thermal Rating: on line 7294-7271 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7002
% INFO    : Updated Thermal Rating: on line 1443-11566 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 795
% INFO    : Updated Thermal Rating: on line 10886-11566 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3468
% INFO    : Updated Thermal Rating: on line 64-8256 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1919
% INFO    : Updated Thermal Rating: on line 64-9025 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3573
% INFO    : Updated Thermal Rating: on line 64-3615 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1190
% INFO    : Updated Thermal Rating: on line 11438-2907 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21536
% INFO    : Updated Thermal Rating: on line 11438-8565 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1424
% INFO    : Updated Thermal Rating: on line 11438-5895 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25801
% INFO    : Updated Thermal Rating: on line 11438-11776 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2103
% INFO    : Updated Thermal Rating: on line 11438-11776 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2143
% INFO    : Updated Thermal Rating: on line 10126-6266 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2367
% INFO    : Updated Thermal Rating: on line 10126-13135 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2875
% INFO    : Updated Thermal Rating: on line 10126-13135 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2932
% INFO    : Updated Thermal Rating: on line 10126-5021 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 36969
% INFO    : Updated Thermal Rating: on line 10157-3807 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2547
% INFO    : Updated Thermal Rating: on line 10157-8144 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1030
% INFO    : Updated Thermal Rating: on line 2125-11213 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1261
% INFO    : Updated Thermal Rating: on line 9042-11868 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23440
% INFO    : Updated Thermal Rating: on line 12544-2714 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1641
% INFO    : Updated Thermal Rating: on line 1814-1227 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8106
% INFO    : Updated Thermal Rating: on line 11878-11466 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6878
% INFO    : Updated Thermal Rating: on line 11878-11466 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7428
% INFO    : Updated Thermal Rating: on line 11878-40 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 200
% INFO    : Updated Thermal Rating: on line 11878-10878 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 771
% INFO    : Updated Thermal Rating: on line 10455-12048 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 50961
% INFO    : Updated Thermal Rating: on line 10455-1530 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9950
% INFO    : Updated Thermal Rating: on line 10455-8972 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3621
% INFO    : Updated Thermal Rating: on line 253-6828 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4968
% INFO    : Updated Thermal Rating: on line 1060-5909 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3543
% INFO    : Updated Thermal Rating: on line 9886-4596 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2965
% INFO    : Updated Thermal Rating: on line 9886-4596 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3624
% INFO    : Updated Thermal Rating: on line 4596-2997 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 675
% INFO    : Updated Thermal Rating: on line 4596-5795 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3889
% INFO    : Updated Thermal Rating: on line 4596-5795 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3960
% INFO    : Updated Thermal Rating: on line 4566-1285 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5799
% INFO    : Updated Thermal Rating: on line 4566-1756 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1361
% INFO    : Updated Thermal Rating: on line 701-3492 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2165
% INFO    : Updated Thermal Rating: on line 9886-390 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1470
% INFO    : Updated Thermal Rating: on line 9886-5795 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1227
% INFO    : Updated Thermal Rating: on line 13117-3441 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 567
% INFO    : Updated Thermal Rating: on line 13117-6993 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 680
% INFO    : Updated Thermal Rating: on line 13117-8177 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1741
% INFO    : Updated Thermal Rating: on line 3441-5536 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 647
% INFO    : Updated Thermal Rating: on line 288-4466 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1495
% INFO    : Updated Thermal Rating: on line 288-5796 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4630
% INFO    : Updated Thermal Rating: on line 11243-13129 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 54080
% INFO    : Updated Thermal Rating: on line 11243-8663 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 42367
% INFO    : Updated Thermal Rating: on line 10837-11031 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17273
% INFO    : Updated Thermal Rating: on line 1602-7446 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2712
% INFO    : Updated Thermal Rating: on line 1602-6322 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6889
% INFO    : Updated Thermal Rating: on line 4419-11725 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7676
% INFO    : Updated Thermal Rating: on line 403-10321 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16221
% INFO    : Updated Thermal Rating: on line 5878-6900 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3060
% INFO    : Updated Thermal Rating: on line 10884-5878 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9483
% INFO    : Updated Thermal Rating: on line 4948-8268 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20189
% INFO    : Updated Thermal Rating: on line 4948-8268 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20569
% INFO    : Updated Thermal Rating: on line 12954-2923 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2188
% INFO    : Updated Thermal Rating: on line 12954-6470 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9249
% INFO    : Updated Thermal Rating: on line 8752-2025 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 701
% INFO    : Updated Thermal Rating: on line 8752-8144 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 955
% INFO    : Updated Thermal Rating: on line 4557-11983 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2437
% INFO    : Updated Thermal Rating: on line 4557-6027 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2487
% INFO    : Updated Thermal Rating: on line 2327-5336 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21937
% INFO    : Updated Thermal Rating: on line 2327-10032 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6105
% INFO    : Updated Thermal Rating: on line 4412-10924 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6572
% INFO    : Updated Thermal Rating: on line 4412-10924 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6529
% INFO    : Updated Thermal Rating: on line 4412-2052 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2198
% INFO    : Updated Thermal Rating: on line 4412-1163 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5729
% INFO    : Updated Thermal Rating: on line 1018-10051 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3930
% INFO    : Updated Thermal Rating: on line 1018-1334 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1518
% INFO    : Updated Thermal Rating: on line 1018-4248 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3332
% INFO    : Updated Thermal Rating: on line 5258-6131 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1628
% INFO    : Updated Thermal Rating: on line 5258-7695 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1180
% INFO    : Updated Thermal Rating: on line 3801-12225 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6843
% INFO    : Updated Thermal Rating: on line 3801-12668 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10399
% INFO    : Updated Thermal Rating: on line 2068-5516 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 41268
% INFO    : Updated Thermal Rating: on line 2068-9031 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1829
% INFO    : Updated Thermal Rating: on line 8475-1524 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2402
% INFO    : Updated Thermal Rating: on line 2059-7254 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1087
% INFO    : Updated Thermal Rating: on line 2059-1612 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 531
% INFO    : Updated Thermal Rating: on line 2059-1468 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 546
% INFO    : Updated Thermal Rating: on line 2059-1468 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 555
% INFO    : Updated Thermal Rating: on line 10704-6878 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 69919
% INFO    : Updated Thermal Rating: on line 7254-7404 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2902
% INFO    : Updated Thermal Rating: on line 6324-108 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1791
% INFO    : Updated Thermal Rating: on line 6324-9264 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13051
% INFO    : Updated Thermal Rating: on line 11468-2945 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1279
% INFO    : Updated Thermal Rating: on line 7542-2945 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1071
% INFO    : Updated Thermal Rating: on line 5107-10032 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20434
% INFO    : Updated Thermal Rating: on line 1911-10032 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20842
% INFO    : Updated Thermal Rating: on line 5433-12810 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21883
% INFO    : Updated Thermal Rating: on line 5433-8622 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14188
% INFO    : Updated Thermal Rating: on line 1743-6727 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22347
% INFO    : Updated Thermal Rating: on line 1743-3958 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5758
% INFO    : Updated Thermal Rating: on line 10884-12810 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 59086
% INFO    : Updated Thermal Rating: on line 6727-10884 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52385
% INFO    : Updated Thermal Rating: on line 11031-6419 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12770
% INFO    : Updated Thermal Rating: on line 11031-11469 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4665
% INFO    : Updated Thermal Rating: on line 11718-297 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18710
% INFO    : Updated Thermal Rating: on line 760-10780 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 963
% INFO    : Updated Thermal Rating: on line 631-1617 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2302
% INFO    : Updated Thermal Rating: on line 2707-7171 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 903
% INFO    : Updated Thermal Rating: on line 5970-2279 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 44749
% INFO    : Updated Thermal Rating: on line 5970-3379 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7447
% INFO    : Updated Thermal Rating: on line 9991-2504 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11554
% INFO    : Updated Thermal Rating: on line 9991-3684 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10244
% INFO    : Updated Thermal Rating: on line 12892-2120 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3294
% INFO    : Updated Thermal Rating: on line 12892-10856 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2813
% INFO    : Updated Thermal Rating: on line 1368-10984 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4369
% INFO    : Updated Thermal Rating: on line 8800-11828 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3717
% INFO    : Updated Thermal Rating: on line 8800-10884 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9681
% INFO    : Updated Thermal Rating: on line 11725-5863 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5055
% INFO    : Updated Thermal Rating: on line 11725-3928 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16876
% INFO    : Updated Thermal Rating: on line 11725-3275 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16532
% INFO    : Updated Thermal Rating: on line 10044-1524 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3282
% INFO    : Updated Thermal Rating: on line 10044-1524 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3354
% INFO    : Updated Thermal Rating: on line 13279-6501 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1547
% INFO    : Updated Thermal Rating: on line 13279-6501 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1518
% INFO    : Updated Thermal Rating: on line 10990-5766 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4229
% INFO    : Updated Thermal Rating: on line 10990-10929 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4410
% INFO    : Updated Thermal Rating: on line 5256-8622 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2181
% INFO    : Updated Thermal Rating: on line 5256-2965 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2176
% INFO    : Updated Thermal Rating: on line 2630-10780 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 970
% INFO    : Updated Thermal Rating: on line 11828-1982 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3181
% INFO    : Updated Thermal Rating: on line 6829-11828 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1112
% INFO    : Updated Thermal Rating: on line 2503-4414 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2772
% INFO    : Updated Thermal Rating: on line 2503-5001 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2393
% INFO    : Updated Thermal Rating: on line 2541-2279 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 45315
% INFO    : Updated Thermal Rating: on line 2541-3379 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 46708
% INFO    : Updated Thermal Rating: on line 7180-5492 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8172
% INFO    : Updated Thermal Rating: on line 7180-13224 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1353
% INFO    : Updated Thermal Rating: on line 5492-9686 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2689
% INFO    : Updated Thermal Rating: on line 1068-12631 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1145
% INFO    : Updated Thermal Rating: on line 1068-10840 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2352
% INFO    : Updated Thermal Rating: on line 1068-8556 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1852
% INFO    : Updated Thermal Rating: on line 1068-7100 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2973
% INFO    : Updated Thermal Rating: on line 8883-1068 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1520
% INFO    : Updated Thermal Rating: on line 1975-9822 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3435
% INFO    : Updated Thermal Rating: on line 1975-9822 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3504
% INFO    : Updated Thermal Rating: on line 3864-1156 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1362
% INFO    : Updated Thermal Rating: on line 6365-10840 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3548
% INFO    : Updated Thermal Rating: on line 12553-7911 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1088
% INFO    : Updated Thermal Rating: on line 12553-12478 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4254
% INFO    : Updated Thermal Rating: on line 2052-10924 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4011
% INFO    : Updated Thermal Rating: on line 2052-10924 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3672
% INFO    : Updated Thermal Rating: on line 449-10924 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20061
% INFO    : Updated Thermal Rating: on line 449-10924 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20439
% INFO    : Updated Thermal Rating: on line 7471-9448 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6509
% INFO    : Updated Thermal Rating: on line 7471-2038 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3497
% INFO    : Updated Thermal Rating: on line 9362-10340 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 874
% INFO    : Updated Thermal Rating: on line 10340-10130 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1020
% INFO    : Updated Thermal Rating: on line 10340-2537 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 983
% INFO    : Updated Thermal Rating: on line 6266-2808 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24058
% INFO    : Updated Thermal Rating: on line 2537-2997 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 780
% INFO    : Updated Thermal Rating: on line 7446-7952 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4440
% INFO    : Updated Thermal Rating: on line 7446-7258 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15189
% INFO    : Updated Thermal Rating: on line 7446-6524 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9749
% INFO    : Updated Thermal Rating: on line 1604-8880 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1991
% INFO    : Updated Thermal Rating: on line 1604-6177 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1474
% INFO    : Updated Thermal Rating: on line 5833-5002 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3101
% INFO    : Updated Thermal Rating: on line 2036-9986 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 33506
% INFO    : Updated Thermal Rating: on line 2036-4544 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16486
% INFO    : Updated Thermal Rating: on line 13602-5796 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21333
% INFO    : Updated Thermal Rating: on line 13602-5438 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4118
% INFO    : Updated Thermal Rating: on line 12631-2395 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2577
% INFO    : Updated Thermal Rating: on line 12631-3687 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1067
% INFO    : Updated Thermal Rating: on line 12631-9878 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2831
% INFO    : Updated Thermal Rating: on line 12631-10884 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 697
% INFO    : Updated Thermal Rating: on line 12631-1810 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 992
% INFO    : Updated Thermal Rating: on line 3905-1625 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 799
% INFO    : Updated Thermal Rating: on line 3905-1625 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 815
% INFO    : Updated Thermal Rating: on line 13349-7463 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 584
% INFO    : Updated Thermal Rating: on line 13349-3076 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 841
% INFO    : Updated Thermal Rating: on line 13349-3807 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 326
% INFO    : Updated Thermal Rating: on line 11116-5795 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14981
% INFO    : Updated Thermal Rating: on line 696-10544 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 824
% INFO    : Updated Thermal Rating: on line 696-7353 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 348
% INFO    : Updated Thermal Rating: on line 10840-8556 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1360
% INFO    : Updated Thermal Rating: on line 10840-957 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11130
% INFO    : Updated Thermal Rating: on line 10840-7223 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1958
% INFO    : Updated Thermal Rating: on line 7911-719 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4376
% INFO    : Updated Thermal Rating: on line 7911-719 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5608
% INFO    : Updated Thermal Rating: on line 7911-12577 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6766
% INFO    : Updated Thermal Rating: on line 7911-10321 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6907
% INFO    : Updated Thermal Rating: on line 7911-5966 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2866
% INFO    : Updated Thermal Rating: on line 7911-12478 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1270
% INFO    : Updated Thermal Rating: on line 3492-10272 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1575
% INFO    : Updated Thermal Rating: on line 3492-10272 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1609
% INFO    : Updated Thermal Rating: on line 3492-7021 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1244
% INFO    : Updated Thermal Rating: on line 3492-7021 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1221
% INFO    : Updated Thermal Rating: on line 3492-1625 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 759
% INFO    : Updated Thermal Rating: on line 5566-807 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 347
% INFO    : Updated Thermal Rating: on line 9198-5566 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1856
% INFO    : Updated Thermal Rating: on line 5566-6294 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 965
% INFO    : Updated Thermal Rating: on line 5566-6136 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 986
% INFO    : Updated Thermal Rating: on line 11468-7542 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 576
% INFO    : Updated Thermal Rating: on line 11468-1468 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1254
% INFO    : Updated Thermal Rating: on line 11468-1468 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1279
% INFO    : Updated Thermal Rating: on line 1352-10906 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2411
% INFO    : Updated Thermal Rating: on line 1352-7181 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3387
% INFO    : Updated Thermal Rating: on line 7640-8556 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4090
% INFO    : Updated Thermal Rating: on line 3189-11983 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1284
% INFO    : Updated Thermal Rating: on line 3189-11983 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1309
% INFO    : Updated Thermal Rating: on line 5568-2395 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 802
% INFO    : Updated Thermal Rating: on line 2395-7100 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3936
% INFO    : Updated Thermal Rating: on line 4779-2395 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3274
% INFO    : Updated Thermal Rating: on line 12143-2395 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3043
% INFO    : Updated Thermal Rating: on line 6105-2395 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1603
% INFO    : Updated Thermal Rating: on line 10544-7353 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 589
% INFO    : Updated Thermal Rating: on line 1529-5489 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23210
% INFO    : Updated Thermal Rating: on line 1529-9448 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5181
% INFO    : Updated Thermal Rating: on line 1529-9448 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5291
% INFO    : Updated Thermal Rating: on line 1617-4415 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11413
% INFO    : Updated Thermal Rating: on line 1397-12940 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1607
% INFO    : Updated Thermal Rating: on line 1397-6746 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1052
% INFO    : Updated Thermal Rating: on line 9646-10183 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3126
% INFO    : Updated Thermal Rating: on line 8556-9883 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3884
% INFO    : Updated Thermal Rating: on line 11983-9025 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 825
% INFO    : Updated Thermal Rating: on line 11983-9025 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 816
% INFO    : Updated Thermal Rating: on line 11983-7541 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7502
% INFO    : Updated Thermal Rating: on line 6294-8799 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2493
% INFO    : Updated Thermal Rating: on line 6682-6733 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5863
% INFO    : Updated Thermal Rating: on line 3450-3846 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2427
% INFO    : Updated Thermal Rating: on line 3450-3846 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1733
% INFO    : Updated Thermal Rating: on line 3450-5377 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1245
% INFO    : Updated Thermal Rating: on line 3450-5377 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1272
% INFO    : Updated Thermal Rating: on line 7118-8982 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1535
% INFO    : Updated Thermal Rating: on line 7118-10085 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 512
% INFO    : Updated Thermal Rating: on line 7118-2713 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2304
% INFO    : Updated Thermal Rating: on line 1512-12079 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4753
% INFO    : Updated Thermal Rating: on line 1512-4089 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1848
% INFO    : Updated Thermal Rating: on line 9362-1680 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1661
% INFO    : Updated Thermal Rating: on line 9362-10130 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 783
% INFO    : Updated Thermal Rating: on line 9362-10130 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 870
% INFO    : Updated Thermal Rating: on line 9362-10176 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 595
% INFO    : Updated Thermal Rating: on line 5409-2731 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6815
% INFO    : Updated Thermal Rating: on line 5409-2731 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6686
% INFO    : Updated Thermal Rating: on line 5409-2731 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9641
% INFO    : Updated Thermal Rating: on line 2383-7610 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22084
% INFO    : Updated Thermal Rating: on line 2383-9822 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1668
% INFO    : Updated Thermal Rating: on line 108-12948 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2383
% INFO    : Updated Thermal Rating: on line 2171-4705 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2931
% INFO    : Updated Thermal Rating: on line 10207-1210 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 53332
% INFO    : Updated Thermal Rating: on line 10207-608 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1286
% INFO    : Updated Thermal Rating: on line 10207-2134 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4327
% INFO    : Updated Thermal Rating: on line 719-6224 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3610
% INFO    : Updated Thermal Rating: on line 719-9844 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4672
% INFO    : Updated Thermal Rating: on line 5568-9773 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25787
% INFO    : Updated Thermal Rating: on line 5568-5263 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2537
% INFO    : Updated Thermal Rating: on line 5568-6105 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1664
% INFO    : Updated Thermal Rating: on line 1147-11466 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3767
% INFO    : Updated Thermal Rating: on line 1147-12350 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1599
% INFO    : Updated Thermal Rating: on line 1147-1756 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 741
% INFO    : Updated Thermal Rating: on line 2052-456 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2548
% INFO    : Updated Thermal Rating: on line 2052-456 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2597
% INFO    : Updated Thermal Rating: on line 2052-12743 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1757
% INFO    : Updated Thermal Rating: on line 6733-13134 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5854
% INFO    : Updated Thermal Rating: on line 6733-13134 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5970
% INFO    : Updated Thermal Rating: on line 8801-216 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 957
% INFO    : Updated Thermal Rating: on line 1682-216 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1365
% INFO    : Updated Thermal Rating: on line 216-9105 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 616
% INFO    : Updated Thermal Rating: on line 216-5435 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 552
% INFO    : Updated Thermal Rating: on line 216-9031 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 597
% INFO    : Updated Thermal Rating: on line 6312-7440 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1967
% INFO    : Updated Thermal Rating: on line 6312-9878 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1217
% INFO    : Updated Thermal Rating: on line 6312-12143 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2117
% INFO    : Updated Thermal Rating: on line 6312-7407 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3020
% INFO    : Updated Thermal Rating: on line 6312-11782 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9367
% INFO    : Updated Thermal Rating: on line 2120-6582 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2494
% INFO    : Updated Thermal Rating: on line 2120-2140 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 791
% INFO    : Updated Thermal Rating: on line 1203-1673 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1866
% INFO    : Updated Thermal Rating: on line 1203-1673 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4637
% INFO    : Updated Thermal Rating: on line 1203-1673 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4545
% INFO    : Updated Thermal Rating: on line 8883-1203 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2065
% INFO    : Updated Thermal Rating: on line 5642-999 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1309
% INFO    : Updated Thermal Rating: on line 5642-8469 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 981
% INFO    : Updated Thermal Rating: on line 5642-3173 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4761
% INFO    : Updated Thermal Rating: on line 5642-3173 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5698
% INFO    : Updated Thermal Rating: on line 7440-6448 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 76837
% INFO    : Updated Thermal Rating: on line 7440-6448 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 76837
% INFO    : Updated Thermal Rating: on line 7440-7258 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9161
% INFO    : Updated Thermal Rating: on line 10906-3595 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1776
% INFO    : Updated Thermal Rating: on line 10886-2732 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2343
% INFO    : Updated Thermal Rating: on line 711-3807 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4224
% INFO    : Updated Thermal Rating: on line 711-8144 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 898
% INFO    : Updated Thermal Rating: on line 7463-6399 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12109
% INFO    : Updated Thermal Rating: on line 9648-5149 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 725
% INFO    : Updated Thermal Rating: on line 12877-4466 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2397
% INFO    : Updated Thermal Rating: on line 12877-1793 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1086
% INFO    : Updated Thermal Rating: on line 3191-7271 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3120
% INFO    : Updated Thermal Rating: on line 7745-4414 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2049
% INFO    : Updated Thermal Rating: on line 12824-1982 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2371
% INFO    : Updated Thermal Rating: on line 7592-2504 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 47279
% INFO    : Updated Thermal Rating: on line 7592-3684 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 48642
% INFO    : Updated Thermal Rating: on line 7592-4359 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27957
% INFO    : Updated Thermal Rating: on line 9986-11718 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18221
% INFO    : Updated Thermal Rating: on line 8626-1210 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 37113
% INFO    : Updated Thermal Rating: on line 10450-10711 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5272
% INFO    : Updated Thermal Rating: on line 10450-10183 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2889
% INFO    : Updated Thermal Rating: on line 8489-10450 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1633
% INFO    : Updated Thermal Rating: on line 8622-3958 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6753
% INFO    : Updated Thermal Rating: on line 13135-10031 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4699
% INFO    : Updated Thermal Rating: on line 3595-1235 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1136
% INFO    : Updated Thermal Rating: on line 4705-4080 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7885
% INFO    : Updated Thermal Rating: on line 4705-4803 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 953
% INFO    : Updated Thermal Rating: on line 11989-4149 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1384
% INFO    : Updated Thermal Rating: on line 11989-2570 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3627
% INFO    : Updated Thermal Rating: on line 8484-6898 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1670
% INFO    : Updated Thermal Rating: on line 8484-1973 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1566
% INFO    : Updated Thermal Rating: on line 12118-4359 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3541
% INFO    : Updated Thermal Rating: on line 1673-9663 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1691
% INFO    : Updated Thermal Rating: on line 1673-11248 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5484
% INFO    : Updated Thermal Rating: on line 1673-1097 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1499
% INFO    : Updated Thermal Rating: on line 3846-6995 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 834
% INFO    : Updated Thermal Rating: on line 3173-6131 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1279
% INFO    : Updated Thermal Rating: on line 5573-4184 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6399
% INFO    : Updated Thermal Rating: on line 5198-4184 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1173
% INFO    : Updated Thermal Rating: on line 7193-807 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 908
% INFO    : Updated Thermal Rating: on line 5001-10150 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11309
% INFO    : Updated Thermal Rating: on line 5001-11776 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2325
% INFO    : Updated Thermal Rating: on line 7171-10856 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2818
% INFO    : Updated Thermal Rating: on line 7171-9287 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11807
% INFO    : Updated Thermal Rating: on line 13129-19 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23815
% INFO    : Updated Thermal Rating: on line 13129-427 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18942
% INFO    : Updated Thermal Rating: on line 6501-7404 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2449
% INFO    : Updated Thermal Rating: on line 6501-7404 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2500
% INFO    : Updated Thermal Rating: on line 6501-7695 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3289
% INFO    : Updated Thermal Rating: on line 6501-7695 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3347
% INFO    : Updated Thermal Rating: on line 5377-6501 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2418
% INFO    : Updated Thermal Rating: on line 5377-6501 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2610
% INFO    : Updated Thermal Rating: on line 10130-4257 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5859
% INFO    : Updated Thermal Rating: on line 4869-13271 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1277
% INFO    : Updated Thermal Rating: on line 3362-5285 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20595
% INFO    : Updated Thermal Rating: on line 3362-8663 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27118
% INFO    : Updated Thermal Rating: on line 4779-7223 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3851
% INFO    : Updated Thermal Rating: on line 12008-2907 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11591
% INFO    : Updated Thermal Rating: on line 2907-9908 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142001
% INFO    : Updated Thermal Rating: on line 3076-875 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 536
% INFO    : Updated Thermal Rating: on line 8565-1530 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23603
% INFO    : Updated Thermal Rating: on line 8880-1682 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 792
% INFO    : Updated Thermal Rating: on line 4493-11248 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1110
% INFO    : Updated Thermal Rating: on line 4493-2965 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2556
% INFO    : Updated Thermal Rating: on line 12008-8005 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 49392
% INFO    : Updated Thermal Rating: on line 10620-4466 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9445
% INFO    : Updated Thermal Rating: on line 10620-5438 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2025
% INFO    : Updated Thermal Rating: on line 9908-8626 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18543
% INFO    : Updated Thermal Rating: on line 9908-7745 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12501
% INFO    : Updated Thermal Rating: on line 1612-6835 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1861
% INFO    : Updated Thermal Rating: on line 5103-1612 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1198
% INFO    : Updated Thermal Rating: on line 5021-10031 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11260
% INFO    : Updated Thermal Rating: on line 2029-7193 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 567
% INFO    : Updated Thermal Rating: on line 4446-7193 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 766
% INFO    : Updated Thermal Rating: on line 11083-13271 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2472
% INFO    : Updated Thermal Rating: on line 4466-8681 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 623
% INFO    : Updated Thermal Rating: on line 4466-5349 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 794
% INFO    : Updated Thermal Rating: on line 4466-5438 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1411
% INFO    : Updated Thermal Rating: on line 4466-11168 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 958
% INFO    : Updated Thermal Rating: on line 10044-456 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2337
% INFO    : Updated Thermal Rating: on line 10044-456 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2523
% INFO    : Updated Thermal Rating: on line 7382-257 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3600
% INFO    : Updated Thermal Rating: on line 7382-6519 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5145
% INFO    : Updated Thermal Rating: on line 3687-9883 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5190
% INFO    : Updated Thermal Rating: on line 7181-9822 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2792
% INFO    : Updated Thermal Rating: on line 5863-10150 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2240
% INFO    : Updated Thermal Rating: on line 1833-7541 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4095
% INFO    : Updated Thermal Rating: on line 9773-9878 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 878
% INFO    : Updated Thermal Rating: on line 9773-9878 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 956
% INFO    : Updated Thermal Rating: on line 9773-9878 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 975
% INFO    : Updated Thermal Rating: on line 9773-13271 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1005
% INFO    : Updated Thermal Rating: on line 11466-40 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 236
% INFO    : Updated Thermal Rating: on line 9264-8019 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1559
% INFO    : Updated Thermal Rating: on line 7404-340 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1744
% INFO    : Updated Thermal Rating: on line 7404-7695 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2197
% INFO    : Updated Thermal Rating: on line 5915-3230 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2310
% INFO    : Updated Thermal Rating: on line 6177-6835 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 393
% INFO    : Updated Thermal Rating: on line 1060-3958 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3338
% INFO    : Updated Thermal Rating: on line 1060-877 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1728
% INFO    : Updated Thermal Rating: on line 1060-570 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9100
% INFO    : Updated Thermal Rating: on line 5766-3684 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3193
% INFO    : Updated Thermal Rating: on line 3958-3761 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9837
% INFO    : Updated Thermal Rating: on line 3958-11270 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4632
% INFO    : Updated Thermal Rating: on line 3958-12155 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7107
% INFO    : Updated Thermal Rating: on line 608-12940 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1729
% INFO    : Updated Thermal Rating: on line 608-6004 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2046
% INFO    : Updated Thermal Rating: on line 10680-456 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3416
% INFO    : Updated Thermal Rating: on line 10680-456 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3487
% INFO    : Updated Thermal Rating: on line 1334-3983 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4351
% INFO    : Updated Thermal Rating: on line 5489-9729 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9468
% INFO    : Updated Thermal Rating: on line 8982-2713 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2007
% INFO    : Updated Thermal Rating: on line 9878-12824 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2443
% INFO    : Updated Thermal Rating: on line 9878-10884 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 829
% INFO    : Updated Thermal Rating: on line 9878-6829 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4456
% INFO    : Updated Thermal Rating: on line 375-40 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 32723
% INFO    : Updated Thermal Rating: on line 10886-375 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1095
% INFO    : Updated Thermal Rating: on line 375-7714 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 472
% INFO    : Updated Thermal Rating: on line 375-6555 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 888
% INFO    : Updated Thermal Rating: on line 375-7714 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 477
% INFO    : Updated Thermal Rating: on line 1973-40 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 265
% INFO    : Updated Thermal Rating: on line 40-3035 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1629
% INFO    : Updated Thermal Rating: on line 4332-9883 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1957
% INFO    : Updated Thermal Rating: on line 9025-8256 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1714
% INFO    : Updated Thermal Rating: on line 12985-8681 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4839
% INFO    : Updated Thermal Rating: on line 650-12985 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2256
% INFO    : Updated Thermal Rating: on line 1793-8681 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3702
% INFO    : Updated Thermal Rating: on line 1227-6582 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1902
% INFO    : Updated Thermal Rating: on line 1227-6582 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1940
% INFO    : Updated Thermal Rating: on line 882-6582 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2415
% INFO    : Updated Thermal Rating: on line 882-6582 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2374
% INFO    : Updated Thermal Rating: on line 9491-12754 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2585
% INFO    : Updated Thermal Rating: on line 9491-10894 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3311
% INFO    : Updated Thermal Rating: on line 12754-6878 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2538
% INFO    : Updated Thermal Rating: on line 8018-2770 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3295
% INFO    : Updated Thermal Rating: on line 8018-6470 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2267
% INFO    : Updated Thermal Rating: on line 8018-6470 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2227
% INFO    : Updated Thermal Rating: on line 11140-4937 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 36111
% INFO    : Updated Thermal Rating: on line 11140-4937 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 36526
% INFO    : Updated Thermal Rating: on line 11140-12384 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13322
% INFO    : Updated Thermal Rating: on line 999-7552 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5534
% INFO    : Updated Thermal Rating: on line 3076-7582 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 774
% INFO    : Updated Thermal Rating: on line 2418-257 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1960
% INFO    : Updated Thermal Rating: on line 2418-257 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1925
% INFO    : Updated Thermal Rating: on line 257-2965 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1323
% INFO    : Updated Thermal Rating: on line 2465-257 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3539
% INFO    : Updated Thermal Rating: on line 2633-6746 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 830
% INFO    : Updated Thermal Rating: on line 2633-6746 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 918
% INFO    : Updated Thermal Rating: on line 4497-8327 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1134
% INFO    : Updated Thermal Rating: on line 4497-8327 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1114
% INFO    : Updated Thermal Rating: on line 8327-6995 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3716
% INFO    : Updated Thermal Rating: on line 11213-6294 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 504
% INFO    : Updated Thermal Rating: on line 9025-7552 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1354
% INFO    : Updated Thermal Rating: on line 777-4876 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14910
% INFO    : Updated Thermal Rating: on line 777-12577 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13316
% INFO    : Updated Thermal Rating: on line 777-7360 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 57786
% INFO    : Updated Thermal Rating: on line 9505-9663 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4045
% INFO    : Updated Thermal Rating: on line 6829-6900 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8536
% INFO    : Updated Thermal Rating: on line 9731-2959 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2435
% INFO    : Updated Thermal Rating: on line 9731-13295 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3519
% INFO    : Updated Thermal Rating: on line 9731-1756 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6012
% INFO    : Updated Thermal Rating: on line 3807-1157 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1310
% INFO    : Updated Thermal Rating: on line 4803-9858 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 350
% INFO    : Updated Thermal Rating: on line 10856-6460 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1361
% INFO    : Updated Thermal Rating: on line 10856-11738 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2586
% INFO    : Updated Thermal Rating: on line 10856-11738 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2632
% INFO    : Updated Thermal Rating: on line 1443-6555 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8366
% INFO    : Updated Thermal Rating: on line 1443-7353 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 648
% INFO    : Updated Thermal Rating: on line 12754-10711 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1222
% INFO    : Updated Thermal Rating: on line 12754-5903 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2000
% INFO    : Updated Thermal Rating: on line 8489-12754 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2363
% INFO    : Updated Thermal Rating: on line 12754-3132 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4179
% INFO    : Updated Thermal Rating: on line 116-4323 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 84901
% INFO    : Updated Thermal Rating: on line 11948-6470 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4622
% INFO    : Updated Thermal Rating: on line 41-4865 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18888
% INFO    : Updated Thermal Rating: on line 9497-12225 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2625
% INFO    : Updated Thermal Rating: on line 9497-10032 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2349
% INFO    : Updated Thermal Rating: on line 6419-11469 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3745
% INFO    : Updated Thermal Rating: on line 4149-7790 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2100
% INFO    : Updated Thermal Rating: on line 8377-9986 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 105292
% INFO    : Updated Thermal Rating: on line 4292-9986 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 105292
% INFO    : Updated Thermal Rating: on line 4292-7854 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3954
% INFO    : Updated Thermal Rating: on line 5349-344 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 770
% INFO    : Updated Thermal Rating: on line 340-1468 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3391
% INFO    : Updated Thermal Rating: on line 2105-10769 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12713
% INFO    : Updated Thermal Rating: on line 10769-7258 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 982
% INFO    : Updated Thermal Rating: on line 5778-1386 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6176
% INFO    : Updated Thermal Rating: on line 5778-6867 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1944
% INFO    : Updated Thermal Rating: on line 5915-7826 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1219
% INFO    : Updated Thermal Rating: on line 11470-5854 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3450
% INFO    : Updated Thermal Rating: on line 11470-5903 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3603
% INFO    : Updated Thermal Rating: on line 5457-11673 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3502
% INFO    : Updated Thermal Rating: on line 5457-11673 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3778
% INFO    : Updated Thermal Rating: on line 5457-4518 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3295
% INFO    : Updated Thermal Rating: on line 5457-4518 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3236
% INFO    : Updated Thermal Rating: on line 6322-7952 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4352
% INFO    : Updated Thermal Rating: on line 2770-6026 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2470
% INFO    : Updated Thermal Rating: on line 5833-1543 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3291
% INFO    : Updated Thermal Rating: on line 5833-1156 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1294
% INFO    : Updated Thermal Rating: on line 5833-6614 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1852
% INFO    : Updated Thermal Rating: on line 8585-5435 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2014
% INFO    : Updated Thermal Rating: on line 12079-4503 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4598
% INFO    : Updated Thermal Rating: on line 12079-4089 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1247
% INFO    : Updated Thermal Rating: on line 5854-5903 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1513
% INFO    : Updated Thermal Rating: on line 2418-5854 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4012
% INFO    : Updated Thermal Rating: on line 2418-5854 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3937
% INFO    : Updated Thermal Rating: on line 2015-5336 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6468
% INFO    : Updated Thermal Rating: on line 3007-2015 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7053
% INFO    : Updated Thermal Rating: on line 4080-4803 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 985
% INFO    : Updated Thermal Rating: on line 2340-7745 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 36222
% INFO    : Updated Thermal Rating: on line 4575-9844 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 764
% INFO    : Updated Thermal Rating: on line 4575-7353 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1017
% INFO    : Updated Thermal Rating: on line 9446-401 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20925
% INFO    : Updated Thermal Rating: on line 401-6004 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3326
% INFO    : Updated Thermal Rating: on line 401-6004 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3395
% INFO    : Updated Thermal Rating: on line 2959-6898 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1975
% INFO    : Updated Thermal Rating: on line 7253-2015 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5036
% INFO    : Updated Thermal Rating: on line 3822-2808 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3501
% INFO    : Updated Thermal Rating: on line 3822-11776 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4810
% INFO    : Updated Thermal Rating: on line 10031-8972 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3461
% INFO    : Updated Thermal Rating: on line 6867-6588 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 364
% INFO    : Updated Thermal Rating: on line 6867-6588 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 379
% INFO    : Updated Thermal Rating: on line 6867-1591 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20833
% INFO    : Updated Thermal Rating: on line 7713-4503 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15802
% INFO    : Updated Thermal Rating: on line 4503-7713 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16708
% INFO    : Updated Thermal Rating: on line 245-2537 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1238
% INFO    : Updated Thermal Rating: on line 11267-2038 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1631
% INFO    : Updated Thermal Rating: on line 8469-1235 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1403
% INFO    : Updated Thermal Rating: on line 5795-12082 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6347
% INFO    : Updated Thermal Rating: on line 5795-1358 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6732
% INFO    : Updated Thermal Rating: on line 3345-12820 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9608
% INFO    : Updated Thermal Rating: on line 3345-11738 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7669
% INFO    : Updated Thermal Rating: on line 9115-1370 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4105
% INFO    : Updated Thermal Rating: on line 9115-13134 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4187
% INFO    : Updated Thermal Rating: on line 2731-2140 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 636
% INFO    : Updated Thermal Rating: on line 10929-2808 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 80052
% INFO    : Updated Thermal Rating: on line 1472-8779 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1733
% INFO    : Updated Thermal Rating: on line 1472-9612 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1715
% INFO    : Updated Thermal Rating: on line 1472-7714 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3672
% INFO    : Updated Thermal Rating: on line 1472-6271 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1404
% INFO    : Updated Thermal Rating: on line 4420-6614 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3620
% INFO    : Updated Thermal Rating: on line 5903-13478 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2668
% INFO    : Updated Thermal Rating: on line 5903-10894 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5324
% INFO    : Updated Thermal Rating: on line 5903-3132 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3176
% INFO    : Updated Thermal Rating: on line 10230-4865 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 915
% INFO    : Updated Thermal Rating: on line 2923-3589 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5124
% INFO    : Updated Thermal Rating: on line 5198-1156 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1155
% INFO    : Updated Thermal Rating: on line 1227-7198 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16962
% INFO    : Updated Thermal Rating: on line 1227-9448 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1268
% INFO    : Updated Thermal Rating: on line 6460-2140 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1045
% INFO    : Updated Thermal Rating: on line 11673-5041 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7010
% INFO    : Updated Thermal Rating: on line 1285-6206 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5932
% INFO    : Updated Thermal Rating: on line 1285-1756 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1407
% INFO    : Updated Thermal Rating: on line 882-7198 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3599
% INFO    : Updated Thermal Rating: on line 9448-882 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2334
% INFO    : Updated Thermal Rating: on line 6206-3480 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2334
% INFO    : Updated Thermal Rating: on line 3275-3928 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16272
% INFO    : Updated Thermal Rating: on line 13552-6470 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3367
% INFO    : Updated Thermal Rating: on line 7854-9287 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8489
% INFO    : Updated Thermal Rating: on line 3615-7542 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 537
% INFO    : Updated Thermal Rating: on line 7542-5516 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 828
% INFO    : Updated Thermal Rating: on line 3983-1370 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4224
% INFO    : Updated Thermal Rating: on line 3983-1370 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2921
% INFO    : Updated Thermal Rating: on line 7258-7952 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2981
% INFO    : Updated Thermal Rating: on line 1156-12743 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1522
% INFO    : Updated Thermal Rating: on line 9198-6294 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1921
% INFO    : Updated Thermal Rating: on line 12143-6448 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1325
% INFO    : Updated Thermal Rating: on line 12143-6448 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1351
% INFO    : Updated Thermal Rating: on line 11168-650 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1463
% INFO    : Updated Thermal Rating: on line 13295-12350 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2856
% INFO    : Updated Thermal Rating: on line 6294-6136 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7808
% INFO    : Updated Thermal Rating: on line 957-11657 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 32126
% INFO    : Updated Thermal Rating: on line 4876-7360 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12595
% INFO    : Updated Thermal Rating: on line 7996-7714 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 981
% INFO    : Updated Thermal Rating: on line 7996-2034 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1340
% INFO    : Updated Thermal Rating: on line 8986-6271 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1006
% INFO    : Updated Thermal Rating: on line 8986-6271 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1164
% INFO    : Updated Thermal Rating: on line 6829-877 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1425
% INFO    : Updated Thermal Rating: on line 4497-1235 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4698
% INFO    : Updated Thermal Rating: on line 4497-1235 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4612
% INFO    : Updated Thermal Rating: on line 5915-1543 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1633
% INFO    : Updated Thermal Rating: on line 3372-12668 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2024
% INFO    : Updated Thermal Rating: on line 2381-5966 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21165
% INFO    : Updated Thermal Rating: on line 6588-11673 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3317
% INFO    : Updated Thermal Rating: on line 11673-9660 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3324
% INFO    : Updated Thermal Rating: on line 9660-2062 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2216
% INFO    : Updated Thermal Rating: on line 3589-11166 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3179
% INFO    : Updated Thermal Rating: on line 2829-13462 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3430
% INFO    : Updated Thermal Rating: on line 7258-11782 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2982
% INFO    : Updated Thermal Rating: on line 6828-8268 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3182
% INFO    : Updated Thermal Rating: on line 6828-8268 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2822
% INFO    : Updated Thermal Rating: on line 286-656 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1334
% INFO    : Updated Thermal Rating: on line 3862-6524 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19605
% INFO    : Updated Thermal Rating: on line 6993-12225 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 433
% INFO    : Updated Thermal Rating: on line 6993-1399 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 634
% INFO    : Updated Thermal Rating: on line 650-344 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 924
% INFO    : Updated Thermal Rating: on line 6224-10146 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 474
% INFO    : Updated Thermal Rating: on line 10800-4518 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2767
% INFO    : Updated Thermal Rating: on line 10800-10878 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 534
% INFO    : Updated Thermal Rating: on line 1097-2965 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1286
% INFO    : Updated Thermal Rating: on line 2279-6027 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7589
% INFO    : Updated Thermal Rating: on line 3379-6027 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7754
% INFO    : Updated Thermal Rating: on line 344-2570 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1394
% INFO    : Updated Thermal Rating: on line 4359-6004 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3458
% INFO    : Updated Thermal Rating: on line 6829-1810 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1293
% INFO    : Updated Thermal Rating: on line 9226-8779 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 548
% INFO    : Updated Thermal Rating: on line 9226-12923 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 391
% INFO    : Updated Thermal Rating: on line 9226-8204 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1307
% INFO    : Updated Thermal Rating: on line 3761-12155 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21248
% INFO    : Updated Thermal Rating: on line 5536-12225 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 927
% INFO    : Updated Thermal Rating: on line 6555-7954 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1507
% INFO    : Updated Thermal Rating: on line 2465-2965 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1399
% INFO    : Updated Thermal Rating: on line 8419-3039 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6585
% INFO    : Updated Thermal Rating: on line 8419-3039 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6718
% INFO    : Updated Thermal Rating: on line 11270-570 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6097
% INFO    : Updated Thermal Rating: on line 12225-10032 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2691
% INFO    : Updated Thermal Rating: on line 2134-6004 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3398
% INFO    : Updated Thermal Rating: on line 8779-1012 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 137464
% INFO    : Updated Thermal Rating: on line 9612-1012 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 42591
% INFO    : Updated Thermal Rating: on line 9612-8204 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 443
% INFO    : Updated Thermal Rating: on line 3035-8204 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4276
% INFO    : Updated Thermal Rating: on line 3035-8204 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6853
% INFO    : Updated Thermal Rating: on line 7954-7353 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1189
% INFO    : Updated Thermal Rating: on line 13224-9686 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2111
% INFO    : Updated Thermal Rating: on line 7714-6271 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 913
% INFO    : Updated Thermal Rating: on line 7714-6271 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 931
% INFO    : Updated Thermal Rating: on line 7353-6962 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4350
% INFO    : Updated Thermal Rating: on line 7353-10146 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4376
% INFO    : Updated Thermal Rating: on line 2034-6271 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 532
% INFO    : Updated Thermal Rating: on line 9729-12384 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 71510
% INFO    : Updated Thermal Rating: on line 9729-12384 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 73159
% INFO    : Updated Thermal Rating: on line 8226-7917 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 39412
% INFO    : Updated Thermal Rating: on line 6321-11066 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1864
% INFO    : Updated Thermal Rating: on line 8434-5760 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7252
% INFO    : Updated Thermal Rating: on line 9867-12476 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12799
% INFO    : Updated Thermal Rating: on line 9867-6599 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8353
% INFO    : Updated Thermal Rating: on line 5046-13471 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 53817
% INFO    : Updated Thermal Rating: on line 4215-13471 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 42657
% INFO    : Updated Thermal Rating: on line 2033-13471 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 53244
% INFO    : Updated Thermal Rating: on line 2634-13471 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 48642
% INFO    : Updated Thermal Rating: on line 5721-13471 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 53416
% INFO    : Updated Thermal Rating: on line 9083-13001 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6384
% INFO    : Updated Thermal Rating: on line 13300-11517 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 41388
% INFO    : Updated Thermal Rating: on line 13300-13605 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5051
% INFO    : Updated Thermal Rating: on line 13300-3010 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4190
% INFO    : Updated Thermal Rating: on line 13300-36 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3577
% INFO    : Updated Thermal Rating: on line 924-13177 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 34578
% INFO    : Updated Thermal Rating: on line 924-6741 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4380
% INFO    : Updated Thermal Rating: on line 3475-8047 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14992
% INFO    : Updated Thermal Rating: on line 3475-1798 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 817
% INFO    : Updated Thermal Rating: on line 3475-13250 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1473
% INFO    : Updated Thermal Rating: on line 3475-12568 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 863
% INFO    : Updated Thermal Rating: on line 3475-10058 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 838
% INFO    : Updated Thermal Rating: on line 3475-4969 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4685
% INFO    : Updated Thermal Rating: on line 3475-936 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3433
% INFO    : Updated Thermal Rating: on line 3475-3737 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9747
% INFO    : Updated Thermal Rating: on line 3475-7793 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1772
% INFO    : Updated Thermal Rating: on line 4397-1039 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 124840
% INFO    : Updated Thermal Rating: on line 4369-3319 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 42335
% INFO    : Updated Thermal Rating: on line 12797-10943 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 972
% INFO    : Updated Thermal Rating: on line 12797-10943 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1055
% INFO    : Updated Thermal Rating: on line 1266-5393 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 70101
% INFO    : Updated Thermal Rating: on line 12926-10303 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21113
% INFO    : Updated Thermal Rating: on line 12926-5753 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 41734
% INFO    : Updated Thermal Rating: on line 3246-2813 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 50883
% INFO    : Updated Thermal Rating: on line 7493-4212 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 35472
% INFO    : Updated Thermal Rating: on line 9692-7207 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2273
% INFO    : Updated Thermal Rating: on line 9692-10710 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2617
% INFO    : Updated Thermal Rating: on line 606-4776 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 50969
% INFO    : Updated Thermal Rating: on line 606-4776 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 49351
% INFO    : Updated Thermal Rating: on line 4732-7207 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7265
% INFO    : Updated Thermal Rating: on line 4732-6274 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1670
% INFO    : Updated Thermal Rating: on line 4732-10710 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9162
% INFO    : Updated Thermal Rating: on line 1647-1694 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2399
% INFO    : Updated Thermal Rating: on line 1647-11678 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9180
% INFO    : Updated Thermal Rating: on line 13172-3466 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25425
% INFO    : Updated Thermal Rating: on line 12795-4279 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 857
% INFO    : Updated Thermal Rating: on line 12795-8788 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2617
% INFO    : Updated Thermal Rating: on line 4805-10642 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2816
% INFO    : Updated Thermal Rating: on line 4805-426 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4036
% INFO    : Updated Thermal Rating: on line 4805-4435 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 939
% INFO    : Updated Thermal Rating: on line 4805-4953 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3066
% INFO    : Updated Thermal Rating: on line 543-1154 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9881
% INFO    : Updated Thermal Rating: on line 543-1154 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9744
% INFO    : Updated Thermal Rating: on line 4667-11443 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1598
% INFO    : Updated Thermal Rating: on line 4667-7938 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 586
% INFO    : Updated Thermal Rating: on line 4667-2641 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1996
% INFO    : Updated Thermal Rating: on line 9942-7878 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7899
% INFO    : Updated Thermal Rating: on line 9942-7878 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8381
% INFO    : Updated Thermal Rating: on line 9942-2296 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4018
% INFO    : Updated Thermal Rating: on line 9942-2296 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4034
% INFO    : Updated Thermal Rating: on line 9942-2296 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4041
% INFO    : Updated Thermal Rating: on line 9942-3493 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9636
% INFO    : Updated Thermal Rating: on line 9942-1346 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11510
% INFO    : Updated Thermal Rating: on line 13517-738 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2502
% INFO    : Updated Thermal Rating: on line 13517-4340 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4315
% INFO    : Updated Thermal Rating: on line 13517-4246 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3575
% INFO    : Updated Thermal Rating: on line 13517-4246 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3646
% INFO    : Updated Thermal Rating: on line 13517-4246 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3663
% INFO    : Updated Thermal Rating: on line 10331-3147 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 36421
% INFO    : Updated Thermal Rating: on line 10331-11861 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25518
% INFO    : Updated Thermal Rating: on line 10331-6577 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23967
% INFO    : Updated Thermal Rating: on line 10331-6228 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8717
% INFO    : Updated Thermal Rating: on line 12595-7709 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 48244
% INFO    : Updated Thermal Rating: on line 7969-5396 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25180
% INFO    : Updated Thermal Rating: on line 7969-4212 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12337
% INFO    : Updated Thermal Rating: on line 4543-5236 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1491
% INFO    : Updated Thermal Rating: on line 11390-12662 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6584
% INFO    : Updated Thermal Rating: on line 11390-12662 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6260
% INFO    : Updated Thermal Rating: on line 5-12839 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3514
% INFO    : Updated Thermal Rating: on line 5-11276 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 725
% INFO    : Updated Thermal Rating: on line 9749-4225 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3928
% INFO    : Updated Thermal Rating: on line 9749-4225 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3990
% INFO    : Updated Thermal Rating: on line 9749-5763 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1480
% INFO    : Updated Thermal Rating: on line 9749-5763 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1511
% INFO    : Updated Thermal Rating: on line 9749-9633 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2201
% INFO    : Updated Thermal Rating: on line 9749-9633 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2246
% INFO    : Updated Thermal Rating: on line 9749-5623 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2175
% INFO    : Updated Thermal Rating: on line 9749-8232 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2087
% INFO    : Updated Thermal Rating: on line 9749-8232 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1658
% INFO    : Updated Thermal Rating: on line 7207-7194 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 879
% INFO    : Updated Thermal Rating: on line 7207-8676 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 656
% INFO    : Updated Thermal Rating: on line 7207-7631 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 911
% INFO    : Updated Thermal Rating: on line 10011-10710 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 148968
% INFO    : Updated Thermal Rating: on line 12238-5367 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13251
% INFO    : Updated Thermal Rating: on line 3966-13022 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7291
% INFO    : Updated Thermal Rating: on line 13659-13022 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7442
% INFO    : Updated Thermal Rating: on line 4462-5428 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7227
% INFO    : Updated Thermal Rating: on line 4462-5428 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6738
% INFO    : Updated Thermal Rating: on line 4462-13138 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6103
% INFO    : Updated Thermal Rating: on line 2234-13237 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2393
% INFO    : Updated Thermal Rating: on line 2234-5194 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2443
% INFO    : Updated Thermal Rating: on line 12849-5446 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 32156
% INFO    : Updated Thermal Rating: on line 12849-5446 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 33953
% INFO    : Updated Thermal Rating: on line 12849-4005 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2515
% INFO    : Updated Thermal Rating: on line 12849-12264 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14927
% INFO    : Updated Thermal Rating: on line 12849-12552 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20990
% INFO    : Updated Thermal Rating: on line 12849-9611 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2238
% INFO    : Updated Thermal Rating: on line 12849-9611 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2415
% INFO    : Updated Thermal Rating: on line 12849-7971 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13028
% INFO    : Updated Thermal Rating: on line 12849-319 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6209
% INFO    : Updated Thermal Rating: on line 12849-4469 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 43067
% INFO    : Updated Thermal Rating: on line 12849-9893 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 122861
% INFO    : Updated Thermal Rating: on line 12849-7698 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 134762
% INFO    : Updated Thermal Rating: on line 5537-3942 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 34015
% INFO    : Updated Thermal Rating: on line 3251-8065 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3946
% INFO    : Updated Thermal Rating: on line 3251-9955 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2621
% INFO    : Updated Thermal Rating: on line 11386-655 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2955
% INFO    : Updated Thermal Rating: on line 11386-7779 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3062
% INFO    : Updated Thermal Rating: on line 1190-5763 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14872
% INFO    : Updated Thermal Rating: on line 1190-1158 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10058
% INFO    : Updated Thermal Rating: on line 6613-3262 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 983
% INFO    : Updated Thermal Rating: on line 6613-9938 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4050
% INFO    : Updated Thermal Rating: on line 6613-8426 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1114
% INFO    : Updated Thermal Rating: on line 9794-9150 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 947
% INFO    : Updated Thermal Rating: on line 9794-2032 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 692
% INFO    : Updated Thermal Rating: on line 9794-10468 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 396
% INFO    : Updated Thermal Rating: on line 9794-10895 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 654
% INFO    : Updated Thermal Rating: on line 8915-1228 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12175
% INFO    : Updated Thermal Rating: on line 11078-1228 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13128
% INFO    : Updated Thermal Rating: on line 1695-2203 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 464
% INFO    : Updated Thermal Rating: on line 1695-12559 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 547
% INFO    : Updated Thermal Rating: on line 5839-6011 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18252
% INFO    : Updated Thermal Rating: on line 5839-6011 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18682
% INFO    : Updated Thermal Rating: on line 9998-6400 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 69711
% INFO    : Updated Thermal Rating: on line 3099-8460 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6000
% INFO    : Updated Thermal Rating: on line 8287-4479 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3309
% INFO    : Updated Thermal Rating: on line 902-9920 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 45348
% INFO    : Updated Thermal Rating: on line 7886-7195 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 37527
% INFO    : Updated Thermal Rating: on line 5786-9955 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2192
% INFO    : Updated Thermal Rating: on line 9788-13544 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 931
% INFO    : Updated Thermal Rating: on line 9788-11829 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 987
% INFO    : Updated Thermal Rating: on line 5026-4088 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4712
% INFO    : Updated Thermal Rating: on line 5026-10309 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4156
% INFO    : Updated Thermal Rating: on line 5026-10309 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5194
% INFO    : Updated Thermal Rating: on line 5026-2348 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1759
% INFO    : Updated Thermal Rating: on line 5026-6736 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6495
% INFO    : Updated Thermal Rating: on line 8307-2413 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7400
% INFO    : Updated Thermal Rating: on line 8307-12054 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7268
% INFO    : Updated Thermal Rating: on line 8307-8496 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1522
% INFO    : Updated Thermal Rating: on line 8307-4621 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1863
% INFO    : Updated Thermal Rating: on line 8307-7730 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2226
% INFO    : Updated Thermal Rating: on line 8307-2392 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 768
% INFO    : Updated Thermal Rating: on line 10642-655 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1912
% INFO    : Updated Thermal Rating: on line 10642-6955 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2014
% INFO    : Updated Thermal Rating: on line 2621-11642 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25490
% INFO    : Updated Thermal Rating: on line 2621-3790 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19252
% INFO    : Updated Thermal Rating: on line 2621-10090 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27681
% INFO    : Updated Thermal Rating: on line 2621-13078 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9714
% INFO    : Updated Thermal Rating: on line 2621-6144 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25490
% INFO    : Updated Thermal Rating: on line 2291-738 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22423
% INFO    : Updated Thermal Rating: on line 4078-738 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20084
% INFO    : Updated Thermal Rating: on line 1919-6911 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3776
% INFO    : Updated Thermal Rating: on line 1919-738 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6259
% INFO    : Updated Thermal Rating: on line 1251-5445 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6921
% INFO    : Updated Thermal Rating: on line 1251-5445 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6952
% INFO    : Updated Thermal Rating: on line 12241-11033 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3162
% INFO    : Updated Thermal Rating: on line 12241-11033 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3103
% INFO    : Updated Thermal Rating: on line 9209-1753 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 70039
% INFO    : Updated Thermal Rating: on line 1753-6486 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 66806
% INFO    : Updated Thermal Rating: on line 1753-835 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 92032
% INFO    : Updated Thermal Rating: on line 1753-1829 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1613
% INFO    : Updated Thermal Rating: on line 1753-5428 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 487
% INFO    : Updated Thermal Rating: on line 13498-320 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10923
% INFO    : Updated Thermal Rating: on line 10251-320 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7964
% INFO    : Updated Thermal Rating: on line 1041-6488 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1764
% INFO    : Updated Thermal Rating: on line 1041-6488 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1730
% INFO    : Updated Thermal Rating: on line 1777-934 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2771
% INFO    : Updated Thermal Rating: on line 1777-934 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2720
% INFO    : Updated Thermal Rating: on line 1777-12691 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3013
% INFO    : Updated Thermal Rating: on line 1777-12691 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2595
% INFO    : Updated Thermal Rating: on line 12078-2847 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 37606
% INFO    : Updated Thermal Rating: on line 12078-11726 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21666
% INFO    : Updated Thermal Rating: on line 1489-13380 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1958
% INFO    : Updated Thermal Rating: on line 1489-10933 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 543
% INFO    : Updated Thermal Rating: on line 1489-457 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7089
% INFO    : Updated Thermal Rating: on line 1489-457 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6970
% INFO    : Updated Thermal Rating: on line 1489-7458 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3531
% INFO    : Updated Thermal Rating: on line 1489-7458 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4433
% INFO    : Updated Thermal Rating: on line 3628-12484 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5811
% INFO    : Updated Thermal Rating: on line 9062-13162 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11214
% INFO    : Updated Thermal Rating: on line 9068-11274 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1676
% INFO    : Updated Thermal Rating: on line 9068-9685 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2206
% INFO    : Updated Thermal Rating: on line 3391-12003 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4292
% INFO    : Updated Thermal Rating: on line 3391-13011 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1294
% INFO    : Updated Thermal Rating: on line 3391-6083 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7181
% INFO    : Updated Thermal Rating: on line 3391-3998 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 955
% INFO    : Updated Thermal Rating: on line 3391-9262 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2673
% INFO    : Updated Thermal Rating: on line 3391-9334 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2795
% INFO    : Updated Thermal Rating: on line 3391-12412 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3327
% INFO    : Updated Thermal Rating: on line 3391-4134 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13596
% INFO    : Updated Thermal Rating: on line 3391-10056 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1729
% INFO    : Updated Thermal Rating: on line 1766-6661 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4424
% INFO    : Updated Thermal Rating: on line 1168-12412 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9048
% INFO    : Updated Thermal Rating: on line 3286-6389 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3847
% INFO    : Updated Thermal Rating: on line 3286-1162 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2165
% INFO    : Updated Thermal Rating: on line 13566-9117 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3756
% INFO    : Updated Thermal Rating: on line 13566-9117 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3682
% INFO    : Updated Thermal Rating: on line 13566-8243 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2374
% INFO    : Updated Thermal Rating: on line 13566-8243 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1979
% INFO    : Updated Thermal Rating: on line 4205-5378 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12101
% INFO    : Updated Thermal Rating: on line 4205-5378 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12156
% INFO    : Updated Thermal Rating: on line 83-8374 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1583
% INFO    : Updated Thermal Rating: on line 83-3377 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1811
% INFO    : Updated Thermal Rating: on line 9532-11801 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27118
% INFO    : Updated Thermal Rating: on line 9532-8620 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2237
% INFO    : Updated Thermal Rating: on line 9532-8620 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2498
% INFO    : Updated Thermal Rating: on line 11601-4090 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7597
% INFO    : Updated Thermal Rating: on line 9407-6043 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 869
% INFO    : Updated Thermal Rating: on line 9407-5222 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 982
% INFO    : Updated Thermal Rating: on line 7189-4031 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5059
% INFO    : Updated Thermal Rating: on line 7189-523 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4370
% INFO    : Updated Thermal Rating: on line 7189-9633 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4041
% INFO    : Updated Thermal Rating: on line 7189-2746 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1823
% INFO    : Updated Thermal Rating: on line 7189-8497 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2756
% INFO    : Updated Thermal Rating: on line 7189-5623 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1671
% INFO    : Updated Thermal Rating: on line 7189-5249 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8198
% INFO    : Updated Thermal Rating: on line 11334-2558 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4858
% INFO    : Updated Thermal Rating: on line 11334-11442 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4792
% INFO    : Updated Thermal Rating: on line 11334-9633 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4130
% INFO    : Updated Thermal Rating: on line 11334-2746 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1968
% INFO    : Updated Thermal Rating: on line 11334-8497 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2707
% INFO    : Updated Thermal Rating: on line 11334-8232 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1707
% INFO    : Updated Thermal Rating: on line 11334-5249 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8371
% INFO    : Updated Thermal Rating: on line 6766-244 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2578
% INFO    : Updated Thermal Rating: on line 4533-3350 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 84603
% INFO    : Updated Thermal Rating: on line 9150-12997 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1269
% INFO    : Updated Thermal Rating: on line 9124-12744 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 753
% INFO    : Updated Thermal Rating: on line 8047-10444 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2183
% INFO    : Updated Thermal Rating: on line 12320-6392 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 67762
% INFO    : Updated Thermal Rating: on line 12320-4212 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 30454
% INFO    : Updated Thermal Rating: on line 890-1902 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1820
% INFO    : Updated Thermal Rating: on line 890-7887 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7777
% INFO    : Updated Thermal Rating: on line 890-7887 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7651
% INFO    : Updated Thermal Rating: on line 890-4974 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1302
% INFO    : Updated Thermal Rating: on line 890-1116 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1631
% INFO    : Updated Thermal Rating: on line 5393-4212 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26642
% INFO    : Updated Thermal Rating: on line 1920-13477 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1078
% INFO    : Updated Thermal Rating: on line 1920-5981 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2059
% INFO    : Updated Thermal Rating: on line 1920-11182 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2019
% INFO    : Updated Thermal Rating: on line 1920-1554 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1140
% INFO    : Updated Thermal Rating: on line 1920-1554 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1188
% INFO    : Updated Thermal Rating: on line 1920-3376 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3422
% INFO    : Updated Thermal Rating: on line 1920-6157 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1849
% INFO    : Updated Thermal Rating: on line 8521-12611 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2811
% INFO    : Updated Thermal Rating: on line 8521-8718 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1075
% INFO    : Updated Thermal Rating: on line 8521-11774 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1037
% INFO    : Updated Thermal Rating: on line 8521-5779 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 958
% INFO    : Updated Thermal Rating: on line 8521-4848 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 749
% INFO    : Updated Thermal Rating: on line 8521-6956 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2964
% INFO    : Updated Thermal Rating: on line 5497-1162 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11971
% INFO    : Updated Thermal Rating: on line 8992-1294 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9442
% INFO    : Updated Thermal Rating: on line 5888-9561 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1777
% INFO    : Updated Thermal Rating: on line 5888-3083 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 716
% INFO    : Updated Thermal Rating: on line 8322-4974 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1579
% INFO    : Updated Thermal Rating: on line 8322-1139 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1683
% INFO    : Updated Thermal Rating: on line 3319-13581 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22821
% INFO    : Updated Thermal Rating: on line 3319-4966 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21440
% INFO    : Updated Thermal Rating: on line 300-6955 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2328
% INFO    : Updated Thermal Rating: on line 300-11424 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5519
% INFO    : Updated Thermal Rating: on line 4638-9840 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 75017
% INFO    : Updated Thermal Rating: on line 4638-970 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3501
% INFO    : Updated Thermal Rating: on line 4638-970 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3579
% INFO    : Updated Thermal Rating: on line 4638-6512 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 927
% INFO    : Updated Thermal Rating: on line 4638-2350 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3991
% INFO    : Updated Thermal Rating: on line 4638-3448 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3742
% INFO    : Updated Thermal Rating: on line 12483-11746 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25173
% INFO    : Updated Thermal Rating: on line 12483-9538 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 28780
% INFO    : Updated Thermal Rating: on line 12483-11283 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25191
% INFO    : Updated Thermal Rating: on line 12483-609 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1284
% INFO    : Updated Thermal Rating: on line 12483-4086 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2810
% INFO    : Updated Thermal Rating: on line 12483-3502 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2871
% INFO    : Updated Thermal Rating: on line 12483-3502 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2961
% INFO    : Updated Thermal Rating: on line 12483-4315 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1609
% INFO    : Updated Thermal Rating: on line 8282-1420 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 328
% INFO    : Updated Thermal Rating: on line 8282-6497 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 424
% INFO    : Updated Thermal Rating: on line 6488-3891 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4683
% INFO    : Updated Thermal Rating: on line 6488-3891 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4773
% INFO    : Updated Thermal Rating: on line 3378-1154 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3215
% INFO    : Updated Thermal Rating: on line 3378-5010 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2630
% INFO    : Updated Thermal Rating: on line 4637-6956 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16743
% INFO    : Updated Thermal Rating: on line 6158-8034 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14024
% INFO    : Updated Thermal Rating: on line 8292-12299 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12826
% INFO    : Updated Thermal Rating: on line 11443-7462 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1823
% INFO    : Updated Thermal Rating: on line 10579-1162 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1003
% INFO    : Updated Thermal Rating: on line 6466-3056 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 113538
% INFO    : Updated Thermal Rating: on line 9009-3917 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4391
% INFO    : Updated Thermal Rating: on line 9009-6675 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4740
% INFO    : Updated Thermal Rating: on line 9009-11015 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2079
% INFO    : Updated Thermal Rating: on line 9009-10996 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2039
% INFO    : Updated Thermal Rating: on line 7339-32 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5182
% INFO    : Updated Thermal Rating: on line 7339-13621 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6285
% INFO    : Updated Thermal Rating: on line 8926-13308 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2344
% INFO    : Updated Thermal Rating: on line 8926-9096 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2089
% INFO    : Updated Thermal Rating: on line 8926-1242 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1654
% INFO    : Updated Thermal Rating: on line 8926-8338 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2297
% INFO    : Updated Thermal Rating: on line 2058-11287 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3302
% INFO    : Updated Thermal Rating: on line 2058-13308 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2693
% INFO    : Updated Thermal Rating: on line 2058-8721 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 538
% INFO    : Updated Thermal Rating: on line 2058-10761 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2234
% INFO    : Updated Thermal Rating: on line 2058-203 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4269
% INFO    : Updated Thermal Rating: on line 3572-6043 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7985
% INFO    : Updated Thermal Rating: on line 5857-9324 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1596
% INFO    : Updated Thermal Rating: on line 5857-6043 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7062
% INFO    : Updated Thermal Rating: on line 5857-7077 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 875
% INFO    : Updated Thermal Rating: on line 5857-11544 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6817
% INFO    : Updated Thermal Rating: on line 4012-11544 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6858
% INFO    : Updated Thermal Rating: on line 3572-8614 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5335
% INFO    : Updated Thermal Rating: on line 3572-3182 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5728
% INFO    : Updated Thermal Rating: on line 961-6290 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1038
% INFO    : Updated Thermal Rating: on line 961-12535 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1298
% INFO    : Updated Thermal Rating: on line 961-12535 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1274
% INFO    : Updated Thermal Rating: on line 6530-13308 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 34833
% INFO    : Updated Thermal Rating: on line 6530-13308 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 31811
% INFO    : Updated Thermal Rating: on line 1294-55 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1405
% INFO    : Updated Thermal Rating: on line 1294-13237 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1387
% INFO    : Updated Thermal Rating: on line 8660-13031 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17349
% INFO    : Updated Thermal Rating: on line 4605-12559 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2903
% INFO    : Updated Thermal Rating: on line 1426-12559 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3155
% INFO    : Updated Thermal Rating: on line 12997-2050 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2543
% INFO    : Updated Thermal Rating: on line 9707-13372 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 41134
% INFO    : Updated Thermal Rating: on line 13465-13372 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 45856
% INFO    : Updated Thermal Rating: on line 10170-9324 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1399
% INFO    : Updated Thermal Rating: on line 10170-13045 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1820
% INFO    : Updated Thermal Rating: on line 7974-6389 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23256
% INFO    : Updated Thermal Rating: on line 10941-4266 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1935
% INFO    : Updated Thermal Rating: on line 10941-4439 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 50038
% INFO    : Updated Thermal Rating: on line 806-9181 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1259
% INFO    : Updated Thermal Rating: on line 806-3268 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1410
% INFO    : Updated Thermal Rating: on line 806-5395 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2991
% INFO    : Updated Thermal Rating: on line 7319-6084 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 586
% INFO    : Updated Thermal Rating: on line 2696-7917 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10884
% INFO    : Updated Thermal Rating: on line 2696-7917 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10446
% INFO    : Updated Thermal Rating: on line 7987-7274 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4899
% INFO    : Updated Thermal Rating: on line 7987-7274 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4772
% INFO    : Updated Thermal Rating: on line 7987-7274 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4325
% INFO    : Updated Thermal Rating: on line 7987-7948 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3631
% INFO    : Updated Thermal Rating: on line 7987-11402 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2930
% INFO    : Updated Thermal Rating: on line 7987-10071 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2877
% INFO    : Updated Thermal Rating: on line 4445-6692 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6077
% INFO    : Updated Thermal Rating: on line 823-12495 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1280
% INFO    : Updated Thermal Rating: on line 823-3211 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1893
% INFO    : Updated Thermal Rating: on line 823-11608 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 666
% INFO    : Updated Thermal Rating: on line 6350-2641 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142001
% INFO    : Updated Thermal Rating: on line 4119-12862 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5705
% INFO    : Updated Thermal Rating: on line 4094-1554 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 669
% INFO    : Updated Thermal Rating: on line 4094-13408 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2146
% INFO    : Updated Thermal Rating: on line 13471-13568 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1795
% INFO    : Updated Thermal Rating: on line 13471-2016 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 448
% INFO    : Updated Thermal Rating: on line 13471-12559 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1775
% INFO    : Updated Thermal Rating: on line 13471-12559 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1879
% INFO    : Updated Thermal Rating: on line 13471-7396 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 545
% INFO    : Updated Thermal Rating: on line 13471-1507 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1771
% INFO    : Updated Thermal Rating: on line 13471-1980 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2012
% INFO    : Updated Thermal Rating: on line 13471-2259 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 925
% INFO    : Updated Thermal Rating: on line 9018-10058 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1835
% INFO    : Updated Thermal Rating: on line 11206-4350 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142001
% INFO    : Updated Thermal Rating: on line 10767-8175 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4392
% INFO    : Updated Thermal Rating: on line 6895-13408 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 31398
% INFO    : Updated Thermal Rating: on line 2390-7811 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 30565
% INFO    : Updated Thermal Rating: on line 5696-7811 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 29969
% INFO    : Updated Thermal Rating: on line 12456-7811 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 30207
% INFO    : Updated Thermal Rating: on line 5300-7811 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 31096
% INFO    : Updated Thermal Rating: on line 3980-7811 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 28500
% INFO    : Updated Thermal Rating: on line 7314-7811 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 29005
% INFO    : Updated Thermal Rating: on line 6389-8821 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2550
% INFO    : Updated Thermal Rating: on line 3067-7638 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16450
% INFO    : Updated Thermal Rating: on line 3067-9916 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2906
% INFO    : Updated Thermal Rating: on line 1499-5150 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157740
% INFO    : Updated Thermal Rating: on line 5948-1242 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 98903
% INFO    : Updated Thermal Rating: on line 6635-1242 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 89464
% INFO    : Updated Thermal Rating: on line 2425-8460 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 827
% INFO    : Updated Thermal Rating: on line 11923-2115 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 49257
% INFO    : Updated Thermal Rating: on line 8249-8034 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7545
% INFO    : Updated Thermal Rating: on line 6575-12299 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7692
% INFO    : Updated Thermal Rating: on line 13011-12412 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2355
% INFO    : Updated Thermal Rating: on line 3341-9412 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1894
% INFO    : Updated Thermal Rating: on line 668-603 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1155
% INFO    : Updated Thermal Rating: on line 668-5664 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 645
% INFO    : Updated Thermal Rating: on line 668-495 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 531
% INFO    : Updated Thermal Rating: on line 668-10138 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1056
% INFO    : Updated Thermal Rating: on line 12101-5395 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5843
% INFO    : Updated Thermal Rating: on line 6970-11371 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1699
% INFO    : Updated Thermal Rating: on line 6970-2768 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2910
% INFO    : Updated Thermal Rating: on line 6970-6217 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 742
% INFO    : Updated Thermal Rating: on line 3725-7804 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 519
% INFO    : Updated Thermal Rating: on line 3725-11066 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1233
% INFO    : Updated Thermal Rating: on line 3725-11066 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1679
% INFO    : Updated Thermal Rating: on line 3725-11066 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1437
% INFO    : Updated Thermal Rating: on line 3725-11753 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 702
% INFO    : Updated Thermal Rating: on line 3725-10585 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1711
% INFO    : Updated Thermal Rating: on line 3725-2220 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1125
% INFO    : Updated Thermal Rating: on line 11642-1657 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7870
% INFO    : Updated Thermal Rating: on line 12857-8007 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3499
% INFO    : Updated Thermal Rating: on line 4464-13138 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2346
% INFO    : Updated Thermal Rating: on line 2238-1385 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 50801
% INFO    : Updated Thermal Rating: on line 2904-2041 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2659
% INFO    : Updated Thermal Rating: on line 5220-934 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4539
% INFO    : Updated Thermal Rating: on line 5220-1154 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2576
% INFO    : Updated Thermal Rating: on line 609-5112 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 998
% INFO    : Updated Thermal Rating: on line 609-11662 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1303
% INFO    : Updated Thermal Rating: on line 4741-1783 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1762
% INFO    : Updated Thermal Rating: on line 4741-2574 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 49730
% INFO    : Updated Thermal Rating: on line 10813-544 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1943
% INFO    : Updated Thermal Rating: on line 6240-3018 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1150
% INFO    : Updated Thermal Rating: on line 6240-3018 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1114
% INFO    : Updated Thermal Rating: on line 6240-8095 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2996
% INFO    : Updated Thermal Rating: on line 9324-2581 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1159
% INFO    : Updated Thermal Rating: on line 9324-2581 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1139
% INFO    : Updated Thermal Rating: on line 9324-11544 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1826
% INFO    : Updated Thermal Rating: on line 6927-10683 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4058
% INFO    : Updated Thermal Rating: on line 6927-5877 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 45778
% INFO    : Updated Thermal Rating: on line 12800-3285 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4384
% INFO    : Updated Thermal Rating: on line 1275-7576 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16400
% INFO    : Updated Thermal Rating: on line 7509-7576 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14972
% INFO    : Updated Thermal Rating: on line 6178-9593 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18862
% INFO    : Updated Thermal Rating: on line 10735-9593 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18455
% INFO    : Updated Thermal Rating: on line 8522-2863 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3688
% INFO    : Updated Thermal Rating: on line 8522-894 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5049
% INFO    : Updated Thermal Rating: on line 5598-3560 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24790
% INFO    : Updated Thermal Rating: on line 1261-9677 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21835
% INFO    : Updated Thermal Rating: on line 5236-11927 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1755
% INFO    : Updated Thermal Rating: on line 5236-11927 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2081
% INFO    : Updated Thermal Rating: on line 9561-3083 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 492
% INFO    : Updated Thermal Rating: on line 9561-12662 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 427
% INFO    : Updated Thermal Rating: on line 9561-889 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 909
% INFO    : Updated Thermal Rating: on line 9561-889 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 990
% INFO    : Updated Thermal Rating: on line 6589-11823 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2279
% INFO    : Updated Thermal Rating: on line 6589-10309 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2375
% INFO    : Updated Thermal Rating: on line 7804-8460 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1202
% INFO    : Updated Thermal Rating: on line 5415-26 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22404
% INFO    : Updated Thermal Rating: on line 7503-955 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5156
% INFO    : Updated Thermal Rating: on line 1893-955 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5264
% INFO    : Updated Thermal Rating: on line 12449-11161 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3961
% INFO    : Updated Thermal Rating: on line 12449-1621 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1303
% INFO    : Updated Thermal Rating: on line 12449-4436 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1457
% INFO    : Updated Thermal Rating: on line 12449-459 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3020
% INFO    : Updated Thermal Rating: on line 12449-459 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2963
% INFO    : Updated Thermal Rating: on line 12449-10966 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1223
% INFO    : Updated Thermal Rating: on line 617-2957 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 35750
% INFO    : Updated Thermal Rating: on line 10959-9125 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25882
% INFO    : Updated Thermal Rating: on line 10959-2230 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 38849
% INFO    : Updated Thermal Rating: on line 11400-2350 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8338
% INFO    : Updated Thermal Rating: on line 11888-3448 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8600
% INFO    : Updated Thermal Rating: on line 13198-2350 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7668
% INFO    : Updated Thermal Rating: on line 1373-3448 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7457
% INFO    : Updated Thermal Rating: on line 13181-2366 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 29496
% INFO    : Updated Thermal Rating: on line 13181-7203 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 29418
% INFO    : Updated Thermal Rating: on line 3805-13455 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1458
% INFO    : Updated Thermal Rating: on line 3805-13130 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1358
% INFO    : Updated Thermal Rating: on line 5160-13455 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1430
% INFO    : Updated Thermal Rating: on line 5160-13130 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1332
% INFO    : Updated Thermal Rating: on line 2538-12744 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2649
% INFO    : Updated Thermal Rating: on line 2538-12744 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3236
% INFO    : Updated Thermal Rating: on line 8217-1464 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 407
% INFO    : Updated Thermal Rating: on line 8217-12744 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3297
% INFO    : Updated Thermal Rating: on line 1578-4134 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17110
% INFO    : Updated Thermal Rating: on line 10821-3917 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1328
% INFO    : Updated Thermal Rating: on line 10821-7013 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 29975
% INFO    : Updated Thermal Rating: on line 5197-1229 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3899
% INFO    : Updated Thermal Rating: on line 5197-5623 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4697
% INFO    : Updated Thermal Rating: on line 3395-1465 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4210
% INFO    : Updated Thermal Rating: on line 3395-8232 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4991
% INFO    : Updated Thermal Rating: on line 544-1679 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3570
% INFO    : Updated Thermal Rating: on line 544-5121 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5103
% INFO    : Updated Thermal Rating: on line 544-12913 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5087
% INFO    : Updated Thermal Rating: on line 2615-11522 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8331
% INFO    : Updated Thermal Rating: on line 2615-11522 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9649
% INFO    : Updated Thermal Rating: on line 2615-5824 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3558
% INFO    : Updated Thermal Rating: on line 2615-13324 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6744
% INFO    : Updated Thermal Rating: on line 2615-3181 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6876
% INFO    : Updated Thermal Rating: on line 5845-3540 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2041
% INFO    : Updated Thermal Rating: on line 5845-3540 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2003
% INFO    : Updated Thermal Rating: on line 8924-13110 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5394
% INFO    : Updated Thermal Rating: on line 8924-1420 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1846
% INFO    : Updated Thermal Rating: on line 11081-2581 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2610
% INFO    : Updated Thermal Rating: on line 11081-4134 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 995
% INFO    : Updated Thermal Rating: on line 32-9685 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 927
% INFO    : Updated Thermal Rating: on line 32-3556 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1303
% INFO    : Updated Thermal Rating: on line 32-6741 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2160
% INFO    : Updated Thermal Rating: on line 32-6212 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3184
% INFO    : Updated Thermal Rating: on line 32-7515 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6520
% INFO    : Updated Thermal Rating: on line 32-7515 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7895
% INFO    : Updated Thermal Rating: on line 11274-3556 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1827
% INFO    : Updated Thermal Rating: on line 11274-3010 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2120
% INFO    : Updated Thermal Rating: on line 11274-13621 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9168
% INFO    : Updated Thermal Rating: on line 11274-13621 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12700
% INFO    : Updated Thermal Rating: on line 11274-6212 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3251
% INFO    : Updated Thermal Rating: on line 11274-5150 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6651
% INFO    : Updated Thermal Rating: on line 11274-5150 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7915
% INFO    : Updated Thermal Rating: on line 2677-7219 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6116
% INFO    : Updated Thermal Rating: on line 167-7219 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6246
% INFO    : Updated Thermal Rating: on line 11371-5520 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1361
% INFO    : Updated Thermal Rating: on line 11371-5520 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1484
% INFO    : Updated Thermal Rating: on line 11371-5520 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1538
% INFO    : Updated Thermal Rating: on line 7251-13274 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2888
% INFO    : Updated Thermal Rating: on line 7251-11276 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1594
% INFO    : Updated Thermal Rating: on line 8935-11583 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 540
% INFO    : Updated Thermal Rating: on line 8935-6666 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2039
% INFO    : Updated Thermal Rating: on line 8935-6666 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2080
% INFO    : Updated Thermal Rating: on line 12716-5445 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1941
% INFO    : Updated Thermal Rating: on line 12716-11033 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7052
% INFO    : Updated Thermal Rating: on line 12716-11033 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8133
% INFO    : Updated Thermal Rating: on line 12716-6081 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2731
% INFO    : Updated Thermal Rating: on line 12716-6081 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2678
% INFO    : Updated Thermal Rating: on line 12716-6187 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2102
% INFO    : Updated Thermal Rating: on line 2529-235 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2472
% INFO    : Updated Thermal Rating: on line 6234-3473 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25068
% INFO    : Updated Thermal Rating: on line 5446-7726 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 45030
% INFO    : Updated Thermal Rating: on line 1087-12264 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25940
% INFO    : Updated Thermal Rating: on line 1087-13332 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21222
% INFO    : Updated Thermal Rating: on line 1087-4469 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 45595
% INFO    : Updated Thermal Rating: on line 3609-2580 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4620
% INFO    : Updated Thermal Rating: on line 3609-5981 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2596
% INFO    : Updated Thermal Rating: on line 3609-11182 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2652
% INFO    : Updated Thermal Rating: on line 3609-6212 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3251
% INFO    : Updated Thermal Rating: on line 3609-7515 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2438
% INFO    : Updated Thermal Rating: on line 3609-5150 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2485
% INFO    : Updated Thermal Rating: on line 10683-5877 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4537
% INFO    : Updated Thermal Rating: on line 4349-1507 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 89200
% INFO    : Updated Thermal Rating: on line 3865-7567 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 43865
% INFO    : Updated Thermal Rating: on line 12696-2876 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 42767
% INFO    : Updated Thermal Rating: on line 1265-11146 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 29632
% INFO    : Updated Thermal Rating: on line 1798-5367 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 837
% INFO    : Updated Thermal Rating: on line 7878-3942 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1363
% INFO    : Updated Thermal Rating: on line 9-6777 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2470
% INFO    : Updated Thermal Rating: on line 9-11015 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3176
% INFO    : Updated Thermal Rating: on line 9-7711 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 105881
% INFO    : Updated Thermal Rating: on line 9-7889 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 39728
% INFO    : Updated Thermal Rating: on line 9-2936 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1535
% INFO    : Updated Thermal Rating: on line 9-6905 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2069
% INFO    : Updated Thermal Rating: on line 9087-3917 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1737
% INFO    : Updated Thermal Rating: on line 9087-10996 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2808
% INFO    : Updated Thermal Rating: on line 9087-2936 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1844
% INFO    : Updated Thermal Rating: on line 11842-6777 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2437
% INFO    : Updated Thermal Rating: on line 11842-6675 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1809
% INFO    : Updated Thermal Rating: on line 11842-2936 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1629
% INFO    : Updated Thermal Rating: on line 2951-1217 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1903
% INFO    : Updated Thermal Rating: on line 2951-1217 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2107
% INFO    : Updated Thermal Rating: on line 2951-1217 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1811
% INFO    : Updated Thermal Rating: on line 2951-11912 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 36840
% INFO    : Updated Thermal Rating: on line 2951-5097 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1031
% INFO    : Updated Thermal Rating: on line 2951-5293 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3104
% INFO    : Updated Thermal Rating: on line 2951-3994 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12197
% INFO    : Updated Thermal Rating: on line 2951-3994 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13903
% INFO    : Updated Thermal Rating: on line 2951-12485 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 785
% INFO    : Updated Thermal Rating: on line 2951-1632 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4796
% INFO    : Updated Thermal Rating: on line 2951-27 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4752
% INFO    : Updated Thermal Rating: on line 13110-1420 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1376
% INFO    : Updated Thermal Rating: on line 13110-2958 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 798
% INFO    : Updated Thermal Rating: on line 13110-6475 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1037
% INFO    : Updated Thermal Rating: on line 13110-9795 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1905
% INFO    : Updated Thermal Rating: on line 13110-7048 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2874
% INFO    : Updated Thermal Rating: on line 13110-10497 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1170
% INFO    : Updated Thermal Rating: on line 4225-4088 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5758
% INFO    : Updated Thermal Rating: on line 4225-4088 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5875
% INFO    : Updated Thermal Rating: on line 4225-227 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2288
% INFO    : Updated Thermal Rating: on line 4225-227 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2025
% INFO    : Updated Thermal Rating: on line 4225-2348 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1418
% INFO    : Updated Thermal Rating: on line 4225-1158 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1448
% INFO    : Updated Thermal Rating: on line 13581-9920 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9227
% INFO    : Updated Thermal Rating: on line 13581-4966 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 37102
% INFO    : Updated Thermal Rating: on line 13581-2587 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10077
% INFO    : Updated Thermal Rating: on line 13581-5472 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12119
% INFO    : Updated Thermal Rating: on line 13581-5449 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13958
% INFO    : Updated Thermal Rating: on line 13581-10989 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3272
% INFO    : Updated Thermal Rating: on line 13581-10989 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2926
% INFO    : Updated Thermal Rating: on line 13581-10989 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3642
% INFO    : Updated Thermal Rating: on line 13581-3444 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4517
% INFO    : Updated Thermal Rating: on line 4005-12552 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 37687
% INFO    : Updated Thermal Rating: on line 4005-319 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4920
% INFO    : Updated Thermal Rating: on line 665-3010 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11419
% INFO    : Updated Thermal Rating: on line 7464-1829 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 604
% INFO    : Updated Thermal Rating: on line 7464-1829 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 423
% INFO    : Updated Thermal Rating: on line 7464-2508 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1500
% INFO    : Updated Thermal Rating: on line 7464-6475 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1189
% INFO    : Updated Thermal Rating: on line 7464-9358 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 902
% INFO    : Updated Thermal Rating: on line 3506-11823 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4461
% INFO    : Updated Thermal Rating: on line 3768-11823 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4501
% INFO    : Updated Thermal Rating: on line 11925-9913 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1793
% INFO    : Updated Thermal Rating: on line 11925-9913 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1627
% INFO    : Updated Thermal Rating: on line 6777-1361 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3346
% INFO    : Updated Thermal Rating: on line 6777-1361 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3251
% INFO    : Updated Thermal Rating: on line 6777-5846 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5920
% INFO    : Updated Thermal Rating: on line 6777-5846 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6655
% INFO    : Updated Thermal Rating: on line 6777-5846 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6285
% INFO    : Updated Thermal Rating: on line 2296-3455 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4907
% INFO    : Updated Thermal Rating: on line 2296-3455 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4995
% INFO    : Updated Thermal Rating: on line 2296-13302 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1808
% INFO    : Updated Thermal Rating: on line 5589-1162 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1108
% INFO    : Updated Thermal Rating: on line 7975-1356 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 150246
% INFO    : Updated Thermal Rating: on line 1892-1356 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 126249
% INFO    : Updated Thermal Rating: on line 742-1356 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 101684
% INFO    : Updated Thermal Rating: on line 4294-1356 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 78748
% INFO    : Updated Thermal Rating: on line 6679-9331 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6562
% INFO    : Updated Thermal Rating: on line 6679-9331 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6397
% INFO    : Updated Thermal Rating: on line 9996-2274 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2606
% INFO    : Updated Thermal Rating: on line 12212-7779 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10281
% INFO    : Updated Thermal Rating: on line 9082-7779 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10093
% INFO    : Updated Thermal Rating: on line 13605-13583 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2955
% INFO    : Updated Thermal Rating: on line 3831-8642 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1359
% INFO    : Updated Thermal Rating: on line 3831-10399 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 728
% INFO    : Updated Thermal Rating: on line 4216-8428 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1584
% INFO    : Updated Thermal Rating: on line 4216-5428 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 715
% INFO    : Updated Thermal Rating: on line 3735-12862 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2061
% INFO    : Updated Thermal Rating: on line 3735-3018 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1039
% INFO    : Updated Thermal Rating: on line 7343-11066 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 959
% INFO    : Updated Thermal Rating: on line 13077-1621 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1820
% INFO    : Updated Thermal Rating: on line 10818-4848 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4788
% INFO    : Updated Thermal Rating: on line 1786-6497 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 678
% INFO    : Updated Thermal Rating: on line 1786-2804 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1550
% INFO    : Updated Thermal Rating: on line 11861-10494 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 61700
% INFO    : Updated Thermal Rating: on line 10112-7192 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1673
% INFO    : Updated Thermal Rating: on line 10112-1835 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21414
% INFO    : Updated Thermal Rating: on line 12331-6906 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1705
% INFO    : Updated Thermal Rating: on line 13250-10444 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4377
% INFO    : Updated Thermal Rating: on line 13250-10058 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1384
% INFO    : Updated Thermal Rating: on line 10782-10258 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 64904
% INFO    : Updated Thermal Rating: on line 10782-9125 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 40281
% INFO    : Updated Thermal Rating: on line 11595-2863 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 895
% INFO    : Updated Thermal Rating: on line 11595-2050 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 798
% INFO    : Updated Thermal Rating: on line 11595-2050 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 777
% INFO    : Updated Thermal Rating: on line 11595-169 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 949
% INFO    : Updated Thermal Rating: on line 8137-6311 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 131160
% INFO    : Updated Thermal Rating: on line 8137-2523 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 150246
% INFO    : Updated Thermal Rating: on line 8137-5445 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 863
% INFO    : Updated Thermal Rating: on line 8137-6297 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2658
% INFO    : Updated Thermal Rating: on line 8137-5315 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2358
% INFO    : Updated Thermal Rating: on line 8137-13480 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1600
% INFO    : Updated Thermal Rating: on line 8137-9592 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 546
% INFO    : Updated Thermal Rating: on line 8137-5299 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 909
% INFO    : Updated Thermal Rating: on line 1420-6073 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26320
% INFO    : Updated Thermal Rating: on line 1420-2820 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 33184
% INFO    : Updated Thermal Rating: on line 1420-4636 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 48317
% INFO    : Updated Thermal Rating: on line 1420-5253 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 37387
% INFO    : Updated Thermal Rating: on line 1420-6416 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1504
% INFO    : Updated Thermal Rating: on line 1420-8183 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1123
% INFO    : Updated Thermal Rating: on line 1420-8183 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1496
% INFO    : Updated Thermal Rating: on line 1420-9795 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1034
% INFO    : Updated Thermal Rating: on line 1420-10497 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4781
% INFO    : Updated Thermal Rating: on line 1420-7861 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4400
% INFO    : Updated Thermal Rating: on line 10896-7779 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2105
% INFO    : Updated Thermal Rating: on line 10896-2184 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2539
% INFO    : Updated Thermal Rating: on line 1844-1829 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 854
% INFO    : Updated Thermal Rating: on line 1844-1829 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 828
% INFO    : Updated Thermal Rating: on line 1844-1829 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 879
% INFO    : Updated Thermal Rating: on line 1844-11576 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10335
% INFO    : Updated Thermal Rating: on line 1844-9412 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5140
% INFO    : Updated Thermal Rating: on line 1126-10564 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1045
% INFO    : Updated Thermal Rating: on line 1126-5757 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4334
% INFO    : Updated Thermal Rating: on line 1126-5709 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8414
% INFO    : Updated Thermal Rating: on line 1126-4437 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 987
% INFO    : Updated Thermal Rating: on line 7726-9143 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 45626
% INFO    : Updated Thermal Rating: on line 5396-5662 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 41622
% INFO    : Updated Thermal Rating: on line 5396-5662 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 45778
% INFO    : Updated Thermal Rating: on line 5396-4212 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12161
% INFO    : Updated Thermal Rating: on line 5396-4212 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12717
% INFO    : Updated Thermal Rating: on line 5396-1679 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13211
% INFO    : Updated Thermal Rating: on line 5396-5121 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4832
% INFO    : Updated Thermal Rating: on line 5396-12913 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5211
% INFO    : Updated Thermal Rating: on line 9470-7807 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17339
% INFO    : Updated Thermal Rating: on line 9470-5824 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13063
% INFO    : Updated Thermal Rating: on line 1707-1905 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4076
% INFO    : Updated Thermal Rating: on line 1707-36 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1978
% INFO    : Updated Thermal Rating: on line 10943-5367 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 971
% INFO    : Updated Thermal Rating: on line 10943-140 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1804
% INFO    : Updated Thermal Rating: on line 10943-2663 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2508
% INFO    : Updated Thermal Rating: on line 518-4608 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6510
% INFO    : Updated Thermal Rating: on line 518-9611 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6187
% INFO    : Updated Thermal Rating: on line 4608-6928 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2626
% INFO    : Updated Thermal Rating: on line 3803-11583 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 982
% INFO    : Updated Thermal Rating: on line 3803-3018 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1303
% INFO    : Updated Thermal Rating: on line 6084-13033 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2846
% INFO    : Updated Thermal Rating: on line 6084-2316 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5227
% INFO    : Updated Thermal Rating: on line 6084-2316 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5276
% INFO    : Updated Thermal Rating: on line 6084-5559 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2479
% INFO    : Updated Thermal Rating: on line 6084-5559 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2204
% INFO    : Updated Thermal Rating: on line 5375-6031 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 44249
% INFO    : Updated Thermal Rating: on line 9685-7792 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 58406
% INFO    : Updated Thermal Rating: on line 9685-10491 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 57347
% INFO    : Updated Thermal Rating: on line 9685-5404 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 54332
% INFO    : Updated Thermal Rating: on line 9685-7983 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 58336
% INFO    : Updated Thermal Rating: on line 9685-6212 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1434
% INFO    : Updated Thermal Rating: on line 9685-6212 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1526
% INFO    : Updated Thermal Rating: on line 9685-6599 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1794
% INFO    : Updated Thermal Rating: on line 9685-634 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3336
% INFO    : Updated Thermal Rating: on line 9685-634 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2840
% INFO    : Updated Thermal Rating: on line 9685-634 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2788
% INFO    : Updated Thermal Rating: on line 2212-10056 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5371
% INFO    : Updated Thermal Rating: on line 3556-4999 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5307
% INFO    : Updated Thermal Rating: on line 3556-4999 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4690
% INFO    : Updated Thermal Rating: on line 7192-4790 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4888
% INFO    : Updated Thermal Rating: on line 7192-4790 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4337
% INFO    : Updated Thermal Rating: on line 7192-6906 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1375
% INFO    : Updated Thermal Rating: on line 7192-1835 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1250
% INFO    : Updated Thermal Rating: on line 7192-5757 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1447
% INFO    : Updated Thermal Rating: on line 7192-4299 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 354
% INFO    : Updated Thermal Rating: on line 7192-8517 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12252
% INFO    : Updated Thermal Rating: on line 7192-11609 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1910
% INFO    : Updated Thermal Rating: on line 7192-4437 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18399
% INFO    : Updated Thermal Rating: on line 3788-281 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 475
% INFO    : Updated Thermal Rating: on line 710-10802 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1469
% INFO    : Updated Thermal Rating: on line 710-12871 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 411
% INFO    : Updated Thermal Rating: on line 710-9296 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 581
% INFO    : Updated Thermal Rating: on line 11583-4519 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 788
% INFO    : Updated Thermal Rating: on line 11583-3527 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4738
% INFO    : Updated Thermal Rating: on line 11583-8095 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1241
% INFO    : Updated Thermal Rating: on line 9391-4435 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1534
% INFO    : Updated Thermal Rating: on line 9391-5691 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9976
% INFO    : Updated Thermal Rating: on line 9391-13022 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2409
% INFO    : Updated Thermal Rating: on line 9391-13022 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2366
% INFO    : Updated Thermal Rating: on line 1185-6675 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5610
% INFO    : Updated Thermal Rating: on line 1185-6061 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1737
% INFO    : Updated Thermal Rating: on line 1185-4880 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1098
% INFO    : Updated Thermal Rating: on line 8038-3401 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 432
% INFO    : Updated Thermal Rating: on line 8038-1984 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1220
% INFO    : Updated Thermal Rating: on line 8038-4090 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 626
% INFO    : Updated Thermal Rating: on line 8038-2729 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 620
% INFO    : Updated Thermal Rating: on line 8038-12978 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 599
% INFO    : Updated Thermal Rating: on line 12552-10790 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25264
% INFO    : Updated Thermal Rating: on line 12552-9030 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 29393
% INFO    : Updated Thermal Rating: on line 4966-1385 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24306
% INFO    : Updated Thermal Rating: on line 2975-6741 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2637
% INFO    : Updated Thermal Rating: on line 2975-6661 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2663
% INFO    : Updated Thermal Rating: on line 2975-7515 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7392
% INFO    : Updated Thermal Rating: on line 7389-3010 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2695
% INFO    : Updated Thermal Rating: on line 7389-6661 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3010
% INFO    : Updated Thermal Rating: on line 7389-5150 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7549
% INFO    : Updated Thermal Rating: on line 3790-2115 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 44610
% INFO    : Updated Thermal Rating: on line 11917-8496 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6392
% INFO    : Updated Thermal Rating: on line 11917-6101 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6111
% INFO    : Updated Thermal Rating: on line 11917-4521 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8784
% INFO    : Updated Thermal Rating: on line 11917-4521 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8261
% INFO    : Updated Thermal Rating: on line 11917-4352 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25671
% INFO    : Updated Thermal Rating: on line 11917-10961 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25386
% INFO    : Updated Thermal Rating: on line 11917-8724 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3668
% INFO    : Updated Thermal Rating: on line 11917-13022 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1588
% INFO    : Updated Thermal Rating: on line 2441-9437 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26216
% INFO    : Updated Thermal Rating: on line 2903-2016 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 48510
% INFO    : Updated Thermal Rating: on line 3086-2581 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7088
% INFO    : Updated Thermal Rating: on line 9315-2581 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7213
% INFO    : Updated Thermal Rating: on line 6911-4108 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3766
% INFO    : Updated Thermal Rating: on line 7274-13490 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 900
% INFO    : Updated Thermal Rating: on line 7274-13490 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 834
% INFO    : Updated Thermal Rating: on line 7274-2937 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5202
% INFO    : Updated Thermal Rating: on line 7274-7948 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11447
% INFO    : Updated Thermal Rating: on line 7274-11927 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2341
% INFO    : Updated Thermal Rating: on line 7274-11927 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2030
% INFO    : Updated Thermal Rating: on line 11696-1027 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1119
% INFO    : Updated Thermal Rating: on line 11696-1162 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3937
% INFO    : Updated Thermal Rating: on line 11696-2660 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1090
% INFO    : Updated Thermal Rating: on line 11696-7985 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 542
% INFO    : Updated Thermal Rating: on line 6265-3540 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1540
% INFO    : Updated Thermal Rating: on line 3320-9003 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6241
% INFO    : Updated Thermal Rating: on line 13572-281 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2352
% INFO    : Updated Thermal Rating: on line 13572-4528 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1159
% INFO    : Updated Thermal Rating: on line 6860-6666 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3334
% INFO    : Updated Thermal Rating: on line 13308-9842 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20291
% INFO    : Updated Thermal Rating: on line 12435-5520 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 728
% INFO    : Updated Thermal Rating: on line 12435-5520 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 748
% INFO    : Updated Thermal Rating: on line 12561-4228 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1572
% INFO    : Updated Thermal Rating: on line 12561-235 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 992
% INFO    : Updated Thermal Rating: on line 1082-12547 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26055
% INFO    : Updated Thermal Rating: on line 10090-7203 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14377
% INFO    : Updated Thermal Rating: on line 655-6955 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7334
% INFO    : Updated Thermal Rating: on line 2065-8040 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3289
% INFO    : Updated Thermal Rating: on line 2065-3942 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1971
% INFO    : Updated Thermal Rating: on line 5291-6928 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9924
% INFO    : Updated Thermal Rating: on line 1768-2936 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 76837
% INFO    : Updated Thermal Rating: on line 1574-2936 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 73380
% INFO    : Updated Thermal Rating: on line 12142-2936 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 80755
% INFO    : Updated Thermal Rating: on line 12250-2936 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 82867
% INFO    : Updated Thermal Rating: on line 2008-5132 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7473
% INFO    : Updated Thermal Rating: on line 6674-5132 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8069
% INFO    : Updated Thermal Rating: on line 4438-934 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7210
% INFO    : Updated Thermal Rating: on line 4438-934 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7718
% INFO    : Updated Thermal Rating: on line 7324-6661 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1146
% INFO    : Updated Thermal Rating: on line 7324-4416 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1873
% INFO    : Updated Thermal Rating: on line 1100-1361 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3905
% INFO    : Updated Thermal Rating: on line 1100-1361 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3830
% INFO    : Updated Thermal Rating: on line 1100-7219 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2741
% INFO    : Updated Thermal Rating: on line 1100-7219 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2425
% INFO    : Updated Thermal Rating: on line 1100-5846 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1984
% INFO    : Updated Thermal Rating: on line 1100-4194 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1133
% INFO    : Updated Thermal Rating: on line 5520-267 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1091
% INFO    : Updated Thermal Rating: on line 5520-3199 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 919
% INFO    : Updated Thermal Rating: on line 9969-6047 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 517
% INFO    : Updated Thermal Rating: on line 8345-10214 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 508
% INFO    : Updated Thermal Rating: on line 12745-10970 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 954
% INFO    : Updated Thermal Rating: on line 12745-3540 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 938
% INFO    : Updated Thermal Rating: on line 5600-7985 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 846
% INFO    : Updated Thermal Rating: on line 5600-11395 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 547
% INFO    : Updated Thermal Rating: on line 7320-9331 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13719
% INFO    : Updated Thermal Rating: on line 7576-6011 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2878
% INFO    : Updated Thermal Rating: on line 7576-6011 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2504
% INFO    : Updated Thermal Rating: on line 7576-11295 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2198
% INFO    : Updated Thermal Rating: on line 7576-10636 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19023
% INFO    : Updated Thermal Rating: on line 7576-3550 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18424
% INFO    : Updated Thermal Rating: on line 7779-11074 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 616
% INFO    : Updated Thermal Rating: on line 8208-6738 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20686
% INFO    : Updated Thermal Rating: on line 2271-8175 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5012
% INFO    : Updated Thermal Rating: on line 4610-4974 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1997
% INFO    : Updated Thermal Rating: on line 8802-8629 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4243
% INFO    : Updated Thermal Rating: on line 5445-12511 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3034
% INFO    : Updated Thermal Rating: on line 5445-11017 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3094
% INFO    : Updated Thermal Rating: on line 5445-13480 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2198
% INFO    : Updated Thermal Rating: on line 5445-2218 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1555
% INFO    : Updated Thermal Rating: on line 1829-6290 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 527
% INFO    : Updated Thermal Rating: on line 9843-3627 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2537
% INFO    : Updated Thermal Rating: on line 9843-3627 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2252
% INFO    : Updated Thermal Rating: on line 9843-3383 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3731
% INFO    : Updated Thermal Rating: on line 9843-3383 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3662
% INFO    : Updated Thermal Rating: on line 9843-6297 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2974
% INFO    : Updated Thermal Rating: on line 9843-5315 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2807
% INFO    : Updated Thermal Rating: on line 9843-10081 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1218
% INFO    : Updated Thermal Rating: on line 13380-7458 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3996
% INFO    : Updated Thermal Rating: on line 13380-7458 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3866
% INFO    : Updated Thermal Rating: on line 705-10497 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 456
% INFO    : Updated Thermal Rating: on line 13490-2424 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 95544
% INFO    : Updated Thermal Rating: on line 13490-13136 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 108858
% INFO    : Updated Thermal Rating: on line 13490-12835 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3531
% INFO    : Updated Thermal Rating: on line 13490-13130 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2062
% INFO    : Updated Thermal Rating: on line 8642-11395 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 868
% INFO    : Updated Thermal Rating: on line 4529-2946 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 930
% INFO    : Updated Thermal Rating: on line 4529-1507 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 895
% INFO    : Updated Thermal Rating: on line 426-7134 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21921
% INFO    : Updated Thermal Rating: on line 426-1548 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20446
% INFO    : Updated Thermal Rating: on line 426-6955 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6998
% INFO    : Updated Thermal Rating: on line 2863-7605 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 768
% INFO    : Updated Thermal Rating: on line 2863-169 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3736
% INFO    : Updated Thermal Rating: on line 2863-169 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3241
% INFO    : Updated Thermal Rating: on line 3194-8360 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5101
% INFO    : Updated Thermal Rating: on line 11029-9593 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2477
% INFO    : Updated Thermal Rating: on line 11029-1228 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3278
% INFO    : Updated Thermal Rating: on line 13162-13033 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 633
% INFO    : Updated Thermal Rating: on line 13162-6605 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3592
% INFO    : Updated Thermal Rating: on line 13162-5011 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2054
% INFO    : Updated Thermal Rating: on line 13162-5011 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2016
% INFO    : Updated Thermal Rating: on line 13162-5011 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1910
% INFO    : Updated Thermal Rating: on line 13162-9593 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1599
% INFO    : Updated Thermal Rating: on line 13162-3560 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13522
% INFO    : Updated Thermal Rating: on line 13162-9677 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11682
% INFO    : Updated Thermal Rating: on line 8182-9274 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 53974
% INFO    : Updated Thermal Rating: on line 1549-9274 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 84816
% INFO    : Updated Thermal Rating: on line 2580-6212 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9642
% INFO    : Updated Thermal Rating: on line 1153-3034 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5557
% INFO    : Updated Thermal Rating: on line 1153-3034 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5672
% INFO    : Updated Thermal Rating: on line 1153-11003 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1593
% INFO    : Updated Thermal Rating: on line 1153-9849 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1628
% INFO    : Updated Thermal Rating: on line 3262-9938 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1209
% INFO    : Updated Thermal Rating: on line 3262-1113 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1193
% INFO    : Updated Thermal Rating: on line 4714-1554 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1501
% INFO    : Updated Thermal Rating: on line 4714-8710 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1467
% INFO    : Updated Thermal Rating: on line 4714-13408 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 630
% INFO    : Updated Thermal Rating: on line 4714-1356 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2314
% INFO    : Updated Thermal Rating: on line 4714-1356 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2061
% INFO    : Updated Thermal Rating: on line 4714-7219 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1040
% INFO    : Updated Thermal Rating: on line 2203-10795 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 390
% INFO    : Updated Thermal Rating: on line 2203-10008 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 524
% INFO    : Updated Thermal Rating: on line 2203-12559 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 297
% INFO    : Updated Thermal Rating: on line 2203-4581 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 747
% INFO    : Updated Thermal Rating: on line 2203-3832 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 454
% INFO    : Updated Thermal Rating: on line 2203-6290 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 411
% INFO    : Updated Thermal Rating: on line 2203-6646 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 937
% INFO    : Updated Thermal Rating: on line 2203-6217 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 361
% INFO    : Updated Thermal Rating: on line 12750-55 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1458
% INFO    : Updated Thermal Rating: on line 12750-4110 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3902
% INFO    : Updated Thermal Rating: on line 12750-4110 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3982
% INFO    : Updated Thermal Rating: on line 12750-301 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10610
% INFO    : Updated Thermal Rating: on line 12750-6189 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9305
% INFO    : Updated Thermal Rating: on line 3406-2740 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1894
% INFO    : Updated Thermal Rating: on line 3406-8030 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1497
% INFO    : Updated Thermal Rating: on line 11190-333 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25736
% INFO    : Updated Thermal Rating: on line 2111-1980 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 64786
% INFO    : Updated Thermal Rating: on line 10260-10411 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1054
% INFO    : Updated Thermal Rating: on line 10260-4848 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2757
% INFO    : Updated Thermal Rating: on line 1765-235 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2413
% INFO    : Updated Thermal Rating: on line 8957-3522 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 78436
% INFO    : Updated Thermal Rating: on line 13033-5559 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1991
% INFO    : Updated Thermal Rating: on line 8586-8106 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2510
% INFO    : Updated Thermal Rating: on line 8586-11222 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1341
% INFO    : Updated Thermal Rating: on line 8586-2392 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5190
% INFO    : Updated Thermal Rating: on line 5875-2184 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 35710
% INFO    : Updated Thermal Rating: on line 262-2184 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 38599
% INFO    : Updated Thermal Rating: on line 4279-5028 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 879
% INFO    : Updated Thermal Rating: on line 12839-1314 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 904
% INFO    : Updated Thermal Rating: on line 12839-1314 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4562
% INFO    : Updated Thermal Rating: on line 12839-4994 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 979
% INFO    : Updated Thermal Rating: on line 4790-4916 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2411
% INFO    : Updated Thermal Rating: on line 7709-26 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 31376
% INFO    : Updated Thermal Rating: on line 7709-26 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21862
% INFO    : Updated Thermal Rating: on line 7709-2217 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1996
% INFO    : Updated Thermal Rating: on line 7709-9004 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10244
% INFO    : Updated Thermal Rating: on line 7709-7132 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3768
% INFO    : Updated Thermal Rating: on line 7709-7942 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3966
% INFO    : Updated Thermal Rating: on line 8106-8251 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2016
% INFO    : Updated Thermal Rating: on line 5032-7942 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24252
% INFO    : Updated Thermal Rating: on line 5817-7132 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24653
% INFO    : Updated Thermal Rating: on line 603-5664 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 817
% INFO    : Updated Thermal Rating: on line 9181-5011 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3696
% INFO    : Updated Thermal Rating: on line 2946-592 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 978
% INFO    : Updated Thermal Rating: on line 4273-13274 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20925
% INFO    : Updated Thermal Rating: on line 4273-13274 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20403
% INFO    : Updated Thermal Rating: on line 13274-3559 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1846
% INFO    : Updated Thermal Rating: on line 13274-11931 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2458
% INFO    : Updated Thermal Rating: on line 2919-11004 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6825
% INFO    : Updated Thermal Rating: on line 2919-11004 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6697
% INFO    : Updated Thermal Rating: on line 6011-6400 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2230
% INFO    : Updated Thermal Rating: on line 6011-3310 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3526
% INFO    : Updated Thermal Rating: on line 6011-4121 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1136
% INFO    : Updated Thermal Rating: on line 3734-10877 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3993
% INFO    : Updated Thermal Rating: on line 10526-13215 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6600
% INFO    : Updated Thermal Rating: on line 7834-13215 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6478
% INFO    : Updated Thermal Rating: on line 11955-13215 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7250
% INFO    : Updated Thermal Rating: on line 9269-13215 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7402
% INFO    : Updated Thermal Rating: on line 1748-13215 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6586
% INFO    : Updated Thermal Rating: on line 6063-13565 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 40572
% INFO    : Updated Thermal Rating: on line 6063-11726 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23949
% INFO    : Updated Thermal Rating: on line 3484-1162 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 419
% INFO    : Updated Thermal Rating: on line 3484-2660 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 528
% INFO    : Updated Thermal Rating: on line 3484-13034 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7955
% INFO    : Updated Thermal Rating: on line 3484-7517 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 400
% INFO    : Updated Thermal Rating: on line 3484-10138 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 582
% INFO    : Updated Thermal Rating: on line 3484-2483 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7075
% INFO    : Updated Thermal Rating: on line 7605-12749 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 703
% INFO    : Updated Thermal Rating: on line 7605-247 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 467
% INFO    : Updated Thermal Rating: on line 7605-10895 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 758
% INFO    : Updated Thermal Rating: on line 10768-8652 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1219
% INFO    : Updated Thermal Rating: on line 10768-13214 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 900
% INFO    : Updated Thermal Rating: on line 13031-1162 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1450
% INFO    : Updated Thermal Rating: on line 13031-1162 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1420
% INFO    : Updated Thermal Rating: on line 13031-8821 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1834
% INFO    : Updated Thermal Rating: on line 8374-6148 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1559
% INFO    : Updated Thermal Rating: on line 12547-2813 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 33783
% INFO    : Updated Thermal Rating: on line 1976-2813 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 33061
% INFO    : Updated Thermal Rating: on line 11866-3009 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 96873
% INFO    : Updated Thermal Rating: on line 7237-12150 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 719
% INFO    : Updated Thermal Rating: on line 7237-6956 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5098
% INFO    : Updated Thermal Rating: on line 3028-5280 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1482
% INFO    : Updated Thermal Rating: on line 3028-6859 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 749
% INFO    : Updated Thermal Rating: on line 6834-12739 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1552
% INFO    : Updated Thermal Rating: on line 6834-12739 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1584
% INFO    : Updated Thermal Rating: on line 10431-7917 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13000
% INFO    : Updated Thermal Rating: on line 10431-7917 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12810
% INFO    : Updated Thermal Rating: on line 12146-8318 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1587
% INFO    : Updated Thermal Rating: on line 12146-8318 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1558
% INFO    : Updated Thermal Rating: on line 9437-4916 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11064
% INFO    : Updated Thermal Rating: on line 9437-8273 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2437
% INFO    : Updated Thermal Rating: on line 3401-7229 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 336
% INFO    : Updated Thermal Rating: on line 1271-13444 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 78402
% INFO    : Updated Thermal Rating: on line 5960-13444 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 71132
% INFO    : Updated Thermal Rating: on line 9987-3034 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 62725
% INFO    : Updated Thermal Rating: on line 8251-3785 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4421
% INFO    : Updated Thermal Rating: on line 8251-11074 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9851
% INFO    : Updated Thermal Rating: on line 8251-11074 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9225
% INFO    : Updated Thermal Rating: on line 8251-11074 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6466
% INFO    : Updated Thermal Rating: on line 8251-2320 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2052
% INFO    : Updated Thermal Rating: on line 1053-1000 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7239
% INFO    : Updated Thermal Rating: on line 5174-1000 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8564
% INFO    : Updated Thermal Rating: on line 9331-3473 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4444
% INFO    : Updated Thermal Rating: on line 9331-3473 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4533
% INFO    : Updated Thermal Rating: on line 9331-8605 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1442
% INFO    : Updated Thermal Rating: on line 9331-8605 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1617
% INFO    : Updated Thermal Rating: on line 9331-8605 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1606
% INFO    : Updated Thermal Rating: on line 11532-13448 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1471
% INFO    : Updated Thermal Rating: on line 9730-2050 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1597
% INFO    : Updated Thermal Rating: on line 7462-8273 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3769
% INFO    : Updated Thermal Rating: on line 4275-8605 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3813
% INFO    : Updated Thermal Rating: on line 7917-5567 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2042
% INFO    : Updated Thermal Rating: on line 7917-11930 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1956
% INFO    : Updated Thermal Rating: on line 7917-3638 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11184
% INFO    : Updated Thermal Rating: on line 7917-8175 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2530
% INFO    : Updated Thermal Rating: on line 7917-8175 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2683
% INFO    : Updated Thermal Rating: on line 7917-8175 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2899
% INFO    : Updated Thermal Rating: on line 7917-5493 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5922
% INFO    : Updated Thermal Rating: on line 7917-8043 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5818
% INFO    : Updated Thermal Rating: on line 7917-8360 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2664
% INFO    : Updated Thermal Rating: on line 13334-3547 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52008
% INFO    : Updated Thermal Rating: on line 1902-1583 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1090
% INFO    : Updated Thermal Rating: on line 3998-12207 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 857
% INFO    : Updated Thermal Rating: on line 3998-12329 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1628
% INFO    : Updated Thermal Rating: on line 3998-1582 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7022
% INFO    : Updated Thermal Rating: on line 3998-10056 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2694
% INFO    : Updated Thermal Rating: on line 7232-10048 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9486
% INFO    : Updated Thermal Rating: on line 11342-10204 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 473
% INFO    : Updated Thermal Rating: on line 10626-4511 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 637
% INFO    : Updated Thermal Rating: on line 3042-422 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3515
% INFO    : Updated Thermal Rating: on line 3042-3602 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 415
% INFO    : Updated Thermal Rating: on line 2316-1109 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20318
% INFO    : Updated Thermal Rating: on line 2821-9097 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 54993
% INFO    : Updated Thermal Rating: on line 5810-1980 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2258
% INFO    : Updated Thermal Rating: on line 1361-13477 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1863
% INFO    : Updated Thermal Rating: on line 1361-13477 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2152
% INFO    : Updated Thermal Rating: on line 1361-2936 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3837
% INFO    : Updated Thermal Rating: on line 1361-2936 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3917
% INFO    : Updated Thermal Rating: on line 8243-7888 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2472
% INFO    : Updated Thermal Rating: on line 8243-13408 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 638
% INFO    : Updated Thermal Rating: on line 8243-10294 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1473
% INFO    : Updated Thermal Rating: on line 8243-10294 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1445
% INFO    : Updated Thermal Rating: on line 8243-13130 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1524
% INFO    : Updated Thermal Rating: on line 12724-11399 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2976
% INFO    : Updated Thermal Rating: on line 12724-11077 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1424
% INFO    : Updated Thermal Rating: on line 12724-11077 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1526
% INFO    : Updated Thermal Rating: on line 12724-6148 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 629
% INFO    : Updated Thermal Rating: on line 13477-6157 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2639
% INFO    : Updated Thermal Rating: on line 2184-5760 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 621
% INFO    : Updated Thermal Rating: on line 2184-6955 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2505
% INFO    : Updated Thermal Rating: on line 2184-6955 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2051
% INFO    : Updated Thermal Rating: on line 6661-4880 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 959
% INFO    : Updated Thermal Rating: on line 6661-4880 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 789
% INFO    : Updated Thermal Rating: on line 1905-4880 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 847
% INFO    : Updated Thermal Rating: on line 5367-3889 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 44610
% INFO    : Updated Thermal Rating: on line 5367-3889 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 31417
% INFO    : Updated Thermal Rating: on line 5367-3889 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 36971
% INFO    : Updated Thermal Rating: on line 5367-4682 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 41087
% INFO    : Updated Thermal Rating: on line 5367-7157 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1761
% INFO    : Updated Thermal Rating: on line 5367-2663 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1518
% INFO    : Updated Thermal Rating: on line 10021-8087 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 47512
% INFO    : Updated Thermal Rating: on line 10021-10282 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 40125
% INFO    : Updated Thermal Rating: on line 10021-8652 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1570
% INFO    : Updated Thermal Rating: on line 10021-13214 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 969
% INFO    : Updated Thermal Rating: on line 1944-9916 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2683
% INFO    : Updated Thermal Rating: on line 1944-10301 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1660
% INFO    : Updated Thermal Rating: on line 3602-8987 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11156
% INFO    : Updated Thermal Rating: on line 130-4954 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1282
% INFO    : Updated Thermal Rating: on line 130-4954 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1500
% INFO    : Updated Thermal Rating: on line 3034-4780 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20489
% INFO    : Updated Thermal Rating: on line 3034-3951 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2774
% INFO    : Updated Thermal Rating: on line 3034-9992 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1734
% INFO    : Updated Thermal Rating: on line 3034-9849 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1023
% INFO    : Updated Thermal Rating: on line 3034-11176 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24993
% INFO    : Updated Thermal Rating: on line 13444-1494 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1752
% INFO    : Updated Thermal Rating: on line 3522-9030 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 79847
% INFO    : Updated Thermal Rating: on line 2016-13025 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5876
% INFO    : Updated Thermal Rating: on line 2016-11395 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 397
% INFO    : Updated Thermal Rating: on line 11574-7811 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 778
% INFO    : Updated Thermal Rating: on line 11574-10204 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 468
% INFO    : Updated Thermal Rating: on line 11405-4851 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7240
% INFO    : Updated Thermal Rating: on line 2797-896 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4685
% INFO    : Updated Thermal Rating: on line 9447-1783 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14149
% INFO    : Updated Thermal Rating: on line 1152-10204 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 509
% INFO    : Updated Thermal Rating: on line 1152-8620 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 508
% INFO    : Updated Thermal Rating: on line 11161-4436 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1926
% INFO    : Updated Thermal Rating: on line 735-4889 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5703
% INFO    : Updated Thermal Rating: on line 735-7638 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 826
% INFO    : Updated Thermal Rating: on line 735-1116 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1815
% INFO    : Updated Thermal Rating: on line 735-11080 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2298
% INFO    : Updated Thermal Rating: on line 3946-4974 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2097
% INFO    : Updated Thermal Rating: on line 3946-3180 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1399
% INFO    : Updated Thermal Rating: on line 3946-10301 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3071
% INFO    : Updated Thermal Rating: on line 6052-1607 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 772
% INFO    : Updated Thermal Rating: on line 6052-5677 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5072
% INFO    : Updated Thermal Rating: on line 2507-12511 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1631
% INFO    : Updated Thermal Rating: on line 2507-11017 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1601
% INFO    : Updated Thermal Rating: on line 2507-11402 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2200
% INFO    : Updated Thermal Rating: on line 2507-10071 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2158
% INFO    : Updated Thermal Rating: on line 2507-1356 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1567
% INFO    : Updated Thermal Rating: on line 2507-1356 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1537
% INFO    : Updated Thermal Rating: on line 5664-6586 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 748
% INFO    : Updated Thermal Rating: on line 5664-8754 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6340
% INFO    : Updated Thermal Rating: on line 5664-10138 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1286
% INFO    : Updated Thermal Rating: on line 1215-2348 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20980
% INFO    : Updated Thermal Rating: on line 4360-1158 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21405
% INFO    : Updated Thermal Rating: on line 7051-2348 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18328
% INFO    : Updated Thermal Rating: on line 2892-1158 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18979
% INFO    : Updated Thermal Rating: on line 5683-2348 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18755
% INFO    : Updated Thermal Rating: on line 5500-1158 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18321
% INFO    : Updated Thermal Rating: on line 1075-1000 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5499
% INFO    : Updated Thermal Rating: on line 4178-8175 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6113
% INFO    : Updated Thermal Rating: on line 8277-9096 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4761
% INFO    : Updated Thermal Rating: on line 7571-7938 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10736
% INFO    : Updated Thermal Rating: on line 1027-10399 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 838
% INFO    : Updated Thermal Rating: on line 5596-1346 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4656
% INFO    : Updated Thermal Rating: on line 9341-3493 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4692
% INFO    : Updated Thermal Rating: on line 281-4299 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2259
% INFO    : Updated Thermal Rating: on line 3616-5150 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1177
% INFO    : Updated Thermal Rating: on line 3616-4880 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1641
% INFO    : Updated Thermal Rating: on line 6666-881 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 708
% INFO    : Updated Thermal Rating: on line 6666-4716 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 666
% INFO    : Updated Thermal Rating: on line 6666-10759 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3724
% INFO    : Updated Thermal Rating: on line 4435-9386 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16227
% INFO    : Updated Thermal Rating: on line 4435-9386 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16547
% INFO    : Updated Thermal Rating: on line 8929-6929 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2043
% INFO    : Updated Thermal Rating: on line 4878-9674 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1921
% INFO    : Updated Thermal Rating: on line 6416-8183 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2898
% INFO    : Updated Thermal Rating: on line 6416-9787 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3753
% INFO    : Updated Thermal Rating: on line 6416-9787 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3514
% INFO    : Updated Thermal Rating: on line 1875-7861 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2196
% INFO    : Updated Thermal Rating: on line 881-897 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1690
% INFO    : Updated Thermal Rating: on line 5118-2217 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1707
% INFO    : Updated Thermal Rating: on line 2743-3181 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8460
% INFO    : Updated Thermal Rating: on line 11858-8605 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6577
% INFO    : Updated Thermal Rating: on line 5840-8605 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6466
% INFO    : Updated Thermal Rating: on line 12862-897 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2023
% INFO    : Updated Thermal Rating: on line 12862-10759 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2076
% INFO    : Updated Thermal Rating: on line 8496-7431 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7834
% INFO    : Updated Thermal Rating: on line 8496-11073 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11334
% INFO    : Updated Thermal Rating: on line 8496-4621 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10177
% INFO    : Updated Thermal Rating: on line 8496-5105 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2635
% INFO    : Updated Thermal Rating: on line 8496-2251 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2919
% INFO    : Updated Thermal Rating: on line 6101-7730 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8927
% INFO    : Updated Thermal Rating: on line 7478-13565 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 41796
% INFO    : Updated Thermal Rating: on line 2957-5601 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 39156
% INFO    : Updated Thermal Rating: on line 2957-9097 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 57521
% INFO    : Updated Thermal Rating: on line 2957-2349 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23719
% INFO    : Updated Thermal Rating: on line 2957-9125 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 106228
% INFO    : Updated Thermal Rating: on line 2957-11146 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14289
% INFO    : Updated Thermal Rating: on line 2957-3981 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19583
% INFO    : Updated Thermal Rating: on line 7414-661 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11368
% INFO    : Updated Thermal Rating: on line 7414-661 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11607
% INFO    : Updated Thermal Rating: on line 11183-4370 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15052
% INFO    : Updated Thermal Rating: on line 11183-4370 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13595
% INFO    : Updated Thermal Rating: on line 4621-3349 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9173
% INFO    : Updated Thermal Rating: on line 4621-12893 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9061
% INFO    : Updated Thermal Rating: on line 3583-12913 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14120
% INFO    : Updated Thermal Rating: on line 3789-5121 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13488
% INFO    : Updated Thermal Rating: on line 6064-12568 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 115370
% INFO    : Updated Thermal Rating: on line 885-227 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3119
% INFO    : Updated Thermal Rating: on line 885-8070 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2164
% INFO    : Updated Thermal Rating: on line 5567-13336 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3176
% INFO    : Updated Thermal Rating: on line 5567-13336 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2817
% INFO    : Updated Thermal Rating: on line 5567-4620 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22385
% INFO    : Updated Thermal Rating: on line 5567-1000 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1811
% INFO    : Updated Thermal Rating: on line 5567-8426 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26969
% INFO    : Updated Thermal Rating: on line 5567-6929 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2300
% INFO    : Updated Thermal Rating: on line 3785-2392 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2295
% INFO    : Updated Thermal Rating: on line 13405-13372 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6238
% INFO    : Updated Thermal Rating: on line 10182-8105 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5164
% INFO    : Updated Thermal Rating: on line 970-2124 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1183
% INFO    : Updated Thermal Rating: on line 970-3917 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 847
% INFO    : Updated Thermal Rating: on line 970-6675 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 863
% INFO    : Updated Thermal Rating: on line 970-2294 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12537
% INFO    : Updated Thermal Rating: on line 970-2961 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4833
% INFO    : Updated Thermal Rating: on line 5234-3083 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 738
% INFO    : Updated Thermal Rating: on line 5234-4077 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5880
% INFO    : Updated Thermal Rating: on line 5312-11722 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2237
% INFO    : Updated Thermal Rating: on line 5312-3559 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3697
% INFO    : Updated Thermal Rating: on line 7888-13130 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3760
% INFO    : Updated Thermal Rating: on line 10411-5004 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1758
% INFO    : Updated Thermal Rating: on line 10411-1607 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 523
% INFO    : Updated Thermal Rating: on line 10877-11003 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3892
% INFO    : Updated Thermal Rating: on line 10877-9849 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2101
% INFO    : Updated Thermal Rating: on line 1464-4954 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 487
% INFO    : Updated Thermal Rating: on line 6980-4851 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5873
% INFO    : Updated Thermal Rating: on line 12476-6599 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5568
% INFO    : Updated Thermal Rating: on line 12299-10746 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1610
% INFO    : Updated Thermal Rating: on line 12299-10746 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1635
% INFO    : Updated Thermal Rating: on line 12299-4108 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1328
% INFO    : Updated Thermal Rating: on line 5922-10761 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2086
% INFO    : Updated Thermal Rating: on line 5922-8338 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2243
% INFO    : Updated Thermal Rating: on line 10737-3559 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2614
% INFO    : Updated Thermal Rating: on line 10737-11276 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8692
% INFO    : Updated Thermal Rating: on line 10944-2259 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 31852
% INFO    : Updated Thermal Rating: on line 13234-4953 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 57640
% INFO    : Updated Thermal Rating: on line 2581-9334 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1167
% INFO    : Updated Thermal Rating: on line 6778-8788 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15773
% INFO    : Updated Thermal Rating: on line 2454-5222 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 43532
% INFO    : Updated Thermal Rating: on line 11278-5677 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 46697
% INFO    : Updated Thermal Rating: on line 13573-4916 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 29820
% INFO    : Updated Thermal Rating: on line 12343-12945 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1506
% INFO    : Updated Thermal Rating: on line 12343-12495 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9896
% INFO    : Updated Thermal Rating: on line 12343-12495 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9471
% INFO    : Updated Thermal Rating: on line 8203-9710 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1792
% INFO    : Updated Thermal Rating: on line 8203-1694 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1649
% INFO    : Updated Thermal Rating: on line 8203-9799 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 853
% INFO    : Updated Thermal Rating: on line 8203-13294 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 968
% INFO    : Updated Thermal Rating: on line 8203-10645 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1374
% INFO    : Updated Thermal Rating: on line 5112-9274 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 534
% INFO    : Updated Thermal Rating: on line 5112-1445 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 834
% INFO    : Updated Thermal Rating: on line 5112-5545 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17314
% INFO    : Updated Thermal Rating: on line 4684-9611 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4294
% INFO    : Updated Thermal Rating: on line 12744-1086 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 597
% INFO    : Updated Thermal Rating: on line 227-3090 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1381
% INFO    : Updated Thermal Rating: on line 11066-5760 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2168
% INFO    : Updated Thermal Rating: on line 11066-10062 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3673
% INFO    : Updated Thermal Rating: on line 3627-9059 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2197
% INFO    : Updated Thermal Rating: on line 3627-9059 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2244
% INFO    : Updated Thermal Rating: on line 7129-5386 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 581
% INFO    : Updated Thermal Rating: on line 3383-9059 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1150
% INFO    : Updated Thermal Rating: on line 3383-9059 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1174
% INFO    : Updated Thermal Rating: on line 3383-6081 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1534
% INFO    : Updated Thermal Rating: on line 3383-1859 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2802
% INFO    : Updated Thermal Rating: on line 5616-247 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3821
% INFO    : Updated Thermal Rating: on line 247-9412 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 564
% INFO    : Updated Thermal Rating: on line 6400-11592 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4102
% INFO    : Updated Thermal Rating: on line 6400-820 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17232
% INFO    : Updated Thermal Rating: on line 6400-13097 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 155017
% INFO    : Updated Thermal Rating: on line 6400-13097 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157839
% INFO    : Updated Thermal Rating: on line 6400-6228 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1379
% INFO    : Updated Thermal Rating: on line 5678-4954 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1340
% INFO    : Updated Thermal Rating: on line 5678-1252 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2178
% INFO    : Updated Thermal Rating: on line 10292-3083 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1979
% INFO    : Updated Thermal Rating: on line 12835-13130 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4019
% INFO    : Updated Thermal Rating: on line 4954-11395 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1694
% INFO    : Updated Thermal Rating: on line 4954-11395 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1435
% INFO    : Updated Thermal Rating: on line 9839-4212 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 111427
% INFO    : Updated Thermal Rating: on line 12014-4212 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 121741
% INFO    : Updated Thermal Rating: on line 6508-4212 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 121741
% INFO    : Updated Thermal Rating: on line 2937-8710 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1212
% INFO    : Updated Thermal Rating: on line 9847-3455 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3657
% INFO    : Updated Thermal Rating: on line 7687-10989 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1961
% INFO    : Updated Thermal Rating: on line 10299-13324 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 93122
% INFO    : Updated Thermal Rating: on line 8103-3181 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 91583
% INFO    : Updated Thermal Rating: on line 5004-11774 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4017
% INFO    : Updated Thermal Rating: on line 934-9289 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 463
% INFO    : Updated Thermal Rating: on line 934-3940 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6761
% INFO    : Updated Thermal Rating: on line 934-12691 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3197
% INFO    : Updated Thermal Rating: on line 11399-6148 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1438
% INFO    : Updated Thermal Rating: on line 2124-8404 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4206
% INFO    : Updated Thermal Rating: on line 158-9674 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3384
% INFO    : Updated Thermal Rating: on line 158-8788 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2386
% INFO    : Updated Thermal Rating: on line 2492-10989 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2854
% INFO    : Updated Thermal Rating: on line 4780-11176 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 87233
% INFO    : Updated Thermal Rating: on line 261-282 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 66610
% INFO    : Updated Thermal Rating: on line 12568-8498 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18651
% INFO    : Updated Thermal Rating: on line 12568-7793 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1239
% INFO    : Updated Thermal Rating: on line 11823-10309 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1307
% INFO    : Updated Thermal Rating: on line 11823-13067 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1283
% INFO    : Updated Thermal Rating: on line 11823-10059 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12298
% INFO    : Updated Thermal Rating: on line 11823-10059 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12936
% INFO    : Updated Thermal Rating: on line 11823-2849 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1392
% INFO    : Updated Thermal Rating: on line 11823-2849 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1503
% INFO    : Updated Thermal Rating: on line 11823-12512 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2932
% INFO    : Updated Thermal Rating: on line 12945-12495 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1200
% INFO    : Updated Thermal Rating: on line 320-9913 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1505
% INFO    : Updated Thermal Rating: on line 320-9913 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1688
% INFO    : Updated Thermal Rating: on line 320-1686 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6680
% INFO    : Updated Thermal Rating: on line 320-3702 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7921
% INFO    : Updated Thermal Rating: on line 320-9799 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 804
% INFO    : Updated Thermal Rating: on line 11722-11276 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1508
% INFO    : Updated Thermal Rating: on line 11722-11276 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1627
% INFO    : Updated Thermal Rating: on line 11722-1493 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2361
% INFO    : Updated Thermal Rating: on line 10407-11515 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3594
% INFO    : Updated Thermal Rating: on line 12397-10852 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7698
% INFO    : Updated Thermal Rating: on line 12397-7112 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4149
% INFO    : Updated Thermal Rating: on line 3995-2508 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5439
% INFO    : Updated Thermal Rating: on line 3995-2508 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4811
% INFO    : Updated Thermal Rating: on line 1850-9183 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1203
% INFO    : Updated Thermal Rating: on line 1850-10204 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1305
% INFO    : Updated Thermal Rating: on line 3917-2564 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1580
% INFO    : Updated Thermal Rating: on line 3917-4880 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 980
% INFO    : Updated Thermal Rating: on line 6675-4880 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 999
% INFO    : Updated Thermal Rating: on line 6924-8338 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1583
% INFO    : Updated Thermal Rating: on line 1563-5545 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 59909
% INFO    : Updated Thermal Rating: on line 1981-8095 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 45315
% INFO    : Updated Thermal Rating: on line 6274-6715 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1898
% INFO    : Updated Thermal Rating: on line 10303-7195 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24666
% INFO    : Updated Thermal Rating: on line 10303-5499 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 42288
% INFO    : Updated Thermal Rating: on line 3547-13332 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 31635
% INFO    : Updated Thermal Rating: on line 13302-8040 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4522
% INFO    : Updated Thermal Rating: on line 10058-10485 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 999
% INFO    : Updated Thermal Rating: on line 7866-11774 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6871
% INFO    : Updated Thermal Rating: on line 7866-11774 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6583
% INFO    : Updated Thermal Rating: on line 8572-5921 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3663
% INFO    : Updated Thermal Rating: on line 4416-12272 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1905
% INFO    : Updated Thermal Rating: on line 1314-9296 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 689
% INFO    : Updated Thermal Rating: on line 1314-9296 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 776
% INFO    : Updated Thermal Rating: on line 1314-3424 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 449
% INFO    : Updated Thermal Rating: on line 1314-5844 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 467
% INFO    : Updated Thermal Rating: on line 5763-2348 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5902
% INFO    : Updated Thermal Rating: on line 9938-1653 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 47123
% INFO    : Updated Thermal Rating: on line 9938-11114 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 50874
% INFO    : Updated Thermal Rating: on line 5914-5872 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 45791
% INFO    : Updated Thermal Rating: on line 2274-2007 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 878
% INFO    : Updated Thermal Rating: on line 4504-5395 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3905
% INFO    : Updated Thermal Rating: on line 7638-3180 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1508
% INFO    : Updated Thermal Rating: on line 7638-11931 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1893
% INFO    : Updated Thermal Rating: on line 7638-2104 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1860
% INFO    : Updated Thermal Rating: on line 4002-12559 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 46722
% INFO    : Updated Thermal Rating: on line 9372-1607 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 868
% INFO    : Updated Thermal Rating: on line 9372-5722 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 731
% INFO    : Updated Thermal Rating: on line 6512-6937 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4819
% INFO    : Updated Thermal Rating: on line 6512-3448 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1381
% INFO    : Updated Thermal Rating: on line 4974-7761 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3255
% INFO    : Updated Thermal Rating: on line 4974-7761 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3175
% INFO    : Updated Thermal Rating: on line 4974-1116 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1957
% INFO    : Updated Thermal Rating: on line 4974-1116 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1920
% INFO    : Updated Thermal Rating: on line 1554-2936 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1478
% INFO    : Updated Thermal Rating: on line 1554-2936 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1555
% INFO    : Updated Thermal Rating: on line 10795-4581 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 517
% INFO    : Updated Thermal Rating: on line 10795-627 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 638
% INFO    : Updated Thermal Rating: on line 4105-2641 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 31275
% INFO    : Updated Thermal Rating: on line 1930-2729 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3794
% INFO    : Updated Thermal Rating: on line 3083-1086 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 461
% INFO    : Updated Thermal Rating: on line 5280-4090 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1966
% INFO    : Updated Thermal Rating: on line 9592-5299 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1494
% INFO    : Updated Thermal Rating: on line 12495-2804 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 716
% INFO    : Updated Thermal Rating: on line 12495-8629 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16954
% INFO    : Updated Thermal Rating: on line 8336-8821 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1212
% INFO    : Updated Thermal Rating: on line 8336-3350 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2596
% INFO    : Updated Thermal Rating: on line 3770-10989 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7813
% INFO    : Updated Thermal Rating: on line 1633-3444 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 60973
% INFO    : Updated Thermal Rating: on line 11074-8460 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 778
% INFO    : Updated Thermal Rating: on line 11074-4700 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1518
% INFO    : Updated Thermal Rating: on line 11222-8460 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5713
% INFO    : Updated Thermal Rating: on line 2508-7048 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 802
% INFO    : Updated Thermal Rating: on line 10008-7396 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 997
% INFO    : Updated Thermal Rating: on line 12234-13028 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27156
% INFO    : Updated Thermal Rating: on line 1268-13028 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27847
% INFO    : Updated Thermal Rating: on line 6605-6394 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 34015
% INFO    : Updated Thermal Rating: on line 10463-11424 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7404
% INFO    : Updated Thermal Rating: on line 10059-2953 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 53817
% INFO    : Updated Thermal Rating: on line 10059-5913 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52926
% INFO    : Updated Thermal Rating: on line 10059-13403 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 58932
% INFO    : Updated Thermal Rating: on line 10059-965 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 60039
% INFO    : Updated Thermal Rating: on line 9669-13125 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20590
% INFO    : Updated Thermal Rating: on line 13215-9059 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5378
% INFO    : Updated Thermal Rating: on line 13215-9059 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4753
% INFO    : Updated Thermal Rating: on line 13215-9059 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4662
% INFO    : Updated Thermal Rating: on line 13215-9059 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4575
% INFO    : Updated Thermal Rating: on line 13215-12531 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9314
% INFO    : Updated Thermal Rating: on line 13215-12531 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9859
% INFO    : Updated Thermal Rating: on line 2349-12594 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 30359
% INFO    : Updated Thermal Rating: on line 282-2813 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25834
% INFO    : Updated Thermal Rating: on line 4165-8105 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 48210
% INFO    : Updated Thermal Rating: on line 2958-6475 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1092
% INFO    : Updated Thermal Rating: on line 2958-495 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1329
% INFO    : Updated Thermal Rating: on line 2958-6490 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 876
% INFO    : Updated Thermal Rating: on line 4927-203 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 76413
% INFO    : Updated Thermal Rating: on line 1465-4719 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 30849
% INFO    : Updated Thermal Rating: on line 1465-10731 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1909
% INFO    : Updated Thermal Rating: on line 1465-4194 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7375
% INFO    : Updated Thermal Rating: on line 1229-4406 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 28859
% INFO    : Updated Thermal Rating: on line 1229-9409 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1872
% INFO    : Updated Thermal Rating: on line 1229-5846 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2490
% INFO    : Updated Thermal Rating: on line 10468-13541 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1592
% INFO    : Updated Thermal Rating: on line 10468-3466 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5934
% INFO    : Updated Thermal Rating: on line 10468-3466 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6053
% INFO    : Updated Thermal Rating: on line 10468-3466 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6164
% INFO    : Updated Thermal Rating: on line 10468-13083 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2466
% INFO    : Updated Thermal Rating: on line 55-301 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1566
% INFO    : Updated Thermal Rating: on line 55-5194 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1338
% INFO    : Updated Thermal Rating: on line 9096-6906 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 524
% INFO    : Updated Thermal Rating: on line 9096-12329 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1785
% INFO    : Updated Thermal Rating: on line 9096-6738 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5477
% INFO    : Updated Thermal Rating: on line 12207-12492 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3592
% INFO    : Updated Thermal Rating: on line 12207-7938 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6500
% INFO    : Updated Thermal Rating: on line 12207-11176 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2493
% INFO    : Updated Thermal Rating: on line 9992-12492 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3825
% INFO    : Updated Thermal Rating: on line 9992-1242 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1055
% INFO    : Updated Thermal Rating: on line 9992-6738 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5255
% INFO    : Updated Thermal Rating: on line 5836-203 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3635
% INFO    : Updated Thermal Rating: on line 1571-1621 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 817
% INFO    : Updated Thermal Rating: on line 1571-4436 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3697
% INFO    : Updated Thermal Rating: on line 12559-7811 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 457
% INFO    : Updated Thermal Rating: on line 12559-7811 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 477
% INFO    : Updated Thermal Rating: on line 12559-6646 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 340
% INFO    : Updated Thermal Rating: on line 12559-4907 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 41929
% INFO    : Updated Thermal Rating: on line 1317-7838 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4856
% INFO    : Updated Thermal Rating: on line 1291-9611 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 155017
% INFO    : Updated Thermal Rating: on line 9740-6497 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13291
% INFO    : Updated Thermal Rating: on line 11015-3090 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9586
% INFO    : Updated Thermal Rating: on line 10996-8070 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9693
% INFO    : Updated Thermal Rating: on line 9611-13167 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8963
% INFO    : Updated Thermal Rating: on line 9611-13167 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9449
% INFO    : Updated Thermal Rating: on line 9611-2375 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2322
% INFO    : Updated Thermal Rating: on line 9611-13481 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4647
% INFO    : Updated Thermal Rating: on line 9611-13092 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7843
% INFO    : Updated Thermal Rating: on line 738-5265 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10995
% INFO    : Updated Thermal Rating: on line 12492-1494 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12244
% INFO    : Updated Thermal Rating: on line 12492-206 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25543
% INFO    : Updated Thermal Rating: on line 12492-6258 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23628
% INFO    : Updated Thermal Rating: on line 1154-5010 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3164
% INFO    : Updated Thermal Rating: on line 12662-13111 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12765
% INFO    : Updated Thermal Rating: on line 3301-6 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3374
% INFO    : Updated Thermal Rating: on line 3301-7077 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2406
% INFO    : Updated Thermal Rating: on line 9125-7838 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2604
% INFO    : Updated Thermal Rating: on line 9125-10989 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2881
% INFO    : Updated Thermal Rating: on line 2849-2350 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3037
% INFO    : Updated Thermal Rating: on line 2849-3448 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2684
% INFO    : Updated Thermal Rating: on line 9710-11515 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3311
% INFO    : Updated Thermal Rating: on line 9710-11515 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3250
% INFO    : Updated Thermal Rating: on line 7948-11927 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2374
% INFO    : Updated Thermal Rating: on line 9183-6148 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1258
% INFO    : Updated Thermal Rating: on line 12385-6955 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7369
% INFO    : Updated Thermal Rating: on line 12385-6715 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1168
% INFO    : Updated Thermal Rating: on line 501-11609 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11239
% INFO    : Updated Thermal Rating: on line 3541-11609 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11053
% INFO    : Updated Thermal Rating: on line 7665-11609 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13399
% INFO    : Updated Thermal Rating: on line 3105-11609 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13134
% INFO    : Updated Thermal Rating: on line 12472-13408 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16324
% INFO    : Updated Thermal Rating: on line 3832-8718 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2085
% INFO    : Updated Thermal Rating: on line 1694-8309 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2558
% INFO    : Updated Thermal Rating: on line 1694-9544 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1169
% INFO    : Updated Thermal Rating: on line 3377-5230 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5704
% INFO    : Updated Thermal Rating: on line 3377-13071 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25455
% INFO    : Updated Thermal Rating: on line 3377-12739 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1801
% INFO    : Updated Thermal Rating: on line 3377-12739 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1773
% INFO    : Updated Thermal Rating: on line 3377-12739 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1833
% INFO    : Updated Thermal Rating: on line 13045-7450 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 565
% INFO    : Updated Thermal Rating: on line 8404-6937 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2600
% INFO    : Updated Thermal Rating: on line 8404-1269 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3928
% INFO    : Updated Thermal Rating: on line 8404-12272 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4709
% INFO    : Updated Thermal Rating: on line 8404-2961 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1199
% INFO    : Updated Thermal Rating: on line 9892-13083 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10553
% INFO    : Updated Thermal Rating: on line 11582-5753 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 61936
% INFO    : Updated Thermal Rating: on line 9835-5753 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 67388
% INFO    : Updated Thermal Rating: on line 6306-5753 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 64510
% INFO    : Updated Thermal Rating: on line 7807-13541 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5841
% INFO    : Updated Thermal Rating: on line 7807-521 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 28553
% INFO    : Updated Thermal Rating: on line 7807-11933 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 28222
% INFO    : Updated Thermal Rating: on line 5662-2813 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 37967
% INFO    : Updated Thermal Rating: on line 5662-2813 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22051
% INFO    : Updated Thermal Rating: on line 5097-812 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1342
% INFO    : Updated Thermal Rating: on line 7280-12094 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1957
% INFO    : Updated Thermal Rating: on line 7280-12094 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1921
% INFO    : Updated Thermal Rating: on line 7280-3891 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2910
% INFO    : Updated Thermal Rating: on line 7280-3891 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2858
% INFO    : Updated Thermal Rating: on line 5559-7758 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1246
% INFO    : Updated Thermal Rating: on line 720-3802 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 46468
% INFO    : Updated Thermal Rating: on line 211-10746 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25372
% INFO    : Updated Thermal Rating: on line 10630-9358 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 688
% INFO    : Updated Thermal Rating: on line 10630-2483 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 456
% INFO    : Updated Thermal Rating: on line 10970-467 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 595
% INFO    : Updated Thermal Rating: on line 10159-11726 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 93784
% INFO    : Updated Thermal Rating: on line 4849-11726 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 99888
% INFO    : Updated Thermal Rating: on line 8197-2483 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16564
% INFO    : Updated Thermal Rating: on line 13541-13083 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4733
% INFO    : Updated Thermal Rating: on line 26-9012 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 55892
% INFO    : Updated Thermal Rating: on line 11446-7811 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 779
% INFO    : Updated Thermal Rating: on line 11446-10204 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 767
% INFO    : Updated Thermal Rating: on line 3268-4528 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 642
% INFO    : Updated Thermal Rating: on line 3268-6943 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1905
% INFO    : Updated Thermal Rating: on line 3268-5395 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1634
% INFO    : Updated Thermal Rating: on line 467-6303 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7799
% INFO    : Updated Thermal Rating: on line 467-8412 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7797
% INFO    : Updated Thermal Rating: on line 467-3540 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1749
% INFO    : Updated Thermal Rating: on line 467-3540 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1709
% INFO    : Updated Thermal Rating: on line 467-7664 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1693
% INFO    : Updated Thermal Rating: on line 4632-3802 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 29775
% INFO    : Updated Thermal Rating: on line 6859-7112 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2496
% INFO    : Updated Thermal Rating: on line 6859-7112 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3923
% INFO    : Updated Thermal Rating: on line 6859-13092 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9867
% INFO    : Updated Thermal Rating: on line 13492-7606 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13881
% INFO    : Updated Thermal Rating: on line 82-326 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8180
% INFO    : Updated Thermal Rating: on line 4479-1206 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3799
% INFO    : Updated Thermal Rating: on line 213-7450 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 537
% INFO    : Updated Thermal Rating: on line 213-5222 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6482
% INFO    : Updated Thermal Rating: on line 10564-4220 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9308
% INFO    : Updated Thermal Rating: on line 2075-7013 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4611
% INFO    : Updated Thermal Rating: on line 2075-5623 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6274
% INFO    : Updated Thermal Rating: on line 2075-8232 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6400
% INFO    : Updated Thermal Rating: on line 2075-8070 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5103
% INFO    : Updated Thermal Rating: on line 11026-12417 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10015
% INFO    : Updated Thermal Rating: on line 11026-5623 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4715
% INFO    : Updated Thermal Rating: on line 11026-8232 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4647
% INFO    : Updated Thermal Rating: on line 1783-3472 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1832
% INFO    : Updated Thermal Rating: on line 1783-1657 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2737
% INFO    : Updated Thermal Rating: on line 1783-7203 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2031
% INFO    : Updated Thermal Rating: on line 1783-7203 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2821
% INFO    : Updated Thermal Rating: on line 1783-6632 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11729
% INFO    : Updated Thermal Rating: on line 1783-816 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2793
% INFO    : Updated Thermal Rating: on line 1783-4350 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4048
% INFO    : Updated Thermal Rating: on line 1783-11640 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12172
% INFO    : Updated Thermal Rating: on line 2217-9004 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2607
% INFO    : Updated Thermal Rating: on line 2217-7132 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4274
% INFO    : Updated Thermal Rating: on line 2217-7942 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4122
% INFO    : Updated Thermal Rating: on line 2217-13324 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1389
% INFO    : Updated Thermal Rating: on line 4436-9530 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10884
% INFO    : Updated Thermal Rating: on line 2224-6604 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 688
% INFO    : Updated Thermal Rating: on line 2224-5251 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2469
% INFO    : Updated Thermal Rating: on line 2224-5251 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2614
% INFO    : Updated Thermal Rating: on line 2224-11608 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on line 1744-4776 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1238
% INFO    : Updated Thermal Rating: on line 1744-13448 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1447
% INFO    : Updated Thermal Rating: on line 1744-8237 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1841
% INFO    : Updated Thermal Rating: on line 12498-8605 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 908
% INFO    : Updated Thermal Rating: on line 4266-6599 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3877
% INFO    : Updated Thermal Rating: on line 6-2590 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2021
% INFO    : Updated Thermal Rating: on line 11080-10301 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9413
% INFO    : Updated Thermal Rating: on line 5968-9694 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1578
% INFO    : Updated Thermal Rating: on line 5968-9274 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2398
% INFO    : Updated Thermal Rating: on line 6497-8183 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 381
% INFO    : Updated Thermal Rating: on line 6497-2804 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 611
% INFO    : Updated Thermal Rating: on line 6497-2528 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 684
% INFO    : Updated Thermal Rating: on line 4370-4776 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7428
% INFO    : Updated Thermal Rating: on line 4370-4564 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4197
% INFO    : Updated Thermal Rating: on line 4370-8237 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2553
% INFO    : Updated Thermal Rating: on line 1252-6839 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 618
% INFO    : Updated Thermal Rating: on line 1252-761 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3383
% INFO    : Updated Thermal Rating: on line 1252-9955 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 459
% INFO    : Updated Thermal Rating: on line 1252-8620 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1300
% INFO    : Updated Thermal Rating: on line 1252-8620 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1287
% INFO    : Updated Thermal Rating: on line 5230-12270 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2291
% INFO    : Updated Thermal Rating: on line 5011-6228 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2547
% INFO    : Updated Thermal Rating: on line 5011-6228 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2529
% INFO    : Updated Thermal Rating: on line 5011-5395 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 698
% INFO    : Updated Thermal Rating: on line 9065-5428 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1201
% INFO    : Updated Thermal Rating: on line 13382-5428 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1035
% INFO    : Updated Thermal Rating: on line 10485-140 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1417
% INFO    : Updated Thermal Rating: on line 3961-459 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1417
% INFO    : Updated Thermal Rating: on line 1039-12376 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1434
% INFO    : Updated Thermal Rating: on line 1039-10204 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 693
% INFO    : Updated Thermal Rating: on line 9155-13028 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2632
% INFO    : Updated Thermal Rating: on line 9155-13028 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2683
% INFO    : Updated Thermal Rating: on line 12683-4315 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5816
% INFO    : Updated Thermal Rating: on line 9633-1173 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 95544
% INFO    : Updated Thermal Rating: on line 9633-12161 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 92864
% INFO    : Updated Thermal Rating: on line 9059-1345 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12195
% INFO    : Updated Thermal Rating: on line 9059-2595 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12483
% INFO    : Updated Thermal Rating: on line 4700-2141 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3602
% INFO    : Updated Thermal Rating: on line 4700-10585 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1472
% INFO    : Updated Thermal Rating: on line 4212-1509 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 37425
% INFO    : Updated Thermal Rating: on line 5760-10062 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2768
% INFO    : Updated Thermal Rating: on line 8821-244 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1839
% INFO    : Updated Thermal Rating: on line 8821-244 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1876
% INFO    : Updated Thermal Rating: on line 13071-13203 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26188
% INFO    : Updated Thermal Rating: on line 2218-1702 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4405
% INFO    : Updated Thermal Rating: on line 5753-5499 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6862
% INFO    : Updated Thermal Rating: on line 5753-10193 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18126
% INFO    : Updated Thermal Rating: on line 5753-10193 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 40050
% INFO    : Updated Thermal Rating: on line 5753-13142 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4693
% INFO    : Updated Thermal Rating: on line 11004-12094 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3758
% INFO    : Updated Thermal Rating: on line 11004-12094 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3689
% INFO    : Updated Thermal Rating: on line 3466-11522 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1819
% INFO    : Updated Thermal Rating: on line 3466-2007 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 844
% INFO    : Updated Thermal Rating: on line 13144-11522 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1615
% INFO    : Updated Thermal Rating: on line 12376-8620 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1464
% INFO    : Updated Thermal Rating: on line 2735-10204 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11266
% INFO    : Updated Thermal Rating: on line 1607-9709 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2308
% INFO    : Updated Thermal Rating: on line 6692-955 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2576
% INFO    : Updated Thermal Rating: on line 6692-955 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2639
% INFO    : Updated Thermal Rating: on line 13078-1657 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5127
% INFO    : Updated Thermal Rating: on line 13078-9310 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5224
% INFO    : Updated Thermal Rating: on line 4953-601 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 39117
% INFO    : Updated Thermal Rating: on line 4953-10594 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 45856
% INFO    : Updated Thermal Rating: on line 4953-8724 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3676
% INFO    : Updated Thermal Rating: on line 5757-3662 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 30131
% INFO    : Updated Thermal Rating: on line 5844-10787 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 464
% INFO    : Updated Thermal Rating: on line 4519-13214 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1025
% INFO    : Updated Thermal Rating: on line 3850-8360 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8836
% INFO    : Updated Thermal Rating: on line 1710-12739 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3507
% INFO    : Updated Thermal Rating: on line 11163-10341 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 74627
% INFO    : Updated Thermal Rating: on line 7062-9999 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5902
% INFO    : Updated Thermal Rating: on line 6081-1859 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3816
% INFO    : Updated Thermal Rating: on line 5428-6699 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1014
% INFO    : Updated Thermal Rating: on line 5428-13138 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 32351
% INFO    : Updated Thermal Rating: on line 11146-7838 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3092
% INFO    : Updated Thermal Rating: on line 3981-7838 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3541
% INFO    : Updated Thermal Rating: on line 6394-9677 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4605
% INFO    : Updated Thermal Rating: on line 12055-3560 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5309
% INFO    : Updated Thermal Rating: on line 10933-7958 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 938
% INFO    : Updated Thermal Rating: on line 4969-7793 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 87580
% INFO    : Updated Thermal Rating: on line 894-333 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4182
% INFO    : Updated Thermal Rating: on line 11295-5921 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1290
% INFO    : Updated Thermal Rating: on line 12094-6599 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1461
% INFO    : Updated Thermal Rating: on line 12094-6599 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1490
% INFO    : Updated Thermal Rating: on line 9593-6228 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5553
% INFO    : Updated Thermal Rating: on line 9593-6228 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5069
% INFO    : Updated Thermal Rating: on line 4228-9003 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3077
% INFO    : Updated Thermal Rating: on line 5785-3502 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15364
% INFO    : Updated Thermal Rating: on line 5785-9544 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 47279
% INFO    : Updated Thermal Rating: on line 2746-5623 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6234
% INFO    : Updated Thermal Rating: on line 2746-8232 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6371
% INFO    : Updated Thermal Rating: on line 7408-7203 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 39182
% INFO    : Updated Thermal Rating: on line 7408-7203 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 41796
% INFO    : Updated Thermal Rating: on line 6061-2350 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1018
% INFO    : Updated Thermal Rating: on line 235-5120 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1573
% INFO    : Updated Thermal Rating: on line 235-2729 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1528
% INFO    : Updated Thermal Rating: on line 11675-11931 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8334
% INFO    : Updated Thermal Rating: on line 11675-2104 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8174
% INFO    : Updated Thermal Rating: on line 3290-5194 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5453
% INFO    : Updated Thermal Rating: on line 5185-13237 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5552
% INFO    : Updated Thermal Rating: on line 2875-13167 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21943
% INFO    : Updated Thermal Rating: on line 7555-13167 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22129
% INFO    : Updated Thermal Rating: on line 11678-7606 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9325
% INFO    : Updated Thermal Rating: on line 2920-12691 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18132
% INFO    : Updated Thermal Rating: on line 2920-12691 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18519
% INFO    : Updated Thermal Rating: on line 6839-9955 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 996
% INFO    : Updated Thermal Rating: on line 11003-1122 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1378
% INFO    : Updated Thermal Rating: on line 13289-7567 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 65948
% INFO    : Updated Thermal Rating: on line 5282-2876 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 65948
% INFO    : Updated Thermal Rating: on line 1228-5921 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1545
% INFO    : Updated Thermal Rating: on line 1228-4121 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2621
% INFO    : Updated Thermal Rating: on line 10787-12978 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1083
% INFO    : Updated Thermal Rating: on line 11726-2866 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2147
% INFO    : Updated Thermal Rating: on line 11726-2866 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2132
% INFO    : Updated Thermal Rating: on line 11726-2497 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3105
% INFO    : Updated Thermal Rating: on line 1984-3285 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 637
% INFO    : Updated Thermal Rating: on line 6604-11608 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1009
% INFO    : Updated Thermal Rating: on line 8497-661 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3535
% INFO    : Updated Thermal Rating: on line 8497-661 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3615
% INFO    : Updated Thermal Rating: on line 8497-2595 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 905
% INFO    : Updated Thermal Rating: on line 8497-10731 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3347
% INFO    : Updated Thermal Rating: on line 8497-9409 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3557
% INFO    : Updated Thermal Rating: on line 8497-2467 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1894
% INFO    : Updated Thermal Rating: on line 13448-872 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1365
% INFO    : Updated Thermal Rating: on line 9289-7856 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7699
% INFO    : Updated Thermal Rating: on line 1024-955 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 932
% INFO    : Updated Thermal Rating: on line 588-10966 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1069
% INFO    : Updated Thermal Rating: on line 5921-4114 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7474
% INFO    : Updated Thermal Rating: on line 5921-11837 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1667
% INFO    : Updated Thermal Rating: on line 2590-4108 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1824
% INFO    : Updated Thermal Rating: on line 7811-10327 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 795
% INFO    : Updated Thermal Rating: on line 7811-6031 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2710
% INFO    : Updated Thermal Rating: on line 7811-7150 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 55676
% INFO    : Updated Thermal Rating: on line 5722-5677 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1228
% INFO    : Updated Thermal Rating: on line 184-2220 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19092
% INFO    : Updated Thermal Rating: on line 285-11753 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2671
% INFO    : Updated Thermal Rating: on line 285-2220 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2016
% INFO    : Updated Thermal Rating: on line 4299-4528 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 931
% INFO    : Updated Thermal Rating: on line 10724-4437 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23827
% INFO    : Updated Thermal Rating: on line 7400-13294 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2371
% INFO    : Updated Thermal Rating: on line 4564-872 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 741
% INFO    : Updated Thermal Rating: on line 994-12497 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7532
% INFO    : Updated Thermal Rating: on line 7517-7985 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 725
% INFO    : Updated Thermal Rating: on line 9709-1122 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1018
% INFO    : Updated Thermal Rating: on line 9694-1139 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2014
% INFO    : Updated Thermal Rating: on line 9263-7150 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5705
% INFO    : Updated Thermal Rating: on line 9263-7150 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5809
% INFO    : Updated Thermal Rating: on line 2685-955 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 961
% INFO    : Updated Thermal Rating: on line 2685-3018 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 552
% INFO    : Updated Thermal Rating: on line 244-3350 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2364
% INFO    : Updated Thermal Rating: on line 4110-14 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16165
% INFO    : Updated Thermal Rating: on line 6577-6228 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19365
% INFO    : Updated Thermal Rating: on line 13203-12739 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1132
% INFO    : Updated Thermal Rating: on line 1206-6534 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3535
% INFO    : Updated Thermal Rating: on line 12417-3090 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11041
% INFO    : Updated Thermal Rating: on line 1657-11640 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3479
% INFO    : Updated Thermal Rating: on line 1657-9310 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 80052
% INFO    : Updated Thermal Rating: on line 10852-7112 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3446
% INFO    : Updated Thermal Rating: on line 5937-9310 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 70621
% INFO    : Updated Thermal Rating: on line 7203-3802 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 59321
% INFO    : Updated Thermal Rating: on line 7203-3802 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 62899
% INFO    : Updated Thermal Rating: on line 7203-816 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8170
% INFO    : Updated Thermal Rating: on line 7203-4350 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11052
% INFO    : Updated Thermal Rating: on line 11753-7664 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1130
% INFO    : Updated Thermal Rating: on line 2433-4880 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1571
% INFO    : Updated Thermal Rating: on line 2433-6905 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3639
% INFO    : Updated Thermal Rating: on line 955-1745 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1613
% INFO    : Updated Thermal Rating: on line 955-11829 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1905
% INFO    : Updated Thermal Rating: on line 12841-2041 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1194
% INFO    : Updated Thermal Rating: on line 11276-4994 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2226
% INFO    : Updated Thermal Rating: on line 4528-12497 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1724
% INFO    : Updated Thermal Rating: on line 9849-941 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2551
% INFO    : Updated Thermal Rating: on line 13167-6320 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17353
% INFO    : Updated Thermal Rating: on line 1113-7631 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1297
% INFO    : Updated Thermal Rating: on line 2804-8629 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 750
% INFO    : Updated Thermal Rating: on line 13326-5877 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21842
% INFO    : Updated Thermal Rating: on line 2740-12386 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11385
% INFO    : Updated Thermal Rating: on line 2740-2878 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11989
% INFO    : Updated Thermal Rating: on line 2740-12210 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2601
% INFO    : Updated Thermal Rating: on line 6943-5395 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 867
% INFO    : Updated Thermal Rating: on line 6943-12497 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3636
% INFO    : Updated Thermal Rating: on line 1127-2350 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4432
% INFO    : Updated Thermal Rating: on line 9274-1445 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1735
% INFO    : Updated Thermal Rating: on line 9274-13294 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1592
% INFO    : Updated Thermal Rating: on line 9274-1139 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2512
% INFO    : Updated Thermal Rating: on line 7321-7856 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17113
% INFO    : Updated Thermal Rating: on line 2432-7219 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 73380
% INFO    : Updated Thermal Rating: on line 13529-7219 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 78748
% INFO    : Updated Thermal Rating: on line 422-13544 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 550
% INFO    : Updated Thermal Rating: on line 11837-5395 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1071
% INFO    : Updated Thermal Rating: on line 8309-13294 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2129
% INFO    : Updated Thermal Rating: on line 8309-12484 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9920
% INFO    : Updated Thermal Rating: on line 8309-10048 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10368
% INFO    : Updated Thermal Rating: on line 7606-10645 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5338
% INFO    : Updated Thermal Rating: on line 13028-13294 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4978
% INFO    : Updated Thermal Rating: on line 13028-13294 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4887
% INFO    : Updated Thermal Rating: on line 13028-13294 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6219
% INFO    : Updated Thermal Rating: on line 321-5028 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1050
% INFO    : Updated Thermal Rating: on line 761-8620 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1999
% INFO    : Updated Thermal Rating: on line 3802-3009 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 36817
% INFO    : Updated Thermal Rating: on line 1725-7631 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 55045
% INFO    : Updated Thermal Rating: on line 10217-8724 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13915
% INFO    : Updated Thermal Rating: on line 7604-8724 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14137
% INFO    : Updated Thermal Rating: on line 5395-9999 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1694
% INFO    : Updated Thermal Rating: on line 1242-2041 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2032
% INFO    : Updated Thermal Rating: on line 7515-4880 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 774
% INFO    : Updated Thermal Rating: on line 5120-3502 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 548
% INFO    : Updated Thermal Rating: on line 6057-4439 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 29948
% INFO    : Updated Thermal Rating: on line 12691-13125 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1805
% INFO    : Updated Thermal Rating: on line 5132-3602 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2962
% INFO    : Updated Thermal Rating: on line 5132-8987 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4121
% INFO    : Updated Thermal Rating: on line 592-2259 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 102150
% INFO    : Updated Thermal Rating: on line 10294-6599 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1780
% INFO    : Updated Thermal Rating: on line 10294-6599 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1573
% INFO    : Updated Thermal Rating: on line 9955-8105 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1074
% INFO    : Updated Thermal Rating: on line 10842-3527 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 62614
% INFO    : Updated Thermal Rating: on line 10842-3527 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 63968
% INFO    : Updated Thermal Rating: on line 6599-634 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3095
% INFO    : Updated Thermal Rating: on line 6599-634 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3633
% INFO    : Updated Thermal Rating: on line 6599-634 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2435
% INFO    : Updated Thermal Rating: on line 6599-634 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4173
% INFO    : Updated Thermal Rating: on line 6599-634 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4092
% INFO    : Updated Thermal Rating: on line 6599-4439 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1376
% INFO    : Updated Thermal Rating: on line 4246-4511 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 809
% INFO    : Updated Thermal Rating: on line 4246-4511 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 807
% INFO    : Updated Thermal Rating: on line 1345-2467 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2312
% INFO    : Updated Thermal Rating: on line 2528-7861 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 587
% INFO    : Updated Thermal Rating: on line 6854-2392 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6553
% INFO    : Updated Thermal Rating: on line 6854-10341 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 28567
% INFO    : Updated Thermal Rating: on line 1745-11829 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5032
% INFO    : Updated Thermal Rating: on line 169-333 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8039
% INFO    : Updated Thermal Rating: on line 8318-7758 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 933
% INFO    : Updated Thermal Rating: on line 5251-7958 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1633
% INFO    : Updated Thermal Rating: on line 4730-178 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 28416
% INFO    : Updated Thermal Rating: on line 10310-7008 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 28923
% INFO    : Updated Thermal Rating: on line 3428-4822 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 35458
% INFO    : Updated Thermal Rating: on line 2710-6572 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 35026
% INFO    : Updated Thermal Rating: on line 990-6534 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 28133
% INFO    : Updated Thermal Rating: on line 1422-7112 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11613
% INFO    : Updated Thermal Rating: on line 9411-2866 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8540
% INFO    : Updated Thermal Rating: on line 2392-10341 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11440
% INFO    : Updated Thermal Rating: on line 7787-10966 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6226
% INFO    : Updated Thermal Rating: on line 3502-9544 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 37622
% INFO    : Updated Thermal Rating: on line 1598-872 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2494
% INFO    : Updated Thermal Rating: on line 6955-11424 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4005
% INFO    : Updated Thermal Rating: on line 7219-6187 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5690
% INFO    : Updated Thermal Rating: on line 7219-1702 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5036
% INFO    : Updated Thermal Rating: on line 8724-13022 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2911
% INFO    : Updated Thermal Rating: on line 2564-12512 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5304
% INFO    : Updated Thermal Rating: on line 3540-9003 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2142
% INFO    : Updated Thermal Rating: on line 3018-3285 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 569
% INFO    : Updated Thermal Rating: on line 13294-12484 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2819
% INFO    : Updated Thermal Rating: on line 13294-10048 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3102
% INFO    : Updated Thermal Rating: on line 13294-4315 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2211
% INFO    : Updated Thermal Rating: on line 7229-4672 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1153
% INFO    : Updated Thermal Rating: on line 7229-4851 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2203
% INFO    : Updated Thermal Rating: on line 7229-5545 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1055
% INFO    : Updated Thermal Rating: on line 7229-5028 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4025
% INFO    : Updated Thermal Rating: on line 7838-2878 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4122
% INFO    : Updated Thermal Rating: on line 7838-6047 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9353
% INFO    : Updated Thermal Rating: on line 7838-8030 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8632
% INFO    : Updated Thermal Rating: on line 7838-12210 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7757
% INFO    : Updated Thermal Rating: on line 7838-7567 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3571
% INFO    : Updated Thermal Rating: on line 10989-10214 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10003
% INFO    : Updated Thermal Rating: on line 10989-3444 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7874
% INFO    : Updated Thermal Rating: on line 10989-2876 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3199
% INFO    : Updated Thermal Rating: on line 9484-8987 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1023
% INFO    : Updated Thermal Rating: on line 7112-10193 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3390
% INFO    : Updated Thermal Rating: on line 7112-10193 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3259
% INFO    : Updated Thermal Rating: on line 7112-8007 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3517
% INFO    : Updated Thermal Rating: on line 7112-13142 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6356
% INFO    : Updated Thermal Rating: on line 7112-13481 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5658
% INFO    : Updated Thermal Rating: on line 7112-13092 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5280
% INFO    : Updated Thermal Rating: on line 2866-2497 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7030
% INFO    : Updated Thermal Rating: on line 2104-9674 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2394
% INFO    : Updated Thermal Rating: on line 1158-6736 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2190
% INFO    : Updated Thermal Rating: on line 12805-6929 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 30397
% INFO    : Updated Thermal Rating: on line 6031-896 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11773
% INFO    : Updated Thermal Rating: on line 9999-7856 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6861
% INFO    : Updated Thermal Rating: on line 4808-6001 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 742
% INFO    : Updated Thermal Rating: on line 252-4808 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3043
% INFO    : Updated Thermal Rating: on line 1639-237 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12582
% INFO    : Updated Thermal Rating: on line 1639-237 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12386
% INFO    : Updated Thermal Rating: on line 7298-1639 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2549
% INFO    : Updated Thermal Rating: on line 7298-1639 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2603
% INFO    : Updated Thermal Rating: on line 1639-2194 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10075
% INFO    : Updated Thermal Rating: on line 1523-1639 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10868
% INFO    : Updated Thermal Rating: on line 1283-1639 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16188
% INFO    : Updated Thermal Rating: on line 9626-11157 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4918
% INFO    : Updated Thermal Rating: on line 11343-11157 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 723
% INFO    : Updated Thermal Rating: on line 9626-9463 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4834
% INFO    : Updated Thermal Rating: on line 9463-12239 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1721
% INFO    : Updated Thermal Rating: on line 9626-8365 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2095
% INFO    : Updated Thermal Rating: on line 675-9626 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 116559
% INFO    : Updated Thermal Rating: on line 12239-9626 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4020
% INFO    : Updated Thermal Rating: on line 6077-10086 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2120
% INFO    : Updated Thermal Rating: on line 5652-6077 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 116559
% INFO    : Updated Thermal Rating: on line 6077-6701 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8200
% INFO    : Updated Thermal Rating: on line 6077-13319 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18439
% INFO    : Updated Thermal Rating: on line 10086-4731 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11385
% INFO    : Updated Thermal Rating: on line 8365-914 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5481
% INFO    : Updated Thermal Rating: on line 11701-2753 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1975
% INFO    : Updated Thermal Rating: on line 12028-2753 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1203
% INFO    : Updated Thermal Rating: on line 2753-642 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2830
% INFO    : Updated Thermal Rating: on line 3087-4118 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 260
% INFO    : Updated Thermal Rating: on line 9293-3087 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2838
% INFO    : Updated Thermal Rating: on line 3087-3703 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 275
% INFO    : Updated Thermal Rating: on line 3087-3703 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 247
% INFO    : Updated Thermal Rating: on line 3087-13618 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3269
% INFO    : Updated Thermal Rating: on line 3087-13618 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3196
% INFO    : Updated Thermal Rating: on line 3087-13618 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3234
% INFO    : Updated Thermal Rating: on line 9433-8446 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 382
% INFO    : Updated Thermal Rating: on line 3512-9433 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 238
% INFO    : Updated Thermal Rating: on line 9433-2678 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 744
% INFO    : Updated Thermal Rating: on line 9433-2678 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 802
% INFO    : Updated Thermal Rating: on line 9433-2678 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 802
% INFO    : Updated Thermal Rating: on line 9433-1014 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1765
% INFO    : Updated Thermal Rating: on line 9433-1014 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1735
% INFO    : Updated Thermal Rating: on line 11444-8932 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19790
% INFO    : Updated Thermal Rating: on line 12617-8932 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3046
% INFO    : Updated Thermal Rating: on line 8932-6345 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 432
% INFO    : Updated Thermal Rating: on line 5873-4232 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 115310
% INFO    : Updated Thermal Rating: on line 7419-5873 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 315
% INFO    : Updated Thermal Rating: on line 6677-4232 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1334
% INFO    : Updated Thermal Rating: on line 1312-4232 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1611
% INFO    : Updated Thermal Rating: on line 3645-12617 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 557
% INFO    : Updated Thermal Rating: on line 9255-6247 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 116559
% INFO    : Updated Thermal Rating: on line 6247-4487 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3860
% INFO    : Updated Thermal Rating: on line 10344-6247 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 957
% INFO    : Updated Thermal Rating: on line 1444-6247 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8641
% INFO    : Updated Thermal Rating: on line 6126-6247 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8961
% INFO    : Updated Thermal Rating: on line 4487-8617 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3186
% INFO    : Updated Thermal Rating: on line 13528-7973 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 116559
% INFO    : Updated Thermal Rating: on line 9798-5047 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 116559
% INFO    : Updated Thermal Rating: on line 11397-5526 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 116559
% INFO    : Updated Thermal Rating: on line 3873-1312 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 116559
% INFO    : Updated Thermal Rating: on line 911-6565 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 116559
% INFO    : Updated Thermal Rating: on line 1374-11610 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 116559
% INFO    : Updated Thermal Rating: on line 12941-6568 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8963
% INFO    : Updated Thermal Rating: on line 2773-6568 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 116559
% INFO    : Updated Thermal Rating: on line 6568-9371 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1418
% INFO    : Updated Thermal Rating: on line 6568-5098 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1031
% INFO    : Updated Thermal Rating: on line 4840-7947 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8135
% INFO    : Updated Thermal Rating: on line 252-4840 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 846
% INFO    : Updated Thermal Rating: on line 13183-7947 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8761
% INFO    : Updated Thermal Rating: on line 8650-13183 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 771
% INFO    : Updated Thermal Rating: on line 11379-8575 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11961
% INFO    : Updated Thermal Rating: on line 11379-8575 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12231
% INFO    : Updated Thermal Rating: on line 884-11379 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1574
% INFO    : Updated Thermal Rating: on line 884-11379 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1607
% INFO    : Updated Thermal Rating: on line 11379-8853 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1233
% INFO    : Updated Thermal Rating: on line 11379-8853 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1331
% INFO    : Updated Thermal Rating: on line 3896-12046 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 32762
% INFO    : Updated Thermal Rating: on line 4579-12046 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2219
% INFO    : Updated Thermal Rating: on line 3896-8381 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 33362
% INFO    : Updated Thermal Rating: on line 11559-8381 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7733
% INFO    : Updated Thermal Rating: on line 8049-4824 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 303
% INFO    : Updated Thermal Rating: on line 4824-10042 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 116559
% INFO    : Updated Thermal Rating: on line 3006-3247 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 8049-3006 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 298
% INFO    : Updated Thermal Rating: on line 3006-10279 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 116559
% INFO    : Updated Thermal Rating: on line 13554-3247 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 237-4835 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7941
% INFO    : Updated Thermal Rating: on line 237-4835 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7785
% INFO    : Updated Thermal Rating: on line 237-4835 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8716
% INFO    : Updated Thermal Rating: on line 237-4835 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8908
% INFO    : Updated Thermal Rating: on line 7298-237 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2047
% INFO    : Updated Thermal Rating: on line 11610-5564 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 879
% INFO    : Updated Thermal Rating: on line 11610-10760 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4224
% INFO    : Updated Thermal Rating: on line 7510-5564 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 890
% INFO    : Updated Thermal Rating: on line 7510-1991 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4300
% INFO    : Updated Thermal Rating: on line 2911-7510 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 940
% INFO    : Updated Thermal Rating: on line 7510-11277 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1419
% INFO    : Updated Thermal Rating: on line 4073-12941 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2486
% INFO    : Updated Thermal Rating: on line 4101-3639 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 3639-13173 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 701
% INFO    : Updated Thermal Rating: on line 5398-1951 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 448
% INFO    : Updated Thermal Rating: on line 5398-1951 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 456
% INFO    : Updated Thermal Rating: on line 1951-11375 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3095
% INFO    : Updated Thermal Rating: on line 1951-7684 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 430
% INFO    : Updated Thermal Rating: on line 1951-1941 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 638
% INFO    : Updated Thermal Rating: on line 1951-4496 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1766
% INFO    : Updated Thermal Rating: on line 10956-7520 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 33796
% INFO    : Updated Thermal Rating: on line 10956-3829 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 36412
% INFO    : Updated Thermal Rating: on line 12767-7285 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4787
% INFO    : Updated Thermal Rating: on line 7285-7006 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2354
% INFO    : Updated Thermal Rating: on line 9132-2596 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 856
% INFO    : Updated Thermal Rating: on line 2596-3818 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 354
% INFO    : Updated Thermal Rating: on line 974-2170 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 9132-2170 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 867
% INFO    : Updated Thermal Rating: on line 2170-1719 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5559
% INFO    : Updated Thermal Rating: on line 10587-12770 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5859
% INFO    : Updated Thermal Rating: on line 10587-12770 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5753
% INFO    : Updated Thermal Rating: on line 7496-5871 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4034
% INFO    : Updated Thermal Rating: on line 1713-5871 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 798
% INFO    : Updated Thermal Rating: on line 393-3896 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 393-9903 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5283
% INFO    : Updated Thermal Rating: on line 2805-393 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1846
% INFO    : Updated Thermal Rating: on line 2805-393 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1816
% INFO    : Updated Thermal Rating: on line 393-11929 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 70604
% INFO    : Updated Thermal Rating: on line 3896-10832 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 70604
% INFO    : Updated Thermal Rating: on line 7973-8617 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 935
% INFO    : Updated Thermal Rating: on line 12426-7973 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 403
% INFO    : Updated Thermal Rating: on line 9077-5047 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23496
% INFO    : Updated Thermal Rating: on line 2805-9077 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3094
% INFO    : Updated Thermal Rating: on line 3733-5526 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24871
% INFO    : Updated Thermal Rating: on line 3263-3733 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3358
% INFO    : Updated Thermal Rating: on line 10122-8913 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9303
% INFO    : Updated Thermal Rating: on line 252-10122 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 571
% INFO    : Updated Thermal Rating: on line 230-4148 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18634
% INFO    : Updated Thermal Rating: on line 230-8913 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9480
% INFO    : Updated Thermal Rating: on line 12244-4148 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 9173-4148 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 507
% INFO    : Updated Thermal Rating: on line 1312-7335 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 639
% INFO    : Updated Thermal Rating: on line 8446-4829 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1436
% INFO    : Updated Thermal Rating: on line 4829-13318 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4866
% INFO    : Updated Thermal Rating: on line 1191-13187 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1040
% INFO    : Updated Thermal Rating: on line 1191-2678 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 354
% INFO    : Updated Thermal Rating: on line 347-1191 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1142
% INFO    : Updated Thermal Rating: on line 10616-3388 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1613
% INFO    : Updated Thermal Rating: on line 4118-10616 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 644
% INFO    : Updated Thermal Rating: on line 10616-13618 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 472
% INFO    : Updated Thermal Rating: on line 6565-5255 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 515
% INFO    : Updated Thermal Rating: on line 6565-9086 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1277
% INFO    : Updated Thermal Rating: on line 8212-4118 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 4118-7739 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1638
% INFO    : Updated Thermal Rating: on line 8171-4118 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 557
% INFO    : Updated Thermal Rating: on line 8362-7739 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2673
% INFO    : Updated Thermal Rating: on line 3516-7514 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 316
% INFO    : Updated Thermal Rating: on line 9533-7514 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3628
% INFO    : Updated Thermal Rating: on line 618-9235 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13023
% INFO    : Updated Thermal Rating: on line 9235-1444 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 480
% INFO    : Updated Thermal Rating: on line 12947-2832 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 9717-2832 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 212
% INFO    : Updated Thermal Rating: on line 12933-2832 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 421
% INFO    : Updated Thermal Rating: on line 2832-6618 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 311
% INFO    : Updated Thermal Rating: on line 7682-2832 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 427
% INFO    : Updated Thermal Rating: on line 7871-6243 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 6243-12473 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 677
% INFO    : Updated Thermal Rating: on line 3271-6243 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 516
% INFO    : Updated Thermal Rating: on line 8748-11441 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 62636
% INFO    : Updated Thermal Rating: on line 2551-11441 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3770
% INFO    : Updated Thermal Rating: on line 2922-8748 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12236
% INFO    : Updated Thermal Rating: on line 11252-1428 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 47320
% INFO    : Updated Thermal Rating: on line 2551-11252 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3877
% INFO    : Updated Thermal Rating: on line 1428-8526 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10520
% INFO    : Updated Thermal Rating: on line 2922-7298 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3132
% INFO    : Updated Thermal Rating: on line 8526-237 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5012
% INFO    : Updated Thermal Rating: on line 5694-11284 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12223
% INFO    : Updated Thermal Rating: on line 5694-8131 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 961
% INFO    : Updated Thermal Rating: on line 8083-5694 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 490
% INFO    : Updated Thermal Rating: on line 9563-6184 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 5713-6184 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1075
% INFO    : Updated Thermal Rating: on line 5290-6184 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1464
% INFO    : Updated Thermal Rating: on line 6536-6184 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 479
% INFO    : Updated Thermal Rating: on line 6184-150 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1035
% INFO    : Updated Thermal Rating: on line 11284-8296 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18395
% INFO    : Updated Thermal Rating: on line 163-618 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 12128-618 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 461
% INFO    : Updated Thermal Rating: on line 12700-8863 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3164
% INFO    : Updated Thermal Rating: on line 8863-5451 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 8863-450 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 8863-8643 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 3649-9001 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3123
% INFO    : Updated Thermal Rating: on line 9001-4541 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 9001-9531 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 9001-2255 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 3649-12700 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 5451-10876 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 338
% INFO    : Updated Thermal Rating: on line 5976-4541 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 330
% INFO    : Updated Thermal Rating: on line 8339-450 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 472
% INFO    : Updated Thermal Rating: on line 542-9531 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1372
% INFO    : Updated Thermal Rating: on line 8643-3629 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1846
% INFO    : Updated Thermal Rating: on line 2255-11339 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3756
% INFO    : Updated Thermal Rating: on line 13246-822 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12194
% INFO    : Updated Thermal Rating: on line 822-7359 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1043
% INFO    : Updated Thermal Rating: on line 13246-10805 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12417
% INFO    : Updated Thermal Rating: on line 139-10805 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1215
% INFO    : Updated Thermal Rating: on line 7762-13246 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 5713-4681 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 965
% INFO    : Updated Thermal Rating: on line 10606-8631 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 10606-10364 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 419-10606 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 5040-8631 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 409
% INFO    : Updated Thermal Rating: on line 9040-10364 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 741
% INFO    : Updated Thermal Rating: on line 3931-12565 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 11067-9293 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 28225
% INFO    : Updated Thermal Rating: on line 11067-5294 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 669
% INFO    : Updated Thermal Rating: on line 5294-12565 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14907
% INFO    : Updated Thermal Rating: on line 8825-12565 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15962
% INFO    : Updated Thermal Rating: on line 11613-8825 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 328
% INFO    : Updated Thermal Rating: on line 586-8062 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 8062-4100 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 218
% INFO    : Updated Thermal Rating: on line 1357-8062 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 488
% INFO    : Updated Thermal Rating: on line 8062-7803 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 137665
% INFO    : Updated Thermal Rating: on line 9780-13508 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 2161-13508 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 961
% INFO    : Updated Thermal Rating: on line 10857-13508 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 314
% INFO    : Updated Thermal Rating: on line 4459-3333 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2098
% INFO    : Updated Thermal Rating: on line 6186-3333 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2917
% INFO    : Updated Thermal Rating: on line 13360-5398 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14718
% INFO    : Updated Thermal Rating: on line 13360-5991 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1035
% INFO    : Updated Thermal Rating: on line 1341-8940 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14973
% INFO    : Updated Thermal Rating: on line 1341-13579 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1130
% INFO    : Updated Thermal Rating: on line 5398-4990 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25454
% INFO    : Updated Thermal Rating: on line 1713-4990 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2069
% INFO    : Updated Thermal Rating: on line 8940-4459 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25060
% INFO    : Updated Thermal Rating: on line 5398-8382 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23332
% INFO    : Updated Thermal Rating: on line 8382-8368 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1138
% INFO    : Updated Thermal Rating: on line 6381-10587 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1196
% INFO    : Updated Thermal Rating: on line 6381-10587 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1174
% INFO    : Updated Thermal Rating: on line 10587-8575 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3367
% INFO    : Updated Thermal Rating: on line 10587-9846 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3303
% INFO    : Updated Thermal Rating: on line 8940-1704 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 902
% INFO    : Updated Thermal Rating: on line 8940-440 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3268
% INFO    : Updated Thermal Rating: on line 6095-6950 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 169332
% INFO    : Updated Thermal Rating: on line 6095-413 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 839
% INFO    : Updated Thermal Rating: on line 6950-11798 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1344
% INFO    : Updated Thermal Rating: on line 5255-3483 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5375
% INFO    : Updated Thermal Rating: on line 3703-1595 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16151
% INFO    : Updated Thermal Rating: on line 1595-6728 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1323
% INFO    : Updated Thermal Rating: on line 3703-11613 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4461
% INFO    : Updated Thermal Rating: on line 790-8757 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1236
% INFO    : Updated Thermal Rating: on line 8757-7635 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1176
% INFO    : Updated Thermal Rating: on line 12443-1270 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4986
% INFO    : Updated Thermal Rating: on line 7225-12443 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 849
% INFO    : Updated Thermal Rating: on line 794-7635 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1924
% INFO    : Updated Thermal Rating: on line 11291-794 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 690
% INFO    : Updated Thermal Rating: on line 5218-7202 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4429
% INFO    : Updated Thermal Rating: on line 7746-5218 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 411
% INFO    : Updated Thermal Rating: on line 3544-7202 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4484
% INFO    : Updated Thermal Rating: on line 3544-12677 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 444
% INFO    : Updated Thermal Rating: on line 10732-2326 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6376
% INFO    : Updated Thermal Rating: on line 3117-2326 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 483
% INFO    : Updated Thermal Rating: on line 9132-4036 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1952
% INFO    : Updated Thermal Rating: on line 12950-4036 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 545
% INFO    : Updated Thermal Rating: on line 7923-1802 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2421
% INFO    : Updated Thermal Rating: on line 9132-1802 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1920
% INFO    : Updated Thermal Rating: on line 9635-7923 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 7923-11258 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 372
% INFO    : Updated Thermal Rating: on line 7746-7923 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 479
% INFO    : Updated Thermal Rating: on line 7923-6022 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 351
% INFO    : Updated Thermal Rating: on line 12842-9132 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 9132-6648 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 645
% INFO    : Updated Thermal Rating: on line 9132-6648 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 657
% INFO    : Updated Thermal Rating: on line 12007-9132 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 823
% INFO    : Updated Thermal Rating: on line 12950-9132 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 438
% INFO    : Updated Thermal Rating: on line 10732-9014 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6288
% INFO    : Updated Thermal Rating: on line 9014-2947 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1827
% INFO    : Updated Thermal Rating: on line 764-3719 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7412
% INFO    : Updated Thermal Rating: on line 764-4236 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3958
% INFO    : Updated Thermal Rating: on line 12284-764 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 661
% INFO    : Updated Thermal Rating: on line 764-529 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10950
% INFO    : Updated Thermal Rating: on line 6198-764 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1556
% INFO    : Updated Thermal Rating: on line 6176-9325 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 9325-12936 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10521
% INFO    : Updated Thermal Rating: on line 9325-11865 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5869
% INFO    : Updated Thermal Rating: on line 8670-9325 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1527
% INFO    : Updated Thermal Rating: on line 11178-5290 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 47405
% INFO    : Updated Thermal Rating: on line 11178-10185 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 46654
% INFO    : Updated Thermal Rating: on line 3402-10185 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1873
% INFO    : Updated Thermal Rating: on line 9786-9817 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 13518-11035 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 9817-13076 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 37645
% INFO    : Updated Thermal Rating: on line 8225-11035 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17716
% INFO    : Updated Thermal Rating: on line 6411-6633 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18939
% INFO    : Updated Thermal Rating: on line 6323-6633 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 471
% INFO    : Updated Thermal Rating: on line 6411-4659 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19385
% INFO    : Updated Thermal Rating: on line 6648-4659 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 372
% INFO    : Updated Thermal Rating: on line 1719-3818 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 393
% INFO    : Updated Thermal Rating: on line 11708-8049 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 8049-13542 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15981
% INFO    : Updated Thermal Rating: on line 4579-8049 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1792
% INFO    : Updated Thermal Rating: on line 4579-8049 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1825
% INFO    : Updated Thermal Rating: on line 6423-6648 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 6648-4588 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 327
% INFO    : Updated Thermal Rating: on line 12473-2908 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3741
% INFO    : Updated Thermal Rating: on line 7076-8795 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 8795-5410 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1182
% INFO    : Updated Thermal Rating: on line 1671-5410 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2238
% INFO    : Updated Thermal Rating: on line 5040-8795 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 246
% INFO    : Updated Thermal Rating: on line 1891-12284 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1352
% INFO    : Updated Thermal Rating: on line 11958-1891 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2564
% INFO    : Updated Thermal Rating: on line 8525-10380 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 437
% INFO    : Updated Thermal Rating: on line 3703-8525 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 206
% INFO    : Updated Thermal Rating: on line 8775-11701 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 72929
% INFO    : Updated Thermal Rating: on line 4404-8775 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 75947
% INFO    : Updated Thermal Rating: on line 11957-9164 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3590
% INFO    : Updated Thermal Rating: on line 9361-9164 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 30253
% INFO    : Updated Thermal Rating: on line 11957-8491 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3653
% INFO    : Updated Thermal Rating: on line 11338-8491 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 557
% INFO    : Updated Thermal Rating: on line 7279-11957 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 8431-7685 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3789
% INFO    : Updated Thermal Rating: on line 6198-8431 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1406
% INFO    : Updated Thermal Rating: on line 9405-7685 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3724
% INFO    : Updated Thermal Rating: on line 9405-12284 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 597
% INFO    : Updated Thermal Rating: on line 4300-7685 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5995
% INFO    : Updated Thermal Rating: on line 1672-7685 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 12950-7419 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 899
% INFO    : Updated Thermal Rating: on line 10600-7419 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 2830-12473 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2678
% INFO    : Updated Thermal Rating: on line 12473-1941 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 903
% INFO    : Updated Thermal Rating: on line 12473-252 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1215
% INFO    : Updated Thermal Rating: on line 12473-252 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1195
% INFO    : Updated Thermal Rating: on line 685-12473 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 3091-12128 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15493
% INFO    : Updated Thermal Rating: on line 12425-12128 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15774
% INFO    : Updated Thermal Rating: on line 2451-10540 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7219
% INFO    : Updated Thermal Rating: on line 1718-2451 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1791
% INFO    : Updated Thermal Rating: on line 3629-2639 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1585
% INFO    : Updated Thermal Rating: on line 7802-9931 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7487
% INFO    : Updated Thermal Rating: on line 7802-4600 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1108
% INFO    : Updated Thermal Rating: on line 5621-9931 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7590
% INFO    : Updated Thermal Rating: on line 10590-5621 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 782
% INFO    : Updated Thermal Rating: on line 12895-9931 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 3703-8527 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 414
% INFO    : Updated Thermal Rating: on line 758-8527 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 246
% INFO    : Updated Thermal Rating: on line 8532-8527 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 8527-8362 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15384
% INFO    : Updated Thermal Rating: on line 10252-6239 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1060
% INFO    : Updated Thermal Rating: on line 10926-10252 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 449
% INFO    : Updated Thermal Rating: on line 10252-3263 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 526
% INFO    : Updated Thermal Rating: on line 9796-9610 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1952
% INFO    : Updated Thermal Rating: on line 9796-6054 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2414
% INFO    : Updated Thermal Rating: on line 9796-6748 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 862
% INFO    : Updated Thermal Rating: on line 11343-1319 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4992
% INFO    : Updated Thermal Rating: on line 4961-11343 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3169
% INFO    : Updated Thermal Rating: on line 4961-4744 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4418
% INFO    : Updated Thermal Rating: on line 4961-6902 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2174
% INFO    : Updated Thermal Rating: on line 11339-11765 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3720
% INFO    : Updated Thermal Rating: on line 1724-11765 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3792
% INFO    : Updated Thermal Rating: on line 1724-3629 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3333
% INFO    : Updated Thermal Rating: on line 2161-8850 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1432
% INFO    : Updated Thermal Rating: on line 542-8850 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1459
% INFO    : Updated Thermal Rating: on line 6932-1570 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9667
% INFO    : Updated Thermal Rating: on line 6932-6054 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 298
% INFO    : Updated Thermal Rating: on line 3202-1570 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8657
% INFO    : Updated Thermal Rating: on line 3629-3202 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3860
% INFO    : Updated Thermal Rating: on line 5636-1943 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1777
% INFO    : Updated Thermal Rating: on line 2169-5636 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5987
% INFO    : Updated Thermal Rating: on line 5636-8528 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6093
% INFO    : Updated Thermal Rating: on line 5340-5636 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 1943-830 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26144
% INFO    : Updated Thermal Rating: on line 830-1824 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 425
% INFO    : Updated Thermal Rating: on line 3155-830 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2204
% INFO    : Updated Thermal Rating: on line 7204-830 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2246
% INFO    : Updated Thermal Rating: on line 5491-830 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24221
% INFO    : Updated Thermal Rating: on line 7015-830 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 12793-2076 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 3849-1843 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 2378-2076 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14764
% INFO    : Updated Thermal Rating: on line 1843-7413 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19159
% INFO    : Updated Thermal Rating: on line 5527-1318 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 55154
% INFO    : Updated Thermal Rating: on line 5239-1318 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 351
% INFO    : Updated Thermal Rating: on line 5527-9073 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 59190
% INFO    : Updated Thermal Rating: on line 9073-10857 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 262
% INFO    : Updated Thermal Rating: on line 12037-5527 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 3269-3091 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 490
% INFO    : Updated Thermal Rating: on line 12425-3859 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8699
% INFO    : Updated Thermal Rating: on line 13657-3483 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 111679
% INFO    : Updated Thermal Rating: on line 13657-8214 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6958
% INFO    : Updated Thermal Rating: on line 8214-1933 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 90942
% INFO    : Updated Thermal Rating: on line 8330-9918 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 111679
% INFO    : Updated Thermal Rating: on line 9918-11992 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7054
% INFO    : Updated Thermal Rating: on line 3977-8330 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 372
% INFO    : Updated Thermal Rating: on line 11992-4374 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 88206
% INFO    : Updated Thermal Rating: on line 7160-8831 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 43152
% INFO    : Updated Thermal Rating: on line 9985-7160 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 572
% INFO    : Updated Thermal Rating: on line 7160-10822 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2014
% INFO    : Updated Thermal Rating: on line 1669-7266 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 70604
% INFO    : Updated Thermal Rating: on line 12370-7266 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2002
% INFO    : Updated Thermal Rating: on line 1669-5392 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 72634
% INFO    : Updated Thermal Rating: on line 11150-5392 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17814
% INFO    : Updated Thermal Rating: on line 171-4812 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 78969
% INFO    : Updated Thermal Rating: on line 636-171 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2697
% INFO    : Updated Thermal Rating: on line 10097-6536 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 75483
% INFO    : Updated Thermal Rating: on line 10097-12370 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1855
% INFO    : Updated Thermal Rating: on line 12370-4812 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1824
% INFO    : Updated Thermal Rating: on line 2675-1175 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 1175-3358 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1057
% INFO    : Updated Thermal Rating: on line 1175-11150 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5529
% INFO    : Updated Thermal Rating: on line 1175-5954 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1196
% INFO    : Updated Thermal Rating: on line 12932-1669 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 3438-8136 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11772
% INFO    : Updated Thermal Rating: on line 9201-4395 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1038
% INFO    : Updated Thermal Rating: on line 4395-13445 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8995
% INFO    : Updated Thermal Rating: on line 6153-9717 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 9717-2277 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 878
% INFO    : Updated Thermal Rating: on line 9717-2277 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 788
% INFO    : Updated Thermal Rating: on line 9717-7682 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 392
% INFO    : Updated Thermal Rating: on line 9210-11258 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 11258-790 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 998
% INFO    : Updated Thermal Rating: on line 1052-1711 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 79250
% INFO    : Updated Thermal Rating: on line 679-1711 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3083
% INFO    : Updated Thermal Rating: on line 4404-1052 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 66746
% INFO    : Updated Thermal Rating: on line 6112-12028 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13138
% INFO    : Updated Thermal Rating: on line 11185-12028 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2472
% INFO    : Updated Thermal Rating: on line 7298-12028 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4086
% INFO    : Updated Thermal Rating: on line 4111-12028 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2476
% INFO    : Updated Thermal Rating: on line 4111-12028 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2672
% INFO    : Updated Thermal Rating: on line 679-12028 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 28994
% INFO    : Updated Thermal Rating: on line 10415-12028 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5624
% INFO    : Updated Thermal Rating: on line 3629-6054 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 239
% INFO    : Updated Thermal Rating: on line 12725-3629 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 558
% INFO    : Updated Thermal Rating: on line 11778-8989 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 3436-8989 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 544
% INFO    : Updated Thermal Rating: on line 7269-2521 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 2521-10009 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 567
% INFO    : Updated Thermal Rating: on line 5040-2521 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 598
% INFO    : Updated Thermal Rating: on line 12677-3818 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 774
% INFO    : Updated Thermal Rating: on line 7746-10319 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 222
% INFO    : Updated Thermal Rating: on line 10319-3818 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 686
% INFO    : Updated Thermal Rating: on line 11266-2378 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 2378-1223 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8010
% INFO    : Updated Thermal Rating: on line 2378-1216 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2425
% INFO    : Updated Thermal Rating: on line 10297-2378 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1705
% INFO    : Updated Thermal Rating: on line 2378-923 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3806
% INFO    : Updated Thermal Rating: on line 2026-3231 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2641
% INFO    : Updated Thermal Rating: on line 8073-3231 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 784
% INFO    : Updated Thermal Rating: on line 3231-13543 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1025
% INFO    : Updated Thermal Rating: on line 2905-3709 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 824
% INFO    : Updated Thermal Rating: on line 3709-6645 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1430
% INFO    : Updated Thermal Rating: on line 9832-12087 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 8073-12087 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1203
% INFO    : Updated Thermal Rating: on line 8073-12087 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1183
% INFO    : Updated Thermal Rating: on line 12087-2905 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6211
% INFO    : Updated Thermal Rating: on line 12087-3438 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5095
% INFO    : Updated Thermal Rating: on line 7060-4801 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9045
% INFO    : Updated Thermal Rating: on line 12370-7060 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4930
% INFO    : Updated Thermal Rating: on line 7060-12766 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 758
% INFO    : Updated Thermal Rating: on line 12922-1825 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 110467
% INFO    : Updated Thermal Rating: on line 4579-1825 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23328
% INFO    : Updated Thermal Rating: on line 12117-4442 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1869
% INFO    : Updated Thermal Rating: on line 2805-12117 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24622
% INFO    : Updated Thermal Rating: on line 7405-2761 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10728
% INFO    : Updated Thermal Rating: on line 4579-2761 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23704
% INFO    : Updated Thermal Rating: on line 607-12922 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13452
% INFO    : Updated Thermal Rating: on line 7728-3048 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2793
% INFO    : Updated Thermal Rating: on line 7728-10104 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2847
% INFO    : Updated Thermal Rating: on line 5355-3048 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 806
% INFO    : Updated Thermal Rating: on line 2604-10104 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1277
% INFO    : Updated Thermal Rating: on line 3040-6222 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16269
% INFO    : Updated Thermal Rating: on line 6714-8783 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15965
% INFO    : Updated Thermal Rating: on line 5615-7265 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 7265-10893 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16076
% INFO    : Updated Thermal Rating: on line 7265-10540 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15777
% INFO    : Updated Thermal Rating: on line 12370-10893 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1360
% INFO    : Updated Thermal Rating: on line 9171-7894 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 6302-7894 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 41138
% INFO    : Updated Thermal Rating: on line 6302-12680 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 176
% INFO    : Updated Thermal Rating: on line 2151-7894 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 44231
% INFO    : Updated Thermal Rating: on line 5239-2151 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 582
% INFO    : Updated Thermal Rating: on line 9977-9399 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1288
% INFO    : Updated Thermal Rating: on line 7234-9399 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9095
% INFO    : Updated Thermal Rating: on line 12602-7809 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 7809-4442 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2523
% INFO    : Updated Thermal Rating: on line 7809-2680 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2317
% INFO    : Updated Thermal Rating: on line 7809-7522 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 374
% INFO    : Updated Thermal Rating: on line 7809-3433 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1048
% INFO    : Updated Thermal Rating: on line 3987-7657 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 9316-12813 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 2911-7657 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6827
% INFO    : Updated Thermal Rating: on line 8551-12813 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13795
% INFO    : Updated Thermal Rating: on line 3266-13076 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10412
% INFO    : Updated Thermal Rating: on line 1540-13076 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9667
% INFO    : Updated Thermal Rating: on line 2805-2680 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1820
% INFO    : Updated Thermal Rating: on line 2081-3719 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 3719-4300 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15906
% INFO    : Updated Thermal Rating: on line 884-11210 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 60064
% INFO    : Updated Thermal Rating: on line 7007-8597 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12638
% INFO    : Updated Thermal Rating: on line 7007-3542 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12861
% INFO    : Updated Thermal Rating: on line 12370-8597 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4746
% INFO    : Updated Thermal Rating: on line 7199-3542 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 488
% INFO    : Updated Thermal Rating: on line 3263-7199 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 33551
% INFO    : Updated Thermal Rating: on line 12488-1023 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 93513
% INFO    : Updated Thermal Rating: on line 12488-6112 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 95886
% INFO    : Updated Thermal Rating: on line 7298-1023 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5309
% INFO    : Updated Thermal Rating: on line 6837-431 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1902
% INFO    : Updated Thermal Rating: on line 13355-6837 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 110467
% INFO    : Updated Thermal Rating: on line 3716-6837 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112127
% INFO    : Updated Thermal Rating: on line 11771-491 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14372
% INFO    : Updated Thermal Rating: on line 10460-9398 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1562
% INFO    : Updated Thermal Rating: on line 10460-12676 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10998
% INFO    : Updated Thermal Rating: on line 7176-11771 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1535
% INFO    : Updated Thermal Rating: on line 11771-7002 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 10036-1069 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 1069-4681 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8505
% INFO    : Updated Thermal Rating: on line 1069-3358 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8364
% INFO    : Updated Thermal Rating: on line 5176-9806 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 3755-9806 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5763
% INFO    : Updated Thermal Rating: on line 3755-9806 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5869
% INFO    : Updated Thermal Rating: on line 3064-9806 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10673
% INFO    : Updated Thermal Rating: on line 9806-3271 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2303
% INFO    : Updated Thermal Rating: on line 9806-3040 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5853
% INFO    : Updated Thermal Rating: on line 9806-7399 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4487
% INFO    : Updated Thermal Rating: on line 9806-1105 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7709
% INFO    : Updated Thermal Rating: on line 9806-242 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26322
% INFO    : Updated Thermal Rating: on line 3883-8131 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4345
% INFO    : Updated Thermal Rating: on line 2189-150 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5367
% INFO    : Updated Thermal Rating: on line 2189-150 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5113
% INFO    : Updated Thermal Rating: on line 8492-6249 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1772
% INFO    : Updated Thermal Rating: on line 1078-6249 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2610
% INFO    : Updated Thermal Rating: on line 8492-2426 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1794
% INFO    : Updated Thermal Rating: on line 2426-11261 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11498
% INFO    : Updated Thermal Rating: on line 7836-4236 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 678-10009 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 3269-10009 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 518
% INFO    : Updated Thermal Rating: on line 3269-10009 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 465
% INFO    : Updated Thermal Rating: on line 6381-12293 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1544
% INFO    : Updated Thermal Rating: on line 6381-12293 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1770
% INFO    : Updated Thermal Rating: on line 1624-12293 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1146
% INFO    : Updated Thermal Rating: on line 1624-12293 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1125
% INFO    : Updated Thermal Rating: on line 9094-8073 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 37132
% INFO    : Updated Thermal Rating: on line 11486-9094 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 562
% INFO    : Updated Thermal Rating: on line 13277-11485 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 949
% INFO    : Updated Thermal Rating: on line 13063-13277 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 11485-8073 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 40119
% INFO    : Updated Thermal Rating: on line 3927-8073 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1082
% INFO    : Updated Thermal Rating: on line 9398-3927 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2670
% INFO    : Updated Thermal Rating: on line 9398-8073 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 828
% INFO    : Updated Thermal Rating: on line 9398-8073 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 892
% INFO    : Updated Thermal Rating: on line 8073-6891 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 160
% INFO    : Updated Thermal Rating: on line 8073-12351 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 237
% INFO    : Updated Thermal Rating: on line 8073-13088 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 462
% INFO    : Updated Thermal Rating: on line 8073-38 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 271
% INFO    : Updated Thermal Rating: on line 8073-1357 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 230
% INFO    : Updated Thermal Rating: on line 11024-8073 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1068
% INFO    : Updated Thermal Rating: on line 8073-13543 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 476
% INFO    : Updated Thermal Rating: on line 8073-13543 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 371
% INFO    : Updated Thermal Rating: on line 4270-7017 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 636
% INFO    : Updated Thermal Rating: on line 973-7017 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1523
% INFO    : Updated Thermal Rating: on line 973-7017 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1628
% INFO    : Updated Thermal Rating: on line 2250-8662 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7165
% INFO    : Updated Thermal Rating: on line 8662-11489 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 279
% INFO    : Updated Thermal Rating: on line 2250-6186 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 597
% INFO    : Updated Thermal Rating: on line 5976-7608 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 825
% INFO    : Updated Thermal Rating: on line 5976-13318 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 593
% INFO    : Updated Thermal Rating: on line 3512-7177 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1045
% INFO    : Updated Thermal Rating: on line 3512-10876 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 777
% INFO    : Updated Thermal Rating: on line 9398-7176 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 9398-9501 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3081
% INFO    : Updated Thermal Rating: on line 5442-7774 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2782
% INFO    : Updated Thermal Rating: on line 7774-11730 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2590
% INFO    : Updated Thermal Rating: on line 9040-10529 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1478
% INFO    : Updated Thermal Rating: on line 5442-10529 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1496
% INFO    : Updated Thermal Rating: on line 8796-10529 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2129
% INFO    : Updated Thermal Rating: on line 4091-5673 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3464
% INFO    : Updated Thermal Rating: on line 8988-4091 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3713
% INFO    : Updated Thermal Rating: on line 569-5673 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3403
% INFO    : Updated Thermal Rating: on line 569-5790 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3784
% INFO    : Updated Thermal Rating: on line 3188-3858 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3483
% INFO    : Updated Thermal Rating: on line 4213-3858 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17233
% INFO    : Updated Thermal Rating: on line 3188-8564 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3126
% INFO    : Updated Thermal Rating: on line 10166-8564 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1424
% INFO    : Updated Thermal Rating: on line 8190-3188 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 3436-4989 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1506
% INFO    : Updated Thermal Rating: on line 6728-4989 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 375
% INFO    : Updated Thermal Rating: on line 913-3436 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 3436-10380 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1462
% INFO    : Updated Thermal Rating: on line 3436-11139 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 258
% INFO    : Updated Thermal Rating: on line 2200-10380 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 12480-8339 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2825
% INFO    : Updated Thermal Rating: on line 10857-8339 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 350
% INFO    : Updated Thermal Rating: on line 11575-12674 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 2568-7937 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 907
% INFO    : Updated Thermal Rating: on line 7937-10729 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 602
% INFO    : Updated Thermal Rating: on line 2826-12674 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 37519
% INFO    : Updated Thermal Rating: on line 2826-12680 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 263
% INFO    : Updated Thermal Rating: on line 2568-12674 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 37904
% INFO    : Updated Thermal Rating: on line 3014-9100 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 2194-11185 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4658
% INFO    : Updated Thermal Rating: on line 11993-4073 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 132626
% INFO    : Updated Thermal Rating: on line 11139-11993 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 570
% INFO    : Updated Thermal Rating: on line 10708-11139 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 2338-2658 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 914
% INFO    : Updated Thermal Rating: on line 16-2338 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1861
% INFO    : Updated Thermal Rating: on line 8080-7465 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 12933-7465 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 690
% INFO    : Updated Thermal Rating: on line 12933-7465 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 619
% INFO    : Updated Thermal Rating: on line 12933-7465 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 607
% INFO    : Updated Thermal Rating: on line 6618-7465 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 862
% INFO    : Updated Thermal Rating: on line 7465-5264 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 346
% INFO    : Updated Thermal Rating: on line 7465-7862 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 307
% INFO    : Updated Thermal Rating: on line 7465-653 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 453
% INFO    : Updated Thermal Rating: on line 7465-6493 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 603
% INFO    : Updated Thermal Rating: on line 7465-10830 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 382
% INFO    : Updated Thermal Rating: on line 758-11139 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1523
% INFO    : Updated Thermal Rating: on line 13429-943 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 887
% INFO    : Updated Thermal Rating: on line 943-10857 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 101
% INFO    : Updated Thermal Rating: on line 2549-6902 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 1979-9985 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 356-3269 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 105-642 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2059
% INFO    : Updated Thermal Rating: on line 8575-105 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1428
% INFO    : Updated Thermal Rating: on line 9846-105 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1402
% INFO    : Updated Thermal Rating: on line 105-4111 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1845
% INFO    : Updated Thermal Rating: on line 105-4111 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1881
% INFO    : Updated Thermal Rating: on line 2110-5239 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 1429-5239 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 666
% INFO    : Updated Thermal Rating: on line 10848-5239 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1899
% INFO    : Updated Thermal Rating: on line 5239-2466 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1219
% INFO    : Updated Thermal Rating: on line 6907-1610 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 1610-1588 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 310
% INFO    : Updated Thermal Rating: on line 5040-1610 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 496
% INFO    : Updated Thermal Rating: on line 2194-10290 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2099
% INFO    : Updated Thermal Rating: on line 2194-10290 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2143
% INFO    : Updated Thermal Rating: on line 7872-10290 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2695
% INFO    : Updated Thermal Rating: on line 6546-10290 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2747
% INFO    : Updated Thermal Rating: on line 884-6381 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8372
% INFO    : Updated Thermal Rating: on line 884-6381 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8559
% INFO    : Updated Thermal Rating: on line 4100-11338 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 551
% INFO    : Updated Thermal Rating: on line 4100-11338 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 561
% INFO    : Updated Thermal Rating: on line 3161-4100 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2270
% INFO    : Updated Thermal Rating: on line 9248-4100 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8221
% INFO    : Updated Thermal Rating: on line 4100-10950 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3101
% INFO    : Updated Thermal Rating: on line 4100-13418 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1240
% INFO    : Updated Thermal Rating: on line 4100-13038 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 457
% INFO    : Updated Thermal Rating: on line 4100-7546 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1098
% INFO    : Updated Thermal Rating: on line 4100-2406 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1079
% INFO    : Updated Thermal Rating: on line 8853-7298 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1190
% INFO    : Updated Thermal Rating: on line 8853-7298 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1053
% INFO    : Updated Thermal Rating: on line 8853-7298 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1129
% INFO    : Updated Thermal Rating: on line 8853-7298 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1153
% INFO    : Updated Thermal Rating: on line 2812-1780 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2089
% INFO    : Updated Thermal Rating: on line 1780-4404 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3393
% INFO    : Updated Thermal Rating: on line 2812-6546 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1849
% INFO    : Updated Thermal Rating: on line 2812-9129 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1814
% INFO    : Updated Thermal Rating: on line 9129-4404 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3464
% INFO    : Updated Thermal Rating: on line 2812-7872 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1781
% INFO    : Updated Thermal Rating: on line 7208-3755 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6709
% INFO    : Updated Thermal Rating: on line 3755-1866 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15280
% INFO    : Updated Thermal Rating: on line 1515-3755 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 10166-5552 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1450
% INFO    : Updated Thermal Rating: on line 11202-10166 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11045
% INFO    : Updated Thermal Rating: on line 10166-1216 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18401
% INFO    : Updated Thermal Rating: on line 10166-10297 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7763
% INFO    : Updated Thermal Rating: on line 10166-4760 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8372
% INFO    : Updated Thermal Rating: on line 13435-3708 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9767
% INFO    : Updated Thermal Rating: on line 5544-13435 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1250
% INFO    : Updated Thermal Rating: on line 2189-5564 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 3883-5564 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 7532-12942 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 12942-2788 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3346
% INFO    : Updated Thermal Rating: on line 8689-12942 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 681
% INFO    : Updated Thermal Rating: on line 12942-3626 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 463
% INFO    : Updated Thermal Rating: on line 1159-2788 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 2788-3818 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 315
% INFO    : Updated Thermal Rating: on line 12471-5564 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 6116-7702 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 7702-13161 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17378
% INFO    : Updated Thermal Rating: on line 7702-10729 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17032
% INFO    : Updated Thermal Rating: on line 4334-3266 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 8398-9903 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 5953-6748 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17809
% INFO    : Updated Thermal Rating: on line 5953-12924 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18064
% INFO    : Updated Thermal Rating: on line 12924-3263 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4414
% INFO    : Updated Thermal Rating: on line 13637-5953 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 7380-413 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2295
% INFO    : Updated Thermal Rating: on line 5083-8627 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 8627-13452 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 77435
% INFO    : Updated Thermal Rating: on line 8627-8977 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 92015
% INFO    : Updated Thermal Rating: on line 3703-13452 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 397
% INFO    : Updated Thermal Rating: on line 758-8977 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 651
% INFO    : Updated Thermal Rating: on line 3703-9201 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 423
% INFO    : Updated Thermal Rating: on line 3703-11383 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4548
% INFO    : Updated Thermal Rating: on line 3703-6551 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7273
% INFO    : Updated Thermal Rating: on line 3703-13445 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 499
% INFO    : Updated Thermal Rating: on line 3703-13445 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 509
% INFO    : Updated Thermal Rating: on line 8575-8853 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1226
% INFO    : Updated Thermal Rating: on line 8575-8853 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1203
% INFO    : Updated Thermal Rating: on line 12619-5104 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 12680-431 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 32802
% INFO    : Updated Thermal Rating: on line 5752-1704 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2032
% INFO    : Updated Thermal Rating: on line 5752-12680 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1760
% INFO    : Updated Thermal Rating: on line 7023-11094 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 550
% INFO    : Updated Thermal Rating: on line 7023-11094 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 592
% INFO    : Updated Thermal Rating: on line 5355-5991 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2070
% INFO    : Updated Thermal Rating: on line 5355-6001 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1190
% INFO    : Updated Thermal Rating: on line 5355-10389 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6858
% INFO    : Updated Thermal Rating: on line 5355-2604 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 469
% INFO    : Updated Thermal Rating: on line 5355-4813 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1706
% INFO    : Updated Thermal Rating: on line 5355-4813 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1793
% INFO    : Updated Thermal Rating: on line 10857-5104 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 257
% INFO    : Updated Thermal Rating: on line 1904-5104 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2048
% INFO    : Updated Thermal Rating: on line 11261-1240 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19388
% INFO    : Updated Thermal Rating: on line 10857-1240 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 364
% INFO    : Updated Thermal Rating: on line 2678-1078 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 484
% INFO    : Updated Thermal Rating: on line 2658-7823 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 631
% INFO    : Updated Thermal Rating: on line 11476-3054 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 169332
% INFO    : Updated Thermal Rating: on line 3778-3054 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 776
% INFO    : Updated Thermal Rating: on line 9767-11489 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 13355-11489 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 490
% INFO    : Updated Thermal Rating: on line 3945-6853 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3956
% INFO    : Updated Thermal Rating: on line 3977-6853 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 722
% INFO    : Updated Thermal Rating: on line 9485-3117 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 512
% INFO    : Updated Thermal Rating: on line 13248-9173 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6321
% INFO    : Updated Thermal Rating: on line 6676-13248 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1557
% INFO    : Updated Thermal Rating: on line 11511-9173 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6432
% INFO    : Updated Thermal Rating: on line 11511-4465 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 627
% INFO    : Updated Thermal Rating: on line 6556-4531 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 11981-9173 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 4531-9173 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1828
% INFO    : Updated Thermal Rating: on line 10144-6676 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 585
% INFO    : Updated Thermal Rating: on line 4531-252 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 358
% INFO    : Updated Thermal Rating: on line 13063-3769 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1166
% INFO    : Updated Thermal Rating: on line 3769-6493 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 524
% INFO    : Updated Thermal Rating: on line 7410-9398 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 5345-1588 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22941
% INFO    : Updated Thermal Rating: on line 8645-12391 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 12515-8645 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 12391-8405 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2387
% INFO    : Updated Thermal Rating: on line 10596-12515 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1979
% INFO    : Updated Thermal Rating: on line 12885-1564 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 111124
% INFO    : Updated Thermal Rating: on line 6041-12885 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3698
% INFO    : Updated Thermal Rating: on line 7651-1564 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 111124
% INFO    : Updated Thermal Rating: on line 7651-10129 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10076
% INFO    : Updated Thermal Rating: on line 3552-1564 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 2947-13578 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16759
% INFO    : Updated Thermal Rating: on line 4270-13578 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16434
% INFO    : Updated Thermal Rating: on line 659-10054 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 10054-9962 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1531
% INFO    : Updated Thermal Rating: on line 10054-12676 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 974
% INFO    : Updated Thermal Rating: on line 13084-9371 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 50742
% INFO    : Updated Thermal Rating: on line 13084-895 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 38851
% INFO    : Updated Thermal Rating: on line 13084-8847 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 54140
% INFO    : Updated Thermal Rating: on line 1547-13084 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 8847-791 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 997
% INFO    : Updated Thermal Rating: on line 4032-6469 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4306
% INFO    : Updated Thermal Rating: on line 4032-11899 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4647
% INFO    : Updated Thermal Rating: on line 1111-6469 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4359
% INFO    : Updated Thermal Rating: on line 1111-2851 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1920
% INFO    : Updated Thermal Rating: on line 4737-6469 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 11338-10013 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 836
% INFO    : Updated Thermal Rating: on line 11338-93 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 669
% INFO    : Updated Thermal Rating: on line 9600-11338 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 38-11338 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 241
% INFO    : Updated Thermal Rating: on line 5787-13161 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 631
% INFO    : Updated Thermal Rating: on line 12933-6618 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1206
% INFO    : Updated Thermal Rating: on line 5563-6618 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 1938-8769 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 12950-12007 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 949
% INFO    : Updated Thermal Rating: on line 5780-10263 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13059
% INFO    : Updated Thermal Rating: on line 4579-10263 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3159
% INFO    : Updated Thermal Rating: on line 5780-10495 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14083
% INFO    : Updated Thermal Rating: on line 4579-10495 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3216
% INFO    : Updated Thermal Rating: on line 6923-5780 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 6110-12950 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 12022-12950 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1319
% INFO    : Updated Thermal Rating: on line 9821-12950 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1297
% INFO    : Updated Thermal Rating: on line 8781-12950 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1398
% INFO    : Updated Thermal Rating: on line 12950-7225 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 880
% INFO    : Updated Thermal Rating: on line 6289-7746 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 7109-7746 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1415
% INFO    : Updated Thermal Rating: on line 7746-3645 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 585
% INFO    : Updated Thermal Rating: on line 2555-12898 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 12725-12898 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1551
% INFO    : Updated Thermal Rating: on line 10926-12898 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1580
% INFO    : Updated Thermal Rating: on line 10279-2173 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 10701-12022 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 9821-1446 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 2173-1446 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 3924-1525 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 551-3924 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 1525-625 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 625-8781 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 4562-10042 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 7522-726 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 4562-551 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 5876-1742 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 472-5876 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 657
% INFO    : Updated Thermal Rating: on line 1742-5432 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 5432-7109 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 726-10701 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 11798-10939 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11053
% INFO    : Updated Thermal Rating: on line 2194-463 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2291
% INFO    : Updated Thermal Rating: on line 4579-8523 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5422
% INFO    : Updated Thermal Rating: on line 4579-2613 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 35346
% INFO    : Updated Thermal Rating: on line 12972-11637 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 13429-11637 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 111679
% INFO    : Updated Thermal Rating: on line 4327-11637 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 111679
% INFO    : Updated Thermal Rating: on line 4327-12680 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 785
% INFO    : Updated Thermal Rating: on line 6345-7520 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 36037
% INFO    : Updated Thermal Rating: on line 2622-7520 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 36258
% INFO    : Updated Thermal Rating: on line 8120-7520 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 36995
% INFO    : Updated Thermal Rating: on line 9021-7520 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 37819
% INFO    : Updated Thermal Rating: on line 13102-7520 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 38616
% INFO    : Updated Thermal Rating: on line 7520-9943 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 34589
% INFO    : Updated Thermal Rating: on line 15-7520 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 4912-7520 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 33796
% INFO    : Updated Thermal Rating: on line 7006-2622 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1169
% INFO    : Updated Thermal Rating: on line 8120-8542 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3291
% INFO    : Updated Thermal Rating: on line 9021-7335 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2554
% INFO    : Updated Thermal Rating: on line 11303-790 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 2194-2850 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 40451
% INFO    : Updated Thermal Rating: on line 1523-2850 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 40968
% INFO    : Updated Thermal Rating: on line 1283-2850 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24570
% INFO    : Updated Thermal Rating: on line 6010-1991 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4331
% INFO    : Updated Thermal Rating: on line 3652-10760 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6191
% INFO    : Updated Thermal Rating: on line 8628-3426 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 3426-3626 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 344
% INFO    : Updated Thermal Rating: on line 3426-5199 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 308
% INFO    : Updated Thermal Rating: on line 8769-12458 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7406
% INFO    : Updated Thermal Rating: on line 1671-12458 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 839
% INFO    : Updated Thermal Rating: on line 1718-8769 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 557
% INFO    : Updated Thermal Rating: on line 5736-10359 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1354
% INFO    : Updated Thermal Rating: on line 139-10359 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 411
% INFO    : Updated Thermal Rating: on line 10359-7759 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1808
% INFO    : Updated Thermal Rating: on line 7909-3749 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 169332
% INFO    : Updated Thermal Rating: on line 3749-803 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1491
% INFO    : Updated Thermal Rating: on line 7909-8405 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 169332
% INFO    : Updated Thermal Rating: on line 3818-3027 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 293
% INFO    : Updated Thermal Rating: on line 139-3027 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 344
% INFO    : Updated Thermal Rating: on line 4838-1824 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 11552-3161 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2993
% INFO    : Updated Thermal Rating: on line 11552-6891 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3223
% INFO    : Updated Thermal Rating: on line 8244-13340 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4566
% INFO    : Updated Thermal Rating: on line 3727-13340 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1860
% INFO    : Updated Thermal Rating: on line 8244-4588 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4650
% INFO    : Updated Thermal Rating: on line 3727-6323 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1155
% INFO    : Updated Thermal Rating: on line 9136-10857 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 10857-8862 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 435
% INFO    : Updated Thermal Rating: on line 10857-12228 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 670
% INFO    : Updated Thermal Rating: on line 8599-5040 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 5040-13459 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1064
% INFO    : Updated Thermal Rating: on line 3945-9086 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 582
% INFO    : Updated Thermal Rating: on line 3945-3977 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 685
% INFO    : Updated Thermal Rating: on line 11089-8210 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2737
% INFO    : Updated Thermal Rating: on line 7359-11089 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 535
% INFO    : Updated Thermal Rating: on line 4600-8210 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2727
% INFO    : Updated Thermal Rating: on line 3157-8210 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 1795-7852 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1683
% INFO    : Updated Thermal Rating: on line 6775-1795 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 111679
% INFO    : Updated Thermal Rating: on line 13173-7852 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2314
% INFO    : Updated Thermal Rating: on line 8014-7852 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 7852-8667 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1936
% INFO    : Updated Thermal Rating: on line 4854-7852 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 217
% INFO    : Updated Thermal Rating: on line 13173-2992 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2231
% INFO    : Updated Thermal Rating: on line 9985-13173 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 605
% INFO    : Updated Thermal Rating: on line 4591-13173 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 11769-13173 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1257
% INFO    : Updated Thermal Rating: on line 3269-2992 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 906
% INFO    : Updated Thermal Rating: on line 9011-2992 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 6775-9716 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 111679
% INFO    : Updated Thermal Rating: on line 7025-6775 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 9985-8667 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1822
% INFO    : Updated Thermal Rating: on line 9985-3516 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9675
% INFO    : Updated Thermal Rating: on line 9985-9672 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 498
% INFO    : Updated Thermal Rating: on line 3269-9716 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1790
% INFO    : Updated Thermal Rating: on line 3269-13358 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 866
% INFO    : Updated Thermal Rating: on line 13216-689 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 689-1837 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24990
% INFO    : Updated Thermal Rating: on line 7603-255 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 255-11434 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25440
% INFO    : Updated Thermal Rating: on line 10145-1671 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1895
% INFO    : Updated Thermal Rating: on line 10145-12370 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 368
% INFO    : Updated Thermal Rating: on line 1671-37 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2314
% INFO    : Updated Thermal Rating: on line 1671-8886 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2266
% INFO    : Updated Thermal Rating: on line 5345-1671 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1931
% INFO    : Updated Thermal Rating: on line 11548-1671 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 1671-3692 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 854
% INFO    : Updated Thermal Rating: on line 1671-4098 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2358
% INFO    : Updated Thermal Rating: on line 1837-37 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2300
% INFO    : Updated Thermal Rating: on line 8886-10370 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3655
% INFO    : Updated Thermal Rating: on line 11434-10370 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3963
% INFO    : Updated Thermal Rating: on line 1824-1480 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2639
% INFO    : Updated Thermal Rating: on line 4835-4568 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4183
% INFO    : Updated Thermal Rating: on line 4835-4568 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4272
% INFO    : Updated Thermal Rating: on line 11826-10596 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 2239-12284 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 11826-12284 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 8670-12284 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 420
% INFO    : Updated Thermal Rating: on line 9111-12284 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 716
% INFO    : Updated Thermal Rating: on line 7359-5736 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3545
% INFO    : Updated Thermal Rating: on line 2915-7359 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 9423-12804 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 627
% INFO    : Updated Thermal Rating: on line 12804-973 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14156
% INFO    : Updated Thermal Rating: on line 7823-7380 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 169332
% INFO    : Updated Thermal Rating: on line 11730-3692 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1255
% INFO    : Updated Thermal Rating: on line 13364-11730 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 2463-5869 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 12546-5869 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 59952
% INFO    : Updated Thermal Rating: on line 5570-12546 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 815
% INFO    : Updated Thermal Rating: on line 8862-5869 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 54676
% INFO    : Updated Thermal Rating: on line 9877-9423 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 111679
% INFO    : Updated Thermal Rating: on line 9877-8171 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 111679
% INFO    : Updated Thermal Rating: on line 10950-4561 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 33551
% INFO    : Updated Thermal Rating: on line 4561-1858 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2886
% INFO    : Updated Thermal Rating: on line 9248-38 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 238
% INFO    : Updated Thermal Rating: on line 9645-10950 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 5045-6287 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6717
% INFO    : Updated Thermal Rating: on line 5045-4854 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1187
% INFO    : Updated Thermal Rating: on line 2472-5045 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 399
% INFO    : Updated Thermal Rating: on line 11562-9894 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 9894-5264 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 32802
% INFO    : Updated Thermal Rating: on line 9894-9962 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 35346
% INFO    : Updated Thermal Rating: on line 2830-13105 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21695
% INFO    : Updated Thermal Rating: on line 4592-2830 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 386
% INFO    : Updated Thermal Rating: on line 7097-1198 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112127
% INFO    : Updated Thermal Rating: on line 9090-1198 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 406
% INFO    : Updated Thermal Rating: on line 7097-11769 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112127
% INFO    : Updated Thermal Rating: on line 3398-7097 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 12426-10685 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 748
% INFO    : Updated Thermal Rating: on line 12867-10685 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1485
% INFO    : Updated Thermal Rating: on line 5954-12426 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 418
% INFO    : Updated Thermal Rating: on line 13642-8302 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 8670-8302 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1263
% INFO    : Updated Thermal Rating: on line 13642-11958 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 1947-13642 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 12710-2 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 9010-3652 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 2-3652 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 1244-2 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8312
% INFO    : Updated Thermal Rating: on line 3818-2545 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3377
% INFO    : Updated Thermal Rating: on line 3818-2545 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3417
% INFO    : Updated Thermal Rating: on line 3818-11951 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4464
% INFO    : Updated Thermal Rating: on line 3818-11951 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4390
% INFO    : Updated Thermal Rating: on line 3818-11951 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4728
% INFO    : Updated Thermal Rating: on line 3818-12944 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8167
% INFO    : Updated Thermal Rating: on line 3818-12233 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8531
% INFO    : Updated Thermal Rating: on line 3818-11995 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7113
% INFO    : Updated Thermal Rating: on line 3818-3851 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 791
% INFO    : Updated Thermal Rating: on line 318-2545 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 318-8789 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 244
% INFO    : Updated Thermal Rating: on line 12755-2545 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 12755-12479 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 263
% INFO    : Updated Thermal Rating: on line 11951-2545 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11538
% INFO    : Updated Thermal Rating: on line 11951-2545 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11357
% INFO    : Updated Thermal Rating: on line 11951-126 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13435
% INFO    : Updated Thermal Rating: on line 6818-12944 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5199
% INFO    : Updated Thermal Rating: on line 5791-12233 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4815
% INFO    : Updated Thermal Rating: on line 6022-5791 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 537
% INFO    : Updated Thermal Rating: on line 12956-11995 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9249
% INFO    : Updated Thermal Rating: on line 12956-126 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9410
% INFO    : Updated Thermal Rating: on line 12120-12956 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 6818-8949 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 280
% INFO    : Updated Thermal Rating: on line 8465-13561 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 3433-13561 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9886
% INFO    : Updated Thermal Rating: on line 472-13561 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10203
% INFO    : Updated Thermal Rating: on line 8794-12379 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24374
% INFO    : Updated Thermal Rating: on line 13094-7635 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 3626-3979 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 631
% INFO    : Updated Thermal Rating: on line 5665-3851 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8864
% INFO    : Updated Thermal Rating: on line 5665-8689 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8978
% INFO    : Updated Thermal Rating: on line 9201-13445 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 932
% INFO    : Updated Thermal Rating: on line 791-12740 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 798
% INFO    : Updated Thermal Rating: on line 1101-791 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 12836-12740 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1902
% INFO    : Updated Thermal Rating: on line 4720-6323 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 11747-6323 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 456
% INFO    : Updated Thermal Rating: on line 11747-6323 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 448
% INFO    : Updated Thermal Rating: on line 6323-10133 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 762
% INFO    : Updated Thermal Rating: on line 5269-2185 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8944
% INFO    : Updated Thermal Rating: on line 2185-11780 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 45081
% INFO    : Updated Thermal Rating: on line 2406-5269 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1312
% INFO    : Updated Thermal Rating: on line 13418-9977 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 65899
% INFO    : Updated Thermal Rating: on line 4308-3778 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 169332
% INFO    : Updated Thermal Rating: on line 6236-3778 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 562
% INFO    : Updated Thermal Rating: on line 3778-7102 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 434
% INFO    : Updated Thermal Rating: on line 3778-2100 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 790
% INFO    : Updated Thermal Rating: on line 415-758 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 758-12836 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2391
% INFO    : Updated Thermal Rating: on line 7420-4115 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 169332
% INFO    : Updated Thermal Rating: on line 1171-7420 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1785
% INFO    : Updated Thermal Rating: on line 9127-540 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1653
% INFO    : Updated Thermal Rating: on line 4115-9127 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 169332
% INFO    : Updated Thermal Rating: on line 540-7091 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 134256
% INFO    : Updated Thermal Rating: on line 16-3402 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3303
% INFO    : Updated Thermal Rating: on line 3859-2169 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 9672-8528 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 4957-3155 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 8568-4957 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 897
% INFO    : Updated Thermal Rating: on line 10822-7204 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 7445-4731 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 12005-6010 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 7882-2295 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 11531-11277 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 11293-7684 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 9940-12239 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 12239-3590 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6761
% INFO    : Updated Thermal Rating: on line 2911-6701 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2292
% INFO    : Updated Thermal Rating: on line 11664-2911 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 2911-4489 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6716
% INFO    : Updated Thermal Rating: on line 1110-7413 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 11728-7413 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 39668
% INFO    : Updated Thermal Rating: on line 11038-7469 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 3708-7469 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 40031
% INFO    : Updated Thermal Rating: on line 7469-10191 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14278
% INFO    : Updated Thermal Rating: on line 6468-1715 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 9560-2295 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10578
% INFO    : Updated Thermal Rating: on line 2295-12853 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1071
% INFO    : Updated Thermal Rating: on line 4046-11277 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10784
% INFO    : Updated Thermal Rating: on line 9952-9560 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1981
% INFO    : Updated Thermal Rating: on line 6334-4046 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1953
% INFO    : Updated Thermal Rating: on line 6256-7684 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 610
% INFO    : Updated Thermal Rating: on line 8794-7684 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 832
% INFO    : Updated Thermal Rating: on line 12444-7862 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5778
% INFO    : Updated Thermal Rating: on line 12444-2851 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5671
% INFO    : Updated Thermal Rating: on line 9212-529 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 529-7366 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6502
% INFO    : Updated Thermal Rating: on line 1841-12936 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 3863-8761 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 12214-8761 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6656
% INFO    : Updated Thermal Rating: on line 3150-7500 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 8100-7500 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7028
% INFO    : Updated Thermal Rating: on line 7277-13318 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 3630-1941 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 12190-8523 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16099
% INFO    : Updated Thermal Rating: on line 8523-11559 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7700
% INFO    : Updated Thermal Rating: on line 6881-7091 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 169332
% INFO    : Updated Thermal Rating: on line 6881-11618 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4017
% INFO    : Updated Thermal Rating: on line 10016-11747 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 1715-11291 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3988
% INFO    : Updated Thermal Rating: on line 1715-1270 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4057
% INFO    : Updated Thermal Rating: on line 7130-6236 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 169332
% INFO    : Updated Thermal Rating: on line 6236-1357 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 517
% INFO    : Updated Thermal Rating: on line 12370-6902 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2182
% INFO    : Updated Thermal Rating: on line 10801-13319 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 10823-2277 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 10129-2277 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 315
% INFO    : Updated Thermal Rating: on line 662-8650 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 127932
% INFO    : Updated Thermal Rating: on line 662-10389 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 132626
% INFO    : Updated Thermal Rating: on line 9555-6001 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5326
% INFO    : Updated Thermal Rating: on line 9555-11034 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 107512
% INFO    : Updated Thermal Rating: on line 9555-9329 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 95764
% INFO    : Updated Thermal Rating: on line 11034-4813 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 948
% INFO    : Updated Thermal Rating: on line 9329-4813 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1021
% INFO    : Updated Thermal Rating: on line 5529-4213 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7502
% INFO    : Updated Thermal Rating: on line 4213-8794 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2233
% INFO    : Updated Thermal Rating: on line 232-5552 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17078
% INFO    : Updated Thermal Rating: on line 232-9100 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3897
% INFO    : Updated Thermal Rating: on line 6800-7208 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 6576-3064 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 1871-8225 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 8225-1402 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6093
% INFO    : Updated Thermal Rating: on line 4192-11865 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 6198-12853 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19261
% INFO    : Updated Thermal Rating: on line 6198-7427 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19482
% INFO    : Updated Thermal Rating: on line 10477-6198 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 12026-6198 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6573
% INFO    : Updated Thermal Rating: on line 8670-3741 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3898
% INFO    : Updated Thermal Rating: on line 1402-8670 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3834
% INFO    : Updated Thermal Rating: on line 9095-8670 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 2051-12853 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3590
% INFO    : Updated Thermal Rating: on line 11044-7427 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 62994
% INFO    : Updated Thermal Rating: on line 11044-12876 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2315
% INFO    : Updated Thermal Rating: on line 3741-13013 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11391
% INFO    : Updated Thermal Rating: on line 12767-1347 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 13284-12767 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 12767-3829 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5159
% INFO    : Updated Thermal Rating: on line 7837-11486 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 7980-9562 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 169332
% INFO    : Updated Thermal Rating: on line 9562-11618 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 169332
% INFO    : Updated Thermal Rating: on line 7980-4807 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1249
% INFO    : Updated Thermal Rating: on line 2614-13102 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3836
% INFO    : Updated Thermal Rating: on line 1513-2614 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 8542-2614 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3653
% INFO    : Updated Thermal Rating: on line 8927-4374 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 31122
% INFO    : Updated Thermal Rating: on line 3505-1933 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27835
% INFO    : Updated Thermal Rating: on line 9943-8927 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17732
% INFO    : Updated Thermal Rating: on line 3505-4912 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3720
% INFO    : Updated Thermal Rating: on line 10262-8542 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 8542-7006 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6119
% INFO    : Updated Thermal Rating: on line 8542-7006 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6191
% INFO    : Updated Thermal Rating: on line 4758-7006 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 7006-10590 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16076
% INFO    : Updated Thermal Rating: on line 7006-6571 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15846
% INFO    : Updated Thermal Rating: on line 7006-139 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 284
% INFO    : Updated Thermal Rating: on line 7006-139 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 255
% INFO    : Updated Thermal Rating: on line 6571-139 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 241
% INFO    : Updated Thermal Rating: on line 10129-11862 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1954
% INFO    : Updated Thermal Rating: on line 1811-11862 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 5491-11301 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6603
% INFO    : Updated Thermal Rating: on line 12113-1429 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 658
% INFO    : Updated Thermal Rating: on line 12113-3053 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 709
% INFO    : Updated Thermal Rating: on line 1904-3053 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1369
% INFO    : Updated Thermal Rating: on line 1888-7366 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 8443-9410 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 10832-9410 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26891
% INFO    : Updated Thermal Rating: on line 11929-7366 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27470
% INFO    : Updated Thermal Rating: on line 12026-2051 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8160
% INFO    : Updated Thermal Rating: on line 12351-7620 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3792
% INFO    : Updated Thermal Rating: on line 13038-7620 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3860
% INFO    : Updated Thermal Rating: on line 2864-7620 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 878-1904 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1176
% INFO    : Updated Thermal Rating: on line 1904-2466 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 730
% INFO    : Updated Thermal Rating: on line 13543-13088 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1859
% INFO    : Updated Thermal Rating: on line 3976-2701 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 2701-4465 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26332
% INFO    : Updated Thermal Rating: on line 2701-9090 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27001
% INFO    : Updated Thermal Rating: on line 8899-11202 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 11094-690 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1326
% INFO    : Updated Thermal Rating: on line 7525-9952 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1732
% INFO    : Updated Thermal Rating: on line 1650-6334 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1702
% INFO    : Updated Thermal Rating: on line 12224-4834 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 12224-1737 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12652
% INFO    : Updated Thermal Rating: on line 4834-923 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12885
% INFO    : Updated Thermal Rating: on line 11383-13114 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 92426
% INFO    : Updated Thermal Rating: on line 11844-7682 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 1581-5954 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 3218-4489 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 12263-3590 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 8591-914 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 4976-10890 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 3241-12680 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6514
% INFO    : Updated Thermal Rating: on line 2472-3241 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2075
% INFO    : Updated Thermal Rating: on line 12680-3716 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1967
% INFO    : Updated Thermal Rating: on line 173-13579 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 82735
% INFO    : Updated Thermal Rating: on line 12680-173 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8312
% INFO    : Updated Thermal Rating: on line 4813-8368 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8444
% INFO    : Updated Thermal Rating: on line 8988-5436 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2478
% INFO    : Updated Thermal Rating: on line 4098-8988 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2409
% INFO    : Updated Thermal Rating: on line 11744-3626 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 139-554 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2833
% INFO    : Updated Thermal Rating: on line 12479-139 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 36037
% INFO    : Updated Thermal Rating: on line 8789-139 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 36258
% INFO    : Updated Thermal Rating: on line 13553-139 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 554-4079 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 36995
% INFO    : Updated Thermal Rating: on line 5199-4079 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 37819
% INFO    : Updated Thermal Rating: on line 3373-4079 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 8235-1718 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 3660-8551 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 80914
% INFO    : Updated Thermal Rating: on line 3660-12214 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 108472
% INFO    : Updated Thermal Rating: on line 1540-8100 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 108472
% INFO    : Updated Thermal Rating: on line 1971-3660 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 3660-1540 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 3175-1540 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 2722-12881 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9015
% INFO    : Updated Thermal Rating: on line 11559-2722 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3323
% INFO    : Updated Thermal Rating: on line 2495-12881 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5563
% INFO    : Updated Thermal Rating: on line 4250-2495 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 11899-1213 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2665
% INFO    : Updated Thermal Rating: on line 6041-1213 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2620
% INFO    : Updated Thermal Rating: on line 10623-12370 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 12370-5790 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 633
% INFO    : Updated Thermal Rating: on line 7234-5426 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 45434
% INFO    : Updated Thermal Rating: on line 11318-10860 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1768
% INFO    : Updated Thermal Rating: on line 10860-2100 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1139
% INFO    : Updated Thermal Rating: on line 9581-11318 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1600
% INFO    : Updated Thermal Rating: on line 11780-9581 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1423
% INFO    : Updated Thermal Rating: on line 10111-11318 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 134256
% INFO    : Updated Thermal Rating: on line 11318-1357 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 540
% INFO    : Updated Thermal Rating: on line 8889-4854 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 13104-38 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 7615-38 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 764
% INFO    : Updated Thermal Rating: on line 10144-252 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5800
% INFO    : Updated Thermal Rating: on line 690-252 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5706
% INFO    : Updated Thermal Rating: on line 12628-5098 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 9715-7615 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 3271-11882 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 7027-8674 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3464
% INFO    : Updated Thermal Rating: on line 3040-7027 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3437
% INFO    : Updated Thermal Rating: on line 8674-12510 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 38616
% INFO    : Updated Thermal Rating: on line 4592-12510 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 34589
% INFO    : Updated Thermal Rating: on line 8248-11882 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 143-11882 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 2930-12510 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 2491-6668 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 6668-7855 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5582
% INFO    : Updated Thermal Rating: on line 6668-10133 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5480
% INFO    : Updated Thermal Rating: on line 4096-7855 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 697
% INFO    : Updated Thermal Rating: on line 1480-5759 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1202
% INFO    : Updated Thermal Rating: on line 5759-12964 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 30844
% INFO    : Updated Thermal Rating: on line 12867-12964 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8050
% INFO    : Updated Thermal Rating: on line 11061-12964 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 7617-4496 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 39340
% INFO    : Updated Thermal Rating: on line 7617-6256 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 35346
% INFO    : Updated Thermal Rating: on line 10851-7617 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 5983-878 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1674
% INFO    : Updated Thermal Rating: on line 5983-5570 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1645
% INFO    : Updated Thermal Rating: on line 7224-5983 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 8949-578 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6546
% INFO    : Updated Thermal Rating: on line 4096-5244 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1139
% INFO    : Updated Thermal Rating: on line 5244-578 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6627
% INFO    : Updated Thermal Rating: on line 5907-4096 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 10543-578 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 6961-4407 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 12876-4407 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 9111-4407 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 3347-12228 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3403
% INFO    : Updated Thermal Rating: on line 3347-347 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3346
% INFO    : Updated Thermal Rating: on line 13519-3347 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 13368-1357 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 169332
% INFO    : Updated Thermal Rating: on line 2100-1357 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 542
% INFO    : Updated Thermal Rating: on line 5582-13358 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 111679
% INFO    : Updated Thermal Rating: on line 5582-8568 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 111679
% INFO    : Updated Thermal Rating: on line 35-5582 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 10939-2398 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2534
% INFO    : Updated Thermal Rating: on line 13459-6126 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 946
% INFO    : Updated Thermal Rating: on line 9678-13459 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 803-11883 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 169332
% INFO    : Updated Thermal Rating: on line 2398-10163 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 169332
% INFO    : Updated Thermal Rating: on line 11883-1171 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 169332
% INFO    : Updated Thermal Rating: on line 11883-4807 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 169332
% INFO    : Updated Thermal Rating: on line 11883-10163 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 169332
% INFO    : Updated Thermal Rating: on line 7803-11024 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 320
% INFO    : Updated Thermal Rating: on line 1105-8783 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18272
% INFO    : Updated Thermal Rating: on line 653-11486 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 540
% INFO    : Updated Thermal Rating: on line 5920-1223 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 7546-5544 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 69008
% INFO    : Updated Thermal Rating: on line 12111-7002 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 46233
% INFO    : Updated Thermal Rating: on line 3295-7399 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 1858-10152 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 60709
% INFO    : Updated Thermal Rating: on line 12753-10152 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1343
% INFO    : Updated Thermal Rating: on line 1281-10297 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16548
% INFO    : Updated Thermal Rating: on line 4760-1737 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3873
% INFO    : Updated Thermal Rating: on line 7335-13283 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5752
% INFO    : Updated Thermal Rating: on line 12753-11728 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8755
% INFO    : Updated Thermal Rating: on line 1866-242 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10739
% INFO    : Updated Thermal Rating: on line 10191-5426 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 47473
% INFO    : Updated Thermal Rating: on line 10191-7102 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 47913
% INFO    : Updated Thermal Rating: on line 5182-10191 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 2993-463 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11066
% INFO    : Updated Thermal Rating: on line 2993-10415 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9768
% INFO    : Updated Thermal Rating: on line 12766-7839 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26322
% INFO    : Updated Thermal Rating: on line 2613-12766 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1420
% INFO    : Updated Thermal Rating: on line 11620-3977 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 10848-5787 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27116
% INFO    : Updated Thermal Rating: on line 6489-10848 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 10848-2466 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2763
% INFO    : Updated Thermal Rating: on line 6251-2466 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 7661-6022 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 11150-12955 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 28148
% INFO    : Updated Thermal Rating: on line 4766-5790 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 461-2100 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 169332
% INFO    : Updated Thermal Rating: on line 1968-1244 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 4890-12026 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 10038-6493 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 1132-3645 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 5954-636 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 970
% INFO    : Updated Thermal Rating: on line 5954-8083 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1046
% INFO    : Updated Thermal Rating: on line 10890-13013 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 41763
% INFO    : Updated Thermal Rating: on line 7759-9485 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 633
% INFO    : Updated Thermal Rating: on line 12111-10830 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2153
% INFO    : Updated Thermal Rating: on line 10830-2457 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 11985-4283 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 293
% INFO    : Updated Thermal Rating: on line 12107-11985 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 361
% INFO    : Updated Thermal Rating: on line 691-12130 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 201
% INFO    : Updated Thermal Rating: on line 7433-691 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 261
% INFO    : Updated Thermal Rating: on line 6583-11209 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 442
% INFO    : Updated Thermal Rating: on line 6583-7347 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 742
% INFO    : Updated Thermal Rating: on line 6583-7347 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 661
% INFO    : Updated Thermal Rating: on line 11907-12130 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 158
% INFO    : Updated Thermal Rating: on line 5481-12130 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 236
% INFO    : Updated Thermal Rating: on line 4863-12130 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 710
% INFO    : Updated Thermal Rating: on line 4863-12130 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 699
% INFO    : Updated Thermal Rating: on line 4016-11907 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 324
% INFO    : Updated Thermal Rating: on line 4586-9093 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on line 5635-4586 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 264
% INFO    : Updated Thermal Rating: on line 8013-12639 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 274
% INFO    : Updated Thermal Rating: on line 12639-13176 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 121
% INFO    : Updated Thermal Rating: on line 11885-410 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 76483
% INFO    : Updated Thermal Rating: on line 11885-8262 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1757
% INFO    : Updated Thermal Rating: on line 11885-8355 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1120
% INFO    : Updated Thermal Rating: on line 11885-8355 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 685
% INFO    : Updated Thermal Rating: on line 12257-410 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2393
% INFO    : Updated Thermal Rating: on line 12257-410 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2576
% INFO    : Updated Thermal Rating: on line 410-9385 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 697
% INFO    : Updated Thermal Rating: on line 2751-410 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1214
% INFO    : Updated Thermal Rating: on line 4915-5800 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2386
% INFO    : Updated Thermal Rating: on line 7347-5800 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 184
% INFO    : Updated Thermal Rating: on line 5800-8006 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 422
% INFO    : Updated Thermal Rating: on line 9650-5066 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 343
% INFO    : Updated Thermal Rating: on line 7363-9650 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 738
% INFO    : Updated Thermal Rating: on line 2546-5066 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 401
% INFO    : Updated Thermal Rating: on line 3274-13278 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 798
% INFO    : Updated Thermal Rating: on line 8064-3274 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 609
% INFO    : Updated Thermal Rating: on line 12188-723 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 664
% INFO    : Updated Thermal Rating: on line 723-4016 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13405
% INFO    : Updated Thermal Rating: on line 2720-13255 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 262
% INFO    : Updated Thermal Rating: on line 8009-2720 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1228
% INFO    : Updated Thermal Rating: on line 2720-8553 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 675
% INFO    : Updated Thermal Rating: on line 6439-12663 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 294
% INFO    : Updated Thermal Rating: on line 12663-12107 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 403
% INFO    : Updated Thermal Rating: on line 1067-8828 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1522
% INFO    : Updated Thermal Rating: on line 1067-8828 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1919
% INFO    : Updated Thermal Rating: on line 8828-84 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 664
% INFO    : Updated Thermal Rating: on line 8828-84 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 658
% INFO    : Updated Thermal Rating: on line 6235-3825 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 272
% INFO    : Updated Thermal Rating: on line 5042-6235 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 750
% INFO    : Updated Thermal Rating: on line 10014-6235 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 607
% INFO    : Updated Thermal Rating: on line 11855-6732 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3248
% INFO    : Updated Thermal Rating: on line 6732-2855 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 284
% INFO    : Updated Thermal Rating: on line 6732-2855 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 283
% INFO    : Updated Thermal Rating: on line 5422-6732 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 574
% INFO    : Updated Thermal Rating: on line 265-6732 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 244
% INFO    : Updated Thermal Rating: on line 6732-9134 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 306
% INFO    : Updated Thermal Rating: on line 6732-9420 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 230
% INFO    : Updated Thermal Rating: on line 6439-11855 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 251
% INFO    : Updated Thermal Rating: on line 4035-9154 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 272
% INFO    : Updated Thermal Rating: on line 9154-350 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 228
% INFO    : Updated Thermal Rating: on line 4475-8009 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 409
% INFO    : Updated Thermal Rating: on line 4475-2689 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 335
% INFO    : Updated Thermal Rating: on line 30-13610 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 280
% INFO    : Updated Thermal Rating: on line 30-1176 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1277
% INFO    : Updated Thermal Rating: on line 5042-4984 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2759
% INFO    : Updated Thermal Rating: on line 5042-4984 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2805
% INFO    : Updated Thermal Rating: on line 10014-4984 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 878
% INFO    : Updated Thermal Rating: on line 10014-4984 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 862
% INFO    : Updated Thermal Rating: on line 11857-2244 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1031
% INFO    : Updated Thermal Rating: on line 1051-2244 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2033
% INFO    : Updated Thermal Rating: on line 7959-13610 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1282
% INFO    : Updated Thermal Rating: on line 7959-6720 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1304
% INFO    : Updated Thermal Rating: on line 8553-560 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 752
% INFO    : Updated Thermal Rating: on line 560-1279 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 293
% INFO    : Updated Thermal Rating: on line 13278-3681 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 734
% INFO    : Updated Thermal Rating: on line 13278-9344 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 838
% INFO    : Updated Thermal Rating: on line 1130-13278 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 472
% INFO    : Updated Thermal Rating: on line 10395-10745 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 475
% INFO    : Updated Thermal Rating: on line 1146-5635 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 532
% INFO    : Updated Thermal Rating: on line 9344-1146 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 839
% INFO    : Updated Thermal Rating: on line 1146-10014 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 132
% INFO    : Updated Thermal Rating: on line 13537-1861 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 191
% INFO    : Updated Thermal Rating: on line 604-1861 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 852
% INFO    : Updated Thermal Rating: on line 11857-1861 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 246
% INFO    : Updated Thermal Rating: on line 12257-664 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8085
% INFO    : Updated Thermal Rating: on line 7347-10824 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1335
% INFO    : Updated Thermal Rating: on line 7347-10824 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1362
% INFO    : Updated Thermal Rating: on line 3780-11841 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 764
% INFO    : Updated Thermal Rating: on line 11628-8625 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 752
% INFO    : Updated Thermal Rating: on line 5638-8625 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1467
% INFO    : Updated Thermal Rating: on line 4642-2024 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 688
% INFO    : Updated Thermal Rating: on line 6439-2855 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 214
% INFO    : Updated Thermal Rating: on line 5080-2855 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1726
% INFO    : Updated Thermal Rating: on line 5080-2855 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 743
% INFO    : Updated Thermal Rating: on line 4283-2855 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 798
% INFO    : Updated Thermal Rating: on line 4283-2855 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 869
% INFO    : Updated Thermal Rating: on line 6826-2855 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 691
% INFO    : Updated Thermal Rating: on line 2855-9134 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 385
% INFO    : Updated Thermal Rating: on line 2855-10334 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 307
% INFO    : Updated Thermal Rating: on line 8015-4915 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 686
% INFO    : Updated Thermal Rating: on line 13255-8028 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 237
% INFO    : Updated Thermal Rating: on line 13603-6659 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 403
% INFO    : Updated Thermal Rating: on line 9712-8064 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1327
% INFO    : Updated Thermal Rating: on line 9712-8064 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1350
% INFO    : Updated Thermal Rating: on line 8009-5701 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 895
% INFO    : Updated Thermal Rating: on line 13537-8009 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 829
% INFO    : Updated Thermal Rating: on line 8009-11628 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 661
% INFO    : Updated Thermal Rating: on line 11628-8009 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 672
% INFO    : Updated Thermal Rating: on line 265-5422 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 437
% INFO    : Updated Thermal Rating: on line 13571-11706 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1002
% INFO    : Updated Thermal Rating: on line 13571-3318 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1011
% INFO    : Updated Thermal Rating: on line 12796-11224 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 403
% INFO    : Updated Thermal Rating: on line 187-12796 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 223
% INFO    : Updated Thermal Rating: on line 1051-2689 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 154
% INFO    : Updated Thermal Rating: on line 13537-5701 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 842
% INFO    : Updated Thermal Rating: on line 6174-10974 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1160
% INFO    : Updated Thermal Rating: on line 10974-3318 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1180
% INFO    : Updated Thermal Rating: on line 4863-11706 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1029
% INFO    : Updated Thermal Rating: on line 2387-5481 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 376
% INFO    : Updated Thermal Rating: on line 2387-10395 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 217
% INFO    : Updated Thermal Rating: on line 13362-11209 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 630
% INFO    : Updated Thermal Rating: on line 7347-11209 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1392
% INFO    : Updated Thermal Rating: on line 1067-8238 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 668
% INFO    : Updated Thermal Rating: on line 1067-8238 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 603
% INFO    : Updated Thermal Rating: on line 1115-1067 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 467
% INFO    : Updated Thermal Rating: on line 1115-1067 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 475
% INFO    : Updated Thermal Rating: on line 1115-1067 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 471
% INFO    : Updated Thermal Rating: on line 13603-3002 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 169
% INFO    : Updated Thermal Rating: on line 3002-7433 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 393
% INFO    : Updated Thermal Rating: on line 8238-455 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 263
% INFO    : Updated Thermal Rating: on line 7832-8064 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 528
% INFO    : Updated Thermal Rating: on line 1495-7832 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 284
% INFO    : Updated Thermal Rating: on line 187-9093 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 291
% INFO    : Updated Thermal Rating: on line 9385-12257 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 756
% INFO    : Updated Thermal Rating: on line 9385-12257 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 681
% INFO    : Updated Thermal Rating: on line 8064-13595 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 248
% INFO    : Updated Thermal Rating: on line 5783-13595 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 330
% INFO    : Updated Thermal Rating: on line 10014-13595 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 448
% INFO    : Updated Thermal Rating: on line 13603-7753 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 242
% INFO    : Updated Thermal Rating: on line 7753-12990 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 518
% INFO    : Updated Thermal Rating: on line 6174-10395 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1147
% INFO    : Updated Thermal Rating: on line 6174-10395 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1160
% INFO    : Updated Thermal Rating: on line 6174-10915 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4947
% INFO    : Updated Thermal Rating: on line 6174-3318 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 601
% INFO    : Updated Thermal Rating: on line 3084-1219 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 806
% INFO    : Updated Thermal Rating: on line 13176-3084 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 195
% INFO    : Updated Thermal Rating: on line 3795-13272 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1707
% INFO    : Updated Thermal Rating: on line 8344-7347 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3544
% INFO    : Updated Thermal Rating: on line 8344-7347 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3616
% INFO    : Updated Thermal Rating: on line 5635-3825 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 282
% INFO    : Updated Thermal Rating: on line 3681-5635 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 511
% INFO    : Updated Thermal Rating: on line 8238-5726 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 531
% INFO    : Updated Thermal Rating: on line 963-1495 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 786
% INFO    : Updated Thermal Rating: on line 963-5783 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 710
% INFO    : Updated Thermal Rating: on line 8536-8553 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 995
% INFO    : Updated Thermal Rating: on line 11224-4035 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 843
% INFO    : Updated Thermal Rating: on line 9949-11224 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 235
% INFO    : Updated Thermal Rating: on line 8028-13603 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 254
% INFO    : Updated Thermal Rating: on line 604-1051 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 155
% INFO    : Updated Thermal Rating: on line 3833-2929 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 910
% INFO    : Updated Thermal Rating: on line 6720-3833 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 342
% INFO    : Updated Thermal Rating: on line 5726-3828 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 193
% INFO    : Updated Thermal Rating: on line 5638-2929 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1196
% INFO    : Updated Thermal Rating: on line 2132-13415 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 845
% INFO    : Updated Thermal Rating: on line 4035-1787 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 179
% INFO    : Updated Thermal Rating: on line 9949-4035 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 174
% INFO    : Updated Thermal Rating: on line 3592-3795 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 911
% INFO    : Updated Thermal Rating: on line 10347-3592 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1132
% INFO    : Updated Thermal Rating: on line 8002-8015 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2470
% INFO    : Updated Thermal Rating: on line 8002-8015 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1862
% INFO    : Updated Thermal Rating: on line 10240-8015 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 669
% INFO    : Updated Thermal Rating: on line 8015-10118 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8493
% INFO    : Updated Thermal Rating: on line 8015-10118 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8699
% INFO    : Updated Thermal Rating: on line 11628-8536 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2442
% INFO    : Updated Thermal Rating: on line 11628-3653 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 906
% INFO    : Updated Thermal Rating: on line 1115-3780 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 345
% INFO    : Updated Thermal Rating: on line 7098-1115 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6805
% INFO    : Updated Thermal Rating: on line 7098-1115 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6688
% INFO    : Updated Thermal Rating: on line 8006-2132 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 771
% INFO    : Updated Thermal Rating: on line 8006-2132 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1345
% INFO    : Updated Thermal Rating: on line 8006-6485 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1366
% INFO    : Updated Thermal Rating: on line 187-11321 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 248
% INFO    : Updated Thermal Rating: on line 187-5042 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 430
% INFO    : Updated Thermal Rating: on line 187-5042 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 433
% INFO    : Updated Thermal Rating: on line 187-9340 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 695
% INFO    : Updated Thermal Rating: on line 8355-187 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 455
% INFO    : Updated Thermal Rating: on line 2751-187 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 492
% INFO    : Updated Thermal Rating: on line 2751-187 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 444
% INFO    : Updated Thermal Rating: on line 1787-1727 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 254
% INFO    : Updated Thermal Rating: on line 5080-6439 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 204
% INFO    : Updated Thermal Rating: on line 10095-6439 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 211
% INFO    : Updated Thermal Rating: on line 1130-8064 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 912
% INFO    : Updated Thermal Rating: on line 84-8013 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 613
% INFO    : Updated Thermal Rating: on line 7433-12188 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 209
% INFO    : Updated Thermal Rating: on line 11126-12188 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 312
% INFO    : Updated Thermal Rating: on line 12990-11126 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 501
% INFO    : Updated Thermal Rating: on line 1279-12990 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 392
% INFO    : Updated Thermal Rating: on line 7433-8133 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1960
% INFO    : Updated Thermal Rating: on line 7433-4016 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 135
% INFO    : Updated Thermal Rating: on line 3828-9733 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 538
% INFO    : Updated Thermal Rating: on line 9435-5080 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2148
% INFO    : Updated Thermal Rating: on line 4283-9435 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 936
% INFO    : Updated Thermal Rating: on line 6826-9435 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5426
% INFO    : Updated Thermal Rating: on line 6826-12107 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 365
% INFO    : Updated Thermal Rating: on line 2546-6890 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 456
% INFO    : Updated Thermal Rating: on line 2546-6720 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 375
% INFO    : Updated Thermal Rating: on line 6720-2546 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 382
% INFO    : Updated Thermal Rating: on line 10240-8002 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 766
% INFO    : Updated Thermal Rating: on line 3653-5638 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1144
% INFO    : Updated Thermal Rating: on line 9385-12404 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1714
% INFO    : Updated Thermal Rating: on line 9385-12404 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1791
% INFO    : Updated Thermal Rating: on line 5783-12404 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 366
% INFO    : Updated Thermal Rating: on line 13202-9385 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2852
% INFO    : Updated Thermal Rating: on line 13202-1362 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2900
% INFO    : Updated Thermal Rating: on line 13400-11857 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 387
% INFO    : Updated Thermal Rating: on line 2795-6890 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 349
% INFO    : Updated Thermal Rating: on line 7363-6890 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 280
% INFO    : Updated Thermal Rating: on line 1727-265 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 244
% INFO    : Updated Thermal Rating: on line 9340-11321 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 361
% INFO    : Updated Thermal Rating: on line 9949-11321 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1856
% INFO    : Updated Thermal Rating: on line 12624-11321 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1805
% INFO    : Updated Thermal Rating: on line 8293-9385 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 859
% INFO    : Updated Thermal Rating: on line 1051-9385 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 153
% INFO    : Updated Thermal Rating: on line 2751-9385 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 493
% INFO    : Updated Thermal Rating: on line 2751-9385 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 575
% INFO    : Updated Thermal Rating: on line 2751-9385 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 565
% INFO    : Updated Thermal Rating: on line 8355-5042 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1194
% INFO    : Updated Thermal Rating: on line 10014-5042 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 759
% INFO    : Updated Thermal Rating: on line 9559-5042 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2388
% INFO    : Updated Thermal Rating: on line 11770-2795 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 378
% INFO    : Updated Thermal Rating: on line 1362-8293 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1040
% INFO    : Updated Thermal Rating: on line 4863-3318 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 315
% INFO    : Updated Thermal Rating: on line 1176-6720 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 187
% INFO    : Updated Thermal Rating: on line 1176-11770 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 861
% INFO    : Updated Thermal Rating: on line 1176-11770 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 847
% INFO    : Updated Thermal Rating: on line 350-10095 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 289
% INFO    : Updated Thermal Rating: on line 8355-8262 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1504
% INFO    : Updated Thermal Rating: on line 10915-4117 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10030
% INFO    : Updated Thermal Rating: on line 7098-4117 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9303
% INFO    : Updated Thermal Rating: on line 7098-4117 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9464
% INFO    : Updated Thermal Rating: on line 9559-8355 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2155
% INFO    : Updated Thermal Rating: on line 3423-10240 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1216
% INFO    : Updated Thermal Rating: on line 3423-10240 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1239
% INFO    : Updated Thermal Rating: on line 12624-9949 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2190
% INFO    : Updated Thermal Rating: on line 10347-2024 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2196
% INFO    : Updated Thermal Rating: on line 13400-2751 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 689
% INFO    : Updated Thermal Rating: on line 9134-10334 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 619
% INFO    : Updated Thermal Rating: on line 9134-9420 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 279
% INFO    : Updated Thermal Rating: on line 6459-9848 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3241
% INFO    : Updated Thermal Rating: on line 6459-9848 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3232
% INFO    : Updated Thermal Rating: on line 6459-4348 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2900
% INFO    : Updated Thermal Rating: on line 6459-4348 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2966
% INFO    : Updated Thermal Rating: on line 6459-829 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3534
% INFO    : Updated Thermal Rating: on line 11848-9066 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2865
% INFO    : Updated Thermal Rating: on line 435-9066 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2919
% INFO    : Updated Thermal Rating: on line 5430-12666 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1808
% INFO    : Updated Thermal Rating: on line 5430-829 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1369
% INFO    : Updated Thermal Rating: on line 6869-12432 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1617
% INFO    : Updated Thermal Rating: on line 4348-6869 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7590
% INFO    : Updated Thermal Rating: on line 9779-4099 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 548
% INFO    : Updated Thermal Rating: on line 7590-4099 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 676
% INFO    : Updated Thermal Rating: on line 9848-12573 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2291
% INFO    : Updated Thermal Rating: on line 12573-10686 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2156
% INFO    : Updated Thermal Rating: on line 7706-12584 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9856
% INFO    : Updated Thermal Rating: on line 7706-10323 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10705
% INFO    : Updated Thermal Rating: on line 7706-1986 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9676
% INFO    : Updated Thermal Rating: on line 7706-4099 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 530
% INFO    : Updated Thermal Rating: on line 7706-4099 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 577
% INFO    : Updated Thermal Rating: on line 7706-1313 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 582
% INFO    : Updated Thermal Rating: on line 7706-9934 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 454
% INFO    : Updated Thermal Rating: on line 7706-9934 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 458
% INFO    : Updated Thermal Rating: on line 2356-9066 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 706
% INFO    : Updated Thermal Rating: on line 13314-9066 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 761
% INFO    : Updated Thermal Rating: on line 9066-7201 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4641
% INFO    : Updated Thermal Rating: on line 9066-3036 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5008
% INFO    : Updated Thermal Rating: on line 9066-11556 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1777
% INFO    : Updated Thermal Rating: on line 9066-11556 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1811
% INFO    : Updated Thermal Rating: on line 9066-3430 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 677
% INFO    : Updated Thermal Rating: on line 7196-5295 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4334
% INFO    : Updated Thermal Rating: on line 7196-10686 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5081
% INFO    : Updated Thermal Rating: on line 7196-10686 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4993
% INFO    : Updated Thermal Rating: on line 7957-9934 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2238
% INFO    : Updated Thermal Rating: on line 10922-12432 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9762
% INFO    : Updated Thermal Rating: on line 10922-7049 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1962
% INFO    : Updated Thermal Rating: on line 10922-3389 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1317
% INFO    : Updated Thermal Rating: on line 13262-3430 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 962
% INFO    : Updated Thermal Rating: on line 13575-7049 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1612
% INFO    : Updated Thermal Rating: on line 13575-3389 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2320
% INFO    : Updated Thermal Rating: on line 13575-3389 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2370
% INFO    : Updated Thermal Rating: on line 13575-7409 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1294
% INFO    : Updated Thermal Rating: on line 10019-4099 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 352
% INFO    : Updated Thermal Rating: on line 7049-4348 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2415
% INFO    : Updated Thermal Rating: on line 7049-11735 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1652
% INFO    : Updated Thermal Rating: on line 4348-11735 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2002
% INFO    : Updated Thermal Rating: on line 11556-9934 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 910
% INFO    : Updated Thermal Rating: on line 11735-9919 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1853
% INFO    : Updated Thermal Rating: on line 11735-9919 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2001
% INFO    : Updated Thermal Rating: on line 11735-12666 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1580
% INFO    : Updated Thermal Rating: on line 11735-7409 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1739
% INFO    : Updated Thermal Rating: on line 8194-10478 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4032
% INFO    : Updated Thermal Rating: on line 8194-10478 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4758
% INFO    : Updated Thermal Rating: on line 8194-10478 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6809
% INFO    : Updated Thermal Rating: on line 10686-4523 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12199
% INFO    : Updated Thermal Rating: on line 4099-1313 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 312
% INFO    : Updated Thermal Rating: on line 4099-13107 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10150
% INFO    : Updated Thermal Rating: on line 4099-6922 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9967
% INFO    : Updated Thermal Rating: on line 4099-12919 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1132
% INFO    : Updated Thermal Rating: on line 13229-1313 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 317
% INFO    : Updated Thermal Rating: on line 541-3196 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12029
% INFO    : Updated Thermal Rating: on line 6705-541 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11032
% INFO    : Updated Thermal Rating: on line 5139-541 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 47495
% INFO    : Updated Thermal Rating: on line 10964-1637 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13986
% INFO    : Updated Thermal Rating: on line 6071-10964 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19669
% INFO    : Updated Thermal Rating: on line 3856-13018 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4013
% INFO    : Updated Thermal Rating: on line 3856-13018 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4332
% INFO    : Updated Thermal Rating: on line 13018-12148 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6742
% INFO    : Updated Thermal Rating: on line 13018-11938 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1598
% INFO    : Updated Thermal Rating: on line 9947-9945 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4335
% INFO    : Updated Thermal Rating: on line 13472-9947 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 31269
% INFO    : Updated Thermal Rating: on line 9947-2575 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4244
% INFO    : Updated Thermal Rating: on line 7737-1430 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 51332
% INFO    : Updated Thermal Rating: on line 10714-11870 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3701
% INFO    : Updated Thermal Rating: on line 7968-11870 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4475
% INFO    : Updated Thermal Rating: on line 7461-4899 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24603
% INFO    : Updated Thermal Rating: on line 6384-13417 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4383
% INFO    : Updated Thermal Rating: on line 13417-10325 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 580
% INFO    : Updated Thermal Rating: on line 6384-13417 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4039
% INFO    : Updated Thermal Rating: on line 9406-12442 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 946
% INFO    : Updated Thermal Rating: on line 2092-9406 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1012
% INFO    : Updated Thermal Rating: on line 5423-9406 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 477
% INFO    : Updated Thermal Rating: on line 9406-11593 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 487
% INFO    : Updated Thermal Rating: on line 7554-9406 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 641
% INFO    : Updated Thermal Rating: on line 2597-1260 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 106240
% INFO    : Updated Thermal Rating: on line 7288-1260 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 106240
% INFO    : Updated Thermal Rating: on line 9966-1260 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 105881
% INFO    : Updated Thermal Rating: on line 1295-1809 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18318
% INFO    : Updated Thermal Rating: on line 1260-1700 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1627
% INFO    : Updated Thermal Rating: on line 4515-1260 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3874
% INFO    : Updated Thermal Rating: on line 4515-1260 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4156
% INFO    : Updated Thermal Rating: on line 12355-11550 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16796
% INFO    : Updated Thermal Rating: on line 12355-11550 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16305
% INFO    : Updated Thermal Rating: on line 8875-10160 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 879
% INFO    : Updated Thermal Rating: on line 8875-2196 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2449
% INFO    : Updated Thermal Rating: on line 1782-5296 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 295
% INFO    : Updated Thermal Rating: on line 1809-12442 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7782
% INFO    : Updated Thermal Rating: on line 1809-5240 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12953
% INFO    : Updated Thermal Rating: on line 7147-6024 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 563
% INFO    : Updated Thermal Rating: on line 7994-7147 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 701
% INFO    : Updated Thermal Rating: on line 7398-8255 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6326
% INFO    : Updated Thermal Rating: on line 8255-7977 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14534
% INFO    : Updated Thermal Rating: on line 4765-6626 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1698
% INFO    : Updated Thermal Rating: on line 4765-8500 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18584
% INFO    : Updated Thermal Rating: on line 7398-11495 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8731
% INFO    : Updated Thermal Rating: on line 7398-10969 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3767
% INFO    : Updated Thermal Rating: on line 7398-10969 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2552
% INFO    : Updated Thermal Rating: on line 7398-3422 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8424
% INFO    : Updated Thermal Rating: on line 12378-1885 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5204
% INFO    : Updated Thermal Rating: on line 12378-1885 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5104
% INFO    : Updated Thermal Rating: on line 1885-11460 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1883
% INFO    : Updated Thermal Rating: on line 1885-7797 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 44419
% INFO    : Updated Thermal Rating: on line 1885-7797 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 38950
% INFO    : Updated Thermal Rating: on line 1885-1395 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20706
% INFO    : Updated Thermal Rating: on line 1885-1395 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21107
% INFO    : Updated Thermal Rating: on line 1885-6133 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19201
% INFO    : Updated Thermal Rating: on line 1885-6133 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18746
% INFO    : Updated Thermal Rating: on line 8766-7554 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6130
% INFO    : Updated Thermal Rating: on line 13251-9007 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 92032
% INFO    : Updated Thermal Rating: on line 8579-8264 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1445
% INFO    : Updated Thermal Rating: on line 8579-5926 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11052
% INFO    : Updated Thermal Rating: on line 1782-70 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 301
% INFO    : Updated Thermal Rating: on line 3830-1782 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2169
% INFO    : Updated Thermal Rating: on line 1108-643 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 54866
% INFO    : Updated Thermal Rating: on line 9945-643 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3825
% INFO    : Updated Thermal Rating: on line 2017-643 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8223
% INFO    : Updated Thermal Rating: on line 13225-3705 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10901
% INFO    : Updated Thermal Rating: on line 8298-7058 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 105361
% INFO    : Updated Thermal Rating: on line 3518-10740 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11048
% INFO    : Updated Thermal Rating: on line 10740-4628 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14451
% INFO    : Updated Thermal Rating: on line 4302-10740 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4279
% INFO    : Updated Thermal Rating: on line 6332-11542 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5429
% INFO    : Updated Thermal Rating: on line 6332-4868 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2682
% INFO    : Updated Thermal Rating: on line 6332-8920 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14953
% INFO    : Updated Thermal Rating: on line 12176-9859 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8417
% INFO    : Updated Thermal Rating: on line 3876-12176 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6087
% INFO    : Updated Thermal Rating: on line 2835-10707 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3018
% INFO    : Updated Thermal Rating: on line 12587-8306 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1513
% INFO    : Updated Thermal Rating: on line 11223-8306 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13587
% INFO    : Updated Thermal Rating: on line 7434-11942 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 126249
% INFO    : Updated Thermal Rating: on line 8840-11942 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 137207
% INFO    : Updated Thermal Rating: on line 3470-11942 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4614
% INFO    : Updated Thermal Rating: on line 1241-11942 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3671
% INFO    : Updated Thermal Rating: on line 3648-1487 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1235
% INFO    : Updated Thermal Rating: on line 546-3648 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1040
% INFO    : Updated Thermal Rating: on line 6852-10025 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 860
% INFO    : Updated Thermal Rating: on line 6852-1272 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 917
% INFO    : Updated Thermal Rating: on line 9133-2643 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 730
% INFO    : Updated Thermal Rating: on line 9133-2643 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 716
% INFO    : Updated Thermal Rating: on line 2643-5625 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1399
% INFO    : Updated Thermal Rating: on line 2643-5625 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1608
% INFO    : Updated Thermal Rating: on line 11845-233 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 29652
% INFO    : Updated Thermal Rating: on line 11845-2898 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3633
% INFO    : Updated Thermal Rating: on line 2519-5509 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10628
% INFO    : Updated Thermal Rating: on line 2519-2089 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3040
% INFO    : Updated Thermal Rating: on line 5725-1785 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3193
% INFO    : Updated Thermal Rating: on line 1785-11966 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6171
% INFO    : Updated Thermal Rating: on line 1785-11966 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6053
% INFO    : Updated Thermal Rating: on line 12715-1785 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2448
% INFO    : Updated Thermal Rating: on line 1785-13320 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4889
% INFO    : Updated Thermal Rating: on line 5538-6984 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2538
% INFO    : Updated Thermal Rating: on line 5232-7735 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13933
% INFO    : Updated Thermal Rating: on line 6957-7735 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9088
% INFO    : Updated Thermal Rating: on line 4628-7735 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10872
% INFO    : Updated Thermal Rating: on line 8003-9859 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6368
% INFO    : Updated Thermal Rating: on line 9859-3843 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6334
% INFO    : Updated Thermal Rating: on line 4689-12587 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13455
% INFO    : Updated Thermal Rating: on line 10160-12587 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 29997
% INFO    : Updated Thermal Rating: on line 10160-12587 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 29439
% INFO    : Updated Thermal Rating: on line 12587-11639 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 31487
% INFO    : Updated Thermal Rating: on line 12587-7796 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3107
% INFO    : Updated Thermal Rating: on line 1239-10646 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5555
% INFO    : Updated Thermal Rating: on line 1239-10646 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4818
% INFO    : Updated Thermal Rating: on line 7467-9197 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 704
% INFO    : Updated Thermal Rating: on line 3196-2575 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2710
% INFO    : Updated Thermal Rating: on line 3196-860 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4486
% INFO    : Updated Thermal Rating: on line 5232-2403 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5940
% INFO    : Updated Thermal Rating: on line 10333-9683 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3440
% INFO    : Updated Thermal Rating: on line 10333-9683 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4247
% INFO    : Updated Thermal Rating: on line 11772-9683 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5513
% INFO    : Updated Thermal Rating: on line 5453-9683 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7013
% INFO    : Updated Thermal Rating: on line 4177-9683 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5027
% INFO    : Updated Thermal Rating: on line 10160-12229 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13791
% INFO    : Updated Thermal Rating: on line 10160-9069 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14090
% INFO    : Updated Thermal Rating: on line 10160-11671 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12022
% INFO    : Updated Thermal Rating: on line 10160-2742 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12064
% INFO    : Updated Thermal Rating: on line 60-10216 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 747
% INFO    : Updated Thermal Rating: on line 10160-3519 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3423
% INFO    : Updated Thermal Rating: on line 10160-6109 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1416
% INFO    : Updated Thermal Rating: on line 5685-4037 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12629
% INFO    : Updated Thermal Rating: on line 8229-4037 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2555
% INFO    : Updated Thermal Rating: on line 4037-2882 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1277
% INFO    : Updated Thermal Rating: on line 12442-13406 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 254
% INFO    : Updated Thermal Rating: on line 12442-997 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2262
% INFO    : Updated Thermal Rating: on line 4123-12442 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8018
% INFO    : Updated Thermal Rating: on line 4123-12442 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7138
% INFO    : Updated Thermal Rating: on line 6626-12442 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 557
% INFO    : Updated Thermal Rating: on line 6626-12442 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 513
% INFO    : Updated Thermal Rating: on line 12442-7044 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4932
% INFO    : Updated Thermal Rating: on line 11420-1430 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1069
% INFO    : Updated Thermal Rating: on line 1430-13217 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1372
% INFO    : Updated Thermal Rating: on line 5423-5219 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7374
% INFO    : Updated Thermal Rating: on line 4113-1637 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7942
% INFO    : Updated Thermal Rating: on line 6707-1637 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1561
% INFO    : Updated Thermal Rating: on line 10873-6957 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8125
% INFO    : Updated Thermal Rating: on line 10873-557 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5061
% INFO    : Updated Thermal Rating: on line 9945-1247 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5180
% INFO    : Updated Thermal Rating: on line 1247-2575 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5001
% INFO    : Updated Thermal Rating: on line 3470-597 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9787
% INFO    : Updated Thermal Rating: on line 3470-6619 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10272
% INFO    : Updated Thermal Rating: on line 3470-7220 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3608
% INFO    : Updated Thermal Rating: on line 3470-12006 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1564
% INFO    : Updated Thermal Rating: on line 13516-10714 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9488
% INFO    : Updated Thermal Rating: on line 13516-10714 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9403
% INFO    : Updated Thermal Rating: on line 13516-10714 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9691
% INFO    : Updated Thermal Rating: on line 4421-13516 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2932
% INFO    : Updated Thermal Rating: on line 10206-13516 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 71624
% INFO    : Updated Thermal Rating: on line 9007-11027 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2879
% INFO    : Updated Thermal Rating: on line 12256-9007 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1690
% INFO    : Updated Thermal Rating: on line 10069-2159 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3412
% INFO    : Updated Thermal Rating: on line 10069-12112 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3683
% INFO    : Updated Thermal Rating: on line 4599-6710 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1890
% INFO    : Updated Thermal Rating: on line 4599-7383 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5523
% INFO    : Updated Thermal Rating: on line 6767-4599 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4942
% INFO    : Updated Thermal Rating: on line 6767-4599 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4851
% INFO    : Updated Thermal Rating: on line 11591-4599 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6992
% INFO    : Updated Thermal Rating: on line 13479-5720 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 416
% INFO    : Updated Thermal Rating: on line 13479-12694 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1778
% INFO    : Updated Thermal Rating: on line 13479-2017 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 587
% INFO    : Updated Thermal Rating: on line 4113-17 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8750
% INFO    : Updated Thermal Rating: on line 4113-6626 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 623
% INFO    : Updated Thermal Rating: on line 6705-1267 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6501
% INFO    : Updated Thermal Rating: on line 128-1267 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20617
% INFO    : Updated Thermal Rating: on line 11316-1267 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8598
% INFO    : Updated Thermal Rating: on line 11316-1267 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8990
% INFO    : Updated Thermal Rating: on line 1267-7570 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11710
% INFO    : Updated Thermal Rating: on line 6643-7934 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2030
% INFO    : Updated Thermal Rating: on line 6643-3563 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4781
% INFO    : Updated Thermal Rating: on line 11910-12598 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 695
% INFO    : Updated Thermal Rating: on line 12549-11910 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1158
% INFO    : Updated Thermal Rating: on line 2591-2196 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4074
% INFO    : Updated Thermal Rating: on line 2591-9458 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6527
% INFO    : Updated Thermal Rating: on line 13153-5535 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8724
% INFO    : Updated Thermal Rating: on line 1778-1396 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 586
% INFO    : Updated Thermal Rating: on line 1396-2476 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 324
% INFO    : Updated Thermal Rating: on line 9008-6710 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5733
% INFO    : Updated Thermal Rating: on line 3949-5200 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1624
% INFO    : Updated Thermal Rating: on line 3949-12823 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3077
% INFO    : Updated Thermal Rating: on line 9752-3949 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2900
% INFO    : Updated Thermal Rating: on line 12996-2083 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 357
% INFO    : Updated Thermal Rating: on line 12996-2083 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 362
% INFO    : Updated Thermal Rating: on line 2083-6018 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1811
% INFO    : Updated Thermal Rating: on line 6018-2083 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1606
% INFO    : Updated Thermal Rating: on line 4450-1487 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7701
% INFO    : Updated Thermal Rating: on line 157-9558 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10204
% INFO    : Updated Thermal Rating: on line 157-10392 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8830
% INFO    : Updated Thermal Rating: on line 4795-10467 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3418
% INFO    : Updated Thermal Rating: on line 4795-437 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17503
% INFO    : Updated Thermal Rating: on line 8849-1321 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3924
% INFO    : Updated Thermal Rating: on line 692-1321 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3832
% INFO    : Updated Thermal Rating: on line 1321-8264 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1409
% INFO    : Updated Thermal Rating: on line 2899-5538 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1637
% INFO    : Updated Thermal Rating: on line 6626-5538 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1895
% INFO    : Updated Thermal Rating: on line 6574-7660 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2478
% INFO    : Updated Thermal Rating: on line 3-11181 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 881
% INFO    : Updated Thermal Rating: on line 3-11505 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 331
% INFO    : Updated Thermal Rating: on line 3-11505 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 338
% INFO    : Updated Thermal Rating: on line 9382-8209 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1509
% INFO    : Updated Thermal Rating: on line 12846-9382 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3848
% INFO    : Updated Thermal Rating: on line 9207-1541 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2164
% INFO    : Updated Thermal Rating: on line 5200-9207 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2337
% INFO    : Updated Thermal Rating: on line 3386-2092 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 348
% INFO    : Updated Thermal Rating: on line 2092-4123 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17439
% INFO    : Updated Thermal Rating: on line 2092-1778 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 304
% INFO    : Updated Thermal Rating: on line 7-7944 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2162
% INFO    : Updated Thermal Rating: on line 7-3830 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 353
% INFO    : Updated Thermal Rating: on line 4170-10167 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14345
% INFO    : Updated Thermal Rating: on line 2575-4170 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14534
% INFO    : Updated Thermal Rating: on line 4170-590 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 35865
% INFO    : Updated Thermal Rating: on line 1106-201 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6342
% INFO    : Updated Thermal Rating: on line 5689-1541 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1002
% INFO    : Updated Thermal Rating: on line 9133-9070 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1537
% INFO    : Updated Thermal Rating: on line 9133-9070 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1314
% INFO    : Updated Thermal Rating: on line 9070-5625 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 730
% INFO    : Updated Thermal Rating: on line 9070-5625 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 716
% INFO    : Updated Thermal Rating: on line 7977-10969 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3605
% INFO    : Updated Thermal Rating: on line 4625-7977 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5260
% INFO    : Updated Thermal Rating: on line 1117-8349 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2177
% INFO    : Updated Thermal Rating: on line 1241-8349 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4054
% INFO    : Updated Thermal Rating: on line 7220-8349 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6409
% INFO    : Updated Thermal Rating: on line 3844-3779 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1167
% INFO    : Updated Thermal Rating: on line 3172-3779 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1860
% INFO    : Updated Thermal Rating: on line 5591-13652 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2973
% INFO    : Updated Thermal Rating: on line 12119-13652 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2123
% INFO    : Updated Thermal Rating: on line 2300-9133 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 294
% INFO    : Updated Thermal Rating: on line 2300-9133 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 261
% INFO    : Updated Thermal Rating: on line 6845-9133 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25619
% INFO    : Updated Thermal Rating: on line 11349-9133 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27605
% INFO    : Updated Thermal Rating: on line 12162-3126 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4037
% INFO    : Updated Thermal Rating: on line 12162-4877 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2978
% INFO    : Updated Thermal Rating: on line 12675-12162 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2670
% INFO    : Updated Thermal Rating: on line 10597-7383 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3394
% INFO    : Updated Thermal Rating: on line 212-7383 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 34205
% INFO    : Updated Thermal Rating: on line 443-1487 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 36308
% INFO    : Updated Thermal Rating: on line 3413-5807 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2004
% INFO    : Updated Thermal Rating: on line 3413-5807 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2044
% INFO    : Updated Thermal Rating: on line 3413-2089 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 371
% INFO    : Updated Thermal Rating: on line 1573-3413 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1458
% INFO    : Updated Thermal Rating: on line 12345-7830 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9136
% INFO    : Updated Thermal Rating: on line 7830-2403 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4756
% INFO    : Updated Thermal Rating: on line 597-12655 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 31827
% INFO    : Updated Thermal Rating: on line 8016-597 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15766
% INFO    : Updated Thermal Rating: on line 343-10467 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3545
% INFO    : Updated Thermal Rating: on line 4486-10467 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4468
% INFO    : Updated Thermal Rating: on line 10025-6078 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1080
% INFO    : Updated Thermal Rating: on line 10025-10632 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3300
% INFO    : Updated Thermal Rating: on line 10632-10025 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1277
% INFO    : Updated Thermal Rating: on line 7316-10025 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11078
% INFO    : Updated Thermal Rating: on line 11316-11785 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4325
% INFO    : Updated Thermal Rating: on line 9723-11785 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9269
% INFO    : Updated Thermal Rating: on line 3843-12345 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9035
% INFO    : Updated Thermal Rating: on line 11772-60 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1511
% INFO    : Updated Thermal Rating: on line 11772-60 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1536
% INFO    : Updated Thermal Rating: on line 60-9311 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 880
% INFO    : Updated Thermal Rating: on line 60-4007 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1274
% INFO    : Updated Thermal Rating: on line 9945-6705 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4872
% INFO    : Updated Thermal Rating: on line 7944-5240 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2039
% INFO    : Updated Thermal Rating: on line 11901-2241 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2588
% INFO    : Updated Thermal Rating: on line 2241-10536 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20992
% INFO    : Updated Thermal Rating: on line 2241-2550 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4272
% INFO    : Updated Thermal Rating: on line 11542-8678 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15726
% INFO    : Updated Thermal Rating: on line 7309-12574 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1411
% INFO    : Updated Thermal Rating: on line 12846-12574 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1416
% INFO    : Updated Thermal Rating: on line 4177-11181 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4678
% INFO    : Updated Thermal Rating: on line 4881-747 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 69084
% INFO    : Updated Thermal Rating: on line 747-692 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4006
% INFO    : Updated Thermal Rating: on line 5926-747 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3254
% INFO    : Updated Thermal Rating: on line 8998-11495 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19837
% INFO    : Updated Thermal Rating: on line 8998-11316 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 65727
% INFO    : Updated Thermal Rating: on line 10714-12703 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11190
% INFO    : Updated Thermal Rating: on line 7968-10714 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1960
% INFO    : Updated Thermal Rating: on line 10714-12675 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9289
% INFO    : Updated Thermal Rating: on line 10714-12675 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7924
% INFO    : Updated Thermal Rating: on line 1867-11027 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3356
% INFO    : Updated Thermal Rating: on line 13225-11027 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2025
% INFO    : Updated Thermal Rating: on line 12256-11027 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1414
% INFO    : Updated Thermal Rating: on line 11027-8297 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3164
% INFO    : Updated Thermal Rating: on line 3824-4421 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10536
% INFO    : Updated Thermal Rating: on line 4421-12762 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5582
% INFO    : Updated Thermal Rating: on line 8-4421 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4204
% INFO    : Updated Thermal Rating: on line 9203-1028 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1498
% INFO    : Updated Thermal Rating: on line 4123-1028 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 939
% INFO    : Updated Thermal Rating: on line 1028-7554 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1450
% INFO    : Updated Thermal Rating: on line 1028-7044 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1093
% INFO    : Updated Thermal Rating: on line 2520-10548 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 36609
% INFO    : Updated Thermal Rating: on line 3777-6523 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11293
% INFO    : Updated Thermal Rating: on line 3777-6523 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9474
% INFO    : Updated Thermal Rating: on line 8283-11901 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 87709
% INFO    : Updated Thermal Rating: on line 7570-12746 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7704
% INFO    : Updated Thermal Rating: on line 12746-10499 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2000
% INFO    : Updated Thermal Rating: on line 11326-1272 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 122178
% INFO    : Updated Thermal Rating: on line 11326-1272 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 117720
% INFO    : Updated Thermal Rating: on line 1272-7315 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5373
% INFO    : Updated Thermal Rating: on line 12979-1272 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1250
% INFO    : Updated Thermal Rating: on line 8209-152 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1298
% INFO    : Updated Thermal Rating: on line 343-10793 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3106
% INFO    : Updated Thermal Rating: on line 343-10793 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2567
% INFO    : Updated Thermal Rating: on line 3844-9307 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2681
% INFO    : Updated Thermal Rating: on line 2575-804 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3805
% INFO    : Updated Thermal Rating: on line 12996-8376 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 460
% INFO    : Updated Thermal Rating: on line 12996-8376 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 452
% INFO    : Updated Thermal Rating: on line 2300-8730 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14933
% INFO    : Updated Thermal Rating: on line 4010-6756 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17319
% INFO    : Updated Thermal Rating: on line 6756-8 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4279
% INFO    : Updated Thermal Rating: on line 4010-2520 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2758
% INFO    : Updated Thermal Rating: on line 10597-8107 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2289
% INFO    : Updated Thermal Rating: on line 10597-10525 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8826
% INFO    : Updated Thermal Rating: on line 10392-10597 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15308
% INFO    : Updated Thermal Rating: on line 9718-10565 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20349
% INFO    : Updated Thermal Rating: on line 1117-2159 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1718
% INFO    : Updated Thermal Rating: on line 2159-12112 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2099
% INFO    : Updated Thermal Rating: on line 3055-2159 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3358
% INFO    : Updated Thermal Rating: on line 2196-5443 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1570
% INFO    : Updated Thermal Rating: on line 2196-8242 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9024
% INFO    : Updated Thermal Rating: on line 11223-2196 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1357
% INFO    : Updated Thermal Rating: on line 2196-5725 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6588
% INFO    : Updated Thermal Rating: on line 2196-9432 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2692
% INFO    : Updated Thermal Rating: on line 1117-7968 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1519
% INFO    : Updated Thermal Rating: on line 1117-2520 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6845
% INFO    : Updated Thermal Rating: on line 2520-1117 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8411
% INFO    : Updated Thermal Rating: on line 1117-3055 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3563
% INFO    : Updated Thermal Rating: on line 9945-2575 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2747
% INFO    : Updated Thermal Rating: on line 9945-7190 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3131
% INFO    : Updated Thermal Rating: on line 9945-2017 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3159
% INFO    : Updated Thermal Rating: on line 9945-8384 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6947
% INFO    : Updated Thermal Rating: on line 9945-9723 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15961
% INFO    : Updated Thermal Rating: on line 4302-7092 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19953
% INFO    : Updated Thermal Rating: on line 4302-7092 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20864
% INFO    : Updated Thermal Rating: on line 1700-7238 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 73281
% INFO    : Updated Thermal Rating: on line 1700-998 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5353
% INFO    : Updated Thermal Rating: on line 2898-1700 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2587
% INFO    : Updated Thermal Rating: on line 11430-8376 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1281
% INFO    : Updated Thermal Rating: on line 11430-5625 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1001
% INFO    : Updated Thermal Rating: on line 11772-6940 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11714
% INFO    : Updated Thermal Rating: on line 8920-6940 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22950
% INFO    : Updated Thermal Rating: on line 8678-6940 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 46475
% INFO    : Updated Thermal Rating: on line 1188-2407 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 67204
% INFO    : Updated Thermal Rating: on line 2837-2407 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 68365
% INFO    : Updated Thermal Rating: on line 2899-6600 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 900
% INFO    : Updated Thermal Rating: on line 6600-6626 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 652
% INFO    : Updated Thermal Rating: on line 5591-12119 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1461
% INFO    : Updated Thermal Rating: on line 5591-10874 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3481
% INFO    : Updated Thermal Rating: on line 12715-5591 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6080
% INFO    : Updated Thermal Rating: on line 5591-9841 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5662
% INFO    : Updated Thermal Rating: on line 10969-6917 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 156073
% INFO    : Updated Thermal Rating: on line 10969-9046 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 148114
% INFO    : Updated Thermal Rating: on line 7934-3691 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2686
% INFO    : Updated Thermal Rating: on line 5447-7934 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 33500
% INFO    : Updated Thermal Rating: on line 7796-3519 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2067
% INFO    : Updated Thermal Rating: on line 1084-3691 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1096
% INFO    : Updated Thermal Rating: on line 9558-4128 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4926
% INFO    : Updated Thermal Rating: on line 9558-3843 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5220
% INFO    : Updated Thermal Rating: on line 13023-6282 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1155
% INFO    : Updated Thermal Rating: on line 13023-10499 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9343
% INFO    : Updated Thermal Rating: on line 9332-10063 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 48037
% INFO    : Updated Thermal Rating: on line 2769-9332 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1414
% INFO    : Updated Thermal Rating: on line 9332-9311 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 248
% INFO    : Updated Thermal Rating: on line 9332-13428 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 352
% INFO    : Updated Thermal Rating: on line 9332-13428 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 359
% INFO    : Updated Thermal Rating: on line 198-2891 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3708
% INFO    : Updated Thermal Rating: on line 10565-198 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7267
% INFO    : Updated Thermal Rating: on line 198-8615 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20511
% INFO    : Updated Thermal Rating: on line 5443-9432 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4392
% INFO    : Updated Thermal Rating: on line 5443-8192 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2622
% INFO    : Updated Thermal Rating: on line 8192-5443 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3294
% INFO    : Updated Thermal Rating: on line 12823-3722 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 42102
% INFO    : Updated Thermal Rating: on line 9752-12823 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2586
% INFO    : Updated Thermal Rating: on line 1487-12879 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3890
% INFO    : Updated Thermal Rating: on line 6232-12879 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4913
% INFO    : Updated Thermal Rating: on line 6509-6513 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 136820
% INFO    : Updated Thermal Rating: on line 6509-6513 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142990
% INFO    : Updated Thermal Rating: on line 5689-6509 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7980
% INFO    : Updated Thermal Rating: on line 5689-6509 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7824
% INFO    : Updated Thermal Rating: on line 13153-2112 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6054
% INFO    : Updated Thermal Rating: on line 2112-6913 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13092
% INFO    : Updated Thermal Rating: on line 6913-11830 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1890
% INFO    : Updated Thermal Rating: on line 6554-13509 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2130
% INFO    : Updated Thermal Rating: on line 10853-6554 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3070
% INFO    : Updated Thermal Rating: on line 11428-9203 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2078
% INFO    : Updated Thermal Rating: on line 9453-11428 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1076
% INFO    : Updated Thermal Rating: on line 12119-9524 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 150246
% INFO    : Updated Thermal Rating: on line 3281-3126 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4119
% INFO    : Updated Thermal Rating: on line 5927-8242 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157740
% INFO    : Updated Thermal Rating: on line 8242-9432 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4224
% INFO    : Updated Thermal Rating: on line 4713-5720 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 537
% INFO    : Updated Thermal Rating: on line 4713-3796 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 39811
% INFO    : Updated Thermal Rating: on line 4713-1253 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2400
% INFO    : Updated Thermal Rating: on line 6078-12979 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 629
% INFO    : Updated Thermal Rating: on line 3752-2297 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6728
% INFO    : Updated Thermal Rating: on line 3752-2297 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5948
% INFO    : Updated Thermal Rating: on line 4877-3752 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17039
% INFO    : Updated Thermal Rating: on line 4877-3752 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17407
% INFO    : Updated Thermal Rating: on line 7718-11372 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17430
% INFO    : Updated Thermal Rating: on line 2108-2942 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13853
% INFO    : Updated Thermal Rating: on line 7394-11591 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9934
% INFO    : Updated Thermal Rating: on line 2403-7394 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6515
% INFO    : Updated Thermal Rating: on line 142-10618 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3674
% INFO    : Updated Thermal Rating: on line 142-13320 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4737
% INFO    : Updated Thermal Rating: on line 860-4356 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2524
% INFO    : Updated Thermal Rating: on line 9607-4356 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5992
% INFO    : Updated Thermal Rating: on line 12112-5908 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2917
% INFO    : Updated Thermal Rating: on line 3837-12112 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2166
% INFO    : Updated Thermal Rating: on line 11421-10618 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12068
% INFO    : Updated Thermal Rating: on line 8708-12890 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157740
% INFO    : Updated Thermal Rating: on line 10874-12890 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5247
% INFO    : Updated Thermal Rating: on line 13320-12890 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20874
% INFO    : Updated Thermal Rating: on line 6580-10148 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 149739
% INFO    : Updated Thermal Rating: on line 12119-10148 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5544
% INFO    : Updated Thermal Rating: on line 11460-10148 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5931
% INFO    : Updated Thermal Rating: on line 3824-3281 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6541
% INFO    : Updated Thermal Rating: on line 2898-1934 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157740
% INFO    : Updated Thermal Rating: on line 11223-1623 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 143431
% INFO    : Updated Thermal Rating: on line 3875-12655 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 125947
% INFO    : Updated Thermal Rating: on line 3875-12655 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 121132
% INFO    : Updated Thermal Rating: on line 1241-7518 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5972
% INFO    : Updated Thermal Rating: on line 4204-7518 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3751
% INFO    : Updated Thermal Rating: on line 9458-11966 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1818
% INFO    : Updated Thermal Rating: on line 6109-9458 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1792
% INFO    : Updated Thermal Rating: on line 10618-11966 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4638
% INFO    : Updated Thermal Rating: on line 10618-11966 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5005
% INFO    : Updated Thermal Rating: on line 11966-13320 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3776
% INFO    : Updated Thermal Rating: on line 11247-998 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2828
% INFO    : Updated Thermal Rating: on line 2898-998 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2864
% INFO    : Updated Thermal Rating: on line 4515-4569 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4337
% INFO    : Updated Thermal Rating: on line 6109-4569 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2672
% INFO    : Updated Thermal Rating: on line 6513-3355 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15840
% INFO    : Updated Thermal Rating: on line 6513-3355 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16104
% INFO    : Updated Thermal Rating: on line 9380-3355 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 78870
% INFO    : Updated Thermal Rating: on line 9380-3355 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 76951
% INFO    : Updated Thermal Rating: on line 7136-6695 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 115804
% INFO    : Updated Thermal Rating: on line 6695-7136 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 111733
% INFO    : Updated Thermal Rating: on line 6695-4688 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 89029
% INFO    : Updated Thermal Rating: on line 6338-8518 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25020
% INFO    : Updated Thermal Rating: on line 6338-12979 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2787
% INFO    : Updated Thermal Rating: on line 2476-1084 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 764
% INFO    : Updated Thermal Rating: on line 6767-3518 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3615
% INFO    : Updated Thermal Rating: on line 3518-11901 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2124
% INFO    : Updated Thermal Rating: on line 3518-11901 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2169
% INFO    : Updated Thermal Rating: on line 10618-4515 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1392
% INFO    : Updated Thermal Rating: on line 10618-4515 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1343
% INFO    : Updated Thermal Rating: on line 5938-4515 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2120
% INFO    : Updated Thermal Rating: on line 5938-4515 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2029
% INFO    : Updated Thermal Rating: on line 505-1102 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 312
% INFO    : Updated Thermal Rating: on line 10333-1790 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17150
% INFO    : Updated Thermal Rating: on line 13115-4038 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 50626
% INFO    : Updated Thermal Rating: on line 4038-17 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1349
% INFO    : Updated Thermal Rating: on line 6626-4038 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 481
% INFO    : Updated Thermal Rating: on line 4038-13325 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3573
% INFO    : Updated Thermal Rating: on line 9432-13503 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12743
% INFO    : Updated Thermal Rating: on line 9432-8192 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1759
% INFO    : Updated Thermal Rating: on line 12119-11460 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3964
% INFO    : Updated Thermal Rating: on line 12119-7772 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3988
% INFO    : Updated Thermal Rating: on line 11153-6767 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 75017
% INFO    : Updated Thermal Rating: on line 2494-6767 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 75017
% INFO    : Updated Thermal Rating: on line 12643-6767 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 89920
% INFO    : Updated Thermal Rating: on line 9899-6767 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 87440
% INFO    : Updated Thermal Rating: on line 11591-6767 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7443
% INFO    : Updated Thermal Rating: on line 4486-7461 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3482
% INFO    : Updated Thermal Rating: on line 7461-437 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8722
% INFO    : Updated Thermal Rating: on line 10383-8849 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 548
% INFO    : Updated Thermal Rating: on line 10383-2891 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2455
% INFO    : Updated Thermal Rating: on line 10383-1487 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2769
% INFO    : Updated Thermal Rating: on line 10383-6232 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3400
% INFO    : Updated Thermal Rating: on line 10383-8264 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 407
% INFO    : Updated Thermal Rating: on line 1166-10525 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5649
% INFO    : Updated Thermal Rating: on line 1166-12762 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4381
% INFO    : Updated Thermal Rating: on line 11420-6707 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1743
% INFO    : Updated Thermal Rating: on line 7061-11420 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2469
% INFO    : Updated Thermal Rating: on line 201-11505 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2980
% INFO    : Updated Thermal Rating: on line 3023-2891 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4131
% INFO    : Updated Thermal Rating: on line 11939-3023 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1235
% INFO    : Updated Thermal Rating: on line 3023-12757 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 34135
% INFO    : Updated Thermal Rating: on line 13225-5599 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6018
% INFO    : Updated Thermal Rating: on line 13225-149 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7317
% INFO    : Updated Thermal Rating: on line 13225-12256 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2602
% INFO    : Updated Thermal Rating: on line 9453-13225 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19454
% INFO    : Updated Thermal Rating: on line 13225-8297 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21767
% INFO    : Updated Thermal Rating: on line 10730-2575 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 38753
% INFO    : Updated Thermal Rating: on line 12508-2575 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 31773
% INFO    : Updated Thermal Rating: on line 4868-7438 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2155
% INFO    : Updated Thermal Rating: on line 4868-3129 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 878
% INFO    : Updated Thermal Rating: on line 11152-4933 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 140617
% INFO    : Updated Thermal Rating: on line 4933-8615 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27356
% INFO    : Updated Thermal Rating: on line 8348-6282 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1699
% INFO    : Updated Thermal Rating: on line 8348-6282 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2270
% INFO    : Updated Thermal Rating: on line 505-6282 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6053
% INFO    : Updated Thermal Rating: on line 2297-6438 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10678
% INFO    : Updated Thermal Rating: on line 8254-640 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1224
% INFO    : Updated Thermal Rating: on line 8254-11100 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2372
% INFO    : Updated Thermal Rating: on line 6118-1181 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152932
% INFO    : Updated Thermal Rating: on line 6118-1181 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 97986
% INFO    : Updated Thermal Rating: on line 6118-1181 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 138387
% INFO    : Updated Thermal Rating: on line 6118-1181 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 158234
% INFO    : Updated Thermal Rating: on line 6118-1181 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 143877
% INFO    : Updated Thermal Rating: on line 6118-5599 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 31485
% INFO    : Updated Thermal Rating: on line 6118-149 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14703
% INFO    : Updated Thermal Rating: on line 9453-6118 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 36400
% INFO    : Updated Thermal Rating: on line 12181-6118 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 64904
% INFO    : Updated Thermal Rating: on line 4486-343 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2753
% INFO    : Updated Thermal Rating: on line 3187-343 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2183
% INFO    : Updated Thermal Rating: on line 3102-11247 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4148
% INFO    : Updated Thermal Rating: on line 11247-3380 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11549
% INFO    : Updated Thermal Rating: on line 13217-12414 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 36710
% INFO    : Updated Thermal Rating: on line 7309-13217 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2416
% INFO    : Updated Thermal Rating: on line 5217-11550 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 833
% INFO    : Updated Thermal Rating: on line 5217-11550 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 850
% INFO    : Updated Thermal Rating: on line 11550-8448 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9208
% INFO    : Updated Thermal Rating: on line 11550-6018 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 781
% INFO    : Updated Thermal Rating: on line 11550-6018 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 798
% INFO    : Updated Thermal Rating: on line 12378-13132 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25219
% INFO    : Updated Thermal Rating: on line 12378-12938 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24823
% INFO    : Updated Thermal Rating: on line 12378-6751 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24263
% INFO    : Updated Thermal Rating: on line 12378-9366 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26279
% INFO    : Updated Thermal Rating: on line 10553-8107 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52464
% INFO    : Updated Thermal Rating: on line 8107-8 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6761
% INFO    : Updated Thermal Rating: on line 10632-10565 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5346
% INFO    : Updated Thermal Rating: on line 10565-10632 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3807
% INFO    : Updated Thermal Rating: on line 6232-10632 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2245
% INFO    : Updated Thermal Rating: on line 5819-502 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19191
% INFO    : Updated Thermal Rating: on line 6388-7315 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1109
% INFO    : Updated Thermal Rating: on line 70-7315 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1256
% INFO    : Updated Thermal Rating: on line 7315-12979 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1426
% INFO    : Updated Thermal Rating: on line 6688-12378 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on line 12378-1309 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1687
% INFO    : Updated Thermal Rating: on line 12006-12378 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1466
% INFO    : Updated Thermal Rating: on line 12378-7772 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1083
% INFO    : Updated Thermal Rating: on line 12378-9199 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1487
% INFO    : Updated Thermal Rating: on line 3563-5423 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1120
% INFO    : Updated Thermal Rating: on line 7796-6109 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2498
% INFO    : Updated Thermal Rating: on line 7492-557 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3706
% INFO    : Updated Thermal Rating: on line 7492-3876 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5652
% INFO    : Updated Thermal Rating: on line 3856-8016 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5245
% INFO    : Updated Thermal Rating: on line 3856-6619 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5483
% INFO    : Updated Thermal Rating: on line 3856-11938 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1950
% INFO    : Updated Thermal Rating: on line 1241-9008 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6693
% INFO    : Updated Thermal Rating: on line 5217-1080 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 38643
% INFO    : Updated Thermal Rating: on line 5217-2300 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 483
% INFO    : Updated Thermal Rating: on line 5217-2300 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 428
% INFO    : Updated Thermal Rating: on line 2891-11152 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5377
% INFO    : Updated Thermal Rating: on line 3080-4123 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1083
% INFO    : Updated Thermal Rating: on line 9642-557 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 95024
% INFO    : Updated Thermal Rating: on line 3331-557 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 89666
% INFO    : Updated Thermal Rating: on line 7482-557 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 104368
% INFO    : Updated Thermal Rating: on line 4882-557 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 111679
% INFO    : Updated Thermal Rating: on line 7190-128 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 63555
% INFO    : Updated Thermal Rating: on line 13596-5475 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 28081
% INFO    : Updated Thermal Rating: on line 6071-13596 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1042
% INFO    : Updated Thermal Rating: on line 3777-10525 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3119
% INFO    : Updated Thermal Rating: on line 2899-8500 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 493
% INFO    : Updated Thermal Rating: on line 8286-8348 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2733
% INFO    : Updated Thermal Rating: on line 9607-8286 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5647
% INFO    : Updated Thermal Rating: on line 11772-5453 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 32471
% INFO    : Updated Thermal Rating: on line 11772-13428 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2782
% INFO    : Updated Thermal Rating: on line 11772-13428 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1445
% INFO    : Updated Thermal Rating: on line 1855-7438 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2467
% INFO    : Updated Thermal Rating: on line 6384-8541 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3536
% INFO    : Updated Thermal Rating: on line 5475-13115 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3094
% INFO    : Updated Thermal Rating: on line 3172-10853 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2573
% INFO    : Updated Thermal Rating: on line 4628-155 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 51672
% INFO    : Updated Thermal Rating: on line 11452-1658 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5194
% INFO    : Updated Thermal Rating: on line 4204-8 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14057
% INFO    : Updated Thermal Rating: on line 8920-9311 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15010
% INFO    : Updated Thermal Rating: on line 11593-13115 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1901
% INFO    : Updated Thermal Rating: on line 6688-8016 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2700
% INFO    : Updated Thermal Rating: on line 12006-8016 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1944
% INFO    : Updated Thermal Rating: on line 10969-3422 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4117
% INFO    : Updated Thermal Rating: on line 8384-10969 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2355
% INFO    : Updated Thermal Rating: on line 9079-12006 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9155
% INFO    : Updated Thermal Rating: on line 2758-12006 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10046
% INFO    : Updated Thermal Rating: on line 2601-2520 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12978
% INFO    : Updated Thermal Rating: on line 2608-7086 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17636
% INFO    : Updated Thermal Rating: on line 4613-7086 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15996
% INFO    : Updated Thermal Rating: on line 2769-9311 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 214
% INFO    : Updated Thermal Rating: on line 11100-640 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1092
% INFO    : Updated Thermal Rating: on line 6024-2407 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 546
% INFO    : Updated Thermal Rating: on line 155-3704 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 30551
% INFO    : Updated Thermal Rating: on line 155-3704 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 31123
% INFO    : Updated Thermal Rating: on line 3876-3704 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8276
% INFO    : Updated Thermal Rating: on line 183-2891 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2270
% INFO    : Updated Thermal Rating: on line 12737-4486 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3511
% INFO    : Updated Thermal Rating: on line 183-10565 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3309
% INFO    : Updated Thermal Rating: on line 1404-3129 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2570
% INFO    : Updated Thermal Rating: on line 6559-2297 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6687
% INFO    : Updated Thermal Rating: on line 6559-1332 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2358
% INFO    : Updated Thermal Rating: on line 4368-6559 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 29974
% INFO    : Updated Thermal Rating: on line 4877-6559 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4974
% INFO    : Updated Thermal Rating: on line 6018-4296 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6305
% INFO    : Updated Thermal Rating: on line 5625-8376 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1073
% INFO    : Updated Thermal Rating: on line 5625-8376 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 952
% INFO    : Updated Thermal Rating: on line 3777-4128 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5515
% INFO    : Updated Thermal Rating: on line 13509-8229 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 619
% INFO    : Updated Thermal Rating: on line 4706-1404 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2159
% INFO    : Updated Thermal Rating: on line 4706-1404 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2099
% INFO    : Updated Thermal Rating: on line 389-3796 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 37183
% INFO    : Updated Thermal Rating: on line 389-1253 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2629
% INFO    : Updated Thermal Rating: on line 389-2407 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 707
% INFO    : Updated Thermal Rating: on line 12889-280 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8329
% INFO    : Updated Thermal Rating: on line 5689-233 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6508
% INFO    : Updated Thermal Rating: on line 12715-7772 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1447
% INFO    : Updated Thermal Rating: on line 12694-2017 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 862
% INFO    : Updated Thermal Rating: on line 2987-7305 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3804
% INFO    : Updated Thermal Rating: on line 2987-11938 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1800
% INFO    : Updated Thermal Rating: on line 2987-11591 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2539
% INFO    : Updated Thermal Rating: on line 2520-7968 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2097
% INFO    : Updated Thermal Rating: on line 5689-9752 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1828
% INFO    : Updated Thermal Rating: on line 1790-8678 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 28344
% INFO    : Updated Thermal Rating: on line 10536-4302 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17692
% INFO    : Updated Thermal Rating: on line 1790-9311 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15233
% INFO    : Updated Thermal Rating: on line 11591-12029 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 34543
% INFO    : Updated Thermal Rating: on line 2766-692 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52825
% INFO    : Updated Thermal Rating: on line 4688-7336 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 125906
% INFO    : Updated Thermal Rating: on line 2898-9380 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5670
% INFO    : Updated Thermal Rating: on line 2898-9380 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5781
% INFO    : Updated Thermal Rating: on line 1309-6636 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6092
% INFO    : Updated Thermal Rating: on line 6636-7772 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6905
% INFO    : Updated Thermal Rating: on line 7797-1309 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2226
% INFO    : Updated Thermal Rating: on line 10325-6384 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 560
% INFO    : Updated Thermal Rating: on line 6384-4613 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4837
% INFO    : Updated Thermal Rating: on line 2407-6384 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 590
% INFO    : Updated Thermal Rating: on line 11460-1921 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6076
% INFO    : Updated Thermal Rating: on line 1921-7797 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2707
% INFO    : Updated Thermal Rating: on line 2608-6574 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3028
% INFO    : Updated Thermal Rating: on line 11939-9747 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1985
% INFO    : Updated Thermal Rating: on line 3876-437 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2337
% INFO    : Updated Thermal Rating: on line 11901-437 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8521
% INFO    : Updated Thermal Rating: on line 1487-6232 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2745
% INFO    : Updated Thermal Rating: on line 13475-1487 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4304
% INFO    : Updated Thermal Rating: on line 3102-5938 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2095
% INFO    : Updated Thermal Rating: on line 9303-1008 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 91030
% INFO    : Updated Thermal Rating: on line 3837-5908 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4099
% INFO    : Updated Thermal Rating: on line 7305-9008 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9003
% INFO    : Updated Thermal Rating: on line 5599-9170 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 88825
% INFO    : Updated Thermal Rating: on line 149-9170 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 87233
% INFO    : Updated Thermal Rating: on line 6626-4123 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 503
% INFO    : Updated Thermal Rating: on line 4123-8500 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 693
% INFO    : Updated Thermal Rating: on line 7316-10565 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1425
% INFO    : Updated Thermal Rating: on line 10565-9608 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 28038
% INFO    : Updated Thermal Rating: on line 10565-8615 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16644
% INFO    : Updated Thermal Rating: on line 1778-5296 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1031
% INFO    : Updated Thermal Rating: on line 6626-17 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 589
% INFO    : Updated Thermal Rating: on line 12549-6388 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7704
% INFO    : Updated Thermal Rating: on line 3875-5827 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5898
% INFO    : Updated Thermal Rating: on line 10563-12256 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2000
% INFO    : Updated Thermal Rating: on line 12979-70 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 646
% INFO    : Updated Thermal Rating: on line 9723-4625 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8705
% INFO    : Updated Thermal Rating: on line 2882-7718 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3811
% INFO    : Updated Thermal Rating: on line 2300-13003 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 31126
% INFO    : Updated Thermal Rating: on line 2300-5096 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 31749
% INFO    : Updated Thermal Rating: on line 2300-7583 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20402
% INFO    : Updated Thermal Rating: on line 2300-5643 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20004
% INFO    : Updated Thermal Rating: on line 1253-2661 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 86322
% INFO    : Updated Thermal Rating: on line 1253-2661 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 87379
% INFO    : Updated Thermal Rating: on line 3837-1233 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10045
% INFO    : Updated Thermal Rating: on line 590-5191 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 55154
% INFO    : Updated Thermal Rating: on line 2407-2229 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21268
% INFO    : Updated Thermal Rating: on line 2407-2229 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17625
% INFO    : Updated Thermal Rating: on line 12675-1332 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5061
% INFO    : Updated Thermal Rating: on line 10563-10853 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1890
% INFO    : Updated Thermal Rating: on line 1015-7797 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26833
% INFO    : Updated Thermal Rating: on line 12395-7797 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24196
% INFO    : Updated Thermal Rating: on line 10325-4351 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6273
% INFO    : Updated Thermal Rating: on line 10325-4351 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6767
% INFO    : Updated Thermal Rating: on line 2407-10325 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 519
% INFO    : Updated Thermal Rating: on line 6626-11830 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1157
% INFO    : Updated Thermal Rating: on line 6626-11830 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1173
% INFO    : Updated Thermal Rating: on line 6626-8500 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1490
% INFO    : Updated Thermal Rating: on line 9311-11071 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1573
% INFO    : Updated Thermal Rating: on line 4007-9311 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4922
% INFO    : Updated Thermal Rating: on line 9841-6482 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7401
% INFO    : Updated Thermal Rating: on line 13320-6482 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13226
% INFO    : Updated Thermal Rating: on line 1555-6482 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 40803
% INFO    : Updated Thermal Rating: on line 6626-7061 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2593
% INFO    : Updated Thermal Rating: on line 13645-6232 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8733
% INFO    : Updated Thermal Rating: on line 7309-9307 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 944
% INFO    : Updated Thermal Rating: on line 13325-12889 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4057
% INFO    : Updated Thermal Rating: on line 11938-2550 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1216
% INFO    : Updated Thermal Rating: on line 5453-1658 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 35314
% INFO    : Updated Thermal Rating: on line 9453-12181 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 68555
% INFO    : Updated Thermal Rating: on line 12757-6232 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18847
% INFO    : Updated Thermal Rating: on line 12006-7772 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 681
% INFO    : Updated Thermal Rating: on line 9607-10499 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2856
% INFO    : Updated Thermal Rating: on line 13475-10707 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2482
% INFO    : Updated Thermal Rating: on line 3837-8192 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4287
% INFO    : Updated Thermal Rating: on line 8192-3837 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4256
% INFO    : Updated Thermal Rating: on line 9199-3837 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1716
% INFO    : Updated Thermal Rating: on line 6845-11349 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52623
% INFO    : Updated Thermal Rating: on line 1778-11071 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21150
% INFO    : Updated Thermal Rating: on line 4688-10175 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3571
% INFO    : Updated Thermal Rating: on line 7136-6062 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6768
% INFO    : Updated Thermal Rating: on line 7136-1847 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3184
% INFO    : Updated Thermal Rating: on line 12757-9608 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21246
% INFO    : Updated Thermal Rating: on line 10707-1855 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2562
% INFO    : Updated Thermal Rating: on line 1573-11071 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14927
% INFO    : Updated Thermal Rating: on line 3187-2550 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2091
% INFO    : Updated Thermal Rating: on line 13428-4177 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7706
% INFO    : Updated Thermal Rating: on line 7554-12846 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1605
% INFO    : Updated Thermal Rating: on line 9747-5926 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1048
% INFO    : Updated Thermal Rating: on line 11159-10796 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6030
% INFO    : Updated Thermal Rating: on line 12995-13647 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6553
% INFO    : Updated Thermal Rating: on line 2360-12894 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 29226
% INFO    : Updated Thermal Rating: on line 10887-12295 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 36191
% INFO    : Updated Thermal Rating: on line 10887-12894 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 48435
% INFO    : Updated Thermal Rating: on line 13647-13352 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3709
% INFO    : Updated Thermal Rating: on line 13647-13352 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3646
% INFO    : Updated Thermal Rating: on line 5972-10796 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4297
% INFO    : Updated Thermal Rating: on line 10796-13647 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4588
% INFO    : Updated Thermal Rating: on line 5972-10796 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4634
% INFO    : Updated Thermal Rating: on line 10796-13647 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4945
% INFO    : Updated Thermal Rating: on line 11232-10481 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2822
% INFO    : Updated Thermal Rating: on line 10481-5972 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3651
% INFO    : Updated Thermal Rating: on line 10481-5972 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3589
% INFO    : Updated Thermal Rating: on line 13647-12295 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7039
% INFO    : Updated Thermal Rating: on line 13647-12894 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11587
% INFO    : Updated Thermal Rating: on line 9076-2755 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 532
% INFO    : Updated Thermal Rating: on line 8291-2755 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 433
% INFO    : Updated Thermal Rating: on line 9076-4471 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 493
% INFO    : Updated Thermal Rating: on line 4471-10817 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 658
% INFO    : Updated Thermal Rating: on line 4471-2674 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 245
% INFO    : Updated Thermal Rating: on line 316-4471 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 515
% INFO    : Updated Thermal Rating: on line 10817-2674 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 292
% INFO    : Updated Thermal Rating: on line 7591-7344 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 823
% INFO    : Updated Thermal Rating: on line 12534-7344 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1066
% INFO    : Updated Thermal Rating: on line 174-316 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 408
% INFO    : Updated Thermal Rating: on line 12534-11008 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1051
% INFO    : Updated Thermal Rating: on line 3901-8358 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 738
% INFO    : Updated Thermal Rating: on line 3901-8358 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 750
% INFO    : Updated Thermal Rating: on line 3901-8358 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 724
% INFO    : Updated Thermal Rating: on line 3901-3174 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 271
% INFO    : Updated Thermal Rating: on line 3901-3174 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 267
% INFO    : Updated Thermal Rating: on line 372-12265 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 714
% INFO    : Updated Thermal Rating: on line 372-12265 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 664
% INFO    : Updated Thermal Rating: on line 7591-372 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 419
% INFO    : Updated Thermal Rating: on line 8358-6142 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 76483
% INFO    : Updated Thermal Rating: on line 6142-9503 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 239
% INFO    : Updated Thermal Rating: on line 8452-4750 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2684
% INFO    : Updated Thermal Rating: on line 3174-2674 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2086
% INFO    : Updated Thermal Rating: on line 3174-2674 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1907
% INFO    : Updated Thermal Rating: on line 8452-11249 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1781
% INFO    : Updated Thermal Rating: on line 8291-2674 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 179
% INFO    : Updated Thermal Rating: on line 5329-3458 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 799
% INFO    : Updated Thermal Rating: on line 5577-3458 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 252
% INFO    : Updated Thermal Rating: on line 8596-8059 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 287
% INFO    : Updated Thermal Rating: on line 10532-8059 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 251
% INFO    : Updated Thermal Rating: on line 10744-5821 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1909
% INFO    : Updated Thermal Rating: on line 10744-4747 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1615
% INFO    : Updated Thermal Rating: on line 10278-550 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 999
% INFO    : Updated Thermal Rating: on line 10278-550 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1015
% INFO    : Updated Thermal Rating: on line 2909-550 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1355
% INFO    : Updated Thermal Rating: on line 92-550 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 269
% INFO    : Updated Thermal Rating: on line 9861-550 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 264
% INFO    : Updated Thermal Rating: on line 10278-11021 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 890
% INFO    : Updated Thermal Rating: on line 2909-10278 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 685
% INFO    : Updated Thermal Rating: on line 5156-10278 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 186
% INFO    : Updated Thermal Rating: on line 5156-10278 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 189
% INFO    : Updated Thermal Rating: on line 2909-11021 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1395
% INFO    : Updated Thermal Rating: on line 3057-2909 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 332
% INFO    : Updated Thermal Rating: on line 4247-5690 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 267
% INFO    : Updated Thermal Rating: on line 10532-5690 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 862
% INFO    : Updated Thermal Rating: on line 6908-5690 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 392
% INFO    : Updated Thermal Rating: on line 9743-8596 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 477
% INFO    : Updated Thermal Rating: on line 4747-5821 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1790
% INFO    : Updated Thermal Rating: on line 494-5821 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3916
% INFO    : Updated Thermal Rating: on line 6974-4247 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 709
% INFO    : Updated Thermal Rating: on line 6974-4247 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 722
% INFO    : Updated Thermal Rating: on line 9510-4247 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 699
% INFO    : Updated Thermal Rating: on line 1276-4247 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 200
% INFO    : Updated Thermal Rating: on line 1276-4247 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 203
% INFO    : Updated Thermal Rating: on line 12482-4247 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8696
% INFO    : Updated Thermal Rating: on line 4247-11050 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 221
% INFO    : Updated Thermal Rating: on line 6974-11941 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2020
% INFO    : Updated Thermal Rating: on line 9615-1817 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 866
% INFO    : Updated Thermal Rating: on line 2939-1817 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 418
% INFO    : Updated Thermal Rating: on line 6315-2474 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 76483
% INFO    : Updated Thermal Rating: on line 5329-1286 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 713
% INFO    : Updated Thermal Rating: on line 7588-1286 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 260
% INFO    : Updated Thermal Rating: on line 12533-3898 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 475
% INFO    : Updated Thermal Rating: on line 9355-3898 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 240
% INFO    : Updated Thermal Rating: on line 3898-5577 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1194
% INFO    : Updated Thermal Rating: on line 12533-9490 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 358
% INFO    : Updated Thermal Rating: on line 9355-12446 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 260
% INFO    : Updated Thermal Rating: on line 9355-9615 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 228
% INFO    : Updated Thermal Rating: on line 9355-2417 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19243
% INFO    : Updated Thermal Rating: on line 92-9510 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 191
% INFO    : Updated Thermal Rating: on line 11941-9510 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1166
% INFO    : Updated Thermal Rating: on line 9510-5571 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 326
% INFO    : Updated Thermal Rating: on line 9490-6899 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 549
% INFO    : Updated Thermal Rating: on line 9861-6899 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 240
% INFO    : Updated Thermal Rating: on line 8150-8084 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 288
% INFO    : Updated Thermal Rating: on line 8150-8084 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 305
% INFO    : Updated Thermal Rating: on line 3256-8084 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1458
% INFO    : Updated Thermal Rating: on line 2925-7368 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1152
% INFO    : Updated Thermal Rating: on line 7368-8946 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 517
% INFO    : Updated Thermal Rating: on line 2939-7368 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 311
% INFO    : Updated Thermal Rating: on line 9826-12554 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 252
% INFO    : Updated Thermal Rating: on line 8606-12554 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 488
% INFO    : Updated Thermal Rating: on line 5247-9826 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2175
% INFO    : Updated Thermal Rating: on line 612-9826 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1957
% INFO    : Updated Thermal Rating: on line 9615-9826 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 332
% INFO    : Updated Thermal Rating: on line 612-5247 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1765
% INFO    : Updated Thermal Rating: on line 59-5247 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 556
% INFO    : Updated Thermal Rating: on line 9615-5727 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1731
% INFO    : Updated Thermal Rating: on line 5727-1776 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 746
% INFO    : Updated Thermal Rating: on line 2925-12446 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 467
% INFO    : Updated Thermal Rating: on line 3256-9743 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 423
% INFO    : Updated Thermal Rating: on line 4341-12460 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2585
% INFO    : Updated Thermal Rating: on line 5156-12460 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2206
% INFO    : Updated Thermal Rating: on line 3057-4341 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 264
% INFO    : Updated Thermal Rating: on line 7588-5156 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 366
% INFO    : Updated Thermal Rating: on line 8150-6884 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 474
% INFO    : Updated Thermal Rating: on line 10655-6884 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 413
% INFO    : Updated Thermal Rating: on line 8946-9490 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 505
% INFO    : Updated Thermal Rating: on line 3774-1776 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 794
% INFO    : Updated Thermal Rating: on line 10655-3774 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 364
% INFO    : Updated Thermal Rating: on line 6897-8036 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 589
% INFO    : Updated Thermal Rating: on line 8036-5577 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 725
% INFO    : Updated Thermal Rating: on line 2612-92 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4746
% INFO    : Updated Thermal Rating: on line 10679-92 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1578
% INFO    : Updated Thermal Rating: on line 9910-2612 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2609
% INFO    : Updated Thermal Rating: on line 9910-10679 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1962
% INFO    : Updated Thermal Rating: on line 8150-8606 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 343
% INFO    : Updated Thermal Rating: on line 3887-10532 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 323
% INFO    : Updated Thermal Rating: on line 1776-59 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 433
% INFO    : Updated Thermal Rating: on line 2939-12446 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 905
% INFO    : Updated Thermal Rating: on line 10542-13118 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 593
% INFO    : Updated Thermal Rating: on line 1776-9615 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 729
% INFO    : Updated Thermal Rating: on line 13257-9615 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2122
% INFO    : Updated Thermal Rating: on line 175-9615 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1384
% INFO    : Updated Thermal Rating: on line 9615-6315 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4333
% INFO    : Updated Thermal Rating: on line 9615-6315 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4420
% INFO    : Updated Thermal Rating: on line 9615-6315 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4263
% INFO    : Updated Thermal Rating: on line 9615-6315 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4350
% INFO    : Updated Thermal Rating: on line 1776-2939 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 586
% INFO    : Updated Thermal Rating: on line 6182-4747 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8815
% INFO    : Updated Thermal Rating: on line 5329-5577 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 215
% INFO    : Updated Thermal Rating: on line 6908-8150 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1691
% INFO    : Updated Thermal Rating: on line 1276-3887 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4760
% INFO    : Updated Thermal Rating: on line 1276-11050 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 519
% INFO    : Updated Thermal Rating: on line 5700-2417 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 424
% INFO    : Updated Thermal Rating: on line 6897-5700 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3476
% INFO    : Updated Thermal Rating: on line 5700-5577 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 294
% INFO    : Updated Thermal Rating: on line 175-13257 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1758
% INFO    : Updated Thermal Rating: on line 8004-10655 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2914
% INFO    : Updated Thermal Rating: on line 8004-6502 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4201
% INFO    : Updated Thermal Rating: on line 6502-10655 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9036
% INFO    : Updated Thermal Rating: on line 5571-6502 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 657
% INFO    : Updated Thermal Rating: on line 8737-2409 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1822
% INFO    : Updated Thermal Rating: on line 6151-1593 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1788
% INFO    : Updated Thermal Rating: on line 13039-2887 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 786
% INFO    : Updated Thermal Rating: on line 13074-5030 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12505
% INFO    : Updated Thermal Rating: on line 13074-5539 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 58713
% INFO    : Updated Thermal Rating: on line 9360-2232 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1126
% INFO    : Updated Thermal Rating: on line 9360-2232 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1149
% INFO    : Updated Thermal Rating: on line 7663-9360 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3255
% INFO    : Updated Thermal Rating: on line 7663-9360 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3323
% INFO    : Updated Thermal Rating: on line 12145-7653 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 33791
% INFO    : Updated Thermal Rating: on line 1716-7653 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2021
% INFO    : Updated Thermal Rating: on line 12145-11700 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 34103
% INFO    : Updated Thermal Rating: on line 1716-11700 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2176
% INFO    : Updated Thermal Rating: on line 6233-209 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 249
% INFO    : Updated Thermal Rating: on line 12901-1047 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 43072
% INFO    : Updated Thermal Rating: on line 1716-1047 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2347
% INFO    : Updated Thermal Rating: on line 13431-1047 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2288
% INFO    : Updated Thermal Rating: on line 4906-2668 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4018
% INFO    : Updated Thermal Rating: on line 9568-2668 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3459
% INFO    : Updated Thermal Rating: on line 8418-2668 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1468
% INFO    : Updated Thermal Rating: on line 4906-12311 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3557
% INFO    : Updated Thermal Rating: on line 9568-12311 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3727
% INFO    : Updated Thermal Rating: on line 8418-12311 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1491
% INFO    : Updated Thermal Rating: on line 13070-8340 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1726
% INFO    : Updated Thermal Rating: on line 5022-13070 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4191
% INFO    : Updated Thermal Rating: on line 11290-13070 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20873
% INFO    : Updated Thermal Rating: on line 3758-12017 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1697
% INFO    : Updated Thermal Rating: on line 370-3758 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3749
% INFO    : Updated Thermal Rating: on line 11290-3758 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21259
% INFO    : Updated Thermal Rating: on line 2585-6946 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 76483
% INFO    : Updated Thermal Rating: on line 5910-11011 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 244
% INFO    : Updated Thermal Rating: on line 5030-10815 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2102
% INFO    : Updated Thermal Rating: on line 236-12520 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2144
% INFO    : Updated Thermal Rating: on line 236-5030 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27021
% INFO    : Updated Thermal Rating: on line 236-12436 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9098
% INFO    : Updated Thermal Rating: on line 236-3874 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9741
% INFO    : Updated Thermal Rating: on line 4508-7794 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8989
% INFO    : Updated Thermal Rating: on line 4508-7794 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9155
% INFO    : Updated Thermal Rating: on line 12436-3874 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5690
% INFO    : Updated Thermal Rating: on line 12436-3287 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1366
% INFO    : Updated Thermal Rating: on line 12436-3287 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1392
% INFO    : Updated Thermal Rating: on line 10839-11072 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1484
% INFO    : Updated Thermal Rating: on line 10839-11072 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1600
% INFO    : Updated Thermal Rating: on line 10839-6483 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 779
% INFO    : Updated Thermal Rating: on line 10839-6872 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 588
% INFO    : Updated Thermal Rating: on line 8406-11072 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1007
% INFO    : Updated Thermal Rating: on line 8406-11072 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1027
% INFO    : Updated Thermal Rating: on line 9967-9063 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7834
% INFO    : Updated Thermal Rating: on line 9967-9063 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7911
% INFO    : Updated Thermal Rating: on line 3324-1033 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 1033-6264 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 606
% INFO    : Updated Thermal Rating: on line 1033-6264 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 617
% INFO    : Updated Thermal Rating: on line 1236-4640 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on line 8098-4640 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1895
% INFO    : Updated Thermal Rating: on line 11519-4640 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1861
% INFO    : Updated Thermal Rating: on line 5119-9063 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 780
% INFO    : Updated Thermal Rating: on line 5119-9063 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 796
% INFO    : Updated Thermal Rating: on line 5119-4601 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2636
% INFO    : Updated Thermal Rating: on line 5119-4601 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2843
% INFO    : Updated Thermal Rating: on line 7898-13483 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6611
% INFO    : Updated Thermal Rating: on line 190-13483 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7317
% INFO    : Updated Thermal Rating: on line 9249-13483 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1188
% INFO    : Updated Thermal Rating: on line 7898-4391 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6492
% INFO    : Updated Thermal Rating: on line 417-4391 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2123
% INFO    : Updated Thermal Rating: on line 190-4391 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7404
% INFO    : Updated Thermal Rating: on line 6147-2682 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2808
% INFO    : Updated Thermal Rating: on line 5733-6147 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 488
% INFO    : Updated Thermal Rating: on line 714-8340 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21658
% INFO    : Updated Thermal Rating: on line 8340-792 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1793
% INFO    : Updated Thermal Rating: on line 714-12017 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22108
% INFO    : Updated Thermal Rating: on line 12017-792 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1932
% INFO    : Updated Thermal Rating: on line 13626-12481 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5484
% INFO    : Updated Thermal Rating: on line 13626-13296 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4279
% INFO    : Updated Thermal Rating: on line 1667-13626 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2322
% INFO    : Updated Thermal Rating: on line 13626-2763 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5449
% INFO    : Updated Thermal Rating: on line 4785-9403 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1089
% INFO    : Updated Thermal Rating: on line 2918-9403 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 34727
% INFO    : Updated Thermal Rating: on line 9157-9403 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2342
% INFO    : Updated Thermal Rating: on line 10451-8621 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1583
% INFO    : Updated Thermal Rating: on line 2918-8621 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 31394
% INFO    : Updated Thermal Rating: on line 9157-8621 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2133
% INFO    : Updated Thermal Rating: on line 10562-9850 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3218
% INFO    : Updated Thermal Rating: on line 3935-9850 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26113
% INFO    : Updated Thermal Rating: on line 4817-9850 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4795
% INFO    : Updated Thermal Rating: on line 3935-4785 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23441
% INFO    : Updated Thermal Rating: on line 4817-4785 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4881
% INFO    : Updated Thermal Rating: on line 6977-9653 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26368
% INFO    : Updated Thermal Rating: on line 694-10631 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2157
% INFO    : Updated Thermal Rating: on line 694-1120 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 9295-5022 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4737
% INFO    : Updated Thermal Rating: on line 7696-5022 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22534
% INFO    : Updated Thermal Rating: on line 9295-370 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4654
% INFO    : Updated Thermal Rating: on line 7696-370 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20195
% INFO    : Updated Thermal Rating: on line 13039-10305 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1685
% INFO    : Updated Thermal Rating: on line 13039-10305 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1658
% INFO    : Updated Thermal Rating: on line 1775-202 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 106479
% INFO    : Updated Thermal Rating: on line 1775-5843 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1569
% INFO    : Updated Thermal Rating: on line 2815-1775 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1482
% INFO    : Updated Thermal Rating: on line 2815-1775 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1496
% INFO    : Updated Thermal Rating: on line 1775-5048 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1014
% INFO    : Updated Thermal Rating: on line 1337-8418 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1554
% INFO    : Updated Thermal Rating: on line 1337-8418 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1673
% INFO    : Updated Thermal Rating: on line 12145-8811 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 10562-10451 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 707
% INFO    : Updated Thermal Rating: on line 8826-1917 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 895
% INFO    : Updated Thermal Rating: on line 8826-9596 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1829
% INFO    : Updated Thermal Rating: on line 952-1974 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1145
% INFO    : Updated Thermal Rating: on line 9983-5189 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1129
% INFO    : Updated Thermal Rating: on line 522-5189 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1108
% INFO    : Updated Thermal Rating: on line 1974-5189 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 68520
% INFO    : Updated Thermal Rating: on line 1974-11313 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5635
% INFO    : Updated Thermal Rating: on line 1508-1974 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1387
% INFO    : Updated Thermal Rating: on line 5189-199 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5757
% INFO    : Updated Thermal Rating: on line 5693-5189 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1362
% INFO    : Updated Thermal Rating: on line 7318-13121 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 469
% INFO    : Updated Thermal Rating: on line 7318-13121 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 475
% INFO    : Updated Thermal Rating: on line 2585-9277 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3361
% INFO    : Updated Thermal Rating: on line 11741-2585 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1142
% INFO    : Updated Thermal Rating: on line 1917-9596 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 743
% INFO    : Updated Thermal Rating: on line 1917-939 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1349
% INFO    : Updated Thermal Rating: on line 1917-2618 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3672
% INFO    : Updated Thermal Rating: on line 1917-2618 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3746
% INFO    : Updated Thermal Rating: on line 2386-1917 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2550
% INFO    : Updated Thermal Rating: on line 2386-1917 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2257
% INFO    : Updated Thermal Rating: on line 1917-11165 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 771
% INFO    : Updated Thermal Rating: on line 1917-464 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 891
% INFO    : Updated Thermal Rating: on line 10226-3561 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 7325-10030 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10075
% INFO    : Updated Thermal Rating: on line 8845-10030 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4092
% INFO    : Updated Thermal Rating: on line 8979-7210 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1016
% INFO    : Updated Thermal Rating: on line 8979-7210 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1033
% INFO    : Updated Thermal Rating: on line 507-8979 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1389
% INFO    : Updated Thermal Rating: on line 507-8979 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1400
% INFO    : Updated Thermal Rating: on line 10591-11365 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 106479
% INFO    : Updated Thermal Rating: on line 10591-9596 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8986
% INFO    : Updated Thermal Rating: on line 10591-10306 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1565
% INFO    : Updated Thermal Rating: on line 10591-9365 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2878
% INFO    : Updated Thermal Rating: on line 2386-10591 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 622
% INFO    : Updated Thermal Rating: on line 10591-13431 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1190
% INFO    : Updated Thermal Rating: on line 5910-3363 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 712
% INFO    : Updated Thermal Rating: on line 5910-1614 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 280
% INFO    : Updated Thermal Rating: on line 5910-8589 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 42268
% INFO    : Updated Thermal Rating: on line 5910-8589 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 43011
% INFO    : Updated Thermal Rating: on line 5910-4019 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 36580
% INFO    : Updated Thermal Rating: on line 5910-11783 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11925
% INFO    : Updated Thermal Rating: on line 5910-8990 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13827
% INFO    : Updated Thermal Rating: on line 5910-8990 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12858
% INFO    : Updated Thermal Rating: on line 5910-10137 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9709
% INFO    : Updated Thermal Rating: on line 11741-8587 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 343
% INFO    : Updated Thermal Rating: on line 7725-8587 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 239
% INFO    : Updated Thermal Rating: on line 3555-8587 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 757
% INFO    : Updated Thermal Rating: on line 3555-8587 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 773
% INFO    : Updated Thermal Rating: on line 3363-1781 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2479
% INFO    : Updated Thermal Rating: on line 1667-12481 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3615
% INFO    : Updated Thermal Rating: on line 1667-13296 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5455
% INFO    : Updated Thermal Rating: on line 13296-10948 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6446
% INFO    : Updated Thermal Rating: on line 13296-10948 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6362
% INFO    : Updated Thermal Rating: on line 4355-1155 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4207
% INFO    : Updated Thermal Rating: on line 8261-1155 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2964
% INFO    : Updated Thermal Rating: on line 3197-13291 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2244
% INFO    : Updated Thermal Rating: on line 792-3197 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7313
% INFO    : Updated Thermal Rating: on line 792-3197 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7397
% INFO    : Updated Thermal Rating: on line 13039-7898 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2464
% INFO    : Updated Thermal Rating: on line 13039-7898 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2418
% INFO    : Updated Thermal Rating: on line 8351-1501 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 59281
% INFO    : Updated Thermal Rating: on line 8351-1501 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 60257
% INFO    : Updated Thermal Rating: on line 8351-2618 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 563
% INFO    : Updated Thermal Rating: on line 8351-2618 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 553
% INFO    : Updated Thermal Rating: on line 8351-9968 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3320
% INFO    : Updated Thermal Rating: on line 8351-9968 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3271
% INFO    : Updated Thermal Rating: on line 8351-9157 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3544
% INFO    : Updated Thermal Rating: on line 8351-9157 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3614
% INFO    : Updated Thermal Rating: on line 4281-4817 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1962
% INFO    : Updated Thermal Rating: on line 2386-4281 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1146
% INFO    : Updated Thermal Rating: on line 10226-13140 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 817
% INFO    : Updated Thermal Rating: on line 2493-871 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 70195
% INFO    : Updated Thermal Rating: on line 871-1593 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1600
% INFO    : Updated Thermal Rating: on line 10226-6671 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 106479
% INFO    : Updated Thermal Rating: on line 10226-9295 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2059
% INFO    : Updated Thermal Rating: on line 10226-9295 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2099
% INFO    : Updated Thermal Rating: on line 10226-7362 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5478
% INFO    : Updated Thermal Rating: on line 10226-7362 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5390
% INFO    : Updated Thermal Rating: on line 10226-4815 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4046
% INFO    : Updated Thermal Rating: on line 10226-4815 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4133
% INFO    : Updated Thermal Rating: on line 10226-4508 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1222
% INFO    : Updated Thermal Rating: on line 10226-4508 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1201
% INFO    : Updated Thermal Rating: on line 10226-2074 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1079
% INFO    : Updated Thermal Rating: on line 10226-2074 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1098
% INFO    : Updated Thermal Rating: on line 1730-1915 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2732
% INFO    : Updated Thermal Rating: on line 1730-1915 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2791
% INFO    : Updated Thermal Rating: on line 3287-1915 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2159
% INFO    : Updated Thermal Rating: on line 3287-1915 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2205
% INFO    : Updated Thermal Rating: on line 287-10546 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6757
% INFO    : Updated Thermal Rating: on line 65-287 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 911
% INFO    : Updated Thermal Rating: on line 7268-12422 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 61936
% INFO    : Updated Thermal Rating: on line 12422-2719 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2650
% INFO    : Updated Thermal Rating: on line 12422-4886 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9965
% INFO    : Updated Thermal Rating: on line 7268-5101 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2708
% INFO    : Updated Thermal Rating: on line 7268-9879 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9781
% INFO    : Updated Thermal Rating: on line 6959-10224 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1489
% INFO    : Updated Thermal Rating: on line 2719-5101 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 60745
% INFO    : Updated Thermal Rating: on line 2719-11660 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9621
% INFO    : Updated Thermal Rating: on line 583-2719 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10047
% INFO    : Updated Thermal Rating: on line 5101-8845 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9827
% INFO    : Updated Thermal Rating: on line 8504-5101 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10239
% INFO    : Updated Thermal Rating: on line 4653-8478 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1622
% INFO    : Updated Thermal Rating: on line 2386-11098 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 834
% INFO    : Updated Thermal Rating: on line 3408-10416 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2037
% INFO    : Updated Thermal Rating: on line 424-11893 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 59599
% INFO    : Updated Thermal Rating: on line 424-8845 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11190
% INFO    : Updated Thermal Rating: on line 5998-424 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4456
% INFO    : Updated Thermal Rating: on line 11893-11660 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12088
% INFO    : Updated Thermal Rating: on line 8583-11893 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4369
% INFO    : Updated Thermal Rating: on line 2101-7663 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11389
% INFO    : Updated Thermal Rating: on line 5822-7663 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11593
% INFO    : Updated Thermal Rating: on line 11831-7663 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11845
% INFO    : Updated Thermal Rating: on line 2834-2276 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 371
% INFO    : Updated Thermal Rating: on line 10113-2276 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 456
% INFO    : Updated Thermal Rating: on line 988-12888 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 763
% INFO    : Updated Thermal Rating: on line 12888-295 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1259
% INFO    : Updated Thermal Rating: on line 12888-5048 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2136
% INFO    : Updated Thermal Rating: on line 12888-5048 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2177
% INFO    : Updated Thermal Rating: on line 11082-11340 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 106479
% INFO    : Updated Thermal Rating: on line 11082-8139 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1898
% INFO    : Updated Thermal Rating: on line 11082-7810 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1158
% INFO    : Updated Thermal Rating: on line 6997-11082 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 865
% INFO    : Updated Thermal Rating: on line 6997-11082 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 882
% INFO    : Updated Thermal Rating: on line 7663-3996 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17383
% INFO    : Updated Thermal Rating: on line 7663-3996 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17554
% INFO    : Updated Thermal Rating: on line 12773-7663 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6295
% INFO    : Updated Thermal Rating: on line 7663-3868 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 947-6035 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 857
% INFO    : Updated Thermal Rating: on line 2834-947 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 491
% INFO    : Updated Thermal Rating: on line 6067-2336 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 9017-6067 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 9017-8554 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2058
% INFO    : Updated Thermal Rating: on line 6067-728 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1580
% INFO    : Updated Thermal Rating: on line 6067-8554 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1831
% INFO    : Updated Thermal Rating: on line 9634-5049 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2507
% INFO    : Updated Thermal Rating: on line 9634-8829 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4046
% INFO    : Updated Thermal Rating: on line 9634-7652 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3601
% INFO    : Updated Thermal Rating: on line 728-8554 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2822
% INFO    : Updated Thermal Rating: on line 8813-11724 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 7246-13401 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112812
% INFO    : Updated Thermal Rating: on line 1145-11839 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19555
% INFO    : Updated Thermal Rating: on line 113-12513 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 32401
% INFO    : Updated Thermal Rating: on line 48-12513 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 34833
% INFO    : Updated Thermal Rating: on line 13039-13175 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2000
% INFO    : Updated Thermal Rating: on line 7325-1289 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 58496
% INFO    : Updated Thermal Rating: on line 2553-7325 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3038
% INFO    : Updated Thermal Rating: on line 11462-7325 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10643
% INFO    : Updated Thermal Rating: on line 7960-1289 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2984
% INFO    : Updated Thermal Rating: on line 1667-6295 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 851
% INFO    : Updated Thermal Rating: on line 1667-12627 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1627
% INFO    : Updated Thermal Rating: on line 1667-12627 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1659
% INFO    : Updated Thermal Rating: on line 1667-694 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1726
% INFO    : Updated Thermal Rating: on line 1667-10948 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4603
% INFO    : Updated Thermal Rating: on line 1667-10948 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4686
% INFO    : Updated Thermal Rating: on line 1667-12180 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 801
% INFO    : Updated Thermal Rating: on line 1667-12180 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 786
% INFO    : Updated Thermal Rating: on line 1667-12180 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 848
% INFO    : Updated Thermal Rating: on line 1456-1575 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1925
% INFO    : Updated Thermal Rating: on line 4601-1575 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 402
% INFO    : Updated Thermal Rating: on line 7067-4355 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 63175
% INFO    : Updated Thermal Rating: on line 7067-1592 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 64464
% INFO    : Updated Thermal Rating: on line 7067-11934 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3709
% INFO    : Updated Thermal Rating: on line 7067-4653 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1806
% INFO    : Updated Thermal Rating: on line 4355-1592 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 65807
% INFO    : Updated Thermal Rating: on line 4355-12977 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3789
% INFO    : Updated Thermal Rating: on line 6275-106 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1293
% INFO    : Updated Thermal Rating: on line 6275-106 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1318
% INFO    : Updated Thermal Rating: on line 6275-9063 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2119
% INFO    : Updated Thermal Rating: on line 6275-1589 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1030
% INFO    : Updated Thermal Rating: on line 6275-1589 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1111
% INFO    : Updated Thermal Rating: on line 6275-10706 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7352
% INFO    : Updated Thermal Rating: on line 6275-10706 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6881
% INFO    : Updated Thermal Rating: on line 6275-10209 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1055
% INFO    : Updated Thermal Rating: on line 6275-10209 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1036
% INFO    : Updated Thermal Rating: on line 6275-6997 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1349
% INFO    : Updated Thermal Rating: on line 6275-5334 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1509
% INFO    : Updated Thermal Rating: on line 4508-2455 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1964
% INFO    : Updated Thermal Rating: on line 5337-4555 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 106479
% INFO    : Updated Thermal Rating: on line 1589-5337 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 861
% INFO    : Updated Thermal Rating: on line 10209-5337 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1966
% INFO    : Updated Thermal Rating: on line 10661-5337 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1130
% INFO    : Updated Thermal Rating: on line 11934-12977 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 67208
% INFO    : Updated Thermal Rating: on line 12369-11934 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2658
% INFO    : Updated Thermal Rating: on line 1112-12977 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2610
% INFO    : Updated Thermal Rating: on line 988-9425 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 106479
% INFO    : Updated Thermal Rating: on line 9064-988 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9887
% INFO    : Updated Thermal Rating: on line 9064-988 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9717
% INFO    : Updated Thermal Rating: on line 988-295 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1514
% INFO    : Updated Thermal Rating: on line 13121-10103 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 324
% INFO    : Updated Thermal Rating: on line 13121-13608 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 421
% INFO    : Updated Thermal Rating: on line 4955-5962 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 306
% INFO    : Updated Thermal Rating: on line 8785-4955 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 583
% INFO    : Updated Thermal Rating: on line 7145-4955 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1340
% INFO    : Updated Thermal Rating: on line 4955-10449 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 314
% INFO    : Updated Thermal Rating: on line 3965-8934 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 70195
% INFO    : Updated Thermal Rating: on line 113-3965 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21010
% INFO    : Updated Thermal Rating: on line 48-8934 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 29290
% INFO    : Updated Thermal Rating: on line 1145-11392 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1763
% INFO    : Updated Thermal Rating: on line 1145-12571 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1622
% INFO    : Updated Thermal Rating: on line 1145-7789 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19813
% INFO    : Updated Thermal Rating: on line 7307-2067 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1441
% INFO    : Updated Thermal Rating: on line 9980-7024 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1472
% INFO    : Updated Thermal Rating: on line 9496-7024 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1505
% INFO    : Updated Thermal Rating: on line 12198-7024 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1327
% INFO    : Updated Thermal Rating: on line 842-1927 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1982
% INFO    : Updated Thermal Rating: on line 409-9452 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1211
% INFO    : Updated Thermal Rating: on line 3900-11947 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1237
% INFO    : Updated Thermal Rating: on line 12821-12218 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1302
% INFO    : Updated Thermal Rating: on line 10053-5967 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1277
% INFO    : Updated Thermal Rating: on line 5478-2067 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1265
% INFO    : Updated Thermal Rating: on line 2699-2067 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1367
% INFO    : Updated Thermal Rating: on line 106-11969 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 106479
% INFO    : Updated Thermal Rating: on line 10694-106 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1515
% INFO    : Updated Thermal Rating: on line 106-11965 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1489
% INFO    : Updated Thermal Rating: on line 7024-12218 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 81721
% INFO    : Updated Thermal Rating: on line 7024-5967 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 83537
% INFO    : Updated Thermal Rating: on line 7024-10831 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 73709
% INFO    : Updated Thermal Rating: on line 7024-2853 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 72292
% INFO    : Updated Thermal Rating: on line 3509-11947 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 61936
% INFO    : Updated Thermal Rating: on line 3509-9452 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 60629
% INFO    : Updated Thermal Rating: on line 3509-9165 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 59487
% INFO    : Updated Thermal Rating: on line 3509-6373 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 58604
% INFO    : Updated Thermal Rating: on line 2067-12218 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 70928
% INFO    : Updated Thermal Rating: on line 2067-5967 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 69614
% INFO    : Updated Thermal Rating: on line 2067-10831 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 75184
% INFO    : Updated Thermal Rating: on line 2067-2853 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 76718
% INFO    : Updated Thermal Rating: on line 486-11947 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 63175
% INFO    : Updated Thermal Rating: on line 486-9452 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 64464
% INFO    : Updated Thermal Rating: on line 486-9165 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 65945
% INFO    : Updated Thermal Rating: on line 486-6373 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 67351
% INFO    : Updated Thermal Rating: on line 10205-12218 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6889
% INFO    : Updated Thermal Rating: on line 5125-11947 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 68520
% INFO    : Updated Thermal Rating: on line 9452-1927 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 70195
% INFO    : Updated Thermal Rating: on line 2792-10831 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6148
% INFO    : Updated Thermal Rating: on line 7729-2853 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1382
% INFO    : Updated Thermal Rating: on line 6373-1508 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1368
% INFO    : Updated Thermal Rating: on line 9737-6959 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 7545-3892 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 65807
% INFO    : Updated Thermal Rating: on line 7545-2409 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2646
% INFO    : Updated Thermal Rating: on line 7545-4653 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3472
% INFO    : Updated Thermal Rating: on line 3892-2409 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2699
% INFO    : Updated Thermal Rating: on line 3892-1593 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2757
% INFO    : Updated Thermal Rating: on line 3892-8261 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3545
% INFO    : Updated Thermal Rating: on line 4906-10546 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3436
% INFO    : Updated Thermal Rating: on line 4906-10546 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3373
% INFO    : Updated Thermal Rating: on line 10546-13275 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6201
% INFO    : Updated Thermal Rating: on line 65-10546 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 775
% INFO    : Updated Thermal Rating: on line 10546-5680 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1929
% INFO    : Updated Thermal Rating: on line 4906-579 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 961
% INFO    : Updated Thermal Rating: on line 4906-5180 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2359
% INFO    : Updated Thermal Rating: on line 4906-5180 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2401
% INFO    : Updated Thermal Rating: on line 4906-8486 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 525
% INFO    : Updated Thermal Rating: on line 13275-9568 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7117
% INFO    : Updated Thermal Rating: on line 11253-9568 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 981
% INFO    : Updated Thermal Rating: on line 11253-9568 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 966
% INFO    : Updated Thermal Rating: on line 2423-4153 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 130167
% INFO    : Updated Thermal Rating: on line 9063-2423 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2101
% INFO    : Updated Thermal Rating: on line 9063-2423 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2145
% INFO    : Updated Thermal Rating: on line 1589-2423 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1777
% INFO    : Updated Thermal Rating: on line 1589-2423 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1812
% INFO    : Updated Thermal Rating: on line 8618-9277 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5590
% INFO    : Updated Thermal Rating: on line 6307-9277 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 193
% INFO    : Updated Thermal Rating: on line 1062-13197 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 588
% INFO    : Updated Thermal Rating: on line 5855-13197 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 553
% INFO    : Updated Thermal Rating: on line 11741-805 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2836
% INFO    : Updated Thermal Rating: on line 805-10113 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 589
% INFO    : Updated Thermal Rating: on line 11783-12548 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 293
% INFO    : Updated Thermal Rating: on line 2269-8081 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 67208
% INFO    : Updated Thermal Rating: on line 2269-7960 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8585
% INFO    : Updated Thermal Rating: on line 2269-12160 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4974
% INFO    : Updated Thermal Rating: on line 11567-12550 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 61936
% INFO    : Updated Thermal Rating: on line 11567-4743 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2015
% INFO    : Updated Thermal Rating: on line 7752-11567 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1408
% INFO    : Updated Thermal Rating: on line 8081-2553 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7586
% INFO    : Updated Thermal Rating: on line 12080-8081 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4875
% INFO    : Updated Thermal Rating: on line 12550-547 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2057
% INFO    : Updated Thermal Rating: on line 13242-12550 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1436
% INFO    : Updated Thermal Rating: on line 8669-1133 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2081
% INFO    : Updated Thermal Rating: on line 8669-4601 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4099
% INFO    : Updated Thermal Rating: on line 8669-4601 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4134
% INFO    : Updated Thermal Rating: on line 10113-7460 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4417
% INFO    : Updated Thermal Rating: on line 8486-579 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 949
% INFO    : Updated Thermal Rating: on line 8589-6233 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1439
% INFO    : Updated Thermal Rating: on line 8589-6233 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1415
% INFO    : Updated Thermal Rating: on line 6233-3890 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2980
% INFO    : Updated Thermal Rating: on line 6233-367 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2552
% INFO    : Updated Thermal Rating: on line 6233-3209 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 259
% INFO    : Updated Thermal Rating: on line 4508-3693 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 869
% INFO    : Updated Thermal Rating: on line 6330-10854 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3405
% INFO    : Updated Thermal Rating: on line 6330-1899 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7613
% INFO    : Updated Thermal Rating: on line 6330-12203 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 525
% INFO    : Updated Thermal Rating: on line 10854-13148 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25816
% INFO    : Updated Thermal Rating: on line 10854-11060 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1346
% INFO    : Updated Thermal Rating: on line 1899-536 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4001
% INFO    : Updated Thermal Rating: on line 536-11060 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 766
% INFO    : Updated Thermal Rating: on line 417-9249 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1652
% INFO    : Updated Thermal Rating: on line 8554-10592 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 527
% INFO    : Updated Thermal Rating: on line 12059-8554 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 517
% INFO    : Updated Thermal Rating: on line 1456-9536 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1630
% INFO    : Updated Thermal Rating: on line 1456-9518 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 1589-9988 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16802
% INFO    : Updated Thermal Rating: on line 12501-8782 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24710
% INFO    : Updated Thermal Rating: on line 11783-8495 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16377
% INFO    : Updated Thermal Rating: on line 4920-1236 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 726
% INFO    : Updated Thermal Rating: on line 10912-4920 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1407
% INFO    : Updated Thermal Rating: on line 10912-4920 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1436
% INFO    : Updated Thermal Rating: on line 9333-4265 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 76483
% INFO    : Updated Thermal Rating: on line 3177-9333 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 280
% INFO    : Updated Thermal Rating: on line 3177-9333 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 299
% INFO    : Updated Thermal Rating: on line 8948-9333 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 625
% INFO    : Updated Thermal Rating: on line 3177-12372 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1020
% INFO    : Updated Thermal Rating: on line 3177-12372 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1002
% INFO    : Updated Thermal Rating: on line 3177-11392 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 563
% INFO    : Updated Thermal Rating: on line 3177-3860 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 786
% INFO    : Updated Thermal Rating: on line 12184-3177 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 750
% INFO    : Updated Thermal Rating: on line 12184-3177 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 763
% INFO    : Updated Thermal Rating: on line 5962-8406 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 726
% INFO    : Updated Thermal Rating: on line 10449-5962 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 609
% INFO    : Updated Thermal Rating: on line 8068-1716 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2582
% INFO    : Updated Thermal Rating: on line 8068-13431 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 726
% INFO    : Updated Thermal Rating: on line 3935-10451 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 929
% INFO    : Updated Thermal Rating: on line 3935-10451 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 947
% INFO    : Updated Thermal Rating: on line 2386-3935 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1223
% INFO    : Updated Thermal Rating: on line 2386-3935 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1247
% INFO    : Updated Thermal Rating: on line 3935-12527 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1728
% INFO    : Updated Thermal Rating: on line 3935-3938 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3983
% INFO    : Updated Thermal Rating: on line 3935-4660 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3288
% INFO    : Updated Thermal Rating: on line 10103-12831 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 544
% INFO    : Updated Thermal Rating: on line 4595-9295 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 833
% INFO    : Updated Thermal Rating: on line 2074-9295 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 776
% INFO    : Updated Thermal Rating: on line 2409-1593 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 68669
% INFO    : Updated Thermal Rating: on line 8845-2409 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4597
% INFO    : Updated Thermal Rating: on line 11660-1593 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4506
% INFO    : Updated Thermal Rating: on line 13039-103 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 594
% INFO    : Updated Thermal Rating: on line 13039-8664 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1297
% INFO    : Updated Thermal Rating: on line 13039-8664 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1159
% INFO    : Updated Thermal Rating: on line 13039-12722 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2633
% INFO    : Updated Thermal Rating: on line 13039-13317 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1096
% INFO    : Updated Thermal Rating: on line 13039-7579 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1100
% INFO    : Updated Thermal Rating: on line 7246-9430 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7019
% INFO    : Updated Thermal Rating: on line 7246-5049 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6477
% INFO    : Updated Thermal Rating: on line 4019-2542 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 4019-8589 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142169
% INFO    : Updated Thermal Rating: on line 7891-8589 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 10902-8589 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7297
% INFO    : Updated Thermal Rating: on line 8813-7688 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12650
% INFO    : Updated Thermal Rating: on line 8813-7688 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11902
% INFO    : Updated Thermal Rating: on line 1848-11394 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 436
% INFO    : Updated Thermal Rating: on line 6070-11394 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 715
% INFO    : Updated Thermal Rating: on line 6070-11394 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 727
% INFO    : Updated Thermal Rating: on line 4008-11394 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 551
% INFO    : Updated Thermal Rating: on line 6190-8785 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20172
% INFO    : Updated Thermal Rating: on line 8785-7145 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 633
% INFO    : Updated Thermal Rating: on line 8785-13524 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 502
% INFO    : Updated Thermal Rating: on line 8785-13524 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 507
% INFO    : Updated Thermal Rating: on line 8827-8785 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 741
% INFO    : Updated Thermal Rating: on line 8827-8785 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 796
% INFO    : Updated Thermal Rating: on line 8785-10245 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1419
% INFO    : Updated Thermal Rating: on line 8785-10245 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1526
% INFO    : Updated Thermal Rating: on line 10694-8155 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 800
% INFO    : Updated Thermal Rating: on line 8155-11965 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 816
% INFO    : Updated Thermal Rating: on line 8155-1456 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 795
% INFO    : Updated Thermal Rating: on line 3753-8155 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1187
% INFO    : Updated Thermal Rating: on line 8155-3287 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 603
% INFO    : Updated Thermal Rating: on line 2834-6035 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 365
% INFO    : Updated Thermal Rating: on line 2697-6035 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2006
% INFO    : Updated Thermal Rating: on line 465-8406 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26367
% INFO    : Updated Thermal Rating: on line 12369-1112 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 70195
% INFO    : Updated Thermal Rating: on line 12369-12160 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2693
% INFO    : Updated Thermal Rating: on line 1112-12080 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2642
% INFO    : Updated Thermal Rating: on line 9653-11060 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4752
% INFO    : Updated Thermal Rating: on line 9653-11060 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4829
% INFO    : Updated Thermal Rating: on line 600-9653 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24150
% INFO    : Updated Thermal Rating: on line 8406-11060 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3935
% INFO    : Updated Thermal Rating: on line 8406-11060 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4244
% INFO    : Updated Thermal Rating: on line 8406-3794 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 683
% INFO    : Updated Thermal Rating: on line 8406-3794 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 730
% INFO    : Updated Thermal Rating: on line 2834-10113 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 353
% INFO    : Updated Thermal Rating: on line 2834-12501 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2028
% INFO    : Updated Thermal Rating: on line 3555-2834 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4258
% INFO    : Updated Thermal Rating: on line 766-9851 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7426
% INFO    : Updated Thermal Rating: on line 766-9851 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7495
% INFO    : Updated Thermal Rating: on line 766-9851 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7045
% INFO    : Updated Thermal Rating: on line 766-10948 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7409
% INFO    : Updated Thermal Rating: on line 103-11538 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2115
% INFO    : Updated Thermal Rating: on line 2386-10306 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1297
% INFO    : Updated Thermal Rating: on line 13611-7881 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1988
% INFO    : Updated Thermal Rating: on line 13611-7881 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2141
% INFO    : Updated Thermal Rating: on line 2682-6437 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2157
% INFO    : Updated Thermal Rating: on line 5180-2682 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9749
% INFO    : Updated Thermal Rating: on line 5180-525 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 130167
% INFO    : Updated Thermal Rating: on line 5180-1887 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 575
% INFO    : Updated Thermal Rating: on line 10694-12439 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12376
% INFO    : Updated Thermal Rating: on line 11965-12439 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12458
% INFO    : Updated Thermal Rating: on line 9365-13431 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1796
% INFO    : Updated Thermal Rating: on line 1259-12831 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2525
% INFO    : Updated Thermal Rating: on line 1259-6983 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 444
% INFO    : Updated Thermal Rating: on line 4743-547 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 60629
% INFO    : Updated Thermal Rating: on line 3408-1456 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 590
% INFO    : Updated Thermal Rating: on line 3408-445 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 764
% INFO    : Updated Thermal Rating: on line 3408-4601 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 628
% INFO    : Updated Thermal Rating: on line 8486-6882 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 130167
% INFO    : Updated Thermal Rating: on line 8486-103 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7004
% INFO    : Updated Thermal Rating: on line 8486-5733 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 702
% INFO    : Updated Thermal Rating: on line 8486-5733 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 756
% INFO    : Updated Thermal Rating: on line 7579-8486 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1234
% INFO    : Updated Thermal Rating: on line 6264-1714 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2199
% INFO    : Updated Thermal Rating: on line 694-8968 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 962
% INFO    : Updated Thermal Rating: on line 5815-694 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 694-9851 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9746
% INFO    : Updated Thermal Rating: on line 694-9851 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9916
% INFO    : Updated Thermal Rating: on line 694-9851 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8979
% INFO    : Updated Thermal Rating: on line 694-10336 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2042
% INFO    : Updated Thermal Rating: on line 694-520 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2003
% INFO    : Updated Thermal Rating: on line 694-2388 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1966
% INFO    : Updated Thermal Rating: on line 9063-10706 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3263
% INFO    : Updated Thermal Rating: on line 9063-10706 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3222
% INFO    : Updated Thermal Rating: on line 939-464 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2416
% INFO    : Updated Thermal Rating: on line 8845-11660 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 61936
% INFO    : Updated Thermal Rating: on line 8768-11660 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2382
% INFO    : Updated Thermal Rating: on line 10912-9802 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 10912-11228 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2799
% INFO    : Updated Thermal Rating: on line 10912-7432 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1041
% INFO    : Updated Thermal Rating: on line 13558-10912 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3018
% INFO    : Updated Thermal Rating: on line 9802-5649 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142169
% INFO    : Updated Thermal Rating: on line 9802-7432 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1022
% INFO    : Updated Thermal Rating: on line 5649-7432 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1004
% INFO    : Updated Thermal Rating: on line 1062-5855 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 558
% INFO    : Updated Thermal Rating: on line 12289-1062 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 908
% INFO    : Updated Thermal Rating: on line 12527-4661 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3326
% INFO    : Updated Thermal Rating: on line 3938-4661 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2982
% INFO    : Updated Thermal Rating: on line 4660-4661 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4156
% INFO    : Updated Thermal Rating: on line 12372-6307 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 636
% INFO    : Updated Thermal Rating: on line 12372-6307 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 686
% INFO    : Updated Thermal Rating: on line 3954-2815 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2582
% INFO    : Updated Thermal Rating: on line 3954-2815 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2626
% INFO    : Updated Thermal Rating: on line 2733-3001 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 11997-2733 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2481
% INFO    : Updated Thermal Rating: on line 11997-2733 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2527
% INFO    : Updated Thermal Rating: on line 2733-8098 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1107
% INFO    : Updated Thermal Rating: on line 2733-8098 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1129
% INFO    : Updated Thermal Rating: on line 2733-11519 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1151
% INFO    : Updated Thermal Rating: on line 6480-5049 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1570
% INFO    : Updated Thermal Rating: on line 6480-5049 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1597
% INFO    : Updated Thermal Rating: on line 9064-1589 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 512
% INFO    : Updated Thermal Rating: on line 9064-3954 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 920
% INFO    : Updated Thermal Rating: on line 9064-3954 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 904
% INFO    : Updated Thermal Rating: on line 9064-9080 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1352
% INFO    : Updated Thermal Rating: on line 2553-7960 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 60745
% INFO    : Updated Thermal Rating: on line 1456-7099 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 1456-4601 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 332
% INFO    : Updated Thermal Rating: on line 3753-1456 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3569
% INFO    : Updated Thermal Rating: on line 1456-13414 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3645
% INFO    : Updated Thermal Rating: on line 10451-12642 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2244
% INFO    : Updated Thermal Rating: on line 3794-12203 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3086
% INFO    : Updated Thermal Rating: on line 11313-199 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 59487
% INFO    : Updated Thermal Rating: on line 11313-7752 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1993
% INFO    : Updated Thermal Rating: on line 199-13242 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1957
% INFO    : Updated Thermal Rating: on line 1848-6983 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 645
% INFO    : Updated Thermal Rating: on line 1848-6983 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 657
% INFO    : Updated Thermal Rating: on line 1848-4008 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1268
% INFO    : Updated Thermal Rating: on line 2386-4817 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 726
% INFO    : Updated Thermal Rating: on line 507-8951 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 786
% INFO    : Updated Thermal Rating: on line 367-12734 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 4653-8261 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 59599
% INFO    : Updated Thermal Rating: on line 4653-6366 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 58496
% INFO    : Updated Thermal Rating: on line 2386-13252 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3028
% INFO    : Updated Thermal Rating: on line 2386-2165 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2946
% INFO    : Updated Thermal Rating: on line 8664-12958 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 771
% INFO    : Updated Thermal Rating: on line 8664-8239 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 757
% INFO    : Updated Thermal Rating: on line 2074-4595 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2298
% INFO    : Updated Thermal Rating: on line 8664-9249 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1322
% INFO    : Updated Thermal Rating: on line 8664-9249 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1425
% INFO    : Updated Thermal Rating: on line 2792-10205 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 75878
% INFO    : Updated Thermal Rating: on line 2792-12160 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1898
% INFO    : Updated Thermal Rating: on line 6333-6237 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 58604
% INFO    : Updated Thermal Rating: on line 6333-113 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2236
% INFO    : Updated Thermal Rating: on line 10205-12080 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2328
% INFO    : Updated Thermal Rating: on line 6237-48 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1977
% INFO    : Updated Thermal Rating: on line 6307-8804 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 464
% INFO    : Updated Thermal Rating: on line 6307-8948 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1123
% INFO    : Updated Thermal Rating: on line 6307-8948 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1151
% INFO    : Updated Thermal Rating: on line 13252-2165 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9475
% INFO    : Updated Thermal Rating: on line 8418-3479 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 130167
% INFO    : Updated Thermal Rating: on line 507-1804 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 580
% INFO    : Updated Thermal Rating: on line 507-2998 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 570
% INFO    : Updated Thermal Rating: on line 507-13166 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 615
% INFO    : Updated Thermal Rating: on line 6070-6983 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 474
% INFO    : Updated Thermal Rating: on line 6070-2552 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 623
% INFO    : Updated Thermal Rating: on line 7059-12352 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18078
% INFO    : Updated Thermal Rating: on line 7725-12352 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6280
% INFO    : Updated Thermal Rating: on line 8804-12352 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 945
% INFO    : Updated Thermal Rating: on line 11783-11627 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 11783-8990 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 50125
% INFO    : Updated Thermal Rating: on line 5835-4914 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1750
% INFO    : Updated Thermal Rating: on line 10953-3890 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 3044-9782 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1789
% INFO    : Updated Thermal Rating: on line 13244-6183 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1828
% INFO    : Updated Thermal Rating: on line 7412-12253 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1938
% INFO    : Updated Thermal Rating: on line 10651-4914 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1582
% INFO    : Updated Thermal Rating: on line 9404-4914 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1553
% INFO    : Updated Thermal Rating: on line 8583-8758 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12610
% INFO    : Updated Thermal Rating: on line 7000-4914 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1523
% INFO    : Updated Thermal Rating: on line 11827-12253 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1645
% INFO    : Updated Thermal Rating: on line 12504-12253 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1679
% INFO    : Updated Thermal Rating: on line 9782-6183 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 64464
% INFO    : Updated Thermal Rating: on line 6934-9782 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 65807
% INFO    : Updated Thermal Rating: on line 11543-6183 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 67208
% INFO    : Updated Thermal Rating: on line 4914-8593 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 68669
% INFO    : Updated Thermal Rating: on line 4914-616 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 70195
% INFO    : Updated Thermal Rating: on line 4914-13170 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 61936
% INFO    : Updated Thermal Rating: on line 12253-11543 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 60745
% INFO    : Updated Thermal Rating: on line 12253-6934 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 59599
% INFO    : Updated Thermal Rating: on line 12253-13170 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 58496
% INFO    : Updated Thermal Rating: on line 8593-8872 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 63175
% INFO    : Updated Thermal Rating: on line 8872-11543 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 64464
% INFO    : Updated Thermal Rating: on line 8872-5998 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7820
% INFO    : Updated Thermal Rating: on line 9167-8872 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7966
% INFO    : Updated Thermal Rating: on line 616-4211 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 65807
% INFO    : Updated Thermal Rating: on line 4211-6934 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 67208
% INFO    : Updated Thermal Rating: on line 4211-8583 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7996
% INFO    : Updated Thermal Rating: on line 6578-4211 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7810
% INFO    : Updated Thermal Rating: on line 3890-367 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 367-818 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 12527-3938 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1486
% INFO    : Updated Thermal Rating: on line 12527-4660 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2710
% INFO    : Updated Thermal Rating: on line 9851-12368 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17144
% INFO    : Updated Thermal Rating: on line 9851-12368 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16976
% INFO    : Updated Thermal Rating: on line 9851-12368 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18102
% INFO    : Updated Thermal Rating: on line 548-464 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2362
% INFO    : Updated Thermal Rating: on line 548-464 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2126
% INFO    : Updated Thermal Rating: on line 1589-3666 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6539
% INFO    : Updated Thermal Rating: on line 1589-10661 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2688
% INFO    : Updated Thermal Rating: on line 1589-9080 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 815
% INFO    : Updated Thermal Rating: on line 13611-2763 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4392
% INFO    : Updated Thermal Rating: on line 10948-2763 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4473
% INFO    : Updated Thermal Rating: on line 6483-13524 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 573
% INFO    : Updated Thermal Rating: on line 6483-13524 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 537
% INFO    : Updated Thermal Rating: on line 11331-6483 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 510
% INFO    : Updated Thermal Rating: on line 8139-7810 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3726
% INFO    : Updated Thermal Rating: on line 8813-6506 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 646
% INFO    : Updated Thermal Rating: on line 8813-6506 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 635
% INFO    : Updated Thermal Rating: on line 11790-9541 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 7432-11790 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6511
% INFO    : Updated Thermal Rating: on line 7442-1781 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 264
% INFO    : Updated Thermal Rating: on line 507-7810 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4845
% INFO    : Updated Thermal Rating: on line 507-7810 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4307
% INFO    : Updated Thermal Rating: on line 7752-13242 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 63175
% INFO    : Updated Thermal Rating: on line 13608-12831 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 312
% INFO    : Updated Thermal Rating: on line 12831-6983 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 391
% INFO    : Updated Thermal Rating: on line 11228-558 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 343
% INFO    : Updated Thermal Rating: on line 11228-1738 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 337
% INFO    : Updated Thermal Rating: on line 11228-5890 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 330
% INFO    : Updated Thermal Rating: on line 8554-11228 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2883
% INFO    : Updated Thermal Rating: on line 8827-2697 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 529
% INFO    : Updated Thermal Rating: on line 8827-2697 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 476
% INFO    : Updated Thermal Rating: on line 6264-5106 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 130167
% INFO    : Updated Thermal Rating: on line 6264-6959 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 910
% INFO    : Updated Thermal Rating: on line 6264-6959 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 928
% INFO    : Updated Thermal Rating: on line 6264-11685 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 873
% INFO    : Updated Thermal Rating: on line 6264-11685 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 891
% INFO    : Updated Thermal Rating: on line 6264-12180 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1181
% INFO    : Updated Thermal Rating: on line 6264-12180 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1204
% INFO    : Updated Thermal Rating: on line 6264-12180 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1228
% INFO    : Updated Thermal Rating: on line 5733-1887 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1221
% INFO    : Updated Thermal Rating: on line 12722-65 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1653
% INFO    : Updated Thermal Rating: on line 11462-4886 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 68669
% INFO    : Updated Thermal Rating: on line 11462-9879 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 70195
% INFO    : Updated Thermal Rating: on line 8768-4886 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 61936
% INFO    : Updated Thermal Rating: on line 8768-9879 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 60745
% INFO    : Updated Thermal Rating: on line 3666-10661 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 32900
% INFO    : Updated Thermal Rating: on line 12180-5462 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 628
% INFO    : Updated Thermal Rating: on line 4950-6959 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 1927-5125 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 64464
% INFO    : Updated Thermal Rating: on line 1927-1508 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1396
% INFO    : Updated Thermal Rating: on line 1927-113 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2464
% INFO    : Updated Thermal Rating: on line 5125-5693 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1426
% INFO    : Updated Thermal Rating: on line 5125-48 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2514
% INFO    : Updated Thermal Rating: on line 279-7432 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2240
% INFO    : Updated Thermal Rating: on line 7103-7432 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2289
% INFO    : Updated Thermal Rating: on line 5437-7432 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2339
% INFO    : Updated Thermal Rating: on line 9249-792 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1282
% INFO    : Updated Thermal Rating: on line 9249-792 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1306
% INFO    : Updated Thermal Rating: on line 8554-9810 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15892
% INFO    : Updated Thermal Rating: on line 7128-9810 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17637
% INFO    : Updated Thermal Rating: on line 8554-5141 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7638
% INFO    : Updated Thermal Rating: on line 8554-5141 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7011
% INFO    : Updated Thermal Rating: on line 8554-5549 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11524
% INFO    : Updated Thermal Rating: on line 7432-5141 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 7432-8696 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 130167
% INFO    : Updated Thermal Rating: on line 13558-7432 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5467
% INFO    : Updated Thermal Rating: on line 7432-6696 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2308
% INFO    : Updated Thermal Rating: on line 3192-7432 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6522
% INFO    : Updated Thermal Rating: on line 5141-7128 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18040
% INFO    : Updated Thermal Rating: on line 5549-5141 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18462
% INFO    : Updated Thermal Rating: on line 8829-9430 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6902
% INFO    : Updated Thermal Rating: on line 7652-9430 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6774
% INFO    : Updated Thermal Rating: on line 6983-2552 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1070
% INFO    : Updated Thermal Rating: on line 10137-10637 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 269
% INFO    : Updated Thermal Rating: on line 1730-7801 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 130167
% INFO    : Updated Thermal Rating: on line 507-1730 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 692
% INFO    : Updated Thermal Rating: on line 507-1730 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 679
% INFO    : Updated Thermal Rating: on line 12571-3860 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1735
% INFO    : Updated Thermal Rating: on line 4660-12053 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 817
% INFO    : Updated Thermal Rating: on line 6872-11331 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 477
% INFO    : Updated Thermal Rating: on line 65-3578 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 130167
% INFO    : Updated Thermal Rating: on line 65-13317 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4778
% INFO    : Updated Thermal Rating: on line 65-1300 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5704
% INFO    : Updated Thermal Rating: on line 65-1300 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5754
% INFO    : Updated Thermal Rating: on line 10209-599 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1061
% INFO    : Updated Thermal Rating: on line 10209-599 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1078
% INFO    : Updated Thermal Rating: on line 4508-8813 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2460
% INFO    : Updated Thermal Rating: on line 4508-8813 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2417
% INFO    : Updated Thermal Rating: on line 4508-11218 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 8990-7919 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 9157-5602 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 130167
% INFO    : Updated Thermal Rating: on line 507-10492 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 130167
% INFO    : Updated Thermal Rating: on line 13431-1406 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 130167
% INFO    : Updated Thermal Rating: on line 13611-4584 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 130167
% INFO    : Updated Thermal Rating: on line 13611-6959 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2359
% INFO    : Updated Thermal Rating: on line 13611-6959 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2397
% INFO    : Updated Thermal Rating: on line 13611-6959 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1696
% INFO    : Updated Thermal Rating: on line 5855-13410 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 904
% INFO    : Updated Thermal Rating: on line 4832-6959 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 6959-1531 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 851
% INFO    : Updated Thermal Rating: on line 6959-6569 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 9242-6959 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 6997-5334 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5869
% INFO    : Updated Thermal Rating: on line 4601-445 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 884
% INFO    : Updated Thermal Rating: on line 10948-2072 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5906
% INFO    : Updated Thermal Rating: on line 10948-2072 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6314
% INFO    : Updated Thermal Rating: on line 1508-5693 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 65945
% INFO    : Updated Thermal Rating: on line 1508-9483 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1997
% INFO    : Updated Thermal Rating: on line 5693-7724 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2141
% INFO    : Updated Thermal Rating: on line 12184-11881 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1111
% INFO    : Updated Thermal Rating: on line 12184-13495 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 664
% INFO    : Updated Thermal Rating: on line 113-48 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 67351
% INFO    : Updated Thermal Rating: on line 4601-2827 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 130167
% INFO    : Updated Thermal Rating: on line 3954-4601 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1240
% INFO    : Updated Thermal Rating: on line 3954-4601 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1260
% INFO    : Updated Thermal Rating: on line 13495-11881 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1469
% INFO    : Updated Thermal Rating: on line 8829-7652 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 6578-583 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20958
% INFO    : Updated Thermal Rating: on line 8504-9167 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20835
% INFO    : Updated Thermal Rating: on line 3555-12501 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 443
% INFO    : Updated Thermal Rating: on line 583-8504 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 59599
% INFO    : Updated Thermal Rating: on line 9483-7724 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 68520
% INFO    : Updated Thermal Rating: on line 12160-12080 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 58496
% INFO    : Updated Thermal Rating: on line 10245-12289 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5165
% INFO    : Updated Thermal Rating: on line 12289-10245 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4920
% INFO    : Updated Thermal Rating: on line 8827-10245 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1616
% INFO    : Updated Thermal Rating: on line 8827-10245 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1687
% INFO    : Updated Thermal Rating: on line 8827-13410 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 693
% INFO    : Updated Thermal Rating: on line 8827-13410 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 682
% INFO    : Updated Thermal Rating: on line 8098-11519 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 3753-12784 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 59712
% INFO    : Updated Thermal Rating: on line 13414-12784 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 60745
% INFO    : Updated Thermal Rating: on line 3287-13414 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1003
% INFO    : Updated Thermal Rating: on line 3601-9145 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 60
% INFO    : Updated Thermal Rating: on line 4373-9145 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 420
% INFO    : Updated Thermal Rating: on line 7999-9145 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 678
% INFO    : Updated Thermal Rating: on line 5745-9145 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 466
% INFO    : Updated Thermal Rating: on line 8031-1506 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 75
% INFO    : Updated Thermal Rating: on line 8031-1506 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1001
% INFO    : Updated Thermal Rating: on line 1506-633 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19
% INFO    : Updated Thermal Rating: on line 1506-7690 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 513
% INFO    : Updated Thermal Rating: on line 1506-12514 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 36
% INFO    : Updated Thermal Rating: on line 8031-1506 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 958
% INFO    : Updated Thermal Rating: on line 1506-12514 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1207
% INFO    : Updated Thermal Rating: on line 12798-5651 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2445
% INFO    : Updated Thermal Rating: on line 5867-5651 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 135
% INFO    : Updated Thermal Rating: on line 7423-9801 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6515
% INFO    : Updated Thermal Rating: on line 4104-12032 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6649
% INFO    : Updated Thermal Rating: on line 6716-6737 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52
% INFO    : Updated Thermal Rating: on line 12597-6737 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 86
% INFO    : Updated Thermal Rating: on line 7534-6737 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2532
% INFO    : Updated Thermal Rating: on line 12597-6716 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 79
% INFO    : Updated Thermal Rating: on line 1998-6716 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2486
% INFO    : Updated Thermal Rating: on line 10689-1379 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 558
% INFO    : Updated Thermal Rating: on line 7749-3514 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 7749-3514 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 97
% INFO    : Updated Thermal Rating: on line 5321-3514 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21
% INFO    : Updated Thermal Rating: on line 1063-3514 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22
% INFO    : Updated Thermal Rating: on line 1063-3514 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 418
% INFO    : Updated Thermal Rating: on line 2109-3514 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 61
% INFO    : Updated Thermal Rating: on line 2619-3514 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 45
% INFO    : Updated Thermal Rating: on line 11043-3514 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19
% INFO    : Updated Thermal Rating: on line 6113-7749 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2460
% INFO    : Updated Thermal Rating: on line 5321-7749 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21
% INFO    : Updated Thermal Rating: on line 1063-7749 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25
% INFO    : Updated Thermal Rating: on line 2109-7749 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 57
% INFO    : Updated Thermal Rating: on line 2619-7749 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 42
% INFO    : Updated Thermal Rating: on line 11043-7749 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20
% INFO    : Updated Thermal Rating: on line 10849-5015 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 795
% INFO    : Updated Thermal Rating: on line 12209-5015 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 50
% INFO    : Updated Thermal Rating: on line 3967-5015 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 29
% INFO    : Updated Thermal Rating: on line 5015-9811 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 567
% INFO    : Updated Thermal Rating: on line 4325-5015 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 42
% INFO    : Updated Thermal Rating: on line 8076-933 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 94
% INFO    : Updated Thermal Rating: on line 933-8076 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 858
% INFO    : Updated Thermal Rating: on line 246-933 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1857
% INFO    : Updated Thermal Rating: on line 246-933 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 129
% INFO    : Updated Thermal Rating: on line 9654-933 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 122
% INFO    : Updated Thermal Rating: on line 5298-933 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 84
% INFO    : Updated Thermal Rating: on line 9643-9177 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 817
% INFO    : Updated Thermal Rating: on line 857-9177 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4656
% INFO    : Updated Thermal Rating: on line 5321-9177 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2611
% INFO    : Updated Thermal Rating: on line 13650-9177 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5094
% INFO    : Updated Thermal Rating: on line 13263-6113 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1069
% INFO    : Updated Thermal Rating: on line 2619-6113 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1145
% INFO    : Updated Thermal Rating: on line 8240-6113 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2304
% INFO    : Updated Thermal Rating: on line 3037-6113 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 681
% INFO    : Updated Thermal Rating: on line 9335-9643 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1388
% INFO    : Updated Thermal Rating: on line 8240-9643 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2486
% INFO    : Updated Thermal Rating: on line 11043-9643 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 734
% INFO    : Updated Thermal Rating: on line 9643-10993 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2152
% INFO    : Updated Thermal Rating: on line 9104-4911 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 998
% INFO    : Updated Thermal Rating: on line 13061-9104 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3894
% INFO    : Updated Thermal Rating: on line 10513-4322 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 117
% INFO    : Updated Thermal Rating: on line 10513-4322 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1551
% INFO    : Updated Thermal Rating: on line 13357-4322 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 106
% INFO    : Updated Thermal Rating: on line 10689-10131 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1127
% INFO    : Updated Thermal Rating: on line 5745-10689 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 948
% INFO    : Updated Thermal Rating: on line 10131-10689 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 786
% INFO    : Updated Thermal Rating: on line 10131-10689 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 32
% INFO    : Updated Thermal Rating: on line 6712-10689 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 50
% INFO    : Updated Thermal Rating: on line 4373-3601 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 30
% INFO    : Updated Thermal Rating: on line 4373-3601 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 604
% INFO    : Updated Thermal Rating: on line 2926-3601 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21
% INFO    : Updated Thermal Rating: on line 8076-4736 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 818
% INFO    : Updated Thermal Rating: on line 246-8076 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25
% INFO    : Updated Thermal Rating: on line 9654-8076 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 28
% INFO    : Updated Thermal Rating: on line 5298-8076 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20
% INFO    : Updated Thermal Rating: on line 10338-5572 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1118
% INFO    : Updated Thermal Rating: on line 317-5572 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1705
% INFO    : Updated Thermal Rating: on line 10265-12450 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19
% INFO    : Updated Thermal Rating: on line 4850-12450 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 361
% INFO    : Updated Thermal Rating: on line 10697-12450 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 32
% INFO    : Updated Thermal Rating: on line 399-12450 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1308
% INFO    : Updated Thermal Rating: on line 399-12450 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 59
% INFO    : Updated Thermal Rating: on line 9019-12450 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52
% INFO    : Updated Thermal Rating: on line 8333-4051 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 781
% INFO    : Updated Thermal Rating: on line 4051-2619 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2102
% INFO    : Updated Thermal Rating: on line 317-6653 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1409
% INFO    : Updated Thermal Rating: on line 6653-9356 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 798
% INFO    : Updated Thermal Rating: on line 6653-9162 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1103
% INFO    : Updated Thermal Rating: on line 537-8472 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3483
% INFO    : Updated Thermal Rating: on line 3952-537 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3560
% INFO    : Updated Thermal Rating: on line 9705-5950 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1006
% INFO    : Updated Thermal Rating: on line 8472-530 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1702
% INFO    : Updated Thermal Rating: on line 530-7328 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1097
% INFO    : Updated Thermal Rating: on line 8472-530 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 76
% INFO    : Updated Thermal Rating: on line 9356-13654 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3857
% INFO    : Updated Thermal Rating: on line 11590-6644 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27
% INFO    : Updated Thermal Rating: on line 13563-6644 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27
% INFO    : Updated Thermal Rating: on line 12963-6644 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 57
% INFO    : Updated Thermal Rating: on line 12963-6644 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 421
% INFO    : Updated Thermal Rating: on line 1107-6644 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 33
% INFO    : Updated Thermal Rating: on line 12187-6246 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 12187-6246 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 62
% INFO    : Updated Thermal Rating: on line 6246-11045 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6236
% INFO    : Updated Thermal Rating: on line 6246-7601 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1145
% INFO    : Updated Thermal Rating: on line 1405-12187 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1105
% INFO    : Updated Thermal Rating: on line 12187-3952 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1775
% INFO    : Updated Thermal Rating: on line 8216-12361 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 8216-12361 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 48
% INFO    : Updated Thermal Rating: on line 12361-10513 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 226
% INFO    : Updated Thermal Rating: on line 8216-5950 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 297
% INFO    : Updated Thermal Rating: on line 11045-3952 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2359
% INFO    : Updated Thermal Rating: on line 488-9973 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17
% INFO    : Updated Thermal Rating: on line 7101-9973 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 82
% INFO    : Updated Thermal Rating: on line 7101-9973 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 802
% INFO    : Updated Thermal Rating: on line 11541-9973 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 96
% INFO    : Updated Thermal Rating: on line 13004-9973 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4418
% INFO    : Updated Thermal Rating: on line 7101-488 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 29
% INFO    : Updated Thermal Rating: on line 7101-488 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 419
% INFO    : Updated Thermal Rating: on line 843-488 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 43
% INFO    : Updated Thermal Rating: on line 11297-488 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 37
% INFO    : Updated Thermal Rating: on line 11297-488 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 433
% INFO    : Updated Thermal Rating: on line 11541-488 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 61
% INFO    : Updated Thermal Rating: on line 10697-488 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25
% INFO    : Updated Thermal Rating: on line 399-488 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19
% INFO    : Updated Thermal Rating: on line 4669-3967 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 835
% INFO    : Updated Thermal Rating: on line 5298-4669 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 574
% INFO    : Updated Thermal Rating: on line 5153-6887 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 5153-6887 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 95
% INFO    : Updated Thermal Rating: on line 6887-5474 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 776
% INFO    : Updated Thermal Rating: on line 5153-13357 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 673
% INFO    : Updated Thermal Rating: on line 4243-7601 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1127
% INFO    : Updated Thermal Rating: on line 3967-12209 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 47
% INFO    : Updated Thermal Rating: on line 5321-12209 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18
% INFO    : Updated Thermal Rating: on line 2109-12209 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2981
% INFO    : Updated Thermal Rating: on line 2109-12209 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 92
% INFO    : Updated Thermal Rating: on line 12267-12209 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 31
% INFO    : Updated Thermal Rating: on line 8333-12209 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 41
% INFO    : Updated Thermal Rating: on line 4325-12209 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 107
% INFO    : Updated Thermal Rating: on line 10849-12209 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 47
% INFO    : Updated Thermal Rating: on line 5867-12209 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18
% INFO    : Updated Thermal Rating: on line 4463-12209 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 63
% INFO    : Updated Thermal Rating: on line 2109-12209 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112
% INFO    : Updated Thermal Rating: on line 9811-12209 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 58
% INFO    : Updated Thermal Rating: on line 10993-12209 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1887
% INFO    : Updated Thermal Rating: on line 10273-12798 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3555
% INFO    : Updated Thermal Rating: on line 5867-10273 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8080
% INFO    : Updated Thermal Rating: on line 9811-13263 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3569
% INFO    : Updated Thermal Rating: on line 4463-13263 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 114
% INFO    : Updated Thermal Rating: on line 8240-13263 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 48
% INFO    : Updated Thermal Rating: on line 7817-10020 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 7817-10020 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 136
% INFO    : Updated Thermal Rating: on line 10020-12998 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 374
% INFO    : Updated Thermal Rating: on line 633-10020 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 35
% INFO    : Updated Thermal Rating: on line 633-10020 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1873
% INFO    : Updated Thermal Rating: on line 7690-10020 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 54
% INFO    : Updated Thermal Rating: on line 12597-10020 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1010
% INFO    : Updated Thermal Rating: on line 12514-10020 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 58
% INFO    : Updated Thermal Rating: on line 633-7817 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 35
% INFO    : Updated Thermal Rating: on line 7690-7817 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52
% INFO    : Updated Thermal Rating: on line 7817-7534 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 757
% INFO    : Updated Thermal Rating: on line 12514-7817 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 55
% INFO    : Updated Thermal Rating: on line 12514-7817 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 697
% INFO    : Updated Thermal Rating: on line 13357-10513 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 13357-10513 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 166
% INFO    : Updated Thermal Rating: on line 10513-4850 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 352
% INFO    : Updated Thermal Rating: on line 13357-4850 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 460
% INFO    : Updated Thermal Rating: on line 4972-12798 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1021
% INFO    : Updated Thermal Rating: on line 7534-12798 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 554
% INFO    : Updated Thermal Rating: on line 2867-12798 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 458
% INFO    : Updated Thermal Rating: on line 1998-12798 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 530
% INFO    : Updated Thermal Rating: on line 12798-10968 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6573
% INFO    : Updated Thermal Rating: on line 3159-9356 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1787
% INFO    : Updated Thermal Rating: on line 4318-3159 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1749
% INFO    : Updated Thermal Rating: on line 3159-11162 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1790
% INFO    : Updated Thermal Rating: on line 9811-4463 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2484
% INFO    : Updated Thermal Rating: on line 8240-4463 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 53
% INFO    : Updated Thermal Rating: on line 2109-4463 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 58
% INFO    : Updated Thermal Rating: on line 2109-4463 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1244
% INFO    : Updated Thermal Rating: on line 9811-4463 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 91
% INFO    : Updated Thermal Rating: on line 4325-3967 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 60
% INFO    : Updated Thermal Rating: on line 3967-4325 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1007
% INFO    : Updated Thermal Rating: on line 4972-9335 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1340
% INFO    : Updated Thermal Rating: on line 10187-2867 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1975
% INFO    : Updated Thermal Rating: on line 9015-2867 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 509
% INFO    : Updated Thermal Rating: on line 2867-4972 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 420
% INFO    : Updated Thermal Rating: on line 5874-2867 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1708
% INFO    : Updated Thermal Rating: on line 5039-1141 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1119
% INFO    : Updated Thermal Rating: on line 7423-4104 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 7423-4104 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 62
% INFO    : Updated Thermal Rating: on line 4104-10131 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 764
% INFO    : Updated Thermal Rating: on line 4104-10131 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18
% INFO    : Updated Thermal Rating: on line 4104-3037 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 384
% INFO    : Updated Thermal Rating: on line 7423-8020 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 474
% INFO    : Updated Thermal Rating: on line 7423-10131 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25
% INFO    : Updated Thermal Rating: on line 1063-5321 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 1063-5321 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 57
% INFO    : Updated Thermal Rating: on line 2109-5321 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 49
% INFO    : Updated Thermal Rating: on line 12267-5321 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25
% INFO    : Updated Thermal Rating: on line 8333-5321 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20
% INFO    : Updated Thermal Rating: on line 2619-5321 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 43
% INFO    : Updated Thermal Rating: on line 4325-5321 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16
% INFO    : Updated Thermal Rating: on line 10849-5321 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17
% INFO    : Updated Thermal Rating: on line 2109-1063 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 53
% INFO    : Updated Thermal Rating: on line 12267-1063 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26
% INFO    : Updated Thermal Rating: on line 2619-1063 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 39
% INFO    : Updated Thermal Rating: on line 4850-8031 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9640
% INFO    : Updated Thermal Rating: on line 8031-5555 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 280
% INFO    : Updated Thermal Rating: on line 8031-12514 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17
% INFO    : Updated Thermal Rating: on line 4850-8031 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9813
% INFO    : Updated Thermal Rating: on line 9811-2109 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 54
% INFO    : Updated Thermal Rating: on line 4325-2109 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1536
% INFO    : Updated Thermal Rating: on line 12267-2109 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 36
% INFO    : Updated Thermal Rating: on line 8333-2109 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 53
% INFO    : Updated Thermal Rating: on line 2619-2109 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 41
% INFO    : Updated Thermal Rating: on line 4325-2109 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 43
% INFO    : Updated Thermal Rating: on line 10849-2109 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 38
% INFO    : Updated Thermal Rating: on line 7741-2121 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 7741-2121 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 163
% INFO    : Updated Thermal Rating: on line 2121-2754 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 432
% INFO    : Updated Thermal Rating: on line 2121-561 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 424
% INFO    : Updated Thermal Rating: on line 7999-2121 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 827
% INFO    : Updated Thermal Rating: on line 9015-2121 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20
% INFO    : Updated Thermal Rating: on line 9015-2121 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 809
% INFO    : Updated Thermal Rating: on line 13206-2121 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19
% INFO    : Updated Thermal Rating: on line 7999-7741 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 844
% INFO    : Updated Thermal Rating: on line 9015-7741 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22
% INFO    : Updated Thermal Rating: on line 13206-7741 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19
% INFO    : Updated Thermal Rating: on line 13206-7741 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 689
% INFO    : Updated Thermal Rating: on line 4071-5525 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1961
% INFO    : Updated Thermal Rating: on line 6805-4071 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1409
% INFO    : Updated Thermal Rating: on line 2040-4071 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1446
% INFO    : Updated Thermal Rating: on line 5874-10187 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 148
% INFO    : Updated Thermal Rating: on line 9015-10187 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19
% INFO    : Updated Thermal Rating: on line 13206-10187 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20
% INFO    : Updated Thermal Rating: on line 11541-7101 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 136
% INFO    : Updated Thermal Rating: on line 11541-7101 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 887
% INFO    : Updated Thermal Rating: on line 7328-1585 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3072
% INFO    : Updated Thermal Rating: on line 1597-1585 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 644
% INFO    : Updated Thermal Rating: on line 13169-8011 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1982
% INFO    : Updated Thermal Rating: on line 13169-4911 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1975
% INFO    : Updated Thermal Rating: on line 374-10360 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1481
% INFO    : Updated Thermal Rating: on line 374-12364 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1841
% INFO    : Updated Thermal Rating: on line 374-12364 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1882
% INFO    : Updated Thermal Rating: on line 1597-374 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 111
% INFO    : Updated Thermal Rating: on line 1597-374 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4065
% INFO    : Updated Thermal Rating: on line 1597-374 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3989
% INFO    : Updated Thermal Rating: on line 4972-9811 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 47
% INFO    : Updated Thermal Rating: on line 5867-9811 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 31
% INFO    : Updated Thermal Rating: on line 10993-9811 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1531
% INFO    : Updated Thermal Rating: on line 9811-10968 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 858
% INFO    : Updated Thermal Rating: on line 11767-11162 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3547
% INFO    : Updated Thermal Rating: on line 13061-11767 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5908
% INFO    : Updated Thermal Rating: on line 399-10265 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 607
% INFO    : Updated Thermal Rating: on line 399-10265 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16
% INFO    : Updated Thermal Rating: on line 10265-5560 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 596
% INFO    : Updated Thermal Rating: on line 9019-10265 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 49
% INFO    : Updated Thermal Rating: on line 8240-4972 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 924
% INFO    : Updated Thermal Rating: on line 5867-4972 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 38
% INFO    : Updated Thermal Rating: on line 11297-843 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 11297-843 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 99
% INFO    : Updated Thermal Rating: on line 843-9320 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1808
% INFO    : Updated Thermal Rating: on line 611-843 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24
% INFO    : Updated Thermal Rating: on line 843-611 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 511
% INFO    : Updated Thermal Rating: on line 11297-2452 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 357
% INFO    : Updated Thermal Rating: on line 1363-11297 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16
% INFO    : Updated Thermal Rating: on line 611-11297 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 39
% INFO    : Updated Thermal Rating: on line 2619-8020 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16
% INFO    : Updated Thermal Rating: on line 8240-8020 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 47
% INFO    : Updated Thermal Rating: on line 8020-8240 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 953
% INFO    : Updated Thermal Rating: on line 8020-8240 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 800
% INFO    : Updated Thermal Rating: on line 11043-8020 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 54
% INFO    : Updated Thermal Rating: on line 3037-8020 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 85
% INFO    : Updated Thermal Rating: on line 314-8020 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 160
% INFO    : Updated Thermal Rating: on line 314-8020 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2532
% INFO    : Updated Thermal Rating: on line 5560-2452 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 393
% INFO    : Updated Thermal Rating: on line 246-2452 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 406
% INFO    : Updated Thermal Rating: on line 4736-2452 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 4736-2452 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 123
% INFO    : Updated Thermal Rating: on line 9654-2452 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 414
% INFO    : Updated Thermal Rating: on line 1363-4736 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 424
% INFO    : Updated Thermal Rating: on line 7843-7483 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 657
% INFO    : Updated Thermal Rating: on line 3208-7483 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17
% INFO    : Updated Thermal Rating: on line 12963-7483 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 291
% INFO    : Updated Thermal Rating: on line 561-7483 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 30
% INFO    : Updated Thermal Rating: on line 7843-7483 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27
% INFO    : Updated Thermal Rating: on line 5525-733 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2180
% INFO    : Updated Thermal Rating: on line 5525-8923 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 744
% INFO    : Updated Thermal Rating: on line 5525-12852 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1792
% INFO    : Updated Thermal Rating: on line 6712-4373 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23
% INFO    : Updated Thermal Rating: on line 2926-4373 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 154
% INFO    : Updated Thermal Rating: on line 2926-4373 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1423
% INFO    : Updated Thermal Rating: on line 13004-11541 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 700
% INFO    : Updated Thermal Rating: on line 2802-3208 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 2802-3208 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20
% INFO    : Updated Thermal Rating: on line 2754-3208 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24
% INFO    : Updated Thermal Rating: on line 3208-12998 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3502
% INFO    : Updated Thermal Rating: on line 12998-3208 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3305
% INFO    : Updated Thermal Rating: on line 561-3208 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 57
% INFO    : Updated Thermal Rating: on line 7843-3208 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 49
% INFO    : Updated Thermal Rating: on line 2754-2802 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 2754-2802 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 64
% INFO    : Updated Thermal Rating: on line 561-2802 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 43
% INFO    : Updated Thermal Rating: on line 7843-2802 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 69
% INFO    : Updated Thermal Rating: on line 7843-2802 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4898
% INFO    : Updated Thermal Rating: on line 12998-2754 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3831
% INFO    : Updated Thermal Rating: on line 561-2754 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 48
% INFO    : Updated Thermal Rating: on line 561-2754 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2226
% INFO    : Updated Thermal Rating: on line 7843-2754 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 64
% INFO    : Updated Thermal Rating: on line 8333-12267 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 8333-12267 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 35
% INFO    : Updated Thermal Rating: on line 4325-12267 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 48
% INFO    : Updated Thermal Rating: on line 10849-12267 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 60
% INFO    : Updated Thermal Rating: on line 10849-12267 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 937
% INFO    : Updated Thermal Rating: on line 4325-8333 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 80
% INFO    : Updated Thermal Rating: on line 10849-8333 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 38
% INFO    : Updated Thermal Rating: on line 12852-733 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 82
% INFO    : Updated Thermal Rating: on line 733-12852 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9218
% INFO    : Updated Thermal Rating: on line 1114-11590 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2231
% INFO    : Updated Thermal Rating: on line 13563-11590 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 13563-11590 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 121
% INFO    : Updated Thermal Rating: on line 11590-4316 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 215
% INFO    : Updated Thermal Rating: on line 13563-1107 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 285
% INFO    : Updated Thermal Rating: on line 3694-12998 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 426
% INFO    : Updated Thermal Rating: on line 12998-5555 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 988
% INFO    : Updated Thermal Rating: on line 12852-4318 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 847
% INFO    : Updated Thermal Rating: on line 12852-4243 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1460
% INFO    : Updated Thermal Rating: on line 1141-6805 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2140
% INFO    : Updated Thermal Rating: on line 317-10360 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 53
% INFO    : Updated Thermal Rating: on line 10360-317 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1960
% INFO    : Updated Thermal Rating: on line 10360-4318 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1140
% INFO    : Updated Thermal Rating: on line 10360-9356 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1094
% INFO    : Updated Thermal Rating: on line 1107-12963 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 1107-12963 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 41
% INFO    : Updated Thermal Rating: on line 7690-633 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 7690-633 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 74
% INFO    : Updated Thermal Rating: on line 7534-633 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 777
% INFO    : Updated Thermal Rating: on line 12514-633 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 210
% INFO    : Updated Thermal Rating: on line 1998-7690 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 762
% INFO    : Updated Thermal Rating: on line 12514-7690 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 83
% INFO    : Updated Thermal Rating: on line 7104-317 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 254
% INFO    : Updated Thermal Rating: on line 7104-317 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3543
% INFO    : Updated Thermal Rating: on line 4850-3694 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 275
% INFO    : Updated Thermal Rating: on line 4316-4850 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 465
% INFO    : Updated Thermal Rating: on line 5555-3694 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19
% INFO    : Updated Thermal Rating: on line 5874-10131 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17
% INFO    : Updated Thermal Rating: on line 5874-10131 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 497
% INFO    : Updated Thermal Rating: on line 4911-1141 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1345
% INFO    : Updated Thermal Rating: on line 5421-1141 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2696
% INFO    : Updated Thermal Rating: on line 5555-561 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26
% INFO    : Updated Thermal Rating: on line 7843-561 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 84
% INFO    : Updated Thermal Rating: on line 1998-12597 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1038
% INFO    : Updated Thermal Rating: on line 399-10697 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20
% INFO    : Updated Thermal Rating: on line 10697-399 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 495
% INFO    : Updated Thermal Rating: on line 10697-3667 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 445
% INFO    : Updated Thermal Rating: on line 9019-399 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2364
% INFO    : Updated Thermal Rating: on line 399-1363 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 313
% INFO    : Updated Thermal Rating: on line 9019-399 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 30
% INFO    : Updated Thermal Rating: on line 4318-4243 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 630
% INFO    : Updated Thermal Rating: on line 5560-1363 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 5560-1363 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 197
% INFO    : Updated Thermal Rating: on line 611-1363 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 177
% INFO    : Updated Thermal Rating: on line 611-1363 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1830
% INFO    : Updated Thermal Rating: on line 611-5560 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 63
% INFO    : Updated Thermal Rating: on line 11043-2619 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22
% INFO    : Updated Thermal Rating: on line 3037-2619 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17
% INFO    : Updated Thermal Rating: on line 13206-7999 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 502
% INFO    : Updated Thermal Rating: on line 9015-5874 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20
% INFO    : Updated Thermal Rating: on line 13206-5874 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20
% INFO    : Updated Thermal Rating: on line 4318-13061 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1114
% INFO    : Updated Thermal Rating: on line 9356-4318 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4207
% INFO    : Updated Thermal Rating: on line 11162-9162 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2748
% INFO    : Updated Thermal Rating: on line 11162-9162 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2995
% INFO    : Updated Thermal Rating: on line 13206-9015 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 13206-9015 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142
% INFO    : Updated Thermal Rating: on line 8011-5421 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 8011-5421 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 121
% INFO    : Updated Thermal Rating: on line 4911-5421 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1473
% INFO    : Updated Thermal Rating: on line 13061-5421 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 513
% INFO    : Updated Thermal Rating: on line 314-8240 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21
% INFO    : Updated Thermal Rating: on line 3037-11043 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 3037-11043 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 40
% INFO    : Updated Thermal Rating: on line 314-11043 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 34
% INFO    : Updated Thermal Rating: on line 314-11043 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1173
% INFO    : Updated Thermal Rating: on line 314-3037 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 51
% INFO    : Updated Thermal Rating: on line 7843-5555 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16
% INFO    : Updated Thermal Rating: on line 5745-6712 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3759
% INFO    : Updated Thermal Rating: on line 2926-6712 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16
% INFO    : Updated Thermal Rating: on line 9654-246 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 9654-246 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 39
% INFO    : Updated Thermal Rating: on line 5298-246 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 43
% INFO    : Updated Thermal Rating: on line 5298-9654 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 936
% INFO    : Updated Thermal Rating: on line 5298-9654 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52
% INFO    : Updated Thermal Rating: on line 34-7104 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3502
% INFO    : Updated Thermal Rating: on line 200-5474 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 150
% INFO    : Updated Thermal Rating: on line 200-5474 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 4316-5474 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 31
% INFO    : Updated Thermal Rating: on line 2617-5474 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 33
% INFO    : Updated Thermal Rating: on line 4316-200 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 28
% INFO    : Updated Thermal Rating: on line 2617-200 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 32
% INFO    : Updated Thermal Rating: on line 200-2617 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 584
% INFO    : Updated Thermal Rating: on line 10849-4325 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 10849-4325 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 65
% INFO    : Updated Thermal Rating: on line 2617-4316 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 140
% INFO    : Updated Thermal Rating: on line 2617-4316 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 10968-5867 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6078
% INFO    : Updated Thermal Rating: on line 5950-3667 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 5950-3667 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 148
% INFO    : Updated Thermal Rating: on line 4873-6248 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 435
% INFO    : Updated Thermal Rating: on line 4873-6248 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 445
% INFO    : Updated Thermal Rating: on line 8437-6920 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4263
% INFO    : Updated Thermal Rating: on line 8437-6920 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4272
% INFO    : Updated Thermal Rating: on line 8437-6920 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3920
% INFO    : Updated Thermal Rating: on line 7935-3919 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 397
% INFO    : Updated Thermal Rating: on line 7935-7693 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 695
% INFO    : Updated Thermal Rating: on line 11572-6920 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 436
% INFO    : Updated Thermal Rating: on line 11572-6920 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 474
% INFO    : Updated Thermal Rating: on line 11572-11064 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 706
% INFO    : Updated Thermal Rating: on line 13366-3919 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 298
% INFO    : Updated Thermal Rating: on line 13366-10792 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 598
% INFO    : Updated Thermal Rating: on line 13366-10792 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 573
% INFO    : Updated Thermal Rating: on line 13366-10792 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 616
% INFO    : Updated Thermal Rating: on line 13366-1993 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 819
% INFO    : Updated Thermal Rating: on line 6349-6920 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 758
% INFO    : Updated Thermal Rating: on line 6349-6920 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 745
% INFO    : Updated Thermal Rating: on line 6349-7566 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2697
% INFO    : Updated Thermal Rating: on line 6349-7566 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2096
% INFO    : Updated Thermal Rating: on line 6349-891 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3971
% INFO    : Updated Thermal Rating: on line 6349-8438 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1411
% INFO    : Updated Thermal Rating: on line 6349-4251 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3911
% INFO    : Updated Thermal Rating: on line 6920-891 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 946
% INFO    : Updated Thermal Rating: on line 6920-3030 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 925
% INFO    : Updated Thermal Rating: on line 6920-6378 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1049
% INFO    : Updated Thermal Rating: on line 6920-8438 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on line 12999-3919 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 285
% INFO    : Updated Thermal Rating: on line 12999-3919 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 289
% INFO    : Updated Thermal Rating: on line 12999-7693 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 495
% INFO    : Updated Thermal Rating: on line 12999-6050 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 341
% INFO    : Updated Thermal Rating: on line 12999-7135 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 264
% INFO    : Updated Thermal Rating: on line 12999-10792 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 168
% INFO    : Updated Thermal Rating: on line 12999-9259 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1862
% INFO    : Updated Thermal Rating: on line 12999-4033 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 1022-13210 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 911
% INFO    : Updated Thermal Rating: on line 8027-2649 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 437
% INFO    : Updated Thermal Rating: on line 8027-12751 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3523
% INFO    : Updated Thermal Rating: on line 8027-810 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2575
% INFO    : Updated Thermal Rating: on line 8027-810 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 898
% INFO    : Updated Thermal Rating: on line 8027-5565 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 554
% INFO    : Updated Thermal Rating: on line 6379-6378 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 221
% INFO    : Updated Thermal Rating: on line 3919-9044 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 209
% INFO    : Updated Thermal Rating: on line 3919-9044 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 206
% INFO    : Updated Thermal Rating: on line 3919-4981 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 742
% INFO    : Updated Thermal Rating: on line 9044-1993 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1790
% INFO    : Updated Thermal Rating: on line 7323-1767 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 611
% INFO    : Updated Thermal Rating: on line 7323-7775 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2130
% INFO    : Updated Thermal Rating: on line 7323-8630 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1172
% INFO    : Updated Thermal Rating: on line 7323-1254 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1196
% INFO    : Updated Thermal Rating: on line 7323-3809 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 467
% INFO    : Updated Thermal Rating: on line 2649-3445 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1262
% INFO    : Updated Thermal Rating: on line 2649-3445 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1272
% INFO    : Updated Thermal Rating: on line 2649-3445 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 843
% INFO    : Updated Thermal Rating: on line 2649-3445 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 666
% INFO    : Updated Thermal Rating: on line 6050-3030 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 652
% INFO    : Updated Thermal Rating: on line 7135-10792 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 474
% INFO    : Updated Thermal Rating: on line 1767-8630 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 635
% INFO    : Updated Thermal Rating: on line 1767-1254 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 684
% INFO    : Updated Thermal Rating: on line 1767-12185 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 545
% INFO    : Updated Thermal Rating: on line 3445-5461 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1278
% INFO    : Updated Thermal Rating: on line 3445-5461 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1290
% INFO    : Updated Thermal Rating: on line 3445-10863 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1130
% INFO    : Updated Thermal Rating: on line 3445-6269 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2572
% INFO    : Updated Thermal Rating: on line 3445-1398 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1194
% INFO    : Updated Thermal Rating: on line 3445-3140 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 668
% INFO    : Updated Thermal Rating: on line 12062-49 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5568
% INFO    : Updated Thermal Rating: on line 12062-5461 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 854
% INFO    : Updated Thermal Rating: on line 12062-11425 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 983
% INFO    : Updated Thermal Rating: on line 12062-2404 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15180
% INFO    : Updated Thermal Rating: on line 12062-4146 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1039
% INFO    : Updated Thermal Rating: on line 12062-6269 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1401
% INFO    : Updated Thermal Rating: on line 12062-1398 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1239
% INFO    : Updated Thermal Rating: on line 810-5461 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 395
% INFO    : Updated Thermal Rating: on line 9519-2208 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1262
% INFO    : Updated Thermal Rating: on line 9519-10291 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1542
% INFO    : Updated Thermal Rating: on line 9519-5259 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 53419
% INFO    : Updated Thermal Rating: on line 9519-1129 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 46965
% INFO    : Updated Thermal Rating: on line 9519-3089 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 46430
% INFO    : Updated Thermal Rating: on line 11655-9126 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2757
% INFO    : Updated Thermal Rating: on line 11655-13245 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 50503
% INFO    : Updated Thermal Rating: on line 11655-13120 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 51129
% INFO    : Updated Thermal Rating: on line 11655-2471 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 51675
% INFO    : Updated Thermal Rating: on line 11655-4759 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 46965
% INFO    : Updated Thermal Rating: on line 3827-2814 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2258
% INFO    : Updated Thermal Rating: on line 3827-2814 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8043
% INFO    : Updated Thermal Rating: on line 3827-254 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1767
% INFO    : Updated Thermal Rating: on line 8247-7778 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 559
% INFO    : Updated Thermal Rating: on line 8247-1849 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 671
% INFO    : Updated Thermal Rating: on line 8247-10291 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3408
% INFO    : Updated Thermal Rating: on line 8247-2859 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 804
% INFO    : Updated Thermal Rating: on line 8247-11381 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1158
% INFO    : Updated Thermal Rating: on line 8247-8082 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 908
% INFO    : Updated Thermal Rating: on line 8247-4654 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 955
% INFO    : Updated Thermal Rating: on line 8247-13253 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1948
% INFO    : Updated Thermal Rating: on line 8247-2531 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1191
% INFO    : Updated Thermal Rating: on line 4609-1596 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 597
% INFO    : Updated Thermal Rating: on line 4609-1596 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 607
% INFO    : Updated Thermal Rating: on line 4609-12530 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 603
% INFO    : Updated Thermal Rating: on line 4609-960 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 34869
% INFO    : Updated Thermal Rating: on line 4609-5860 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2822
% INFO    : Updated Thermal Rating: on line 2814-8480 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 742
% INFO    : Updated Thermal Rating: on line 2814-10624 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3550
% INFO    : Updated Thermal Rating: on line 2814-10624 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18766
% INFO    : Updated Thermal Rating: on line 2814-254 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2954
% INFO    : Updated Thermal Rating: on line 5100-2859 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1147
% INFO    : Updated Thermal Rating: on line 5100-2859 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1237
% INFO    : Updated Thermal Rating: on line 5100-468 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3002
% INFO    : Updated Thermal Rating: on line 5100-2118 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2956
% INFO    : Updated Thermal Rating: on line 10949-10161 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3557
% INFO    : Updated Thermal Rating: on line 10949-9330 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11743
% INFO    : Updated Thermal Rating: on line 10949-9330 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11868
% INFO    : Updated Thermal Rating: on line 10949-1754 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3867
% INFO    : Updated Thermal Rating: on line 10949-8227 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 123896
% INFO    : Updated Thermal Rating: on line 8259-1849 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1376
% INFO    : Updated Thermal Rating: on line 8259-9390 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 729
% INFO    : Updated Thermal Rating: on line 8259-9390 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1235
% INFO    : Updated Thermal Rating: on line 8259-13301 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1135
% INFO    : Updated Thermal Rating: on line 7778-9925 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 885
% INFO    : Updated Thermal Rating: on line 7778-9925 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 682
% INFO    : Updated Thermal Rating: on line 7778-4654 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 904
% INFO    : Updated Thermal Rating: on line 9925-4401 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 980
% INFO    : Updated Thermal Rating: on line 9925-4401 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1195
% INFO    : Updated Thermal Rating: on line 9925-3679 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 971
% INFO    : Updated Thermal Rating: on line 4401-9126 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1453
% INFO    : Updated Thermal Rating: on line 4401-2208 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2065
% INFO    : Updated Thermal Rating: on line 4401-13245 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1172
% INFO    : Updated Thermal Rating: on line 4401-4759 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1347
% INFO    : Updated Thermal Rating: on line 4401-11149 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 660
% INFO    : Updated Thermal Rating: on line 8480-254 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 585
% INFO    : Updated Thermal Rating: on line 8480-9390 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1057
% INFO    : Updated Thermal Rating: on line 8480-6951 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 802
% INFO    : Updated Thermal Rating: on line 8480-9050 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1707
% INFO    : Updated Thermal Rating: on line 8480-2846 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16463
% INFO    : Updated Thermal Rating: on line 1849-9390 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 562
% INFO    : Updated Thermal Rating: on line 1849-10982 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1616
% INFO    : Updated Thermal Rating: on line 13464-254 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3496
% INFO    : Updated Thermal Rating: on line 13464-13301 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6784
% INFO    : Updated Thermal Rating: on line 13464-7806 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3122
% INFO    : Updated Thermal Rating: on line 9126-10161 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1922
% INFO    : Updated Thermal Rating: on line 9126-10161 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2511
% INFO    : Updated Thermal Rating: on line 9126-13513 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3954
% INFO    : Updated Thermal Rating: on line 9126-9305 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3487
% INFO    : Updated Thermal Rating: on line 9126-10284 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3026
% INFO    : Updated Thermal Rating: on line 9126-3584 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1927
% INFO    : Updated Thermal Rating: on line 9126-13120 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1757
% INFO    : Updated Thermal Rating: on line 9126-2471 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2924
% INFO    : Updated Thermal Rating: on line 5094-4654 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9816
% INFO    : Updated Thermal Rating: on line 10624-10599 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2889
% INFO    : Updated Thermal Rating: on line 10161-5813 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17448
% INFO    : Updated Thermal Rating: on line 10161-8227 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5262
% INFO    : Updated Thermal Rating: on line 10169-3679 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 856
% INFO    : Updated Thermal Rating: on line 10169-10284 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6859
% INFO    : Updated Thermal Rating: on line 10169-8227 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3711
% INFO    : Updated Thermal Rating: on line 254-3532 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1790
% INFO    : Updated Thermal Rating: on line 254-6951 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2039
% INFO    : Updated Thermal Rating: on line 254-9217 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5184
% INFO    : Updated Thermal Rating: on line 254-7806 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5827
% INFO    : Updated Thermal Rating: on line 254-10599 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2256
% INFO    : Updated Thermal Rating: on line 5813-3584 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20641
% INFO    : Updated Thermal Rating: on line 3532-9390 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2941
% INFO    : Updated Thermal Rating: on line 563-7785 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1010
% INFO    : Updated Thermal Rating: on line 563-9050 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1682
% INFO    : Updated Thermal Rating: on line 2631-7491 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 724
% INFO    : Updated Thermal Rating: on line 2631-7443 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 671
% INFO    : Updated Thermal Rating: on line 2631-5339 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2871
% INFO    : Updated Thermal Rating: on line 2631-1134 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2926
% INFO    : Updated Thermal Rating: on line 2631-1490 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1521
% INFO    : Updated Thermal Rating: on line 11795-1016 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1603
% INFO    : Updated Thermal Rating: on line 11795-915 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 473
% INFO    : Updated Thermal Rating: on line 1596-468 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1520
% INFO    : Updated Thermal Rating: on line 1596-2118 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1503
% INFO    : Updated Thermal Rating: on line 1596-7491 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2240
% INFO    : Updated Thermal Rating: on line 1596-7443 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2287
% INFO    : Updated Thermal Rating: on line 9390-9050 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 648
% INFO    : Updated Thermal Rating: on line 9390-12530 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1222
% INFO    : Updated Thermal Rating: on line 9390-12530 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1246
% INFO    : Updated Thermal Rating: on line 10982-8082 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5786
% INFO    : Updated Thermal Rating: on line 10291-2859 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 504
% INFO    : Updated Thermal Rating: on line 12487-5339 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 944
% INFO    : Updated Thermal Rating: on line 12487-1134 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 962
% INFO    : Updated Thermal Rating: on line 7785-6120 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 813
% INFO    : Updated Thermal Rating: on line 6120-1016 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 881
% INFO    : Updated Thermal Rating: on line 6120-1016 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1181
% INFO    : Updated Thermal Rating: on line 6120-6356 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1404
% INFO    : Updated Thermal Rating: on line 6120-6356 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1197
% INFO    : Updated Thermal Rating: on line 2859-13253 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1787
% INFO    : Updated Thermal Rating: on line 2859-11216 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 859
% INFO    : Updated Thermal Rating: on line 12530-915 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1195
% INFO    : Updated Thermal Rating: on line 12530-915 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1219
% INFO    : Updated Thermal Rating: on line 186-13247 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2543
% INFO    : Updated Thermal Rating: on line 186-789 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2249
% INFO    : Updated Thermal Rating: on line 186-11488 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2287
% INFO    : Updated Thermal Rating: on line 11490-11719 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8606
% INFO    : Updated Thermal Rating: on line 11490-5201 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6190
% INFO    : Updated Thermal Rating: on line 1463-9196 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1997
% INFO    : Updated Thermal Rating: on line 1463-4330 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8436
% INFO    : Updated Thermal Rating: on line 1463-5331 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3931
% INFO    : Updated Thermal Rating: on line 1900-5331 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1474
% INFO    : Updated Thermal Rating: on line 1900-5483 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2582
% INFO    : Updated Thermal Rating: on line 1900-11869 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1940
% INFO    : Updated Thermal Rating: on line 1900-9534 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1491
% INFO    : Updated Thermal Rating: on line 647-3465 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6031
% INFO    : Updated Thermal Rating: on line 647-5331 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1756
% INFO    : Updated Thermal Rating: on line 9196-5483 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1590
% INFO    : Updated Thermal Rating: on line 9196-11869 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1564
% INFO    : Updated Thermal Rating: on line 3465-13247 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1320
% INFO    : Updated Thermal Rating: on line 3465-801 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9877
% INFO    : Updated Thermal Rating: on line 3465-10345 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23777
% INFO    : Updated Thermal Rating: on line 3465-12695 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20968
% INFO    : Updated Thermal Rating: on line 3465-1655 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20572
% INFO    : Updated Thermal Rating: on line 3465-4742 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20179
% INFO    : Updated Thermal Rating: on line 3465-8461 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7008
% INFO    : Updated Thermal Rating: on line 3465-8461 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7142
% INFO    : Updated Thermal Rating: on line 13247-2715 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1582
% INFO    : Updated Thermal Rating: on line 13247-13348 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13394
% INFO    : Updated Thermal Rating: on line 13247-8743 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13175
% INFO    : Updated Thermal Rating: on line 13247-11445 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1961
% INFO    : Updated Thermal Rating: on line 13247-12752 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12430
% INFO    : Updated Thermal Rating: on line 13247-12044 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12894
% INFO    : Updated Thermal Rating: on line 13247-1977 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13145
% INFO    : Updated Thermal Rating: on line 12100-11719 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5149
% INFO    : Updated Thermal Rating: on line 12100-11719 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3733
% INFO    : Updated Thermal Rating: on line 12100-11547 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2325
% INFO    : Updated Thermal Rating: on line 12100-9043 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6953
% INFO    : Updated Thermal Rating: on line 4330-5331 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5928
% INFO    : Updated Thermal Rating: on line 4330-801 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2197
% INFO    : Updated Thermal Rating: on line 4330-11445 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1853
% INFO    : Updated Thermal Rating: on line 7038-9043 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3585
% INFO    : Updated Thermal Rating: on line 7038-5201 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3148
% INFO    : Updated Thermal Rating: on line 7038-7217 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4127
% INFO    : Updated Thermal Rating: on line 11719-9534 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1743
% INFO    : Updated Thermal Rating: on line 11719-9511 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2520
% INFO    : Updated Thermal Rating: on line 11719-11737 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5194
% INFO    : Updated Thermal Rating: on line 11719-5201 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3851
% INFO    : Updated Thermal Rating: on line 789-13219 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3148
% INFO    : Updated Thermal Rating: on line 789-5866 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4691
% INFO    : Updated Thermal Rating: on line 5483-9534 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2461
% INFO    : Updated Thermal Rating: on line 5483-11737 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1273
% INFO    : Updated Thermal Rating: on line 5483-6664 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12907
% INFO    : Updated Thermal Rating: on line 5483-9272 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12704
% INFO    : Updated Thermal Rating: on line 5483-397 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 28598
% INFO    : Updated Thermal Rating: on line 5483-2921 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 29098
% INFO    : Updated Thermal Rating: on line 11547-9043 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3853
% INFO    : Updated Thermal Rating: on line 8865-11869 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3658
% INFO    : Updated Thermal Rating: on line 8865-13219 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1407
% INFO    : Updated Thermal Rating: on line 11869-7679 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 131160
% INFO    : Updated Thermal Rating: on line 9534-195 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2366
% INFO    : Updated Thermal Rating: on line 2715-8085 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2259
% INFO    : Updated Thermal Rating: on line 195-9511 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2136
% INFO    : Updated Thermal Rating: on line 6592-9511 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1411
% INFO    : Updated Thermal Rating: on line 6592-2240 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5503
% INFO    : Updated Thermal Rating: on line 9511-2848 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 150416
% INFO    : Updated Thermal Rating: on line 13219-5866 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3344
% INFO    : Updated Thermal Rating: on line 13219-10952 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6422
% INFO    : Updated Thermal Rating: on line 13219-10952 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6547
% INFO    : Updated Thermal Rating: on line 49-1681 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2138
% INFO    : Updated Thermal Rating: on line 1681-5461 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1206
% INFO    : Updated Thermal Rating: on line 574-6248 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1652
% INFO    : Updated Thermal Rating: on line 5461-10863 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142286
% INFO    : Updated Thermal Rating: on line 5461-4146 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 34509
% INFO    : Updated Thermal Rating: on line 12976-11425 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 141820
% INFO    : Updated Thermal Rating: on line 9451-10863 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2134
% INFO    : Updated Thermal Rating: on line 8168-891 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3944
% INFO    : Updated Thermal Rating: on line 8168-6711 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10566
% INFO    : Updated Thermal Rating: on line 8168-13344 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 95764
% INFO    : Updated Thermal Rating: on line 4093-7775 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27645
% INFO    : Updated Thermal Rating: on line 6378-11374 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2319
% INFO    : Updated Thermal Rating: on line 11064-8973 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 943
% INFO    : Updated Thermal Rating: on line 8630-9569 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5693
% INFO    : Updated Thermal Rating: on line 1016-8230 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2517
% INFO    : Updated Thermal Rating: on line 1016-8230 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2282
% INFO    : Updated Thermal Rating: on line 1016-6356 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1931
% INFO    : Updated Thermal Rating: on line 13301-9217 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6644
% INFO    : Updated Thermal Rating: on line 11381-2531 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 59725
% INFO    : Updated Thermal Rating: on line 9217-7806 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 73269
% INFO    : Updated Thermal Rating: on line 2531-11300 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5225
% INFO    : Updated Thermal Rating: on line 2118-8414 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6519
% INFO    : Updated Thermal Rating: on line 7443-7683 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 51867
% INFO    : Updated Thermal Rating: on line 5339-13451 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18122
% INFO    : Updated Thermal Rating: on line 10599-6029 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19594
% INFO    : Updated Thermal Rating: on line 8461-5866 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2279
% INFO    : Updated Thermal Rating: on line 10741-11216 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 6972-11516 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 869
% INFO    : Updated Thermal Rating: on line 12931-11516 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 269
% INFO    : Updated Thermal Rating: on line 3999-1890 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 254
% INFO    : Updated Thermal Rating: on line 4188-3999 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 307
% INFO    : Updated Thermal Rating: on line 6752-13155 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 545
% INFO    : Updated Thermal Rating: on line 2522-6752 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1542
% INFO    : Updated Thermal Rating: on line 13564-9982 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 348
% INFO    : Updated Thermal Rating: on line 9982-9539 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 452
% INFO    : Updated Thermal Rating: on line 13141-10872 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 39833
% INFO    : Updated Thermal Rating: on line 5513-13141 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 567
% INFO    : Updated Thermal Rating: on line 736-10872 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 254
% INFO    : Updated Thermal Rating: on line 8186-7395 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 391
% INFO    : Updated Thermal Rating: on line 7395-12413 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 579
% INFO    : Updated Thermal Rating: on line 5020-7395 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 509
% INFO    : Updated Thermal Rating: on line 7395-2954 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 754
% INFO    : Updated Thermal Rating: on line 677-3726 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1881
% INFO    : Updated Thermal Rating: on line 12776-677 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 511
% INFO    : Updated Thermal Rating: on line 677-5513 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 469
% INFO    : Updated Thermal Rating: on line 677-7623 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 228
% INFO    : Updated Thermal Rating: on line 736-3726 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1853
% INFO    : Updated Thermal Rating: on line 12776-736 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 467
% INFO    : Updated Thermal Rating: on line 736-9121 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 231
% INFO    : Updated Thermal Rating: on line 9211-2018 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1771
% INFO    : Updated Thermal Rating: on line 3933-9211 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3715
% INFO    : Updated Thermal Rating: on line 8450-9270 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 434
% INFO    : Updated Thermal Rating: on line 7040-8450 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 283
% INFO    : Updated Thermal Rating: on line 8450-6579 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 207
% INFO    : Updated Thermal Rating: on line 8450-11697 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 404
% INFO    : Updated Thermal Rating: on line 1316-8450 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 240
% INFO    : Updated Thermal Rating: on line 1316-8450 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 239
% INFO    : Updated Thermal Rating: on line 12851-8450 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 693
% INFO    : Updated Thermal Rating: on line 10960-90 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 41563
% INFO    : Updated Thermal Rating: on line 90-3016 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 270
% INFO    : Updated Thermal Rating: on line 7497-90 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 380
% INFO    : Updated Thermal Rating: on line 7964-90 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 234
% INFO    : Updated Thermal Rating: on line 6175-10960 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 161
% INFO    : Updated Thermal Rating: on line 10960-5175 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 258
% INFO    : Updated Thermal Rating: on line 4064-10960 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1172
% INFO    : Updated Thermal Rating: on line 6652-12237 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 287
% INFO    : Updated Thermal Rating: on line 10393-12237 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1609
% INFO    : Updated Thermal Rating: on line 12237-6830 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 268
% INFO    : Updated Thermal Rating: on line 1699-2094 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 278
% INFO    : Updated Thermal Rating: on line 4913-1699 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 951
% INFO    : Updated Thermal Rating: on line 8512-6888 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1586
% INFO    : Updated Thermal Rating: on line 6888-11651 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1495
% INFO    : Updated Thermal Rating: on line 4097-11791 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 353
% INFO    : Updated Thermal Rating: on line 630-4097 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 532
% INFO    : Updated Thermal Rating: on line 12083-9714 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1055
% INFO    : Updated Thermal Rating: on line 9714-11041 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 245
% INFO    : Updated Thermal Rating: on line 1103-12115 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 538
% INFO    : Updated Thermal Rating: on line 12115-12125 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 847
% INFO    : Updated Thermal Rating: on line 5427-3149 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2831
% INFO    : Updated Thermal Rating: on line 12909-5427 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1962
% INFO    : Updated Thermal Rating: on line 8012-5944 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2869
% INFO    : Updated Thermal Rating: on line 688-8012 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 934
% INFO    : Updated Thermal Rating: on line 1925-763 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3149
% INFO    : Updated Thermal Rating: on line 1371-1925 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1146
% INFO    : Updated Thermal Rating: on line 9813-1925 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5120
% INFO    : Updated Thermal Rating: on line 3640-8341 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 42457
% INFO    : Updated Thermal Rating: on line 3640-2706 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1322
% INFO    : Updated Thermal Rating: on line 8341-12672 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1302
% INFO    : Updated Thermal Rating: on line 6947-11002 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1481
% INFO    : Updated Thermal Rating: on line 11002-10088 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 613
% INFO    : Updated Thermal Rating: on line 13051-4510 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 547
% INFO    : Updated Thermal Rating: on line 13051-2416 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 889
% INFO    : Updated Thermal Rating: on line 1403-10539 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 202
% INFO    : Updated Thermal Rating: on line 1403-10539 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 205
% INFO    : Updated Thermal Rating: on line 10539-3933 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 731
% INFO    : Updated Thermal Rating: on line 2258-5488 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 37471
% INFO    : Updated Thermal Rating: on line 9557-2258 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1268
% INFO    : Updated Thermal Rating: on line 2258-7127 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 409
% INFO    : Updated Thermal Rating: on line 5488-6253 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1174
% INFO    : Updated Thermal Rating: on line 3685-12183 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 151
% INFO    : Updated Thermal Rating: on line 6652-3685 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 337
% INFO    : Updated Thermal Rating: on line 4362-1081 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3867
% INFO    : Updated Thermal Rating: on line 1945-1081 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6006
% INFO    : Updated Thermal Rating: on line 9671-10682 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 352
% INFO    : Updated Thermal Rating: on line 10682-12827 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 802
% INFO    : Updated Thermal Rating: on line 7961-5590 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1246
% INFO    : Updated Thermal Rating: on line 953-5590 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 506
% INFO    : Updated Thermal Rating: on line 6687-7089 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 461
% INFO    : Updated Thermal Rating: on line 10577-6687 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7612
% INFO    : Updated Thermal Rating: on line 3972-2833 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 340
% INFO    : Updated Thermal Rating: on line 3501-3972 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1470
% INFO    : Updated Thermal Rating: on line 4361-3249 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13435
% INFO    : Updated Thermal Rating: on line 3249-3250 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3457
% INFO    : Updated Thermal Rating: on line 10421-4175 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6579
% INFO    : Updated Thermal Rating: on line 744-4175 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 742
% INFO    : Updated Thermal Rating: on line 2469-12012 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3230
% INFO    : Updated Thermal Rating: on line 2469-10698 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2784
% INFO    : Updated Thermal Rating: on line 9101-9118 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1245
% INFO    : Updated Thermal Rating: on line 9101-268 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3325
% INFO    : Updated Thermal Rating: on line 12774-9101 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 849
% INFO    : Updated Thermal Rating: on line 848-9101 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 793
% INFO    : Updated Thermal Rating: on line 11800-12242 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1271
% INFO    : Updated Thermal Rating: on line 11800-1660 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6573
% INFO    : Updated Thermal Rating: on line 2511-6954 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 221
% INFO    : Updated Thermal Rating: on line 6954-5372 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1145
% INFO    : Updated Thermal Rating: on line 6954-5372 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1168
% INFO    : Updated Thermal Rating: on line 6343-6954 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 680
% INFO    : Updated Thermal Rating: on line 13098-10326 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4998
% INFO    : Updated Thermal Rating: on line 10326-8918 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3652
% INFO    : Updated Thermal Rating: on line 12077-1205 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 922
% INFO    : Updated Thermal Rating: on line 12077-9941 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157
% INFO    : Updated Thermal Rating: on line 7422-1091 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 104
% INFO    : Updated Thermal Rating: on line 1091-11147 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1504
% INFO    : Updated Thermal Rating: on line 13098-12685 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4729
% INFO    : Updated Thermal Rating: on line 5351-7373 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1321
% INFO    : Updated Thermal Rating: on line 7373-348 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3783
% INFO    : Updated Thermal Rating: on line 5351-1205 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2148
% INFO    : Updated Thermal Rating: on line 9131-7927 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 415
% INFO    : Updated Thermal Rating: on line 7927-12685 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2300
% INFO    : Updated Thermal Rating: on line 7927-348 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1072
% INFO    : Updated Thermal Rating: on line 7927-5811 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 236
% INFO    : Updated Thermal Rating: on line 7927-9816 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 380
% INFO    : Updated Thermal Rating: on line 8918-1205 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3330
% INFO    : Updated Thermal Rating: on line 1205-9644 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 653
% INFO    : Updated Thermal Rating: on line 12147-6492 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1571
% INFO    : Updated Thermal Rating: on line 10843-12147 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 543
% INFO    : Updated Thermal Rating: on line 7455-12596 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 258
% INFO    : Updated Thermal Rating: on line 7455-10412 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 562
% INFO    : Updated Thermal Rating: on line 10393-7455 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 158
% INFO    : Updated Thermal Rating: on line 6304-8124 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on line 703-8124 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 319
% INFO    : Updated Thermal Rating: on line 9118-7744 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 649
% INFO    : Updated Thermal Rating: on line 12410-10385 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 199
% INFO    : Updated Thermal Rating: on line 1799-10385 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 300
% INFO    : Updated Thermal Rating: on line 2995-10385 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 278
% INFO    : Updated Thermal Rating: on line 10634-9671 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 876
% INFO    : Updated Thermal Rating: on line 5024-3991 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 483
% INFO    : Updated Thermal Rating: on line 3944-5024 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 505
% INFO    : Updated Thermal Rating: on line 13150-2309 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6305
% INFO    : Updated Thermal Rating: on line 2309-12953 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8810
% INFO    : Updated Thermal Rating: on line 10024-12183 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2729
% INFO    : Updated Thermal Rating: on line 12183-1034 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2687
% INFO    : Updated Thermal Rating: on line 6725-12183 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 982
% INFO    : Updated Thermal Rating: on line 2632-12183 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 272
% INFO    : Updated Thermal Rating: on line 4919-5454 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 531
% INFO    : Updated Thermal Rating: on line 6205-4919 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 278
% INFO    : Updated Thermal Rating: on line 9535-2800 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 206
% INFO    : Updated Thermal Rating: on line 9535-2213 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 384
% INFO    : Updated Thermal Rating: on line 11589-6146 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5658
% INFO    : Updated Thermal Rating: on line 2986-6146 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 396
% INFO    : Updated Thermal Rating: on line 1761-6669 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 234
% INFO    : Updated Thermal Rating: on line 6669-7629 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 133
% INFO    : Updated Thermal Rating: on line 6669-8180 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 849
% INFO    : Updated Thermal Rating: on line 6669-6979 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 267
% INFO    : Updated Thermal Rating: on line 9139-9276 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1157
% INFO    : Updated Thermal Rating: on line 5859-9276 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 342
% INFO    : Updated Thermal Rating: on line 5486-3411 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 789
% INFO    : Updated Thermal Rating: on line 12516-5486 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1960
% INFO    : Updated Thermal Rating: on line 1103-9632 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 330
% INFO    : Updated Thermal Rating: on line 1103-12268 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 332
% INFO    : Updated Thermal Rating: on line 1103-6722 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 445
% INFO    : Updated Thermal Rating: on line 7358-7781 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 309
% INFO    : Updated Thermal Rating: on line 13446-7781 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 874
% INFO    : Updated Thermal Rating: on line 7093-1572 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 35373
% INFO    : Updated Thermal Rating: on line 7093-2671 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 676
% INFO    : Updated Thermal Rating: on line 7093-5487 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 686
% INFO    : Updated Thermal Rating: on line 8673-7093 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 456
% INFO    : Updated Thermal Rating: on line 9939-1572 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 284
% INFO    : Updated Thermal Rating: on line 10346-1572 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 417
% INFO    : Updated Thermal Rating: on line 5068-1572 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 245
% INFO    : Updated Thermal Rating: on line 3051-12596 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 417
% INFO    : Updated Thermal Rating: on line 10799-2415 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1753
% INFO    : Updated Thermal Rating: on line 5699-10799 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3292
% INFO    : Updated Thermal Rating: on line 2046-10571 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 725
% INFO    : Updated Thermal Rating: on line 9208-2046 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 242
% INFO    : Updated Thermal Rating: on line 12226-7040 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 147
% INFO    : Updated Thermal Rating: on line 13089-12226 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 374
% INFO    : Updated Thermal Rating: on line 9537-12174 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 262
% INFO    : Updated Thermal Rating: on line 3537-9537 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 264
% INFO    : Updated Thermal Rating: on line 3195-3970 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 38242
% INFO    : Updated Thermal Rating: on line 12496-3970 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 794
% INFO    : Updated Thermal Rating: on line 3195-1296 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 369
% INFO    : Updated Thermal Rating: on line 8101-3195 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 900
% INFO    : Updated Thermal Rating: on line 6968-13599 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 321
% INFO    : Updated Thermal Rating: on line 9208-6968 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 422
% INFO    : Updated Thermal Rating: on line 9208-6968 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 379
% INFO    : Updated Thermal Rating: on line 1137-9575 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 573
% INFO    : Updated Thermal Rating: on line 9575-11954 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 570
% INFO    : Updated Thermal Rating: on line 499-1539 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 671
% INFO    : Updated Thermal Rating: on line 1539-11984 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 539
% INFO    : Updated Thermal Rating: on line 903-2199 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 550
% INFO    : Updated Thermal Rating: on line 5374-2199 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 413
% INFO    : Updated Thermal Rating: on line 8833-6723 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 38997
% INFO    : Updated Thermal Rating: on line 8833-13236 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2987
% INFO    : Updated Thermal Rating: on line 3688-8833 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1263
% INFO    : Updated Thermal Rating: on line 6723-1890 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2939
% INFO    : Updated Thermal Rating: on line 3688-6723 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1245
% INFO    : Updated Thermal Rating: on line 8325-5829 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2655
% INFO    : Updated Thermal Rating: on line 8325-6972 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1925
% INFO    : Updated Thermal Rating: on line 8329-8325 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 362
% INFO    : Updated Thermal Rating: on line 703-5283 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 276
% INFO    : Updated Thermal Rating: on line 5283-11357 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157
% INFO    : Updated Thermal Rating: on line 2548-7247 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 559
% INFO    : Updated Thermal Rating: on line 12205-7247 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 943
% INFO    : Updated Thermal Rating: on line 3476-10871 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1089
% INFO    : Updated Thermal Rating: on line 2517-10871 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 844
% INFO    : Updated Thermal Rating: on line 4510-4908 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6761
% INFO    : Updated Thermal Rating: on line 3047-4510 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 615
% INFO    : Updated Thermal Rating: on line 4510-2524 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 754
% INFO    : Updated Thermal Rating: on line 4510-6474 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 821
% INFO    : Updated Thermal Rating: on line 922-4852 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 39833
% INFO    : Updated Thermal Rating: on line 922-12297 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 491
% INFO    : Updated Thermal Rating: on line 922-9291 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 883
% INFO    : Updated Thermal Rating: on line 4852-8684 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1544
% INFO    : Updated Thermal Rating: on line 4852-8684 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1569
% INFO    : Updated Thermal Rating: on line 6521-4852 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1446
% INFO    : Updated Thermal Rating: on line 8366-6941 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10550
% INFO    : Updated Thermal Rating: on line 6281-2989 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 641
% INFO    : Updated Thermal Rating: on line 12104-6281 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 856
% INFO    : Updated Thermal Rating: on line 2989-12301 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 760
% INFO    : Updated Thermal Rating: on line 12952-1838 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7000
% INFO    : Updated Thermal Rating: on line 11292-1838 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 33525
% INFO    : Updated Thermal Rating: on line 3476-1193 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12436
% INFO    : Updated Thermal Rating: on line 12012-3476 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1337
% INFO    : Updated Thermal Rating: on line 3476-883 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1187
% INFO    : Updated Thermal Rating: on line 9139-11164 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2889
% INFO    : Updated Thermal Rating: on line 9139-13615 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 333
% INFO    : Updated Thermal Rating: on line 2833-9139 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 446
% INFO    : Updated Thermal Rating: on line 9139-4081 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 182
% INFO    : Updated Thermal Rating: on line 1095-9139 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1079
% INFO    : Updated Thermal Rating: on line 8703-9139 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 398
% INFO    : Updated Thermal Rating: on line 9888-11164 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2843
% INFO    : Updated Thermal Rating: on line 9888-12886 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 195
% INFO    : Updated Thermal Rating: on line 9888-10190 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 627
% INFO    : Updated Thermal Rating: on line 10551-9888 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 670
% INFO    : Updated Thermal Rating: on line 9888-5828 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 372
% INFO    : Updated Thermal Rating: on line 5952-10002 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 496
% INFO    : Updated Thermal Rating: on line 13015-10002 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 940
% INFO    : Updated Thermal Rating: on line 1193-11513 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1472
% INFO    : Updated Thermal Rating: on line 9834-11513 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2621
% INFO    : Updated Thermal Rating: on line 9234-6415 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 178159
% INFO    : Updated Thermal Rating: on line 13627-9234 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 616
% INFO    : Updated Thermal Rating: on line 9234-2524 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 843
% INFO    : Updated Thermal Rating: on line 6415-13315 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 605
% INFO    : Updated Thermal Rating: on line 6415-10654 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1371
% INFO    : Updated Thermal Rating: on line 6415-6474 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 835
% INFO    : Updated Thermal Rating: on line 13293-2861 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3243
% INFO    : Updated Thermal Rating: on line 10843-13293 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 505
% INFO    : Updated Thermal Rating: on line 10770-4363 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 579
% INFO    : Updated Thermal Rating: on line 4363-989 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 409
% INFO    : Updated Thermal Rating: on line 5035-5734 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 656
% INFO    : Updated Thermal Rating: on line 5734-172 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 571
% INFO    : Updated Thermal Rating: on line 9834-10593 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3399
% INFO    : Updated Thermal Rating: on line 10593-7326 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1277
% INFO    : Updated Thermal Rating: on line 10593-6261 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1413
% INFO    : Updated Thermal Rating: on line 10256-10593 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 894
% INFO    : Updated Thermal Rating: on line 8281-3637 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 171651
% INFO    : Updated Thermal Rating: on line 13627-3637 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1719
% INFO    : Updated Thermal Rating: on line 3637-13315 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1687
% INFO    : Updated Thermal Rating: on line 3637-293 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 632
% INFO    : Updated Thermal Rating: on line 3637-802 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6959
% INFO    : Updated Thermal Rating: on line 4361-3250 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5835
% INFO    : Updated Thermal Rating: on line 8928-4361 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1910
% INFO    : Updated Thermal Rating: on line 4361-10300 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1709
% INFO    : Updated Thermal Rating: on line 1683-6849 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2359
% INFO    : Updated Thermal Rating: on line 11615-1683 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1295
% INFO    : Updated Thermal Rating: on line 8700-6520 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 500
% INFO    : Updated Thermal Rating: on line 5650-8700 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 181
% INFO    : Updated Thermal Rating: on line 5626-4383 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1259
% INFO    : Updated Thermal Rating: on line 12981-5626 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1780
% INFO    : Updated Thermal Rating: on line 7302-11091 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1221
% INFO    : Updated Thermal Rating: on line 7302-5448 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1237
% INFO    : Updated Thermal Rating: on line 8985-5584 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 607
% INFO    : Updated Thermal Rating: on line 12349-12952 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4439
% INFO    : Updated Thermal Rating: on line 12349-13622 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3187
% INFO    : Updated Thermal Rating: on line 4365-2563 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1128
% INFO    : Updated Thermal Rating: on line 2002-2563 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4509
% INFO    : Updated Thermal Rating: on line 11292-2563 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3134
% INFO    : Updated Thermal Rating: on line 591-11799 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11752
% INFO    : Updated Thermal Rating: on line 5224-591 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4214
% INFO    : Updated Thermal Rating: on line 989-3144 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 30252
% INFO    : Updated Thermal Rating: on line 989-3144 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 30614
% INFO    : Updated Thermal Rating: on line 10571-11113 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 408
% INFO    : Updated Thermal Rating: on line 11113-9271 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 305
% INFO    : Updated Thermal Rating: on line 4827-658 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1344
% INFO    : Updated Thermal Rating: on line 658-2632 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 340
% INFO    : Updated Thermal Rating: on line 658-2632 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 316
% INFO    : Updated Thermal Rating: on line 7704-9029 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1254
% INFO    : Updated Thermal Rating: on line 2679-7704 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 713
% INFO    : Updated Thermal Rating: on line 9921-8188 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1685
% INFO    : Updated Thermal Rating: on line 9921-13335 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1058
% INFO    : Updated Thermal Rating: on line 9921-47 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 579
% INFO    : Updated Thermal Rating: on line 9921-47 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 589
% INFO    : Updated Thermal Rating: on line 8188-5425 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 885
% INFO    : Updated Thermal Rating: on line 7424-1852 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1523
% INFO    : Updated Thermal Rating: on line 7424-7656 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 439
% INFO    : Updated Thermal Rating: on line 5425-7424 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3575
% INFO    : Updated Thermal Rating: on line 8455-7424 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3840
% INFO    : Updated Thermal Rating: on line 7424-47 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 519
% INFO    : Updated Thermal Rating: on line 7424-5744 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 682
% INFO    : Updated Thermal Rating: on line 1852-47 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 449
% INFO    : Updated Thermal Rating: on line 5381-9302 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 429
% INFO    : Updated Thermal Rating: on line 9302-3293 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 294
% INFO    : Updated Thermal Rating: on line 12524-1403 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 206
% INFO    : Updated Thermal Rating: on line 12649-1403 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 876
% INFO    : Updated Thermal Rating: on line 10459-6553 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11228
% INFO    : Updated Thermal Rating: on line 10459-8917 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 221
% INFO    : Updated Thermal Rating: on line 10459-7295 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 381
% INFO    : Updated Thermal Rating: on line 12324-10459 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1125
% INFO    : Updated Thermal Rating: on line 10459-13422 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1290
% INFO    : Updated Thermal Rating: on line 7873-3160 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 637
% INFO    : Updated Thermal Rating: on line 4606-3160 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1527
% INFO    : Updated Thermal Rating: on line 6318-682 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 333
% INFO    : Updated Thermal Rating: on line 682-7385 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 843
% INFO    : Updated Thermal Rating: on line 682-1121 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1232
% INFO    : Updated Thermal Rating: on line 682-2193 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 274
% INFO    : Updated Thermal Rating: on line 8917-6553 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 260
% INFO    : Updated Thermal Rating: on line 11791-12588 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2961
% INFO    : Updated Thermal Rating: on line 11791-12503 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 508
% INFO    : Updated Thermal Rating: on line 5102-11791 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 469
% INFO    : Updated Thermal Rating: on line 12588-13204 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 609
% INFO    : Updated Thermal Rating: on line 6364-763 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27475
% INFO    : Updated Thermal Rating: on line 10634-12371 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 774
% INFO    : Updated Thermal Rating: on line 6449-10634 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 325
% INFO    : Updated Thermal Rating: on line 7263-6925 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 271
% INFO    : Updated Thermal Rating: on line 3125-7263 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 343
% INFO    : Updated Thermal Rating: on line 5829-6972 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2168
% INFO    : Updated Thermal Rating: on line 9807-11836 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2854
% INFO    : Updated Thermal Rating: on line 12496-11836 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3723
% INFO    : Updated Thermal Rating: on line 10049-9131 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 205
% INFO    : Updated Thermal Rating: on line 13636-10937 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 545
% INFO    : Updated Thermal Rating: on line 2996-13636 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 200
% INFO    : Updated Thermal Rating: on line 3677-2094 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 270
% INFO    : Updated Thermal Rating: on line 744-3677 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1281
% INFO    : Updated Thermal Rating: on line 2002-8798 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1254
% INFO    : Updated Thermal Rating: on line 5737-8798 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6869
% INFO    : Updated Thermal Rating: on line 12952-10108 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1350
% INFO    : Updated Thermal Rating: on line 8324-10108 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6151
% INFO    : Updated Thermal Rating: on line 9941-7422 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3006
% INFO    : Updated Thermal Rating: on line 8115-10571 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 714
% INFO    : Updated Thermal Rating: on line 2018-2616 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1971
% INFO    : Updated Thermal Rating: on line 9116-425 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2254
% INFO    : Updated Thermal Rating: on line 7326-425 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2712
% INFO    : Updated Thermal Rating: on line 7326-425 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2690
% INFO    : Updated Thermal Rating: on line 425-5789 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9389
% INFO    : Updated Thermal Rating: on line 6261-425 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1665
% INFO    : Updated Thermal Rating: on line 10393-9936 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1703
% INFO    : Updated Thermal Rating: on line 9936-6033 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2537
% INFO    : Updated Thermal Rating: on line 12672-2706 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1342
% INFO    : Updated Thermal Rating: on line 10498-6492 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 264
% INFO    : Updated Thermal Rating: on line 13239-10498 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 708
% INFO    : Updated Thermal Rating: on line 2833-11164 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3061
% INFO    : Updated Thermal Rating: on line 11164-9631 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3087
% INFO    : Updated Thermal Rating: on line 5424-13040 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1729
% INFO    : Updated Thermal Rating: on line 12090-13040 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 419
% INFO    : Updated Thermal Rating: on line 9838-1926 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1542
% INFO    : Updated Thermal Rating: on line 1926-744 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1100
% INFO    : Updated Thermal Rating: on line 1926-744 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1081
% INFO    : Updated Thermal Rating: on line 6175-3612 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 735
% INFO    : Updated Thermal Rating: on line 1800-3612 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 807
% INFO    : Updated Thermal Rating: on line 3612-7222 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1499
% INFO    : Updated Thermal Rating: on line 9112-11615 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2733
% INFO    : Updated Thermal Rating: on line 9112-8928 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1842
% INFO    : Updated Thermal Rating: on line 6520-6134 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 948
% INFO    : Updated Thermal Rating: on line 6520-6134 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 963
% INFO    : Updated Thermal Rating: on line 10289-6134 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1227
% INFO    : Updated Thermal Rating: on line 12177-6134 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1209
% INFO    : Updated Thermal Rating: on line 2385-2599 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 523
% INFO    : Updated Thermal Rating: on line 5659-2599 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 439
% INFO    : Updated Thermal Rating: on line 3051-6397 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 266
% INFO    : Updated Thermal Rating: on line 10412-3051 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 366
% INFO    : Updated Thermal Rating: on line 3051-6518 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 203
% INFO    : Updated Thermal Rating: on line 12981-10684 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1738
% INFO    : Updated Thermal Rating: on line 4571-10684 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 415
% INFO    : Updated Thermal Rating: on line 13204-4527 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2526
% INFO    : Updated Thermal Rating: on line 12503-4527 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1499
% INFO    : Updated Thermal Rating: on line 11751-1846 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1756
% INFO    : Updated Thermal Rating: on line 4409-1846 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 513
% INFO    : Updated Thermal Rating: on line 268-3852 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 317
% INFO    : Updated Thermal Rating: on line 9174-7484 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 42457
% INFO    : Updated Thermal Rating: on line 4365-9174 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2520
% INFO    : Updated Thermal Rating: on line 9174-5737 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1087
% INFO    : Updated Thermal Rating: on line 7484-8324 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1068
% INFO    : Updated Thermal Rating: on line 4297-4885 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 287
% INFO    : Updated Thermal Rating: on line 4297-4885 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 291
% INFO    : Updated Thermal Rating: on line 3332-4885 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2051
% INFO    : Updated Thermal Rating: on line 7094-7004 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1373
% INFO    : Updated Thermal Rating: on line 7004-12667 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 198
% INFO    : Updated Thermal Rating: on line 10403-9053 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3066
% INFO    : Updated Thermal Rating: on line 6449-10403 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1146
% INFO    : Updated Thermal Rating: on line 11041-9053 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1997
% INFO    : Updated Thermal Rating: on line 1630-9814 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 545
% INFO    : Updated Thermal Rating: on line 9814-9750 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 553
% INFO    : Updated Thermal Rating: on line 5035-1336 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 321
% INFO    : Updated Thermal Rating: on line 5035-785 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 237
% INFO    : Updated Thermal Rating: on line 7656-1863 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3733
% INFO    : Updated Thermal Rating: on line 6410-12380 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 501
% INFO    : Updated Thermal Rating: on line 12380-9954 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 521
% INFO    : Updated Thermal Rating: on line 11607-6540 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2085
% INFO    : Updated Thermal Rating: on line 7961-9915 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 571
% INFO    : Updated Thermal Rating: on line 85-10644 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 352
% INFO    : Updated Thermal Rating: on line 1870-10644 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 765
% INFO    : Updated Thermal Rating: on line 7301-10644 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 754
% INFO    : Updated Thermal Rating: on line 10566-12988 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 255
% INFO    : Updated Thermal Rating: on line 12988-11041 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 269
% INFO    : Updated Thermal Rating: on line 58-6216 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 418
% INFO    : Updated Thermal Rating: on line 58-3747 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 424
% INFO    : Updated Thermal Rating: on line 1819-9632 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5472
% INFO    : Updated Thermal Rating: on line 5142-6935 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8831
% INFO    : Updated Thermal Rating: on line 8512-12982 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2863
% INFO    : Updated Thermal Rating: on line 8512-4884 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3115
% INFO    : Updated Thermal Rating: on line 9271-8512 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 638
% INFO    : Updated Thermal Rating: on line 11651-5583 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 748
% INFO    : Updated Thermal Rating: on line 11651-899 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 750
% INFO    : Updated Thermal Rating: on line 11651-8917 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 155
% INFO    : Updated Thermal Rating: on line 11651-13422 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 235
% INFO    : Updated Thermal Rating: on line 12982-10233 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2883
% INFO    : Updated Thermal Rating: on line 10233-1503 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2906
% INFO    : Updated Thermal Rating: on line 1503-5583 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1252
% INFO    : Updated Thermal Rating: on line 11512-5583 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on line 4884-1503 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 677
% INFO    : Updated Thermal Rating: on line 2659-8186 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 737
% INFO    : Updated Thermal Rating: on line 8186-6424 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1425
% INFO    : Updated Thermal Rating: on line 8186-6343 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 563
% INFO    : Updated Thermal Rating: on line 13615-2562 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 542
% INFO    : Updated Thermal Rating: on line 8115-3442 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 338
% INFO    : Updated Thermal Rating: on line 9208-3442 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 244
% INFO    : Updated Thermal Rating: on line 10611-5424 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1051
% INFO    : Updated Thermal Rating: on line 825-2060 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 515
% INFO    : Updated Thermal Rating: on line 2060-1214 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 965
% INFO    : Updated Thermal Rating: on line 1336-172 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 744
% INFO    : Updated Thermal Rating: on line 13591-6520 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1062
% INFO    : Updated Thermal Rating: on line 10289-6520 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 978
% INFO    : Updated Thermal Rating: on line 3798-8463 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 600
% INFO    : Updated Thermal Rating: on line 2562-3798 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1570
% INFO    : Updated Thermal Rating: on line 12886-5859 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2239
% INFO    : Updated Thermal Rating: on line 2216-9116 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2472
% INFO    : Updated Thermal Rating: on line 8455-13335 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1652
% INFO    : Updated Thermal Rating: on line 10583-1890 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 539
% INFO    : Updated Thermal Rating: on line 3852-10583 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 951
% INFO    : Updated Thermal Rating: on line 8310-2479 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 754
% INFO    : Updated Thermal Rating: on line 2479-7415 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 597
% INFO    : Updated Thermal Rating: on line 7205-11872 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 36730
% INFO    : Updated Thermal Rating: on line 7205-12538 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 395
% INFO    : Updated Thermal Rating: on line 7205-1364 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 366
% INFO    : Updated Thermal Rating: on line 7926-7205 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 227
% INFO    : Updated Thermal Rating: on line 5102-11872 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 237
% INFO    : Updated Thermal Rating: on line 7158-5837 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 463
% INFO    : Updated Thermal Rating: on line 5837-4312 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2281
% INFO    : Updated Thermal Rating: on line 9449-3937 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1363
% INFO    : Updated Thermal Rating: on line 13204-10189 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 578
% INFO    : Updated Thermal Rating: on line 6739-10189 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 356
% INFO    : Updated Thermal Rating: on line 10691-8869 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 321
% INFO    : Updated Thermal Rating: on line 8869-11437 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 439
% INFO    : Updated Thermal Rating: on line 4388-12247 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 197
% INFO    : Updated Thermal Rating: on line 5033-4388 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 214
% INFO    : Updated Thermal Rating: on line 13638-5480 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 144235
% INFO    : Updated Thermal Rating: on line 13638-7984 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3658
% INFO    : Updated Thermal Rating: on line 6914-13638 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 699
% INFO    : Updated Thermal Rating: on line 13638-10584 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 319
% INFO    : Updated Thermal Rating: on line 5480-7984 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4163
% INFO    : Updated Thermal Rating: on line 5480-12756 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 498
% INFO    : Updated Thermal Rating: on line 6914-5480 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 687
% INFO    : Updated Thermal Rating: on line 4070-11936 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1338
% INFO    : Updated Thermal Rating: on line 6033-11936 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1244
% INFO    : Updated Thermal Rating: on line 11199-4317 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2554
% INFO    : Updated Thermal Rating: on line 11199-9454 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1889
% INFO    : Updated Thermal Rating: on line 6953-10393 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 928
% INFO    : Updated Thermal Rating: on line 6904-6953 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1086
% INFO    : Updated Thermal Rating: on line 1293-2924 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 36059
% INFO    : Updated Thermal Rating: on line 11439-2924 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 748
% INFO    : Updated Thermal Rating: on line 6904-2924 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3765
% INFO    : Updated Thermal Rating: on line 6904-2924 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3829
% INFO    : Updated Thermal Rating: on line 1293-6652 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 231
% INFO    : Updated Thermal Rating: on line 7986-1293 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1629
% INFO    : Updated Thermal Rating: on line 1293-2800 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 178
% INFO    : Updated Thermal Rating: on line 10812-6304 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 179
% INFO    : Updated Thermal Rating: on line 534-7158 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 226
% INFO    : Updated Thermal Rating: on line 13073-534 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 270
% INFO    : Updated Thermal Rating: on line 10566-8057 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 669
% INFO    : Updated Thermal Rating: on line 8057-6449 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 188
% INFO    : Updated Thermal Rating: on line 7331-6838 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 374
% INFO    : Updated Thermal Rating: on line 5918-7331 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 782
% INFO    : Updated Thermal Rating: on line 12827-11000 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 579
% INFO    : Updated Thermal Rating: on line 5033-11000 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 336
% INFO    : Updated Thermal Rating: on line 5692-127 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 35373
% INFO    : Updated Thermal Rating: on line 669-127 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 541
% INFO    : Updated Thermal Rating: on line 127-8673 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 810
% INFO    : Updated Thermal Rating: on line 9939-5692 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 432
% INFO    : Updated Thermal Rating: on line 5692-7584 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 301
% INFO    : Updated Thermal Rating: on line 5692-6094 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 913
% INFO    : Updated Thermal Rating: on line 5692-11431 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 741
% INFO    : Updated Thermal Rating: on line 6397-6518 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 311
% INFO    : Updated Thermal Rating: on line 8215-12637 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 511
% INFO    : Updated Thermal Rating: on line 11431-8215 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1244
% INFO    : Updated Thermal Rating: on line 2511-2659 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 551
% INFO    : Updated Thermal Rating: on line 6947-6739 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 908
% INFO    : Updated Thermal Rating: on line 6947-3598 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 702
% INFO    : Updated Thermal Rating: on line 10882-12635 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 316
% INFO    : Updated Thermal Rating: on line 12635-6205 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 257
% INFO    : Updated Thermal Rating: on line 11380-630 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 527
% INFO    : Updated Thermal Rating: on line 1364-11380 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 655
% INFO    : Updated Thermal Rating: on line 7926-11380 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 127
% INFO    : Updated Thermal Rating: on line 2578-451 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1028
% INFO    : Updated Thermal Rating: on line 10531-451 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 526
% INFO    : Updated Thermal Rating: on line 7089-5231 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 661
% INFO    : Updated Thermal Rating: on line 5231-4923 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 612
% INFO    : Updated Thermal Rating: on line 2443-11280 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 240
% INFO    : Updated Thermal Rating: on line 12931-2443 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 208
% INFO    : Updated Thermal Rating: on line 12776-3726 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 459
% INFO    : Updated Thermal Rating: on line 10791-825 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 325
% INFO    : Updated Thermal Rating: on line 8115-899 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 94
% INFO    : Updated Thermal Rating: on line 13599-8115 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 189
% INFO    : Updated Thermal Rating: on line 8115-9816 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 143
% INFO    : Updated Thermal Rating: on line 8115-13623 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 234
% INFO    : Updated Thermal Rating: on line 989-5553 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 123
% INFO    : Updated Thermal Rating: on line 5553-3467 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1556
% INFO    : Updated Thermal Rating: on line 3963-5381 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 575
% INFO    : Updated Thermal Rating: on line 9577-159 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 647
% INFO    : Updated Thermal Rating: on line 159-4447 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 838
% INFO    : Updated Thermal Rating: on line 11449-8756 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1235
% INFO    : Updated Thermal Rating: on line 703-11449 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 811
% INFO    : Updated Thermal Rating: on line 8756-4447 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 978
% INFO    : Updated Thermal Rating: on line 4317-11439 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 38242
% INFO    : Updated Thermal Rating: on line 4317-4070 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9654
% INFO    : Updated Thermal Rating: on line 4317-9454 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1068
% INFO    : Updated Thermal Rating: on line 11439-1459 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9482
% INFO    : Updated Thermal Rating: on line 9029-2833 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 463
% INFO    : Updated Thermal Rating: on line 2833-8832 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1564
% INFO    : Updated Thermal Rating: on line 2833-8832 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1431
% INFO    : Updated Thermal Rating: on line 2833-9631 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4125
% INFO    : Updated Thermal Rating: on line 2833-9631 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3727
% INFO    : Updated Thermal Rating: on line 2524-1040 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3129
% INFO    : Updated Thermal Rating: on line 6474-5186 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2436
% INFO    : Updated Thermal Rating: on line 3149-5944 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 38997
% INFO    : Updated Thermal Rating: on line 3149-8198 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1032
% INFO    : Updated Thermal Rating: on line 5944-7332 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 603
% INFO    : Updated Thermal Rating: on line 5944-11554 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 456
% INFO    : Updated Thermal Rating: on line 7032-8304 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 264
% INFO    : Updated Thermal Rating: on line 8304-6972 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 199
% INFO    : Updated Thermal Rating: on line 1720-9834 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 648
% INFO    : Updated Thermal Rating: on line 8310-12952 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 386
% INFO    : Updated Thermal Rating: on line 6216-12952 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 568
% INFO    : Updated Thermal Rating: on line 2002-13404 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 598
% INFO    : Updated Thermal Rating: on line 373-12960 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 391
% INFO    : Updated Thermal Rating: on line 3634-373 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 428
% INFO    : Updated Thermal Rating: on line 5650-11280 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 255
% INFO    : Updated Thermal Rating: on line 11508-13204 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 430
% INFO    : Updated Thermal Rating: on line 13204-1799 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 300
% INFO    : Updated Thermal Rating: on line 11658-13204 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 388
% INFO    : Updated Thermal Rating: on line 13204-1118 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 652
% INFO    : Updated Thermal Rating: on line 12410-11450 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 781
% INFO    : Updated Thermal Rating: on line 3598-12410 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 671
% INFO    : Updated Thermal Rating: on line 11751-6694 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 521
% INFO    : Updated Thermal Rating: on line 9238-10256 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4685
% INFO    : Updated Thermal Rating: on line 2636-6318 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 480
% INFO    : Updated Thermal Rating: on line 9373-117 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 182
% INFO    : Updated Thermal Rating: on line 9373-3634 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 584
% INFO    : Updated Thermal Rating: on line 876-2874 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 997
% INFO    : Updated Thermal Rating: on line 5454-6655 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 509
% INFO    : Updated Thermal Rating: on line 6849-1038 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1471
% INFO    : Updated Thermal Rating: on line 7533-10300 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1807
% INFO    : Updated Thermal Rating: on line 11994-7533 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 964
% INFO    : Updated Thermal Rating: on line 11679-5579 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 511
% INFO    : Updated Thermal Rating: on line 5579-12015 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1296
% INFO    : Updated Thermal Rating: on line 13155-4260 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 309
% INFO    : Updated Thermal Rating: on line 4571-4383 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 766
% INFO    : Updated Thermal Rating: on line 596-13378 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1452
% INFO    : Updated Thermal Rating: on line 13378-2142 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 160
% INFO    : Updated Thermal Rating: on line 13378-7300 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1586
% INFO    : Updated Thermal Rating: on line 13378-2865 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 228
% INFO    : Updated Thermal Rating: on line 12637-1099 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 344
% INFO    : Updated Thermal Rating: on line 1459-12463 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 409
% INFO    : Updated Thermal Rating: on line 2616-9557 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2226
% INFO    : Updated Thermal Rating: on line 5996-674 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3045
% INFO    : Updated Thermal Rating: on line 5996-7222 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3570
% INFO    : Updated Thermal Rating: on line 953-10900 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 297
% INFO    : Updated Thermal Rating: on line 4708-10900 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 293
% INFO    : Updated Thermal Rating: on line 1706-8231 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 317
% INFO    : Updated Thermal Rating: on line 7094-8231 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 320
% INFO    : Updated Thermal Rating: on line 11679-7281 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 213
% INFO    : Updated Thermal Rating: on line 11491-7281 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 632
% INFO    : Updated Thermal Rating: on line 7281-595 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 364
% INFO    : Updated Thermal Rating: on line 10770-9459 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 40653
% INFO    : Updated Thermal Rating: on line 10770-12382 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 810
% INFO    : Updated Thermal Rating: on line 10770-11553 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1157
% INFO    : Updated Thermal Rating: on line 9459-12382 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 871
% INFO    : Updated Thermal Rating: on line 9459-13116 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 183
% INFO    : Updated Thermal Rating: on line 9459-11557 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 136
% INFO    : Updated Thermal Rating: on line 12174-5267 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 530
% INFO    : Updated Thermal Rating: on line 4524-5267 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 522
% INFO    : Updated Thermal Rating: on line 7032-10289 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 376
% INFO    : Updated Thermal Rating: on line 7032-10705 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 247
% INFO    : Updated Thermal Rating: on line 7744-4188 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 980
% INFO    : Updated Thermal Rating: on line 1492-499 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 424
% INFO    : Updated Thermal Rating: on line 6655-1492 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 445
% INFO    : Updated Thermal Rating: on line 1038-6319 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 41563
% INFO    : Updated Thermal Rating: on line 11994-6319 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1470
% INFO    : Updated Thermal Rating: on line 2193-903 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 578
% INFO    : Updated Thermal Rating: on line 9784-7332 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 539
% INFO    : Updated Thermal Rating: on line 9784-7332 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 543
% INFO    : Updated Thermal Rating: on line 7332-8198 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1005
% INFO    : Updated Thermal Rating: on line 4396-11589 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1382
% INFO    : Updated Thermal Rating: on line 7659-4560 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 42457
% INFO    : Updated Thermal Rating: on line 5768-7659 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 765
% INFO    : Updated Thermal Rating: on line 1697-4560 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1305
% INFO    : Updated Thermal Rating: on line 2334-6652 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 376
% INFO    : Updated Thermal Rating: on line 6652-2213 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 340
% INFO    : Updated Thermal Rating: on line 1705-5719 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 453
% INFO    : Updated Thermal Rating: on line 5719-1383 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1259
% INFO    : Updated Thermal Rating: on line 498-7158 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 117
% INFO    : Updated Thermal Rating: on line 7158-1222 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 291
% INFO    : Updated Thermal Rating: on line 7158-4923 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 383
% INFO    : Updated Thermal Rating: on line 12540-7158 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 289
% INFO    : Updated Thermal Rating: on line 7158-3539 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 200
% INFO    : Updated Thermal Rating: on line 7158-3539 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 203
% INFO    : Updated Thermal Rating: on line 1503-899 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1273
% INFO    : Updated Thermal Rating: on line 899-9539 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 702
% INFO    : Updated Thermal Rating: on line 3992-11846 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 704
% INFO    : Updated Thermal Rating: on line 11846-11091 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1298
% INFO    : Updated Thermal Rating: on line 2986-11679 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 462
% INFO    : Updated Thermal Rating: on line 13328-11540 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1323
% INFO    : Updated Thermal Rating: on line 13328-11540 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1605
% INFO    : Updated Thermal Rating: on line 13328-9721 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 435
% INFO    : Updated Thermal Rating: on line 11877-13328 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 518
% INFO    : Updated Thermal Rating: on line 11540-2442 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 834
% INFO    : Updated Thermal Rating: on line 2527-8868 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1226
% INFO    : Updated Thermal Rating: on line 5597-8868 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1317
% INFO    : Updated Thermal Rating: on line 3293-9630 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1163
% INFO    : Updated Thermal Rating: on line 3293-7390 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 549
% INFO    : Updated Thermal Rating: on line 3293-8180 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 358
% INFO    : Updated Thermal Rating: on line 13606-2527 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 884
% INFO    : Updated Thermal Rating: on line 7926-11508 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 150
% INFO    : Updated Thermal Rating: on line 9770-12953 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8696
% INFO    : Updated Thermal Rating: on line 11832-9770 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2086
% INFO    : Updated Thermal Rating: on line 5431-4641 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 36059
% INFO    : Updated Thermal Rating: on line 9128-5142 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2956
% INFO    : Updated Thermal Rating: on line 5142-13221 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1374
% INFO    : Updated Thermal Rating: on line 6838-11554 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 233
% INFO    : Updated Thermal Rating: on line 5768-1697 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 987
% INFO    : Updated Thermal Rating: on line 11433-12242 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 741
% INFO    : Updated Thermal Rating: on line 11433-12242 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 729
% INFO    : Updated Thermal Rating: on line 10937-3594 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 387
% INFO    : Updated Thermal Rating: on line 12015-1705 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 651
% INFO    : Updated Thermal Rating: on line 7094-1706 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 164
% INFO    : Updated Thermal Rating: on line 12667-1706 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1819
% INFO    : Updated Thermal Rating: on line 12774-9876 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1011
% INFO    : Updated Thermal Rating: on line 12774-848 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20628
% INFO    : Updated Thermal Rating: on line 1250-12774 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 819
% INFO    : Updated Thermal Rating: on line 1250-12774 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 832
% INFO    : Updated Thermal Rating: on line 12774-8985 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 545
% INFO    : Updated Thermal Rating: on line 9454-7986 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3147
% INFO    : Updated Thermal Rating: on line 9271-3342 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 343
% INFO    : Updated Thermal Rating: on line 13623-3342 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 315
% INFO    : Updated Thermal Rating: on line 8463-10190 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1037
% INFO    : Updated Thermal Rating: on line 293-802 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 628
% INFO    : Updated Thermal Rating: on line 293-10584 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 485
% INFO    : Updated Thermal Rating: on line 6175-8417 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 38242
% INFO    : Updated Thermal Rating: on line 6175-1800 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 585
% INFO    : Updated Thermal Rating: on line 6175-674 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 595
% INFO    : Updated Thermal Rating: on line 6175-5175 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 481
% INFO    : Updated Thermal Rating: on line 6175-4909 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 266
% INFO    : Updated Thermal Rating: on line 7415-6175 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 259
% INFO    : Updated Thermal Rating: on line 3747-6175 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142
% INFO    : Updated Thermal Rating: on line 1214-9876 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 214
% INFO    : Updated Thermal Rating: on line 3400-674 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 250
% INFO    : Updated Thermal Rating: on line 2010-2364 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 275
% INFO    : Updated Thermal Rating: on line 1296-2010 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 298
% INFO    : Updated Thermal Rating: on line 2010-6945 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 324
% INFO    : Updated Thermal Rating: on line 2727-2450 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 898
% INFO    : Updated Thermal Rating: on line 7326-6941 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2144
% INFO    : Updated Thermal Rating: on line 2884-7984 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 644
% INFO    : Updated Thermal Rating: on line 6914-2884 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1692
% INFO    : Updated Thermal Rating: on line 12301-10882 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 425
% INFO    : Updated Thermal Rating: on line 9161-8337 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 38997
% INFO    : Updated Thermal Rating: on line 9161-11292 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5413
% INFO    : Updated Thermal Rating: on line 6518-4827 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1074
% INFO    : Updated Thermal Rating: on line 13622-8337 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5448
% INFO    : Updated Thermal Rating: on line 5374-2636 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 219
% INFO    : Updated Thermal Rating: on line 5374-5971 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 222
% INFO    : Updated Thermal Rating: on line 5374-2499 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 627
% INFO    : Updated Thermal Rating: on line 10296-6205 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 294
% INFO    : Updated Thermal Rating: on line 2204-12012 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1279
% INFO    : Updated Thermal Rating: on line 8051-11491 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 382
% INFO    : Updated Thermal Rating: on line 13236-1890 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 40653
% INFO    : Updated Thermal Rating: on line 1890-9721 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 153
% INFO    : Updated Thermal Rating: on line 7924-1890 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 159
% INFO    : Updated Thermal Rating: on line 7924-1890 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 161
% INFO    : Updated Thermal Rating: on line 1890-1773 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 563
% INFO    : Updated Thermal Rating: on line 1890-11877 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 135
% INFO    : Updated Thermal Rating: on line 3411-5020 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1590
% INFO    : Updated Thermal Rating: on line 3411-10999 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2904
% INFO    : Updated Thermal Rating: on line 3411-3092 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1664
% INFO    : Updated Thermal Rating: on line 11779-11354 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 323
% INFO    : Updated Thermal Rating: on line 11779-11075 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 316
% INFO    : Updated Thermal Rating: on line 2744-7358 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 431
% INFO    : Updated Thermal Rating: on line 2744-13446 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 233
% INFO    : Updated Thermal Rating: on line 7358-11607 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1285
% INFO    : Updated Thermal Rating: on line 7358-7669 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1617
% INFO    : Updated Thermal Rating: on line 12104-12301 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 888
% INFO    : Updated Thermal Rating: on line 1137-4064 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 233
% INFO    : Updated Thermal Rating: on line 7584-10293 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 175
% INFO    : Updated Thermal Rating: on line 2126-10293 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 503
% INFO    : Updated Thermal Rating: on line 6817-4081 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 387
% INFO    : Updated Thermal Rating: on line 498-1222 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 207
% INFO    : Updated Thermal Rating: on line 989-11433 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1780
% INFO    : Updated Thermal Rating: on line 989-11433 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1811
% INFO    : Updated Thermal Rating: on line 6972-5980 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 284
% INFO    : Updated Thermal Rating: on line 9270-13564 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 222
% INFO    : Updated Thermal Rating: on line 10289-9630 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 265
% INFO    : Updated Thermal Rating: on line 6657-13199 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 178
% INFO    : Updated Thermal Rating: on line 6657-13199 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 178
% INFO    : Updated Thermal Rating: on line 4524-13199 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 245
% INFO    : Updated Thermal Rating: on line 8042-6725 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 342
% INFO    : Updated Thermal Rating: on line 6979-3963 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 637
% INFO    : Updated Thermal Rating: on line 11450-2995 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 266
% INFO    : Updated Thermal Rating: on line 989-11799 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1728
% INFO    : Updated Thermal Rating: on line 989-5224 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3055
% INFO    : Updated Thermal Rating: on line 989-3564 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 183
% INFO    : Updated Thermal Rating: on line 1660-11553 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2059
% INFO    : Updated Thermal Rating: on line 13139-9488 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1284
% INFO    : Updated Thermal Rating: on line 13139-11682 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1311
% INFO    : Updated Thermal Rating: on line 11041-12371 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 261
% INFO    : Updated Thermal Rating: on line 1496-8416 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 303
% INFO    : Updated Thermal Rating: on line 1496-8257 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2526
% INFO    : Updated Thermal Rating: on line 883-9128 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1997
% INFO    : Updated Thermal Rating: on line 1383-2511 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1152
% INFO    : Updated Thermal Rating: on line 1383-2511 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1426
% INFO    : Updated Thermal Rating: on line 8917-7295 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 665
% INFO    : Updated Thermal Rating: on line 2231-13404 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1807
% INFO    : Updated Thermal Rating: on line 10868-13649 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1324
% INFO    : Updated Thermal Rating: on line 13649-5597 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 482
% INFO    : Updated Thermal Rating: on line 3435-10296 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 147
% INFO    : Updated Thermal Rating: on line 8832-10691 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 247
% INFO    : Updated Thermal Rating: on line 9792-9721 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 955
% INFO    : Updated Thermal Rating: on line 8257-9792 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 618
% INFO    : Updated Thermal Rating: on line 744-4409 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 428
% INFO    : Updated Thermal Rating: on line 256-6941 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2408
% INFO    : Updated Thermal Rating: on line 256-2204 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2853
% INFO    : Updated Thermal Rating: on line 256-2204 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2801
% INFO    : Updated Thermal Rating: on line 2216-256 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3060
% INFO    : Updated Thermal Rating: on line 4169-256 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5563
% INFO    : Updated Thermal Rating: on line 8931-7984 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 149704
% INFO    : Updated Thermal Rating: on line 6914-7984 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 574
% INFO    : Updated Thermal Rating: on line 10393-12463 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 41563
% INFO    : Updated Thermal Rating: on line 13591-8503 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1528
% INFO    : Updated Thermal Rating: on line 9807-9304 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1026
% INFO    : Updated Thermal Rating: on line 11658-12538 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 569
% INFO    : Updated Thermal Rating: on line 13557-596 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1211
% INFO    : Updated Thermal Rating: on line 2193-4514 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1303
% INFO    : Updated Thermal Rating: on line 4514-5971 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 682
% INFO    : Updated Thermal Rating: on line 2578-11105 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 608
% INFO    : Updated Thermal Rating: on line 2578-2450 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 912
% INFO    : Updated Thermal Rating: on line 4362-10897 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 357
% INFO    : Updated Thermal Rating: on line 10897-6387 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1749
% INFO    : Updated Thermal Rating: on line 2231-2862 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2370
% INFO    : Updated Thermal Rating: on line 3400-2231 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 251
% INFO    : Updated Thermal Rating: on line 8310-2862 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2551
% INFO    : Updated Thermal Rating: on line 1296-6263 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 265
% INFO    : Updated Thermal Rating: on line 6263-6594 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 485
% INFO    : Updated Thermal Rating: on line 6263-7306 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 239
% INFO    : Updated Thermal Rating: on line 6263-7306 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 242
% INFO    : Updated Thermal Rating: on line 6941-2204 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5254
% INFO    : Updated Thermal Rating: on line 12301-3435 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 42457
% INFO    : Updated Thermal Rating: on line 12301-11984 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 331
% INFO    : Updated Thermal Rating: on line 744-4913 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 346
% INFO    : Updated Thermal Rating: on line 1901-5417 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3185
% INFO    : Updated Thermal Rating: on line 13150-1901 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10709
% INFO    : Updated Thermal Rating: on line 12960-6410 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 470
% INFO    : Updated Thermal Rating: on line 12960-6410 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 477
% INFO    : Updated Thermal Rating: on line 1502-8416 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 497
% INFO    : Updated Thermal Rating: on line 4312-9402 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2430
% INFO    : Updated Thermal Rating: on line 6722-7019 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1103
% INFO    : Updated Thermal Rating: on line 7019-13527 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 863
% INFO    : Updated Thermal Rating: on line 12860-10413 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 517
% INFO    : Updated Thermal Rating: on line 12860-12669 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 528
% INFO    : Updated Thermal Rating: on line 2548-12205 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 928
% INFO    : Updated Thermal Rating: on line 9939-13006 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 311
% INFO    : Updated Thermal Rating: on line 13019-12268 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5526
% INFO    : Updated Thermal Rating: on line 9517-13019 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1303
% INFO    : Updated Thermal Rating: on line 2364-8042 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 919
% INFO    : Updated Thermal Rating: on line 1630-11727 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1552
% INFO    : Updated Thermal Rating: on line 4272-9750 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1575
% INFO    : Updated Thermal Rating: on line 5828-6817 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 720
% INFO    : Updated Thermal Rating: on line 1066-4125 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 185
% INFO    : Updated Thermal Rating: on line 4125-3944 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 425
% INFO    : Updated Thermal Rating: on line 6694-10421 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 995
% INFO    : Updated Thermal Rating: on line 420-12206 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 135
% INFO    : Updated Thermal Rating: on line 1316-12206 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1265
% INFO    : Updated Thermal Rating: on line 1250-7924 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 37471
% INFO    : Updated Thermal Rating: on line 57-11404 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 156
% INFO    : Updated Thermal Rating: on line 11404-11554 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 202
% INFO    : Updated Thermal Rating: on line 2216-5789 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2117
% INFO    : Updated Thermal Rating: on line 7584-6241 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1226
% INFO    : Updated Thermal Rating: on line 7584-10570 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 969
% INFO    : Updated Thermal Rating: on line 7584-2126 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 251
% INFO    : Updated Thermal Rating: on line 10570-2671 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 942
% INFO    : Updated Thermal Rating: on line 6241-5487 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1419
% INFO    : Updated Thermal Rating: on line 669-6241 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 517
% INFO    : Updated Thermal Rating: on line 3539-10577 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 498
% INFO    : Updated Thermal Rating: on line 9545-7912 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 662
% INFO    : Updated Thermal Rating: on line 7127-7912 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2530
% INFO    : Updated Thermal Rating: on line 11512-12324 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2545
% INFO    : Updated Thermal Rating: on line 10231-9000 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 403
% INFO    : Updated Thermal Rating: on line 13006-9000 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 307
% INFO    : Updated Thermal Rating: on line 1118-6739 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 623
% INFO    : Updated Thermal Rating: on line 1371-883 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1356
% INFO    : Updated Thermal Rating: on line 10999-10664 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2146
% INFO    : Updated Thermal Rating: on line 10664-398 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 358
% INFO    : Updated Thermal Rating: on line 10999-5020 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2314
% INFO    : Updated Thermal Rating: on line 703-9577 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1625
% INFO    : Updated Thermal Rating: on line 3992-12524 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 36059
% INFO    : Updated Thermal Rating: on line 12297-3992 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 553
% INFO    : Updated Thermal Rating: on line 3992-9291 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 404
% INFO    : Updated Thermal Rating: on line 12524-12649 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 265
% INFO    : Updated Thermal Rating: on line 7385-1121 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2381
% INFO    : Updated Thermal Rating: on line 11954-12243 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 674
% INFO    : Updated Thermal Rating: on line 3747-12243 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 719
% INFO    : Updated Thermal Rating: on line 85-9915 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 664
% INFO    : Updated Thermal Rating: on line 10771-9254 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 393
% INFO    : Updated Thermal Rating: on line 9254-12931 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 466
% INFO    : Updated Thermal Rating: on line 47-7495 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 198
% INFO    : Updated Thermal Rating: on line 1020-7495 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 409
% INFO    : Updated Thermal Rating: on line 2800-6830 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 490
% INFO    : Updated Thermal Rating: on line 1214-8814 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 531
% INFO    : Updated Thermal Rating: on line 12247-10566 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 182
% INFO    : Updated Thermal Rating: on line 12247-10566 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 185
% INFO    : Updated Thermal Rating: on line 12247-12083 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 195
% INFO    : Updated Thermal Rating: on line 11554-785 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 281
% INFO    : Updated Thermal Rating: on line 172-9784 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 541
% INFO    : Updated Thermal Rating: on line 172-9784 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 549
% INFO    : Updated Thermal Rating: on line 9741-802 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 904
% INFO    : Updated Thermal Rating: on line 6410-9954 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 246
% INFO    : Updated Thermal Rating: on line 8042-6594 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 299
% INFO    : Updated Thermal Rating: on line 8042-2334 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 207
% INFO    : Updated Thermal Rating: on line 8042-6945 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 182
% INFO    : Updated Thermal Rating: on line 6657-10595 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 246
% INFO    : Updated Thermal Rating: on line 6657-7188 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3394
% INFO    : Updated Thermal Rating: on line 6657-7188 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3401
% INFO    : Updated Thermal Rating: on line 3467-6657 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3082
% INFO    : Updated Thermal Rating: on line 3467-6657 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2883
% INFO    : Updated Thermal Rating: on line 9270-6579 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 441
% INFO    : Updated Thermal Rating: on line 7138-13606 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 594
% INFO    : Updated Thermal Rating: on line 9813-6453 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2633
% INFO    : Updated Thermal Rating: on line 6094-10318 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 821
% INFO    : Updated Thermal Rating: on line 13006-10318 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 405
% INFO    : Updated Thermal Rating: on line 5699-2861 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 677
% INFO    : Updated Thermal Rating: on line 10595-13116 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 450
% INFO    : Updated Thermal Rating: on line 12792-9644 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 707
% INFO    : Updated Thermal Rating: on line 5235-12792 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 342
% INFO    : Updated Thermal Rating: on line 12081-1066 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 259
% INFO    : Updated Thermal Rating: on line 12081-5744 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 263
% INFO    : Updated Thermal Rating: on line 1099-12201 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 716
% INFO    : Updated Thermal Rating: on line 13073-12540 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 220
% INFO    : Updated Thermal Rating: on line 7040-420 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 751
% INFO    : Updated Thermal Rating: on line 7040-420 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 763
% INFO    : Updated Thermal Rating: on line 7040-12851 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on line 13089-7040 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 107
% INFO    : Updated Thermal Rating: on line 420-11871 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 188
% INFO    : Updated Thermal Rating: on line 13221-6453 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1158
% INFO    : Updated Thermal Rating: on line 5597-7873 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 253
% INFO    : Updated Thermal Rating: on line 1819-7436 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1043
% INFO    : Updated Thermal Rating: on line 11832-5417 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5896
% INFO    : Updated Thermal Rating: on line 4894-6889 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1274
% INFO    : Updated Thermal Rating: on line 6889-10256 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 973
% INFO    : Updated Thermal Rating: on line 1720-6889 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1831
% INFO    : Updated Thermal Rating: on line 5659-2385 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 568
% INFO    : Updated Thermal Rating: on line 9703-5659 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 178159
% INFO    : Updated Thermal Rating: on line 5659-13139 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 405
% INFO    : Updated Thermal Rating: on line 5659-13139 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 413
% INFO    : Updated Thermal Rating: on line 5659-5758 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3180
% INFO    : Updated Thermal Rating: on line 5659-1619 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3124
% INFO    : Updated Thermal Rating: on line 6122-13557 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1263
% INFO    : Updated Thermal Rating: on line 3534-4898 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 183
% INFO    : Updated Thermal Rating: on line 2893-3534 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 818
% INFO    : Updated Thermal Rating: on line 7138-10868 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2607
% INFO    : Updated Thermal Rating: on line 8673-10346 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3231
% INFO    : Updated Thermal Rating: on line 8673-11431 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 35373
% INFO    : Updated Thermal Rating: on line 7575-12516 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 948
% INFO    : Updated Thermal Rating: on line 13461-9517 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 844
% INFO    : Updated Thermal Rating: on line 13461-10779 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4682
% INFO    : Updated Thermal Rating: on line 13461-13527 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1388
% INFO    : Updated Thermal Rating: on line 11597-11354 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 491
% INFO    : Updated Thermal Rating: on line 1863-1066 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 228
% INFO    : Updated Thermal Rating: on line 12201-5068 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1285
% INFO    : Updated Thermal Rating: on line 3975-11376 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1658
% INFO    : Updated Thermal Rating: on line 3975-12125 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9509
% INFO    : Updated Thermal Rating: on line 11376-10779 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 737
% INFO    : Updated Thermal Rating: on line 4909-3978 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 251
% INFO    : Updated Thermal Rating: on line 10049-11147 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 459
% INFO    : Updated Thermal Rating: on line 6658-2865 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2431
% INFO    : Updated Thermal Rating: on line 6658-1380 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1448
% INFO    : Updated Thermal Rating: on line 1296-1916 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 529
% INFO    : Updated Thermal Rating: on line 7306-1916 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 770
% INFO    : Updated Thermal Rating: on line 9545-526 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 38242
% INFO    : Updated Thermal Rating: on line 11091-526 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2523
% INFO    : Updated Thermal Rating: on line 5448-526 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 538
% INFO    : Updated Thermal Rating: on line 9545-6521 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 768
% INFO    : Updated Thermal Rating: on line 10843-9158 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1304
% INFO    : Updated Thermal Rating: on line 9158-13239 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 809
% INFO    : Updated Thermal Rating: on line 10843-5952 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 38997
% INFO    : Updated Thermal Rating: on line 8196-10843 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 962
% INFO    : Updated Thermal Rating: on line 4278-5952 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 948
% INFO    : Updated Thermal Rating: on line 5952-12090 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 415
% INFO    : Updated Thermal Rating: on line 5952-10106 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 586
% INFO    : Updated Thermal Rating: on line 2415-10611 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1077
% INFO    : Updated Thermal Rating: on line 13239-13015 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1315
% INFO    : Updated Thermal Rating: on line 3991-8196 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1573
% INFO    : Updated Thermal Rating: on line 1584-4278 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1550
% INFO    : Updated Thermal Rating: on line 3944-1584 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 734
% INFO    : Updated Thermal Rating: on line 1761-7629 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 313
% INFO    : Updated Thermal Rating: on line 1818-1095 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 614
% INFO    : Updated Thermal Rating: on line 6150-9580 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 234
% INFO    : Updated Thermal Rating: on line 9580-1945 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2852
% INFO    : Updated Thermal Rating: on line 3978-7964 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1010
% INFO    : Updated Thermal Rating: on line 57-5918 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 801
% INFO    : Updated Thermal Rating: on line 1818-10551 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 506
% INFO    : Updated Thermal Rating: on line 9121-11727 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 274
% INFO    : Updated Thermal Rating: on line 7623-4272 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 270
% INFO    : Updated Thermal Rating: on line 8814-8985 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 466
% INFO    : Updated Thermal Rating: on line 10039-5650 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 289
% INFO    : Updated Thermal Rating: on line 10039-7390 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 437
% INFO    : Updated Thermal Rating: on line 12177-10039 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 247
% INFO    : Updated Thermal Rating: on line 11105-9838 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2235
% INFO    : Updated Thermal Rating: on line 9838-744 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 785
% INFO    : Updated Thermal Rating: on line 7188-3537 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 355
% INFO    : Updated Thermal Rating: on line 12540-2414 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 176
% INFO    : Updated Thermal Rating: on line 8207-2414 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 236
% INFO    : Updated Thermal Rating: on line 3332-2414 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 240
% INFO    : Updated Thermal Rating: on line 11697-6579 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 382
% INFO    : Updated Thermal Rating: on line 4894-6989 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2007
% INFO    : Updated Thermal Rating: on line 11041-6449 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 39833
% INFO    : Updated Thermal Rating: on line 11514-10771 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 458
% INFO    : Updated Thermal Rating: on line 2416-3047 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2874
% INFO    : Updated Thermal Rating: on line 9381-47 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 551
% INFO    : Updated Thermal Rating: on line 744-10531 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 463
% INFO    : Updated Thermal Rating: on line 1296-6434 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 630
% INFO    : Updated Thermal Rating: on line 1296-6434 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 619
% INFO    : Updated Thermal Rating: on line 10698-13036 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1552
% INFO    : Updated Thermal Rating: on line 11075-2142 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3130
% INFO    : Updated Thermal Rating: on line 4898-11075 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2864
% INFO    : Updated Thermal Rating: on line 4898-2142 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 40653
% INFO    : Updated Thermal Rating: on line 11597-2142 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 310
% INFO    : Updated Thermal Rating: on line 5372-7313 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1062
% INFO    : Updated Thermal Rating: on line 708-1857 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 191
% INFO    : Updated Thermal Rating: on line 1857-3016 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1722
% INFO    : Updated Thermal Rating: on line 3937-7300 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1475
% INFO    : Updated Thermal Rating: on line 12177-8503 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1191
% INFO    : Updated Thermal Rating: on line 9935-5235 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 195
% INFO    : Updated Thermal Rating: on line 3125-9935 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 692
% INFO    : Updated Thermal Rating: on line 6989-6364 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6061
% INFO    : Updated Thermal Rating: on line 5597-4879 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 41563
% INFO    : Updated Thermal Rating: on line 5597-4606 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 409
% INFO    : Updated Thermal Rating: on line 4879-12981 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 42457
% INFO    : Updated Thermal Rating: on line 10231-13006 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 510
% INFO    : Updated Thermal Rating: on line 6343-7782 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1325
% INFO    : Updated Thermal Rating: on line 4362-6387 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 348
% INFO    : Updated Thermal Rating: on line 1945-4362 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5417
% INFO    : Updated Thermal Rating: on line 1380-6122 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1108
% INFO    : Updated Thermal Rating: on line 2893-2865 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 557
% INFO    : Updated Thermal Rating: on line 11215-12756 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 524
% INFO    : Updated Thermal Rating: on line 9400-1316 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 263
% INFO    : Updated Thermal Rating: on line 6925-9400 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 264
% INFO    : Updated Thermal Rating: on line 5811-10665 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 233
% INFO    : Updated Thermal Rating: on line 10665-3125 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 704
% INFO    : Updated Thermal Rating: on line 1325-708 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 578
% INFO    : Updated Thermal Rating: on line 11437-8703 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 220
% INFO    : Updated Thermal Rating: on line 2517-883 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 586
% INFO    : Updated Thermal Rating: on line 2522-1870 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 877
% INFO    : Updated Thermal Rating: on line 1870-953 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 200
% INFO    : Updated Thermal Rating: on line 2522-7301 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 864
% INFO    : Updated Thermal Rating: on line 7301-4708 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 197
% INFO    : Updated Thermal Rating: on line 1316-6150 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 517
% INFO    : Updated Thermal Rating: on line 2679-3501 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1706
% INFO    : Updated Thermal Rating: on line 2517-10256 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2058
% INFO    : Updated Thermal Rating: on line 5738-10088 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 36730
% INFO    : Updated Thermal Rating: on line 2636-117 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 36059
% INFO    : Updated Thermal Rating: on line 3594-117 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1416
% INFO    : Updated Thermal Rating: on line 2499-2636 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 281
% INFO    : Updated Thermal Rating: on line 12496-5986 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3793
% INFO    : Updated Thermal Rating: on line 5986-8101 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 962
% INFO    : Updated Thermal Rating: on line 10705-7629 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 204
% INFO    : Updated Thermal Rating: on line 10154-7629 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 196
% INFO    : Updated Thermal Rating: on line 10654-7303 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 858
% INFO    : Updated Thermal Rating: on line 5980-11514 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 360
% INFO    : Updated Thermal Rating: on line 10289-12177 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 38242
% INFO    : Updated Thermal Rating: on line 10154-12177 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 162
% INFO    : Updated Thermal Rating: on line 12177-8329 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 696
% INFO    : Updated Thermal Rating: on line 1316-11871 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 661
% INFO    : Updated Thermal Rating: on line 4769-2517 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16461
% INFO    : Updated Thermal Rating: on line 4769-2517 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16827
% INFO    : Updated Thermal Rating: on line 2517-1720 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2499
% INFO    : Updated Thermal Rating: on line 2216-4169 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2668
% INFO    : Updated Thermal Rating: on line 1502-2442 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 388
% INFO    : Updated Thermal Rating: on line 13239-5699 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 38997
% INFO    : Updated Thermal Rating: on line 5699-10106 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 796
% INFO    : Updated Thermal Rating: on line 11215-7575 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1993
% INFO    : Updated Thermal Rating: on line 9304-8101 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 39833
% INFO    : Updated Thermal Rating: on line 8101-6434 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1385
% INFO    : Updated Thermal Rating: on line 1773-10791 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 927
% INFO    : Updated Thermal Rating: on line 4571-7138 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 40653
% INFO    : Updated Thermal Rating: on line 12909-11554 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 455
% INFO    : Updated Thermal Rating: on line 5918-11554 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 554
% INFO    : Updated Thermal Rating: on line 688-11554 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 451
% INFO    : Updated Thermal Rating: on line 9402-8207 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2280
% INFO    : Updated Thermal Rating: on line 9402-3332 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1927
% INFO    : Updated Thermal Rating: on line 7497-1325 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 209
% INFO    : Updated Thermal Rating: on line 11557-3564 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 384
% INFO    : Updated Thermal Rating: on line 3871-838 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 42457
% INFO    : Updated Thermal Rating: on line 6856-1720 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11376
% INFO    : Updated Thermal Rating: on line 6856-1720 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11607
% INFO    : Updated Thermal Rating: on line 12090-1020 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1026
% INFO    : Updated Thermal Rating: on line 10812-11357 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 312
% INFO    : Updated Thermal Rating: on line 7127-5448 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 36059
% INFO    : Updated Thermal Rating: on line 6253-5448 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 625
% INFO    : Updated Thermal Rating: on line 11784-12056 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 287
% INFO    : Updated Thermal Rating: on line 10519-11784 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 297
% INFO    : Updated Thermal Rating: on line 11127-5756 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 356
% INFO    : Updated Thermal Rating: on line 180-5756 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 196
% INFO    : Updated Thermal Rating: on line 5508-12532 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 238
% INFO    : Updated Thermal Rating: on line 3041-12532 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 254
% INFO    : Updated Thermal Rating: on line 10046-8328 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 615
% INFO    : Updated Thermal Rating: on line 10046-2022 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 562
% INFO    : Updated Thermal Rating: on line 6978-8078 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 457
% INFO    : Updated Thermal Rating: on line 12604-6978 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 263
% INFO    : Updated Thermal Rating: on line 6978-8540 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 542
% INFO    : Updated Thermal Rating: on line 11385-11022 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 507
% INFO    : Updated Thermal Rating: on line 11385-9765 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 501
% INFO    : Updated Thermal Rating: on line 11320-2022 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 290
% INFO    : Updated Thermal Rating: on line 13260-11320 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 368
% INFO    : Updated Thermal Rating: on line 8334-6514 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on line 8334-4491 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 582
% INFO    : Updated Thermal Rating: on line 8334-10454 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4557
% INFO    : Updated Thermal Rating: on line 8334-3439 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2775
% INFO    : Updated Thermal Rating: on line 3902-8334 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 326
% INFO    : Updated Thermal Rating: on line 11733-8334 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 719
% INFO    : Updated Thermal Rating: on line 8334-13559 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4876
% INFO    : Updated Thermal Rating: on line 8334-12405 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4789
% INFO    : Updated Thermal Rating: on line 8334-7184 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 260
% INFO    : Updated Thermal Rating: on line 8334-1011 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 635
% INFO    : Updated Thermal Rating: on line 7529-6060 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 563
% INFO    : Updated Thermal Rating: on line 1568-6060 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 316
% INFO    : Updated Thermal Rating: on line 2988-1826 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 457
% INFO    : Updated Thermal Rating: on line 7010-1826 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 405
% INFO    : Updated Thermal Rating: on line 264-12403 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 448
% INFO    : Updated Thermal Rating: on line 264-371 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 436
% INFO    : Updated Thermal Rating: on line 9290-1842 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 883
% INFO    : Updated Thermal Rating: on line 67-1842 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 280
% INFO    : Updated Thermal Rating: on line 6552-11093 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 76483
% INFO    : Updated Thermal Rating: on line 6552-2187 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3628
% INFO    : Updated Thermal Rating: on line 11093-5193 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2886
% INFO    : Updated Thermal Rating: on line 4291-11093 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 387
% INFO    : Updated Thermal Rating: on line 2079-11093 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 812
% INFO    : Updated Thermal Rating: on line 8636-219 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2144
% INFO    : Updated Thermal Rating: on line 219-5775 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 600
% INFO    : Updated Thermal Rating: on line 219-4874 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3795
% INFO    : Updated Thermal Rating: on line 219-4960 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 944
% INFO    : Updated Thermal Rating: on line 219-12402 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 327
% INFO    : Updated Thermal Rating: on line 219-11847 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 215
% INFO    : Updated Thermal Rating: on line 8607-1322 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 617
% INFO    : Updated Thermal Rating: on line 8607-11720 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 278
% INFO    : Updated Thermal Rating: on line 3902-4227 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1320
% INFO    : Updated Thermal Rating: on line 3902-4227 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1296
% INFO    : Updated Thermal Rating: on line 3902-4227 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1331
% INFO    : Updated Thermal Rating: on line 3902-4227 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1357
% INFO    : Updated Thermal Rating: on line 504-10789 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1080
% INFO    : Updated Thermal Rating: on line 504-10789 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1134
% INFO    : Updated Thermal Rating: on line 504-10789 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1115
% INFO    : Updated Thermal Rating: on line 504-2560 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4559
% INFO    : Updated Thermal Rating: on line 504-7403 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6436
% INFO    : Updated Thermal Rating: on line 504-2187 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1056
% INFO    : Updated Thermal Rating: on line 504-7863 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2634
% INFO    : Updated Thermal Rating: on line 504-7863 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2583
% INFO    : Updated Thermal Rating: on line 10789-1948 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 536
% INFO    : Updated Thermal Rating: on line 10789-4106 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 514
% INFO    : Updated Thermal Rating: on line 4291-11646 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2775
% INFO    : Updated Thermal Rating: on line 12729-11646 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1129
% INFO    : Updated Thermal Rating: on line 2560-7403 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6550
% INFO    : Updated Thermal Rating: on line 5193-8636 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5749
% INFO    : Updated Thermal Rating: on line 12489-453 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3859
% INFO    : Updated Thermal Rating: on line 12489-453 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3926
% INFO    : Updated Thermal Rating: on line 1322-5775 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4599
% INFO    : Updated Thermal Rating: on line 7771-13329 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14483
% INFO    : Updated Thermal Rating: on line 2405-13329 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4369
% INFO    : Updated Thermal Rating: on line 3689-4291 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 437
% INFO    : Updated Thermal Rating: on line 3902-6514 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1077
% INFO    : Updated Thermal Rating: on line 3356-6514 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3245
% INFO    : Updated Thermal Rating: on line 12489-6514 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3280
% INFO    : Updated Thermal Rating: on line 10798-7771 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3292
% INFO    : Updated Thermal Rating: on line 7771-12313 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3222
% INFO    : Updated Thermal Rating: on line 3356-2505 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 929
% INFO    : Updated Thermal Rating: on line 12489-12928 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2713
% INFO    : Updated Thermal Rating: on line 4491-11733 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 581
% INFO    : Updated Thermal Rating: on line 5735-4491 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5129
% INFO    : Updated Thermal Rating: on line 13353-12490 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 795
% INFO    : Updated Thermal Rating: on line 12490-12399 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 785
% INFO    : Updated Thermal Rating: on line 9135-12490 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 291
% INFO    : Updated Thermal Rating: on line 5925-562 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 525
% INFO    : Updated Thermal Rating: on line 7033-562 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 324
% INFO    : Updated Thermal Rating: on line 7065-4095 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1952
% INFO    : Updated Thermal Rating: on line 4095-12632 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1722
% INFO    : Updated Thermal Rating: on line 329-1946 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3426
% INFO    : Updated Thermal Rating: on line 12235-1946 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 112
% INFO    : Updated Thermal Rating: on line 329-5675 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3250
% INFO    : Updated Thermal Rating: on line 5675-8991 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 191
% INFO    : Updated Thermal Rating: on line 329-4574 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 198
% INFO    : Updated Thermal Rating: on line 329-6858 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 167
% INFO    : Updated Thermal Rating: on line 329-757 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1069
% INFO    : Updated Thermal Rating: on line 329-13632 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 421
% INFO    : Updated Thermal Rating: on line 1400-12992 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1251
% INFO    : Updated Thermal Rating: on line 13260-12992 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 333
% INFO    : Updated Thermal Rating: on line 1568-1400 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 272
% INFO    : Updated Thermal Rating: on line 2420-12403 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1029
% INFO    : Updated Thermal Rating: on line 12403-4875 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 414
% INFO    : Updated Thermal Rating: on line 4358-10702 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2031
% INFO    : Updated Thermal Rating: on line 10702-10212 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3994
% INFO    : Updated Thermal Rating: on line 6119-10212 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8079
% INFO    : Updated Thermal Rating: on line 6119-12418 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 581
% INFO    : Updated Thermal Rating: on line 4358-5639 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 390
% INFO    : Updated Thermal Rating: on line 11712-4358 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 362
% INFO    : Updated Thermal Rating: on line 12298-7786 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 849
% INFO    : Updated Thermal Rating: on line 7786-11733 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1233
% INFO    : Updated Thermal Rating: on line 11127-9719 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 379
% INFO    : Updated Thermal Rating: on line 6843-9719 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 374
% INFO    : Updated Thermal Rating: on line 2941-2988 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 268
% INFO    : Updated Thermal Rating: on line 2380-9865 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 562
% INFO    : Updated Thermal Rating: on line 9865-2022 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 289
% INFO    : Updated Thermal Rating: on line 10608-10500 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 272
% INFO    : Updated Thermal Rating: on line 10608-2022 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 508
% INFO    : Updated Thermal Rating: on line 4289-10212 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1965
% INFO    : Updated Thermal Rating: on line 5639-4289 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 324
% INFO    : Updated Thermal Rating: on line 9765-4289 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 391
% INFO    : Updated Thermal Rating: on line 3004-8066 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 569
% INFO    : Updated Thermal Rating: on line 1151-3004 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 366
% INFO    : Updated Thermal Rating: on line 3548-3004 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 132
% INFO    : Updated Thermal Rating: on line 10-6376 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 438
% INFO    : Updated Thermal Rating: on line 10-9275 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 513
% INFO    : Updated Thermal Rating: on line 6376-8602 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1954
% INFO    : Updated Thermal Rating: on line 6376-9572 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 474
% INFO    : Updated Thermal Rating: on line 8602-2896 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 267
% INFO    : Updated Thermal Rating: on line 8602-8201 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 305
% INFO    : Updated Thermal Rating: on line 8602-8201 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 418
% INFO    : Updated Thermal Rating: on line 9308-6832 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 392
% INFO    : Updated Thermal Rating: on line 9308-12312 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 149
% INFO    : Updated Thermal Rating: on line 9308-12312 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 295
% INFO    : Updated Thermal Rating: on line 12034-6813 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 285
% INFO    : Updated Thermal Rating: on line 11014-6813 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 398
% INFO    : Updated Thermal Rating: on line 6926-12729 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 374
% INFO    : Updated Thermal Rating: on line 12604-6926 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 780
% INFO    : Updated Thermal Rating: on line 11127-12056 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 300
% INFO    : Updated Thermal Rating: on line 13290-4241 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 249
% INFO    : Updated Thermal Rating: on line 11663-13290 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 730
% INFO    : Updated Thermal Rating: on line 8558-9994 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1164
% INFO    : Updated Thermal Rating: on line 7046-8558 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 703
% INFO    : Updated Thermal Rating: on line 3847-8074 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 76418
% INFO    : Updated Thermal Rating: on line 868-3847 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 710
% INFO    : Updated Thermal Rating: on line 3689-4874 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 273
% INFO    : Updated Thermal Rating: on line 11435-2420 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1082
% INFO    : Updated Thermal Rating: on line 1762-7686 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 372
% INFO    : Updated Thermal Rating: on line 2798-1762 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 556
% INFO    : Updated Thermal Rating: on line 4006-10733 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 568
% INFO    : Updated Thermal Rating: on line 9135-10733 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 425
% INFO    : Updated Thermal Rating: on line 580-9455 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16502
% INFO    : Updated Thermal Rating: on line 580-9455 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17624
% INFO    : Updated Thermal Rating: on line 12354-1220 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 541
% INFO    : Updated Thermal Rating: on line 12354-1220 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 620
% INFO    : Updated Thermal Rating: on line 1220-9691 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 350
% INFO    : Updated Thermal Rating: on line 9455-5434 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 648
% INFO    : Updated Thermal Rating: on line 9455-12567 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2565
% INFO    : Updated Thermal Rating: on line 9455-12567 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2480
% INFO    : Updated Thermal Rating: on line 13228-4103 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1983
% INFO    : Updated Thermal Rating: on line 13228-371 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2523
% INFO    : Updated Thermal Rating: on line 4103-371 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2278
% INFO    : Updated Thermal Rating: on line 371-6832 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 378
% INFO    : Updated Thermal Rating: on line 371-2444 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 278
% INFO    : Updated Thermal Rating: on line 371-7581 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 290
% INFO    : Updated Thermal Rating: on line 9765-12418 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 593
% INFO    : Updated Thermal Rating: on line 12493-7065 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1055
% INFO    : Updated Thermal Rating: on line 6858-11134 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1323
% INFO    : Updated Thermal Rating: on line 10471-11134 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2626
% INFO    : Updated Thermal Rating: on line 757-11134 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 169
% INFO    : Updated Thermal Rating: on line 11134-13632 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 168
% INFO    : Updated Thermal Rating: on line 7607-3118 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 652
% INFO    : Updated Thermal Rating: on line 12731-12928 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1774
% INFO    : Updated Thermal Rating: on line 856-13353 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 998
% INFO    : Updated Thermal Rating: on line 4394-4295 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10473
% INFO    : Updated Thermal Rating: on line 9688-856 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 819
% INFO    : Updated Thermal Rating: on line 4532-9688 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 470
% INFO    : Updated Thermal Rating: on line 11906-7299 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2186
% INFO    : Updated Thermal Rating: on line 4241-11906 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 660
% INFO    : Updated Thermal Rating: on line 4241-7299 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 989
% INFO    : Updated Thermal Rating: on line 11663-4241 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 199
% INFO    : Updated Thermal Rating: on line 4241-9666 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 812
% INFO    : Updated Thermal Rating: on line 4241-13588 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 325
% INFO    : Updated Thermal Rating: on line 4241-632 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 303
% INFO    : Updated Thermal Rating: on line 6851-12502 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 183
% INFO    : Updated Thermal Rating: on line 12502-6377 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 324
% INFO    : Updated Thermal Rating: on line 12502-489 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 137
% INFO    : Updated Thermal Rating: on line 6260-13628 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 343
% INFO    : Updated Thermal Rating: on line 4106-13628 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 578
% INFO    : Updated Thermal Rating: on line 2468-11533 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1571
% INFO    : Updated Thermal Rating: on line 2468-9971 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 302
% INFO    : Updated Thermal Rating: on line 2468-3118 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 227
% INFO    : Updated Thermal Rating: on line 9765-11022 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 276
% INFO    : Updated Thermal Rating: on line 13273-11787 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1526
% INFO    : Updated Thermal Rating: on line 12231-11787 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 205
% INFO    : Updated Thermal Rating: on line 2195-11494 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2744
% INFO    : Updated Thermal Rating: on line 12632-11494 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1347
% INFO    : Updated Thermal Rating: on line 11127-13273 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 198
% INFO    : Updated Thermal Rating: on line 13273-8487 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 421
% INFO    : Updated Thermal Rating: on line 9994-13273 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 247
% INFO    : Updated Thermal Rating: on line 5508-8066 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 568
% INFO    : Updated Thermal Rating: on line 4960-12402 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 484
% INFO    : Updated Thermal Rating: on line 3776-13208 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 649
% INFO    : Updated Thermal Rating: on line 13260-3776 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 361
% INFO    : Updated Thermal Rating: on line 2941-4336 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1504
% INFO    : Updated Thermal Rating: on line 7010-4336 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 139
% INFO    : Updated Thermal Rating: on line 7529-2941 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 244
% INFO    : Updated Thermal Rating: on line 2896-11533 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 519
% INFO    : Updated Thermal Rating: on line 868-8074 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 726
% INFO    : Updated Thermal Rating: on line 3162-5505 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 285
% INFO    : Updated Thermal Rating: on line 5465-5505 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 177
% INFO    : Updated Thermal Rating: on line 12567-7311 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 32943
% INFO    : Updated Thermal Rating: on line 4006-9812 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 418
% INFO    : Updated Thermal Rating: on line 12156-9812 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 228
% INFO    : Updated Thermal Rating: on line 2195-13376 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1852
% INFO    : Updated Thermal Rating: on line 12231-12409 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1194
% INFO    : Updated Thermal Rating: on line 12231-2374 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 459
% INFO    : Updated Thermal Rating: on line 12231-8540 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 295
% INFO    : Updated Thermal Rating: on line 12231-10867 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 776
% INFO    : Updated Thermal Rating: on line 12409-10867 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1944
% INFO    : Updated Thermal Rating: on line 11103-11712 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 880
% INFO    : Updated Thermal Rating: on line 12644-11712 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 736
% INFO    : Updated Thermal Rating: on line 12644-11103 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1405
% INFO    : Updated Thermal Rating: on line 9436-11103 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1059
% INFO    : Updated Thermal Rating: on line 12644-9436 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1512
% INFO    : Updated Thermal Rating: on line 12644-2579 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 138
% INFO    : Updated Thermal Rating: on line 12644-9038 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 560
% INFO    : Updated Thermal Rating: on line 967-12298 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 709
% INFO    : Updated Thermal Rating: on line 12298-11733 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 534
% INFO    : Updated Thermal Rating: on line 7125-967 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 535
% INFO    : Updated Thermal Rating: on line 967-6450 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 451
% INFO    : Updated Thermal Rating: on line 11127-3131 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 378
% INFO    : Updated Thermal Rating: on line 1568-2380 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 335
% INFO    : Updated Thermal Rating: on line 2380-12427 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1345
% INFO    : Updated Thermal Rating: on line 12290-180 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 259
% INFO    : Updated Thermal Rating: on line 9994-2374 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 797
% INFO    : Updated Thermal Rating: on line 7686-3689 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 501
% INFO    : Updated Thermal Rating: on line 12632-2818 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4434
% INFO    : Updated Thermal Rating: on line 2818-8891 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2513
% INFO    : Updated Thermal Rating: on line 7125-10005 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 959
% INFO    : Updated Thermal Rating: on line 11663-12034 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 843
% INFO    : Updated Thermal Rating: on line 12034-11014 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 186
% INFO    : Updated Thermal Rating: on line 7033-6851 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 233
% INFO    : Updated Thermal Rating: on line 1739-2444 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 742
% INFO    : Updated Thermal Rating: on line 1739-12220 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 631
% INFO    : Updated Thermal Rating: on line 6377-2798 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 120
% INFO    : Updated Thermal Rating: on line 4574-8991 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2516
% INFO    : Updated Thermal Rating: on line 4574-8289 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1553
% INFO    : Updated Thermal Rating: on line 12235-8289 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 179
% INFO    : Updated Thermal Rating: on line 808-9572 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 620
% INFO    : Updated Thermal Rating: on line 808-7586 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 519
% INFO    : Updated Thermal Rating: on line 4816-1994 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1103
% INFO    : Updated Thermal Rating: on line 4816-3118 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1215
% INFO    : Updated Thermal Rating: on line 8078-12826 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 370
% INFO    : Updated Thermal Rating: on line 5925-67 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 994
% INFO    : Updated Thermal Rating: on line 7010-7529 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 275
% INFO    : Updated Thermal Rating: on line 6858-10471 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1130
% INFO    : Updated Thermal Rating: on line 10519-11014 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 639
% INFO    : Updated Thermal Rating: on line 10519-11014 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 746
% INFO    : Updated Thermal Rating: on line 11014-10519 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 767
% INFO    : Updated Thermal Rating: on line 10519-2807 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2640
% INFO    : Updated Thermal Rating: on line 10519-12290 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 339
% INFO    : Updated Thermal Rating: on line 2807-11014 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 975
% INFO    : Updated Thermal Rating: on line 11014-4394 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 135
% INFO    : Updated Thermal Rating: on line 11014-3162 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 458
% INFO    : Updated Thermal Rating: on line 12632-9582 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1176
% INFO    : Updated Thermal Rating: on line 4106-1948 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2052
% INFO    : Updated Thermal Rating: on line 8805-12326 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1772
% INFO    : Updated Thermal Rating: on line 12326-3118 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 270
% INFO    : Updated Thermal Rating: on line 2579-8805 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 432
% INFO    : Updated Thermal Rating: on line 8805-4532 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 158
% INFO    : Updated Thermal Rating: on line 6681-12354 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 543
% INFO    : Updated Thermal Rating: on line 6681-6260 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 960
% INFO    : Updated Thermal Rating: on line 5495-9290 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 229
% INFO    : Updated Thermal Rating: on line 12354-10602 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 909
% INFO    : Updated Thermal Rating: on line 10602-9160 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1451
% INFO    : Updated Thermal Rating: on line 8271-7029 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1814
% INFO    : Updated Thermal Rating: on line 8271-7029 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1943
% INFO    : Updated Thermal Rating: on line 7029-1255 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1850
% INFO    : Updated Thermal Rating: on line 3902-9828 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 396
% INFO    : Updated Thermal Rating: on line 11007-9828 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1248
% INFO    : Updated Thermal Rating: on line 9828-2095 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 765
% INFO    : Updated Thermal Rating: on line 12354-4978 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1200
% INFO    : Updated Thermal Rating: on line 12354-5518 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1167
% INFO    : Updated Thermal Rating: on line 9160-12354 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2019
% INFO    : Updated Thermal Rating: on line 7611-1568 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 332
% INFO    : Updated Thermal Rating: on line 7611-10552 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 873
% INFO    : Updated Thermal Rating: on line 4978-10552 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1127
% INFO    : Updated Thermal Rating: on line 10552-5518 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2906
% INFO    : Updated Thermal Rating: on line 10798-8271 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 30218
% INFO    : Updated Thermal Rating: on line 10798-6525 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 138377
% INFO    : Updated Thermal Rating: on line 10798-9119 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 178202
% INFO    : Updated Thermal Rating: on line 10798-8271 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 28169
% INFO    : Updated Thermal Rating: on line 10798-13376 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5396
% INFO    : Updated Thermal Rating: on line 3902-11413 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 749
% INFO    : Updated Thermal Rating: on line 3902-5284 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 47437
% INFO    : Updated Thermal Rating: on line 3902-1635 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 28868
% INFO    : Updated Thermal Rating: on line 3902-4800 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 29690
% INFO    : Updated Thermal Rating: on line 3902-6991 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 36317
% INFO    : Updated Thermal Rating: on line 3902-10515 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 35909
% INFO    : Updated Thermal Rating: on line 3902-8332 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2479
% INFO    : Updated Thermal Rating: on line 3902-1011 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 662
% INFO    : Updated Thermal Rating: on line 12427-10500 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 285
% INFO    : Updated Thermal Rating: on line 2532-489 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 273
% INFO    : Updated Thermal Rating: on line 9691-10936 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3267
% INFO    : Updated Thermal Rating: on line 1568-10936 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 202
% INFO    : Updated Thermal Rating: on line 5508-12402 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1359
% INFO    : Updated Thermal Rating: on line 5508-12402 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1565
% INFO    : Updated Thermal Rating: on line 12493-2405 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3370
% INFO    : Updated Thermal Rating: on line 2095-12731 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 434
% INFO    : Updated Thermal Rating: on line 8487-6843 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3659
% INFO    : Updated Thermal Rating: on line 9275-9971 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1296
% INFO    : Updated Thermal Rating: on line 9582-10718 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2524
% INFO    : Updated Thermal Rating: on line 11533-9971 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 310
% INFO    : Updated Thermal Rating: on line 7033-5762 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 248
% INFO    : Updated Thermal Rating: on line 740-5762 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 264
% INFO    : Updated Thermal Rating: on line 1151-7010 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 283
% INFO    : Updated Thermal Rating: on line 1528-12235 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 227
% INFO    : Updated Thermal Rating: on line 1528-12235 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on line 12235-9994 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 326
% INFO    : Updated Thermal Rating: on line 1234-4394 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1134
% INFO    : Updated Thermal Rating: on line 3162-1234 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 186
% INFO    : Updated Thermal Rating: on line 6450-12567 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1041
% INFO    : Updated Thermal Rating: on line 6069-1528 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 813
% INFO    : Updated Thermal Rating: on line 6069-1528 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 825
% INFO    : Updated Thermal Rating: on line 9765-4006 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 542
% INFO    : Updated Thermal Rating: on line 9765-13126 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 413
% INFO    : Updated Thermal Rating: on line 13588-4875 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 217
% INFO    : Updated Thermal Rating: on line 7485-2444 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1005
% INFO    : Updated Thermal Rating: on line 7485-2444 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1577
% INFO    : Updated Thermal Rating: on line 7485-11269 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1399
% INFO    : Updated Thermal Rating: on line 7485-11269 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1072
% INFO    : Updated Thermal Rating: on line 12661-9917 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 914
% INFO    : Updated Thermal Rating: on line 12661-2444 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1554
% INFO    : Updated Thermal Rating: on line 9917-11269 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1436
% INFO    : Updated Thermal Rating: on line 13546-12567 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1850
% INFO    : Updated Thermal Rating: on line 13546-12567 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2015
% INFO    : Updated Thermal Rating: on line 2444-12312 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 295
% INFO    : Updated Thermal Rating: on line 1923-8201 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2994
% INFO    : Updated Thermal Rating: on line 1923-3597 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2153
% INFO    : Updated Thermal Rating: on line 8201-3597 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1066
% INFO    : Updated Thermal Rating: on line 3597-7586 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 470
% INFO    : Updated Thermal Rating: on line 11847-11720 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 219
% INFO    : Updated Thermal Rating: on line 8271-3715 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2863
% INFO    : Updated Thermal Rating: on line 6745-8271 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19187
% INFO    : Updated Thermal Rating: on line 12832-8271 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19585
% INFO    : Updated Thermal Rating: on line 7047-4346 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1510
% INFO    : Updated Thermal Rating: on line 6069-4346 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 692
% INFO    : Updated Thermal Rating: on line 8792-7047 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3595
% INFO    : Updated Thermal Rating: on line 725-5495 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 295
% INFO    : Updated Thermal Rating: on line 740-725 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 448
% INFO    : Updated Thermal Rating: on line 7033-2103 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2403
% INFO    : Updated Thermal Rating: on line 8727-2103 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19462
% INFO    : Updated Thermal Rating: on line 7033-8392 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1581
% INFO    : Updated Thermal Rating: on line 11415-8392 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1274
% INFO    : Updated Thermal Rating: on line 7033-8727 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2442
% INFO    : Updated Thermal Rating: on line 7033-11415 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 637
% INFO    : Updated Thermal Rating: on line 1568-13208 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157
% INFO    : Updated Thermal Rating: on line 4006-5904 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1758
% INFO    : Updated Thermal Rating: on line 12220-7586 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 356
% INFO    : Updated Thermal Rating: on line 12220-6229 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1347
% INFO    : Updated Thermal Rating: on line 11847-12638 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5372
% INFO    : Updated Thermal Rating: on line 416-12638 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5000
% INFO    : Updated Thermal Rating: on line 12638-3273 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3309
% INFO    : Updated Thermal Rating: on line 12638-6069 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 417
% INFO    : Updated Thermal Rating: on line 416-5079 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1634
% INFO    : Updated Thermal Rating: on line 416-5079 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1606
% INFO    : Updated Thermal Rating: on line 12313-12493 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4700
% INFO    : Updated Thermal Rating: on line 5079-12826 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 336
% INFO    : Updated Thermal Rating: on line 5079-6069 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 357
% INFO    : Updated Thermal Rating: on line 5079-6069 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 350
% INFO    : Updated Thermal Rating: on line 6069-3273 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 409
% INFO    : Updated Thermal Rating: on line 868-740 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1187
% INFO    : Updated Thermal Rating: on line 67-740 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1202
% INFO    : Updated Thermal Rating: on line 7184-11007 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 501
% INFO    : Updated Thermal Rating: on line 868-10072 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2367
% INFO    : Updated Thermal Rating: on line 67-10072 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2095
% INFO    : Updated Thermal Rating: on line 12826-7046 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 646
% INFO    : Updated Thermal Rating: on line 8328-5221 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 822
% INFO    : Updated Thermal Rating: on line 5221-2022 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2823
% INFO    : Updated Thermal Rating: on line 5221-2022 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1425
% INFO    : Updated Thermal Rating: on line 1255-387 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2376
% INFO    : Updated Thermal Rating: on line 1568-12427 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 579
% INFO    : Updated Thermal Rating: on line 1568-1424 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 717
% INFO    : Updated Thermal Rating: on line 3689-2079 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 417
% INFO    : Updated Thermal Rating: on line 13260-4701 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 76483
% INFO    : Updated Thermal Rating: on line 1994-6197 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 857
% INFO    : Updated Thermal Rating: on line 6441-3689 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 538
% INFO    : Updated Thermal Rating: on line 2798-6441 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 317
% INFO    : Updated Thermal Rating: on line 6069-8792 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 955
% INFO    : Updated Thermal Rating: on line 5511-12567 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10143
% INFO    : Updated Thermal Rating: on line 5511-12567 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10731
% INFO    : Updated Thermal Rating: on line 11269-12312 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 99
% INFO    : Updated Thermal Rating: on line 11269-3118 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 201
% INFO    : Updated Thermal Rating: on line 8265-11269 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 410
% INFO    : Updated Thermal Rating: on line 11269-6197 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 322
% INFO    : Updated Thermal Rating: on line 9582-3212 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 149888
% INFO    : Updated Thermal Rating: on line 9582-3212 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 144157
% INFO    : Updated Thermal Rating: on line 3212-3923 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4551
% INFO    : Updated Thermal Rating: on line 3131-9038 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 907
% INFO    : Updated Thermal Rating: on line 7010-9298 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 873
% INFO    : Updated Thermal Rating: on line 9298-4304 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 28177
% INFO    : Updated Thermal Rating: on line 6229-12312 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 827
% INFO    : Updated Thermal Rating: on line 7581-12312 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21858
% INFO    : Updated Thermal Rating: on line 7581-12312 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21475
% INFO    : Updated Thermal Rating: on line 13126-5904 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1993
% INFO    : Updated Thermal Rating: on line 2798-12156 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3714
% INFO    : Updated Thermal Rating: on line 2532-12156 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3177
% INFO    : Updated Thermal Rating: on line 9666-11435 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 329
% INFO    : Updated Thermal Rating: on line 11435-13588 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2811
% INFO    : Updated Thermal Rating: on line 11435-632 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2846
% INFO    : Updated Thermal Rating: on line 632-13588 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2884
% INFO    : Updated Thermal Rating: on line 1424-12427 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1105
% INFO    : Updated Thermal Rating: on line 3041-3548 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3917
% INFO    : Updated Thermal Rating: on line 8265-6197 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5487
% INFO    : Updated Thermal Rating: on line 13632-5465 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2016
% INFO    : Updated Thermal Rating: on line 7010-4304 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 821
% INFO    : Updated Thermal Rating: on line 10322-7215 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1758
% INFO    : Updated Thermal Rating: on line 7215-10709 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1866
% INFO    : Updated Thermal Rating: on line 7215-10709 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1831
% INFO    : Updated Thermal Rating: on line 12158-7215 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4878
% INFO    : Updated Thermal Rating: on line 12158-7215 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4985
% INFO    : Updated Thermal Rating: on line 7215-8477 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2953
% INFO    : Updated Thermal Rating: on line 3071-7270 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2715
% INFO    : Updated Thermal Rating: on line 11977-3071 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 597
% INFO    : Updated Thermal Rating: on line 9388-10709 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2495
% INFO    : Updated Thermal Rating: on line 1165-9388 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7692
% INFO    : Updated Thermal Rating: on line 1165-9388 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7547
% INFO    : Updated Thermal Rating: on line 9388-8477 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2804
% INFO    : Updated Thermal Rating: on line 11977-12261 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 766
% INFO    : Updated Thermal Rating: on line 4131-7270 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 544
% INFO    : Updated Thermal Rating: on line 7441-3791 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3708
% INFO    : Updated Thermal Rating: on line 3791-8008 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2671
% INFO    : Updated Thermal Rating: on line 3791-9434 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1743
% INFO    : Updated Thermal Rating: on line 7264-8432 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 424
% INFO    : Updated Thermal Rating: on line 7264-4629 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 473
% INFO    : Updated Thermal Rating: on line 7264-4082 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 725
% INFO    : Updated Thermal Rating: on line 10124-13346 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4408
% INFO    : Updated Thermal Rating: on line 7678-8008 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9112
% INFO    : Updated Thermal Rating: on line 10910-10320 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24570
% INFO    : Updated Thermal Rating: on line 10910-388 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25560
% INFO    : Updated Thermal Rating: on line 2456-2913 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 28113
% INFO    : Updated Thermal Rating: on line 1898-1199 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3639
% INFO    : Updated Thermal Rating: on line 10910-1898 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1948
% INFO    : Updated Thermal Rating: on line 10910-1898 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1722
% INFO    : Updated Thermal Rating: on line 430-4014 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3906
% INFO    : Updated Thermal Rating: on line 4014-6044 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2209
% INFO    : Updated Thermal Rating: on line 11378-8008 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11122
% INFO    : Updated Thermal Rating: on line 8008-1199 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3629
% INFO    : Updated Thermal Rating: on line 10910-8008 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2209
% INFO    : Updated Thermal Rating: on line 8432-6284 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 620
% INFO    : Updated Thermal Rating: on line 5959-7459 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4869
% INFO    : Updated Thermal Rating: on line 5959-8466 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2456
% INFO    : Updated Thermal Rating: on line 5959-13463 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6334
% INFO    : Updated Thermal Rating: on line 5959-11565 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3556
% INFO    : Updated Thermal Rating: on line 5959-11565 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3627
% INFO    : Updated Thermal Rating: on line 430-12141 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1248
% INFO    : Updated Thermal Rating: on line 10910-430 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10341
% INFO    : Updated Thermal Rating: on line 10910-430 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10267
% INFO    : Updated Thermal Rating: on line 10910-430 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10247
% INFO    : Updated Thermal Rating: on line 13346-11056 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3246
% INFO    : Updated Thermal Rating: on line 13346-8466 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1852
% INFO    : Updated Thermal Rating: on line 13346-9434 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2734
% INFO    : Updated Thermal Rating: on line 11056-6044 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2892
% INFO    : Updated Thermal Rating: on line 7459-12141 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1633
% INFO    : Updated Thermal Rating: on line 13463-7459 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6891
% INFO    : Updated Thermal Rating: on line 7459-2456 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1585
% INFO    : Updated Thermal Rating: on line 1199-3272 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3211
% INFO    : Updated Thermal Rating: on line 6921-4082 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 981
% INFO    : Updated Thermal Rating: on line 6921-4082 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 963
% INFO    : Updated Thermal Rating: on line 6044-9434 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8045
% INFO    : Updated Thermal Rating: on line 11565-2456 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3206
% INFO    : Updated Thermal Rating: on line 11565-2456 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3269
% INFO    : Updated Thermal Rating: on line 7850-1144 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 855
% INFO    : Updated Thermal Rating: on line 11323-12959 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 76
% INFO    : Updated Thermal Rating: on line 11835-12959 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 128
% INFO    : Updated Thermal Rating: on line 11561-6149 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 692
% INFO    : Updated Thermal Rating: on line 5799-8882 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1178
% INFO    : Updated Thermal Rating: on line 5799-8882 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1280
% INFO    : Updated Thermal Rating: on line 5799-7850 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 660
% INFO    : Updated Thermal Rating: on line 5799-7850 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 674
% INFO    : Updated Thermal Rating: on line 1351-3321 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 338
% INFO    : Updated Thermal Rating: on line 10826-12633 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2455
% INFO    : Updated Thermal Rating: on line 13474-8882 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5210
% INFO    : Updated Thermal Rating: on line 13474-8882 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5294
% INFO    : Updated Thermal Rating: on line 9599-8560 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1027
% INFO    : Updated Thermal Rating: on line 8560-3321 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 267
% INFO    : Updated Thermal Rating: on line 11835-8560 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 145
% INFO    : Updated Thermal Rating: on line 879-2402 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 614
% INFO    : Updated Thermal Rating: on line 879-2402 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 626
% INFO    : Updated Thermal Rating: on line 6231-11323 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 62
% INFO    : Updated Thermal Rating: on line 657-6231 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 260
% INFO    : Updated Thermal Rating: on line 7850-2402 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 422
% INFO    : Updated Thermal Rating: on line 7850-2402 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 414
% INFO    : Updated Thermal Rating: on line 7397-2402 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 400
% INFO    : Updated Thermal Rating: on line 7397-2402 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 347
% INFO    : Updated Thermal Rating: on line 657-11323 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 162
% INFO    : Updated Thermal Rating: on line 6538-10041 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11147
% INFO    : Updated Thermal Rating: on line 6538-8623 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13517
% INFO    : Updated Thermal Rating: on line 1161-7955 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 78577
% INFO    : Updated Thermal Rating: on line 1161-8364 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1806
% INFO    : Updated Thermal Rating: on line 1161-8623 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2561
% INFO    : Updated Thermal Rating: on line 1161-2885 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4344
% INFO    : Updated Thermal Rating: on line 7260-7955 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1736
% INFO    : Updated Thermal Rating: on line 7260-10123 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6226
% INFO    : Updated Thermal Rating: on line 7260-9640 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1243
% INFO    : Updated Thermal Rating: on line 7260-10041 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12989
% INFO    : Updated Thermal Rating: on line 781-6831 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 681
% INFO    : Updated Thermal Rating: on line 781-9251 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 647
% INFO    : Updated Thermal Rating: on line 781-12787 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 423
% INFO    : Updated Thermal Rating: on line 781-8335 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 474
% INFO    : Updated Thermal Rating: on line 11-1019 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 46208
% INFO    : Updated Thermal Rating: on line 11-9103 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 595
% INFO    : Updated Thermal Rating: on line 11-12491 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1025
% INFO    : Updated Thermal Rating: on line 11-12420 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 575
% INFO    : Updated Thermal Rating: on line 1019-2379 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 281
% INFO    : Updated Thermal Rating: on line 1019-12491 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 904
% INFO    : Updated Thermal Rating: on line 2379-851 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8330
% INFO    : Updated Thermal Rating: on line 2379-851 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8330
% INFO    : Updated Thermal Rating: on line 2379-3392 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1075
% INFO    : Updated Thermal Rating: on line 11825-9103 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 452
% INFO    : Updated Thermal Rating: on line 11825-214 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 650
% INFO    : Updated Thermal Rating: on line 11825-6831 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 464
% INFO    : Updated Thermal Rating: on line 11825-10797 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19369
% INFO    : Updated Thermal Rating: on line 9103-214 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1074
% INFO    : Updated Thermal Rating: on line 9103-11918 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 766
% INFO    : Updated Thermal Rating: on line 9103-12974 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19369
% INFO    : Updated Thermal Rating: on line 214-12491 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1005
% INFO    : Updated Thermal Rating: on line 214-12491 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1174
% INFO    : Updated Thermal Rating: on line 214-6019 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1249
% INFO    : Updated Thermal Rating: on line 214-3392 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 578
% INFO    : Updated Thermal Rating: on line 10736-3075 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1052
% INFO    : Updated Thermal Rating: on line 10736-9251 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 836
% INFO    : Updated Thermal Rating: on line 3075-10550 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 414
% INFO    : Updated Thermal Rating: on line 4821-11337 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 344
% INFO    : Updated Thermal Rating: on line 4821-9339 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 275
% INFO    : Updated Thermal Rating: on line 6831-9565 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2756
% INFO    : Updated Thermal Rating: on line 6831-6019 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 444
% INFO    : Updated Thermal Rating: on line 6831-12089 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 547
% INFO    : Updated Thermal Rating: on line 3446-9339 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 704
% INFO    : Updated Thermal Rating: on line 3446-8335 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 400
% INFO    : Updated Thermal Rating: on line 10550-12787 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 607
% INFO    : Updated Thermal Rating: on line 10550-12089 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1914
% INFO    : Updated Thermal Rating: on line 1856-11918 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 763
% INFO    : Updated Thermal Rating: on line 9565-10797 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 514
% INFO    : Updated Thermal Rating: on line 9339-1654 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 398
% INFO    : Updated Thermal Rating: on line 9339-8335 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 394
% INFO    : Updated Thermal Rating: on line 12491-1654 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1014
% INFO    : Updated Thermal Rating: on line 12420-3392 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1075
% INFO    : Updated Thermal Rating: on line 9313-8364 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7097
% INFO    : Updated Thermal Rating: on line 9640-3730 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 39374
% INFO    : Updated Thermal Rating: on line 9640-1187 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8604
% INFO    : Updated Thermal Rating: on line 9640-940 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4898
% INFO    : Updated Thermal Rating: on line 9640-9200 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7428
% INFO    : Updated Thermal Rating: on line 8364-5348 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7290
% INFO    : Updated Thermal Rating: on line 8364-13005 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21698
% INFO    : Updated Thermal Rating: on line 8364-1187 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13517
% INFO    : Updated Thermal Rating: on line 5348-11896 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7290
% INFO    : Updated Thermal Rating: on line 5348-6535 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1192
% INFO    : Updated Thermal Rating: on line 5348-10858 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1184
% INFO    : Updated Thermal Rating: on line 5348-2885 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4344
% INFO    : Updated Thermal Rating: on line 11707-9704 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20154
% INFO    : Updated Thermal Rating: on line 11707-9704 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20154
% INFO    : Updated Thermal Rating: on line 13005-1187 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 35349
% INFO    : Updated Thermal Rating: on line 13005-12365 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 46958
% INFO    : Updated Thermal Rating: on line 9146-7900 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2195
% INFO    : Updated Thermal Rating: on line 9146-7900 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2195
% INFO    : Updated Thermal Rating: on line 9146-4389 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 882
% INFO    : Updated Thermal Rating: on line 9146-13288 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 882
% INFO    : Updated Thermal Rating: on line 9147-7550 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1235
% INFO    : Updated Thermal Rating: on line 9147-7550 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1235
% INFO    : Updated Thermal Rating: on line 9147-12357 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2343
% INFO    : Updated Thermal Rating: on line 9147-12357 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2343
% INFO    : Updated Thermal Rating: on line 9147-3941 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3078
% INFO    : Updated Thermal Rating: on line 9147-3941 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3078
% INFO    : Updated Thermal Rating: on line 10353-1207 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4908
% INFO    : Updated Thermal Rating: on line 7293-4263 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3416
% INFO    : Updated Thermal Rating: on line 7293-4263 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3416
% INFO    : Updated Thermal Rating: on line 7293-2825 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11912
% INFO    : Updated Thermal Rating: on line 7293-2825 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15411
% INFO    : Updated Thermal Rating: on line 7293-1207 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9949
% INFO    : Updated Thermal Rating: on line 7293-5969 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9949
% INFO    : Updated Thermal Rating: on line 7900-3237 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2737
% INFO    : Updated Thermal Rating: on line 7900-13211 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2809
% INFO    : Updated Thermal Rating: on line 9058-10916 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8755
% INFO    : Updated Thermal Rating: on line 9058-10916 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8755
% INFO    : Updated Thermal Rating: on line 3237-13211 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6050
% INFO    : Updated Thermal Rating: on line 11319-8501 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6338
% INFO    : Updated Thermal Rating: on line 11319-3397 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10624
% INFO    : Updated Thermal Rating: on line 11319-9768 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10347
% INFO    : Updated Thermal Rating: on line 3760-7550 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 992
% INFO    : Updated Thermal Rating: on line 3760-4971 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5981
% INFO    : Updated Thermal Rating: on line 3760-4971 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5981
% INFO    : Updated Thermal Rating: on line 8501-7747 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3331
% INFO    : Updated Thermal Rating: on line 8501-7747 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3331
% INFO    : Updated Thermal Rating: on line 4389-4970 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 833
% INFO    : Updated Thermal Rating: on line 4389-4970 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 833
% INFO    : Updated Thermal Rating: on line 4389-13288 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9714
% INFO    : Updated Thermal Rating: on line 4970-13211 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1332
% INFO    : Updated Thermal Rating: on line 4970-13211 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1332
% INFO    : Updated Thermal Rating: on line 4970-12811 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1332
% INFO    : Updated Thermal Rating: on line 4970-12811 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1332
% INFO    : Updated Thermal Rating: on line 3399-11944 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11775
% INFO    : Updated Thermal Rating: on line 3399-12634 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14040
% INFO    : Updated Thermal Rating: on line 4971-9576 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2296
% INFO    : Updated Thermal Rating: on line 4971-9576 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2296
% INFO    : Updated Thermal Rating: on line 3397-7747 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7844
% INFO    : Updated Thermal Rating: on line 3397-7747 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7844
% INFO    : Updated Thermal Rating: on line 7747-13511 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4226
% INFO    : Updated Thermal Rating: on line 7747-13511 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4226
% INFO    : Updated Thermal Rating: on line 9159-9704 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9559
% INFO    : Updated Thermal Rating: on line 9159-9704 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12377
% INFO    : Updated Thermal Rating: on line 9159-9113 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10139
% INFO    : Updated Thermal Rating: on line 9159-9113 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10139
% INFO    : Updated Thermal Rating: on line 8950-8037 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27898
% INFO    : Updated Thermal Rating: on line 13499-8037 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7005
% INFO    : Updated Thermal Rating: on line 13499-12634 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12673
% INFO    : Updated Thermal Rating: on line 7703-10667 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2616
% INFO    : Updated Thermal Rating: on line 7703-10667 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2616
% INFO    : Updated Thermal Rating: on line 7703-10916 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9218
% INFO    : Updated Thermal Rating: on line 7703-10916 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9218
% INFO    : Updated Thermal Rating: on line 7480-7788 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8525
% INFO    : Updated Thermal Rating: on line 11944-12634 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5528
% INFO    : Updated Thermal Rating: on line 11944-5969 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1933
% INFO    : Updated Thermal Rating: on line 10667-3276 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 785
% INFO    : Updated Thermal Rating: on line 10667-3276 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 785
% INFO    : Updated Thermal Rating: on line 12357-10663 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4813
% INFO    : Updated Thermal Rating: on line 12357-3941 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4028
% INFO    : Updated Thermal Rating: on line 10663-12626 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7844
% INFO    : Updated Thermal Rating: on line 3730-12365 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23479
% INFO    : Updated Thermal Rating: on line 11896-2609 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10569
% INFO    : Updated Thermal Rating: on line 2273-5861 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2201
% INFO    : Updated Thermal Rating: on line 2273-5861 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2167
% INFO    : Updated Thermal Rating: on line 2273-12845 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2305
% INFO    : Updated Thermal Rating: on line 2273-7206 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4881
% INFO    : Updated Thermal Rating: on line 2273-10858 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9721
% INFO    : Updated Thermal Rating: on line 2273-12897 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1114
% INFO    : Updated Thermal Rating: on line 2273-2477 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1169
% INFO    : Updated Thermal Rating: on line 2273-9769 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1587
% INFO    : Updated Thermal Rating: on line 2273-7769 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 831
% INFO    : Updated Thermal Rating: on line 5861-2609 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9155
% INFO    : Updated Thermal Rating: on line 5861-940 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5995
% INFO    : Updated Thermal Rating: on line 5861-7206 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3113
% INFO    : Updated Thermal Rating: on line 5861-7166 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11301
% INFO    : Updated Thermal Rating: on line 12845-6535 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2561
% INFO    : Updated Thermal Rating: on line 12845-7209 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1087
% INFO    : Updated Thermal Rating: on line 12845-1652 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 920
% INFO    : Updated Thermal Rating: on line 12845-10819 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3202
% INFO    : Updated Thermal Rating: on line 2609-10858 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1814
% INFO    : Updated Thermal Rating: on line 2609-9200 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8971
% INFO    : Updated Thermal Rating: on line 940-7166 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11301
% INFO    : Updated Thermal Rating: on line 5268-1828 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2334
% INFO    : Updated Thermal Rating: on line 5268-6730 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 160
% INFO    : Updated Thermal Rating: on line 1828-9755 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 642
% INFO    : Updated Thermal Rating: on line 1828-3756 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 426
% INFO    : Updated Thermal Rating: on line 1828-8947 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 322
% INFO    : Updated Thermal Rating: on line 1828-10083 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 518
% INFO    : Updated Thermal Rating: on line 9336-12328 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 865
% INFO    : Updated Thermal Rating: on line 9336-2860 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 472
% INFO    : Updated Thermal Rating: on line 686-1733 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 965
% INFO    : Updated Thermal Rating: on line 686-2367 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 642
% INFO    : Updated Thermal Rating: on line 686-6730 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 204
% INFO    : Updated Thermal Rating: on line 1733-9882 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3272
% INFO    : Updated Thermal Rating: on line 2889-5975 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 999
% INFO    : Updated Thermal Rating: on line 2889-7107 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1332
% INFO    : Updated Thermal Rating: on line 3855-2565 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1203
% INFO    : Updated Thermal Rating: on line 3855-7001 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1287
% INFO    : Updated Thermal Rating: on line 3855-11937 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10078
% INFO    : Updated Thermal Rating: on line 3855-6308 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1249
% INFO    : Updated Thermal Rating: on line 1258-6292 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7243
% INFO    : Updated Thermal Rating: on line 1258-1498 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1537
% INFO    : Updated Thermal Rating: on line 2565-11879 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2127
% INFO    : Updated Thermal Rating: on line 2565-11879 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2127
% INFO    : Updated Thermal Rating: on line 2565-7107 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3331
% INFO    : Updated Thermal Rating: on line 9755-12328 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 400
% INFO    : Updated Thermal Rating: on line 7798-13453 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1298
% INFO    : Updated Thermal Rating: on line 7798-1124 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 999
% INFO    : Updated Thermal Rating: on line 1860-12328 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 441
% INFO    : Updated Thermal Rating: on line 391-7991 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 946
% INFO    : Updated Thermal Rating: on line 391-7627 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5179
% INFO    : Updated Thermal Rating: on line 391-7001 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2106
% INFO    : Updated Thermal Rating: on line 391-8408 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5071
% INFO    : Updated Thermal Rating: on line 391-555 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8683
% INFO    : Updated Thermal Rating: on line 8925-7715 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 992
% INFO    : Updated Thermal Rating: on line 2367-12328 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 762
% INFO    : Updated Thermal Rating: on line 12689-5556 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 555
% INFO    : Updated Thermal Rating: on line 12689-5556 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 555
% INFO    : Updated Thermal Rating: on line 12689-1760 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3827
% INFO    : Updated Thermal Rating: on line 12689-4034 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1693
% INFO    : Updated Thermal Rating: on line 12689-4034 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1693
% INFO    : Updated Thermal Rating: on line 12689-1124 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3331
% INFO    : Updated Thermal Rating: on line 12689-1124 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3331
% INFO    : Updated Thermal Rating: on line 11587-5891 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6329
% INFO    : Updated Thermal Rating: on line 5975-7991 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16667
% INFO    : Updated Thermal Rating: on line 12609-3756 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 504
% INFO    : Updated Thermal Rating: on line 12609-6730 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 309
% INFO    : Updated Thermal Rating: on line 10066-11937 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3992
% INFO    : Updated Thermal Rating: on line 10066-6308 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 497
% INFO    : Updated Thermal Rating: on line 1674-473 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6329
% INFO    : Updated Thermal Rating: on line 1674-10641 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8736
% INFO    : Updated Thermal Rating: on line 6787-6308 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 608
% INFO    : Updated Thermal Rating: on line 6787-13501 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1367
% INFO    : Updated Thermal Rating: on line 4538-555 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13107
% INFO    : Updated Thermal Rating: on line 4538-1741 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11940
% INFO    : Updated Thermal Rating: on line 473-6013 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7132
% INFO    : Updated Thermal Rating: on line 473-6013 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7132
% INFO    : Updated Thermal Rating: on line 473-10641 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10139
% INFO    : Updated Thermal Rating: on line 473-4583 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1537
% INFO    : Updated Thermal Rating: on line 13458-11396 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 904
% INFO    : Updated Thermal Rating: on line 13458-5556 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 294
% INFO    : Updated Thermal Rating: on line 9720-5556 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 374
% INFO    : Updated Thermal Rating: on line 9720-5556 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 374
% INFO    : Updated Thermal Rating: on line 5891-10641 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8736
% INFO    : Updated Thermal Rating: on line 7627-7466 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8905
% INFO    : Updated Thermal Rating: on line 7627-7466 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8905
% INFO    : Updated Thermal Rating: on line 13453-1124 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3025
% INFO    : Updated Thermal Rating: on line 6535-10858 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 158282
% INFO    : Updated Thermal Rating: on line 11396-5556 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 625
% INFO    : Updated Thermal Rating: on line 5556-7715 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 873
% INFO    : Updated Thermal Rating: on line 6308-13501 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 412
% INFO    : Updated Thermal Rating: on line 6308-1498 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2617
% INFO    : Updated Thermal Rating: on line 5798-4034 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 33513
% INFO    : Updated Thermal Rating: on line 9882-12564 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 570
% INFO    : Updated Thermal Rating: on line 7206-12897 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1319
% INFO    : Updated Thermal Rating: on line 4034-3861 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 727
% INFO    : Updated Thermal Rating: on line 4034-3861 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 727
% INFO    : Updated Thermal Rating: on line 10858-7769 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 873
% INFO    : Updated Thermal Rating: on line 12809-12897 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9644
% INFO    : Updated Thermal Rating: on line 12809-2683 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1429
% INFO    : Updated Thermal Rating: on line 12809-10885 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1780
% INFO    : Updated Thermal Rating: on line 7910-12801 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1249
% INFO    : Updated Thermal Rating: on line 7910-6125 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 799
% INFO    : Updated Thermal Rating: on line 7910-10089 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1998
% INFO    : Updated Thermal Rating: on line 7218-799 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2700
% INFO    : Updated Thermal Rating: on line 7218-10277 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 778
% INFO    : Updated Thermal Rating: on line 13373-12437 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3841
% INFO    : Updated Thermal Rating: on line 13373-1628 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2855
% INFO    : Updated Thermal Rating: on line 13373-2042 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1332
% INFO    : Updated Thermal Rating: on line 12437-2042 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1998
% INFO    : Updated Thermal Rating: on line 6783-12292 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 573
% INFO    : Updated Thermal Rating: on line 6783-9026 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1110
% INFO    : Updated Thermal Rating: on line 6783-3930 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7652
% INFO    : Updated Thermal Rating: on line 6783-12801 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1110
% INFO    : Updated Thermal Rating: on line 6783-12801 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1110
% INFO    : Updated Thermal Rating: on line 11052-11710 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5883
% INFO    : Updated Thermal Rating: on line 11052-11710 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5883
% INFO    : Updated Thermal Rating: on line 11052-10277 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1816
% INFO    : Updated Thermal Rating: on line 11052-2152 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1284
% INFO    : Updated Thermal Rating: on line 799-5865 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 989
% INFO    : Updated Thermal Rating: on line 799-9036 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 850
% INFO    : Updated Thermal Rating: on line 799-9036 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 850
% INFO    : Updated Thermal Rating: on line 799-10277 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 619
% INFO    : Updated Thermal Rating: on line 799-8947 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 234
% INFO    : Updated Thermal Rating: on line 5865-10277 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1314
% INFO    : Updated Thermal Rating: on line 160-3936 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 458
% INFO    : Updated Thermal Rating: on line 160-5942 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 625
% INFO    : Updated Thermal Rating: on line 160-12292 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 254
% INFO    : Updated Thermal Rating: on line 3861-9036 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 359
% INFO    : Updated Thermal Rating: on line 3936-12292 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 587
% INFO    : Updated Thermal Rating: on line 5942-9711 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 505
% INFO    : Updated Thermal Rating: on line 5942-9026 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1332
% INFO    : Updated Thermal Rating: on line 5942-1628 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1998
% INFO    : Updated Thermal Rating: on line 6706-12292 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 310
% INFO    : Updated Thermal Rating: on line 6706-3257 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 818
% INFO    : Updated Thermal Rating: on line 12292-3930 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 572
% INFO    : Updated Thermal Rating: on line 12292-3257 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 250
% INFO    : Updated Thermal Rating: on line 9711-8947 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 469
% INFO    : Updated Thermal Rating: on line 12897-8508 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1083
% INFO    : Updated Thermal Rating: on line 9026-1628 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1175
% INFO    : Updated Thermal Rating: on line 9026-1628 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1175
% INFO    : Updated Thermal Rating: on line 12801-10089 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1332
% INFO    : Updated Thermal Rating: on line 6125-3257 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 668
% INFO    : Updated Thermal Rating: on line 2683-3973 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2404
% INFO    : Updated Thermal Rating: on line 5044-2226 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 908
% INFO    : Updated Thermal Rating: on line 5044-13574 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 200
% INFO    : Updated Thermal Rating: on line 5044-3257 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 278
% INFO    : Updated Thermal Rating: on line 5044-1690 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 303
% INFO    : Updated Thermal Rating: on line 5044-11788 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 714
% INFO    : Updated Thermal Rating: on line 2226-4867 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 932
% INFO    : Updated Thermal Rating: on line 2226-12783 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 267
% INFO    : Updated Thermal Rating: on line 4867-10061 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 306
% INFO    : Updated Thermal Rating: on line 4867-10061 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 219
% INFO    : Updated Thermal Rating: on line 6791-10139 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 668
% INFO    : Updated Thermal Rating: on line 6791-3257 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 326
% INFO    : Updated Thermal Rating: on line 6791-1690 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 500
% INFO    : Updated Thermal Rating: on line 6791-10003 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2086
% INFO    : Updated Thermal Rating: on line 10139-2535 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 549
% INFO    : Updated Thermal Rating: on line 13085-13574 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 365
% INFO    : Updated Thermal Rating: on line 13085-2535 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 183
% INFO    : Updated Thermal Rating: on line 13574-5266 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 272
% INFO    : Updated Thermal Rating: on line 13574-11932 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 172
% INFO    : Updated Thermal Rating: on line 13574-1690 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 336
% INFO    : Updated Thermal Rating: on line 13574-7868 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2350
% INFO    : Updated Thermal Rating: on line 13574-7868 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2350
% INFO    : Updated Thermal Rating: on line 5266-263 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1159
% INFO    : Updated Thermal Rating: on line 5266-10758 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19083
% INFO    : Updated Thermal Rating: on line 5266-10758 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19083
% INFO    : Updated Thermal Rating: on line 11932-263 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 540
% INFO    : Updated Thermal Rating: on line 13396-12783 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 364
% INFO    : Updated Thermal Rating: on line 13396-263 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 328
% INFO    : Updated Thermal Rating: on line 12783-3623 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 444
% INFO    : Updated Thermal Rating: on line 12783-1280 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 307
% INFO    : Updated Thermal Rating: on line 8508-3973 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1024
% INFO    : Updated Thermal Rating: on line 7720-10885 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3721
% INFO    : Updated Thermal Rating: on line 7720-6700 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 550
% INFO    : Updated Thermal Rating: on line 7720-8641 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 863
% INFO    : Updated Thermal Rating: on line 7720-13258 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3113
% INFO    : Updated Thermal Rating: on line 3993-7364 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 407
% INFO    : Updated Thermal Rating: on line 3993-11555 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 558
% INFO    : Updated Thermal Rating: on line 9833-8481 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 283
% INFO    : Updated Thermal Rating: on line 9833-8930 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 364
% INFO    : Updated Thermal Rating: on line 11788-8464 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 420
% INFO    : Updated Thermal Rating: on line 13430-8947 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1235
% INFO    : Updated Thermal Rating: on line 13430-6786 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 224
% INFO    : Updated Thermal Rating: on line 12288-7255 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 366
% INFO    : Updated Thermal Rating: on line 12288-7172 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 687
% INFO    : Updated Thermal Rating: on line 12288-1551 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 398
% INFO    : Updated Thermal Rating: on line 12288-10601 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8311
% INFO    : Updated Thermal Rating: on line 12288-10601 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8311
% INFO    : Updated Thermal Rating: on line 7364-5941 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 341
% INFO    : Updated Thermal Rating: on line 6782-12236 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 596
% INFO    : Updated Thermal Rating: on line 8464-13630 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 244
% INFO    : Updated Thermal Rating: on line 12670-13630 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 435
% INFO    : Updated Thermal Rating: on line 12670-6986 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 295
% INFO    : Updated Thermal Rating: on line 7907-11555 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 434
% INFO    : Updated Thermal Rating: on line 11555-6786 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 170
% INFO    : Updated Thermal Rating: on line 11555-6771 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 443
% INFO    : Updated Thermal Rating: on line 11555-1551 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 602
% INFO    : Updated Thermal Rating: on line 11555-1551 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 509
% INFO    : Updated Thermal Rating: on line 5941-7255 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 257
% INFO    : Updated Thermal Rating: on line 8481-8638 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2876
% INFO    : Updated Thermal Rating: on line 8481-8638 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2876
% INFO    : Updated Thermal Rating: on line 8481-8638 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2876
% INFO    : Updated Thermal Rating: on line 8481-7255 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 886
% INFO    : Updated Thermal Rating: on line 8481-7255 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 886
% INFO    : Updated Thermal Rating: on line 8481-13630 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 307
% INFO    : Updated Thermal Rating: on line 8481-13630 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 307
% INFO    : Updated Thermal Rating: on line 8947-7172 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 532
% INFO    : Updated Thermal Rating: on line 8947-6786 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 189
% INFO    : Updated Thermal Rating: on line 8947-10083 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 638
% INFO    : Updated Thermal Rating: on line 10397-6786 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 646
% INFO    : Updated Thermal Rating: on line 10397-13630 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7970
% INFO    : Updated Thermal Rating: on line 10397-13630 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7970
% INFO    : Updated Thermal Rating: on line 6786-1551 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 170
% INFO    : Updated Thermal Rating: on line 6986-12236 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 426
% INFO    : Updated Thermal Rating: on line 6986-10244 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 570
% INFO    : Updated Thermal Rating: on line 8778-6700 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3282
% INFO    : Updated Thermal Rating: on line 8778-3808 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2746
% INFO    : Updated Thermal Rating: on line 8778-12251 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 121132
% INFO    : Updated Thermal Rating: on line 8778-12251 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 121132
% INFO    : Updated Thermal Rating: on line 8778-3973 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1899
% INFO    : Updated Thermal Rating: on line 8778-3841 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4919
% INFO    : Updated Thermal Rating: on line 6700-3841 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7102
% INFO    : Updated Thermal Rating: on line 6700-1297 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1068
% INFO    : Updated Thermal Rating: on line 6700-1297 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1289
% INFO    : Updated Thermal Rating: on line 3808-12975 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2631
% INFO    : Updated Thermal Rating: on line 3808-5794 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2893
% INFO    : Updated Thermal Rating: on line 2776-7815 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 588
% INFO    : Updated Thermal Rating: on line 2776-7815 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 588
% INFO    : Updated Thermal Rating: on line 7117-716 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12773
% INFO    : Updated Thermal Rating: on line 7117-716 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12773
% INFO    : Updated Thermal Rating: on line 7117-8590 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15360
% INFO    : Updated Thermal Rating: on line 7117-8590 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15360
% INFO    : Updated Thermal Rating: on line 9735-716 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4663
% INFO    : Updated Thermal Rating: on line 9735-716 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4663
% INFO    : Updated Thermal Rating: on line 9735-8590 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8683
% INFO    : Updated Thermal Rating: on line 9735-8590 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8683
% INFO    : Updated Thermal Rating: on line 6152-11207 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 957
% INFO    : Updated Thermal Rating: on line 6152-11207 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 957
% INFO    : Updated Thermal Rating: on line 11427-7357 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 501
% INFO    : Updated Thermal Rating: on line 11427-10988 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 378
% INFO    : Updated Thermal Rating: on line 13613-3920 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3444
% INFO    : Updated Thermal Rating: on line 13613-1712 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18789
% INFO    : Updated Thermal Rating: on line 13613-5870 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3570
% INFO    : Updated Thermal Rating: on line 13613-497 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3992
% INFO    : Updated Thermal Rating: on line 13613-10316 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6765
% INFO    : Updated Thermal Rating: on line 7402-8046 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15192
% INFO    : Updated Thermal Rating: on line 7402-11465 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10347
% INFO    : Updated Thermal Rating: on line 2628-8854 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18789
% INFO    : Updated Thermal Rating: on line 2628-13347 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20832
% INFO    : Updated Thermal Rating: on line 2628-12605 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14562
% INFO    : Updated Thermal Rating: on line 2628-4320 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8450
% INFO    : Updated Thermal Rating: on line 9429-12605 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4513
% INFO    : Updated Thermal Rating: on line 9429-1256 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19656
% INFO    : Updated Thermal Rating: on line 3370-11207 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3244
% INFO    : Updated Thermal Rating: on line 3370-11207 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3244
% INFO    : Updated Thermal Rating: on line 5390-13347 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11502
% INFO    : Updated Thermal Rating: on line 5390-11921 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1665
% INFO    : Updated Thermal Rating: on line 5390-4320 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3385
% INFO    : Updated Thermal Rating: on line 8590-11740 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19369
% INFO    : Updated Thermal Rating: on line 8590-11740 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19369
% INFO    : Updated Thermal Rating: on line 7773-4408 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10624
% INFO    : Updated Thermal Rating: on line 7773-4408 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10624
% INFO    : Updated Thermal Rating: on line 11271-3920 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4975
% INFO    : Updated Thermal Rating: on line 11271-3920 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4975
% INFO    : Updated Thermal Rating: on line 11271-497 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3992
% INFO    : Updated Thermal Rating: on line 11921-4320 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1722
% INFO    : Updated Thermal Rating: on line 8046-11207 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1707
% INFO    : Updated Thermal Rating: on line 8046-13624 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 925
% INFO    : Updated Thermal Rating: on line 12605-4320 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18068
% INFO    : Updated Thermal Rating: on line 12605-4320 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18068
% INFO    : Updated Thermal Rating: on line 12605-11255 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5857
% INFO    : Updated Thermal Rating: on line 4565-5870 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1081
% INFO    : Updated Thermal Rating: on line 4565-602 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 547
% INFO    : Updated Thermal Rating: on line 4565-4739 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13107
% INFO    : Updated Thermal Rating: on line 8511-7357 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 662
% INFO    : Updated Thermal Rating: on line 8511-4015 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 379
% INFO    : Updated Thermal Rating: on line 12068-4408 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3752
% INFO    : Updated Thermal Rating: on line 12068-4408 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3752
% INFO    : Updated Thermal Rating: on line 11465-11207 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1998
% INFO    : Updated Thermal Rating: on line 11465-13624 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 555
% INFO    : Updated Thermal Rating: on line 11451-7815 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 435
% INFO    : Updated Thermal Rating: on line 11451-4320 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 818
% INFO    : Updated Thermal Rating: on line 7357-10988 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 500
% INFO    : Updated Thermal Rating: on line 7815-4320 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 523
% INFO    : Updated Thermal Rating: on line 7815-13634 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23121
% INFO    : Updated Thermal Rating: on line 13413-4408 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2220
% INFO    : Updated Thermal Rating: on line 13413-7421 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2780
% INFO    : Updated Thermal Rating: on line 5870-13624 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4439
% INFO    : Updated Thermal Rating: on line 5870-13624 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4439
% INFO    : Updated Thermal Rating: on line 12660-3606 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 407
% INFO    : Updated Thermal Rating: on line 12660-6504 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 595
% INFO    : Updated Thermal Rating: on line 8984-6755 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 328
% INFO    : Updated Thermal Rating: on line 8984-3821 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 144
% INFO    : Updated Thermal Rating: on line 8984-1579 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 270
% INFO    : Updated Thermal Rating: on line 3623-1280 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 290
% INFO    : Updated Thermal Rating: on line 1280-10061 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 507
% INFO    : Updated Thermal Rating: on line 1280-7421 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 428
% INFO    : Updated Thermal Rating: on line 6755-3158 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 710
% INFO    : Updated Thermal Rating: on line 11373-602 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1933
% INFO    : Updated Thermal Rating: on line 11373-602 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1994
% INFO    : Updated Thermal Rating: on line 11373-10909 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 408
% INFO    : Updated Thermal Rating: on line 11373-3606 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1112
% INFO    : Updated Thermal Rating: on line 602-10316 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 957
% INFO    : Updated Thermal Rating: on line 3158-10909 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 292
% INFO    : Updated Thermal Rating: on line 10061-6504 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19959
% INFO    : Updated Thermal Rating: on line 10244-8181 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 160
% INFO    : Updated Thermal Rating: on line 10244-9548 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1390
% INFO    : Updated Thermal Rating: on line 3821-8930 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 160
% INFO    : Updated Thermal Rating: on line 3821-9548 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1390
% INFO    : Updated Thermal Rating: on line 10586-1297 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3289
% INFO    : Updated Thermal Rating: on line 10586-12110 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12187
% INFO    : Updated Thermal Rating: on line 1297-12110 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3730
% INFO    : Updated Thermal Rating: on line 1297-10975 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1585
% INFO    : Updated Thermal Rating: on line 12110-12975 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1698
% INFO    : Updated Thermal Rating: on line 6313-7276 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 384
% INFO    : Updated Thermal Rating: on line 6313-7879 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 377
% INFO    : Updated Thermal Rating: on line 6037-13065 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 342
% INFO    : Updated Thermal Rating: on line 6037-2039 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 393
% INFO    : Updated Thermal Rating: on line 12296-484 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 415
% INFO    : Updated Thermal Rating: on line 4015-10988 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 766
% INFO    : Updated Thermal Rating: on line 4015-6257 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 411
% INFO    : Updated Thermal Rating: on line 4015-2824 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 377
% INFO    : Updated Thermal Rating: on line 8178-484 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 357
% INFO    : Updated Thermal Rating: on line 8178-2567 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 412
% INFO    : Updated Thermal Rating: on line 11777-13065 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 349
% INFO    : Updated Thermal Rating: on line 11777-1722 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1012
% INFO    : Updated Thermal Rating: on line 11777-7276 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 268
% INFO    : Updated Thermal Rating: on line 11777-10716 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 283
% INFO    : Updated Thermal Rating: on line 13065-10199 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 270
% INFO    : Updated Thermal Rating: on line 10259-2096 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 485
% INFO    : Updated Thermal Rating: on line 10259-1912 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 249
% INFO    : Updated Thermal Rating: on line 10259-2037 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 799
% INFO    : Updated Thermal Rating: on line 1277-1497 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 348
% INFO    : Updated Thermal Rating: on line 1277-1497 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 348
% INFO    : Updated Thermal Rating: on line 1722-2039 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 530
% INFO    : Updated Thermal Rating: on line 1722-7879 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1359
% INFO    : Updated Thermal Rating: on line 2039-2412 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2349
% INFO    : Updated Thermal Rating: on line 2039-2188 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 954
% INFO    : Updated Thermal Rating: on line 2039-7879 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1182
% INFO    : Updated Thermal Rating: on line 2039-7879 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1182
% INFO    : Updated Thermal Rating: on line 2412-5441 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 421
% INFO    : Updated Thermal Rating: on line 2096-2037 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 571
% INFO    : Updated Thermal Rating: on line 2096-10109 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 580
% INFO    : Updated Thermal Rating: on line 2096-10109 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 580
% INFO    : Updated Thermal Rating: on line 2096-52 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 203
% INFO    : Updated Thermal Rating: on line 10988-1098 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 765
% INFO    : Updated Thermal Rating: on line 10988-8050 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1103
% INFO    : Updated Thermal Rating: on line 10988-5818 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 242
% INFO    : Updated Thermal Rating: on line 1579-6257 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 301
% INFO    : Updated Thermal Rating: on line 1579-2188 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1517
% INFO    : Updated Thermal Rating: on line 6966-1912 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 381
% INFO    : Updated Thermal Rating: on line 6966-12149 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1669
% INFO    : Updated Thermal Rating: on line 12718-2567 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1356
% INFO    : Updated Thermal Rating: on line 12718-2567 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1356
% INFO    : Updated Thermal Rating: on line 7616-7276 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 366
% INFO    : Updated Thermal Rating: on line 7616-9965 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 319
% INFO    : Updated Thermal Rating: on line 1098-8050 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1232
% INFO    : Updated Thermal Rating: on line 1497-1912 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 527
% INFO    : Updated Thermal Rating: on line 1497-5818 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 322
% INFO    : Updated Thermal Rating: on line 1497-7594 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1669
% INFO    : Updated Thermal Rating: on line 484-5818 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 622
% INFO    : Updated Thermal Rating: on line 484-2567 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 803
% INFO    : Updated Thermal Rating: on line 1912-5818 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 729
% INFO    : Updated Thermal Rating: on line 6257-12149 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 418
% INFO    : Updated Thermal Rating: on line 5818-2567 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 405
% INFO    : Updated Thermal Rating: on line 5818-5441 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 240
% INFO    : Updated Thermal Rating: on line 5818-2824 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 456
% INFO    : Updated Thermal Rating: on line 10975-12144 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1526
% INFO    : Updated Thermal Rating: on line 215-7953 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2061
% INFO    : Updated Thermal Rating: on line 215-7953 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2492
% INFO    : Updated Thermal Rating: on line 215-2748 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1836
% INFO    : Updated Thermal Rating: on line 215-4804 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1894
% INFO    : Updated Thermal Rating: on line 7953-2748 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1894
% INFO    : Updated Thermal Rating: on line 7953-12144 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1115
% INFO    : Updated Thermal Rating: on line 1897-11963 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 732
% INFO    : Updated Thermal Rating: on line 1897-8600 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1669
% INFO    : Updated Thermal Rating: on line 11864-9428 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 364
% INFO    : Updated Thermal Rating: on line 11864-1830 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1063
% INFO    : Updated Thermal Rating: on line 11864-886 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 740
% INFO    : Updated Thermal Rating: on line 13186-2266 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 749
% INFO    : Updated Thermal Rating: on line 13186-9965 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 860
% INFO    : Updated Thermal Rating: on line 13186-7457 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 557
% INFO    : Updated Thermal Rating: on line 13186-11852 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 83913
% INFO    : Updated Thermal Rating: on line 12327-12036 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 393
% INFO    : Updated Thermal Rating: on line 12327-12036 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 465
% INFO    : Updated Thermal Rating: on line 12327-12036 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 465
% INFO    : Updated Thermal Rating: on line 12327-2266 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1559
% INFO    : Updated Thermal Rating: on line 12327-9965 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1119
% INFO    : Updated Thermal Rating: on line 12327-9965 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1119
% INFO    : Updated Thermal Rating: on line 12036-12848 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 316
% INFO    : Updated Thermal Rating: on line 12036-12848 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 333
% INFO    : Updated Thermal Rating: on line 12036-12848 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 333
% INFO    : Updated Thermal Rating: on line 11963-8514 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 500
% INFO    : Updated Thermal Rating: on line 11963-3762 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 999
% INFO    : Updated Thermal Rating: on line 11963-11991 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 869
% INFO    : Updated Thermal Rating: on line 10568-2266 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3149
% INFO    : Updated Thermal Rating: on line 12848-52 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 313
% INFO    : Updated Thermal Rating: on line 10274-1830 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 660
% INFO    : Updated Thermal Rating: on line 10274-1830 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 500
% INFO    : Updated Thermal Rating: on line 2266-9965 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2034
% INFO    : Updated Thermal Rating: on line 2266-1717 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3992
% INFO    : Updated Thermal Rating: on line 2266-1717 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3992
% INFO    : Updated Thermal Rating: on line 9428-8514 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 759
% INFO    : Updated Thermal Rating: on line 9428-8514 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 866
% INFO    : Updated Thermal Rating: on line 9428-8514 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 866
% INFO    : Updated Thermal Rating: on line 9428-886 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 833
% INFO    : Updated Thermal Rating: on line 9428-11991 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1046
% INFO    : Updated Thermal Rating: on line 9428-519 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2383
% INFO    : Updated Thermal Rating: on line 8514-1830 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 200
% INFO    : Updated Thermal Rating: on line 8514-11389 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 588
% INFO    : Updated Thermal Rating: on line 9965-8600 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1332
% INFO    : Updated Thermal Rating: on line 9965-8600 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1332
% INFO    : Updated Thermal Rating: on line 8600-3762 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 869
% INFO    : Updated Thermal Rating: on line 10490-11742 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2331
% INFO    : Updated Thermal Rating: on line 10490-10018 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4085
% INFO    : Updated Thermal Rating: on line 10490-6028 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 445
% INFO    : Updated Thermal Rating: on line 11742-10018 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5121
% INFO    : Updated Thermal Rating: on line 11742-8624 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5121
% INFO    : Updated Thermal Rating: on line 11742-10266 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2200
% INFO    : Updated Thermal Rating: on line 11742-4116 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1589
% INFO    : Updated Thermal Rating: on line 1952-9639 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 463
% INFO    : Updated Thermal Rating: on line 1952-9528 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 194
% INFO    : Updated Thermal Rating: on line 1952-5853 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 982
% INFO    : Updated Thermal Rating: on line 1952-7439 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 890
% INFO    : Updated Thermal Rating: on line 9907-9528 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 201
% INFO    : Updated Thermal Rating: on line 9907-6270 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 130
% INFO    : Updated Thermal Rating: on line 9907-5313 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 333
% INFO    : Updated Thermal Rating: on line 9907-5313 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 333
% INFO    : Updated Thermal Rating: on line 10511-1569 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 720
% INFO    : Updated Thermal Rating: on line 10511-1569 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 720
% INFO    : Updated Thermal Rating: on line 10511-3200 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3188
% INFO    : Updated Thermal Rating: on line 1569-12620 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 668
% INFO    : Updated Thermal Rating: on line 1569-10179 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 565
% INFO    : Updated Thermal Rating: on line 1119-2344 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 673
% INFO    : Updated Thermal Rating: on line 1119-2344 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 673
% INFO    : Updated Thermal Rating: on line 2589-2765 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 911
% INFO    : Updated Thermal Rating: on line 2589-2765 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 911
% INFO    : Updated Thermal Rating: on line 2589-2344 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 388
% INFO    : Updated Thermal Rating: on line 2589-10807 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 451
% INFO    : Updated Thermal Rating: on line 2765-13534 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 319
% INFO    : Updated Thermal Rating: on line 2765-452 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 426
% INFO    : Updated Thermal Rating: on line 2765-9684 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 220
% INFO    : Updated Thermal Rating: on line 2765-4017 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 593
% INFO    : Updated Thermal Rating: on line 2765-4017 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 593
% INFO    : Updated Thermal Rating: on line 2765-11062 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 368
% INFO    : Updated Thermal Rating: on line 2765-8165 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 798
% INFO    : Updated Thermal Rating: on line 10781-10820 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 342
% INFO    : Updated Thermal Rating: on line 10781-10820 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 342
% INFO    : Updated Thermal Rating: on line 3024-12103 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2383
% INFO    : Updated Thermal Rating: on line 3024-9684 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1126
% INFO    : Updated Thermal Rating: on line 3024-12067 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 655
% INFO    : Updated Thermal Rating: on line 3024-7829 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 371
% INFO    : Updated Thermal Rating: on line 12103-11148 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 355
% INFO    : Updated Thermal Rating: on line 12103-9684 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1100
% INFO    : Updated Thermal Rating: on line 12103-2344 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 315
% INFO    : Updated Thermal Rating: on line 12103-8321 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 500
% INFO    : Updated Thermal Rating: on line 12103-8165 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 376
% INFO    : Updated Thermal Rating: on line 6528-7827 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1139
% INFO    : Updated Thermal Rating: on line 6528-11160 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 421
% INFO    : Updated Thermal Rating: on line 6528-11160 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 421
% INFO    : Updated Thermal Rating: on line 6528-9684 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1227
% INFO    : Updated Thermal Rating: on line 6528-9684 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1227
% INFO    : Updated Thermal Rating: on line 6528-10955 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27344
% INFO    : Updated Thermal Rating: on line 6528-10955 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27344
% INFO    : Updated Thermal Rating: on line 6528-12957 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 677
% INFO    : Updated Thermal Rating: on line 6528-13168 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 418
% INFO    : Updated Thermal Rating: on line 6528-12935 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 557
% INFO    : Updated Thermal Rating: on line 10457-9528 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 301
% INFO    : Updated Thermal Rating: on line 10457-5853 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 832
% INFO    : Updated Thermal Rating: on line 10457-5853 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 832
% INFO    : Updated Thermal Rating: on line 10457-10582 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 957
% INFO    : Updated Thermal Rating: on line 10457-10582 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 957
% INFO    : Updated Thermal Rating: on line 10457-7439 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 501
% INFO    : Updated Thermal Rating: on line 6042-10179 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 541
% INFO    : Updated Thermal Rating: on line 6042-10179 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 541
% INFO    : Updated Thermal Rating: on line 6042-2344 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1952
% INFO    : Updated Thermal Rating: on line 6042-2344 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1952
% INFO    : Updated Thermal Rating: on line 6042-11884 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 658
% INFO    : Updated Thermal Rating: on line 6042-11884 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 658
% INFO    : Updated Thermal Rating: on line 4124-11884 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15411
% INFO    : Updated Thermal Rating: on line 4124-11884 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15411
% INFO    : Updated Thermal Rating: on line 13534-7827 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 312
% INFO    : Updated Thermal Rating: on line 13534-7827 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 312
% INFO    : Updated Thermal Rating: on line 13534-11884 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 562
% INFO    : Updated Thermal Rating: on line 13534-12067 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 802
% INFO    : Updated Thermal Rating: on line 13534-11062 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1595
% INFO    : Updated Thermal Rating: on line 7827-12957 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 677
% INFO    : Updated Thermal Rating: on line 7827-3511 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8330
% INFO    : Updated Thermal Rating: on line 12620-11884 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1341
% INFO    : Updated Thermal Rating: on line 10179-9676 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 475
% INFO    : Updated Thermal Rating: on line 10179-11884 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3310
% INFO    : Updated Thermal Rating: on line 10179-1989 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19083
% INFO    : Updated Thermal Rating: on line 9676-3200 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 364
% INFO    : Updated Thermal Rating: on line 7292-9639 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2086
% INFO    : Updated Thermal Rating: on line 7292-2950 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 810
% INFO    : Updated Thermal Rating: on line 7292-9456 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 358
% INFO    : Updated Thermal Rating: on line 9639-2950 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1324
% INFO    : Updated Thermal Rating: on line 452-11148 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 618
% INFO    : Updated Thermal Rating: on line 11160-713 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 400
% INFO    : Updated Thermal Rating: on line 11160-8321 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1175
% INFO    : Updated Thermal Rating: on line 11160-2950 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 434
% INFO    : Updated Thermal Rating: on line 11160-8983 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1545
% INFO    : Updated Thermal Rating: on line 11160-787 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3827
% INFO    : Updated Thermal Rating: on line 11160-787 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3827
% INFO    : Updated Thermal Rating: on line 1949-2950 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 36
% INFO    : Updated Thermal Rating: on line 1949-2762 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2086
% INFO    : Updated Thermal Rating: on line 1949-8876 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1933
% INFO    : Updated Thermal Rating: on line 10820-2950 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3169
% INFO    : Updated Thermal Rating: on line 10820-7723 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2595
% INFO    : Updated Thermal Rating: on line 10820-787 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 513
% INFO    : Updated Thermal Rating: on line 10820-787 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 513
% INFO    : Updated Thermal Rating: on line 10820-7439 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1126
% INFO    : Updated Thermal Rating: on line 10820-7439 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1126
% INFO    : Updated Thermal Rating: on line 2344-6532 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16672
% INFO    : Updated Thermal Rating: on line 11884-11999 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4172
% INFO    : Updated Thermal Rating: on line 11884-1204 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6653
% INFO    : Updated Thermal Rating: on line 8321-8983 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 665
% INFO    : Updated Thermal Rating: on line 8321-7829 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2780
% INFO    : Updated Thermal Rating: on line 4017-8584 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 610
% INFO    : Updated Thermal Rating: on line 4017-8584 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 610
% INFO    : Updated Thermal Rating: on line 4017-12098 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 787
% INFO    : Updated Thermal Rating: on line 2950-8983 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 687
% INFO    : Updated Thermal Rating: on line 9528-7883 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27898
% INFO    : Updated Thermal Rating: on line 9528-6270 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 186
% INFO    : Updated Thermal Rating: on line 9456-3573 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 301
% INFO    : Updated Thermal Rating: on line 7723-2762 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8330
% INFO    : Updated Thermal Rating: on line 12067-12957 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 308
% INFO    : Updated Thermal Rating: on line 12067-12957 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 308
% INFO    : Updated Thermal Rating: on line 12067-8485 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2895
% INFO    : Updated Thermal Rating: on line 12067-8485 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2895
% INFO    : Updated Thermal Rating: on line 8983-11766 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2855
% INFO    : Updated Thermal Rating: on line 8983-11766 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2855
% INFO    : Updated Thermal Rating: on line 10018-2752 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1458
% INFO    : Updated Thermal Rating: on line 3200-8140 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 444
% INFO    : Updated Thermal Rating: on line 3200-8140 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 444
% INFO    : Updated Thermal Rating: on line 5853-7439 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 934
% INFO    : Updated Thermal Rating: on line 5853-7439 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 870
% INFO    : Updated Thermal Rating: on line 5853-8876 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 699
% INFO    : Updated Thermal Rating: on line 191-8624 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2960
% INFO    : Updated Thermal Rating: on line 191-4116 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 903
% INFO    : Updated Thermal Rating: on line 2477-7209 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2032
% INFO    : Updated Thermal Rating: on line 9769-3045 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 948
% INFO    : Updated Thermal Rating: on line 9769-13258 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2267
% INFO    : Updated Thermal Rating: on line 3045-7209 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4720
% INFO    : Updated Thermal Rating: on line 3045-12844 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 586
% INFO    : Updated Thermal Rating: on line 3045-7647 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 586
% INFO    : Updated Thermal Rating: on line 7209-7769 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7562
% INFO    : Updated Thermal Rating: on line 7209-3317 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6772
% INFO    : Updated Thermal Rating: on line 7209-8817 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 713
% INFO    : Updated Thermal Rating: on line 7209-6223 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 713
% INFO    : Updated Thermal Rating: on line 7769-10487 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1119
% INFO    : Updated Thermal Rating: on line 7769-3066 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1119
% INFO    : Updated Thermal Rating: on line 12424-2928 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6338
% INFO    : Updated Thermal Rating: on line 12424-9803 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2855
% INFO    : Updated Thermal Rating: on line 12424-8705 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9559
% INFO    : Updated Thermal Rating: on line 12424-9529 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1531
% INFO    : Updated Thermal Rating: on line 12424-9529 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1531
% INFO    : Updated Thermal Rating: on line 12424-5233 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 542
% INFO    : Updated Thermal Rating: on line 12424-7763 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5607
% INFO    : Updated Thermal Rating: on line 5469-9803 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1998
% INFO    : Updated Thermal Rating: on line 5469-9803 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2855
% INFO    : Updated Thermal Rating: on line 5469-8808 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1561
% INFO    : Updated Thermal Rating: on line 5469-8808 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1209
% INFO    : Updated Thermal Rating: on line 5469-8808 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1561
% INFO    : Updated Thermal Rating: on line 5469-8808 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1209
% INFO    : Updated Thermal Rating: on line 2928-9803 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1367
% INFO    : Updated Thermal Rating: on line 2928-8303 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9559
% INFO    : Updated Thermal Rating: on line 2928-5233 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 642
% INFO    : Updated Thermal Rating: on line 3964-9529 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 699
% INFO    : Updated Thermal Rating: on line 3964-13457 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 580
% INFO    : Updated Thermal Rating: on line 6244-6781 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 850
% INFO    : Updated Thermal Rating: on line 6244-12868 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4172
% INFO    : Updated Thermal Rating: on line 6244-12967 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 171
% INFO    : Updated Thermal Rating: on line 13044-13 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 582
% INFO    : Updated Thermal Rating: on line 13044-5233 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 261
% INFO    : Updated Thermal Rating: on line 13184-3562 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1514
% INFO    : Updated Thermal Rating: on line 13184-629 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1276
% INFO    : Updated Thermal Rating: on line 13-6730 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 729
% INFO    : Updated Thermal Rating: on line 13297-3562 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 431
% INFO    : Updated Thermal Rating: on line 13297-3562 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 431
% INFO    : Updated Thermal Rating: on line 11188-1746 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 454
% INFO    : Updated Thermal Rating: on line 11188-3315 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1491
% INFO    : Updated Thermal Rating: on line 11188-3315 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1491
% INFO    : Updated Thermal Rating: on line 3317-7972 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 715
% INFO    : Updated Thermal Rating: on line 3562-629 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1197
% INFO    : Updated Thermal Rating: on line 3562-8166 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 444
% INFO    : Updated Thermal Rating: on line 3562-6647 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1332
% INFO    : Updated Thermal Rating: on line 2704-9369 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11918
% INFO    : Updated Thermal Rating: on line 2704-11356 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1439
% INFO    : Updated Thermal Rating: on line 2704-10703 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 445
% INFO    : Updated Thermal Rating: on line 1746-11356 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 460
% INFO    : Updated Thermal Rating: on line 1746-1174 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 284
% INFO    : Updated Thermal Rating: on line 11356-13457 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1472
% INFO    : Updated Thermal Rating: on line 11356-13457 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1472
% INFO    : Updated Thermal Rating: on line 11356-9180 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 274
% INFO    : Updated Thermal Rating: on line 9803-7893 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1586
% INFO    : Updated Thermal Rating: on line 9803-3315 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1332
% INFO    : Updated Thermal Rating: on line 9529-8169 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1069
% INFO    : Updated Thermal Rating: on line 9529-7763 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9828
% INFO    : Updated Thermal Rating: on line 7893-3315 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3767
% INFO    : Updated Thermal Rating: on line 6781-6958 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 522
% INFO    : Updated Thermal Rating: on line 8808-11843 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 970
% INFO    : Updated Thermal Rating: on line 8808-11843 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 970
% INFO    : Updated Thermal Rating: on line 8808-5533 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9570
% INFO    : Updated Thermal Rating: on line 9328-5233 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1235
% INFO    : Updated Thermal Rating: on line 9328-5233 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1235
% INFO    : Updated Thermal Rating: on line 9328-6958 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 891
% INFO    : Updated Thermal Rating: on line 9328-6958 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 891
% INFO    : Updated Thermal Rating: on line 9328-9495 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2409
% INFO    : Updated Thermal Rating: on line 9328-9495 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2409
% INFO    : Updated Thermal Rating: on line 11843-3315 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 500
% INFO    : Updated Thermal Rating: on line 8166-6647 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 588
% INFO    : Updated Thermal Rating: on line 3315-9990 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1665
% INFO    : Updated Thermal Rating: on line 3315-12623 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1665
% INFO    : Updated Thermal Rating: on line 12868-13450 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 668
% INFO    : Updated Thermal Rating: on line 13457-8169 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 851
% INFO    : Updated Thermal Rating: on line 9990-7763 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13107
% INFO    : Updated Thermal Rating: on line 12623-7763 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13107
% INFO    : Updated Thermal Rating: on line 12096-1652 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 879
% INFO    : Updated Thermal Rating: on line 12096-11647 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1386
% INFO    : Updated Thermal Rating: on line 7972-11647 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1386
% INFO    : Updated Thermal Rating: on line 12230-11647 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1386
% INFO    : Updated Thermal Rating: on line 12230-6634 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1128
% INFO    : Updated Thermal Rating: on line 11647-8026 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1553
% INFO    : Updated Thermal Rating: on line 11647-2129 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1241
% INFO    : Updated Thermal Rating: on line 6718-639 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 398
% INFO    : Updated Thermal Rating: on line 6718-8363 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 177
% INFO    : Updated Thermal Rating: on line 4271-11833 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 418
% INFO    : Updated Thermal Rating: on line 4271-9252 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 418
% INFO    : Updated Thermal Rating: on line 10880-12927 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 358
% INFO    : Updated Thermal Rating: on line 10880-10777 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 987
% INFO    : Updated Thermal Rating: on line 10880-20 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 522
% INFO    : Updated Thermal Rating: on line 13438-12154 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1112
% INFO    : Updated Thermal Rating: on line 13438-908 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 344
% INFO    : Updated Thermal Rating: on line 1601-9462 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 286
% INFO    : Updated Thermal Rating: on line 1601-5985 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 388
% INFO    : Updated Thermal Rating: on line 1601-9800 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 509
% INFO    : Updated Thermal Rating: on line 1174-2117 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 136
% INFO    : Updated Thermal Rating: on line 1174-12608 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 514
% INFO    : Updated Thermal Rating: on line 1174-11890 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 232
% INFO    : Updated Thermal Rating: on line 2117-11833 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 856
% INFO    : Updated Thermal Rating: on line 2117-12154 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 257
% INFO    : Updated Thermal Rating: on line 2117-908 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 313
% INFO    : Updated Thermal Rating: on line 2117-10549 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 833
% INFO    : Updated Thermal Rating: on line 2117-10549 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 833
% INFO    : Updated Thermal Rating: on line 11833-12154 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 250
% INFO    : Updated Thermal Rating: on line 12927-8449 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on line 12154-5458 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 459
% INFO    : Updated Thermal Rating: on line 10777-292 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 151
% INFO    : Updated Thermal Rating: on line 12608-4500 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 247
% INFO    : Updated Thermal Rating: on line 12608-2910 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 286
% INFO    : Updated Thermal Rating: on line 7799-639 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 389
% INFO    : Updated Thermal Rating: on line 7799-4930 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 240
% INFO    : Updated Thermal Rating: on line 639-6396 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 280
% INFO    : Updated Thermal Rating: on line 9462-9252 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 539
% INFO    : Updated Thermal Rating: on line 20-5458 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on line 20-8363 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1589
% INFO    : Updated Thermal Rating: on line 20-6164 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 215
% INFO    : Updated Thermal Rating: on line 6479-10609 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 802
% INFO    : Updated Thermal Rating: on line 6479-8877 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 278
% INFO    : Updated Thermal Rating: on line 10609-9252 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 922
% INFO    : Updated Thermal Rating: on line 5985-3033 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 388
% INFO    : Updated Thermal Rating: on line 6874-10487 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1014
% INFO    : Updated Thermal Rating: on line 6874-13337 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1545
% INFO    : Updated Thermal Rating: on line 13231-3066 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1014
% INFO    : Updated Thermal Rating: on line 13231-13337 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1545
% INFO    : Updated Thermal Rating: on line 2202-12486 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1386
% INFO    : Updated Thermal Rating: on line 2202-8817 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1386
% INFO    : Updated Thermal Rating: on line 1618-6223 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1374
% INFO    : Updated Thermal Rating: on line 1618-9905 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1374
% INFO    : Updated Thermal Rating: on line 12486-1036 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 944
% INFO    : Updated Thermal Rating: on line 9905-10726 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 932
% INFO    : Updated Thermal Rating: on line 12844-6395 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1306
% INFO    : Updated Thermal Rating: on line 7647-6395 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1306
% INFO    : Updated Thermal Rating: on line 6395-1036 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1071
% INFO    : Updated Thermal Rating: on line 6395-8751 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 571
% INFO    : Updated Thermal Rating: on line 6395-8751 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 571
% INFO    : Updated Thermal Rating: on line 13337-1365 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1371
% INFO    : Updated Thermal Rating: on line 13337-7644 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1371
% INFO    : Updated Thermal Rating: on line 13337-4417 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1918
% INFO    : Updated Thermal Rating: on line 13337-10351 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 842
% INFO    : Updated Thermal Rating: on line 9583-3033 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 418
% INFO    : Updated Thermal Rating: on line 9583-9800 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 540
% INFO    : Updated Thermal Rating: on line 9583-6396 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 259
% INFO    : Updated Thermal Rating: on line 9583-9564 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 720
% INFO    : Updated Thermal Rating: on line 9583-9564 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 720
% INFO    : Updated Thermal Rating: on line 9583-598 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 230
% INFO    : Updated Thermal Rating: on line 9583-10528 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 428
% INFO    : Updated Thermal Rating: on line 3573-11079 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 594
% INFO    : Updated Thermal Rating: on line 3573-972 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 200
% INFO    : Updated Thermal Rating: on line 3033-231 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 458
% INFO    : Updated Thermal Rating: on line 3033-6901 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1914
% INFO    : Updated Thermal Rating: on line 3033-6901 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1914
% INFO    : Updated Thermal Rating: on line 3033-1703 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 856
% INFO    : Updated Thermal Rating: on line 5684-8877 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 288
% INFO    : Updated Thermal Rating: on line 5684-5851 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 438
% INFO    : Updated Thermal Rating: on line 5684-10703 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1007
% INFO    : Updated Thermal Rating: on line 5684-9180 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1007
% INFO    : Updated Thermal Rating: on line 5684-2311 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 311
% INFO    : Updated Thermal Rating: on line 6396-231 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1561
% INFO    : Updated Thermal Rating: on line 6396-231 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1495
% INFO    : Updated Thermal Rating: on line 6396-231 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1495
% INFO    : Updated Thermal Rating: on line 4249-231 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 576
% INFO    : Updated Thermal Rating: on line 231-6901 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 890
% INFO    : Updated Thermal Rating: on line 231-6901 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 890
% INFO    : Updated Thermal Rating: on line 6901-1942 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19083
% INFO    : Updated Thermal Rating: on line 6901-1942 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19083
% INFO    : Updated Thermal Rating: on line 12215-10703 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7652
% INFO    : Updated Thermal Rating: on line 12215-9180 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7652
% INFO    : Updated Thermal Rating: on line 8877-598 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1875
% INFO    : Updated Thermal Rating: on line 1169-11079 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 466
% INFO    : Updated Thermal Rating: on line 1169-10528 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 668
% INFO    : Updated Thermal Rating: on line 11079-7710 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 425
% INFO    : Updated Thermal Rating: on line 8507-1703 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 902
% INFO    : Updated Thermal Rating: on line 8507-7710 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 439
% INFO    : Updated Thermal Rating: on line 5851-972 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 206
% INFO    : Updated Thermal Rating: on line 7710-11683 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 387
% INFO    : Updated Thermal Rating: on line 7710-11683 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 387
% INFO    : Updated Thermal Rating: on line 7710-10528 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 476
% INFO    : Updated Thermal Rating: on line 6028-2748 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1526
% INFO    : Updated Thermal Rating: on line 2748-2162 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1590
% INFO    : Updated Thermal Rating: on line 2748-8641 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1386
% INFO    : Updated Thermal Rating: on line 11389-12569 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 372
% INFO    : Updated Thermal Rating: on line 3000-2644 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 314
% INFO    : Updated Thermal Rating: on line 3000-2311 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 311
% INFO    : Updated Thermal Rating: on line 13299-11006 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 407
% INFO    : Updated Thermal Rating: on line 13299-2644 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 366
% INFO    : Updated Thermal Rating: on line 7043-1622 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 286
% INFO    : Updated Thermal Rating: on line 7043-8728 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 660
% INFO    : Updated Thermal Rating: on line 7043-11359 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 500
% INFO    : Updated Thermal Rating: on line 7043-13587 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1451
% INFO    : Updated Thermal Rating: on line 6270-9629 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 444
% INFO    : Updated Thermal Rating: on line 6270-13050 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 668
% INFO    : Updated Thermal Rating: on line 1622-8411 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1151
% INFO    : Updated Thermal Rating: on line 1622-9629 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 415
% INFO    : Updated Thermal Rating: on line 1622-10441 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 638
% INFO    : Updated Thermal Rating: on line 5016-3784 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 364
% INFO    : Updated Thermal Rating: on line 5016-8728 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 264
% INFO    : Updated Thermal Rating: on line 4866-1221 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1665
% INFO    : Updated Thermal Rating: on line 4866-1221 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1665
% INFO    : Updated Thermal Rating: on line 4866-12569 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 231
% INFO    : Updated Thermal Rating: on line 4866-8728 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 489
% INFO    : Updated Thermal Rating: on line 1221-11006 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 513
% INFO    : Updated Thermal Rating: on line 11006-8728 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 764
% INFO    : Updated Thermal Rating: on line 11006-8728 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 764
% INFO    : Updated Thermal Rating: on line 3784-8411 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 190
% INFO    : Updated Thermal Rating: on line 12569-7650 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 428
% INFO    : Updated Thermal Rating: on line 12569-13587 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 227
% INFO    : Updated Thermal Rating: on line 2162-10351 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1825
% INFO    : Updated Thermal Rating: on line 8728-3387 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 452
% INFO    : Updated Thermal Rating: on line 7650-10125 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 220
% INFO    : Updated Thermal Rating: on line 8375-13587 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8330
% INFO    : Updated Thermal Rating: on line 8181-8930 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3700
% INFO    : Updated Thermal Rating: on line 8181-3554 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 185
% INFO    : Updated Thermal Rating: on line 8930-5580 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 177
% INFO    : Updated Thermal Rating: on line 8930-10199 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 400
% INFO    : Updated Thermal Rating: on line 10125-5580 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 276
% INFO    : Updated Thermal Rating: on line 10125-13515 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 672
% INFO    : Updated Thermal Rating: on line 10125-11173 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 274
% INFO    : Updated Thermal Rating: on line 3554-8160 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 506
% INFO    : Updated Thermal Rating: on line 3554-9675 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 854
% INFO    : Updated Thermal Rating: on line 2927-81 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 437
% INFO    : Updated Thermal Rating: on line 2927-4474 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 623
% INFO    : Updated Thermal Rating: on line 2927-7119 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 515
% INFO    : Updated Thermal Rating: on line 2927-7457 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 642
% INFO    : Updated Thermal Rating: on line 81-11876 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 921
% INFO    : Updated Thermal Rating: on line 81-10716 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 549
% INFO    : Updated Thermal Rating: on line 5580-12967 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 279
% INFO    : Updated Thermal Rating: on line 5580-10199 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 200
% INFO    : Updated Thermal Rating: on line 8160-7119 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 570
% INFO    : Updated Thermal Rating: on line 8160-2207 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 295
% INFO    : Updated Thermal Rating: on line 11876-9675 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1816
% INFO    : Updated Thermal Rating: on line 11876-1698 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4172
% INFO    : Updated Thermal Rating: on line 4474-8539 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1314
% INFO    : Updated Thermal Rating: on line 9675-10199 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 222
% INFO    : Updated Thermal Rating: on line 13515-2207 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 479
% INFO    : Updated Thermal Rating: on line 9367-3888 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 532
% INFO    : Updated Thermal Rating: on line 9367-4335 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 912
% INFO    : Updated Thermal Rating: on line 8026-2129 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1995
% INFO    : Updated Thermal Rating: on line 2129-4820 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8405
% INFO    : Updated Thermal Rating: on line 2129-4820 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8405
% INFO    : Updated Thermal Rating: on line 2129-5088 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 923
% INFO    : Updated Thermal Rating: on line 9927-3888 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 686
% INFO    : Updated Thermal Rating: on line 9927-5820 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1126
% INFO    : Updated Thermal Rating: on line 7248-10369 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 394
% INFO    : Updated Thermal Rating: on line 7248-7578 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 194
% INFO    : Updated Thermal Rating: on line 3888-5820 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1276
% INFO    : Updated Thermal Rating: on line 3888-10369 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 173
% INFO    : Updated Thermal Rating: on line 9071-12157 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 289
% INFO    : Updated Thermal Rating: on line 9071-9300 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 414
% INFO    : Updated Thermal Rating: on line 11535-3624 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 355
% INFO    : Updated Thermal Rating: on line 11535-6444 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on line 8449-7697 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 775
% INFO    : Updated Thermal Rating: on line 8449-767 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5564
% INFO    : Updated Thermal Rating: on line 8449-13178 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 735
% INFO    : Updated Thermal Rating: on line 8449-3565 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1004
% INFO    : Updated Thermal Rating: on line 8449-168 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 284
% INFO    : Updated Thermal Rating: on line 8449-9854 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 226
% INFO    : Updated Thermal Rating: on line 11964-2910 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 239
% INFO    : Updated Thermal Rating: on line 11964-9300 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 673
% INFO    : Updated Thermal Rating: on line 12157-4996 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 237
% INFO    : Updated Thermal Rating: on line 4-3507 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19083
% INFO    : Updated Thermal Rating: on line 4-7182 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12773
% INFO    : Updated Thermal Rating: on line 2860-6382 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 438
% INFO    : Updated Thermal Rating: on line 2860-1461 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1814
% INFO    : Updated Thermal Rating: on line 2860-3507 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7652
% INFO    : Updated Thermal Rating: on line 2860-7182 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12563
% INFO    : Updated Thermal Rating: on line 2860-5894 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 716
% INFO    : Updated Thermal Rating: on line 3235-4500 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 418
% INFO    : Updated Thermal Rating: on line 3235-12564 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 570
% INFO    : Updated Thermal Rating: on line 4500-12356 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 392
% INFO    : Updated Thermal Rating: on line 12356-2910 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1143
% INFO    : Updated Thermal Rating: on line 11612-908 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 190
% INFO    : Updated Thermal Rating: on line 11612-11890 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 397
% INFO    : Updated Thermal Rating: on line 5558-3624 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 444
% INFO    : Updated Thermal Rating: on line 5558-11890 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 335
% INFO    : Updated Thermal Rating: on line 5558-3459 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 835
% INFO    : Updated Thermal Rating: on line 4996-3459 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 735
% INFO    : Updated Thermal Rating: on line 4996-7578 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2607
% INFO    : Updated Thermal Rating: on line 11960-908 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 328
% INFO    : Updated Thermal Rating: on line 11960-4335 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 278
% INFO    : Updated Thermal Rating: on line 908-4335 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 189
% INFO    : Updated Thermal Rating: on line 908-6444 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 596
% INFO    : Updated Thermal Rating: on line 4335-7697 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1298
% INFO    : Updated Thermal Rating: on line 4335-13178 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1148
% INFO    : Updated Thermal Rating: on line 4335-3565 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1243
% INFO    : Updated Thermal Rating: on line 7697-13178 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13672
% INFO    : Updated Thermal Rating: on line 7697-12262 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13672
% INFO    : Updated Thermal Rating: on line 9300-6382 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1227
% INFO    : Updated Thermal Rating: on line 9300-5894 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 714
% INFO    : Updated Thermal Rating: on line 12262-3565 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2734
% INFO    : Updated Thermal Rating: on line 5088-10067 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 738
% INFO    : Updated Thermal Rating: on line 125-2725 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 754
% INFO    : Updated Thermal Rating: on line 125-1200 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 378
% INFO    : Updated Thermal Rating: on line 125-1200 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 378
% INFO    : Updated Thermal Rating: on line 125-6426 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 497
% INFO    : Updated Thermal Rating: on line 3453-13182 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 490
% INFO    : Updated Thermal Rating: on line 3453-5574 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 198
% INFO    : Updated Thermal Rating: on line 3453-11614 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1100
% INFO    : Updated Thermal Rating: on line 3453-13416 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 342
% INFO    : Updated Thermal Rating: on line 13488-7865 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 433
% INFO    : Updated Thermal Rating: on line 13488-10572 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 395
% INFO    : Updated Thermal Rating: on line 13488-8294 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 201
% INFO    : Updated Thermal Rating: on line 13488-7348 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3992
% INFO    : Updated Thermal Rating: on line 7865-1200 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 434
% INFO    : Updated Thermal Rating: on line 2725-13182 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 515
% INFO    : Updated Thermal Rating: on line 7658-5574 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 642
% INFO    : Updated Thermal Rating: on line 8467-1307 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 394
% INFO    : Updated Thermal Rating: on line 8467-1307 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 356
% INFO    : Updated Thermal Rating: on line 8467-5574 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 451
% INFO    : Updated Thermal Rating: on line 8467-5574 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 393
% INFO    : Updated Thermal Rating: on line 2243-1307 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 461
% INFO    : Updated Thermal Rating: on line 2243-11754 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1276
% INFO    : Updated Thermal Rating: on line 1200-2629 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 714
% INFO    : Updated Thermal Rating: on line 1200-2629 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 714
% INFO    : Updated Thermal Rating: on line 1200-12105 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1294
% INFO    : Updated Thermal Rating: on line 13182-6426 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 829
% INFO    : Updated Thermal Rating: on line 13182-11614 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 356
% INFO    : Updated Thermal Rating: on line 5363-5574 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 418
% INFO    : Updated Thermal Rating: on line 5363-3513 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 908
% INFO    : Updated Thermal Rating: on line 951-7159 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 406
% INFO    : Updated Thermal Rating: on line 951-9668 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 200
% INFO    : Updated Thermal Rating: on line 951-13442 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 486
% INFO    : Updated Thermal Rating: on line 1307-5574 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 211
% INFO    : Updated Thermal Rating: on line 1307-168 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 358
% INFO    : Updated Thermal Rating: on line 1307-9854 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 547
% INFO    : Updated Thermal Rating: on line 1307-11754 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 479
% INFO    : Updated Thermal Rating: on line 6426-5879 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 161
% INFO    : Updated Thermal Rating: on line 5574-3513 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 370
% INFO    : Updated Thermal Rating: on line 5574-11614 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 199
% INFO    : Updated Thermal Rating: on line 5574-13416 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 445
% INFO    : Updated Thermal Rating: on line 7159-13442 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 514
% INFO    : Updated Thermal Rating: on line 3513-11614 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 364
% INFO    : Updated Thermal Rating: on line 3513-11614 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 364
% INFO    : Updated Thermal Rating: on line 10067-3088 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7570
% INFO    : Updated Thermal Rating: on line 2629-10572 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1249
% INFO    : Updated Thermal Rating: on line 2629-6255 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1998
% INFO    : Updated Thermal Rating: on line 10572-7348 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 666
% INFO    : Updated Thermal Rating: on line 10572-6255 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1998
% INFO    : Updated Thermal Rating: on line 8462-10673 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1038
% INFO    : Updated Thermal Rating: on line 8462-8874 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 938
% INFO    : Updated Thermal Rating: on line 8462-3088 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1083
% INFO    : Updated Thermal Rating: on line 10153-3959 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 183
% INFO    : Updated Thermal Rating: on line 10153-13100 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 232
% INFO    : Updated Thermal Rating: on line 10153-3431 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 192
% INFO    : Updated Thermal Rating: on line 8294-10561 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 216
% INFO    : Updated Thermal Rating: on line 1143-5879 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 300
% INFO    : Updated Thermal Rating: on line 1143-8252 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 509
% INFO    : Updated Thermal Rating: on line 1143-12557 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 520
% INFO    : Updated Thermal Rating: on line 1143-1659 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 41957
% INFO    : Updated Thermal Rating: on line 5879-7783 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 298
% INFO    : Updated Thermal Rating: on line 10561-9668 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 380
% INFO    : Updated Thermal Rating: on line 3959-8280 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 406
% INFO    : Updated Thermal Rating: on line 4799-3765 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 642
% INFO    : Updated Thermal Rating: on line 4799-7783 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 224
% INFO    : Updated Thermal Rating: on line 4799-4402 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 390
% INFO    : Updated Thermal Rating: on line 4799-292 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 122
% INFO    : Updated Thermal Rating: on line 10200-7680 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1517
% INFO    : Updated Thermal Rating: on line 3736-8252 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1135
% INFO    : Updated Thermal Rating: on line 3736-8252 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1135
% INFO    : Updated Thermal Rating: on line 3736-605 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 222
% INFO    : Updated Thermal Rating: on line 3736-13100 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 253
% INFO    : Updated Thermal Rating: on line 3736-6753 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 333
% INFO    : Updated Thermal Rating: on line 8252-931 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 633
% INFO    : Updated Thermal Rating: on line 3765-5043 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 270
% INFO    : Updated Thermal Rating: on line 605-4050 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 408
% INFO    : Updated Thermal Rating: on line 13100-9668 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 174
% INFO    : Updated Thermal Rating: on line 13100-6753 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 339
% INFO    : Updated Thermal Rating: on line 8280-9668 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157
% INFO    : Updated Thermal Rating: on line 7680-292 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1426
% INFO    : Updated Thermal Rating: on line 7680-292 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1426
% INFO    : Updated Thermal Rating: on line 4402-12557 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 280
% INFO    : Updated Thermal Rating: on line 4402-240 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 287
% INFO    : Updated Thermal Rating: on line 5043-292 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 249
% INFO    : Updated Thermal Rating: on line 292-7791 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 359
% INFO    : Updated Thermal Rating: on line 10673-11184 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1053
% INFO    : Updated Thermal Rating: on line 10266-10726 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1461
% INFO    : Updated Thermal Rating: on line 474-10726 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1068
% INFO    : Updated Thermal Rating: on line 474-11407 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1066
% INFO    : Updated Thermal Rating: on line 474-10892 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1066
% INFO    : Updated Thermal Rating: on line 474-4116 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1851
% INFO    : Updated Thermal Rating: on line 474-7800 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2960
% INFO    : Updated Thermal Rating: on line 474-7448 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2480
% INFO    : Updated Thermal Rating: on line 474-4624 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2338
% INFO    : Updated Thermal Rating: on line 1036-10726 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13607
% INFO    : Updated Thermal Rating: on line 1036-8751 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 919
% INFO    : Updated Thermal Rating: on line 10726-13612 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13043
% INFO    : Updated Thermal Rating: on line 10726-13612 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13043
% INFO    : Updated Thermal Rating: on line 10726-13612 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13043
% INFO    : Updated Thermal Rating: on line 10726-13612 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13043
% INFO    : Updated Thermal Rating: on line 10726-4417 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2558
% INFO    : Updated Thermal Rating: on line 11407-1365 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1014
% INFO    : Updated Thermal Rating: on line 10892-7644 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1014
% INFO    : Updated Thermal Rating: on line 4116-8356 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 95327
% INFO    : Updated Thermal Rating: on line 5743-8751 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1360
% INFO    : Updated Thermal Rating: on line 5743-6634 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3055
% INFO    : Updated Thermal Rating: on line 3198-8751 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1735
% INFO    : Updated Thermal Rating: on line 3198-8751 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1758
% INFO    : Updated Thermal Rating: on line 3198-4624 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2506
% INFO    : Updated Thermal Rating: on line 3198-3669 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1976
% INFO    : Updated Thermal Rating: on line 3198-3669 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1976
% INFO    : Updated Thermal Rating: on line 8751-1608 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22611
% INFO    : Updated Thermal Rating: on line 8751-1608 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22611
% INFO    : Updated Thermal Rating: on line 8751-1608 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22611
% INFO    : Updated Thermal Rating: on line 8751-8874 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1247
% INFO    : Updated Thermal Rating: on line 1500-7614 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1112
% INFO    : Updated Thermal Rating: on line 1500-25 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 540
% INFO    : Updated Thermal Rating: on line 1500-1922 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 386
% INFO    : Updated Thermal Rating: on line 7614-4293 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 407
% INFO    : Updated Thermal Rating: on line 7614-7569 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 522
% INFO    : Updated Thermal Rating: on line 7614-12759 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 418
% INFO    : Updated Thermal Rating: on line 9092-12686 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 364
% INFO    : Updated Thermal Rating: on line 9092-10350 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 485
% INFO    : Updated Thermal Rating: on line 9092-12061 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 422
% INFO    : Updated Thermal Rating: on line 8584-11262 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1192
% INFO    : Updated Thermal Rating: on line 8584-7090 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 642
% INFO    : Updated Thermal Rating: on line 25-4293 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2383
% INFO    : Updated Thermal Rating: on line 25-5801 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 270
% INFO    : Updated Thermal Rating: on line 25-4410 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 371
% INFO    : Updated Thermal Rating: on line 11972-1956 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 201
% INFO    : Updated Thermal Rating: on line 11972-1956 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 201
% INFO    : Updated Thermal Rating: on line 11972-7906 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 241
% INFO    : Updated Thermal Rating: on line 11972-7906 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 241
% INFO    : Updated Thermal Rating: on line 11972-8633 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 175
% INFO    : Updated Thermal Rating: on line 11972-8633 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 175
% INFO    : Updated Thermal Rating: on line 5801-1886 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 392
% INFO    : Updated Thermal Rating: on line 5801-12686 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 297
% INFO    : Updated Thermal Rating: on line 5801-9507 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 903
% INFO    : Updated Thermal Rating: on line 5801-9507 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 903
% INFO    : Updated Thermal Rating: on line 5801-6558 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2774
% INFO    : Updated Thermal Rating: on line 5801-6558 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2774
% INFO    : Updated Thermal Rating: on line 2233-8052 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 272
% INFO    : Updated Thermal Rating: on line 2233-9819 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 719
% INFO    : Updated Thermal Rating: on line 2233-11943 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 557
% INFO    : Updated Thermal Rating: on line 8429-1510 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 306
% INFO    : Updated Thermal Rating: on line 8429-10243 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 265
% INFO    : Updated Thermal Rating: on line 667-11594 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 204
% INFO    : Updated Thermal Rating: on line 667-9253 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 190
% INFO    : Updated Thermal Rating: on line 667-7791 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 184
% INFO    : Updated Thermal Rating: on line 1510-4930 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 230
% INFO    : Updated Thermal Rating: on line 1510-8633 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 651
% INFO    : Updated Thermal Rating: on line 1510-8633 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 651
% INFO    : Updated Thermal Rating: on line 1510-4768 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3336
% INFO    : Updated Thermal Rating: on line 1510-4768 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3336
% INFO    : Updated Thermal Rating: on line 10807-5403 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 251
% INFO    : Updated Thermal Rating: on line 6638-5403 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 965
% INFO    : Updated Thermal Rating: on line 6638-5403 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 693
% INFO    : Updated Thermal Rating: on line 6638-1886 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1669
% INFO    : Updated Thermal Rating: on line 6638-5648 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 415
% INFO    : Updated Thermal Rating: on line 10541-4768 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 288
% INFO    : Updated Thermal Rating: on line 10541-3003 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 270
% INFO    : Updated Thermal Rating: on line 5403-7050 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1461
% INFO    : Updated Thermal Rating: on line 5403-7050 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1461
% INFO    : Updated Thermal Rating: on line 5403-7906 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 586
% INFO    : Updated Thermal Rating: on line 5403-7906 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 586
% INFO    : Updated Thermal Rating: on line 5403-6816 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 668
% INFO    : Updated Thermal Rating: on line 7050-1886 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 755
% INFO    : Updated Thermal Rating: on line 7050-1886 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 755
% INFO    : Updated Thermal Rating: on line 1886-11911 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 511
% INFO    : Updated Thermal Rating: on line 10243-11594 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 321
% INFO    : Updated Thermal Rating: on line 10243-11594 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 321
% INFO    : Updated Thermal Rating: on line 10243-8233 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 192
% INFO    : Updated Thermal Rating: on line 7569-3713 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 217
% INFO    : Updated Thermal Rating: on line 11594-6164 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 241
% INFO    : Updated Thermal Rating: on line 11594-2299 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 241
% INFO    : Updated Thermal Rating: on line 3713-6074 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 326
% INFO    : Updated Thermal Rating: on line 3713-3357 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 309
% INFO    : Updated Thermal Rating: on line 9253-10810 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 266
% INFO    : Updated Thermal Rating: on line 9253-10248 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2780
% INFO    : Updated Thermal Rating: on line 9253-3357 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 331
% INFO    : Updated Thermal Rating: on line 9253-729 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 467
% INFO    : Updated Thermal Rating: on line 12098-10828 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1994
% INFO    : Updated Thermal Rating: on line 12098-7906 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 472
% INFO    : Updated Thermal Rating: on line 12098-11731 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 843
% INFO    : Updated Thermal Rating: on line 8052-13484 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 526
% INFO    : Updated Thermal Rating: on line 8052-13484 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 526
% INFO    : Updated Thermal Rating: on line 8052-4965 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1490
% INFO    : Updated Thermal Rating: on line 8052-402 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 333
% INFO    : Updated Thermal Rating: on line 429-10828 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 847
% INFO    : Updated Thermal Rating: on line 429-7906 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 618
% INFO    : Updated Thermal Rating: on line 429-11731 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3444
% INFO    : Updated Thermal Rating: on line 8233-10810 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 525
% INFO    : Updated Thermal Rating: on line 8233-1956 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 776
% INFO    : Updated Thermal Rating: on line 8233-12759 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 374
% INFO    : Updated Thermal Rating: on line 10828-3003 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1517
% INFO    : Updated Thermal Rating: on line 7906-6816 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 642
% INFO    : Updated Thermal Rating: on line 12366-8580 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 535
% INFO    : Updated Thermal Rating: on line 12366-8974 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 494
% INFO    : Updated Thermal Rating: on line 1922-5648 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 352
% INFO    : Updated Thermal Rating: on line 6164-7791 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 201
% INFO    : Updated Thermal Rating: on line 6164-2299 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2391
% INFO    : Updated Thermal Rating: on line 6074-8974 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 384
% INFO    : Updated Thermal Rating: on line 12686-9507 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 484
% INFO    : Updated Thermal Rating: on line 12686-1693 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 328
% INFO    : Updated Thermal Rating: on line 9187-3956 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1514
% INFO    : Updated Thermal Rating: on line 9187-10350 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 423
% INFO    : Updated Thermal Rating: on line 9187-8138 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1525
% INFO    : Updated Thermal Rating: on line 9187-1693 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1112
% INFO    : Updated Thermal Rating: on line 9819-12061 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 447
% INFO    : Updated Thermal Rating: on line 3956-5440 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 668
% INFO    : Updated Thermal Rating: on line 8580-13484 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 500
% INFO    : Updated Thermal Rating: on line 8580-11943 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1669
% INFO    : Updated Thermal Rating: on line 8580-7860 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 835
% INFO    : Updated Thermal Rating: on line 8138-1693 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 666
% INFO    : Updated Thermal Rating: on line 8138-12061 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 286
% INFO    : Updated Thermal Rating: on line 8138-7860 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 246
% INFO    : Updated Thermal Rating: on line 7800-11422 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2106
% INFO    : Updated Thermal Rating: on line 7448-8356 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3267
% INFO    : Updated Thermal Rating: on line 13473-8270 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2914
% INFO    : Updated Thermal Rating: on line 13473-11422 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2669
% INFO    : Updated Thermal Rating: on line 2227-8974 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 571
% INFO    : Updated Thermal Rating: on line 2227-8974 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 571
% INFO    : Updated Thermal Rating: on line 466-3003 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8330
% INFO    : Updated Thermal Rating: on line 3300-7860 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16672
% INFO    : Updated Thermal Rating: on line 10248-4364 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2780
% INFO    : Updated Thermal Rating: on line 3669-12408 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2037
% INFO    : Updated Thermal Rating: on line 4818-3431 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 279
% INFO    : Updated Thermal Rating: on line 4818-9950 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 340
% INFO    : Updated Thermal Rating: on line 4818-4050 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 211
% INFO    : Updated Thermal Rating: on line 4818-4050 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 211
% INFO    : Updated Thermal Rating: on line 11743-5237 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 122
% INFO    : Updated Thermal Rating: on line 11743-11282 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 426
% INFO    : Updated Thermal Rating: on line 2576-6537 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 305
% INFO    : Updated Thermal Rating: on line 2576-1006 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 337
% INFO    : Updated Thermal Rating: on line 2576-4748 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10515
% INFO    : Updated Thermal Rating: on line 2576-4748 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10515
% INFO    : Updated Thermal Rating: on line 3203-9950 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 174
% INFO    : Updated Thermal Rating: on line 3203-3574 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1094
% INFO    : Updated Thermal Rating: on line 3203-11432 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 513
% INFO    : Updated Thermal Rating: on line 8787-380 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 221
% INFO    : Updated Thermal Rating: on line 8787-3600 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 315
% INFO    : Updated Thermal Rating: on line 8787-7140 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 168
% INFO    : Updated Thermal Rating: on line 8787-1064 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 333
% INFO    : Updated Thermal Rating: on line 8787-1064 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 333
% INFO    : Updated Thermal Rating: on line 741-3443 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1007
% INFO    : Updated Thermal Rating: on line 741-3443 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1007
% INFO    : Updated Thermal Rating: on line 11013-1049 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1651
% INFO    : Updated Thermal Rating: on line 11013-1049 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1651
% INFO    : Updated Thermal Rating: on line 11013-1049 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1598
% INFO    : Updated Thermal Rating: on line 11013-9163 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 330
% INFO    : Updated Thermal Rating: on line 11013-5407 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 130
% INFO    : Updated Thermal Rating: on line 1049-1387 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 356
% INFO    : Updated Thermal Rating: on line 1049-3443 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 522
% INFO    : Updated Thermal Rating: on line 1049-1006 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 377
% INFO    : Updated Thermal Rating: on line 1049-5522 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1368
% INFO    : Updated Thermal Rating: on line 1049-5522 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1368
% INFO    : Updated Thermal Rating: on line 6627-10121 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 594
% INFO    : Updated Thermal Rating: on line 6627-9950 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 193
% INFO    : Updated Thermal Rating: on line 3357-380 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 389
% INFO    : Updated Thermal Rating: on line 3357-380 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 389
% INFO    : Updated Thermal Rating: on line 3357-6412 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1254
% INFO    : Updated Thermal Rating: on line 3357-729 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1052
% INFO    : Updated Thermal Rating: on line 3357-4364 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 334
% INFO    : Updated Thermal Rating: on line 3357-1056 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 377
% INFO    : Updated Thermal Rating: on line 5237-9950 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 172
% INFO    : Updated Thermal Rating: on line 5237-11684 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 463
% INFO    : Updated Thermal Rating: on line 3431-11684 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 180
% INFO    : Updated Thermal Rating: on line 1387-3443 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 716
% INFO    : Updated Thermal Rating: on line 1387-2944 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1192
% INFO    : Updated Thermal Rating: on line 9163-4965 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 397
% INFO    : Updated Thermal Rating: on line 380-7185 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 333
% INFO    : Updated Thermal Rating: on line 6412-2944 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 474
% INFO    : Updated Thermal Rating: on line 6412-10314 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5564
% INFO    : Updated Thermal Rating: on line 3600-3574 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 286
% INFO    : Updated Thermal Rating: on line 4965-5407 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 340
% INFO    : Updated Thermal Rating: on line 8738-3437 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1472
% INFO    : Updated Thermal Rating: on line 7140-9950 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 234
% INFO    : Updated Thermal Rating: on line 8346-7673 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 666
% INFO    : Updated Thermal Rating: on line 8346-7673 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 666
% INFO    : Updated Thermal Rating: on line 8346-3253 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 638
% INFO    : Updated Thermal Rating: on line 8346-3253 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 638
% INFO    : Updated Thermal Rating: on line 8346-7185 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1332
% INFO    : Updated Thermal Rating: on line 8346-1064 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19959
% INFO    : Updated Thermal Rating: on line 8346-1064 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19959
% INFO    : Updated Thermal Rating: on line 2175-7642 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 557
% INFO    : Updated Thermal Rating: on line 2175-1178 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 76679
% INFO    : Updated Thermal Rating: on line 2175-918 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 456
% INFO    : Updated Thermal Rating: on line 2175-918 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 456
% INFO    : Updated Thermal Rating: on line 12315-5407 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 488
% INFO    : Updated Thermal Rating: on line 12315-7642 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 645
% INFO    : Updated Thermal Rating: on line 5407-402 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 766
% INFO    : Updated Thermal Rating: on line 10121-6537 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 883
% INFO    : Updated Thermal Rating: on line 10121-918 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 209
% INFO    : Updated Thermal Rating: on line 240-3437 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 376
% INFO    : Updated Thermal Rating: on line 240-3437 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 376
% INFO    : Updated Thermal Rating: on line 240-1056 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 749
% INFO    : Updated Thermal Rating: on line 5618-11282 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 232
% INFO    : Updated Thermal Rating: on line 5618-918 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 456
% INFO    : Updated Thermal Rating: on line 7642-4748 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 155
% INFO    : Updated Thermal Rating: on line 12408-11184 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 925
% INFO    : Updated Thermal Rating: on line 12408-8270 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4736
% INFO    : Updated Thermal Rating: on line 4748-11432 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9980
% INFO    : Updated Thermal Rating: on line 3190-4364 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 835
% INFO    : Updated Thermal Rating: on line 11184-5949 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1184
% INFO    : Updated Thermal Rating: on line 8270-8119 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2368
% INFO    : Updated Thermal Rating: on line 4804-2752 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1307
% INFO    : Updated Thermal Rating: on line 11928-11422 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157937
% INFO    : Updated Thermal Rating: on line 5949-8119 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1263
% INFO    : Updated Thermal Rating: on line 8119-8892 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7290
% INFO    : Updated Thermal Rating: on line 8408-13128 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4610
% INFO    : Updated Thermal Rating: on line 13128-1741 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13107
% INFO    : Updated Thermal Rating: on line 11255-1256 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1477
% INFO    : Updated Thermal Rating: on line 9601-12149 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157801
% INFO    : Updated Thermal Rating: on line 7348-13442 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 999
% INFO    : Updated Thermal Rating: on line 7348-13442 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 999
% INFO    : Updated Thermal Rating: on line 5440-4410 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2383
% INFO    : Updated Thermal Rating: on line 12438-11943 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 83913
% INFO    : Updated Thermal Rating: on transformer 8859-10123 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2739
% INFO    : Updated Thermal Rating: on transformer 4222-7260 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3053
% INFO    : Updated Thermal Rating: on transformer 642-6538 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3555
% INFO    : Updated Thermal Rating: on transformer 11825-2422 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12
% INFO    : Updated Thermal Rating: on transformer 11825-7731 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on transformer 11825-1599 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13
% INFO    : Updated Thermal Rating: on transformer 11825-9830 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13
% INFO    : Updated Thermal Rating: on transformer 11825-7962 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9
% INFO    : Updated Thermal Rating: on transformer 11825-11903 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9
% INFO    : Updated Thermal Rating: on transformer 11825-12507 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on transformer 11825-3894 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13
% INFO    : Updated Thermal Rating: on transformer 11825-8359 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23
% INFO    : Updated Thermal Rating: on transformer 11825-5658 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on transformer 11825-423 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on transformer 11825-2192 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on transformer 11825-4611 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on transformer 11825-2526 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on transformer 9103-4746 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15
% INFO    : Updated Thermal Rating: on transformer 9103-10613 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5
% INFO    : Updated Thermal Rating: on transformer 214-1048 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on transformer 214-5254 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on transformer 214-8246 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on transformer 214-3360 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on transformer 214-6347 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on transformer 214-11781 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14
% INFO    : Updated Thermal Rating: on transformer 214-3348 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 34
% INFO    : Updated Thermal Rating: on transformer 214-13510 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on transformer 214-9797 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on transformer 214-5210 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10
% INFO    : Updated Thermal Rating: on transformer 214-9728 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on transformer 214-635 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on transformer 214-12541 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10
% INFO    : Updated Thermal Rating: on transformer 214-11393 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on transformer 214-9056 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16
% INFO    : Updated Thermal Rating: on transformer 214-4009 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on transformer 214-12221 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19
% INFO    : Updated Thermal Rating: on transformer 214-392 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13
% INFO    : Updated Thermal Rating: on transformer 214-9421 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11
% INFO    : Updated Thermal Rating: on transformer 214-10829 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13
% INFO    : Updated Thermal Rating: on transformer 214-1088 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on transformer 214-8764 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 45
% INFO    : Updated Thermal Rating: on transformer 214-5333 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13
% INFO    : Updated Thermal Rating: on transformer 214-9997 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on transformer 2042-10452 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 93
% INFO    : Updated Thermal Rating: on transformer 2042-5116 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 85
% INFO    : Updated Thermal Rating: on transformer 2042-12383 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 92
% INFO    : Updated Thermal Rating: on transformer 2042-7114 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 74
% INFO    : Updated Thermal Rating: on transformer 2042-10891 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 101
% INFO    : Updated Thermal Rating: on transformer 2042-8033 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 161
% INFO    : Updated Thermal Rating: on transformer 2042-2712 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 85
% INFO    : Updated Thermal Rating: on transformer 7827-5316 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22
% INFO    : Updated Thermal Rating: on transformer 7119-332 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8
% INFO    : Updated Thermal Rating: on transformer 7119-1421 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8
% INFO    : Updated Thermal Rating: on transformer 7119-6717 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8
% INFO    : Updated Thermal Rating: on transformer 4116-6272 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16
% INFO    : Updated Thermal Rating: on transformer 4116-11672 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8
% INFO    : Updated Thermal Rating: on transformer 10180-111 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 339
% INFO    : Updated Thermal Rating: on transformer 10180-111 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 346
% INFO    : Updated Thermal Rating: on transformer 11863-8494 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 221
% INFO    : Updated Thermal Rating: on transformer 3549-10458 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 309
% INFO    : Updated Thermal Rating: on transformer 3549-10458 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 316
% INFO    : Updated Thermal Rating: on transformer 3549-10458 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 300
% INFO    : Updated Thermal Rating: on transformer 12153-8241 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 643
% INFO    : Updated Thermal Rating: on transformer 12153-8241 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 678
% INFO    : Updated Thermal Rating: on transformer 10717-11653 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 651
% INFO    : Updated Thermal Rating: on transformer 11653-10859 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 437
% INFO    : Updated Thermal Rating: on transformer 11653-10859 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 445
% INFO    : Updated Thermal Rating: on transformer 11653-10859 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 455
% INFO    : Updated Thermal Rating: on transformer 414-12283 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 396
% INFO    : Updated Thermal Rating: on transformer 414-12283 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 405
% INFO    : Updated Thermal Rating: on transformer 2209-414 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 781
% INFO    : Updated Thermal Rating: on transformer 2209-414 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 689
% INFO    : Updated Thermal Rating: on transformer 2972-13068 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 408
% INFO    : Updated Thermal Rating: on transformer 2972-13068 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 400
% INFO    : Updated Thermal Rating: on transformer 8698-6348 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 346
% INFO    : Updated Thermal Rating: on transformer 8698-6348 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 8720-6779 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 405
% INFO    : Updated Thermal Rating: on transformer 8720-6779 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 409
% INFO    : Updated Thermal Rating: on transformer 8720-6779 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 451
% INFO    : Updated Thermal Rating: on transformer 850-3658 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 401
% INFO    : Updated Thermal Rating: on transformer 7565-756 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1092
% INFO    : Updated Thermal Rating: on transformer 7565-756 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 963
% INFO    : Updated Thermal Rating: on transformer 3133-11180 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 948
% INFO    : Updated Thermal Rating: on transformer 1929-11180 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 930
% INFO    : Updated Thermal Rating: on transformer 9701-11180 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1936
% INFO    : Updated Thermal Rating: on transformer 9701-5617 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1250
% INFO    : Updated Thermal Rating: on transformer 8760-2611 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 993
% INFO    : Updated Thermal Rating: on transformer 8760-2611 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1014
% INFO    : Updated Thermal Rating: on transformer 6316-971 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 675
% INFO    : Updated Thermal Rating: on transformer 6316-2611 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 690
% INFO    : Updated Thermal Rating: on transformer 4778-8152 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 833
% INFO    : Updated Thermal Rating: on transformer 4778-8152 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 680
% INFO    : Updated Thermal Rating: on transformer 5140-8509 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 948
% INFO    : Updated Thermal Rating: on transformer 5140-8509 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 930
% INFO    : Updated Thermal Rating: on transformer 8134-8509 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1980
% INFO    : Updated Thermal Rating: on transformer 8134-5450 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2139
% INFO    : Updated Thermal Rating: on transformer 517-446 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2165
% INFO    : Updated Thermal Rating: on line 517-9874 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2269
% INFO    : Updated Thermal Rating: on transformer 4357-5711 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2419
% INFO    : Updated Thermal Rating: on transformer 11750-404 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1019
% INFO    : Updated Thermal Rating: on transformer 11750-404 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1042
% INFO    : Updated Thermal Rating: on transformer 672-249 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2038
% INFO    : Updated Thermal Rating: on transformer 8315-8142 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 441
% INFO    : Updated Thermal Rating: on transformer 3604-9284 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 615
% INFO    : Updated Thermal Rating: on transformer 3604-9284 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 591
% INFO    : Updated Thermal Rating: on transformer 10639-13644 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 729
% INFO    : Updated Thermal Rating: on transformer 3925-10834 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 483
% INFO    : Updated Thermal Rating: on transformer 3925-10834 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 494
% INFO    : Updated Thermal Rating: on transformer 12721-7418 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 426
% INFO    : Updated Thermal Rating: on transformer 1360-5067 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 451
% INFO    : Updated Thermal Rating: on transformer 1360-5067 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 443
% INFO    : Updated Thermal Rating: on transformer 5338-1360 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1155
% INFO    : Updated Thermal Rating: on transformer 5338-1360 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1179
% INFO    : Updated Thermal Rating: on transformer 3750-5578 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 457
% INFO    : Updated Thermal Rating: on transformer 3750-5578 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 431
% INFO    : Updated Thermal Rating: on transformer 524-4231 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 409
% INFO    : Updated Thermal Rating: on transformer 524-4231 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 418
% INFO    : Updated Thermal Rating: on transformer 7701-5663 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 824
% INFO    : Updated Thermal Rating: on transformer 10387-3766 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1046
% INFO    : Updated Thermal Rating: on transformer 10387-2914 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1163
% INFO    : Updated Thermal Rating: on transformer 3840-1375 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 434
% INFO    : Updated Thermal Rating: on transformer 4711-12377 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 435
% INFO    : Updated Thermal Rating: on transformer 10677-524 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1236
% INFO    : Updated Thermal Rating: on transformer 11279-5793 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 442
% INFO    : Updated Thermal Rating: on transformer 11279-5793 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 452
% INFO    : Updated Thermal Rating: on transformer 8195-11279 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 925
% INFO    : Updated Thermal Rating: on transformer 8195-11279 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 907
% INFO    : Updated Thermal Rating: on transformer 9783-5452 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1077
% INFO    : Updated Thermal Rating: on transformer 9783-5161 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 839
% INFO    : Updated Thermal Rating: on transformer 13164-11388 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 897
% INFO    : Updated Thermal Rating: on transformer 4485-11018 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 432
% INFO    : Updated Thermal Rating: on transformer 4485-11018 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 441
% INFO    : Updated Thermal Rating: on transformer 3183-3359 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 470
% INFO    : Updated Thermal Rating: on transformer 3183-3359 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 495
% INFO    : Updated Thermal Rating: on transformer 8848-13586 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 675
% INFO    : Updated Thermal Rating: on transformer 8848-4381 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 699
% INFO    : Updated Thermal Rating: on transformer 11493-4381 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on transformer 7727-3277 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 790
% INFO    : Updated Thermal Rating: on transformer 7727-8135 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 698
% INFO    : Updated Thermal Rating: on transformer 7221-2593 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 514
% INFO    : Updated Thermal Rating: on transformer 2593-1142 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on transformer 9805-6724 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 645
% INFO    : Updated Thermal Rating: on transformer 3500-5137 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 661
% INFO    : Updated Thermal Rating: on transformer 1937-9970 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 615
% INFO    : Updated Thermal Rating: on transformer 2394-342 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 603
% INFO    : Updated Thermal Rating: on transformer 11493-9970 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 492
% INFO    : Updated Thermal Rating: on transformer 962-4784 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 650
% INFO    : Updated Thermal Rating: on transformer 7602-1142 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 351
% INFO    : Updated Thermal Rating: on transformer 2044-1142 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 653
% INFO    : Updated Thermal Rating: on transformer 10523-3070 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 733
% INFO    : Updated Thermal Rating: on transformer 9981-13254 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 730
% INFO    : Updated Thermal Rating: on transformer 5402-10366 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 645
% INFO    : Updated Thermal Rating: on transformer 12041-6499 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 643
% INFO    : Updated Thermal Rating: on transformer 13341-11058 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 618
% INFO    : Updated Thermal Rating: on transformer 3238-7602 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 806
% INFO    : Updated Thermal Rating: on transformer 7602-9831 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26
% INFO    : Updated Thermal Rating: on transformer 7602-12273 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 120
% INFO    : Updated Thermal Rating: on transformer 7602-3510 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52
% INFO    : Updated Thermal Rating: on transformer 7602-6844 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9
% INFO    : Updated Thermal Rating: on transformer 7602-6590 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on transformer 12038-9831 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 723
% INFO    : Updated Thermal Rating: on transformer 2044-9831 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14
% INFO    : Updated Thermal Rating: on transformer 7626-12273 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 692
% INFO    : Updated Thermal Rating: on transformer 7626-2191 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 620
% INFO    : Updated Thermal Rating: on transformer 2044-12273 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 57
% INFO    : Updated Thermal Rating: on transformer 11382-10883 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 700
% INFO    : Updated Thermal Rating: on transformer 11382-412 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 662
% INFO    : Updated Thermal Rating: on transformer 11493-8395 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 117
% INFO    : Updated Thermal Rating: on transformer 5712-2044 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 552
% INFO    : Updated Thermal Rating: on transformer 5712-2044 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 564
% INFO    : Updated Thermal Rating: on transformer 2044-3510 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 30
% INFO    : Updated Thermal Rating: on transformer 2044-6844 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5
% INFO    : Updated Thermal Rating: on transformer 3239-4174 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 628
% INFO    : Updated Thermal Rating: on transformer 13103-8395 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 637
% INFO    : Updated Thermal Rating: on transformer 13103-3579 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 667
% INFO    : Updated Thermal Rating: on transformer 471-3510 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 779
% INFO    : Updated Thermal Rating: on line 11179-7780 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3669
% INFO    : Updated Thermal Rating: on transformer 8510-11012 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2080
% INFO    : Updated Thermal Rating: on transformer 129-6590 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 693
% INFO    : Updated Thermal Rating: on transformer 3618-6844 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 705
% INFO    : Updated Thermal Rating: on transformer 8729-6473 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 731
% INFO    : Updated Thermal Rating: on transformer 3049-8729 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2502
% INFO    : Updated Thermal Rating: on transformer 10227-5892 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2060
% INFO    : Updated Thermal Rating: on transformer 5892-8032 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 496
% INFO    : Updated Thermal Rating: on transformer 5892-8032 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 532
% INFO    : Updated Thermal Rating: on transformer 4589-12971 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 505
% INFO    : Updated Thermal Rating: on transformer 4589-12971 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 548
% INFO    : Updated Thermal Rating: on transformer 7401-2028 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 531
% INFO    : Updated Thermal Rating: on transformer 7401-13653 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 515
% INFO    : Updated Thermal Rating: on transformer 3581-7895 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 509
% INFO    : Updated Thermal Rating: on transformer 3581-7895 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 449
% INFO    : Updated Thermal Rating: on transformer 1248-2267 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 376
% INFO    : Updated Thermal Rating: on transformer 6446-1542 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 585
% INFO    : Updated Thermal Rating: on transformer 6446-1542 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 574
% INFO    : Updated Thermal Rating: on transformer 11068-8672 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 455
% INFO    : Updated Thermal Rating: on transformer 11068-8672 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 460
% INFO    : Updated Thermal Rating: on transformer 5019-6742 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 393
% INFO    : Updated Thermal Rating: on transformer 5019-6742 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 401
% INFO    : Updated Thermal Rating: on transformer 13321-13072 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 423
% INFO    : Updated Thermal Rating: on transformer 13321-13072 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 433
% INFO    : Updated Thermal Rating: on transformer 1292-6703 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 449
% INFO    : Updated Thermal Rating: on transformer 11423-5014 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 480
% INFO    : Updated Thermal Rating: on transformer 13151-704 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 500
% INFO    : Updated Thermal Rating: on transformer 1784-704 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 403
% INFO    : Updated Thermal Rating: on transformer 1784-704 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 420
% INFO    : Updated Thermal Rating: on transformer 3834-2401 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 511
% INFO    : Updated Thermal Rating: on transformer 3834-2401 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 536
% INFO    : Updated Thermal Rating: on transformer 3420-2931 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 371
% INFO    : Updated Thermal Rating: on transformer 7537-832 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 522
% INFO    : Updated Thermal Rating: on transformer 2035-1873 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 489
% INFO    : Updated Thermal Rating: on transformer 2035-1873 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 480
% INFO    : Updated Thermal Rating: on transformer 2035-1873 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 471
% INFO    : Updated Thermal Rating: on transformer 573-10751 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 454
% INFO    : Updated Thermal Rating: on transformer 573-10751 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 482
% INFO    : Updated Thermal Rating: on transformer 2384-13523 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 688
% INFO    : Updated Thermal Rating: on transformer 13646-13522 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1396
% INFO    : Updated Thermal Rating: on transformer 13522-2673 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 524
% INFO    : Updated Thermal Rating: on transformer 13522-2673 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 535
% INFO    : Updated Thermal Rating: on transformer 8812-1580 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 458
% INFO    : Updated Thermal Rating: on transformer 12258-9419 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2648
% INFO    : Updated Thermal Rating: on transformer 2900-8749 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2060
% INFO    : Updated Thermal Rating: on transformer 8749-5414 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 569
% INFO    : Updated Thermal Rating: on transformer 8749-5414 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 604
% INFO    : Updated Thermal Rating: on transformer 12618-9130 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 444
% INFO    : Updated Thermal Rating: on transformer 12618-9130 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 363
% INFO    : Updated Thermal Rating: on transformer 2745-1565 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 621
% INFO    : Updated Thermal Rating: on transformer 12830-4536 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 391
% INFO    : Updated Thermal Rating: on transformer 12830-4536 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 403
% INFO    : Updated Thermal Rating: on transformer 7538-12389 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 490
% INFO    : Updated Thermal Rating: on transformer 7538-12389 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 485
% INFO    : Updated Thermal Rating: on transformer 1643-4221 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 443
% INFO    : Updated Thermal Rating: on transformer 1643-4221 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 446
% INFO    : Updated Thermal Rating: on transformer 2145-6309 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 372
% INFO    : Updated Thermal Rating: on transformer 2145-6309 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 378
% INFO    : Updated Thermal Rating: on transformer 5852-46 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1920
% INFO    : Updated Thermal Rating: on transformer 5852-2346 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 594
% INFO    : Updated Thermal Rating: on transformer 46-2346 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 549
% INFO    : Updated Thermal Rating: on transformer 5205-6143 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 490
% INFO    : Updated Thermal Rating: on transformer 969-5917 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 276
% INFO    : Updated Thermal Rating: on transformer 2598-10920 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 471
% INFO    : Updated Thermal Rating: on transformer 349-13276 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 424
% INFO    : Updated Thermal Rating: on transformer 9002-6629 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 526
% INFO    : Updated Thermal Rating: on transformer 9002-6629 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 522
% INFO    : Updated Thermal Rating: on transformer 10919-5136 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 894
% INFO    : Updated Thermal Rating: on transformer 1708-8682 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 592
% INFO    : Updated Thermal Rating: on transformer 9895-7914 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 642
% INFO    : Updated Thermal Rating: on transformer 9895-7914 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 656
% INFO    : Updated Thermal Rating: on transformer 2956-6660 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1497
% INFO    : Updated Thermal Rating: on transformer 13180-10140 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 955
% INFO    : Updated Thermal Rating: on transformer 5115-3596 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2280
% INFO    : Updated Thermal Rating: on transformer 7231-4303 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 676
% INFO    : Updated Thermal Rating: on transformer 2225-5238 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1053
% INFO    : Updated Thermal Rating: on transformer 4782-3568 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1932
% INFO    : Updated Thermal Rating: on transformer 1939-9543 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1140
% INFO    : Updated Thermal Rating: on transformer 8399-9418 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1141
% INFO    : Updated Thermal Rating: on transformer 8399-9418 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1166
% INFO    : Updated Thermal Rating: on transformer 2399-565 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1025
% INFO    : Updated Thermal Rating: on transformer 6503-565 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 414
% INFO    : Updated Thermal Rating: on transformer 6173-10574 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1515
% INFO    : Updated Thermal Rating: on transformer 6000-217 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2874
% INFO    : Updated Thermal Rating: on transformer 6000-217 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2820
% INFO    : Updated Thermal Rating: on transformer 7078-6129 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1683
% INFO    : Updated Thermal Rating: on transformer 4399-3110 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1107
% INFO    : Updated Thermal Rating: on transformer 4399-3110 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1128
% INFO    : Updated Thermal Rating: on transformer 2362-5841 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 949
% INFO    : Updated Thermal Rating: on transformer 2362-5841 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1072
% INFO    : Updated Thermal Rating: on transformer 1194-566 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1204
% INFO    : Updated Thermal Rating: on transformer 1194-566 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1063
% INFO    : Updated Thermal Rating: on transformer 1788-1140 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 187
% INFO    : Updated Thermal Rating: on transformer 1788-1140 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 184
% INFO    : Updated Thermal Rating: on transformer 892-8601 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1914
% INFO    : Updated Thermal Rating: on transformer 10332-8762 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1167
% INFO    : Updated Thermal Rating: on transformer 4802-436 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1210
% INFO    : Updated Thermal Rating: on transformer 12785-4872 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1235
% INFO    : Updated Thermal Rating: on transformer 10774-3721 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1409
% INFO    : Updated Thermal Rating: on transformer 10838-9099 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on transformer 8035-9099 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on transformer 11812-9099 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 12474-9099 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 91-9099 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 10349-9099 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 41
% INFO    : Updated Thermal Rating: on transformer 12274-9099 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 1789-9099 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13
% INFO    : Updated Thermal Rating: on transformer 10838-11009 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 8035-11009 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 10349-11009 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23
% INFO    : Updated Thermal Rating: on transformer 1789-11009 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on transformer 7867-3932 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 38
% INFO    : Updated Thermal Rating: on transformer 9172-3932 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 38
% INFO    : Updated Thermal Rating: on transformer 9153-3773 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 53
% INFO    : Updated Thermal Rating: on transformer 9153-1645 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 67
% INFO    : Updated Thermal Rating: on transformer 9153-4860 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 102
% INFO    : Updated Thermal Rating: on transformer 131-707 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on transformer 12474-707 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 11732-707 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 3895-707 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 131-9072 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on transformer 12474-9072 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 11732-9072 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 3895-9072 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 10335-5899 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 86
% INFO    : Updated Thermal Rating: on transformer 10335-1467 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 28
% INFO    : Updated Thermal Rating: on transformer 10335-5005 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26
% INFO    : Updated Thermal Rating: on transformer 10335-5923 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on transformer 10335-1752 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on transformer 10335-644 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 28
% INFO    : Updated Thermal Rating: on transformer 10335-2726 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 29
% INFO    : Updated Thermal Rating: on transformer 10335-5344 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 35
% INFO    : Updated Thermal Rating: on transformer 10335-2264 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9
% INFO    : Updated Thermal Rating: on transformer 10335-4342 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8
% INFO    : Updated Thermal Rating: on transformer 10335-1684 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8
% INFO    : Updated Thermal Rating: on transformer 12622-5899 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11
% INFO    : Updated Thermal Rating: on transformer 272-5899 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11
% INFO    : Updated Thermal Rating: on transformer 4883-5899 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11
% INFO    : Updated Thermal Rating: on transformer 7997-5899 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5
% INFO    : Updated Thermal Rating: on transformer 6414-5899 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on transformer 12406-5899 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9
% INFO    : Updated Thermal Rating: on transformer 8314-5899 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8
% INFO    : Updated Thermal Rating: on transformer 9085-5899 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5
% INFO    : Updated Thermal Rating: on transformer 10280-7699 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 972
% INFO    : Updated Thermal Rating: on transformer 10280-7699 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 770
% INFO    : Updated Thermal Rating: on transformer 10280-7699 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 786
% INFO    : Updated Thermal Rating: on transformer 376-7699 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 6032-7699 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 3603-7699 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 2174-7699 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 63
% INFO    : Updated Thermal Rating: on transformer 7131-7699 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on transformer 13017-7699 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 6550-7699 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21
% INFO    : Updated Thermal Rating: on transformer 964-7699 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13
% INFO    : Updated Thermal Rating: on transformer 13282-7699 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8
% INFO    : Updated Thermal Rating: on transformer 12961-12536 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 271
% INFO    : Updated Thermal Rating: on transformer 3288-260 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 67
% INFO    : Updated Thermal Rating: on transformer 2382-260 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 47
% INFO    : Updated Thermal Rating: on transformer 5152-260 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 47
% INFO    : Updated Thermal Rating: on transformer 10382-11302 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1107
% INFO    : Updated Thermal Rating: on transformer 6823-11302 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1130
% INFO    : Updated Thermal Rating: on transformer 131-11302 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 40
% INFO    : Updated Thermal Rating: on transformer 10838-11302 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 8035-11302 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 11812-11302 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 12474-11302 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on transformer 91-11302 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on transformer 11732-11302 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15
% INFO    : Updated Thermal Rating: on transformer 12274-11302 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 3895-11302 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on transformer 12622-1467 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on transformer 12622-5005 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on transformer 12622-5923 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on transformer 12622-1752 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5
% INFO    : Updated Thermal Rating: on transformer 12622-644 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 53
% INFO    : Updated Thermal Rating: on transformer 12622-2726 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 55
% INFO    : Updated Thermal Rating: on transformer 12622-5344 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on transformer 12622-2264 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16
% INFO    : Updated Thermal Rating: on transformer 12622-4342 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 12622-1684 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 12622-5667 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 475
% INFO    : Updated Thermal Rating: on transformer 9636-7765 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22
% INFO    : Updated Thermal Rating: on transformer 13354-7765 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 29
% INFO    : Updated Thermal Rating: on transformer 9506-7765 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 64
% INFO    : Updated Thermal Rating: on transformer 1172-7765 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 81
% INFO    : Updated Thermal Rating: on transformer 5569-7765 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on transformer 8176-7765 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on transformer 6825-7765 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 47
% INFO    : Updated Thermal Rating: on transformer 10957-7765 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 28
% INFO    : Updated Thermal Rating: on transformer 9636-9820 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 113
% INFO    : Updated Thermal Rating: on transformer 9636-9820 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 673
% INFO    : Updated Thermal Rating: on transformer 9636-7733 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15
% INFO    : Updated Thermal Rating: on transformer 9636-3193 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16
% INFO    : Updated Thermal Rating: on transformer 9636-6386 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 50
% INFO    : Updated Thermal Rating: on transformer 13354-9820 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 150
% INFO    : Updated Thermal Rating: on transformer 13354-9820 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2963
% INFO    : Updated Thermal Rating: on transformer 13354-7733 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21
% INFO    : Updated Thermal Rating: on transformer 13354-3193 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21
% INFO    : Updated Thermal Rating: on transformer 13354-6386 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 58
% INFO    : Updated Thermal Rating: on transformer 9506-9820 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5
% INFO    : Updated Thermal Rating: on transformer 1172-9820 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13
% INFO    : Updated Thermal Rating: on transformer 5569-9820 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11
% INFO    : Updated Thermal Rating: on transformer 8176-9820 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12
% INFO    : Updated Thermal Rating: on transformer 6825-9820 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on transformer 10957-9820 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 34
% INFO    : Updated Thermal Rating: on transformer 622-7915 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2247
% INFO    : Updated Thermal Rating: on transformer 9506-3170 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2294
% INFO    : Updated Thermal Rating: on transformer 9506-7733 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 9506-3193 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 9506-6386 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 2872-13213 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26
% INFO    : Updated Thermal Rating: on transformer 7278-13213 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26
% INFO    : Updated Thermal Rating: on transformer 2872-10921 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 28
% INFO    : Updated Thermal Rating: on transformer 7278-10921 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 29
% INFO    : Updated Thermal Rating: on transformer 6362-1167 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 933
% INFO    : Updated Thermal Rating: on transformer 6362-3932 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 36
% INFO    : Updated Thermal Rating: on transformer 6362-10699 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2955
% INFO    : Updated Thermal Rating: on transformer 13454-3746 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 178
% INFO    : Updated Thermal Rating: on transformer 13454-12363 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 62
% INFO    : Updated Thermal Rating: on transformer 13454-5547 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 230
% INFO    : Updated Thermal Rating: on transformer 131-13629 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 131-8267 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 131-4147 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 131-11448 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8
% INFO    : Updated Thermal Rating: on transformer 131-2359 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8
% INFO    : Updated Thermal Rating: on transformer 131-366 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12
% INFO    : Updated Thermal Rating: on transformer 131-1535 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on transformer 131-5183 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 131-7014 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27
% INFO    : Updated Thermal Rating: on transformer 131-12720 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 29
% INFO    : Updated Thermal Rating: on transformer 131-9401 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 51
% INFO    : Updated Thermal Rating: on transformer 131-2256 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 131-1566 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8
% INFO    : Updated Thermal Rating: on transformer 131-5754 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on transformer 1172-7733 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 5569-7733 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 60
% INFO    : Updated Thermal Rating: on transformer 8176-7733 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 61
% INFO    : Updated Thermal Rating: on transformer 6825-7733 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 10957-7733 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5
% INFO    : Updated Thermal Rating: on transformer 1172-3193 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 5569-3193 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52
% INFO    : Updated Thermal Rating: on transformer 8176-3193 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 51
% INFO    : Updated Thermal Rating: on transformer 6825-3193 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 10957-3193 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5
% INFO    : Updated Thermal Rating: on transformer 10838-13629 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 10838-8267 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 10838-4147 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 10838-11448 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 10838-2359 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 10838-366 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16
% INFO    : Updated Thermal Rating: on transformer 10838-9823 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 10838-6896 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on transformer 10838-10979 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on transformer 10838-1535 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 10838-5183 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9
% INFO    : Updated Thermal Rating: on transformer 10838-7014 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on transformer 10838-12720 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8
% INFO    : Updated Thermal Rating: on transformer 10838-7916 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20
% INFO    : Updated Thermal Rating: on transformer 10838-3743 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18
% INFO    : Updated Thermal Rating: on transformer 10838-9401 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 10838-4717 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 10838-2256 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on transformer 8035-13629 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 8035-8267 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 8035-4147 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 8035-11448 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 8035-2359 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 8035-366 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18
% INFO    : Updated Thermal Rating: on transformer 8035-9823 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 8035-6896 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on transformer 8035-10979 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on transformer 8035-1535 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 8035-5183 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9
% INFO    : Updated Thermal Rating: on transformer 8035-7014 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on transformer 8035-12720 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on transformer 8035-7916 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19
% INFO    : Updated Thermal Rating: on transformer 8035-3743 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19
% INFO    : Updated Thermal Rating: on transformer 8035-9401 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 8035-4717 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 8035-2256 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on transformer 8653-3932 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 65
% INFO    : Updated Thermal Rating: on transformer 272-1467 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20
% INFO    : Updated Thermal Rating: on transformer 272-5005 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20
% INFO    : Updated Thermal Rating: on transformer 272-5923 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 272-1752 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 272-644 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8
% INFO    : Updated Thermal Rating: on transformer 272-2726 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9
% INFO    : Updated Thermal Rating: on transformer 272-5344 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8
% INFO    : Updated Thermal Rating: on transformer 272-2264 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on transformer 272-4342 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 272-1684 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 4883-1467 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20
% INFO    : Updated Thermal Rating: on transformer 4883-5005 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20
% INFO    : Updated Thermal Rating: on transformer 4883-5923 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 4883-1752 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 4883-644 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8
% INFO    : Updated Thermal Rating: on transformer 4883-2726 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9
% INFO    : Updated Thermal Rating: on transformer 4883-5344 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8
% INFO    : Updated Thermal Rating: on transformer 4883-2264 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on transformer 4883-4342 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 4883-1684 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 7997-1467 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on transformer 6414-1467 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 12406-1467 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on transformer 8314-1467 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on transformer 9085-1467 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on transformer 7997-5005 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on transformer 6414-5005 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 12406-5005 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on transformer 8314-5005 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on transformer 9085-5005 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on transformer 3464-1758 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 153
% INFO    : Updated Thermal Rating: on transformer 2872-1758 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 35
% INFO    : Updated Thermal Rating: on transformer 7278-1758 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 36
% INFO    : Updated Thermal Rating: on transformer 1172-6386 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on transformer 2872-9140 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22
% INFO    : Updated Thermal Rating: on transformer 2872-141 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 29
% INFO    : Updated Thermal Rating: on transformer 7278-9140 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23
% INFO    : Updated Thermal Rating: on transformer 7278-141 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26
% INFO    : Updated Thermal Rating: on transformer 1550-9140 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 861
% INFO    : Updated Thermal Rating: on transformer 10000-141 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 832
% INFO    : Updated Thermal Rating: on transformer 10000-141 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 983
% INFO    : Updated Thermal Rating: on transformer 3288-4180 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 66
% INFO    : Updated Thermal Rating: on transformer 2382-4180 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 54
% INFO    : Updated Thermal Rating: on transformer 5152-4180 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 54
% INFO    : Updated Thermal Rating: on transformer 5912-11734 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3212
% INFO    : Updated Thermal Rating: on transformer 7454-3986 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 71
% INFO    : Updated Thermal Rating: on transformer 7454-12363 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 74
% INFO    : Updated Thermal Rating: on transformer 2586-3986 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 65
% INFO    : Updated Thermal Rating: on transformer 2586-12363 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 65
% INFO    : Updated Thermal Rating: on transformer 5380-4199 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2738
% INFO    : Updated Thermal Rating: on transformer 7997-5923 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10
% INFO    : Updated Thermal Rating: on transformer 6414-5923 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27
% INFO    : Updated Thermal Rating: on transformer 12406-5923 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 8314-5923 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 9085-5923 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12
% INFO    : Updated Thermal Rating: on transformer 7997-1752 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12
% INFO    : Updated Thermal Rating: on transformer 6414-1752 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 33
% INFO    : Updated Thermal Rating: on transformer 12406-1752 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 8314-1752 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 9085-1752 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12
% INFO    : Updated Thermal Rating: on transformer 7997-644 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 7997-2726 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on transformer 7997-5344 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11
% INFO    : Updated Thermal Rating: on transformer 7997-2264 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on transformer 7997-4342 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 96
% INFO    : Updated Thermal Rating: on transformer 7997-1684 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 99
% INFO    : Updated Thermal Rating: on transformer 5569-6386 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21
% INFO    : Updated Thermal Rating: on transformer 8176-6386 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19
% INFO    : Updated Thermal Rating: on transformer 11812-13629 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on transformer 12474-13629 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on transformer 11732-13629 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 10349-13629 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 12274-13629 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on transformer 1789-13629 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on transformer 2123-4147 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 933
% INFO    : Updated Thermal Rating: on transformer 11812-8267 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5
% INFO    : Updated Thermal Rating: on transformer 12474-8267 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on transformer 11732-8267 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 10349-8267 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 12274-8267 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5
% INFO    : Updated Thermal Rating: on transformer 1789-8267 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 11812-4147 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on transformer 12474-4147 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on transformer 11732-4147 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 10349-4147 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 12274-4147 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5
% INFO    : Updated Thermal Rating: on transformer 1789-4147 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on transformer 7042-359 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1559
% INFO    : Updated Thermal Rating: on transformer 4338-1990 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3146
% INFO    : Updated Thermal Rating: on transformer 6414-644 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on transformer 12406-644 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21
% INFO    : Updated Thermal Rating: on transformer 8314-644 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22
% INFO    : Updated Thermal Rating: on transformer 9085-644 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on transformer 6414-2726 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on transformer 12406-2726 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24
% INFO    : Updated Thermal Rating: on transformer 8314-2726 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25
% INFO    : Updated Thermal Rating: on transformer 9085-2726 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on transformer 10367-4860 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5
% INFO    : Updated Thermal Rating: on transformer 10367-8960 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on transformer 10367-1779 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24
% INFO    : Updated Thermal Rating: on transformer 10367-6012 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52
% INFO    : Updated Thermal Rating: on transformer 9178-4860 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5
% INFO    : Updated Thermal Rating: on transformer 9178-8960 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on transformer 9178-1779 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26
% INFO    : Updated Thermal Rating: on transformer 9178-6012 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 59
% INFO    : Updated Thermal Rating: on transformer 6414-5344 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on transformer 12406-5344 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5
% INFO    : Updated Thermal Rating: on transformer 8314-5344 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on transformer 9085-5344 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11
% INFO    : Updated Thermal Rating: on transformer 11812-11448 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 47
% INFO    : Updated Thermal Rating: on transformer 11812-2359 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 35
% INFO    : Updated Thermal Rating: on transformer 11812-366 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 11812-917 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 11812-4995 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 11812-1535 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52
% INFO    : Updated Thermal Rating: on transformer 11812-5183 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on transformer 11812-7014 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on transformer 11812-12720 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on transformer 11812-7916 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 11812-3743 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 11812-9401 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on transformer 11812-2256 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11
% INFO    : Updated Thermal Rating: on transformer 11812-7691 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 11812-6065 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 12474-11448 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 29
% INFO    : Updated Thermal Rating: on transformer 12474-2359 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 33
% INFO    : Updated Thermal Rating: on transformer 12474-366 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on transformer 12474-1535 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 38
% INFO    : Updated Thermal Rating: on transformer 12474-5183 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 12474-7014 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8
% INFO    : Updated Thermal Rating: on transformer 12474-12720 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9
% INFO    : Updated Thermal Rating: on transformer 12474-7916 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 12474-3743 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 12474-9401 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9
% INFO    : Updated Thermal Rating: on transformer 12474-2256 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8
% INFO    : Updated Thermal Rating: on transformer 12474-1566 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 12474-5754 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 12474-7691 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 12474-6065 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 6414-2264 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13
% INFO    : Updated Thermal Rating: on transformer 6414-4342 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 35
% INFO    : Updated Thermal Rating: on transformer 6414-1684 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 38
% INFO    : Updated Thermal Rating: on transformer 12406-2264 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on transformer 8314-2264 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on transformer 9085-2264 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on transformer 722-10991 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 994
% INFO    : Updated Thermal Rating: on transformer 722-4860 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21
% INFO    : Updated Thermal Rating: on transformer 722-8960 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23
% INFO    : Updated Thermal Rating: on transformer 722-1779 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17
% INFO    : Updated Thermal Rating: on transformer 722-6012 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 72
% INFO    : Updated Thermal Rating: on transformer 11650-9023 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 976
% INFO    : Updated Thermal Rating: on transformer 12406-4342 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 8314-4342 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 9085-4342 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 100
% INFO    : Updated Thermal Rating: on transformer 12406-1684 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 8314-1684 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 9085-1684 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 108
% INFO    : Updated Thermal Rating: on transformer 478-4860 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8
% INFO    : Updated Thermal Rating: on transformer 8529-4860 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16
% INFO    : Updated Thermal Rating: on transformer 5951-4860 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16
% INFO    : Updated Thermal Rating: on transformer 478-8960 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9
% INFO    : Updated Thermal Rating: on transformer 8529-8960 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20
% INFO    : Updated Thermal Rating: on transformer 5951-8960 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20
% INFO    : Updated Thermal Rating: on transformer 91-11448 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on transformer 11732-11448 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17
% INFO    : Updated Thermal Rating: on transformer 10349-11448 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 12274-11448 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 28
% INFO    : Updated Thermal Rating: on transformer 3895-11448 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on transformer 1789-11448 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 91-2359 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on transformer 11732-2359 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14
% INFO    : Updated Thermal Rating: on transformer 10349-2359 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 12274-2359 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 31
% INFO    : Updated Thermal Rating: on transformer 3895-2359 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on transformer 1789-2359 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 478-3932 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 54
% INFO    : Updated Thermal Rating: on transformer 478-1779 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on transformer 478-6012 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on transformer 10349-8608 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 1789-8608 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 10349-4055 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 1789-4055 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 91-366 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 114
% INFO    : Updated Thermal Rating: on transformer 91-1535 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 91-5183 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 91-7014 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 33
% INFO    : Updated Thermal Rating: on transformer 91-12720 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 36
% INFO    : Updated Thermal Rating: on transformer 91-7916 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on transformer 91-3743 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on transformer 91-9401 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on transformer 91-2256 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 91-1566 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 91-5754 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 11732-366 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21
% INFO    : Updated Thermal Rating: on transformer 12274-366 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 3895-366 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26
% INFO    : Updated Thermal Rating: on transformer 1789-366 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on transformer 10349-8156 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 10349-6030 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 6825-6386 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 9567-2772 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2462
% INFO    : Updated Thermal Rating: on transformer 12271-2801 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2659
% INFO    : Updated Thermal Rating: on transformer 10446-917 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 916
% INFO    : Updated Thermal Rating: on transformer 12274-917 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 12274-4995 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 11732-1535 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12
% INFO    : Updated Thermal Rating: on transformer 11732-5183 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 11732-7014 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24
% INFO    : Updated Thermal Rating: on transformer 11732-12720 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25
% INFO    : Updated Thermal Rating: on transformer 11732-7916 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 11732-3743 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 11732-9401 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18
% INFO    : Updated Thermal Rating: on transformer 11732-2256 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on transformer 11732-1566 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on transformer 11732-5754 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on transformer 9492-6495 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1201
% INFO    : Updated Thermal Rating: on transformer 9492-9067 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1228
% INFO    : Updated Thermal Rating: on transformer 10349-12043 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on transformer 1789-12043 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 10349-9823 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10
% INFO    : Updated Thermal Rating: on transformer 1789-9823 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 10349-6896 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 74
% INFO    : Updated Thermal Rating: on transformer 10349-10979 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 76
% INFO    : Updated Thermal Rating: on transformer 10349-5183 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24
% INFO    : Updated Thermal Rating: on transformer 10349-7916 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16
% INFO    : Updated Thermal Rating: on transformer 10349-3743 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16
% INFO    : Updated Thermal Rating: on transformer 10349-4717 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15
% INFO    : Updated Thermal Rating: on transformer 10349-2256 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on transformer 10349-7691 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 10349-6065 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 7108-10979 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 828
% INFO    : Updated Thermal Rating: on transformer 7108-6896 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 885
% INFO    : Updated Thermal Rating: on transformer 1789-6896 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10
% INFO    : Updated Thermal Rating: on transformer 1789-10979 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10
% INFO    : Updated Thermal Rating: on transformer 12274-1535 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 135
% INFO    : Updated Thermal Rating: on transformer 12274-5183 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 12274-7014 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on transformer 12274-12720 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on transformer 12274-7916 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 12274-3743 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 12274-9401 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 12274-2256 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8
% INFO    : Updated Thermal Rating: on transformer 12274-7691 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 12274-6065 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 12274-1535 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 999
% INFO    : Updated Thermal Rating: on transformer 3895-1535 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on transformer 1789-1535 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 3895-5183 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 1789-5183 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 34
% INFO    : Updated Thermal Rating: on transformer 6656-7014 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1076
% INFO    : Updated Thermal Rating: on transformer 3895-7014 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 113
% INFO    : Updated Thermal Rating: on transformer 3895-12720 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 133
% INFO    : Updated Thermal Rating: on transformer 3895-7916 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 3895-3743 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 3895-9401 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9
% INFO    : Updated Thermal Rating: on transformer 3895-2256 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 3895-1566 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 3895-5754 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 1789-7014 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 1789-12720 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 1789-7916 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1044
% INFO    : Updated Thermal Rating: on transformer 1789-7916 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 77
% INFO    : Updated Thermal Rating: on transformer 1789-3743 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 78
% INFO    : Updated Thermal Rating: on transformer 1789-4717 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 1789-2256 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11
% INFO    : Updated Thermal Rating: on transformer 1789-7691 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 1789-6065 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 9085-12614 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 592
% INFO    : Updated Thermal Rating: on transformer 8529-1779 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on transformer 5951-1779 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on transformer 8529-6012 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12
% INFO    : Updated Thermal Rating: on transformer 5951-6012 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13
% INFO    : Updated Thermal Rating: on transformer 10957-13306 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1903
% INFO    : Updated Thermal Rating: on transformer 10957-6386 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15
% INFO    : Updated Thermal Rating: on transformer 12058-3119 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 995
% INFO    : Updated Thermal Rating: on transformer 12058-3119 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 860
% INFO    : Updated Thermal Rating: on transformer 3043-5297 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 256
% INFO    : Updated Thermal Rating: on transformer 3635-5297 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 990
% INFO    : Updated Thermal Rating: on transformer 2376-4127 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 36
% INFO    : Updated Thermal Rating: on transformer 2354-4127 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5
% INFO    : Updated Thermal Rating: on transformer 7451-4127 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12
% INFO    : Updated Thermal Rating: on transformer 2265-4127 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11
% INFO    : Updated Thermal Rating: on transformer 12109-4127 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 48
% INFO    : Updated Thermal Rating: on transformer 2376-9057 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 29
% INFO    : Updated Thermal Rating: on transformer 9661-11453 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 64
% INFO    : Updated Thermal Rating: on transformer 10358-80 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20
% INFO    : Updated Thermal Rating: on transformer 3462-7437 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 541
% INFO    : Updated Thermal Rating: on transformer 3462-7437 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 531
% INFO    : Updated Thermal Rating: on transformer 2376-5802 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1898
% INFO    : Updated Thermal Rating: on transformer 2376-587 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 120
% INFO    : Updated Thermal Rating: on transformer 2376-7275 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 81
% INFO    : Updated Thermal Rating: on transformer 2376-1611 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 115
% INFO    : Updated Thermal Rating: on transformer 2376-587 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2063
% INFO    : Updated Thermal Rating: on transformer 2376-13460 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2107
% INFO    : Updated Thermal Rating: on transformer 6804-2393 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 81
% INFO    : Updated Thermal Rating: on transformer 6804-5190 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 75
% INFO    : Updated Thermal Rating: on transformer 10358-2314 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1666
% INFO    : Updated Thermal Rating: on transformer 10358-2314 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 147
% INFO    : Updated Thermal Rating: on transformer 10358-12360 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 31
% INFO    : Updated Thermal Rating: on transformer 10358-13555 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 61
% INFO    : Updated Thermal Rating: on transformer 5633-3742 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 34
% INFO    : Updated Thermal Rating: on transformer 1025-3742 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 97
% INFO    : Updated Thermal Rating: on transformer 3417-3742 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 53
% INFO    : Updated Thermal Rating: on transformer 9661-6301 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 35
% INFO    : Updated Thermal Rating: on transformer 9661-3085 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 37
% INFO    : Updated Thermal Rating: on transformer 2354-3879 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13
% INFO    : Updated Thermal Rating: on transformer 2354-8543 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on transformer 4172-2393 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 71
% INFO    : Updated Thermal Rating: on transformer 11636-3742 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 37
% INFO    : Updated Thermal Rating: on transformer 2948-3742 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 38
% INFO    : Updated Thermal Rating: on transformer 10879-3742 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10
% INFO    : Updated Thermal Rating: on transformer 9048-3742 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19
% INFO    : Updated Thermal Rating: on transformer 7451-3879 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 34
% INFO    : Updated Thermal Rating: on transformer 7451-8543 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14
% INFO    : Updated Thermal Rating: on transformer 2265-3879 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 30
% INFO    : Updated Thermal Rating: on transformer 2265-8543 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12
% INFO    : Updated Thermal Rating: on transformer 1620-11840 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1989
% INFO    : Updated Thermal Rating: on transformer 11151-1910 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1079
% INFO    : Updated Thermal Rating: on transformer 6796-8189 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 85
% INFO    : Updated Thermal Rating: on transformer 3026-8189 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 87
% INFO    : Updated Thermal Rating: on transformer 4172-8189 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 97
% INFO    : Updated Thermal Rating: on transformer 9156-8189 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 69
% INFO    : Updated Thermal Rating: on transformer 2843-13196 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 900
% INFO    : Updated Thermal Rating: on transformer 2843-2600 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1818
% INFO    : Updated Thermal Rating: on transformer 4172-5190 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 567
% INFO    : Updated Thermal Rating: on transformer 9661-3817 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 41
% INFO    : Updated Thermal Rating: on transformer 9661-7035 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26
% INFO    : Updated Thermal Rating: on transformer 9661-11123 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26
% INFO    : Updated Thermal Rating: on transformer 9156-584 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 651
% INFO    : Updated Thermal Rating: on transformer 1894-234 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3066
% INFO    : Updated Thermal Rating: on transformer 1894-2319 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 831
% INFO    : Updated Thermal Rating: on transformer 1894-2319 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 849
% INFO    : Updated Thermal Rating: on transformer 12109-3879 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 127
% INFO    : Updated Thermal Rating: on transformer 12109-8543 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 51
% INFO    : Updated Thermal Rating: on transformer 12918-7095 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 41
% INFO    : Updated Thermal Rating: on transformer 5993-7095 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 42
% INFO    : Updated Thermal Rating: on transformer 10087-7095 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9
% INFO    : Updated Thermal Rating: on transformer 8361-7095 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13
% INFO    : Updated Thermal Rating: on transformer 9091-4168 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 48
% INFO    : Updated Thermal Rating: on transformer 5557-9394 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24
% INFO    : Updated Thermal Rating: on transformer 3447-9394 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 83
% INFO    : Updated Thermal Rating: on transformer 3260-9394 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 76
% INFO    : Updated Thermal Rating: on transformer 6117-10372 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 42
% INFO    : Updated Thermal Rating: on transformer 8691-10372 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 42
% INFO    : Updated Thermal Rating: on transformer 2728-10372 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 108
% INFO    : Updated Thermal Rating: on transformer 4506-11358 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8
% INFO    : Updated Thermal Rating: on transformer 13547-11358 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 64
% INFO    : Updated Thermal Rating: on transformer 1649-3636 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23
% INFO    : Updated Thermal Rating: on transformer 10400-3636 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 36
% INFO    : Updated Thermal Rating: on transformer 1983-11136 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 133
% INFO    : Updated Thermal Rating: on transformer 1983-7018 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 37
% INFO    : Updated Thermal Rating: on transformer 12051-11136 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 50
% INFO    : Updated Thermal Rating: on transformer 12051-7018 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 86
% INFO    : Updated Thermal Rating: on transformer 4556-4168 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 35
% INFO    : Updated Thermal Rating: on transformer 1723-4168 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 71
% INFO    : Updated Thermal Rating: on transformer 1771-4168 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 39
% INFO    : Updated Thermal Rating: on transformer 7818-4168 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 64
% INFO    : Updated Thermal Rating: on transformer 7012-4168 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 53
% INFO    : Updated Thermal Rating: on transformer 8784-4168 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18
% INFO    : Updated Thermal Rating: on transformer 10047-4168 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18
% INFO    : Updated Thermal Rating: on transformer 7835-6099 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 89
% INFO    : Updated Thermal Rating: on transformer 10846-7216 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 100
% INFO    : Updated Thermal Rating: on transformer 5557-228 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 114
% INFO    : Updated Thermal Rating: on transformer 3447-228 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 28
% INFO    : Updated Thermal Rating: on transformer 3260-228 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 32
% INFO    : Updated Thermal Rating: on transformer 5557-6735 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 87
% INFO    : Updated Thermal Rating: on transformer 8870-6735 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52
% INFO    : Updated Thermal Rating: on transformer 3447-6735 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 28
% INFO    : Updated Thermal Rating: on transformer 3260-6735 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 31
% INFO    : Updated Thermal Rating: on transformer 4570-6735 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 43
% INFO    : Updated Thermal Rating: on transformer 4506-12086 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1064
% INFO    : Updated Thermal Rating: on transformer 4506-10015 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 211
% INFO    : Updated Thermal Rating: on transformer 4506-10015 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 904
% INFO    : Updated Thermal Rating: on transformer 4506-10225 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 62
% INFO    : Updated Thermal Rating: on transformer 9468-3227 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 921
% INFO    : Updated Thermal Rating: on transformer 5993-13243 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1352
% INFO    : Updated Thermal Rating: on transformer 12918-7494 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 143
% INFO    : Updated Thermal Rating: on transformer 5993-7494 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 126
% INFO    : Updated Thermal Rating: on transformer 1649-7018 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 33
% INFO    : Updated Thermal Rating: on transformer 1649-13016 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10
% INFO    : Updated Thermal Rating: on transformer 1649-2365 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 147
% INFO    : Updated Thermal Rating: on transformer 10904-6104 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 72
% INFO    : Updated Thermal Rating: on transformer 8870-6104 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 32
% INFO    : Updated Thermal Rating: on transformer 10904-12768 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 68
% INFO    : Updated Thermal Rating: on transformer 10904-9268 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 30
% INFO    : Updated Thermal Rating: on transformer 10904-5095 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18
% INFO    : Updated Thermal Rating: on transformer 10904-7630 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16
% INFO    : Updated Thermal Rating: on transformer 10904-12875 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 37
% INFO    : Updated Thermal Rating: on transformer 10904-5550 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15
% INFO    : Updated Thermal Rating: on transformer 10904-5687 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16
% INFO    : Updated Thermal Rating: on transformer 10904-11156 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17
% INFO    : Updated Thermal Rating: on transformer 4685-10914 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 53
% INFO    : Updated Thermal Rating: on transformer 12475-10914 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 879
% INFO    : Updated Thermal Rating: on transformer 9641-10914 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 96
% INFO    : Updated Thermal Rating: on transformer 1149-10914 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 85
% INFO    : Updated Thermal Rating: on transformer 6597-10914 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 83
% INFO    : Updated Thermal Rating: on transformer 10087-7494 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 28
% INFO    : Updated Thermal Rating: on transformer 8361-7494 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 38
% INFO    : Updated Thermal Rating: on transformer 3566-3503 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 110
% INFO    : Updated Thermal Rating: on transformer 6522-462 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18
% INFO    : Updated Thermal Rating: on transformer 3081-462 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on transformer 2602-462 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52
% INFO    : Updated Thermal Rating: on transformer 5257-462 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on transformer 10026-462 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 34
% INFO    : Updated Thermal Rating: on transformer 2201-239 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 921
% INFO    : Updated Thermal Rating: on transformer 13547-239 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 146
% INFO    : Updated Thermal Rating: on transformer 8870-12768 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21
% INFO    : Updated Thermal Rating: on transformer 8870-1246 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 38
% INFO    : Updated Thermal Rating: on transformer 4570-1246 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15
% INFO    : Updated Thermal Rating: on transformer 1872-6099 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 91
% INFO    : Updated Thermal Rating: on transformer 5394-6099 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 85
% INFO    : Updated Thermal Rating: on transformer 9641-9245 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 91
% INFO    : Updated Thermal Rating: on transformer 1149-9245 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 98
% INFO    : Updated Thermal Rating: on transformer 6597-9245 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 57
% INFO    : Updated Thermal Rating: on transformer 1723-8592 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1010
% INFO    : Updated Thermal Rating: on transformer 6522-8592 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14
% INFO    : Updated Thermal Rating: on transformer 3081-8592 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8
% INFO    : Updated Thermal Rating: on transformer 2602-8592 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18
% INFO    : Updated Thermal Rating: on transformer 5257-8592 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on transformer 10026-8592 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 32
% INFO    : Updated Thermal Rating: on transformer 8870-10093 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 51
% INFO    : Updated Thermal Rating: on transformer 4570-10093 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22
% INFO    : Updated Thermal Rating: on transformer 6522-8936 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 82
% INFO    : Updated Thermal Rating: on transformer 3081-8936 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5
% INFO    : Updated Thermal Rating: on transformer 2602-8936 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 29
% INFO    : Updated Thermal Rating: on transformer 5257-8936 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on transformer 10026-8936 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23
% INFO    : Updated Thermal Rating: on transformer 12854-6522 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11951
% INFO    : Updated Thermal Rating: on transformer 6522-7527 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on transformer 6522-11961 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20
% INFO    : Updated Thermal Rating: on transformer 6522-3731 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17
% INFO    : Updated Thermal Rating: on transformer 6522-12457 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16
% INFO    : Updated Thermal Rating: on transformer 3081-7527 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 123
% INFO    : Updated Thermal Rating: on transformer 3081-7527 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 947
% INFO    : Updated Thermal Rating: on transformer 2602-7527 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3
% INFO    : Updated Thermal Rating: on transformer 5257-7527 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 55
% INFO    : Updated Thermal Rating: on transformer 10026-7527 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20
% INFO    : Updated Thermal Rating: on transformer 3081-11961 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 3081-3731 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2
% INFO    : Updated Thermal Rating: on transformer 3081-12457 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15
% INFO    : Updated Thermal Rating: on transformer 1179-9396 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 212
% INFO    : Updated Thermal Rating: on transformer 8361-9396 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 99
% INFO    : Updated Thermal Rating: on transformer 10846-9396 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 60
% INFO    : Updated Thermal Rating: on transformer 6598-8996 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16
% INFO    : Updated Thermal Rating: on transformer 13441-8996 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14
% INFO    : Updated Thermal Rating: on transformer 12362-8996 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 38
% INFO    : Updated Thermal Rating: on transformer 1820-3742 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 133
% INFO    : Updated Thermal Rating: on transformer 1820-3742 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1835
% INFO    : Updated Thermal Rating: on transformer 1820-185 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 109
% INFO    : Updated Thermal Rating: on transformer 10196-12543 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 139
% INFO    : Updated Thermal Rating: on transformer 6598-4735 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 47
% INFO    : Updated Thermal Rating: on transformer 13441-4735 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 42
% INFO    : Updated Thermal Rating: on transformer 12362-4735 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24
% INFO    : Updated Thermal Rating: on transformer 6598-444 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 32
% INFO    : Updated Thermal Rating: on transformer 13441-444 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27
% INFO    : Updated Thermal Rating: on transformer 12362-444 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 142
% INFO    : Updated Thermal Rating: on transformer 12850-11860 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 38
% INFO    : Updated Thermal Rating: on transformer 2525-11860 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18
% INFO    : Updated Thermal Rating: on transformer 909-11860 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22
% INFO    : Updated Thermal Rating: on transformer 2114-11860 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 50
% INFO    : Updated Thermal Rating: on transformer 6916-11860 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23
% INFO    : Updated Thermal Rating: on transformer 1149-10055 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 78
% INFO    : Updated Thermal Rating: on transformer 1149-10493 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 82
% INFO    : Updated Thermal Rating: on transformer 10196-2779 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24
% INFO    : Updated Thermal Rating: on transformer 854-8044 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 34
% INFO    : Updated Thermal Rating: on transformer 854-3171 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23
% INFO    : Updated Thermal Rating: on transformer 13539-6637 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 46
% INFO    : Updated Thermal Rating: on transformer 11674-6637 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 37
% INFO    : Updated Thermal Rating: on transformer 13539-2431 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 50
% INFO    : Updated Thermal Rating: on transformer 11674-2431 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 38
% INFO    : Updated Thermal Rating: on transformer 2602-3731 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1003
% INFO    : Updated Thermal Rating: on transformer 2602-11961 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 102
% INFO    : Updated Thermal Rating: on transformer 2602-3731 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 78
% INFO    : Updated Thermal Rating: on transformer 2602-12457 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10
% INFO    : Updated Thermal Rating: on transformer 5257-11961 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 10026-11961 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10
% INFO    : Updated Thermal Rating: on transformer 5257-3731 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1
% INFO    : Updated Thermal Rating: on transformer 10026-3731 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10
% INFO    : Updated Thermal Rating: on transformer 10846-793 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 78
% INFO    : Updated Thermal Rating: on transformer 12850-8677 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27
% INFO    : Updated Thermal Rating: on transformer 12850-9658 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 90
% INFO    : Updated Thermal Rating: on transformer 12850-1626 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16
% INFO    : Updated Thermal Rating: on transformer 2525-8677 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 38
% INFO    : Updated Thermal Rating: on transformer 2525-9658 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25
% INFO    : Updated Thermal Rating: on transformer 2525-1626 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 54
% INFO    : Updated Thermal Rating: on transformer 5784-8044 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52
% INFO    : Updated Thermal Rating: on transformer 5784-10203 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 53
% INFO    : Updated Thermal Rating: on transformer 3229-8044 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23
% INFO    : Updated Thermal Rating: on transformer 3229-3171 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16
% INFO    : Updated Thermal Rating: on transformer 6598-6259 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 103
% INFO    : Updated Thermal Rating: on transformer 13441-6259 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 86
% INFO    : Updated Thermal Rating: on transformer 12362-6259 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 114
% INFO    : Updated Thermal Rating: on transformer 5257-12457 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9
% INFO    : Updated Thermal Rating: on transformer 4685-4749 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 63
% INFO    : Updated Thermal Rating: on transformer 13539-996 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 45
% INFO    : Updated Thermal Rating: on transformer 13539-10794 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 35
% INFO    : Updated Thermal Rating: on transformer 13539-6683 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 35
% INFO    : Updated Thermal Rating: on transformer 490-8044 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 48
% INFO    : Updated Thermal Rating: on transformer 680-8044 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 50
% INFO    : Updated Thermal Rating: on transformer 148-8044 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 50
% INFO    : Updated Thermal Rating: on transformer 9278-8044 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 51
% INFO    : Updated Thermal Rating: on transformer 909-8677 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23
% INFO    : Updated Thermal Rating: on transformer 909-9658 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52
% INFO    : Updated Thermal Rating: on transformer 909-1626 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16
% INFO    : Updated Thermal Rating: on transformer 2114-8677 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 32
% INFO    : Updated Thermal Rating: on transformer 6916-8677 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 76
% INFO    : Updated Thermal Rating: on transformer 10196-6981 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 78
% INFO    : Updated Thermal Rating: on transformer 10026-12457 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 78
% INFO    : Updated Thermal Rating: on transformer 8870-9268 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 70
% INFO    : Updated Thermal Rating: on transformer 4685-9268 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 111
% INFO    : Updated Thermal Rating: on transformer 118-10055 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 79
% INFO    : Updated Thermal Rating: on transformer 118-10493 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 72
% INFO    : Updated Thermal Rating: on transformer 8870-3748 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18
% INFO    : Updated Thermal Rating: on transformer 4570-3748 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 110
% INFO    : Updated Thermal Rating: on transformer 9487-5095 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1176
% INFO    : Updated Thermal Rating: on transformer 8870-5095 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5
% INFO    : Updated Thermal Rating: on transformer 7990-8260 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1106
% INFO    : Updated Thermal Rating: on transformer 7990-8260 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1129
% INFO    : Updated Thermal Rating: on transformer 8616-8260 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 105
% INFO    : Updated Thermal Rating: on transformer 6117-12560 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 65
% INFO    : Updated Thermal Rating: on transformer 6117-11208 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 81
% INFO    : Updated Thermal Rating: on transformer 8691-12560 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 58
% INFO    : Updated Thermal Rating: on transformer 8691-11208 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 66
% INFO    : Updated Thermal Rating: on transformer 2114-9658 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 130
% INFO    : Updated Thermal Rating: on transformer 2114-9658 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1906
% INFO    : Updated Thermal Rating: on transformer 6916-9658 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13
% INFO    : Updated Thermal Rating: on transformer 2114-1626 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14
% INFO    : Updated Thermal Rating: on transformer 2728-12560 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 65
% INFO    : Updated Thermal Rating: on transformer 2728-12560 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 921
% INFO    : Updated Thermal Rating: on transformer 2728-11208 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 36
% INFO    : Updated Thermal Rating: on transformer 8870-7630 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5
% INFO    : Updated Thermal Rating: on transformer 8870-12875 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 90
% INFO    : Updated Thermal Rating: on transformer 8870-5550 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on transformer 8870-5687 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5
% INFO    : Updated Thermal Rating: on transformer 8870-11156 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5
% INFO    : Updated Thermal Rating: on transformer 8616-3171 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 107
% INFO    : Updated Thermal Rating: on transformer 4570-4305 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1909
% INFO    : Updated Thermal Rating: on transformer 10400-7018 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 80
% INFO    : Updated Thermal Rating: on transformer 11674-996 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 38
% INFO    : Updated Thermal Rating: on transformer 10846-996 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 57
% INFO    : Updated Thermal Rating: on transformer 10846-5661 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 57
% INFO    : Updated Thermal Rating: on transformer 10400-13016 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20
% INFO    : Updated Thermal Rating: on transformer 9013-4956 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1237
% INFO    : Updated Thermal Rating: on transformer 6597-10055 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 68
% INFO    : Updated Thermal Rating: on transformer 6597-10493 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 69
% INFO    : Updated Thermal Rating: on transformer 13547-12769 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 73
% INFO    : Updated Thermal Rating: on transformer 13547-8118 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 74
% INFO    : Updated Thermal Rating: on transformer 490-10203 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 45
% INFO    : Updated Thermal Rating: on transformer 680-10203 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 46
% INFO    : Updated Thermal Rating: on transformer 13171-7609 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1155
% INFO    : Updated Thermal Rating: on transformer 13547-7766 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1565
% INFO    : Updated Thermal Rating: on transformer 11674-10794 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 50
% INFO    : Updated Thermal Rating: on transformer 11674-6683 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 51
% INFO    : Updated Thermal Rating: on transformer 10400-2365 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 77
% INFO    : Updated Thermal Rating: on transformer 10400-2365 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1753
% INFO    : Updated Thermal Rating: on transformer 10400-9625 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1846
% INFO    : Updated Thermal Rating: on transformer 11436-11156 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1279
% INFO    : Updated Thermal Rating: on transformer 11436-11156 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1322
% INFO    : Updated Thermal Rating: on transformer 6916-1626 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 163
% INFO    : Updated Thermal Rating: on transformer 6598-2128 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1371
% INFO    : Updated Thermal Rating: on transformer 12362-2536 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1020
% INFO    : Updated Thermal Rating: on transformer 148-3171 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 31
% INFO    : Updated Thermal Rating: on transformer 9278-3171 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 31
% INFO    : Updated Thermal Rating: on transformer 9278-568 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1174
% INFO    : Updated Thermal Rating: on transformer 12987-12396 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18
% INFO    : Updated Thermal Rating: on transformer 12987-9924 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20
% INFO    : Updated Thermal Rating: on transformer 6850-10235 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1056
% INFO    : Updated Thermal Rating: on transformer 6850-10235 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1078
% INFO    : Updated Thermal Rating: on transformer 2716-13230 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 172
% INFO    : Updated Thermal Rating: on transformer 2716-4092 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 34
% INFO    : Updated Thermal Rating: on transformer 2716-645 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 36
% INFO    : Updated Thermal Rating: on transformer 2716-712 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16
% INFO    : Updated Thermal Rating: on transformer 748-13230 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 50
% INFO    : Updated Thermal Rating: on transformer 2684-13230 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 32
% INFO    : Updated Thermal Rating: on transformer 795-12063 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 68
% INFO    : Updated Thermal Rating: on transformer 10162-12063 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 74
% INFO    : Updated Thermal Rating: on transformer 7574-9680 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 78
% INFO    : Updated Thermal Rating: on transformer 7574-6056 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14
% INFO    : Updated Thermal Rating: on transformer 9460-9680 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 81
% INFO    : Updated Thermal Rating: on transformer 9460-6056 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14
% INFO    : Updated Thermal Rating: on transformer 12151-12396 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 38
% INFO    : Updated Thermal Rating: on transformer 12151-9924 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 65
% INFO    : Updated Thermal Rating: on transformer 3115-2049 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1029
% INFO    : Updated Thermal Rating: on transformer 3115-11366 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 249
% INFO    : Updated Thermal Rating: on transformer 6458-3921 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 54
% INFO    : Updated Thermal Rating: on transformer 9450-4092 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 76
% INFO    : Updated Thermal Rating: on transformer 748-4092 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1566
% INFO    : Updated Thermal Rating: on transformer 748-4092 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 748-645 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14
% INFO    : Updated Thermal Rating: on transformer 748-712 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 44
% INFO    : Updated Thermal Rating: on transformer 6457-4092 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12
% INFO    : Updated Thermal Rating: on transformer 2684-4092 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12
% INFO    : Updated Thermal Rating: on transformer 2684-645 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 187
% INFO    : Updated Thermal Rating: on transformer 6458-5521 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 269
% INFO    : Updated Thermal Rating: on transformer 11659-9680 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1379
% INFO    : Updated Thermal Rating: on transformer 11659-9680 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1413
% INFO    : Updated Thermal Rating: on transformer 6973-277 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 163
% INFO    : Updated Thermal Rating: on transformer 2684-712 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 168
% INFO    : Updated Thermal Rating: on transformer 8715-11366 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 120
% INFO    : Updated Thermal Rating: on transformer 6933-8132 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 834
% INFO    : Updated Thermal Rating: on transformer 4218-8132 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 853
% INFO    : Updated Thermal Rating: on transformer 6973-11046 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2081
% INFO    : Updated Thermal Rating: on transformer 6973-11046 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 127
% INFO    : Updated Thermal Rating: on transformer 6973-11046 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2097
% INFO    : Updated Thermal Rating: on transformer 795-11046 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 61
% INFO    : Updated Thermal Rating: on transformer 10162-11046 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 66
% INFO    : Updated Thermal Rating: on transformer 6458-4615 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 59
% INFO    : Updated Thermal Rating: on transformer 5273-313 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 251
% INFO    : Updated Thermal Rating: on transformer 5273-313 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 945
% INFO    : Updated Thermal Rating: on transformer 284-313 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 157
% INFO    : Updated Thermal Rating: on transformer 3291-12396 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2318
% INFO    : Updated Thermal Rating: on transformer 3291-12396 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 104
% INFO    : Updated Thermal Rating: on transformer 3291-9924 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 53
% INFO    : Updated Thermal Rating: on transformer 739-12396 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2410
% INFO    : Updated Thermal Rating: on transformer 739-12396 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 98
% INFO    : Updated Thermal Rating: on transformer 739-9924 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 56
% INFO    : Updated Thermal Rating: on transformer 2509-10997 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 223
% INFO    : Updated Thermal Rating: on transformer 6595-4615 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3278
% INFO    : Updated Thermal Rating: on transformer 6595-4615 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3348
% INFO    : Updated Thermal Rating: on transformer 284-1224 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1381
% INFO    : Updated Thermal Rating: on transformer 284-1224 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1219
% INFO    : Updated Thermal Rating: on transformer 11275-6442 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 310
% INFO    : Updated Thermal Rating: on transformer 11275-6442 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 304
% INFO    : Updated Thermal Rating: on transformer 11518-12899 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 219
% INFO    : Updated Thermal Rating: on transformer 9006-3632 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 245
% INFO    : Updated Thermal Rating: on transformer 9006-3632 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 250
% INFO    : Updated Thermal Rating: on transformer 6702-8295 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 336
% INFO    : Updated Thermal Rating: on transformer 6702-8295 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 343
% INFO    : Updated Thermal Rating: on transformer 5740-6625 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 202
% INFO    : Updated Thermal Rating: on transformer 5740-2262 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 206
% INFO    : Updated Thermal Rating: on transformer 1615-8420 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 572
% INFO    : Updated Thermal Rating: on transformer 8161-11298 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1171
% INFO    : Updated Thermal Rating: on transformer 9727-9494 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1147
% INFO    : Updated Thermal Rating: on transformer 2337-6209 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 578
% INFO    : Updated Thermal Rating: on transformer 2337-6209 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 570
% INFO    : Updated Thermal Rating: on transformer 9493-12719 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 574
% INFO    : Updated Thermal Rating: on transformer 10869-2932 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1229
% INFO    : Updated Thermal Rating: on transformer 10869-2932 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1286
% INFO    : Updated Thermal Rating: on transformer 7387-2932 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2368
% INFO    : Updated Thermal Rating: on transformer 428-10739 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 648
% INFO    : Updated Thermal Rating: on transformer 6191-3261 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 615
% INFO    : Updated Thermal Rating: on transformer 6191-3261 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 692
% INFO    : Updated Thermal Rating: on transformer 7978-11053 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 605
% INFO    : Updated Thermal Rating: on transformer 9500-2391 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 600
% INFO    : Updated Thermal Rating: on transformer 5173-327 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1464
% INFO    : Updated Thermal Rating: on transformer 7453-12066 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1205
% INFO    : Updated Thermal Rating: on transformer 8871-6744 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 670
% INFO    : Updated Thermal Rating: on transformer 6230-3205 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1737
% INFO    : Updated Thermal Rating: on transformer 6915-8410 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1091
% INFO    : Updated Thermal Rating: on transformer 7896-10888 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1898
% INFO    : Updated Thermal Rating: on transformer 7896-10888 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1622
% INFO    : Updated Thermal Rating: on transformer 1388-5387 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 755
% INFO    : Updated Thermal Rating: on transformer 1388-5387 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1242
% INFO    : Updated Thermal Rating: on transformer 10105-7259 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1521
% INFO    : Updated Thermal Rating: on transformer 4268-10628 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 649
% INFO    : Updated Thermal Rating: on transformer 4268-10628 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1280
% INFO    : Updated Thermal Rating: on transformer 6662-10992 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1541
% INFO    : Updated Thermal Rating: on transformer 6662-10992 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1303
% INFO    : Updated Thermal Rating: on transformer 2214-4789 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1231
% INFO    : Updated Thermal Rating: on transformer 2214-4789 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1203
% INFO    : Updated Thermal Rating: on transformer 2214-4789 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1111
% INFO    : Updated Thermal Rating: on transformer 1709-5206 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1579
% INFO    : Updated Thermal Rating: on transformer 9891-7037 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1030
% INFO    : Updated Thermal Rating: on transformer 1567-9431 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1473
% INFO    : Updated Thermal Rating: on transformer 1567-9431 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1591
% INFO    : Updated Thermal Rating: on transformer 13545-9509 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1640
% INFO    : Updated Thermal Rating: on transformer 13545-9509 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1706
% INFO    : Updated Thermal Rating: on transformer 8272-4929 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1743
% INFO    : Updated Thermal Rating: on transformer 1009-10220 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1685
% INFO    : Updated Thermal Rating: on transformer 1009-10220 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1919
% INFO    : Updated Thermal Rating: on transformer 6340-5358 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1282
% INFO    : Updated Thermal Rating: on transformer 6340-5358 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1258
% INFO    : Updated Thermal Rating: on line 11828-5909 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5702
% INFO    : Updated Thermal Rating: on transformer 2829-1460 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6524
% INFO    : Updated Thermal Rating: on transformer 701-9886 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1899
% INFO    : Updated Thermal Rating: on transformer 701-9886 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1855
% INFO    : Updated Thermal Rating: on transformer 701-9886 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1895
% INFO    : Updated Thermal Rating: on transformer 5878-4948 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1717
% INFO    : Updated Thermal Rating: on transformer 4412-1018 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1157
% INFO    : Updated Thermal Rating: on transformer 4412-1018 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 844
% INFO    : Updated Thermal Rating: on transformer 8475-10394 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 931
% INFO    : Updated Thermal Rating: on transformer 8475-10394 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1358
% INFO    : Updated Thermal Rating: on transformer 2059-10394 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17465
% INFO    : Updated Thermal Rating: on transformer 2775-6324 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1863
% INFO    : Updated Thermal Rating: on transformer 10704-631 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1678
% INFO    : Updated Thermal Rating: on transformer 8800-11725 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1710
% INFO    : Updated Thermal Rating: on transformer 8800-11725 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 993
% INFO    : Updated Thermal Rating: on transformer 1524-13279 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1861
% INFO    : Updated Thermal Rating: on transformer 11828-2503 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1579
% INFO    : Updated Thermal Rating: on transformer 1068-1975 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 956
% INFO    : Updated Thermal Rating: on transformer 6365-12553 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1114
% INFO    : Updated Thermal Rating: on transformer 5002-2036 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1436
% INFO    : Updated Thermal Rating: on transformer 3905-13349 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1565
% INFO    : Updated Thermal Rating: on transformer 3905-13349 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1556
% INFO    : Updated Thermal Rating: on transformer 10840-7911 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1036
% INFO    : Updated Thermal Rating: on transformer 10840-7911 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1076
% INFO    : Updated Thermal Rating: on transformer 3492-5566 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1628
% INFO    : Updated Thermal Rating: on transformer 3492-5566 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1436
% INFO    : Updated Thermal Rating: on transformer 7640-3189 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 912
% INFO    : Updated Thermal Rating: on transformer 8556-11983 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 897
% INFO    : Updated Thermal Rating: on transformer 8556-11983 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1002
% INFO    : Updated Thermal Rating: on transformer 8556-11983 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1507
% INFO    : Updated Thermal Rating: on transformer 205-1755 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1187
% INFO    : Updated Thermal Rating: on transformer 205-1755 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1211
% INFO    : Updated Thermal Rating: on transformer 1512-9362 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1776
% INFO    : Updated Thermal Rating: on transformer 5568-1147 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1743
% INFO    : Updated Thermal Rating: on transformer 2052-6733 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1291
% INFO    : Updated Thermal Rating: on transformer 2052-6733 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1138
% INFO    : Updated Thermal Rating: on transformer 1203-5642 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 993
% INFO    : Updated Thermal Rating: on transformer 1203-5642 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1310
% INFO    : Updated Thermal Rating: on transformer 8622-13135 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1399
% INFO    : Updated Thermal Rating: on transformer 8622-13135 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1605
% INFO    : Updated Thermal Rating: on transformer 8622-13135 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1582
% INFO    : Updated Thermal Rating: on transformer 1673-3846 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1682
% INFO    : Updated Thermal Rating: on transformer 1673-3846 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1718
% INFO    : Updated Thermal Rating: on transformer 4779-9114 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1678
% INFO    : Updated Thermal Rating: on transformer 5573-1612 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 726
% INFO    : Updated Thermal Rating: on transformer 11083-4466 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1684
% INFO    : Updated Thermal Rating: on transformer 11083-4466 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1645
% INFO    : Updated Thermal Rating: on transformer 11083-4466 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1621
% INFO    : Updated Thermal Rating: on transformer 9773-11466 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1489
% INFO    : Updated Thermal Rating: on transformer 9773-11466 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 821
% INFO    : Updated Thermal Rating: on transformer 3230-6177 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1553
% INFO    : Updated Thermal Rating: on transformer 1060-5766 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1002
% INFO    : Updated Thermal Rating: on transformer 1060-5766 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1015
% INFO    : Updated Thermal Rating: on transformer 1060-5766 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1264
% INFO    : Updated Thermal Rating: on transformer 3958-608 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1161
% INFO    : Updated Thermal Rating: on transformer 3958-608 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1025
% INFO    : Updated Thermal Rating: on transformer 449-1334 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1520
% INFO    : Updated Thermal Rating: on transformer 449-1334 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1491
% INFO    : Updated Thermal Rating: on transformer 9878-40 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1020
% INFO    : Updated Thermal Rating: on transformer 4332-8256 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1522
% INFO    : Updated Thermal Rating: on transformer 257-2633 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 830
% INFO    : Updated Thermal Rating: on transformer 12754-4323 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1678
% INFO    : Updated Thermal Rating: on transformer 12754-116 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1713
% INFO    : Updated Thermal Rating: on transformer 10272-41 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1856
% INFO    : Updated Thermal Rating: on transformer 10272-41 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1898
% INFO    : Updated Thermal Rating: on transformer 9663-340 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 671
% INFO    : Updated Thermal Rating: on transformer 9663-340 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 658
% INFO    : Updated Thermal Rating: on transformer 10769-5778 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1644
% INFO    : Updated Thermal Rating: on transformer 5833-8585 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1238
% INFO    : Updated Thermal Rating: on transformer 12079-10130 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1767
% INFO    : Updated Thermal Rating: on transformer 12079-10130 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1804
% INFO    : Updated Thermal Rating: on transformer 2449-2731 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1820
% INFO    : Updated Thermal Rating: on transformer 2449-2731 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1861
% INFO    : Updated Thermal Rating: on transformer 5198-1227 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1129
% INFO    : Updated Thermal Rating: on transformer 5198-1227 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1150
% INFO    : Updated Thermal Rating: on transformer 957-4876 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 985
% INFO    : Updated Thermal Rating: on transformer 8883-4497 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1484
% INFO    : Updated Thermal Rating: on transformer 1543-11738 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1084
% INFO    : Updated Thermal Rating: on transformer 1543-11738 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1126
% INFO    : Updated Thermal Rating: on transformer 1543-11738 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1200
% INFO    : Updated Thermal Rating: on transformer 7258-11673 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1649
% INFO    : Updated Thermal Rating: on transformer 10884-8972 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1276
% INFO    : Updated Thermal Rating: on transformer 10884-8972 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1304
% INFO    : Updated Thermal Rating: on transformer 10884-6828 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1119
% INFO    : Updated Thermal Rating: on transformer 10183-6790 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1698
% INFO    : Updated Thermal Rating: on transformer 3862-13240 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1463
% INFO    : Updated Thermal Rating: on transformer 3862-13240 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1436
% INFO    : Updated Thermal Rating: on transformer 4089-4803 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1602
% INFO    : Updated Thermal Rating: on transformer 6524-2062 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1392
% INFO    : Updated Thermal Rating: on transformer 1163-11469 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1442
% INFO    : Updated Thermal Rating: on transformer 10894-11166 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1100
% INFO    : Updated Thermal Rating: on transformer 10894-13462 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1189
% INFO    : Updated Thermal Rating: on transformer 5263-1756 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1727
% INFO    : Updated Thermal Rating: on transformer 5263-1756 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1497
% INFO    : Updated Thermal Rating: on transformer 11270-12225 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1491
% INFO    : Updated Thermal Rating: on transformer 11270-12225 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1463
% INFO    : Updated Thermal Rating: on transformer 6614-2140 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 385
% INFO    : Updated Thermal Rating: on transformer 6614-2140 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 647
% INFO    : Updated Thermal Rating: on transformer 6614-2140 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1775
% INFO    : Updated Thermal Rating: on transformer 6614-2140 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 675
% INFO    : Updated Thermal Rating: on transformer 12155-6004 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1685
% INFO    : Updated Thermal Rating: on transformer 12155-6004 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1723
% INFO    : Updated Thermal Rating: on transformer 1810-6271 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1708
% INFO    : Updated Thermal Rating: on transformer 1810-6271 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1603
% INFO    : Updated Thermal Rating: on transformer 570-11776 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1917
% INFO    : Updated Thermal Rating: on transformer 570-11776 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1409
% INFO    : Updated Thermal Rating: on transformer 9883-6027 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1026
% INFO    : Updated Thermal Rating: on transformer 13300-3475 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 644
% INFO    : Updated Thermal Rating: on transformer 13300-3475 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1269
% INFO    : Updated Thermal Rating: on transformer 924-3475 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1296
% INFO    : Updated Thermal Rating: on transformer 4543-11390 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1336
% INFO    : Updated Thermal Rating: on transformer 9749-7207 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1231
% INFO    : Updated Thermal Rating: on transformer 9749-7207 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1077
% INFO    : Updated Thermal Rating: on transformer 1190-6613 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 607
% INFO    : Updated Thermal Rating: on transformer 1190-6613 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 726
% INFO    : Updated Thermal Rating: on transformer 5026-8307 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 5026-8307 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1215
% INFO    : Updated Thermal Rating: on transformer 5026-10642 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1240
% INFO    : Updated Thermal Rating: on transformer 1251-9209 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 804
% INFO    : Updated Thermal Rating: on transformer 1041-1777 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1189
% INFO    : Updated Thermal Rating: on transformer 1041-1777 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1201
% INFO    : Updated Thermal Rating: on transformer 9068-3391 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1354
% INFO    : Updated Thermal Rating: on transformer 9068-3391 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1198
% INFO    : Updated Thermal Rating: on transformer 13566-4205 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 731
% INFO    : Updated Thermal Rating: on transformer 13566-4205 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 717
% INFO    : Updated Thermal Rating: on transformer 1920-8521 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 725
% INFO    : Updated Thermal Rating: on transformer 1920-8521 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 766
% INFO    : Updated Thermal Rating: on transformer 1920-8521 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 780
% INFO    : Updated Thermal Rating: on transformer 4638-12483 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 725
% INFO    : Updated Thermal Rating: on transformer 4638-12483 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 741
% INFO    : Updated Thermal Rating: on transformer 6488-3378 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1027
% INFO    : Updated Thermal Rating: on transformer 6488-3378 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1050
% INFO    : Updated Thermal Rating: on transformer 7339-8926 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1195
% INFO    : Updated Thermal Rating: on transformer 7339-2058 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1175
% INFO    : Updated Thermal Rating: on transformer 10941-806 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1150
% INFO    : Updated Thermal Rating: on transformer 10941-806 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1122
% INFO    : Updated Thermal Rating: on transformer 806-7319 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2125
% INFO    : Updated Thermal Rating: on transformer 7987-3056 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 710
% INFO    : Updated Thermal Rating: on transformer 4094-13471 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 800
% INFO    : Updated Thermal Rating: on transformer 5236-9561 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1296
% INFO    : Updated Thermal Rating: on transformer 5236-9561 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1317
% INFO    : Updated Thermal Rating: on transformer 6589-2737 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1231
% INFO    : Updated Thermal Rating: on transformer 3805-2538 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 747
% INFO    : Updated Thermal Rating: on transformer 5160-8217 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 752
% INFO    : Updated Thermal Rating: on transformer 5197-544 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1128
% INFO    : Updated Thermal Rating: on transformer 5197-2615 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1410
% INFO    : Updated Thermal Rating: on transformer 3395-544 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1199
% INFO    : Updated Thermal Rating: on transformer 3395-544 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1240
% INFO    : Updated Thermal Rating: on transformer 2677-11371 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1283
% INFO    : Updated Thermal Rating: on transformer 167-11371 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1314
% INFO    : Updated Thermal Rating: on transformer 3609-10683 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 826
% INFO    : Updated Thermal Rating: on transformer 3609-10683 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 772
% INFO    : Updated Thermal Rating: on transformer 9-2951 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1099
% INFO    : Updated Thermal Rating: on transformer 9087-2951 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1165
% INFO    : Updated Thermal Rating: on transformer 11842-2951 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 666
% INFO    : Updated Thermal Rating: on transformer 6777-2296 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 6777-2296 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1199
% INFO    : Updated Thermal Rating: on transformer 6777-2296 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1230
% INFO    : Updated Thermal Rating: on transformer 8137-1420 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1157
% INFO    : Updated Thermal Rating: on transformer 8137-1420 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1185
% INFO    : Updated Thermal Rating: on transformer 8137-1420 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 844
% INFO    : Updated Thermal Rating: on transformer 8137-1420 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 897
% INFO    : Updated Thermal Rating: on transformer 1707-10943 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1182
% INFO    : Updated Thermal Rating: on transformer 1707-10943 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1149
% INFO    : Updated Thermal Rating: on transformer 3556-7192 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1156
% INFO    : Updated Thermal Rating: on transformer 3556-7192 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1126
% INFO    : Updated Thermal Rating: on transformer 1185-8038 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1264
% INFO    : Updated Thermal Rating: on transformer 1185-8038 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1385
% INFO    : Updated Thermal Rating: on transformer 1185-8038 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1269
% INFO    : Updated Thermal Rating: on transformer 7274-11696 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1308
% INFO    : Updated Thermal Rating: on transformer 7274-11696 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1325
% INFO    : Updated Thermal Rating: on transformer 7324-10802 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 786
% INFO    : Updated Thermal Rating: on transformer 1100-5520 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1092
% INFO    : Updated Thermal Rating: on transformer 5445-1829 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1172
% INFO    : Updated Thermal Rating: on transformer 5445-1829 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 692
% INFO    : Updated Thermal Rating: on transformer 5445-1829 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 646
% INFO    : Updated Thermal Rating: on transformer 5445-1829 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1219
% INFO    : Updated Thermal Rating: on transformer 9843-13380 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1156
% INFO    : Updated Thermal Rating: on transformer 9843-13380 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1164
% INFO    : Updated Thermal Rating: on transformer 13490-8642 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1300
% INFO    : Updated Thermal Rating: on transformer 2580-1153 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1201
% INFO    : Updated Thermal Rating: on transformer 2580-1153 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1234
% INFO    : Updated Thermal Rating: on transformer 4714-2203 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1202
% INFO    : Updated Thermal Rating: on transformer 4714-2203 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 676
% INFO    : Updated Thermal Rating: on transformer 2919-6011 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1176
% INFO    : Updated Thermal Rating: on transformer 2919-6011 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1154
% INFO    : Updated Thermal Rating: on transformer 6741-7462 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 704
% INFO    : Updated Thermal Rating: on transformer 3010-7462 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 710
% INFO    : Updated Thermal Rating: on transformer 8243-12724 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 922
% INFO    : Updated Thermal Rating: on transformer 8243-12724 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1296
% INFO    : Updated Thermal Rating: on transformer 4088-2184 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1328
% INFO    : Updated Thermal Rating: on transformer 6661-10021 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1362
% INFO    : Updated Thermal Rating: on transformer 6661-10021 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1188
% INFO    : Updated Thermal Rating: on transformer 2507-5664 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1080
% INFO    : Updated Thermal Rating: on transformer 2507-5664 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1054
% INFO    : Updated Thermal Rating: on transformer 2507-5664 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1020
% INFO    : Updated Thermal Rating: on transformer 3616-6666 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1229
% INFO    : Updated Thermal Rating: on transformer 3616-6666 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1244
% INFO    : Updated Thermal Rating: on transformer 4435-8929 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3147
% INFO    : Updated Thermal Rating: on transformer 7414-11183 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1332
% INFO    : Updated Thermal Rating: on transformer 12476-12299 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1344
% INFO    : Updated Thermal Rating: on transformer 12476-8034 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1179
% INFO    : Updated Thermal Rating: on transformer 12511-13001 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 669
% INFO    : Updated Thermal Rating: on transformer 11017-13001 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 722
% INFO    : Updated Thermal Rating: on transformer 227-11066 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1031
% INFO    : Updated Thermal Rating: on transformer 227-11066 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1117
% INFO    : Updated Thermal Rating: on transformer 227-11066 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1124
% INFO    : Updated Thermal Rating: on transformer 3627-7129 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 801
% INFO    : Updated Thermal Rating: on transformer 3383-5616 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1304
% INFO    : Updated Thermal Rating: on transformer 12835-4954 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1317
% INFO    : Updated Thermal Rating: on transformer 12835-4954 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1324
% INFO    : Updated Thermal Rating: on transformer 2124-158 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 761
% INFO    : Updated Thermal Rating: on transformer 2124-158 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 740
% INFO    : Updated Thermal Rating: on transformer 13480-3995 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1128
% INFO    : Updated Thermal Rating: on transformer 4416-1314 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 655
% INFO    : Updated Thermal Rating: on transformer 4416-1314 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 700
% INFO    : Updated Thermal Rating: on transformer 4416-1314 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 718
% INFO    : Updated Thermal Rating: on transformer 5763-9938 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 711
% INFO    : Updated Thermal Rating: on transformer 5763-5914 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 721
% INFO    : Updated Thermal Rating: on transformer 6512-4974 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1325
% INFO    : Updated Thermal Rating: on transformer 6512-4974 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1358
% INFO    : Updated Thermal Rating: on transformer 6512-4974 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1182
% INFO    : Updated Thermal Rating: on transformer 1554-10795 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 672
% INFO    : Updated Thermal Rating: on transformer 13455-3083 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1150
% INFO    : Updated Thermal Rating: on transformer 9592-12495 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1107
% INFO    : Updated Thermal Rating: on transformer 9592-12495 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1195
% INFO    : Updated Thermal Rating: on transformer 10309-11074 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1237
% INFO    : Updated Thermal Rating: on transformer 10309-11074 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1269
% INFO    : Updated Thermal Rating: on transformer 10309-13372 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1289
% INFO    : Updated Thermal Rating: on transformer 10059-9913 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 768
% INFO    : Updated Thermal Rating: on transformer 10059-9913 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 853
% INFO    : Updated Thermal Rating: on transformer 10059-9913 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1188
% INFO    : Updated Thermal Rating: on transformer 1465-10468 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1065
% INFO    : Updated Thermal Rating: on transformer 1465-55 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1150
% INFO    : Updated Thermal Rating: on transformer 1229-10468 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1031
% INFO    : Updated Thermal Rating: on transformer 1229-55 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1108
% INFO    : Updated Thermal Rating: on transformer 13621-9096 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1247
% INFO    : Updated Thermal Rating: on transformer 13621-12207 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1281
% INFO    : Updated Thermal Rating: on transformer 13621-9992 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1286
% INFO    : Updated Thermal Rating: on transformer 5299-9740 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1328
% INFO    : Updated Thermal Rating: on transformer 11015-9611 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1339
% INFO    : Updated Thermal Rating: on transformer 11015-9611 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1191
% INFO    : Updated Thermal Rating: on transformer 10996-9611 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1159
% INFO    : Updated Thermal Rating: on transformer 10996-9611 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1146
% INFO    : Updated Thermal Rating: on transformer 2849-9710 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1031
% INFO    : Updated Thermal Rating: on transformer 2849-9710 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1117
% INFO    : Updated Thermal Rating: on transformer 7948-1162 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 859
% INFO    : Updated Thermal Rating: on transformer 7948-1162 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 862
% INFO    : Updated Thermal Rating: on transformer 7948-1162 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 929
% INFO    : Updated Thermal Rating: on transformer 7280-5559 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1214
% INFO    : Updated Thermal Rating: on transformer 7280-5559 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1231
% INFO    : Updated Thermal Rating: on transformer 10630-6586 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3170
% INFO    : Updated Thermal Rating: on transformer 13583-82 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4652
% INFO    : Updated Thermal Rating: on transformer 13583-4479 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 671
% INFO    : Updated Thermal Rating: on transformer 2075-1783 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 2075-1783 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1229
% INFO    : Updated Thermal Rating: on transformer 2075-2217 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1240
% INFO    : Updated Thermal Rating: on transformer 11026-2217 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1160
% INFO    : Updated Thermal Rating: on transformer 11026-2217 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1192
% INFO    : Updated Thermal Rating: on transformer 10081-2224 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1194
% INFO    : Updated Thermal Rating: on transformer 4266-6 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 784
% INFO    : Updated Thermal Rating: on transformer 11004-820 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1222
% INFO    : Updated Thermal Rating: on transformer 1086-3185 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1344
% INFO    : Updated Thermal Rating: on transformer 6081-5428 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1043
% INFO    : Updated Thermal Rating: on transformer 6081-5428 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1032
% INFO    : Updated Thermal Rating: on transformer 10933-5386 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2769
% INFO    : Updated Thermal Rating: on transformer 12094-9593 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1272
% INFO    : Updated Thermal Rating: on transformer 12094-9593 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1262
% INFO    : Updated Thermal Rating: on transformer 12094-9593 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1311
% INFO    : Updated Thermal Rating: on transformer 6061-235 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1325
% INFO    : Updated Thermal Rating: on transformer 6061-235 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1366
% INFO    : Updated Thermal Rating: on transformer 6061-235 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 739
% INFO    : Updated Thermal Rating: on transformer 8497-13448 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 666
% INFO    : Updated Thermal Rating: on transformer 8497-2050 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1054
% INFO    : Updated Thermal Rating: on transformer 8497-2050 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1055
% INFO    : Updated Thermal Rating: on transformer 13408-7811 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 770
% INFO    : Updated Thermal Rating: on transformer 13408-7811 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 749
% INFO    : Updated Thermal Rating: on transformer 3376-11774 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 767
% INFO    : Updated Thermal Rating: on transformer 3376-11774 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 817
% INFO    : Updated Thermal Rating: on transformer 11927-244 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1204
% INFO    : Updated Thermal Rating: on transformer 11927-244 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1241
% INFO    : Updated Thermal Rating: on transformer 12417-1657 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1086
% INFO    : Updated Thermal Rating: on transformer 6937-3180 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1065
% INFO    : Updated Thermal Rating: on transformer 2433-955 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1146
% INFO    : Updated Thermal Rating: on transformer 2433-955 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1126
% INFO    : Updated Thermal Rating: on transformer 1269-11276 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 770
% INFO    : Updated Thermal Rating: on transformer 12272-11276 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 788
% INFO    : Updated Thermal Rating: on transformer 12272-11276 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 731
% INFO    : Updated Thermal Rating: on transformer 1127-9274 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1189
% INFO    : Updated Thermal Rating: on transformer 6157-422 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 784
% INFO    : Updated Thermal Rating: on transformer 6157-422 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 780
% INFO    : Updated Thermal Rating: on transformer 2936-5132 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 749
% INFO    : Updated Thermal Rating: on transformer 2936-5132 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 732
% INFO    : Updated Thermal Rating: on transformer 10294-12739 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1137
% INFO    : Updated Thermal Rating: on transformer 10294-12739 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1132
% INFO    : Updated Thermal Rating: on transformer 10294-12739 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1219
% INFO    : Updated Thermal Rating: on transformer 6599-4246 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1266
% INFO    : Updated Thermal Rating: on transformer 6599-4246 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1293
% INFO    : Updated Thermal Rating: on transformer 5623-459 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1197
% INFO    : Updated Thermal Rating: on transformer 8232-459 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1238
% INFO    : Updated Thermal Rating: on transformer 2467-169 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1054
% INFO    : Updated Thermal Rating: on transformer 2467-169 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1059
% INFO    : Updated Thermal Rating: on transformer 3891-8318 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1150
% INFO    : Updated Thermal Rating: on transformer 3891-8318 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1129
% INFO    : Updated Thermal Rating: on transformer 634-4730 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2432
% INFO    : Updated Thermal Rating: on transformer 634-10310 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2483
% INFO    : Updated Thermal Rating: on transformer 634-3428 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2533
% INFO    : Updated Thermal Rating: on transformer 634-2710 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2588
% INFO    : Updated Thermal Rating: on transformer 634-4980 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2447
% INFO    : Updated Thermal Rating: on transformer 634-8350 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2502
% INFO    : Updated Thermal Rating: on transformer 634-4502 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2207
% INFO    : Updated Thermal Rating: on transformer 634-4502 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2165
% INFO    : Updated Thermal Rating: on transformer 634-11544 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1160
% INFO    : Updated Thermal Rating: on transformer 1356-12535 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 745
% INFO    : Updated Thermal Rating: on transformer 1356-12535 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 718
% INFO    : Updated Thermal Rating: on transformer 5249-8605 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1269
% INFO    : Updated Thermal Rating: on transformer 5249-8605 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1286
% INFO    : Updated Thermal Rating: on transformer 5249-8605 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1317
% INFO    : Updated Thermal Rating: on transformer 13130-8620 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1358
% INFO    : Updated Thermal Rating: on transformer 13130-8620 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1198
% INFO    : Updated Thermal Rating: on transformer 2564-3540 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1063
% INFO    : Updated Thermal Rating: on transformer 2564-3540 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1045
% INFO    : Updated Thermal Rating: on transformer 4880-3018 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 717
% INFO    : Updated Thermal Rating: on transformer 4880-3018 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1212
% INFO    : Updated Thermal Rating: on transformer 4880-3018 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 792
% INFO    : Updated Thermal Rating: on transformer 3448-13294 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1266
% INFO    : Updated Thermal Rating: on transformer 13152-13294 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1185
% INFO    : Updated Thermal Rating: on transformer 2961-7229 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1328
% INFO    : Updated Thermal Rating: on transformer 2961-7229 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1346
% INFO    : Updated Thermal Rating: on transformer 326-2206 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1195
% INFO    : Updated Thermal Rating: on transformer 5846-7838 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1169
% INFO    : Updated Thermal Rating: on transformer 5846-7838 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1150
% INFO    : Updated Thermal Rating: on transformer 5846-7838 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 5846-10989 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1222
% INFO    : Updated Thermal Rating: on transformer 5846-10989 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1206
% INFO    : Updated Thermal Rating: on transformer 5846-10989 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1256
% INFO    : Updated Thermal Rating: on transformer 8070-7112 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1304
% INFO    : Updated Thermal Rating: on transformer 8070-2866 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1303
% INFO    : Updated Thermal Rating: on transformer 3090-7112 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1358
% INFO    : Updated Thermal Rating: on transformer 3090-2866 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1365
% INFO    : Updated Thermal Rating: on transformer 2348-8175 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1185
% INFO    : Updated Thermal Rating: on transformer 2348-1000 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1169
% INFO    : Updated Thermal Rating: on transformer 1158-8175 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1144
% INFO    : Updated Thermal Rating: on transformer 1158-1000 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1209
% INFO    : Updated Thermal Rating: on transformer 6736-13022 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1220
% INFO    : Updated Thermal Rating: on transformer 6736-13022 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1252
% INFO    : Updated Thermal Rating: on transformer 4194-6189 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1178
% INFO    : Updated Thermal Rating: on transformer 1639-9626 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 380
% INFO    : Updated Thermal Rating: on transformer 1639-6077 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 349
% INFO    : Updated Thermal Rating: on transformer 2753-3087 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 528
% INFO    : Updated Thermal Rating: on transformer 2753-9433 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 519
% INFO    : Updated Thermal Rating: on transformer 237-11610 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 357
% INFO    : Updated Thermal Rating: on transformer 237-7510 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 370
% INFO    : Updated Thermal Rating: on transformer 2551-5694 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 429
% INFO    : Updated Thermal Rating: on transformer 2551-6184 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 447
% INFO    : Updated Thermal Rating: on transformer 10587-8940 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 370
% INFO    : Updated Thermal Rating: on transformer 12028-3629 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 352
% INFO    : Updated Thermal Rating: on transformer 12488-2856 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1100
% INFO    : Updated Thermal Rating: on transformer 12293-8073 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 548
% INFO    : Updated Thermal Rating: on transformer 105-5239 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 431
% INFO    : Updated Thermal Rating: on transformer 6381-4100 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 403
% INFO    : Updated Thermal Rating: on transformer 6381-4100 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 396
% INFO    : Updated Thermal Rating: on transformer 7298-1671 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 384
% INFO    : Updated Thermal Rating: on transformer 7298-1671 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 377
% INFO    : Updated Thermal Rating: on transformer 2812-2545 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 439
% INFO    : Updated Thermal Rating: on transformer 1624-12444 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 541
% INFO    : Updated Thermal Rating: on transformer 884-3755 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 454
% INFO    : Updated Thermal Rating: on transformer 884-3755 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 391
% INFO    : Updated Thermal Rating: on transformer 884-10166 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 424
% INFO    : Updated Thermal Rating: on transformer 884-10166 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 423
% INFO    : Updated Thermal Rating: on transformer 884-10166 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 479
% INFO    : Updated Thermal Rating: on transformer 642-3703 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 479
% INFO    : Updated Thermal Rating: on transformer 8575-5752 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 430
% INFO    : Updated Thermal Rating: on transformer 8575-7023 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 454
% INFO    : Updated Thermal Rating: on transformer 8575-5355 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 370
% INFO    : Updated Thermal Rating: on transformer 10290-12950 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 414
% INFO    : Updated Thermal Rating: on transformer 2194-2805 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 369
% INFO    : Updated Thermal Rating: on transformer 2194-4579 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 361
% INFO    : Updated Thermal Rating: on transformer 2194-2805 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 401
% INFO    : Updated Thermal Rating: on transformer 2194-3263 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 354
% INFO    : Updated Thermal Rating: on transformer 2194-4579 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 291
% INFO    : Updated Thermal Rating: on transformer 2194-3263 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 326
% INFO    : Updated Thermal Rating: on transformer 4404-7520 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 406
% INFO    : Updated Thermal Rating: on transformer 2850-3660 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 342
% INFO    : Updated Thermal Rating: on transformer 2850-1540 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 349
% INFO    : Updated Thermal Rating: on transformer 4111-5040 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 422
% INFO    : Updated Thermal Rating: on transformer 8853-9985 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 453
% INFO    : Updated Thermal Rating: on transformer 8853-3269 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 510
% INFO    : Updated Thermal Rating: on transformer 7622-12284 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 358
% INFO    : Updated Thermal Rating: on transformer 4835-6198 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 387
% INFO    : Updated Thermal Rating: on transformer 4835-8670 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 369
% INFO    : Updated Thermal Rating: on transformer 4835-8670 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 317
% INFO    : Updated Thermal Rating: on transformer 6583-12130 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 494
% INFO    : Updated Thermal Rating: on transformer 6583-12130 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 505
% INFO    : Updated Thermal Rating: on transformer 6583-12130 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 515
% INFO    : Updated Thermal Rating: on transformer 2245-6732 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 502
% INFO    : Updated Thermal Rating: on transformer 2245-6732 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 443
% INFO    : Updated Thermal Rating: on transformer 4642-2855 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 803
% INFO    : Updated Thermal Rating: on transformer 4642-2855 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 788
% INFO    : Updated Thermal Rating: on transformer 4642-2855 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 773
% INFO    : Updated Thermal Rating: on transformer 4915-13255 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 469
% INFO    : Updated Thermal Rating: on transformer 11209-1067 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 217
% INFO    : Updated Thermal Rating: on transformer 13272-7347 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1045
% INFO    : Updated Thermal Rating: on transformer 13272-7347 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1063
% INFO    : Updated Thermal Rating: on transformer 7347-10395 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 440
% INFO    : Updated Thermal Rating: on transformer 7347-10395 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 388
% INFO    : Updated Thermal Rating: on transformer 13415-4035 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 403
% INFO    : Updated Thermal Rating: on transformer 3592-8015 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 933
% INFO    : Updated Thermal Rating: on transformer 3592-8015 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 892
% INFO    : Updated Thermal Rating: on transformer 8015-11628 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 432
% INFO    : Updated Thermal Rating: on transformer 8015-11628 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 441
% INFO    : Updated Thermal Rating: on transformer 8006-187 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 466
% INFO    : Updated Thermal Rating: on transformer 8006-187 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 485
% INFO    : Updated Thermal Rating: on transformer 8006-187 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 495
% INFO    : Updated Thermal Rating: on transformer 3795-8133 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 941
% INFO    : Updated Thermal Rating: on transformer 8002-5638 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 450
% INFO    : Updated Thermal Rating: on transformer 8002-5638 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 442
% INFO    : Updated Thermal Rating: on transformer 9037-1219 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 466
% INFO    : Updated Thermal Rating: on transformer 2132-9949 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 440
% INFO    : Updated Thermal Rating: on transformer 10240-6720 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 432
% INFO    : Updated Thermal Rating: on transformer 10240-6720 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 441
% INFO    : Updated Thermal Rating: on transformer 10347-2751 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 707
% INFO    : Updated Thermal Rating: on transformer 10347-2751 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 722
% INFO    : Updated Thermal Rating: on transformer 10347-2751 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 767
% INFO    : Updated Thermal Rating: on transformer 3423-11770 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 502
% INFO    : Updated Thermal Rating: on transformer 3423-11770 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 443
% INFO    : Updated Thermal Rating: on transformer 8344-7098 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 451
% INFO    : Updated Thermal Rating: on transformer 8344-7098 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 442
% INFO    : Updated Thermal Rating: on transformer 2024-6485 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 915
% INFO    : Updated Thermal Rating: on transformer 2024-10014 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 679
% INFO    : Updated Thermal Rating: on transformer 2024-10014 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 693
% INFO    : Updated Thermal Rating: on transformer 2582-6459 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3074
% INFO    : Updated Thermal Rating: on transformer 2582-6459 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3110
% INFO    : Updated Thermal Rating: on transformer 12573-4076 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 577
% INFO    : Updated Thermal Rating: on transformer 12573-4076 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 576
% INFO    : Updated Thermal Rating: on transformer 7706-4076 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 537
% INFO    : Updated Thermal Rating: on transformer 7706-4076 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 531
% INFO    : Updated Thermal Rating: on transformer 9848-9665 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 623
% INFO    : Updated Thermal Rating: on transformer 9848-9665 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 595
% INFO    : Updated Thermal Rating: on transformer 9848-9665 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 640
% INFO    : Updated Thermal Rating: on transformer 7957-9665 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 461
% INFO    : Updated Thermal Rating: on transformer 10922-3077 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 495
% INFO    : Updated Thermal Rating: on transformer 10922-3077 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 471
% INFO    : Updated Thermal Rating: on transformer 13262-3077 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 496
% INFO    : Updated Thermal Rating: on transformer 13262-3077 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 511
% INFO    : Updated Thermal Rating: on transformer 4348-7201 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1352
% INFO    : Updated Thermal Rating: on transformer 4348-3036 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1354
% INFO    : Updated Thermal Rating: on transformer 12666-8194 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 567
% INFO    : Updated Thermal Rating: on transformer 12666-8194 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 568
% INFO    : Updated Thermal Rating: on transformer 10686-4099 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1194
% INFO    : Updated Thermal Rating: on transformer 13229-10478 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 556
% INFO    : Updated Thermal Rating: on transformer 829-208 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 548
% INFO    : Updated Thermal Rating: on transformer 829-208 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 547
% INFO    : Updated Thermal Rating: on transformer 1313-208 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 595
% INFO    : Updated Thermal Rating: on transformer 1313-208 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 613
% INFO    : Updated Thermal Rating: on line 4899-7506 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3518
% INFO    : Updated Thermal Rating: on line 3705-9266 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7295
% INFO    : Updated Thermal Rating: on transformer 9266-7058 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 250
% INFO    : Updated Thermal Rating: on transformer 10740-6332 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1030
% INFO    : Updated Thermal Rating: on transformer 10740-6332 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1112
% INFO    : Updated Thermal Rating: on line 7434-6145 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 610
% INFO    : Updated Thermal Rating: on line 8840-8919 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 623
% INFO    : Updated Thermal Rating: on line 2519-12023 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 134
% INFO    : Updated Thermal Rating: on transformer 12587-10646 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1571
% INFO    : Updated Thermal Rating: on transformer 12587-9197 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1606
% INFO    : Updated Thermal Rating: on transformer 5232-9683 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1108
% INFO    : Updated Thermal Rating: on transformer 5232-9683 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1002
% INFO    : Updated Thermal Rating: on transformer 13516-9007 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1364
% INFO    : Updated Thermal Rating: on transformer 3949-2083 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 961
% INFO    : Updated Thermal Rating: on transformer 3949-2083 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1037
% INFO    : Updated Thermal Rating: on transformer 6957-3 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1388
% INFO    : Updated Thermal Rating: on transformer 1541-9070 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1081
% INFO    : Updated Thermal Rating: on transformer 8349-13406 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1135
% INFO    : Updated Thermal Rating: on transformer 10467-10025 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1574
% INFO    : Updated Thermal Rating: on transformer 12345-60 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1235
% INFO    : Updated Thermal Rating: on line 11181-9338 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1174
% INFO    : Updated Thermal Rating: on transformer 10714-11027 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1390
% INFO    : Updated Thermal Rating: on transformer 4421-1028 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1408
% INFO    : Updated Thermal Rating: on line 11639-8959 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3331
% INFO    : Updated Thermal Rating: on line 11639-13350 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3595
% INFO    : Updated Thermal Rating: on line 11639-10040 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3597
% INFO    : Updated Thermal Rating: on line 10548-7864 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3563
% INFO    : Updated Thermal Rating: on line 10548-21 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3552
% INFO    : Updated Thermal Rating: on line 6756-13304 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4130
% INFO    : Updated Thermal Rating: on line 6756-2211 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4223
% INFO    : Updated Thermal Rating: on line 10793-2588 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5590
% INFO    : Updated Thermal Rating: on line 10793-5916 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4891
% INFO    : Updated Thermal Rating: on line 10793-8502 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4802
% INFO    : Updated Thermal Rating: on line 10793-6461 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6016
% INFO    : Updated Thermal Rating: on line 7092-9760 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 523
% INFO    : Updated Thermal Rating: on line 7092-4687 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3895
% INFO    : Updated Thermal Rating: on line 7092-7308 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3424
% INFO    : Updated Thermal Rating: on transformer 3752-11372 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1092
% INFO    : Updated Thermal Rating: on transformer 3752-2942 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1115
% INFO    : Updated Thermal Rating: on transformer 142-4356 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1563
% INFO    : Updated Thermal Rating: on line 6695-2484 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 571
% INFO    : Updated Thermal Rating: on line 6695-8104 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 560
% INFO    : Updated Thermal Rating: on line 6695-5995 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 549
% INFO    : Updated Thermal Rating: on line 2089-434 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 675
% INFO    : Updated Thermal Rating: on transformer 4515-1102 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 989
% INFO    : Updated Thermal Rating: on transformer 7461-10383 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1164
% INFO    : Updated Thermal Rating: on line 5447-1299 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1604
% INFO    : Updated Thermal Rating: on transformer 10618-6282 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1110
% INFO    : Updated Thermal Rating: on transformer 10618-6282 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1135
% INFO    : Updated Thermal Rating: on line 12414-1676 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2119
% INFO    : Updated Thermal Rating: on line 10553-12002 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3656
% INFO    : Updated Thermal Rating: on line 10553-1931 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3586
% INFO    : Updated Thermal Rating: on transformer 10525-2899 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1091
% INFO    : Updated Thermal Rating: on transformer 4628-11452 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1260
% INFO    : Updated Thermal Rating: on transformer 10874-10969 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1226
% INFO    : Updated Thermal Rating: on transformer 10874-10969 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1556
% INFO    : Updated Thermal Rating: on transformer 10874-10969 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1497
% INFO    : Updated Thermal Rating: on transformer 4486-183 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1504
% INFO    : Updated Thermal Rating: on transformer 2297-11100 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1622
% INFO    : Updated Thermal Rating: on transformer 2297-11100 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1658
% INFO    : Updated Thermal Rating: on transformer 1309-6384 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1233
% INFO    : Updated Thermal Rating: on transformer 1309-6384 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1189
% INFO    : Updated Thermal Rating: on transformer 11460-6574 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1466
% INFO    : Updated Thermal Rating: on transformer 11460-6574 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1436
% INFO    : Updated Thermal Rating: on transformer 1186-437 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3178
% INFO    : Updated Thermal Rating: on transformer 12182-437 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3179
% INFO    : Updated Thermal Rating: on transformer 437-1487 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1473
% INFO    : Updated Thermal Rating: on line 9642-4794 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4263
% INFO    : Updated Thermal Rating: on line 3331-7406 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4357
% INFO    : Updated Thermal Rating: on line 7482-2310 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2237
% INFO    : Updated Thermal Rating: on line 4882-11681 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3930
% INFO    : Updated Thermal Rating: on transformer 12148-9303 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 781
% INFO    : Updated Thermal Rating: on transformer 5827-7994 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1212
% INFO    : Updated Thermal Rating: on line 3777-12047 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 68669
% INFO    : Updated Thermal Rating: on line 3777-10091 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 73459
% INFO    : Updated Thermal Rating: on transformer 1233-2661 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1436
% INFO    : Updated Thermal Rating: on transformer 1332-10853 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1564
% INFO    : Updated Thermal Rating: on transformer 7797-10325 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1187
% INFO    : Updated Thermal Rating: on transformer 6482-2017 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1490
% INFO    : Updated Thermal Rating: on transformer 11938-3830 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1565
% INFO    : Updated Thermal Rating: on transformer 5689-2300 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1427
% INFO    : Updated Thermal Rating: on transformer 5689-2300 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1392
% INFO    : Updated Thermal Rating: on transformer 5689-2300 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1365
% INFO    : Updated Thermal Rating: on transformer 13320-10730 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1272
% INFO    : Updated Thermal Rating: on transformer 13320-12508 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1369
% INFO    : Updated Thermal Rating: on transformer 3876-546 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1388
% INFO    : Updated Thermal Rating: on transformer 3837-502 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1024
% INFO    : Updated Thermal Rating: on transformer 7796-10175 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1622
% INFO    : Updated Thermal Rating: on transformer 7796-6062 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1658
% INFO    : Updated Thermal Rating: on transformer 7796-1847 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1694
% INFO    : Updated Thermal Rating: on transformer 7796-7467 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1134
% INFO    : Updated Thermal Rating: on transformer 2403-11071 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 980
% INFO    : Updated Thermal Rating: on transformer 3187-12549 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1398
% INFO    : Updated Thermal Rating: on transformer 3187-12549 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1372
% INFO    : Updated Thermal Rating: on transformer 2476-5906 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 987
% INFO    : Updated Thermal Rating: on transformer 330-5906 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 347
% INFO    : Updated Thermal Rating: on transformer 3843-13428 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1661
% INFO    : Updated Thermal Rating: on transformer 2550-12979 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1541
% INFO    : Updated Thermal Rating: on transformer 8192-11171 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1069
% INFO    : Updated Thermal Rating: on transformer 9199-2407 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1606
% INFO    : Updated Thermal Rating: on transformer 11008-3901 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 351
% INFO    : Updated Thermal Rating: on transformer 4750-372 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1113
% INFO    : Updated Thermal Rating: on transformer 4750-372 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1101
% INFO    : Updated Thermal Rating: on transformer 12534-3174 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 350
% INFO    : Updated Thermal Rating: on transformer 12534-3174 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 426
% INFO    : Updated Thermal Rating: on transformer 11249-2674 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 872
% INFO    : Updated Thermal Rating: on transformer 11249-2674 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 890
% INFO    : Updated Thermal Rating: on transformer 10744-10278 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 916
% INFO    : Updated Thermal Rating: on transformer 10744-10278 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 913
% INFO    : Updated Thermal Rating: on transformer 5821-4247 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 965
% INFO    : Updated Thermal Rating: on transformer 5821-4247 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 831
% INFO    : Updated Thermal Rating: on transformer 10542-9615 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 409
% INFO    : Updated Thermal Rating: on transformer 6182-9615 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 781
% INFO    : Updated Thermal Rating: on transformer 6182-9615 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 766
% INFO    : Updated Thermal Rating: on transformer 4747-1776 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 848
% INFO    : Updated Thermal Rating: on transformer 4747-1776 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 865
% INFO    : Updated Thermal Rating: on transformer 494-8150 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 905
% INFO    : Updated Thermal Rating: on transformer 13118-5577 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 422
% INFO    : Updated Thermal Rating: on transformer 1974-7318 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 430
% INFO    : Updated Thermal Rating: on transformer 5189-7318 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 439
% INFO    : Updated Thermal Rating: on transformer 10030-8979 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 775
% INFO    : Updated Thermal Rating: on transformer 1155-12901 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 760
% INFO    : Updated Thermal Rating: on transformer 2493-10226 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 742
% INFO    : Updated Thermal Rating: on transformer 871-10226 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 728
% INFO    : Updated Thermal Rating: on transformer 12422-10224 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 776
% INFO    : Updated Thermal Rating: on transformer 12422-10224 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 790
% INFO    : Updated Thermal Rating: on transformer 12422-10224 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 806
% INFO    : Updated Thermal Rating: on transformer 2719-8098 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 840
% INFO    : Updated Thermal Rating: on transformer 5101-8098 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 859
% INFO    : Updated Thermal Rating: on transformer 5101-11519 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 878
% INFO    : Updated Thermal Rating: on transformer 424-5822 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 775
% INFO    : Updated Thermal Rating: on transformer 11893-2101 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 760
% INFO    : Updated Thermal Rating: on transformer 11893-11831 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 745
% INFO    : Updated Thermal Rating: on transformer 7325-1667 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 732
% INFO    : Updated Thermal Rating: on transformer 7325-1667 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 790
% INFO    : Updated Thermal Rating: on transformer 1289-1667 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 806
% INFO    : Updated Thermal Rating: on transformer 1289-1667 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 823
% INFO    : Updated Thermal Rating: on transformer 7067-6275 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 840
% INFO    : Updated Thermal Rating: on transformer 4355-6275 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 859
% INFO    : Updated Thermal Rating: on transformer 1592-6275 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 878
% INFO    : Updated Thermal Rating: on transformer 11934-9064 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 775
% INFO    : Updated Thermal Rating: on transformer 12977-9064 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 760
% INFO    : Updated Thermal Rating: on transformer 5967-9165 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1790
% INFO    : Updated Thermal Rating: on transformer 2853-6373 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1757
% INFO    : Updated Thermal Rating: on transformer 7545-4906 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 790
% INFO    : Updated Thermal Rating: on transformer 7545-4906 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 806
% INFO    : Updated Thermal Rating: on transformer 3892-4906 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 823
% INFO    : Updated Thermal Rating: on transformer 3892-4906 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 840
% INFO    : Updated Thermal Rating: on transformer 2269-11567 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1073
% INFO    : Updated Thermal Rating: on transformer 8081-12550 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1097
% INFO    : Updated Thermal Rating: on transformer 8081-12550 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 968
% INFO    : Updated Thermal Rating: on transformer 2409-13039 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 760
% INFO    : Updated Thermal Rating: on transformer 1593-13039 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 745
% INFO    : Updated Thermal Rating: on transformer 12369-11060 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 614
% INFO    : Updated Thermal Rating: on transformer 12369-11060 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 663
% INFO    : Updated Thermal Rating: on transformer 1112-11060 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 676
% INFO    : Updated Thermal Rating: on transformer 4743-8827 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 690
% INFO    : Updated Thermal Rating: on transformer 547-8827 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 705
% INFO    : Updated Thermal Rating: on transformer 547-8827 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 720
% INFO    : Updated Thermal Rating: on transformer 8845-10912 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 878
% INFO    : Updated Thermal Rating: on transformer 8845-9802 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 775
% INFO    : Updated Thermal Rating: on transformer 11660-5649 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 760
% INFO    : Updated Thermal Rating: on transformer 2553-1456 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 745
% INFO    : Updated Thermal Rating: on transformer 11313-1848 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 366
% INFO    : Updated Thermal Rating: on transformer 199-1848 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 395
% INFO    : Updated Thermal Rating: on transformer 4653-2386 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 806
% INFO    : Updated Thermal Rating: on transformer 8261-2386 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 823
% INFO    : Updated Thermal Rating: on transformer 6366-2386 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 840
% INFO    : Updated Thermal Rating: on transformer 7003-2792 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3704
% INFO    : Updated Thermal Rating: on transformer 6333-6307 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 736
% INFO    : Updated Thermal Rating: on transformer 10205-6237 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1860
% INFO    : Updated Thermal Rating: on transformer 8646-10205 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3892
% INFO    : Updated Thermal Rating: on transformer 6237-6307 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 625
% INFO    : Updated Thermal Rating: on transformer 8593-3890 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 732
% INFO    : Updated Thermal Rating: on transformer 616-367 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 790
% INFO    : Updated Thermal Rating: on transformer 13170-8819 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 806
% INFO    : Updated Thermal Rating: on transformer 7752-12831 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 412
% INFO    : Updated Thermal Rating: on transformer 13242-12831 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 420
% INFO    : Updated Thermal Rating: on transformer 11462-10336 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 840
% INFO    : Updated Thermal Rating: on transformer 8768-520 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 858
% INFO    : Updated Thermal Rating: on transformer 9879-2388 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 760
% INFO    : Updated Thermal Rating: on transformer 5998-10902 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 760
% INFO    : Updated Thermal Rating: on transformer 1508-12184 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 5693-12184 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 366
% INFO    : Updated Thermal Rating: on transformer 113-7789 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 662
% INFO    : Updated Thermal Rating: on transformer 6578-4321 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 806
% INFO    : Updated Thermal Rating: on transformer 6578-4321 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 823
% INFO    : Updated Thermal Rating: on transformer 9167-4321 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 840
% INFO    : Updated Thermal Rating: on transformer 583-8829 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 859
% INFO    : Updated Thermal Rating: on transformer 8504-7652 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 878
% INFO    : Updated Thermal Rating: on transformer 8504-7652 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 775
% INFO    : Updated Thermal Rating: on transformer 9483-3555 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 380
% INFO    : Updated Thermal Rating: on transformer 7724-3555 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 2040-9145 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 275
% INFO    : Updated Thermal Rating: on transformer 6805-9145 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18
% INFO    : Updated Thermal Rating: on transformer 9356-5651 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 92
% INFO    : Updated Thermal Rating: on transformer 4318-6737 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 54
% INFO    : Updated Thermal Rating: on transformer 4318-6716 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 139
% INFO    : Updated Thermal Rating: on transformer 13169-1379 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 62
% INFO    : Updated Thermal Rating: on transformer 5421-1379 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 91
% INFO    : Updated Thermal Rating: on transformer 8011-1379 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 79
% INFO    : Updated Thermal Rating: on transformer 11162-5015 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 70
% INFO    : Updated Thermal Rating: on transformer 5572-933 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17
% INFO    : Updated Thermal Rating: on transformer 317-933 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20
% INFO    : Updated Thermal Rating: on transformer 7104-933 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 53
% INFO    : Updated Thermal Rating: on transformer 9104-6113 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1258
% INFO    : Updated Thermal Rating: on transformer 6805-10689 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25
% INFO    : Updated Thermal Rating: on transformer 5421-10689 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23
% INFO    : Updated Thermal Rating: on transformer 8011-10689 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23
% INFO    : Updated Thermal Rating: on transformer 2040-3601 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 83
% INFO    : Updated Thermal Rating: on transformer 5572-1363 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 51
% INFO    : Updated Thermal Rating: on transformer 5572-611 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 50
% INFO    : Updated Thermal Rating: on transformer 374-12450 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 53
% INFO    : Updated Thermal Rating: on transformer 12364-12450 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16
% INFO    : Updated Thermal Rating: on transformer 1597-12450 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 96
% INFO    : Updated Thermal Rating: on transformer 6653-4669 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 308
% INFO    : Updated Thermal Rating: on transformer 530-9705 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 966
% INFO    : Updated Thermal Rating: on transformer 530-11541 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 38
% INFO    : Updated Thermal Rating: on transformer 8923-6644 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 102
% INFO    : Updated Thermal Rating: on transformer 1405-6644 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 33
% INFO    : Updated Thermal Rating: on transformer 6246-12361 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 65
% INFO    : Updated Thermal Rating: on transformer 6246-8216 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 72
% INFO    : Updated Thermal Rating: on transformer 12187-12361 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 82
% INFO    : Updated Thermal Rating: on transformer 11045-12361 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1272
% INFO    : Updated Thermal Rating: on transformer 3952-12361 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 45
% INFO    : Updated Thermal Rating: on transformer 3952-8216 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 76
% INFO    : Updated Thermal Rating: on transformer 1597-488 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25
% INFO    : Updated Thermal Rating: on transformer 317-4669 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18
% INFO    : Updated Thermal Rating: on transformer 7104-4669 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 29
% INFO    : Updated Thermal Rating: on transformer 7601-6887 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 149
% INFO    : Updated Thermal Rating: on transformer 7601-6887 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1014
% INFO    : Updated Thermal Rating: on transformer 7601-5153 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 145
% INFO    : Updated Thermal Rating: on transformer 11162-12209 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 106
% INFO    : Updated Thermal Rating: on transformer 13061-13263 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 58
% INFO    : Updated Thermal Rating: on transformer 3159-12798 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1173
% INFO    : Updated Thermal Rating: on transformer 3159-12798 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1213
% INFO    : Updated Thermal Rating: on transformer 13061-4463 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 67
% INFO    : Updated Thermal Rating: on transformer 11162-3967 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 71
% INFO    : Updated Thermal Rating: on transformer 5039-2867 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1340
% INFO    : Updated Thermal Rating: on transformer 4911-4104 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 114
% INFO    : Updated Thermal Rating: on transformer 4911-7423 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 98
% INFO    : Updated Thermal Rating: on transformer 12364-8031 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 75
% INFO    : Updated Thermal Rating: on transformer 4071-2121 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1306
% INFO    : Updated Thermal Rating: on transformer 2040-2121 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17
% INFO    : Updated Thermal Rating: on transformer 2040-7741 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18
% INFO    : Updated Thermal Rating: on transformer 1585-7101 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1645
% INFO    : Updated Thermal Rating: on transformer 374-10265 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 54
% INFO    : Updated Thermal Rating: on transformer 11162-9811 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 70
% INFO    : Updated Thermal Rating: on transformer 13061-9811 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 49
% INFO    : Updated Thermal Rating: on transformer 10360-10265 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 34
% INFO    : Updated Thermal Rating: on transformer 1597-10265 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 49
% INFO    : Updated Thermal Rating: on transformer 11162-4972 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 37
% INFO    : Updated Thermal Rating: on transformer 13061-4972 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 102
% INFO    : Updated Thermal Rating: on transformer 1597-843 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17
% INFO    : Updated Thermal Rating: on transformer 13061-8020 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 32
% INFO    : Updated Thermal Rating: on transformer 10338-2452 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1063
% INFO    : Updated Thermal Rating: on transformer 10338-4736 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1085
% INFO    : Updated Thermal Rating: on transformer 5525-7483 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 205
% INFO    : Updated Thermal Rating: on transformer 5525-7483 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 999
% INFO    : Updated Thermal Rating: on transformer 733-7483 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 32
% INFO    : Updated Thermal Rating: on transformer 5525-561 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 47
% INFO    : Updated Thermal Rating: on transformer 7328-11541 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1425
% INFO    : Updated Thermal Rating: on transformer 733-3208 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 83
% INFO    : Updated Thermal Rating: on transformer 12852-3208 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 51
% INFO    : Updated Thermal Rating: on transformer 733-2802 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 75
% INFO    : Updated Thermal Rating: on transformer 12852-2802 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 38
% INFO    : Updated Thermal Rating: on transformer 733-2754 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 78
% INFO    : Updated Thermal Rating: on transformer 12852-2754 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 40
% INFO    : Updated Thermal Rating: on transformer 733-561 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 89
% INFO    : Updated Thermal Rating: on transformer 733-7843 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 151
% INFO    : Updated Thermal Rating: on transformer 1405-1114 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 948
% INFO    : Updated Thermal Rating: on transformer 1405-11590 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 95
% INFO    : Updated Thermal Rating: on transformer 1405-13563 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 94
% INFO    : Updated Thermal Rating: on transformer 12852-12998 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1211
% INFO    : Updated Thermal Rating: on transformer 12852-561 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 47
% INFO    : Updated Thermal Rating: on transformer 12852-5555 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 57
% INFO    : Updated Thermal Rating: on transformer 12852-7843 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 54
% INFO    : Updated Thermal Rating: on transformer 9356-7690 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23
% INFO    : Updated Thermal Rating: on transformer 12364-4850 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 49
% INFO    : Updated Thermal Rating: on transformer 12364-4850 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1074
% INFO    : Updated Thermal Rating: on transformer 4243-3694 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 191
% INFO    : Updated Thermal Rating: on transformer 1141-10131 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 976
% INFO    : Updated Thermal Rating: on transformer 4911-10131 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17
% INFO    : Updated Thermal Rating: on transformer 4318-12597 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 45
% INFO    : Updated Thermal Rating: on transformer 1597-10697 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 34
% INFO    : Updated Thermal Rating: on transformer 1597-399 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1190
% INFO    : Updated Thermal Rating: on transformer 1597-399 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 188
% INFO    : Updated Thermal Rating: on transformer 1597-9019 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 57
% INFO    : Updated Thermal Rating: on transformer 4243-5555 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 70
% INFO    : Updated Thermal Rating: on transformer 4318-7534 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1221
% INFO    : Updated Thermal Rating: on transformer 4318-1998 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1078
% INFO    : Updated Thermal Rating: on transformer 11162-4325 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52
% INFO    : Updated Thermal Rating: on transformer 11162-5867 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 79
% INFO    : Updated Thermal Rating: on transformer 13061-8240 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 57
% INFO    : Updated Thermal Rating: on transformer 8472-3667 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 70
% INFO    : Updated Thermal Rating: on transformer 8472-5950 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 70
% INFO    : Updated Thermal Rating: on transformer 34-246 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1505
% INFO    : Updated Thermal Rating: on transformer 7104-246 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 44
% INFO    : Updated Thermal Rating: on transformer 7104-9654 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 38
% INFO    : Updated Thermal Rating: on transformer 9356-5867 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 88
% INFO    : Updated Thermal Rating: on transformer 9162-4325 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1001
% INFO    : Updated Thermal Rating: on transformer 7104-5298 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 51
% INFO    : Updated Thermal Rating: on transformer 9519-4873 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 623
% INFO    : Updated Thermal Rating: on transformer 186-7935 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 613
% INFO    : Updated Thermal Rating: on transformer 186-7935 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 660
% INFO    : Updated Thermal Rating: on transformer 647-6349 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1078
% INFO    : Updated Thermal Rating: on transformer 3465-6920 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1128
% INFO    : Updated Thermal Rating: on transformer 3465-6920 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1189
% INFO    : Updated Thermal Rating: on transformer 13247-12999 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1050
% INFO    : Updated Thermal Rating: on transformer 13247-12999 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1089
% INFO    : Updated Thermal Rating: on transformer 8480-1022 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 405
% INFO    : Updated Thermal Rating: on transformer 12100-8027 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 682
% INFO    : Updated Thermal Rating: on transformer 12100-8027 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 669
% INFO    : Updated Thermal Rating: on transformer 789-6379 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 630
% INFO    : Updated Thermal Rating: on transformer 8865-7323 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 793
% INFO    : Updated Thermal Rating: on transformer 8865-7323 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 810
% INFO    : Updated Thermal Rating: on transformer 2715-10792 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 982
% INFO    : Updated Thermal Rating: on transformer 12487-1767 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 923
% INFO    : Updated Thermal Rating: on transformer 12487-1767 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 943
% INFO    : Updated Thermal Rating: on transformer 9043-3445 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 778
% INFO    : Updated Thermal Rating: on transformer 9043-3445 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 763
% INFO    : Updated Thermal Rating: on transformer 8085-1993 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 832
% INFO    : Updated Thermal Rating: on transformer 11490-2814 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 881
% INFO    : Updated Thermal Rating: on transformer 1463-10949 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 809
% INFO    : Updated Thermal Rating: on transformer 9196-9925 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1210
% INFO    : Updated Thermal Rating: on transformer 9196-9925 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1226
% INFO    : Updated Thermal Rating: on transformer 4330-9126 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 932
% INFO    : Updated Thermal Rating: on transformer 11719-254 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1348
% INFO    : Updated Thermal Rating: on transformer 11719-254 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1181
% INFO    : Updated Thermal Rating: on transformer 9534-10982 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 862
% INFO    : Updated Thermal Rating: on transformer 9534-10982 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 846
% INFO    : Updated Thermal Rating: on transformer 6592-6120 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 886
% INFO    : Updated Thermal Rating: on transformer 6592-6120 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 957
% INFO    : Updated Thermal Rating: on transformer 6592-6120 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 976
% INFO    : Updated Thermal Rating: on transformer 9511-12530 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1213
% INFO    : Updated Thermal Rating: on transformer 1463-1754 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1123
% INFO    : Updated Thermal Rating: on transformer 4330-13513 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1257
% INFO    : Updated Thermal Rating: on transformer 4330-9305 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1250
% INFO    : Updated Thermal Rating: on transformer 7395-677 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 423
% INFO    : Updated Thermal Rating: on transformer 7395-736 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 415
% INFO    : Updated Thermal Rating: on transformer 1925-8341 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 382
% INFO    : Updated Thermal Rating: on transformer 1925-8341 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 375
% INFO    : Updated Thermal Rating: on transformer 13051-10539 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 260
% INFO    : Updated Thermal Rating: on transformer 13051-10539 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 529
% INFO    : Updated Thermal Rating: on transformer 2469-9101 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 422
% INFO    : Updated Thermal Rating: on transformer 6954-7927 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 459
% INFO    : Updated Thermal Rating: on transformer 6954-1205 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 469
% INFO    : Updated Thermal Rating: on transformer 6146-10976 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 480
% INFO    : Updated Thermal Rating: on transformer 5486-1103 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 415
% INFO    : Updated Thermal Rating: on transformer 8051-8833 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 489
% INFO    : Updated Thermal Rating: on transformer 10871-4510 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 611
% INFO    : Updated Thermal Rating: on transformer 10871-4510 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 660
% INFO    : Updated Thermal Rating: on transformer 4510-922 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 529
% INFO    : Updated Thermal Rating: on transformer 4510-4852 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 540
% INFO    : Updated Thermal Rating: on transformer 3476-9139 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 431
% INFO    : Updated Thermal Rating: on transformer 3476-9888 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 440
% INFO    : Updated Thermal Rating: on transformer 6415-10002 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 576
% INFO    : Updated Thermal Rating: on transformer 11513-9234 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1163
% INFO    : Updated Thermal Rating: on transformer 9234-13293 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 499
% INFO    : Updated Thermal Rating: on transformer 10593-3637 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1119
% INFO    : Updated Thermal Rating: on transformer 10593-3637 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1098
% INFO    : Updated Thermal Rating: on transformer 3637-4361 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 503
% INFO    : Updated Thermal Rating: on transformer 3637-1683 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 513
% INFO    : Updated Thermal Rating: on transformer 6935-8512 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 422
% INFO    : Updated Thermal Rating: on transformer 8186-5583 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 459
% INFO    : Updated Thermal Rating: on transformer 8186-899 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 469
% INFO    : Updated Thermal Rating: on transformer 9116-127 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 450
% INFO    : Updated Thermal Rating: on transformer 9116-127 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 397
% INFO    : Updated Thermal Rating: on transformer 13638-2924 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 415
% INFO    : Updated Thermal Rating: on transformer 5480-1293 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 407
% INFO    : Updated Thermal Rating: on transformer 1193-2833 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 375
% INFO    : Updated Thermal Rating: on transformer 9834-12952 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 405
% INFO    : Updated Thermal Rating: on transformer 9834-2002 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 414
% INFO    : Updated Thermal Rating: on transformer 9238-13204 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 352
% INFO    : Updated Thermal Rating: on transformer 5579-13378 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 552
% INFO    : Updated Thermal Rating: on transformer 5579-13378 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 564
% INFO    : Updated Thermal Rating: on transformer 7281-10770 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 576
% INFO    : Updated Thermal Rating: on transformer 7281-9459 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 508
% INFO    : Updated Thermal Rating: on transformer 11589-4560 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 415
% INFO    : Updated Thermal Rating: on transformer 5719-7158 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 407
% INFO    : Updated Thermal Rating: on transformer 2986-11540 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 400
% INFO    : Updated Thermal Rating: on transformer 13627-9770 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 735
% INFO    : Updated Thermal Rating: on transformer 13315-4641 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 750
% INFO    : Updated Thermal Rating: on transformer 1705-1706 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 450
% INFO    : Updated Thermal Rating: on transformer 1705-1706 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 459
% INFO    : Updated Thermal Rating: on transformer 293-6175 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 469
% INFO    : Updated Thermal Rating: on transformer 293-8417 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 480
% INFO    : Updated Thermal Rating: on transformer 7326-5374 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 397
% INFO    : Updated Thermal Rating: on transformer 7326-5374 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 390
% INFO    : Updated Thermal Rating: on transformer 2884-1799 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 407
% INFO    : Updated Thermal Rating: on transformer 2884-1799 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 400
% INFO    : Updated Thermal Rating: on transformer 12012-8051 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1186
% INFO    : Updated Thermal Rating: on transformer 12012-11679 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1210
% INFO    : Updated Thermal Rating: on transformer 11679-13236 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 540
% INFO    : Updated Thermal Rating: on transformer 11679-1890 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 552
% INFO    : Updated Thermal Rating: on transformer 3411-2744 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 469
% INFO    : Updated Thermal Rating: on transformer 3411-2744 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 480
% INFO    : Updated Thermal Rating: on transformer 9488-12371 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 423
% INFO    : Updated Thermal Rating: on transformer 11682-7764 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 415
% INFO    : Updated Thermal Rating: on transformer 9128-2511 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1178
% INFO    : Updated Thermal Rating: on transformer 2511-4297 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 257
% INFO    : Updated Thermal Rating: on transformer 7984-10393 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 289
% INFO    : Updated Thermal Rating: on transformer 8931-12463 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 295
% INFO    : Updated Thermal Rating: on transformer 6941-4396 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1289
% INFO    : Updated Thermal Rating: on transformer 6941-4396 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1318
% INFO    : Updated Thermal Rating: on transformer 4396-12301 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 508
% INFO    : Updated Thermal Rating: on transformer 4396-3435 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 499
% INFO    : Updated Thermal Rating: on transformer 12860-2548 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 489
% INFO    : Updated Thermal Rating: on transformer 5789-2671 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 375
% INFO    : Updated Thermal Rating: on transformer 5789-5487 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 405
% INFO    : Updated Thermal Rating: on transformer 1371-10664 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1210
% INFO    : Updated Thermal Rating: on transformer 1371-5020 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1235
% INFO    : Updated Thermal Rating: on transformer 5020-703 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 552
% INFO    : Updated Thermal Rating: on transformer 5020-703 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 564
% INFO    : Updated Thermal Rating: on transformer 9741-6410 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 480
% INFO    : Updated Thermal Rating: on transformer 11491-6657 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 508
% INFO    : Updated Thermal Rating: on transformer 2385-9239 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 499
% INFO    : Updated Thermal Rating: on transformer 2385-9239 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 489
% INFO    : Updated Thermal Rating: on transformer 6453-7040 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 375
% INFO    : Updated Thermal Rating: on transformer 6889-5659 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1226
% INFO    : Updated Thermal Rating: on transformer 6889-9703 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1370
% INFO    : Updated Thermal Rating: on transformer 6889-9703 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1399
% INFO    : Updated Thermal Rating: on transformer 12516-13461 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 656
% INFO    : Updated Thermal Rating: on transformer 6261-1121 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 440
% INFO    : Updated Thermal Rating: on transformer 10999-4447 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 576
% INFO    : Updated Thermal Rating: on transformer 4908-8684 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 423
% INFO    : Updated Thermal Rating: on transformer 2416-9838 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 415
% INFO    : Updated Thermal Rating: on transformer 4894-13139 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1129
% INFO    : Updated Thermal Rating: on transformer 4894-11041 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 375
% INFO    : Updated Thermal Rating: on transformer 13139-11041 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 432
% INFO    : Updated Thermal Rating: on transformer 10698-11075 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 422
% INFO    : Updated Thermal Rating: on transformer 13221-5372 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1060
% INFO    : Updated Thermal Rating: on transformer 6364-5597 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 440
% INFO    : Updated Thermal Rating: on transformer 7782-4362 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 480
% INFO    : Updated Thermal Rating: on transformer 12756-7306 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 423
% INFO    : Updated Thermal Rating: on transformer 883-10413 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1151
% INFO    : Updated Thermal Rating: on transformer 883-12669 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1129
% INFO    : Updated Thermal Rating: on transformer 883-1870 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 375
% INFO    : Updated Thermal Rating: on transformer 883-7301 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 405
% INFO    : Updated Thermal Rating: on transformer 10256-6914 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1017
% INFO    : Updated Thermal Rating: on transformer 10256-6914 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1038
% INFO    : Updated Thermal Rating: on transformer 10256-6914 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1060
% INFO    : Updated Thermal Rating: on transformer 6914-5738 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 469
% INFO    : Updated Thermal Rating: on transformer 6914-5738 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 480
% INFO    : Updated Thermal Rating: on transformer 2204-2960 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 397
% INFO    : Updated Thermal Rating: on transformer 2204-5768 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 390
% INFO    : Updated Thermal Rating: on transformer 12015-7629 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 489
% INFO    : Updated Thermal Rating: on transformer 7303-47 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 400
% INFO    : Updated Thermal Rating: on transformer 3047-744 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 432
% INFO    : Updated Thermal Rating: on transformer 3047-744 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 441
% INFO    : Updated Thermal Rating: on transformer 13036-12177 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 422
% INFO    : Updated Thermal Rating: on transformer 13036-12177 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 431
% INFO    : Updated Thermal Rating: on transformer 595-12177 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 564
% INFO    : Updated Thermal Rating: on transformer 10654-13239 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 480
% INFO    : Updated Thermal Rating: on transformer 7575-12496 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 423
% INFO    : Updated Thermal Rating: on transformer 6343-6387 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 208
% INFO    : Updated Thermal Rating: on transformer 6989-398 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1119
% INFO    : Updated Thermal Rating: on transformer 6989-4571 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 375
% INFO    : Updated Thermal Rating: on transformer 6989-7138 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 405
% INFO    : Updated Thermal Rating: on transformer 6474-11554 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 441
% INFO    : Updated Thermal Rating: on transformer 6474-11554 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 450
% INFO    : Updated Thermal Rating: on transformer 10584-1325 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 459
% INFO    : Updated Thermal Rating: on transformer 10584-1325 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 469
% INFO    : Updated Thermal Rating: on transformer 5758-876 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 541
% INFO    : Updated Thermal Rating: on transformer 1619-876 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 478
% INFO    : Updated Thermal Rating: on transformer 4169-3871 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 643
% INFO    : Updated Thermal Rating: on transformer 4169-838 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 631
% INFO    : Updated Thermal Rating: on transformer 1383-8207 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 400
% INFO    : Updated Thermal Rating: on transformer 1383-3332 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 432
% INFO    : Updated Thermal Rating: on transformer 1720-11215 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1221
% INFO    : Updated Thermal Rating: on transformer 11215-6434 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 450
% INFO    : Updated Thermal Rating: on transformer 7313-3125 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 459
% INFO    : Updated Thermal Rating: on transformer 6514-219 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 568
% INFO    : Updated Thermal Rating: on transformer 6514-8607 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 455
% INFO    : Updated Thermal Rating: on transformer 4227-504 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 711
% INFO    : Updated Thermal Rating: on transformer 4227-504 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 695
% INFO    : Updated Thermal Rating: on transformer 4227-504 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 384
% INFO    : Updated Thermal Rating: on transformer 4227-504 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 692
% INFO    : Updated Thermal Rating: on transformer 13329-5775 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 654
% INFO    : Updated Thermal Rating: on transformer 13329-5775 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 667
% INFO    : Updated Thermal Rating: on transformer 7771-3356 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1003
% INFO    : Updated Thermal Rating: on transformer 7771-12489 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1196
% INFO    : Updated Thermal Rating: on transformer 4491-12490 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 450
% INFO    : Updated Thermal Rating: on transformer 4095-329 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 522
% INFO    : Updated Thermal Rating: on transformer 4095-329 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 817
% INFO    : Updated Thermal Rating: on transformer 7786-4358 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 393
% INFO    : Updated Thermal Rating: on transformer 11494-13273 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 671
% INFO    : Updated Thermal Rating: on transformer 2195-12231 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 650
% INFO    : Updated Thermal Rating: on transformer 2195-12231 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 689
% INFO    : Updated Thermal Rating: on transformer 12298-12644 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 406
% INFO    : Updated Thermal Rating: on transformer 12298-12644 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 405
% INFO    : Updated Thermal Rating: on transformer 967-11127 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 347
% INFO    : Updated Thermal Rating: on transformer 967-11127 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 465
% INFO    : Updated Thermal Rating: on transformer 2818-11663 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 949
% INFO    : Updated Thermal Rating: on transformer 10005-11663 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 364
% INFO    : Updated Thermal Rating: on transformer 10005-11663 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 395
% INFO    : Updated Thermal Rating: on transformer 7125-11014 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 366
% INFO    : Updated Thermal Rating: on transformer 12632-7125 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 953
% INFO    : Updated Thermal Rating: on transformer 12632-11014 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 701
% INFO    : Updated Thermal Rating: on transformer 12632-11014 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 698
% INFO    : Updated Thermal Rating: on transformer 7029-9828 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1253
% INFO    : Updated Thermal Rating: on transformer 7029-12354 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 929
% INFO    : Updated Thermal Rating: on transformer 9828-7611 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 431
% INFO    : Updated Thermal Rating: on transformer 10798-3902 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1130
% INFO    : Updated Thermal Rating: on transformer 10798-3902 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1115
% INFO    : Updated Thermal Rating: on transformer 2405-12731 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 907
% INFO    : Updated Thermal Rating: on transformer 2405-5508 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 663
% INFO    : Updated Thermal Rating: on transformer 2405-5508 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 708
% INFO    : Updated Thermal Rating: on transformer 10718-11533 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 897
% INFO    : Updated Thermal Rating: on transformer 11733-9765 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 434
% INFO    : Updated Thermal Rating: on transformer 11733-9765 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 448
% INFO    : Updated Thermal Rating: on transformer 13546-2444 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 429
% INFO    : Updated Thermal Rating: on transformer 13546-2444 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 438
% INFO    : Updated Thermal Rating: on transformer 5434-8201 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 399
% INFO    : Updated Thermal Rating: on transformer 5434-8201 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 391
% INFO    : Updated Thermal Rating: on transformer 11413-7033 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 384
% INFO    : Updated Thermal Rating: on transformer 11413-7033 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 344
% INFO    : Updated Thermal Rating: on transformer 12313-5079 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 855
% INFO    : Updated Thermal Rating: on transformer 2505-5079 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 426
% INFO    : Updated Thermal Rating: on transformer 2505-5079 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 435
% INFO    : Updated Thermal Rating: on transformer 3715-7184 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1249
% INFO    : Updated Thermal Rating: on transformer 7184-868 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 451
% INFO    : Updated Thermal Rating: on transformer 7184-67 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 432
% INFO    : Updated Thermal Rating: on transformer 387-2022 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 698
% INFO    : Updated Thermal Rating: on transformer 11007-1568 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 383
% INFO    : Updated Thermal Rating: on transformer 11007-1568 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 361
% INFO    : Updated Thermal Rating: on transformer 1255-13260 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on transformer 1255-4701 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 708
% INFO    : Updated Thermal Rating: on transformer 5511-11269 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 316
% INFO    : Updated Thermal Rating: on transformer 5511-11269 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 403
% INFO    : Updated Thermal Rating: on transformer 5511-11269 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 412
% INFO    : Updated Thermal Rating: on transformer 5511-11269 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 421
% INFO    : Updated Thermal Rating: on transformer 9582-12567 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1296
% INFO    : Updated Thermal Rating: on transformer 9582-12567 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1144
% INFO    : Updated Thermal Rating: on transformer 9582-12567 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1122
% INFO    : Updated Thermal Rating: on transformer 3923-7581 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 829
% INFO    : Updated Thermal Rating: on transformer 1011-2798 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 377
% INFO    : Updated Thermal Rating: on transformer 1011-2532 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 414
% INFO    : Updated Thermal Rating: on transformer 8891-13588 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 872
% INFO    : Updated Thermal Rating: on transformer 2095-7010 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 387
% INFO    : Updated Thermal Rating: on transformer 2095-7010 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 478
% INFO    : Updated Thermal Rating: on transformer 7215-3071 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1052
% INFO    : Updated Thermal Rating: on transformer 7215-3071 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1076
% INFO    : Updated Thermal Rating: on transformer 10322-13504 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1609
% INFO    : Updated Thermal Rating: on transformer 8477-11977 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 931
% INFO    : Updated Thermal Rating: on transformer 6044-5814 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 601
% INFO    : Updated Thermal Rating: on transformer 4082-5814 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 384
% INFO    : Updated Thermal Rating: on transformer 1144-12959 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 732
% INFO    : Updated Thermal Rating: on transformer 1144-12959 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 747
% INFO    : Updated Thermal Rating: on transformer 6149-5799 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1227
% INFO    : Updated Thermal Rating: on transformer 6149-5799 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1253
% INFO    : Updated Thermal Rating: on transformer 6149-10826 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2328
% INFO    : Updated Thermal Rating: on transformer 5799-1351 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 398
% INFO    : Updated Thermal Rating: on transformer 10826-5799 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 727
% INFO    : Updated Thermal Rating: on transformer 10826-5799 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 408
% INFO    : Updated Thermal Rating: on transformer 8882-8560 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 510
% INFO    : Updated Thermal Rating: on transformer 8882-8560 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 501
% INFO    : Updated Thermal Rating: on transformer 13474-9599 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 359
% INFO    : Updated Thermal Rating: on transformer 13474-9599 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 366
% INFO    : Updated Thermal Rating: on transformer 11561-879 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 746
% INFO    : Updated Thermal Rating: on transformer 879-6231 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 509
% INFO    : Updated Thermal Rating: on transformer 879-6231 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 520
% INFO    : Updated Thermal Rating: on transformer 7850-11835 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 340
% INFO    : Updated Thermal Rating: on transformer 7850-11835 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 259
% INFO    : Updated Thermal Rating: on transformer 7397-657 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 272
% INFO    : Updated Thermal Rating: on transformer 7397-657 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 267
% INFO    : Updated Thermal Rating: on transformer 9363-12633 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2747
% INFO    : Updated Thermal Rating: on transformer 12894-5804 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 12894-7115 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 12894-3481 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 12894-4910 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 12894-6291 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 12894-7625 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 12894-10785 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 12894-7057 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 12894-8370 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 12894-8159 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 7344-4480 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 7344-6135 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 3901-10983 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 3901-564 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 3901-3617 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 12265-6846 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 12265-9976 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 12265-1895 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 372-4692 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 372-5627 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 10709-6780 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 10709-3577 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 10709-531 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 10709-7105 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 10709-10352 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 10709-2473 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 10709-13122 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 10709-6049 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 10709-2786 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 10709-8524 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 10709-11699 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 10709-1192 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 10709-4298 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 10709-7447 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 10709-10605 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 10709-12035 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 10709-1516 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 10709-4671 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 10709-6225 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 8477-2462 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 8477-6317 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 8477-2084 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 11379-1606 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 444
% INFO    : Updated Thermal Rating: on transformer 11379-6885 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 444
% INFO    : Updated Thermal Rating: on transformer 11379-9960 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 444
% INFO    : Updated Thermal Rating: on transformer 11379-10847 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 444
% INFO    : Updated Thermal Rating: on transformer 11379-7930 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1771
% INFO    : Updated Thermal Rating: on transformer 11379-9687 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1771
% INFO    : Updated Thermal Rating: on transformer 11379-12962 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1771
% INFO    : Updated Thermal Rating: on transformer 12770-7173 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 444
% INFO    : Updated Thermal Rating: on transformer 12770-3962 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 444
% INFO    : Updated Thermal Rating: on transformer 12770-910 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 444
% INFO    : Updated Thermal Rating: on transformer 3896-1096 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 3896-10865 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 3896-7689 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 3896-5765 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 5694-7356 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 5694-11891 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 5694-8704 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 5694-5739 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 6184-8793 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 6184-11996 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 6184-9236 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 6184-6799 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 12700-9884 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 12700-13133 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 12700-2485 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 12700-5420 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 12700-8490 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 12700-7064 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 3649-3854 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 3649-798 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 3649-13409 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 3649-8096 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 10587-4448 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1771
% INFO    : Updated Thermal Rating: on transformer 10587-1308 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1771
% INFO    : Updated Thermal Rating: on transformer 11210-13327 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1771
% INFO    : Updated Thermal Rating: on transformer 12488-5319 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1787
% INFO    : Updated Thermal Rating: on transformer 2551-5581 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1787
% INFO    : Updated Thermal Rating: on transformer 2551-11483 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1787
% INFO    : Updated Thermal Rating: on transformer 2551-6436 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1787
% INFO    : Updated Thermal Rating: on transformer 8575-1323 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1771
% INFO    : Updated Thermal Rating: on transformer 8575-4443 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1771
% INFO    : Updated Thermal Rating: on transformer 8575-8632 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1771
% INFO    : Updated Thermal Rating: on transformer 12933-10535 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1787
% INFO    : Updated Thermal Rating: on transformer 12933-2895 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1787
% INFO    : Updated Thermal Rating: on transformer 4568-9370 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 4568-9281 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 7622-8763 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 7622-2777 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 7622-1455 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 7622-6507 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 7622-6034 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 7622-1749 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 7622-5924 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 7622-458 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4568-6754 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 4568-39 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 12284-1125 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 12284-7668 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 12284-666 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 12284-824 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 3818-6103 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 11951-1072 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 11951-5341 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 11951-11299 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 2678-2970 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 2678-5037 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 2678-12099 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 2678-5548 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 2678-12612 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 2678-8969 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 6551-10408 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 6551-6539 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 6551-13651 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4813-1278 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4813-2662 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4813-888 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4813-7392 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4813-1324 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4813-7875 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 12680-12641 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 12680-7111 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 679-10640 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1340
% INFO    : Updated Thermal Rating: on transformer 679-11154 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1340
% INFO    : Updated Thermal Rating: on transformer 2993-4310 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1787
% INFO    : Updated Thermal Rating: on transformer 12838-1071 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 12838-6948 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4783-394 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4783-10418 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4783-869 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 5808-7859 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 5808-1305 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 5808-9614 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 5808-1763 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 5808-4988 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1613-4339 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 145
% INFO    : Updated Thermal Rating: on transformer 1613-4938 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 145
% INFO    : Updated Thermal Rating: on transformer 1613-7039 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 145
% INFO    : Updated Thermal Rating: on transformer 1613-8029 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 145
% INFO    : Updated Thermal Rating: on transformer 1613-1017 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 145
% INFO    : Updated Thermal Rating: on transformer 11260-6670 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 11260-13292 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 11260-7116 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 11260-133 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 11260-5723 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 11260-9374 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 11260-4440 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 11260-11487 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 11260-3915 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 11260-11005 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 13548-5439 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 13548-6068 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 13548-4934 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 13548-11988 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 13548-2459 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 13548-3248 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 13548-1304 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 13548-7858 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 13548-859 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 13548-7365 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 2873-3292 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 2873-11643 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 2873-626 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 2873-11131 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 2873-4063 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 7748-9766 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 173
% INFO    : Updated Thermal Rating: on transformer 7748-11802 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 173
% INFO    : Updated Thermal Rating: on transformer 7748-4377 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 173
% INFO    : Updated Thermal Rating: on transformer 7748-5940 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 173
% INFO    : Updated Thermal Rating: on transformer 7748-5755 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 173
% INFO    : Updated Thermal Rating: on transformer 7748-10833 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 173
% INFO    : Updated Thermal Rating: on transformer 7748-4238 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 173
% INFO    : Updated Thermal Rating: on transformer 7748-181 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 173
% INFO    : Updated Thermal Rating: on transformer 7748-4761 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 173
% INFO    : Updated Thermal Rating: on transformer 3764-144 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 3764-7139 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 3764-12551 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 7231-7252 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3718
% INFO    : Updated Thermal Rating: on transformer 7231-241 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3718
% INFO    : Updated Thermal Rating: on transformer 4303-5979 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4303-12282 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4303-6487 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4303-395 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4303-995 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4303-9317 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4303-3468 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4303-9354 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 2116-3404 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 2116-8852 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 2116-2242 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 2116-8367 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 2116-1794 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 2116-7890 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 2116-1330 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 2116-11315 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 2116-4763 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 2116-10001 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 8695-3361 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 8695-9520 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 8695-7812 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 8695-10935 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 12322-4354 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 12322-10469 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 12322-3845 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 12322-8067 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 12322-9149 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 12322-13223 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 12322-6123 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 12322-54 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 12322-6602 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 12322-12216 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 12322-5187 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1378-12728 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1378-5672 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1378-11221 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1378-4133 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1378-3683 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1378-10788 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1378-4191 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1378-11264 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1378-2698 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1378-9808 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1378-3176 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 2225-5347 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 2225-2080 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 2225-8637 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 2225-10633 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 2225-4004 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 2225-11128 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 2225-4573 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 2225-9662 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 2225-3029 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 2225-2681 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 2225-3535 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 1736-12448 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1736-1701 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1736-5188 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1736-12217 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1736-4675 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1736-11729 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1736-4135 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 2917-11230 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on transformer 2917-3650 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7
% INFO    : Updated Thermal Rating: on transformer 8505-7142 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 8505-5335 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 8505-7289 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 8505-3644 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 8505-9179 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 8505-3139 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 8505-9775 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 8505-3050 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 322-3724 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3718
% INFO    : Updated Thermal Rating: on transformer 322-10330 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3718
% INFO    : Updated Thermal Rating: on transformer 10861-8573 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 10861-2429 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 10861-9061 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 10861-12528 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 10861-5963 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 10861-13041 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 10861-11467 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 10861-9873 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4525-4264 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4525-354 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4525-7317 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4525-10527 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4525-3899 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4525-1972 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4525-11648 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4525-1514 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4525-8063 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4525-2877 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 8693-9521 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 6185-2410 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4831-9041 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4831-121 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4831-12911 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4831-6210 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4831-13303 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4831-5741 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4831-12822 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4831-7168 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4831-623 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4831-10384 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 210-153 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 210-8092 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 210-1553 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 210-9297 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 11596-2210 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 11596-9809 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 11596-2700 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 11596-8326 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 11596-1288 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 11596-8797 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 11596-1757 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 11596-11265 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 3591-4193 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 3591-259 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 11417-6820 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 11417-8851 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 11417-6341 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 11417-1202 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 11417-7740 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 11417-724 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 7621-7242 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 7621-13412 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 7621-8686 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 7621-10696 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 7621-4074 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 7621-11155 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 7621-4594 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 7621-11654 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 566-5109 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 566-12195 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 5209-5641 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 5209-12717 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 5209-6107 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 5209-12227 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 5209-13174 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 5209-7028 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 5209-18 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 5209-4384 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 5209-477 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 11908-7939 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 11908-938 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 11908-4563 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 11908-11115 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 11908-3323 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4468-12819 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4468-2796 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4468-9901 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4468-2332 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4468-9427 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4468-1889 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 8450-29 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 13051-9123 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 448
% INFO    : Updated Thermal Rating: on transformer 13051-2066 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 448
% INFO    : Updated Thermal Rating: on transformer 9101-4052 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 164
% INFO    : Updated Thermal Rating: on transformer 9101-2583 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 164
% INFO    : Updated Thermal Rating: on transformer 9101-9192 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 164
% INFO    : Updated Thermal Rating: on transformer 10976-8687 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 10976-721 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 7247-1685 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 7247-8253 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 7247-1208 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 8366-12390 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1787
% INFO    : Updated Thermal Rating: on transformer 8366-5354 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1787
% INFO    : Updated Thermal Rating: on transformer 11513-5155 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1340
% INFO    : Updated Thermal Rating: on transformer 6415-11704 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1340
% INFO    : Updated Thermal Rating: on transformer 3637-5356 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 448
% INFO    : Updated Thermal Rating: on transformer 3637-3154 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 448
% INFO    : Updated Thermal Rating: on transformer 4361-5653 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4361-3508 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1683-6296 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 1683-12900 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 12349-2789 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 12349-9422 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 12349-8976 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 2563-8961 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 2563-2803 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 3144-6440 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 3144-8726 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 658-7951 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1403-1896 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 425-12537 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4466
% INFO    : Updated Thermal Rating: on transformer 425-9148 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4466
% INFO    : Updated Thermal Rating: on transformer 12672-7031 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 12672-9288 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 10498-6346 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 10498-12400 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 10498-5842 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 11164-266 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 11164-7249 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 11164-13456 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1926-5592 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 1926-496 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 3612-4324 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 9112-11065 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 9112-3990 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 9112-10612 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 6134-3517 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 6134-12091 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 6134-5029 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 10024-11577 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 10024-4513 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1034-13086 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1034-6016 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1034-7933 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 2874-1382 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 2874-8415 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 11508-1834 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 58
% INFO    : Updated Thermal Rating: on transformer 12413-8900 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 12413-9321 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 9876-9389 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 38
% INFO    : Updated Thermal Rating: on transformer 2010-2756 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 2010-9860 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 9161-3234 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 9161-9169 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 8337-5593 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 8337-12681 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 11433-6076 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 11433-11145 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 11433-4590 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 12371-11652 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 12371-5099 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 2511-1031 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 2511-7561 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 8917-10218 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 8917-8205 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 8917-9081 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 7984-11285 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 7984-4752 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 7984-7754 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 12860-2627 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1787
% INFO    : Updated Thermal Rating: on transformer 12860-9265 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1787
% INFO    : Updated Thermal Rating: on transformer 6424-3543 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 6424-10158 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 7584-8109 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 7584-11880 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 10664-12563 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1787
% INFO    : Updated Thermal Rating: on transformer 5020-2670 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 448
% INFO    : Updated Thermal Rating: on transformer 5020-9301 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 448
% INFO    : Updated Thermal Rating: on transformer 9270-12902 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 114
% INFO    : Updated Thermal Rating: on transformer 9270-5357 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 114
% INFO    : Updated Thermal Rating: on transformer 12081-12387 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 12081-2790 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 9239-5166 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 9239-7146 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 7040-937 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 7040-8409 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 420-1376 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 420-6990 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4827-13639 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 116
% INFO    : Updated Thermal Rating: on transformer 4827-7167 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 116
% INFO    : Updated Thermal Rating: on transformer 5659-4718 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1787
% INFO    : Updated Thermal Rating: on transformer 9703-2624 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1787
% INFO    : Updated Thermal Rating: on transformer 8673-12636 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 8673-7236 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 11431-715 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 11431-7700 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 13461-11030 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 448
% INFO    : Updated Thermal Rating: on transformer 8684-8206 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 8684-1641 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 2862-11638 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 2862-2102 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 3092-5416 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 183
% INFO    : Updated Thermal Rating: on transformer 3092-12451 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 183
% INFO    : Updated Thermal Rating: on transformer 3092-10386 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 183
% INFO    : Updated Thermal Rating: on transformer 8985-3270 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 38
% INFO    : Updated Thermal Rating: on transformer 6579-9896 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 9454-2785 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 9454-2767 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 9454-4282 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 6904-10881 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 6904-3771 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 6904-10417 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 7629-754 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 7629-5456 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 2954-6992 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 2954-13147 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 2216-4367 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1787
% INFO    : Updated Thermal Rating: on transformer 4769-13322 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1787
% INFO    : Updated Thermal Rating: on transformer 4769-4670 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1787
% INFO    : Updated Thermal Rating: on transformer 4769-10715 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1787
% INFO    : Updated Thermal Rating: on transformer 2450-11076 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 6856-12208 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1787
% INFO    : Updated Thermal Rating: on transformer 6856-5674 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1787
% INFO    : Updated Thermal Rating: on transformer 1380-13467 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 58
% INFO    : Updated Thermal Rating: on transformer 6945-1906 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 6945-4366 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 5744-2351 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 39
% INFO    : Updated Thermal Rating: on transformer 9066-8958 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3718
% INFO    : Updated Thermal Rating: on transformer 12432-3607 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 12432-9738 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 12584-9084 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 12584-5444 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 10323-12494 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 10323-9035 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 10323-1969 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 1986-2592 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 11735-7388 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4466
% INFO    : Updated Thermal Rating: on transformer 11735-5797 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1787
% INFO    : Updated Thermal Rating: on transformer 11735-12874 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1787
% INFO    : Updated Thermal Rating: on transformer 11735-6903 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1787
% INFO    : Updated Thermal Rating: on transformer 11735-13530 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1787
% INFO    : Updated Thermal Rating: on transformer 11735-3280 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1340
% INFO    : Updated Thermal Rating: on transformer 11735-11619 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1340
% INFO    : Updated Thermal Rating: on transformer 4523-66 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 4523-7073 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 13107-533 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 6922-7511 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 10124-7551 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 371
% INFO    : Updated Thermal Rating: on transformer 10124-567 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 371
% INFO    : Updated Thermal Rating: on transformer 7441-5587 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1861
% INFO    : Updated Thermal Rating: on transformer 7678-12665 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1861
% INFO    : Updated Thermal Rating: on transformer 10320-6058 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1861
% INFO    : Updated Thermal Rating: on transformer 388-13158 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1861
% INFO    : Updated Thermal Rating: on transformer 2913-2964 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 138
% INFO    : Updated Thermal Rating: on transformer 2913-10100 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 138
% INFO    : Updated Thermal Rating: on transformer 2913-3474 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 138
% INFO    : Updated Thermal Rating: on transformer 2913-10581 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 138
% INFO    : Updated Thermal Rating: on transformer 2913-2056 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 138
% INFO    : Updated Thermal Rating: on transformer 2913-9109 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 138
% INFO    : Updated Thermal Rating: on transformer 2913-2496 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 138
% INFO    : Updated Thermal Rating: on transformer 2913-9604 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 138
% INFO    : Updated Thermal Rating: on transformer 1898-9597 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 11378-8191 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 11378-10249 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 11378-6465 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 11378-5764 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 11378-12321 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 11378-5292 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 11378-11822 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 11378-4777 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 11378-11328 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 11378-4252 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 11378-10845 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 12707-5637 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 12707-5718 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 1282-3823 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 1282-10918 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 1282-2368 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 1282-470 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 1282-4203 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 2985-6651 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 2985-10738 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 2985-4120 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 2985-2172 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 2985-8753 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 2985-9627 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3718
% INFO    : Updated Thermal Rating: on transformer 1282-8770 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 1282-819 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 1282-3553 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 1282-1262 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 6724-11677 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 6724-10390 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 5402-4509 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3718
% INFO    : Updated Thermal Rating: on transformer 5402-6085 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3718
% INFO    : Updated Thermal Rating: on transformer 10981-3330 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 79
% INFO    : Updated Thermal Rating: on transformer 3238-4309 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 3238-585 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 3238-3792 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 3238-10901 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 3238-3296 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 9831-10406 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 131
% INFO    : Updated Thermal Rating: on transformer 13656-9206 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 13656-2625 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 11702-693 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 11702-7233 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 9098-11403 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 9098-2053 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 9098-7674 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 61-13192 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3718
% INFO    : Updated Thermal Rating: on transformer 10744-1559 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1771
% INFO    : Updated Thermal Rating: on transformer 10278-2197 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1787
% INFO    : Updated Thermal Rating: on transformer 2474-3922 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 2474-11010 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 1286-2955 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 7368-10092 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 7368-3471 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 9490-10575 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 9490-3947 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 9490-11039 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 5329-4483 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 5329-11551 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 11941-4985 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 11941-12049 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 12482-9408 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 12482-7499 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 5577-5761 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 5577-12310 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 5577-7164 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 5577-182 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1506-10165 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 5015-5036 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 5015-13658 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 6113-3165 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 9643-5517 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 10689-6847 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 10689-12973 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 3601-10987 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 3601-753 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 5572-7734 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 5572-289 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 6653-7071 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 6653-13235 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 6653-6620 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 6653-10505 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 6653-6729 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 6653-11786 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 537-9852 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 530-3224 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 13654-4400 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1787
% INFO    : Updated Thermal Rating: on transformer 13654-11982 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1787
% INFO    : Updated Thermal Rating: on transformer 13654-4928 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1787
% INFO    : Updated Thermal Rating: on transformer 488-476 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 4669-4371 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 6887-12381 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 6887-5350 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 5153-12914 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 5153-5825 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 12209-1394 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 13263-6667 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 10020-229 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 10020-6769 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 7817-10388 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 7817-6842 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4463-2301 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 4104-2561 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4104-8651 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 7423-11504 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 8031-13012 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 8031-1636 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 8031-7712 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 2109-7005 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 2109-492 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 2109-7045 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 2121-5534 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 2121-12606 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 7741-5034 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 4071-13620 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 4071-6500 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 4071-13123 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 7101-4013 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 7101-11096 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 1585-3551 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 1585-10647 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 374-2819 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 374-5575 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 11767-5023 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 11767-11586 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 10265-9815 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 843-2642 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 11297-4344 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 11297-778 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 8020-6476 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 2452-13079 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 2452-7654 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 4736-12016 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 4736-13333 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 10338-1561 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 7483-2559 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 7483-11588 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4373-3031 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 11541-648 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 3208-328 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 2802-6886 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 2754-8772 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 1405-7474 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 11590-248 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 13563-1629 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 6805-1419 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 6805-8447 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 10360-956 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 10360-7342 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 12963-12794 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 1107-5714 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 317-358 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 4850-7334 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 4850-13560 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 4850-10567 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 12364-7929 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 12364-10102 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 10131-828 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 1141-7808 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 1141-12065 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 1141-5503 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 13004-11578 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 399-8914 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 399-2292 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 9019-9387 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 9019-932 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 5874-7931 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 7534-2894 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 7534-9527 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 1998-1552 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 1998-8097 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 4318-9875 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 4318-2760 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 4318-10357 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 4318-3255 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 4318-13137 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 4318-1851 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 4318-9392 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 4318-2302 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 8240-10946 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 8472-13145 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 5555-13081 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 6712-6477 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 6712-12570 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 13061-4622 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 5474-12088 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 200-5512 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 9356-11579 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 9356-5025 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4325-532 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 4325-7072 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 10849-12373 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 10849-5816 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 9162-9250 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 9162-3463 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 4316-6713 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 7104-3943 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 5867-12477 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 5867-5911 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 2926-12013 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 595
% INFO    : Updated Thermal Rating: on transformer 857-4952 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 9320-11037 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 12514-4473 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 3952-1369 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 3952-7925 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 3952-925 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 3952-3469 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 611-6096 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 3532-9542 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 3532-4256 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 9390-10841 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 9390-9556 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 11547-9690 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 11547-2584 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 11488-12799 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 11488-4686 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 11488-11251 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 49-4126 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1681-11214 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 574-3646 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 574-10743 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 574-1070 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 5461-7613 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 5461-1532 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 6248-8089 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 12976-12042 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 13210-8563 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 13210-2458 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 9451-12419 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 9451-9120 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 9451-2063 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 4093-4167 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4093-11250 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4093-1359 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4093-11773 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 2404-3166 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 2404-10283 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 2404-3680 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 9259-4130 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 5259-6195 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 5259-13298 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1129-8421 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1129-2222 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1016-11377 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 8230-1796 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 6356-11895 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 6356-13232 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 6356-1043 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 2846-8945 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 2846-2787 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 2846-9417 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 915-9282 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 915-2647 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 915-9756 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 11381-3396 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 11381-11473 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 11381-4925 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 960-10978 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 960-4411 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 960-10862 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 5860-1960 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 5860-115 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4401-6066 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 2240-11745 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 2240-4697 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 12752-11226 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 12752-3663 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 12752-9793 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 10741-6156 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 10741-11716 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4033-1013 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4033-9138 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 8480-10037 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 8480-1869 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 8480-12388 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 5565-10110 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 5565-7976 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 5565-9314 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 3809-10534 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 3809-4949 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 3809-11986 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 1490-10017 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 1490-3403 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 1490-9508 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 12185-4793 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 12185-13330 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 12185-10223 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 3140-8538 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 3140-1963 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 3140-11975 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 9050-7156 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 9050-5715 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 11216-5896 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 11216-13468 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 11216-6363 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 2848-11976 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 2848-4922 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 2848-12459 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 5799-8655 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 5799-8912 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 5799-1839 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 5799-11558 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 5799-4998 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 5799-11051 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 5799-4499 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 5799-10589 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 5799-3971 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 5799-10101 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 10826-3482 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 10826-9613 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 10826-2976 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 10826-8387 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 10826-1344 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 10826-10617 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 10826-901 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 10826-9359 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 10826-681 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 10826-8884 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 10180-7849 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 9689-11736 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 10859-2569 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 7106-1627 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 4150-10373 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 746
% INFO    : Updated Thermal Rating: on transformer 119-5192 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 8722-921 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 8722-676 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 8722-1372 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 8722-8894 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 8410-5138 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 8410-10246 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 8410-3633 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 8410-9342 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 1303-3984 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 1303-12415 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 1303-4505 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 3116-2205 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 31
% INFO    : Updated Thermal Rating: on transformer 3116-8791 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 31
% INFO    : Updated Thermal Rating: on transformer 7896-10448 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 7896-3343 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 7896-7133 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 7896-134 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 10888-197 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 10888-6734 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 10888-926 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 5604-12411 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 5604-5850 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 5604-12934 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 5604-6331 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 1388-7354 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3718
% INFO    : Updated Thermal Rating: on transformer 1388-11521 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3718
% INFO    : Updated Thermal Rating: on transformer 1388-4959 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3718
% INFO    : Updated Thermal Rating: on transformer 2306-3409 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 60
% INFO    : Updated Thermal Rating: on transformer 2306-10022 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 60
% INFO    : Updated Thermal Rating: on transformer 2306-3886 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 60
% INFO    : Updated Thermal Rating: on transformer 2306-10516 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 60
% INFO    : Updated Thermal Rating: on transformer 6137-12097 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 6137-5546 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 6137-7539 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 6137-6025 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 6137-8519 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 6137-8389 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 6137-2510 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 6137-815 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 1029-3893 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 62
% INFO    : Updated Thermal Rating: on transformer 1029-10986 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 62
% INFO    : Updated Thermal Rating: on transformer 1029-3434 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 62
% INFO    : Updated Thermal Rating: on transformer 1029-10520 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 62
% INFO    : Updated Thermal Rating: on transformer 12004-1123 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 12004-7667 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 12004-4495 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 12004-11049 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 12004-10629 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 12004-4000 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 12004-6912 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 290-2464 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21
% INFO    : Updated Thermal Rating: on transformer 2064-5135 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 2064-12211 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 2064-4616 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 2064-11680 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 2064-4102 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 11501-1104 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 11501-1055 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 11501-408 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 11501-7371 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 11501-5391 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 11501-8820 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 3786-10998 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3718
% INFO    : Updated Thermal Rating: on transformer 3786-3265 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3718
% INFO    : Updated Thermal Rating: on transformer 2557-13607 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 2557-4987 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 6841-4326 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 6841-12542 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 6841-5977 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 8978-12045 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1377-5490 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 82
% INFO    : Updated Thermal Rating: on transformer 1377-11560 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 82
% INFO    : Updated Thermal Rating: on transformer 1377-2809 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 82
% INFO    : Updated Thermal Rating: on transformer 1377-12323 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 82
% INFO    : Updated Thermal Rating: on transformer 1377-188 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 82
% INFO    : Updated Thermal Rating: on transformer 7876-4703 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 7876-11749 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 7876-9713 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 7876-2610 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 13307-9144 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 13307-1423 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 13307-6998 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 13307-4347 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 13307-10120 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 1996-1462 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 1996-9512 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 1996-2408 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 1996-841 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 1996-7351 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 1996-1274 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 1996-6650 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 1996-13569 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 10312-637 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 10312-7634 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 3461-12786 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 3461-7122 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 3461-7304 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 3461-9357 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 3461-1257 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 3461-8774 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 3461-1732 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 5419-3329 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 5419-9953 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 5419-2828 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 5419-9464 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 5419-4301 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 5419-10907 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 1457-3228 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1457-783 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1457-6861 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 6367-304 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 13233-4209 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 13233-10808 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 13233-3710 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 13233-7784 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 13233-1306 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 13233-6870 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 13233-179 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 13233-11968 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 8692-10315 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 8692-3206 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 8692-11761 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 8692-4715 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 8692-33 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 8692-4217 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 7241-5473 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 7241-12024 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 7241-7297 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 7241-5317 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 7241-12341 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 4003-11797 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 4003-4757 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 4003-7833 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 4003-4226 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 10578-5992 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 10578-2183 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 10578-9273 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 10578-3384 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 10578-10004 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 10578-3877 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 10578-8810 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 64-3148 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 29
% INFO    : Updated Thermal Rating: on transformer 64-4673 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 29
% INFO    : Updated Thermal Rating: on transformer 11878-2676 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4566-9312 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 35
% INFO    : Updated Thermal Rating: on transformer 4566-6127 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 35
% INFO    : Updated Thermal Rating: on transformer 13117-8099 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 13117-2635 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 13117-9742 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 13117-3146 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 13117-10264 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 13117-1731 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 4557-1148 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 35
% INFO    : Updated Thermal Rating: on transformer 4557-2793 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 35
% INFO    : Updated Thermal Rating: on transformer 5258-698 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 103
% INFO    : Updated Thermal Rating: on transformer 5258-10615 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 103
% INFO    : Updated Thermal Rating: on transformer 8475-13411 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 8475-8342 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 8475-1310 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 8475-2347 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 8475-1774 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 2059-12887 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21
% INFO    : Updated Thermal Rating: on transformer 7254-5805 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 7254-13370 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 7254-6278 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 2775-9881 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19
% INFO    : Updated Thermal Rating: on transformer 10704-5260 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 10704-2881 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 10704-2880 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 13279-8530 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 75
% INFO    : Updated Thermal Rating: on transformer 13279-8531 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 75
% INFO    : Updated Thermal Rating: on transformer 13279-8534 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 75
% INFO    : Updated Thermal Rating: on transformer 13279-8535 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 75
% INFO    : Updated Thermal Rating: on transformer 13279-8533 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 75
% INFO    : Updated Thermal Rating: on transformer 5256-6155 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 119
% INFO    : Updated Thermal Rating: on transformer 5256-6159 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 119
% INFO    : Updated Thermal Rating: on transformer 5256-6160 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 119
% INFO    : Updated Thermal Rating: on transformer 5256-10977 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 119
% INFO    : Updated Thermal Rating: on transformer 5256-13261 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 119
% INFO    : Updated Thermal Rating: on transformer 1068-6548 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 1068-6547 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 1068-13069 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 1068-12102 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 1068-6544 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 10340-1957 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 49
% INFO    : Updated Thermal Rating: on transformer 10340-1954 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 49
% INFO    : Updated Thermal Rating: on transformer 10340-1953 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 49
% INFO    : Updated Thermal Rating: on transformer 5566-8053 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 5566-7943 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 5566-8055 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 5566-8056 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 5566-7490 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 5566-7932 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 11468-6641 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 11468-6642 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 11468-6639 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 11468-6640 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 11468-100 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 11468-99 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 2714-102 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 2714-101 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 2714-97 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 2714-96 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 2714-98 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 9646-1505 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 82
% INFO    : Updated Thermal Rating: on transformer 9646-9416 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 82
% INFO    : Updated Thermal Rating: on transformer 9646-1511 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 82
% INFO    : Updated Thermal Rating: on transformer 9646-8200 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 82
% INFO    : Updated Thermal Rating: on transformer 9646-7587 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 82
% INFO    : Updated Thermal Rating: on transformer 3450-5212 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 255
% INFO    : Updated Thermal Rating: on transformer 3450-5213 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 255
% INFO    : Updated Thermal Rating: on transformer 3450-5585 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 255
% INFO    : Updated Thermal Rating: on transformer 3450-5215 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 255
% INFO    : Updated Thermal Rating: on transformer 3450-5216 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 255
% INFO    : Updated Thermal Rating: on transformer 3450-5624 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 255
% INFO    : Updated Thermal Rating: on transformer 205-3867 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 205-3866 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 205-8759 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 2383-1044 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21
% INFO    : Updated Thermal Rating: on transformer 719-1046 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 33
% INFO    : Updated Thermal Rating: on transformer 719-1045 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 33
% INFO    : Updated Thermal Rating: on transformer 900-362 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 900-363 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 900-360 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 900-361 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 900-368 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 900-369 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 900-6931 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 900-6930 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 2052-5777 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 2052-5776 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 2052-5782 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 2052-5781 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 1203-7143 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 34
% INFO    : Updated Thermal Rating: on transformer 1203-7144 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 34
% INFO    : Updated Thermal Rating: on transformer 5642-2166 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 83
% INFO    : Updated Thermal Rating: on transformer 5642-7141 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 83
% INFO    : Updated Thermal Rating: on transformer 5642-594 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 83
% INFO    : Updated Thermal Rating: on transformer 5642-593 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 83
% INFO    : Updated Thermal Rating: on transformer 5642-3614 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 83
% INFO    : Updated Thermal Rating: on transformer 7440-8343 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 7440-12761 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 7440-12760 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 7440-12763 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 7440-8354 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 7440-8357 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 10906-589 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52
% INFO    : Updated Thermal Rating: on transformer 10906-10509 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52
% INFO    : Updated Thermal Rating: on transformer 10906-10510 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52
% INFO    : Updated Thermal Rating: on transformer 3191-10507 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21
% INFO    : Updated Thermal Rating: on transformer 1982-10508 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 43
% INFO    : Updated Thermal Rating: on transformer 1982-6252 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 43
% INFO    : Updated Thermal Rating: on transformer 1982-10512 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 43
% INFO    : Updated Thermal Rating: on transformer 10450-4893 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 10450-4892 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 10450-4897 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 10450-4896 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 13135-1454 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 13135-1453 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 13135-9047 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 13135-1451 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 7100-10361 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26
% INFO    : Updated Thermal Rating: on transformer 7100-3885 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26
% INFO    : Updated Thermal Rating: on transformer 4705-1450 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 4705-1449 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 4705-1448 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 4705-1447 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 4705-9246 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 4705-1381 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 4705-9247 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 8484-11705 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 51
% INFO    : Updated Thermal Rating: on transformer 8484-11709 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 51
% INFO    : Updated Thermal Rating: on transformer 8484-2335 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 51
% INFO    : Updated Thermal Rating: on transformer 3846-9244 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 131
% INFO    : Updated Thermal Rating: on transformer 3846-9243 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 131
% INFO    : Updated Thermal Rating: on transformer 3846-9241 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 131
% INFO    : Updated Thermal Rating: on transformer 3846-9240 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 131
% INFO    : Updated Thermal Rating: on transformer 3846-2163 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 131
% INFO    : Updated Thermal Rating: on transformer 3846-2164 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 131
% INFO    : Updated Thermal Rating: on transformer 6501-4644 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 58
% INFO    : Updated Thermal Rating: on transformer 6501-13351 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 58
% INFO    : Updated Thermal Rating: on transformer 6501-4646 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 58
% INFO    : Updated Thermal Rating: on transformer 6501-4647 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 58
% INFO    : Updated Thermal Rating: on transformer 4869-4648 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 83
% INFO    : Updated Thermal Rating: on transformer 4869-4649 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 83
% INFO    : Updated Thermal Rating: on transformer 4869-4650 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 83
% INFO    : Updated Thermal Rating: on transformer 4869-4651 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 83
% INFO    : Updated Thermal Rating: on transformer 4869-12246 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 83
% INFO    : Updated Thermal Rating: on transformer 8880-12245 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 8880-7178 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1612-8747 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 1612-8746 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 1612-8745 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 1612-8744 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 1612-4206 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 1612-8755 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 4466-12240 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 197
% INFO    : Updated Thermal Rating: on transformer 4466-5170 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 197
% INFO    : Updated Thermal Rating: on transformer 4466-5171 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 197
% INFO    : Updated Thermal Rating: on transformer 4466-5168 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 197
% INFO    : Updated Thermal Rating: on transformer 10044-5169 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 77
% INFO    : Updated Thermal Rating: on transformer 10044-12812 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 77
% INFO    : Updated Thermal Rating: on transformer 10044-5167 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 77
% INFO    : Updated Thermal Rating: on transformer 10044-5164 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 77
% INFO    : Updated Thermal Rating: on transformer 10044-5165 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 77
% INFO    : Updated Thermal Rating: on transformer 7181-5177 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 7181-5178 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 9773-12782 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 83
% INFO    : Updated Thermal Rating: on transformer 9773-12781 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 83
% INFO    : Updated Thermal Rating: on transformer 9773-12780 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 83
% INFO    : Updated Thermal Rating: on transformer 9773-12779 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 83
% INFO    : Updated Thermal Rating: on transformer 9773-12778 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 83
% INFO    : Updated Thermal Rating: on transformer 11466-12777 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 98
% INFO    : Updated Thermal Rating: on transformer 11466-8403 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 98
% INFO    : Updated Thermal Rating: on transformer 10984-364 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21
% INFO    : Updated Thermal Rating: on transformer 6177-8396 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17
% INFO    : Updated Thermal Rating: on transformer 3958-6601 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 3958-250 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 3958-45 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 456-5702 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25
% INFO    : Updated Thermal Rating: on transformer 456-5703 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25
% INFO    : Updated Thermal Rating: on transformer 449-6628 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 449-10117 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 449-10116 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 449-10115 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 40-5697 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 31
% INFO    : Updated Thermal Rating: on transformer 40-5698 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 31
% INFO    : Updated Thermal Rating: on transformer 8256-13268 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 65
% INFO    : Updated Thermal Rating: on transformer 8256-11288 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 65
% INFO    : Updated Thermal Rating: on transformer 8256-10317 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 65
% INFO    : Updated Thermal Rating: on transformer 8256-13269 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 65
% INFO    : Updated Thermal Rating: on transformer 12985-13265 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 40
% INFO    : Updated Thermal Rating: on transformer 12985-13264 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 40
% INFO    : Updated Thermal Rating: on transformer 12985-13266 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 40
% INFO    : Updated Thermal Rating: on transformer 9491-3496 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 9491-3494 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 9491-3495 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 6878-10954 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 6878-13209 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 6878-12556 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 1680-6163 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17
% INFO    : Updated Thermal Rating: on transformer 999-6167 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 79
% INFO    : Updated Thermal Rating: on transformer 999-6168 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 79
% INFO    : Updated Thermal Rating: on transformer 999-6165 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 79
% INFO    : Updated Thermal Rating: on transformer 999-6166 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 79
% INFO    : Updated Thermal Rating: on transformer 999-6170 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 79
% INFO    : Updated Thermal Rating: on transformer 257-809 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 119
% INFO    : Updated Thermal Rating: on transformer 257-11142 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 119
% INFO    : Updated Thermal Rating: on transformer 257-11141 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 119
% INFO    : Updated Thermal Rating: on transformer 257-11144 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 119
% INFO    : Updated Thermal Rating: on transformer 257-11143 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 119
% INFO    : Updated Thermal Rating: on transformer 2633-9778 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 42
% INFO    : Updated Thermal Rating: on transformer 2633-9777 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 42
% INFO    : Updated Thermal Rating: on transformer 2633-8562 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 42
% INFO    : Updated Thermal Rating: on transformer 8327-2107 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 73
% INFO    : Updated Thermal Rating: on transformer 8327-9772 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 73
% INFO    : Updated Thermal Rating: on transformer 8327-9771 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 73
% INFO    : Updated Thermal Rating: on transformer 8327-2664 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 73
% INFO    : Updated Thermal Rating: on transformer 8327-2665 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 73
% INFO    : Updated Thermal Rating: on transformer 11213-2666 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 11213-2667 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 11213-1988 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 11213-2669 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 9731-4066 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 9731-4067 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 9731-4068 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 9731-4069 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 9731-12434 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 13271-11294 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3718
% INFO    : Updated Thermal Rating: on transformer 13271-814 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3718
% INFO    : Updated Thermal Rating: on transformer 3807-12433 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 3807-12430 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 3807-12431 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 3807-12428 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 3807-12429 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 1682-12440 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 1682-6654 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 1682-7967 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 1682-5864 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 10272-11510 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 10272-10930 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 10272-10927 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 10272-10928 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 41-9327 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21
% INFO    : Updated Thermal Rating: on transformer 4149-1836 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14
% INFO    : Updated Thermal Rating: on transformer 5349-9323 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 5349-9322 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 5349-2693 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 5349-2694 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 340-2691 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21
% INFO    : Updated Thermal Rating: on transformer 8019-3233 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 8019-3225 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 8019-2690 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 8019-2687 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 5457-2688 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 12079-346 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 12079-345 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 12079-646 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 12079-649 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 10130-12726 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 10130-10461 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 10130-10462 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 5854-5401 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 148
% INFO    : Updated Thermal Rating: on transformer 5854-5400 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 148
% INFO    : Updated Thermal Rating: on transformer 5854-5399 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 148
% INFO    : Updated Thermal Rating: on transformer 5854-5405 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 148
% INFO    : Updated Thermal Rating: on transformer 5854-5204 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 148
% INFO    : Updated Thermal Rating: on transformer 5854-13434 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 148
% INFO    : Updated Thermal Rating: on transformer 5854-12317 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 148
% INFO    : Updated Thermal Rating: on transformer 2130-3164 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21
% INFO    : Updated Thermal Rating: on transformer 5336-13433 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 5336-12325 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 5336-13439 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 5336-12319 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 5336-13437 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 4575-13440 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 129
% INFO    : Updated Thermal Rating: on transformer 4575-12342 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 129
% INFO    : Updated Thermal Rating: on transformer 4575-6810 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 129
% INFO    : Updated Thermal Rating: on transformer 4575-6809 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 129
% INFO    : Updated Thermal Rating: on transformer 4575-6812 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 129
% INFO    : Updated Thermal Rating: on transformer 4575-6811 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 129
% INFO    : Updated Thermal Rating: on transformer 2959-10281 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 6867-6806 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 6867-6808 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 6867-6807 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 6867-6815 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 6867-6814 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 4503-6709 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 63
% INFO    : Updated Thermal Rating: on transformer 4503-8997 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 63
% INFO    : Updated Thermal Rating: on transformer 4503-3668 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 63
% INFO    : Updated Thermal Rating: on transformer 4503-6698 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 63
% INFO    : Updated Thermal Rating: on transformer 2537-3674 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17
% INFO    : Updated Thermal Rating: on transformer 9105-3675 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21
% INFO    : Updated Thermal Rating: on transformer 8469-8999 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 88
% INFO    : Updated Thermal Rating: on transformer 8469-3673 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 88
% INFO    : Updated Thermal Rating: on transformer 8469-3664 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 88
% INFO    : Updated Thermal Rating: on transformer 8469-3665 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 88
% INFO    : Updated Thermal Rating: on transformer 8469-10445 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 88
% INFO    : Updated Thermal Rating: on transformer 8469-10776 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 88
% INFO    : Updated Thermal Rating: on transformer 6519-13371 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 79
% INFO    : Updated Thermal Rating: on transformer 6519-10778 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 79
% INFO    : Updated Thermal Rating: on transformer 6519-10773 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 79
% INFO    : Updated Thermal Rating: on transformer 6519-10772 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 79
% INFO    : Updated Thermal Rating: on transformer 6519-13323 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 79
% INFO    : Updated Thermal Rating: on transformer 6835-6337 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 6835-6336 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 6835-6335 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 6835-10488 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 6835-10489 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 1472-6088 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1472-5984 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1472-11875 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1472-4154 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 13287-8725 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 88
% INFO    : Updated Thermal Rating: on transformer 13287-10486 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 88
% INFO    : Updated Thermal Rating: on transformer 13287-10483 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 88
% INFO    : Updated Thermal Rating: on transformer 13287-10484 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 88
% INFO    : Updated Thermal Rating: on transformer 2418-12692 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 73
% INFO    : Updated Thermal Rating: on transformer 2418-12679 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 73
% INFO    : Updated Thermal Rating: on transformer 2418-11234 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 73
% INFO    : Updated Thermal Rating: on transformer 2418-13374 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 73
% INFO    : Updated Thermal Rating: on transformer 2418-12741 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 73
% INFO    : Updated Thermal Rating: on transformer 5435-11239 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20
% INFO    : Updated Thermal Rating: on transformer 6898-12723 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 6898-11237 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 6898-11244 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1285-3857 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 1285-11796 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 1285-1884 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 1285-1883 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 1285-1882 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 5438-1881 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 5438-1880 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 5438-1879 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 5438-1878 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 5438-1877 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 5438-1876 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 5438-8456 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 12743-12027 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 79
% INFO    : Updated Thermal Rating: on transformer 12743-1237 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 79
% INFO    : Updated Thermal Rating: on transformer 12743-5031 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 79
% INFO    : Updated Thermal Rating: on transformer 12743-12159 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 79
% INFO    : Updated Thermal Rating: on transformer 12743-4176 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 79
% INFO    : Updated Thermal Rating: on transformer 1973-12020 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 11168-12021 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 167
% INFO    : Updated Thermal Rating: on transformer 11168-12018 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 167
% INFO    : Updated Thermal Rating: on transformer 11168-3059 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 167
% INFO    : Updated Thermal Rating: on transformer 3615-2695 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 178
% INFO    : Updated Thermal Rating: on transformer 3615-8279 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 178
% INFO    : Updated Thermal Rating: on transformer 3615-2686 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 178
% INFO    : Updated Thermal Rating: on transformer 3615-4962 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 178
% INFO    : Updated Thermal Rating: on transformer 3615-4968 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 178
% INFO    : Updated Thermal Rating: on transformer 13295-4967 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 13295-2702 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4876-2318 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 4876-2322 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 4876-2321 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 4876-8939 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 4876-4924 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 4876-8937 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 4876-8938 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 8986-8943 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 8986-8944 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 8986-8941 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 8986-13285 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 8883-8717 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 8883-8716 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 8883-2147 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 1235-6431 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 80
% INFO    : Updated Thermal Rating: on transformer 1235-6433 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 80
% INFO    : Updated Thermal Rating: on transformer 1235-6432 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 80
% INFO    : Updated Thermal Rating: on transformer 1235-11350 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 80
% INFO    : Updated Thermal Rating: on transformer 1235-11346 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 80
% INFO    : Updated Thermal Rating: on transformer 12350-11355 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 7258-2146 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 7258-2143 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 7258-2144 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 7258-1263 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 5915-3515 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 5915-3781 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 5915-3782 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 5915-3787 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 5915-7970 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 7790-13029 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 42
% INFO    : Updated Thermal Rating: on transformer 7790-13030 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 42
% INFO    : Updated Thermal Rating: on transformer 7790-13026 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 42
% INFO    : Updated Thermal Rating: on transformer 7552-13027 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 75
% INFO    : Updated Thermal Rating: on transformer 7552-5958 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 75
% INFO    : Updated Thermal Rating: on transformer 7552-5957 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 75
% INFO    : Updated Thermal Rating: on transformer 7552-5956 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 75
% INFO    : Updated Thermal Rating: on transformer 7552-5955 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 75
% INFO    : Updated Thermal Rating: on transformer 4803-10405 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 4803-10404 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 4803-8301 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 4803-10402 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 4803-10401 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 6993-5961 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 6993-660 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 6993-12521 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 6993-12522 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 6993-12523 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 650-7070 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18
% INFO    : Updated Thermal Rating: on transformer 7271-7981 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 7271-7979 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 7271-7452 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 7271-7988 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 7271-7989 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 7271-69 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 7271-68 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 9031-7350 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 9031-7349 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4865-7352 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4865-6963 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 8177-3714 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 8177-3712 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 8177-7346 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 8489-7345 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 15
% INFO    : Updated Thermal Rating: on transformer 6995-336 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 62
% INFO    : Updated Thermal Rating: on transformer 6995-337 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 62
% INFO    : Updated Thermal Rating: on transformer 6995-334 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 62
% INFO    : Updated Thermal Rating: on transformer 6995-12562 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 62
% INFO    : Updated Thermal Rating: on transformer 2965-6372 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 2965-6371 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 2965-6370 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 2965-6369 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 1756-338 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 63
% INFO    : Updated Thermal Rating: on transformer 1756-339 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 63
% INFO    : Updated Thermal Rating: on transformer 1756-13538 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 63
% INFO    : Updated Thermal Rating: on transformer 1756-11887 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 63
% INFO    : Updated Thermal Rating: on transformer 3173-12863 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21
% INFO    : Updated Thermal Rating: on transformer 7954-12864 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 71
% INFO    : Updated Thermal Rating: on transformer 7954-12858 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 71
% INFO    : Updated Thermal Rating: on transformer 7954-13535 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 71
% INFO    : Updated Thermal Rating: on transformer 7954-13532 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 71
% INFO    : Updated Thermal Rating: on transformer 7954-13533 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 71
% INFO    : Updated Thermal Rating: on transformer 1370-12847 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 43
% INFO    : Updated Thermal Rating: on transformer 1370-13531 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 43
% INFO    : Updated Thermal Rating: on transformer 1370-6892 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 43
% INFO    : Updated Thermal Rating: on transformer 12923-10222 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 127
% INFO    : Updated Thermal Rating: on transformer 12923-613 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 127
% INFO    : Updated Thermal Rating: on transformer 12923-6893 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 127
% INFO    : Updated Thermal Rating: on transformer 1156-8843 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 1156-8844 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 1156-8841 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 1156-8842 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 1156-12772 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 12143-4764 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 12143-165 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 12143-11805 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 12143-135 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 12143-2870 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 12143-114 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 3480-9897 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 3480-9900 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 5377-13032 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 63
% INFO    : Updated Thermal Rating: on transformer 5377-13024 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 63
% INFO    : Updated Thermal Rating: on transformer 5377-6179 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 63
% INFO    : Updated Thermal Rating: on transformer 5377-6430 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 63
% INFO    : Updated Thermal Rating: on transformer 7407-6429 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52
% INFO    : Updated Thermal Rating: on transformer 7407-6428 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52
% INFO    : Updated Thermal Rating: on transformer 7407-6427 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52
% INFO    : Updated Thermal Rating: on transformer 7714-4345 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 7714-4343 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 7714-5262 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 7714-5261 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 7714-4314 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 7714-5252 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 7353-839 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 30
% INFO    : Updated Thermal Rating: on transformer 7353-840 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 30
% INFO    : Updated Thermal Rating: on transformer 6271-5323 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 6271-5324 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 6271-5327 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 6271-5328 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 6271-5325 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 6271-5326 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 1793-836 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 74
% INFO    : Updated Thermal Rating: on transformer 1793-837 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 74
% INFO    : Updated Thermal Rating: on transformer 1793-7824 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 74
% INFO    : Updated Thermal Rating: on transformer 1793-6665 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 74
% INFO    : Updated Thermal Rating: on transformer 1793-6673 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 74
% INFO    : Updated Thermal Rating: on transformer 7223-7825 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 79
% INFO    : Updated Thermal Rating: on transformer 7223-7820 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 79
% INFO    : Updated Thermal Rating: on transformer 7223-7819 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 79
% INFO    : Updated Thermal Rating: on transformer 7223-7822 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 79
% INFO    : Updated Thermal Rating: on transformer 7223-7821 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 79
% INFO    : Updated Thermal Rating: on transformer 11657-7476 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 11657-7477 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 11657-1401 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 9729-3997 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 9729-5163 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 9729-5159 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 9729-2198 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 9729-9862 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 9729-12915 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 9729-5143 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 9729-9870 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 10227-6141 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3718
% INFO    : Updated Thermal Rating: on transformer 10227-11909 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3718
% INFO    : Updated Thermal Rating: on transformer 9285-3013 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 1248-3015 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 9904-5359 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 55
% INFO    : Updated Thermal Rating: on transformer 9904-3011 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 55
% INFO    : Updated Thermal Rating: on transformer 9845-12986 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 9845-12984 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 7816-3012 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 2626-12993 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 2626-12994 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 2626-4926 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1054-5060 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1787
% INFO    : Updated Thermal Rating: on transformer 1054-5059 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1787
% INFO    : Updated Thermal Rating: on transformer 8812-5058 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 8812-5065 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 9419-5064 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 9419-5063 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 9419-5062 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 929-4932 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 929-4931 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 929-1079 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 7355-12084 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 7355-12085 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 4754-1090 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4754-11471 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 12640-1073 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 10889-6865 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 10889-11474 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 7239-11481 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 5893-11482 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 5893-8719 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 5893-3625 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 3390-6162 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 3390-6161 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 13014-3621 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 115
% INFO    : Updated Thermal Rating: on transformer 13014-3622 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 115
% INFO    : Updated Thermal Rating: on transformer 11341-3619 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 11341-3620 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4230-11333 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1340
% INFO    : Updated Thermal Rating: on transformer 4230-11332 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1340
% INFO    : Updated Thermal Rating: on transformer 2724-4253 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1340
% INFO    : Updated Thermal Rating: on transformer 2724-4254 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1340
% INFO    : Updated Thermal Rating: on transformer 1580-12764 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 1580-12765 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 5506-10720 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 5506-10719 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 10725-10722 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 10725-10721 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 10725-10713 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 3950-10712 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 3950-3107 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 3950-3108 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 269-3109 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 269-5931 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 269-3111 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 5113-3112 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 5917-3113 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 3069-5695 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 3069-4393 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 8790-3114 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 8790-7291 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 8790-10236 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 349-10378 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 349-10377 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 9516-5322 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 9516-10238 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 13276-10375 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 13276-10374 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 355-10242 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 355-10241 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 7941-4618 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 7941-4619 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 3032-855 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 3060-4617 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 5203-5287 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 5203-5286 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 12735-2389 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 12735-405 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 12735-406 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 12339-6406 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1787
% INFO    : Updated Thermal Rating: on transformer 11063-7372 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 11063-11529 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 11063-7370 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 7310-7369 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 7310-7376 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 7310-7375 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 7310-7374 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 6124-3838 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 8697-7379 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 8697-7378 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 3659-3934 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 116
% INFO    : Updated Thermal Rating: on transformer 3659-867 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 116
% INFO    : Updated Thermal Rating: on transformer 7708-865 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 7708-5385 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 7708-864 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 7708-861 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 7708-862 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4311-4452 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1787
% INFO    : Updated Thermal Rating: on transformer 9193-874 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 9193-10363 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 9193-10348 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 9193-7847 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 3759-6774 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 3759-6785 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 3759-7848 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 3759-7851 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 3759-6789 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 3759-7842 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 13194-7841 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 13194-10034 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1616-13052 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1616-13053 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1616-13054 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1616-13047 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1616-13048 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1616-13049 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1375-5352 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1375-13057 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1375-13058 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 12377-6456 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 12377-6455 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4711-4197 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 13164-4195 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1787
% INFO    : Updated Thermal Rating: on transformer 13267-6452 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 303-6451 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 10454-2974 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 10454-2973 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 10454-2969 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 10454-2968 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 10454-9880 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 3439-8373 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 3439-9885 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 3439-10410 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 3439-8378 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 3439-9887 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 5735-8380 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 5735-10096 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 5735-8369 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 7065-6262 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1787
% INFO    : Updated Thermal Rating: on transformer 7065-12859 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1787
% INFO    : Updated Thermal Rating: on transformer 7065-8921 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1787
% INFO    : Updated Thermal Rating: on transformer 11134-1342 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 11134-1343 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 11134-8457 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 11134-8459 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 11134-1338 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 11134-1339 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 11134-1348 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 7607-1349 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4295-7902 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4295-7901 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 12399-7056 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 9688-7899 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 11906-7075 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 11906-7905 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 12502-7904 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 12502-7903 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 12502-7908 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 13559-2345 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 12405-9439 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 12493-12346 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1787
% INFO    : Updated Thermal Rating: on transformer 12493-485 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1787
% INFO    : Updated Thermal Rating: on transformer 6525-12348 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1787
% INFO    : Updated Thermal Rating: on transformer 1635-4501 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1635-4512 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1635-904 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1635-5668 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1635-5670 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1635-907 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 6991-9350 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 6991-9349 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 6991-9352 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 6991-9351 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 6991-9346 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 6991-9345 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 6991-9348 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 6991-9347 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 10515-4612 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 6745-5311 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1787
% INFO    : Updated Thermal Rating: on transformer 6745-11853 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1787
% INFO    : Updated Thermal Rating: on transformer 12832-11854 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1787
% INFO    : Updated Thermal Rating: on transformer 12832-11851 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1787
% INFO    : Updated Thermal Rating: on transformer 13376-3152 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1787
% INFO    : Updated Thermal Rating: on transformer 3689-2249 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 3689-610 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 3689-2247 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 3689-2248 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 3689-2252 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 5511-2253 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 5511-12856 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 5511-8867 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 5511-8866 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 5511-9914 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 5511-8864 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 5511-12843 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 5511-12840 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 11269-8861 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 11269-8860 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 9582-8167 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1787
% INFO    : Updated Thermal Rating: on transformer 9582-11360 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1787
% INFO    : Updated Thermal Rating: on transformer 3212-11361 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1787
% INFO    : Updated Thermal Rating: on transformer 3212-11362 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1787
% INFO    : Updated Thermal Rating: on transformer 6069-11363 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 9994-1805 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 9994-11336 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 9994-1807 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 7863-1808 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 7863-1803 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 10552-11327 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 10552-6542 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 10552-6541 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 10552-12106 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 10552-6543 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 9298-12904 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 9298-6545 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 5046-3325 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 5046-3326 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4215-3327 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4215-3328 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 2033-8445 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 2033-10422 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 2634-8441 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 61
% INFO    : Updated Thermal Rating: on transformer 2634-10420 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 61
% INFO    : Updated Thermal Rating: on transformer 3475-10427 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 147
% INFO    : Updated Thermal Rating: on transformer 3475-10426 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 147
% INFO    : Updated Thermal Rating: on transformer 3475-10425 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 147
% INFO    : Updated Thermal Rating: on transformer 3475-10424 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 147
% INFO    : Updated Thermal Rating: on transformer 3475-10430 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 147
% INFO    : Updated Thermal Rating: on transformer 3475-10429 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 147
% INFO    : Updated Thermal Rating: on transformer 3475-4546 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 147
% INFO    : Updated Thermal Rating: on transformer 3475-4545 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 147
% INFO    : Updated Thermal Rating: on transformer 606-4548 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 606-4547 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 606-4550 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 606-4549 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 606-4552 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 606-4551 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 606-4554 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4667-4553 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4667-11110 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 13517-11111 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 13517-11108 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 13517-11109 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 13517-11106 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 9749-11107 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 9749-11104 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 9749-12747 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 9749-11102 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 9749-12742 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 7207-4025 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 7207-4024 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 12238-11229 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 3251-4022 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 151
% INFO    : Updated Thermal Rating: on transformer 3251-4029 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 151
% INFO    : Updated Thermal Rating: on transformer 3251-4028 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 151
% INFO    : Updated Thermal Rating: on transformer 6613-4027 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 6613-4026 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 5839-4021 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 5839-4020 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 5839-10653 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 9998-11289 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 9998-11309 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 9998-10656 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 8287-10657 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 173
% INFO    : Updated Thermal Rating: on transformer 8287-10658 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 173
% INFO    : Updated Thermal Rating: on transformer 8287-10659 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 173
% INFO    : Updated Thermal Rating: on transformer 5786-10660 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 5786-10648 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 5786-10649 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 2291-5612 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 2291-5611 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4078-5614 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1919-5613 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1919-5608 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 3391-5607 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 133
% INFO    : Updated Thermal Rating: on transformer 3391-5610 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 133
% INFO    : Updated Thermal Rating: on transformer 3391-5609 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 133
% INFO    : Updated Thermal Rating: on transformer 3391-5606 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 133
% INFO    : Updated Thermal Rating: on transformer 3391-5605 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 133
% INFO    : Updated Thermal Rating: on transformer 12003-12168 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 12003-12169 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 12003-12166 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 12003-12167 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 12003-12172 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 13566-11203 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 13566-12170 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 13566-12171 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 13566-12163 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 13566-12164 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 13566-5057 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 13566-5056 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 13566-5055 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 13566-5054 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 3802-5053 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 3802-5052 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 3802-5051 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 13177-5050 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 66
% INFO    : Updated Thermal Rating: on transformer 13177-3316 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 66
% INFO    : Updated Thermal Rating: on transformer 13177-3311 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 66
% INFO    : Updated Thermal Rating: on transformer 13177-11621 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 66
% INFO    : Updated Thermal Rating: on transformer 13177-11622 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 66
% INFO    : Updated Thermal Rating: on transformer 11517-11623 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 11517-11624 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 11517-11617 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 11517-10151 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 11517-10164 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 8047-10178 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 8047-11625 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 8047-11626 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 8047-6567 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 8047-6566 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 8521-12070 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 8521-12069 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 8521-4449 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 8521-12071 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 8521-12074 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 8521-12073 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 8521-12076 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 8521-12075 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 8521-5009 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 8521-2963 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 8521-5007 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 8521-5008 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4638-3763 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 4638-3297 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 4638-3298 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 4638-3299 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 4638-3306 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 4638-3307 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 4638-7844 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 4638-6773 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 4638-7846 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 7987-10558 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3718
% INFO    : Updated Thermal Rating: on transformer 7987-9152 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3718
% INFO    : Updated Thermal Rating: on transformer 7987-10555 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3718
% INFO    : Updated Thermal Rating: on transformer 7987-10556 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3718
% INFO    : Updated Thermal Rating: on transformer 9538-6398 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 9538-11227 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 9538-11231 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 9538-9974 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 9538-13500 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 9538-2858 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 9538-13502 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 11283-13505 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 11283-2871 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 11283-13507 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 11283-13506 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 11283-13497 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 11283-13496 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 11283-5928 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 3572-5929 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 3572-5930 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 3572-10622 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 3572-5932 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 3572-5933 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 3572-5934 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 3572-5935 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 3572-5936 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 3572-8323 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4605-13009 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4605-13008 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4605-13007 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 2696-11167 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 2696-10627 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 2696-11172 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 2696-13062 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 2696-13066 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 2696-11174 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 2696-11175 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 2696-3104 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 2696-3103 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 823-7282 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27
% INFO    : Updated Thermal Rating: on transformer 823-7283 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27
% INFO    : Updated Thermal Rating: on transformer 823-7286 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27
% INFO    : Updated Thermal Rating: on transformer 823-7287 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27
% INFO    : Updated Thermal Rating: on transformer 823-7284 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27
% INFO    : Updated Thermal Rating: on transformer 823-3226 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27
% INFO    : Updated Thermal Rating: on transformer 823-3242 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27
% INFO    : Updated Thermal Rating: on transformer 823-3245 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27
% INFO    : Updated Thermal Rating: on transformer 6350-773 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 6350-1791 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 9018-775 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 103
% INFO    : Updated Thermal Rating: on transformer 9018-774 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 103
% INFO    : Updated Thermal Rating: on transformer 6895-769 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 179
% INFO    : Updated Thermal Rating: on transformer 6895-768 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 179
% INFO    : Updated Thermal Rating: on transformer 6895-771 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 179
% INFO    : Updated Thermal Rating: on transformer 6895-770 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 179
% INFO    : Updated Thermal Rating: on transformer 6895-4781 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 179
% INFO    : Updated Thermal Rating: on transformer 6895-776 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 179
% INFO    : Updated Thermal Rating: on transformer 7515-10064 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3718
% INFO    : Updated Thermal Rating: on transformer 7515-10065 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3718
% INFO    : Updated Thermal Rating: on transformer 5150-4083 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 5150-11520 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 5150-11536 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 1499-4084 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 1499-4087 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 1499-11649 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 13477-10060 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3718
% INFO    : Updated Thermal Rating: on transformer 13477-6368 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3718
% INFO    : Updated Thermal Rating: on transformer 13477-3451 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3718
% INFO    : Updated Thermal Rating: on transformer 13477-7776 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3718
% INFO    : Updated Thermal Rating: on transformer 8249-312 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 8249-311 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 8249-310 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 8249-309 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 6575-308 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 6575-307 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 13011-306 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 13011-305 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 13011-4434 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 13011-13512 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 13011-4432 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 13011-4433 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 12101-4430 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 8287-4431 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 173
% INFO    : Updated Thermal Rating: on transformer 8287-4428 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 173
% INFO    : Updated Thermal Rating: on transformer 8287-4429 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 173
% INFO    : Updated Thermal Rating: on transformer 9324-4426 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 9324-4427 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 9324-1189 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 9324-5330 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 9324-11498 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 9324-11497 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 9324-11500 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 9324-11499 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 11400-5990 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4466
% INFO    : Updated Thermal Rating: on transformer 11400-5989 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4466
% INFO    : Updated Thermal Rating: on transformer 11888-5988 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4466
% INFO    : Updated Thermal Rating: on transformer 11888-5987 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4466
% INFO    : Updated Thermal Rating: on transformer 13198-145 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4466
% INFO    : Updated Thermal Rating: on transformer 13198-800 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4466
% INFO    : Updated Thermal Rating: on transformer 1373-147 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4466
% INFO    : Updated Thermal Rating: on transformer 1373-146 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4466
% INFO    : Updated Thermal Rating: on transformer 7251-2711 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 7251-9477 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 5446-2705 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 5446-2703 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4349-9474 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4349-9473 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4349-2369 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4349-2370 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4349-2371 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 665-10023 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 665-3910 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 665-3911 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 665-3908 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 665-3909 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 665-3906 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 665-3907 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 665-10538 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 665-10537 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 1251-12884 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 1251-9060 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 1251-12882 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 1251-12883 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 1251-12880 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 1251-9051 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 12241-12878 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 12241-9045 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 12241-6277 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 12241-6276 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 12241-6279 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 12241-12509 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 3506-6201 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3718
% INFO    : Updated Thermal Rating: on transformer 3506-6202 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3718
% INFO    : Updated Thermal Rating: on transformer 3768-6203 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3718
% INFO    : Updated Thermal Rating: on transformer 3768-6204 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3718
% INFO    : Updated Thermal Rating: on transformer 7975-6208 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3718
% INFO    : Updated Thermal Rating: on transformer 7975-1656 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3718
% INFO    : Updated Thermal Rating: on transformer 1892-12818 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3718
% INFO    : Updated Thermal Rating: on transformer 1892-12817 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3718
% INFO    : Updated Thermal Rating: on transformer 13605-10670 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 151
% INFO    : Updated Thermal Rating: on transformer 13605-10456 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 151
% INFO    : Updated Thermal Rating: on transformer 13605-10690 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 151
% INFO    : Updated Thermal Rating: on transformer 13605-8513 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 151
% INFO    : Updated Thermal Rating: on transformer 13605-10518 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 151
% INFO    : Updated Thermal Rating: on transformer 13605-10681 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 151
% INFO    : Updated Thermal Rating: on transformer 13605-10700 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 151
% INFO    : Updated Thermal Rating: on transformer 13605-8516 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 151
% INFO    : Updated Thermal Rating: on transformer 3831-1477 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 3831-1478 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 3831-1479 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 13250-9214 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 150
% INFO    : Updated Thermal Rating: on transformer 13250-1481 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 150
% INFO    : Updated Thermal Rating: on transformer 13250-1482 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 150
% INFO    : Updated Thermal Rating: on transformer 13250-1483 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 150
% INFO    : Updated Thermal Rating: on transformer 1420-1484 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1420-1485 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1420-1486 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4636-1473 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 4636-1474 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 4636-1475 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 4636-1476 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 4636-1470 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 4636-1471 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 5253-11496 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 5253-2236 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 5253-11507 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 5253-11506 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 5253-4424 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 5253-4425 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 5253-13482 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 5253-13486 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 5253-13466 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 5253-4422 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 1126-1928 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 64
% INFO    : Updated Thermal Rating: on transformer 1126-3346 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 64
% INFO    : Updated Thermal Rating: on transformer 5375-1935 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 5375-1936 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 5375-7564 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 2212-7563 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 2212-7562 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 7192-11752 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 7192-7560 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 7192-7559 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 7192-7558 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 7192-7557 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 7192-11892 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 7792-1997 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3718
% INFO    : Updated Thermal Rating: on transformer 10491-8570 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3718
% INFO    : Updated Thermal Rating: on transformer 5404-8571 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3718
% INFO    : Updated Thermal Rating: on transformer 7983-8569 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3718
% INFO    : Updated Thermal Rating: on transformer 13572-581 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 13572-575 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 13572-576 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 13572-577 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1768-7645 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 1768-7649 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 1768-7648 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 1574-9256 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 1574-9257 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 1574-9258 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 12142-7426 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 12142-9260 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 12142-9261 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 12250-2090 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 12250-2091 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 12250-2093 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 1100-5388 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1100-11913 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1100-11914 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 7576-9679 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3718
% INFO    : Updated Thermal Rating: on transformer 4529-11916 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4529-13163 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4529-11099 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4529-11919 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 9274-10635 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 9274-10803 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 9274-10804 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 9274-3698 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 9274-3697 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 9274-3696 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 9274-3695 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 9274-3701 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 9274-3700 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 9274-3699 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 12839-1853 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 12839-5849 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 8404-1631 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 8404-8648 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 8404-8647 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 8404-4729 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 8404-4728 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 8404-4727 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 8404-4726 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 8404-4725 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 8404-4724 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 8404-4723 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 8404-4722 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 8404-10811 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 13274-6329 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 13274-6328 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 13274-6327 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 13274-6326 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 13274-6325 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 6011-5229 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 6011-5228 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 6011-5226 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 6011-5225 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 6011-11759 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 6011-11760 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 6011-2646 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 6011-11758 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 6011-11762 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 6011-11763 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 10526-8713 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3718
% INFO    : Updated Thermal Rating: on transformer 10526-8714 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3718
% INFO    : Updated Thermal Rating: on transformer 7834-8711 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3718
% INFO    : Updated Thermal Rating: on transformer 7834-8712 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3718
% INFO    : Updated Thermal Rating: on transformer 1748-1689 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3718
% INFO    : Updated Thermal Rating: on transformer 1748-10530 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3718
% INFO    : Updated Thermal Rating: on transformer 9437-6798 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 9437-6797 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 5960-6793 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 5960-6792 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 7462-6795 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 7462-6794 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4776-6802 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4776-6801 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1902-13419 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1902-6731 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1902-12219 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 3998-12222 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 3998-13423 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 3998-13424 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 3998-13421 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 3998-10050 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 5810-13426 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 242
% INFO    : Updated Thermal Rating: on transformer 5810-13427 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 242
% INFO    : Updated Thermal Rating: on transformer 5810-3305 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 242
% INFO    : Updated Thermal Rating: on transformer 5810-3304 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 242
% INFO    : Updated Thermal Rating: on transformer 5810-3303 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 242
% INFO    : Updated Thermal Rating: on transformer 5810-3302 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 242
% INFO    : Updated Thermal Rating: on transformer 8243-3309 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 8243-3308 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 8243-6969 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 8243-6967 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 8243-5463 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 8243-6944 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 3889-9926 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 150
% INFO    : Updated Thermal Rating: on transformer 3889-5528 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 150
% INFO    : Updated Thermal Rating: on transformer 3889-9928 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 150
% INFO    : Updated Thermal Rating: on transformer 3889-9929 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 150
% INFO    : Updated Thermal Rating: on transformer 3889-9930 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 150
% INFO    : Updated Thermal Rating: on transformer 8087-11922 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 8087-9932 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 10282-9933 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 10282-9922 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4682-9923 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4682-2153 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1944-2154 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1944-13585 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1944-13589 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1944-13604 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 9262-2158 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 9262-2155 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 2016-2156 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 2424-62 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3718
% INFO    : Updated Thermal Rating: on transformer 2424-63 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3718
% INFO    : Updated Thermal Rating: on transformer 13136-1726 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3718
% INFO    : Updated Thermal Rating: on transformer 13136-7063 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3718
% INFO    : Updated Thermal Rating: on transformer 2797-9225 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1152-1298 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1152-1287 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1152-9218 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1152-11344 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 6052-1290 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 6052-9216 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 2507-9215 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1215-510 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3718
% INFO    : Updated Thermal Rating: on transformer 4360-3068 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3718
% INFO    : Updated Thermal Rating: on transformer 7051-508 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3718
% INFO    : Updated Thermal Rating: on transformer 2892-509 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3718
% INFO    : Updated Thermal Rating: on transformer 5683-514 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3718
% INFO    : Updated Thermal Rating: on transformer 5500-3757 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 5500-3754 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 5500-11950 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 5981-1662 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 101
% INFO    : Updated Thermal Rating: on transformer 5981-1663 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 101
% INFO    : Updated Thermal Rating: on transformer 6416-13520 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 6416-4187 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 6416-13489 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 6416-4185 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 6416-4182 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 6416-4183 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 6416-1074 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 12849-8675 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 12849-8680 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 12849-8679 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 7414-2783 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 7414-2799 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 7414-2810 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 7414-12673 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 7414-2012 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 7414-2013 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 7414-2014 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 7414-12659 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 7414-2020 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 7414-12690 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 11183-8219 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 11183-8218 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 11183-8221 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 11183-8220 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 11183-8223 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 11183-8222 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 11183-8224 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 11183-4691 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 11183-4698 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 11183-4699 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 11183-5523 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 11183-12232 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 11183-5530 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 6064-749 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 6064-750 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 6064-751 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 13405-10132 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 13405-6749 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 13405-10134 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 13405-10135 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 13405-3523 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 13405-8130 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 13405-3521 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 13405-3520 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 13405-3526 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 13405-3525 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 13405-3524 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 10182-7732 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 10182-11401 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 5234-5973 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 5234-4041 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 5312-4042 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 5312-4039 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 5312-4040 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 8652-4045 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 12476-13190 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 12476-13189 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 12476-13188 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 12299-4048 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 12299-11330 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 12511-12825 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 12511-11122 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 10737-11125 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 10737-11124 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 10737-11119 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 10737-11118 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 10944-11121 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 10944-11120 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 10944-11130 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 2581-11129 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 2581-7946 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 2581-12697 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 2581-3878 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 2581-12699 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 2581-12702 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 6778-12701 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 6778-12704 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 2454-3916 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 5112-12706 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 5112-12705 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 5112-5622 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 12744-5476 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 12744-7386 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 12744-12586 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 12744-12592 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 12744-12591 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 12744-12590 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 12744-12589 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 8065-5619 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 896-6593 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 227-6008 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 227-8838 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 227-6006 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 227-6007 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 227-8824 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 227-6005 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 227-6002 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 227-6003 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 6400-5134 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 6400-12175 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 5691-5126 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 5691-5127 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 934-5128 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 934-5129 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 934-5130 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 934-5131 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 934-13584 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 934-5133 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 934-5122 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 158-5123 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 3455-4405 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 3455-77 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 12568-454 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 33
% INFO    : Updated Thermal Rating: on transformer 897-2167 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 897-9377 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 897-9376 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 897-9379 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 897-9378 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 897-9384 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 897-9383 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 897-2284 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 897-2285 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 897-2282 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 897-2283 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 897-811 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 12397-12664 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 12397-11484 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1563-6630 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1563-6623 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1563-6624 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 10058-13064 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 10058-13060 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 10058-13059 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 10058-13055 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 10058-8906 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 10058-13046 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 10058-13043 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 10058-8903 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 10058-8902 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 10058-8901 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 8572-6090 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 8572-6091 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4504-6092 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 7638-6093 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 7638-10447 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 7638-6087 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 7638-10470 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4002-6089 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4002-6097 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4002-6098 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4002-975 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 13455-7470 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3718
% INFO    : Updated Thermal Rating: on transformer 3083-977 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 3083-976 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 3083-978 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 10309-3528 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 10309-3529 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 10309-3530 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 10309-8123 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 10309-8126 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 10309-10619 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 10008-7508 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1268-4707 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1268-10339 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1268-516 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1268-4702 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1268-4690 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1268-4694 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1268-7512 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4165-7513 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4077-9475 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4077-9476 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4077-2708 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 12559-9478 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 12559-9479 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 12559-9480 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 12559-9481 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 12559-9482 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 12492-9471 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 12492-9472 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 12492-2841 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 12492-2840 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 12492-12738 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 7948-2838 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 7948-2845 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1162-2844 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1162-4200 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 9183-2842 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 9183-4166 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 9183-2836 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 501-4171 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 501-207 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 501-9963 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 3541-9964 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 3541-9961 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 12472-5838 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3718
% INFO    : Updated Thermal Rating: on transformer 13045-9959 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 13045-13491 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 13045-9957 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 13045-9958 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 9009-12921 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3718
% INFO    : Updated Thermal Rating: on transformer 9009-12920 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3718
% INFO    : Updated Thermal Rating: on transformer 9009-12937 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3718
% INFO    : Updated Thermal Rating: on transformer 9009-12925 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3718
% INFO    : Updated Thermal Rating: on transformer 3268-3335 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 3268-3334 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 3268-3337 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 3268-3336 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 3268-3339 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4479-3338 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4479-10436 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 3559-10437 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 3559-10438 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4479-10439 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4479-10432 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 213-8479 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 213-10434 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 213-10435 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 213-3608 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 7396-10443 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 7396-9946 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 7396-3816 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 7396-3815 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 10564-3814 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 28
% INFO    : Updated Thermal Rating: on transformer 1744-3491 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1744-3812 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1744-3811 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 11080-3810 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 11080-3820 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 8460-13392 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 8460-6757 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 8460-6758 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 8460-13580 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 8460-13582 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 8460-6761 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 8460-6762 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 8460-6759 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 8460-6760 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 8460-6763 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 8460-9659 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1252-4386 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1252-4385 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1252-4387 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4031-1675 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3718
% INFO    : Updated Thermal Rating: on transformer 4031-276 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3718
% INFO    : Updated Thermal Rating: on transformer 2558-275 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3718
% INFO    : Updated Thermal Rating: on transformer 2558-274 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3718
% INFO    : Updated Thermal Rating: on transformer 11442-273 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3718
% INFO    : Updated Thermal Rating: on transformer 11442-1661 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3718
% INFO    : Updated Thermal Rating: on transformer 523-271 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3718
% INFO    : Updated Thermal Rating: on transformer 523-12968 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3718
% INFO    : Updated Thermal Rating: on transformer 5011-3065 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 5011-7531 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 5011-5657 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 1835-11454 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1835-11455 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 10485-11456 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 116
% INFO    : Updated Thermal Rating: on transformer 10485-11457 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 116
% INFO    : Updated Thermal Rating: on transformer 10485-11458 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 116
% INFO    : Updated Thermal Rating: on transformer 10485-11459 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 116
% INFO    : Updated Thermal Rating: on transformer 10485-4901 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 116
% INFO    : Updated Thermal Rating: on transformer 10485-2289 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 116
% INFO    : Updated Thermal Rating: on transformer 1173-11419 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3718
% INFO    : Updated Thermal Rating: on transformer 1173-11418 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3718
% INFO    : Updated Thermal Rating: on transformer 12161-6254 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3718
% INFO    : Updated Thermal Rating: on transformer 12161-709 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3718
% INFO    : Updated Thermal Rating: on transformer 5760-4903 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 5760-4902 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 8710-4905 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 8710-4904 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 11004-6611 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 11004-6612 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 11004-6609 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 11004-6610 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 11004-6607 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 11004-6608 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 11004-12529 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 11004-6606 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 3466-10202 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 3466-10201 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 2735-12582 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 150
% INFO    : Updated Thermal Rating: on transformer 2735-12583 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 150
% INFO    : Updated Thermal Rating: on transformer 2735-7428 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 150
% INFO    : Updated Thermal Rating: on transformer 2735-12585 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 150
% INFO    : Updated Thermal Rating: on transformer 2735-12578 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 150
% INFO    : Updated Thermal Rating: on transformer 2735-7361 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 150
% INFO    : Updated Thermal Rating: on transformer 2735-12580 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 150
% INFO    : Updated Thermal Rating: on transformer 2735-12581 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 150
% INFO    : Updated Thermal Rating: on transformer 2735-12575 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 150
% INFO    : Updated Thermal Rating: on transformer 2735-12576 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 150
% INFO    : Updated Thermal Rating: on transformer 2735-6481 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 150
% INFO    : Updated Thermal Rating: on transformer 2735-13469 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 150
% INFO    : Updated Thermal Rating: on transformer 1086-10676 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1086-10675 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1086-10672 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1086-10671 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1086-10674 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1086-898 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4953-10669 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4953-10668 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4953-3571 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 7062-8425 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 40
% INFO    : Updated Thermal Rating: on transformer 10933-3569 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 146
% INFO    : Updated Thermal Rating: on transformer 10933-3570 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 146
% INFO    : Updated Thermal Rating: on transformer 10933-3575 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 146
% INFO    : Updated Thermal Rating: on transformer 10933-8435 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 146
% INFO    : Updated Thermal Rating: on transformer 10933-8427 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 146
% INFO    : Updated Thermal Rating: on transformer 10933-8430 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 146
% INFO    : Updated Thermal Rating: on transformer 12094-8397 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 12094-8402 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 2953-7240 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 2953-9220 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 2953-9219 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 2953-10007 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 2953-7475 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 5913-9224 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 5913-10068 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 5913-9222 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 5913-1273 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 5913-9213 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 6061-3410 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 6061-12200 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 9916-13594 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 9916-13597 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 9916-7547 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 6839-13601 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 9289-2157 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 9289-13609 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 13408-2148 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 13408-2149 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 13408-9696 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 13408-9695 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 13408-9698 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 13408-9697 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 7811-9700 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 3376-9699 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 3376-9702 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 13583-7179 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 359
% INFO    : Updated Thermal Rating: on transformer 13583-7053 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 359
% INFO    : Updated Thermal Rating: on transformer 13583-7054 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 359
% INFO    : Updated Thermal Rating: on transformer 13583-515 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 359
% INFO    : Updated Thermal Rating: on transformer 13583-3078 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 359
% INFO    : Updated Thermal Rating: on transformer 13583-513 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 359
% INFO    : Updated Thermal Rating: on transformer 13583-512 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 359
% INFO    : Updated Thermal Rating: on transformer 13583-511 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 359
% INFO    : Updated Thermal Rating: on transformer 4299-8274 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 231
% INFO    : Updated Thermal Rating: on transformer 4299-8275 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 231
% INFO    : Updated Thermal Rating: on transformer 4299-8276 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 231
% INFO    : Updated Thermal Rating: on transformer 4299-9182 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 231
% INFO    : Updated Thermal Rating: on transformer 4299-8278 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 231
% INFO    : Updated Thermal Rating: on transformer 4299-1231 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 231
% INFO    : Updated Thermal Rating: on transformer 4299-1230 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 231
% INFO    : Updated Thermal Rating: on transformer 4299-1232 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 231
% INFO    : Updated Thermal Rating: on transformer 1582-12127 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1582-12126 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 994-4870 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 994-12124 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4114-12123 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18
% INFO    : Updated Thermal Rating: on transformer 4114-12122 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 18
% INFO    : Updated Thermal Rating: on transformer 9263-12121 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 9263-3351 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 9263-5076 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 9263-5077 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 9263-5078 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1206-5071 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1206-5072 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1206-5073 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1206-5074 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1206-5069 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 5709-5070 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 62
% INFO    : Updated Thermal Rating: on transformer 5709-7088 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 62
% INFO    : Updated Thermal Rating: on transformer 7157-9706 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 7157-1815 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 7157-7087 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 7157-7084 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4528-7085 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4528-7082 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4528-7083 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4528-7080 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4528-7081 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4528-528 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 6212-2137 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3718
% INFO    : Updated Thermal Rating: on transformer 6212-2136 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3718
% INFO    : Updated Thermal Rating: on transformer 6212-2135 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3718
% INFO    : Updated Thermal Rating: on transformer 6212-2138 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3718
% INFO    : Updated Thermal Rating: on transformer 1127-2540 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 1127-2577 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 1127-2543 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 1127-2571 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 1127-2534 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 1127-10172 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 1127-10171 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 1127-10174 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 1127-10173 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 9274-12656 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 9274-10210 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 9274-6631 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 6699-10232 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 6699-6621 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4121-6622 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 204
% INFO    : Updated Thermal Rating: on transformer 4121-76 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 204
% INFO    : Updated Thermal Rating: on transformer 4121-75 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 204
% INFO    : Updated Thermal Rating: on transformer 4121-74 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 204
% INFO    : Updated Thermal Rating: on transformer 3662-438 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 3662-8039 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 3662-79 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 7321-78 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 209
% INFO    : Updated Thermal Rating: on transformer 7321-447 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 209
% INFO    : Updated Thermal Rating: on transformer 7321-72 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 209
% INFO    : Updated Thermal Rating: on transformer 7321-71 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 209
% INFO    : Updated Thermal Rating: on transformer 2432-9681 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3718
% INFO    : Updated Thermal Rating: on transformer 13529-9682 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3718
% INFO    : Updated Thermal Rating: on transformer 11837-7995 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 11837-8386 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 11837-8000 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 11837-8001 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4220-7998 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13
% INFO    : Updated Thermal Rating: on transformer 4220-8442 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13
% INFO    : Updated Thermal Rating: on transformer 13028-7992 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 13028-7993 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4907-1440 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 171
% INFO    : Updated Thermal Rating: on transformer 4907-1439 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 171
% INFO    : Updated Thermal Rating: on transformer 4907-1442 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 171
% INFO    : Updated Thermal Rating: on transformer 3473-1441 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 3473-1436 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 3473-1435 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 5395-1438 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 5395-1437 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 5395-1434 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 5395-1433 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 5395-7505 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 5395-4709 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 10204-7507 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 10204-11723 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 10204-7501 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 10301-7502 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 10301-9028 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 10301-7504 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 10294-4733 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 10294-4738 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 9955-987 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 9955-986 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 9955-985 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 9955-984 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 3527-983 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 3527-982 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 3527-981 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1122-980 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 178-3558 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3718
% INFO    : Updated Thermal Rating: on transformer 7008-3557 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3718
% INFO    : Updated Thermal Rating: on transformer 4822-6879 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3718
% INFO    : Updated Thermal Rating: on transformer 6572-6880 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3718
% INFO    : Updated Thermal Rating: on transformer 7985-8956 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 7985-13363 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1422-8954 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1422-8955 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1422-8952 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1422-8953 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1422-8962 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 9411-8963 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 9411-2329 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 9411-2328 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 9411-2331 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 9411-2330 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4999-323 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3718
% INFO    : Updated Thermal Rating: on transformer 4999-1932 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3718
% INFO    : Updated Thermal Rating: on transformer 3737-2333 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 3737-1077 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 3737-2325 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 3737-2324 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4880-11604 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4880-11603 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 7698-11606 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 7698-11605 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 7698-11600 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 326-13393 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 326-13395 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 326-13394 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 326-13391 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 326-13390 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 326-10621 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 326-10625 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 326-6298 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 326-6299 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 326-8942 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 11931-448 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 97
% INFO    : Updated Thermal Rating: on transformer 11931-441 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 97
% INFO    : Updated Thermal Rating: on transformer 2104-442 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 2104-4539 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4848-4540 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4848-11095 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 13214-12912 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 13214-2411 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 13214-12910 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 13214-9184 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 13214-12908 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 13214-12907 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 13214-12906 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 13214-12917 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 13214-12916 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 13214-5831 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 13214-5832 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 2348-4011 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 2348-10898 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 7867-10643 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 9172-7599 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 10335-7598 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 5899-9781 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 5899-4607 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 12622-1966 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 12622-1967 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 12622-6139 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3718
% INFO    : Updated Thermal Rating: on transformer 12622-6140 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3718
% INFO    : Updated Thermal Rating: on transformer 12622-6138 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3718
% INFO    : Updated Thermal Rating: on transformer 7765-3141 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 7765-3142 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 9820-3143 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 622-6663 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 622-8439 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 622-1412 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 622-1413 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 622-1410 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 622-1411 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 622-1416 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 9506-1417 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 9506-1414 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 9506-1415 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 9506-1407 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 9506-1408 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 9506-7333 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 9506-7966 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 9506-7965 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 6362-1521 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 7733-1517 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 7733-1518 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 3193-1519 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 3193-1520 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 5496-3641 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 5496-3642 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 8653-10311 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 8653-10742 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 272-8550 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 272-8549 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 4883-8548 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 4883-8547 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 1467-8546 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 1467-8545 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 5005-8544 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 5005-9393 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 10000-12790 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 10000-12791 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 10000-12788 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 10000-12789 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 5569-11212 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 8176-11211 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 644-9890 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 2726-4144 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 2257-4143 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 2257-2734 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 2257-4141 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 2257-4140 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 4997-4139 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 4997-4138 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 4997-4137 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 10367-4136 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 10367-11803 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 9178-10753 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 9178-10754 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 9415-10755 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 448
% INFO    : Updated Thermal Rating: on transformer 9415-10756 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 448
% INFO    : Updated Thermal Rating: on transformer 9415-10337 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 448
% INFO    : Updated Thermal Rating: on transformer 9415-10750 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 448
% INFO    : Updated Thermal Rating: on transformer 5344-10343 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 5344-10752 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 11902-10328 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 11902-10747 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 11902-4665 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 11902-4664 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 722-1057 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 722-4666 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 8960-4946 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 8960-4945 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 478-4663 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 478-4662 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 945-4943 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 945-4942 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 6825-11219 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 12961-8806 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 12961-8807 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 12961-12519 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 12961-8809 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 12406-9279 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 8314-11220 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 9863-9280 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 9863-9075 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 3932-9088 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 3932-11225 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1779-6405 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1779-6408 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 8529-6407 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 8529-6402 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 5951-6401 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 5951-6404 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 7322-8839 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 7322-10748 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 7322-3647 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 7322-10253 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 7322-10254 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 6386-9785 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 6386-4652 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 4756-9751 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1128-9753 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 6012-3655 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 6012-3186 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 6570-3137 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 6570-3136 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 6570-3135 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 6570-3134 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 6570-6048 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 2113-3656 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 2113-3651 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 2113-8885 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 12866-12500 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 12866-6976 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 9948-10269 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 9948-10270 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 10965-10267 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 448
% INFO    : Updated Thermal Rating: on transformer 10965-10268 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 448
% INFO    : Updated Thermal Rating: on transformer 1691-2179 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 1691-2178 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 1691-2177 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 1691-2176 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 12622-3094 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 12622-3096 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 866-3093 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 866-3101 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 3429-3100 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 3429-13526 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 4472-3582 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4472-3580 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 8588-12093 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 8588-10355 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 2750-13397 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 2750-13398 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 2750-13399 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 2750-13388 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 2750-13389 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 1425-6764 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 12051-7526 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 12051-7055 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 12051-7528 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 12051-7523 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 12051-7524 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 462-6765 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 2201-6422 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 2201-6417 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 2201-6418 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 4372-224 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 4372-225 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 4372-222 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 8454-223 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 8454-220 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 8454-221 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 8592-3061 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 8592-3062 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 8936-3063 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 8936-5660 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 6522-10195 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 6522-10194 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 7527-2440 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 7527-10192 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 3081-10198 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 3081-10197 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 10271-7628 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 10271-8017 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 10271-8021 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 10271-8022 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 10271-104 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 2602-4572 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 2602-11633 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 11961-11632 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 11961-11635 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 3731-11634 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 3731-11631 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 10850-7672 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 10850-7671 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 10850-7670 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 3452-7676 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 3452-7675 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 23-11979 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 23-11978 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 23-3904 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 23-11980 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 23-3914 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 5257-4047 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 8044-11325 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 8044-4049 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 12457-4043 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 12457-4044 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 13600-8444 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 13600-8151 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 13600-8154 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 7069-8153 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 7069-8148 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 7069-8147 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 3744-1534 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 3744-8149 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 3744-8146 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 10354-8145 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 10354-1586 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 10354-1587 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 6971-10476 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 6971-10475 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 6971-10474 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 6971-8665 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 6971-10472 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 6971-8658 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 5773-10480 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 5773-10479 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 5773-3365 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 5773-3366 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 5773-3367 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 5773-3368 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 238-8604 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 238-8610 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 238-8609 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 9397-9232 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 9397-9233 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 9397-9230 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 9397-9231 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 9397-9228 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 9397-9229 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 8077-11924 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 8077-12758 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 8077-9237 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 8077-1335 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 8077-2651 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 8077-2650 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 9397-2653 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 9397-2652 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 9397-2655 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 9397-2654 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 9397-2657 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 9397-2656 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 2453-3611 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 2453-3610 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 2453-10764 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 3732-10765 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 3732-10762 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 3732-10763 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 2728-8731 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 2728-8732 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 2728-8733 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 2728-8734 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 2728-8735 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 10026-7228 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 10026-243 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 10149-8904 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 10149-8905 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 10149-3631 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 10149-8907 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 31-8908 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 31-8909 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 31-8910 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 31-8897 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 9736-8898 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 7609-3729 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 7609-3728 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 7869-12461 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 7869-12462 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 7869-12466 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 7869-12467 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 7869-12464 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 638-12465 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 638-12469 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 638-12470 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 638-5901 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 638-5900 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 11573-8173 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 11573-5902 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 11573-5898 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 11573-5897 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 11573-8162 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 7161-10329 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 7161-10324 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 7161-1801 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 7161-9761 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 7161-9762 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 7161-9763 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 7161-9764 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 7161-9757 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 7161-9758 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 5515-9759 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 5515-4145 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 5515-9754 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 5515-4470 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 5515-3122 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 5515-3121 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 5479-9856 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 582-4376 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 582-4379 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 582-4380 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 582-4378 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 582-3095 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 582-3098 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 582-3097 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 6850-9550 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 6850-9551 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 6850-3145 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 6850-9549 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 6850-9547 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 2716-4751 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 448
% INFO    : Updated Thermal Rating: on transformer 2716-1458 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 448
% INFO    : Updated Thermal Rating: on transformer 2716-4753 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 448
% INFO    : Updated Thermal Rating: on transformer 2716-1427 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 448
% INFO    : Updated Thermal Rating: on transformer 2716-4745 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 448
% INFO    : Updated Thermal Rating: on transformer 2716-11307 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 448
% INFO    : Updated Thermal Rating: on transformer 13230-11308 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 448
% INFO    : Updated Thermal Rating: on transformer 3921-11305 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 3921-849 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 3921-107 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 9450-110 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 448
% INFO    : Updated Thermal Rating: on transformer 6840-11032 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3718
% INFO    : Updated Thermal Rating: on transformer 6840-12173 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3718
% INFO    : Updated Thermal Rating: on transformer 748-11312 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 448
% INFO    : Updated Thermal Rating: on transformer 748-136 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 448
% INFO    : Updated Thermal Rating: on transformer 4092-10775 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 448
% INFO    : Updated Thermal Rating: on transformer 4092-3800 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 448
% INFO    : Updated Thermal Rating: on transformer 11254-1183 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 11254-1182 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 7543-11367 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 7543-11368 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 7543-11369 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 7543-11370 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 7543-11364 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 7543-5868 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 7543-4814 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 10219-8994 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 10219-10913 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 645-3671 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 448
% INFO    : Updated Thermal Rating: on transformer 645-3672 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 448
% INFO    : Updated Thermal Rating: on transformer 4520-4811 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 448
% INFO    : Updated Thermal Rating: on transformer 4520-4810 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 448
% INFO    : Updated Thermal Rating: on transformer 4520-4809 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 448
% INFO    : Updated Thermal Rating: on transformer 4520-1772 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 448
% INFO    : Updated Thermal Rating: on transformer 4520-1770 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 448
% INFO    : Updated Thermal Rating: on transformer 4520-11849 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 448
% INFO    : Updated Thermal Rating: on transformer 645-11233 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 448
% INFO    : Updated Thermal Rating: on transformer 645-11236 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 448
% INFO    : Updated Thermal Rating: on transformer 6772-11235 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 448
% INFO    : Updated Thermal Rating: on transformer 6772-11238 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 448
% INFO    : Updated Thermal Rating: on transformer 2021-13383 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 2021-11240 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 2021-3217 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 2021-11242 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 2021-11241 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 5521-4163 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 5521-4164 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 11659-4161 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 11659-10442 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 11659-4159 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 9680-4160 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 9680-4157 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 9680-4158 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 712-4155 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 712-4156 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 712-2482 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 6457-2435 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 448
% INFO    : Updated Thermal Rating: on transformer 6457-2436 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 448
% INFO    : Updated Thermal Rating: on transformer 6457-2437 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 448
% INFO    : Updated Thermal Rating: on transformer 6457-2438 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 448
% INFO    : Updated Thermal Rating: on transformer 6457-2439 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 448
% INFO    : Updated Thermal Rating: on transformer 1393-9585 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4466
% INFO    : Updated Thermal Rating: on transformer 1393-9584 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4466
% INFO    : Updated Thermal Rating: on transformer 6128-9579 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4466
% INFO    : Updated Thermal Rating: on transformer 6128-154 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4466
% INFO    : Updated Thermal Rating: on transformer 8715-2480 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4466
% INFO    : Updated Thermal Rating: on transformer 8715-2481 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4466
% INFO    : Updated Thermal Rating: on transformer 10099-4679 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 448
% INFO    : Updated Thermal Rating: on transformer 10099-4680 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 448
% INFO    : Updated Thermal Rating: on transformer 13256-4676 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 448
% INFO    : Updated Thermal Rating: on transformer 13256-4677 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 448
% INFO    : Updated Thermal Rating: on transformer 13256-4678 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 448
% INFO    : Updated Thermal Rating: on transformer 10502-8668 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 183
% INFO    : Updated Thermal Rating: on transformer 10502-8671 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 183
% INFO    : Updated Thermal Rating: on transformer 9319-4683 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 448
% INFO    : Updated Thermal Rating: on transformer 9319-12279 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 448
% INFO    : Updated Thermal Rating: on transformer 9319-12278 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 448
% INFO    : Updated Thermal Rating: on transformer 9319-12281 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 448
% INFO    : Updated Thermal Rating: on transformer 2684-12280 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 448
% INFO    : Updated Thermal Rating: on transformer 2684-12276 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 448
% INFO    : Updated Thermal Rating: on transformer 2684-12275 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 448
% INFO    : Updated Thermal Rating: on transformer 6458-2372 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 448
% INFO    : Updated Thermal Rating: on transformer 6458-2373 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 448
% INFO    : Updated Thermal Rating: on transformer 6458-9467 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 448
% INFO    : Updated Thermal Rating: on transformer 6458-2377 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 448
% INFO    : Updated Thermal Rating: on transformer 6458-9486 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 448
% INFO    : Updated Thermal Rating: on transformer 853-4284 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 448
% INFO    : Updated Thermal Rating: on transformer 853-4286 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 448
% INFO    : Updated Thermal Rating: on transformer 853-4285 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 448
% INFO    : Updated Thermal Rating: on transformer 853-4288 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 448
% INFO    : Updated Thermal Rating: on transformer 853-4287 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 448
% INFO    : Updated Thermal Rating: on transformer 853-4290 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 448
% INFO    : Updated Thermal Rating: on transformer 6056-5246 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 6056-5242 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 6056-4242 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 1759-8552 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 448
% INFO    : Updated Thermal Rating: on transformer 6595-7498 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 448
% INFO    : Updated Thermal Rating: on transformer 6595-12803 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 448
% INFO    : Updated Thermal Rating: on transformer 4615-12802 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 284-12808 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 448
% INFO    : Updated Thermal Rating: on transformer 284-12807 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 448
% INFO    : Updated Thermal Rating: on transformer 284-12806 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 448
% INFO    : Updated Thermal Rating: on transformer 13593-5498 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 13593-12930 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 2445-12929 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 2445-5847 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 11518-5728 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 11518-5729 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 11518-5730 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 11518-5731 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 12899-5732 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 7516-13379 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1600
% INFO    : Updated Thermal Rating: on transformer 7516-13377 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1600
% INFO    : Updated Thermal Rating: on transformer 7516-11246 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1600
% INFO    : Updated Thermal Rating: on transformer 1032-6918 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 1032-12833 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 8878-8116 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 8878-8113 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 13384-8114 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 13384-8111 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1854-8112 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1854-8110 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 8187-8317 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 8187-8319 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 8187-8320 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 5588-2119 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4466
% INFO    : Updated Thermal Rating: on transformer 12621-6227 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 10332-7814 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 10398-1556 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 10398-1558 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 10398-1557 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 5767-6226 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 2967-5510 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 2967-5514 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 1197-1560 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1197-7636 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1197-7637 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 5945-12255 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 8520-5640 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 8520-5084 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 7273-4245 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 7273-12252 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 2221-4274 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 2221-5654 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 1035-12259 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 1035-5708 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 13619-5707 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 13619-5706 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 4951-1089 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4951-1093 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4951-1092 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 10569-5705 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 7880-5704 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 11998-6039 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 11998-6040 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 1729-2186 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 5749-7736 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 5997-1914 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 5997-1913 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 4280-9655 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4466
% INFO    : Updated Thermal Rating: on transformer 1634-9656 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4466
% INFO    : Updated Thermal Rating: on transformer 2938-9106 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 2938-9107 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 2938-9102 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 6463-6409 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 2293-5223 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 4802-846 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 4802-845 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 4802-844 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 3374-2489 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 3374-2488 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 7738-8773 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 9318-2490 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 9318-2487 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 9318-2486 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 9318-8576 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 5288-8577 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 5288-8578 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 759-12814 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 759-12072 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 11688-1735 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 11688-1734 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 10391-13592 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 4306-8581 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4306-8582 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4306-2006 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4872-2005 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4872-2004 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4872-2003 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 6154-12855 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3718
% INFO    : Updated Thermal Rating: on transformer 3721-2001 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 8574-2000 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 8574-1999 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 8574-2011 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 5211-4710 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 553-5858 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 553-5856 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 4921-1050 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 8266-9818 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 4842-3913 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 1201-4240 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 255
% INFO    : Updated Thermal Rating: on transformer 1201-4239 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 255
% INFO    : Updated Thermal Rating: on transformer 1212-10453 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 3364-3903 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 6517-4234 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 6517-11806 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 7530-11886 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 6209-6420 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 8699-7338 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 4567-1218 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 4333-6421 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 5655-4162 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 9664-9074 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 11245-4152 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 4075-4151 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 12719-10362 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 8690-5406 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 13381-5245 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 3156-8740 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 6425-8741 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 10931-873 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 9500-1995 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 3813-5411 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 327-10287 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 110
% INFO    : Updated Thermal Rating: on transformer 8557-5243 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 3690-2307 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 5502-7377 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 10128-3853 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 11904-12 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 7692-8451 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 1962-13655 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 8737-11889 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 8737-1940 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 8737-11897 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 6151-11898 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 6151-4858 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 6151-4857 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 2887-4856 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 2887-4855 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 2493-4862 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 2493-4861 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 2493-2047 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 13140-4859 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 13140-4864 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 6366-10250 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 6366-6017 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 6366-3127 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 11839-11408 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 11839-11409 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 12513-11410 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 317
% INFO    : Updated Thermal Rating: on transformer 5478-3130 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 5478-3128 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 5478-6023 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 2699-3123 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 2699-3124 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 2699-11406 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 2699-8803 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 3693-6358 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 3693-6357 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 9988-6352 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 9988-6351 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 8968-6354 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1340
% INFO    : Updated Thermal Rating: on transformer 8968-6353 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1340
% INFO    : Updated Thermal Rating: on transformer 8968-6361 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1340
% INFO    : Updated Thermal Rating: on transformer 2553-6360 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 2553-12965 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 7099-9522 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 7099-9513 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 11165-9515 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 3044-12969 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 3044-12970 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 13244-9523 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 13244-9525 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 7412-1750 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1787
% INFO    : Updated Thermal Rating: on transformer 7412-1751 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1787
% INFO    : Updated Thermal Rating: on transformer 7412-9294 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1787
% INFO    : Updated Thermal Rating: on transformer 10651-5889 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 10651-9540 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 10651-5887 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 8758-8090 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 8758-8088 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 7000-5884 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 7000-5883 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 7000-5882 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 279-5881 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 7103-12452 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 5437-12453 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 7891-12454 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 10637-6726 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 122
% INFO    : Updated Thermal Rating: on transformer 7729-1546 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 686
% INFO    : Updated Thermal Rating: on transformer 7729-1545 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 686
% INFO    : Updated Thermal Rating: on transformer 7729-1544 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 686
% INFO    : Updated Thermal Rating: on transformer 7729-13056 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 686
% INFO    : Updated Thermal Rating: on transformer 7729-1537 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 686
% INFO    : Updated Thermal Rating: on transformer 7729-9979 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 686
% INFO    : Updated Thermal Rating: on transformer 7729-13124 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 686
% INFO    : Updated Thermal Rating: on transformer 7729-11463 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 686
% INFO    : Updated Thermal Rating: on transformer 7729-13099 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 686
% INFO    : Updated Thermal Rating: on transformer 7729-11461 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 686
% INFO    : Updated Thermal Rating: on transformer 7729-11464 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 686
% INFO    : Updated Thermal Rating: on transformer 1531-3344 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 1531-7137 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 2043-9602 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 288
% INFO    : Updated Thermal Rating: on transformer 2043-9606 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 288
% INFO    : Updated Thermal Rating: on transformer 2043-9605 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 288
% INFO    : Updated Thermal Rating: on transformer 2043-2500 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 288
% INFO    : Updated Thermal Rating: on transformer 2043-2501 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 288
% INFO    : Updated Thermal Rating: on transformer 2043-2502 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 288
% INFO    : Updated Thermal Rating: on transformer 4109-5366 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 148
% INFO    : Updated Thermal Rating: on transformer 4109-4939 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 148
% INFO    : Updated Thermal Rating: on transformer 4109-5365 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 148
% INFO    : Updated Thermal Rating: on transformer 4109-5362 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 148
% INFO    : Updated Thermal Rating: on transformer 4109-13207 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 148
% INFO    : Updated Thermal Rating: on transformer 4109-5360 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 148
% INFO    : Updated Thermal Rating: on transformer 4109-5361 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 148
% INFO    : Updated Thermal Rating: on transformer 4109-11084 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 148
% INFO    : Updated Thermal Rating: on transformer 756-11085 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 756-11086 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 756-11087 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 756-11088 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 7425-12646 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 7425-11090 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 12423-652 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 12423-651 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 1646-5455 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 422
% INFO    : Updated Thermal Rating: on transformer 1646-12010 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 422
% INFO    : Updated Thermal Rating: on transformer 1646-12011 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 422
% INFO    : Updated Thermal Rating: on transformer 1646-12009 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 422
% INFO    : Updated Thermal Rating: on transformer 6181-433 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 6181-4537 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 6181-12709 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 6181-4535 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 6181-4534 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 6181-2286 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 6181-2287 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 8152-1813 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 177-1816 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 5140-5332 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 5140-5594 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 5140-5196 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4559-11602 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4559-11599 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4559-5540 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 2461-1831 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 2461-11611 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 2461-5038 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 249-5746 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 122
% INFO    : Updated Thermal Rating: on transformer 249-5748 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 122
% INFO    : Updated Thermal Rating: on transformer 249-5747 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 122
% INFO    : Updated Thermal Rating: on transformer 13278-12711 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 121
% INFO    : Updated Thermal Rating: on transformer 13278-12712 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 121
% INFO    : Updated Thermal Rating: on transformer 10745-12713 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1146-12714 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1146-12708 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1861-7540 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 664-5629 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 664-5628 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 10824-7262 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 377
% INFO    : Updated Thermal Rating: on transformer 11841-5630 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 42
% INFO    : Updated Thermal Rating: on transformer 8625-5632 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4915-5631 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 4915-5634 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 13255-11757 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 13255-11756 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 13255-11755 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 9712-12193 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 9712-12194 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 8009-12191 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 8009-12192 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 11209-382 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 389
% INFO    : Updated Thermal Rating: on transformer 11209-381 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 389
% INFO    : Updated Thermal Rating: on transformer 11209-384 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 389
% INFO    : Updated Thermal Rating: on transformer 1067-383 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 387
% INFO    : Updated Thermal Rating: on transformer 1067-378 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 387
% INFO    : Updated Thermal Rating: on transformer 1067-377 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 387
% INFO    : Updated Thermal Rating: on transformer 604-5144 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 3795-12601 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 448
% INFO    : Updated Thermal Rating: on transformer 3795-12599 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 448
% INFO    : Updated Thermal Rating: on transformer 3795-12600 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 448
% INFO    : Updated Thermal Rating: on transformer 4283-5148 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 9037-5147 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 9037-5146 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 9037-5145 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1219-5151 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1219-1764 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 1219-11686 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 13202-11687 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 2132-2246 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 2132-11689 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 2132-11690 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 2132-11691 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 2132-11692 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 2132-11693 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 10240-11694 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 10240-11695 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 10240-4634 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 10240-4633 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 10240-930 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 10240-4635 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 10240-4630 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 10240-912 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 10240-920 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 10240-4631 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 10240-4627 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 10240-4626 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 10240-11193 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 10240-11194 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 10240-11191 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 10240-13160 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 10240-11197 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 10240-11198 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 10240-11195 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 10240-11196 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 152
% INFO    : Updated Thermal Rating: on transformer 10118-2303 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 495
% INFO    : Updated Thermal Rating: on transformer 8355-13091 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 8355-9574 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 8355-9573 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 7506-8966 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 7506-8967 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 7506-8964 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 7506-8965 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 2597-13577 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 2597-156 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 2597-162 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 2597-161 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 2597-6690 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 7288-6691 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 7288-13080 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 7288-6689 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 7288-3912 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 7288-13101 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 9966-7600 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 9966-6693 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 9966-13108 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 9966-6697 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 9966-13316 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 12355-8470 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 12355-8471 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 12355-10423 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 12355-8473 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 12355-8474 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 8579-13313 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 8579-11580 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 8298-13311 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 270
% INFO    : Updated Thermal Rating: on transformer 9266-13310 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 9266-6219 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 8919-6220 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 253
% INFO    : Updated Thermal Rating: on transformer 8919-6221 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 253
% INFO    : Updated Thermal Rating: on transformer 8919-10155 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 253
% INFO    : Updated Thermal Rating: on transformer 6145-6215 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 257
% INFO    : Updated Thermal Rating: on transformer 6145-8185 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 257
% INFO    : Updated Thermal Rating: on transformer 6145-8199 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 257
% INFO    : Updated Thermal Rating: on transformer 6984-6218 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 6984-6213 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 4689-3352 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 4689-9911 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 4689-9912 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 4689-9909 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 12229-11472 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 12229-11477 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 9069-11478 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 9069-11475 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 11671-1083 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 11671-11479 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 2742-11480 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 2742-2434 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 13479-8873 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 13479-5750 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 6643-5751 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 2591-3282 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 2591-6862 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 2591-3284 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 2591-3283 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 4795-2902 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 4795-2901 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 4450-9440 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 4450-9441 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 4450-9442 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 4450-9443 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 4450-9438 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 5538-12304 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 5538-12303 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 5538-12302 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 5538-12307 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 1106-12306 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 12345-5270 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 12345-5271 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 12345-4403 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 12345-9343 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 60-5274 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 60-5275 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 60-5276 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 60-5277 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 12345-5278 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 12345-5279 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 12345-11818 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 12345-11817 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 60-11820 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 60-11819 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 60-11814 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 60-11813 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 1108-11816 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 1108-11815 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 1108-11811 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 5240-11810 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 5240-4772 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 5240-4773 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 5240-4770 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 11181-4771 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 9338-4774 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 9338-1577 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 8959-481 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 8959-480 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 8959-483 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 8959-482 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 13350-12140 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 13350-12139 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 13350-12138 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 13350-12137 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 10040-12136 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 10040-12135 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 10040-12134 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 10040-12133 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 7864-12132 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 7864-12131 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 7864-5089 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 7864-5090 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 21-5091 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 21-5092 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 21-5085 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 21-5086 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 6523-4695 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 958
% INFO    : Updated Thermal Rating: on transformer 6523-4696 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 958
% INFO    : Updated Thermal Rating: on transformer 6523-4693 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 958
% INFO    : Updated Thermal Rating: on transformer 13304-5082 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 13304-12652 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 13304-12651 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 13304-12654 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 2211-12653 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 2211-12648 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 2211-12647 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 2211-12650 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 8283-11259 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 8283-11256 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 10793-11028 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 10793-4455 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 2588-4454 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 2588-4457 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 2588-4456 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 6461-4451 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 6461-7183 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 6461-4453 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 6461-7200 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 6461-4461 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 3844-4460 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 3844-9586 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 3844-9587 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 9760-9588 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 9760-9589 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 9760-9590 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 9760-9591 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 4687-11133 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 4687-11132 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 4687-11137 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 4687-12869 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 7308-4053 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 7308-4054 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 7308-11345 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 7308-4056 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 12703-4057 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 12703-4058 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 12703-4059 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 12703-4060 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 12703-4061 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 12703-4062 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 1867-6454 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 1867-10080 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 1867-10077 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 1867-10078 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 1867-10075 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 1867-10076 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 1188-10073 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 2837-10074 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 6600-6471 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 6600-10084 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 5509-3456 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 9332-4580 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 9332-4577 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 9332-4578 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 9332-6391 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 9332-4576 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 5443-5207 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 5443-5208 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 12823-4585 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 12823-654 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 12823-10143 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 12823-10142 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 12823-10141 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 9524-86 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 574
% INFO    : Updated Thermal Rating: on transformer 9524-88 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 574
% INFO    : Updated Thermal Rating: on transformer 9524-87 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 574
% INFO    : Updated Thermal Rating: on transformer 1934-11714 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 1934-11713 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 1934-6996 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 1623-11717 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 1623-4655 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 1623-4656 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 3102-4657 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 3102-4658 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 3102-1002 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 13472-12610 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 13472-12607 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 3722-3017 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 3722-3021 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 3722-3022 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 3722-2533 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 3722-2572 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 3722-2573 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 6695-12334 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 6695-12333 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 6695-12332 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 6695-6055 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 6695-12330 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 2484-12338 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 2484-12337 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 8104-5305 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 8104-5306 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 5995-5307 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 5995-5308 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 5807-5301 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 434-5302 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 4038-5303 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 4038-5304 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 11153-5309 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 11153-5310 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 2494-1812 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 2494-2446 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 2494-2447 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 2494-2448 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 12643-2991 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 12643-8537 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 12643-5013 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 12643-5012 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 9899-5018 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 9899-5017 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 9899-11568 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 9899-11569 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 1299-13425 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 201-5769 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 201-5772 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 201-13525 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 8254-5770 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 8254-5771 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 8254-13345 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 8254-7391 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 8254-11352 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 8254-11351 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 13132-351 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 13132-2097 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 10632-3167 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 10632-3168 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 10632-3169 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 5819-11353 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 5819-11348 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 3080-11347 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 12002-7020 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 12002-8702 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 12002-8701 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 12002-11946 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 1931-8707 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 1931-8706 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 1931-11962 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 1931-11959 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 11316-10985 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 11316-11894 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 11316-3418 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 11316-3419 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 13596-3058 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 178
% INFO    : Updated Thermal Rating: on transformer 13596-11838 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 178
% INFO    : Updated Thermal Rating: on transformer 8-3414 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 8-3415 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 8-3416 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 8-7544 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 8-3412 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 8-8598 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 8-10522 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 8-10521 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 8-9189 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 8-9188 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 8-9191 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 8-9190 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 2601-6910 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 2601-6909 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 2769-4791 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 2769-4792 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 2769-619 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 6024-4602 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 6024-4603 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 6024-4604 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 6024-4598 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 6024-765 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 1181-6193 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 1181-6194 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 4706-615 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 4706-614 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 280-7163 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 12715-11670 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 12715-11669 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 12715-11668 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 12715-11667 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 12715-11666 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 8448-8308 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 8448-8125 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 8448-8128 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 8448-8127 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 3796-9141 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 3796-9142 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 12029-1389 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 12029-1390 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 12029-1391 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 12148-196 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 12148-5886 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 12148-5885 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 12148-5880 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 7406-9137 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 7406-2513 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 7406-2190 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 4794-2515 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 4794-2514 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 4794-2516 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 1008-12455 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 1008-6719 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 1008-6721 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 1008-12447 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 5296-2518 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 5296-8639 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 5296-11570 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 5827-5371 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 5827-5370 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 5827-5369 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 5827-5368 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 3380-4888 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 3380-4887 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 4204-1840 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 4204-11564 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 4204-8911 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 12047-13095 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 221
% INFO    : Updated Thermal Rating: on transformer 12047-2082 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 221
% INFO    : Updated Thermal Rating: on transformer 12047-9570 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 221
% INFO    : Updated Thermal Rating: on transformer 12047-2088 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 221
% INFO    : Updated Thermal Rating: on transformer 12047-2087 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 221
% INFO    : Updated Thermal Rating: on transformer 10091-2086 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 222
% INFO    : Updated Thermal Rating: on transformer 10091-2085 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 222
% INFO    : Updated Thermal Rating: on transformer 10091-2078 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 222
% INFO    : Updated Thermal Rating: on transformer 10091-2077 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 222
% INFO    : Updated Thermal Rating: on transformer 10091-10107 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 222
% INFO    : Updated Thermal Rating: on transformer 13003-6498 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 13003-3219 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 13003-3220 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 13003-3213 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 5096-3214 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 5096-3215 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 5096-3216 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 5096-3210 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 7583-6557 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 7583-13093 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 7583-3487 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 5643-3490 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 5643-3489 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 5643-3485 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 1233-11416 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 1233-684 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 1233-11414 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 1233-11411 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 1233-11412 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 6626-7110 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 6626-3720 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 6626-3717 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 6626-3718 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 13645-9616 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 8229-9617 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 8229-9618 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 5139-9619 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 5139-9622 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 11505-9623 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 11505-2982 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 11505-2981 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 9307-2980 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 9307-2979 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 9307-2978 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 9841-12525 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 9841-12526 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 9841-7113 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 13325-2984 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 11938-12518 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 11938-9283 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 11938-7719 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 11938-7722 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 11938-7721 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 11938-7717 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 11938-7716 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 11938-5978 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 1555-4207 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 1555-4214 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 1555-12152 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 1555-10809 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 12889-4481 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 11830-4484 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 13503-9033 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 13503-9034 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 6845-732 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 6845-730 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 6845-731 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 6845-734 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 6845-4982 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 11349-4963 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 11349-5342 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 11349-5382 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 11349-4964 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 11901-3585 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 11901-3586 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 4368-3587 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 4368-3588 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 4368-2934 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 8500-4958 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 8500-5676 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 3876-11530 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 3876-11527 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 3876-11528 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 3876-11525 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 3876-11526 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 3876-11523 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 3876-11524 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 3876-1367 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 3876-5830 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 3876-13386 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 3876-13385 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 3876-13387 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 3876-13633 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 3876-13487 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 3876-13648 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 3876-6014 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 3876-5999 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 3876-1 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 3876-4458 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 3876-11023 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 3876-12116 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 3876-11025 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 1015-11204 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 1015-11201 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 12395-6877 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 12395-6876 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 12395-6875 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 12395-12095 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 1395-2811 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 1395-6280 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 1395-8424 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 1395-8423 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 6133-858 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 6133-10908 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1116
% INFO    : Updated Thermal Rating: on transformer 2403-2606 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 2403-2607 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 2403-12727 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 2403-396 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 2403-8143 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 2403-6121 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 8264-7079 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 8264-12517 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 3187-4843 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 3187-4844 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 3187-4845 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 3187-4846 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 3187-4847 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 3187-4837 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 3187-1955 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 3187-9984 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 3187-3074 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 3187-3072 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1488
% INFO    : Updated Thermal Rating: on transformer 10536-6985 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 10536-6987 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 10536-12505 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 10536-12506 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on transformer 12737-5468 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 12737-5467 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 12737-5466 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 12737-4181 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 1404-12025 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on transformer 6538-781 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 730
% INFO    : Updated Thermal Rating: on transformer 6538-781 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 730
% INFO    : Updated Thermal Rating: on transformer 1161-13143 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 582
% INFO    : Updated Thermal Rating: on transformer 1161-12001 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 582
% INFO    : Updated Thermal Rating: on transformer 1161-6747 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 582
% INFO    : Updated Thermal Rating: on transformer 7260-6831 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 626
% INFO    : Updated Thermal Rating: on transformer 7260-10963 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 304
% INFO    : Updated Thermal Rating: on transformer 7260-12393 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 365
% INFO    : Updated Thermal Rating: on transformer 7260-6305 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 365
% INFO    : Updated Thermal Rating: on transformer 7260-11539 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 304
% INFO    : Updated Thermal Rating: on transformer 7260-12678 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 365
% INFO    : Updated Thermal Rating: on transformer 7260-13010 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 365
% INFO    : Updated Thermal Rating: on transformer 7260-9204 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 304
% INFO    : Updated Thermal Rating: on transformer 11-12266 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 558
% INFO    : Updated Thermal Rating: on transformer 11-3201 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 558
% INFO    : Updated Thermal Rating: on transformer 11-8816 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 695
% INFO    : Updated Thermal Rating: on transformer 6831-9937 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 304
% INFO    : Updated Thermal Rating: on transformer 6831-8290 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 304
% INFO    : Updated Thermal Rating: on transformer 12420-12815 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 111
% INFO    : Updated Thermal Rating: on transformer 6019-7473 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 53
% INFO    : Updated Thermal Rating: on transformer 6019-1903 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12
% INFO    : Updated Thermal Rating: on transformer 6019-5982 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12
% INFO    : Updated Thermal Rating: on transformer 6019-13165 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12
% INFO    : Updated Thermal Rating: on transformer 6019-10186 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12
% INFO    : Updated Thermal Rating: on transformer 6019-5162 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27
% INFO    : Updated Thermal Rating: on transformer 6019-10466 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27
% INFO    : Updated Thermal Rating: on transformer 6019-8493 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13
% INFO    : Updated Thermal Rating: on transformer 6019-324 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13
% INFO    : Updated Thermal Rating: on transformer 6019-13131 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 53
% INFO    : Updated Thermal Rating: on transformer 11918-4614 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 88
% INFO    : Updated Thermal Rating: on transformer 10797-12441 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 41
% INFO    : Updated Thermal Rating: on transformer 10797-7639 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 40
% INFO    : Updated Thermal Rating: on transformer 10797-11768 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 154
% INFO    : Updated Thermal Rating: on transformer 10797-2906 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 40
% INFO    : Updated Thermal Rating: on transformer 12089-9292 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 106
% INFO    : Updated Thermal Rating: on transformer 12089-10428 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 106
% INFO    : Updated Thermal Rating: on transformer 12089-2048 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 79
% INFO    : Updated Thermal Rating: on transformer 9313-9146 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 718
% INFO    : Updated Thermal Rating: on transformer 9313-9146 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 718
% INFO    : Updated Thermal Rating: on transformer 9313-6491 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 474
% INFO    : Updated Thermal Rating: on transformer 9313-7535 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 474
% INFO    : Updated Thermal Rating: on transformer 9313-12865 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 527
% INFO    : Updated Thermal Rating: on transformer 9640-3760 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on transformer 9640-3760 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on transformer 9640-8501 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 835
% INFO    : Updated Thermal Rating: on transformer 9640-8501 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 835
% INFO    : Updated Thermal Rating: on transformer 8364-7550 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 698
% INFO    : Updated Thermal Rating: on transformer 8364-7550 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 698
% INFO    : Updated Thermal Rating: on transformer 8364-4263 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 693
% INFO    : Updated Thermal Rating: on transformer 8364-4263 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 693
% INFO    : Updated Thermal Rating: on transformer 5348-4970 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on transformer 5348-4970 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on transformer 5348-9576 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 642
% INFO    : Updated Thermal Rating: on transformer 5348-9576 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 642
% INFO    : Updated Thermal Rating: on transformer 5348-13191 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 711
% INFO    : Updated Thermal Rating: on transformer 5348-7327 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 711
% INFO    : Updated Thermal Rating: on transformer 5348-2069 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 764
% INFO    : Updated Thermal Rating: on transformer 12365-11707 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 642
% INFO    : Updated Thermal Rating: on transformer 12365-11707 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 642
% INFO    : Updated Thermal Rating: on transformer 13005-9058 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 677
% INFO    : Updated Thermal Rating: on transformer 13005-7788 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on transformer 9147-6616 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 474
% INFO    : Updated Thermal Rating: on transformer 9147-7643 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 474
% INFO    : Updated Thermal Rating: on transformer 9147-13002 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 527
% INFO    : Updated Thermal Rating: on transformer 1187-10353 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on transformer 1187-10353 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on transformer 3237-8887 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 119
% INFO    : Updated Thermal Rating: on transformer 3237-10784 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 120
% INFO    : Updated Thermal Rating: on transformer 3237-5542 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 120
% INFO    : Updated Thermal Rating: on transformer 3237-11509 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 179
% INFO    : Updated Thermal Rating: on transformer 4389-9395 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 198
% INFO    : Updated Thermal Rating: on transformer 3730-11944 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 642
% INFO    : Updated Thermal Rating: on transformer 3730-11944 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 642
% INFO    : Updated Thermal Rating: on transformer 3730-8037 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on transformer 3730-8037 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on transformer 10667-6585 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 333
% INFO    : Updated Thermal Rating: on transformer 10667-1868 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 333
% INFO    : Updated Thermal Rating: on transformer 10667-10239 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 298
% INFO    : Updated Thermal Rating: on transformer 10667-10932 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 488
% INFO    : Updated Thermal Rating: on transformer 10667-12983 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 488
% INFO    : Updated Thermal Rating: on transformer 11896-13511 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on transformer 11896-13511 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on transformer 1187-9113 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 695
% INFO    : Updated Thermal Rating: on transformer 1187-9113 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 695
% INFO    : Updated Thermal Rating: on transformer 2273-1828 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on transformer 2273-1828 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on transformer 2273-5556 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on transformer 2273-5556 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on transformer 5861-2565 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 645
% INFO    : Updated Thermal Rating: on transformer 5861-2565 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 645
% INFO    : Updated Thermal Rating: on transformer 5861-6308 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on transformer 5861-6308 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on transformer 5861-5343 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 711
% INFO    : Updated Thermal Rating: on transformer 5861-3369 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 711
% INFO    : Updated Thermal Rating: on transformer 5861-7593 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 764
% INFO    : Updated Thermal Rating: on transformer 12845-12328 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 642
% INFO    : Updated Thermal Rating: on transformer 12845-12328 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 642
% INFO    : Updated Thermal Rating: on transformer 2609-6292 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on transformer 2609-6292 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on transformer 2609-7466 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 642
% INFO    : Updated Thermal Rating: on transformer 2609-7466 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 642
% INFO    : Updated Thermal Rating: on transformer 940-473 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 571
% INFO    : Updated Thermal Rating: on transformer 940-473 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 571
% INFO    : Updated Thermal Rating: on transformer 940-473 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 571
% INFO    : Updated Thermal Rating: on transformer 940-473 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 571
% INFO    : Updated Thermal Rating: on transformer 2889-5314 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 430
% INFO    : Updated Thermal Rating: on transformer 2889-365 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 417
% INFO    : Updated Thermal Rating: on transformer 7166-11587 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on transformer 7166-11587 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on transformer 10066-12178 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 158
% INFO    : Updated Thermal Rating: on transformer 10066-12401 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 330
% INFO    : Updated Thermal Rating: on transformer 10066-11257 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 164
% INFO    : Updated Thermal Rating: on transformer 13458-9855 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22
% INFO    : Updated Thermal Rating: on transformer 13458-11177 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27
% INFO    : Updated Thermal Rating: on transformer 13458-10012 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27
% INFO    : Updated Thermal Rating: on transformer 13458-12358 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 44
% INFO    : Updated Thermal Rating: on transformer 13458-8933 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 44
% INFO    : Updated Thermal Rating: on transformer 13453-786 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 95
% INFO    : Updated Thermal Rating: on transformer 13453-2852 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 95
% INFO    : Updated Thermal Rating: on transformer 13453-7949 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 95
% INFO    : Updated Thermal Rating: on transformer 6535-7449 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 717
% INFO    : Updated Thermal Rating: on transformer 6535-6836 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 717
% INFO    : Updated Thermal Rating: on transformer 6535-1085 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 766
% INFO    : Updated Thermal Rating: on transformer 11937-2260 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 402
% INFO    : Updated Thermal Rating: on transformer 11937-5965 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 409
% INFO    : Updated Thermal Rating: on transformer 7206-1124 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 626
% INFO    : Updated Thermal Rating: on transformer 7206-1124 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 626
% INFO    : Updated Thermal Rating: on transformer 7206-1124 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 626
% INFO    : Updated Thermal Rating: on transformer 1760-8352 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 100
% INFO    : Updated Thermal Rating: on transformer 1760-7257 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 100
% INFO    : Updated Thermal Rating: on transformer 1760-1959 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 100
% INFO    : Updated Thermal Rating: on transformer 10858-10094 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 717
% INFO    : Updated Thermal Rating: on transformer 10858-2759 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 717
% INFO    : Updated Thermal Rating: on transformer 10858-8388 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 766
% INFO    : Updated Thermal Rating: on transformer 10858-12291 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 717
% INFO    : Updated Thermal Rating: on transformer 10858-7662 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 717
% INFO    : Updated Thermal Rating: on transformer 10858-12248 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 766
% INFO    : Updated Thermal Rating: on transformer 12809-6783 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on transformer 12809-6783 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 693
% INFO    : Updated Thermal Rating: on transformer 12809-2042 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 643
% INFO    : Updated Thermal Rating: on transformer 12809-2042 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 643
% INFO    : Updated Thermal Rating: on transformer 11052-1007 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 53
% INFO    : Updated Thermal Rating: on transformer 6706-10973 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 422
% INFO    : Updated Thermal Rating: on transformer 12292-5742 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 718
% INFO    : Updated Thermal Rating: on transformer 9036-3682 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 44
% INFO    : Updated Thermal Rating: on transformer 9036-11967 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13
% INFO    : Updated Thermal Rating: on transformer 9036-10052 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13
% INFO    : Updated Thermal Rating: on transformer 9036-4337 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 56
% INFO    : Updated Thermal Rating: on transformer 9036-8881 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25
% INFO    : Updated Thermal Rating: on transformer 9036-10757 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25
% INFO    : Updated Thermal Rating: on transformer 9036-9168 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12
% INFO    : Updated Thermal Rating: on transformer 9036-1004 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12
% INFO    : Updated Thermal Rating: on transformer 9036-2784 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14
% INFO    : Updated Thermal Rating: on transformer 12897-6527 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 809
% INFO    : Updated Thermal Rating: on transformer 12897-1822 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 809
% INFO    : Updated Thermal Rating: on transformer 12897-9871 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 809
% INFO    : Updated Thermal Rating: on transformer 9026-151 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1087
% INFO    : Updated Thermal Rating: on transformer 9026-11856 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1087
% INFO    : Updated Thermal Rating: on transformer 11710-4353 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 232
% INFO    : Updated Thermal Rating: on transformer 11710-9628 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 243
% INFO    : Updated Thermal Rating: on transformer 11710-3593 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 240
% INFO    : Updated Thermal Rating: on transformer 10277-9024 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1087
% INFO    : Updated Thermal Rating: on transformer 2152-8433 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 123
% INFO    : Updated Thermal Rating: on transformer 2152-9552 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 71
% INFO    : Updated Thermal Rating: on transformer 2152-13075 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on transformer 2152-315 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6
% INFO    : Updated Thermal Rating: on transformer 2683-5044 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 465
% INFO    : Updated Thermal Rating: on transformer 2683-5044 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 465
% INFO    : Updated Thermal Rating: on transformer 2683-5044 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on transformer 2226-7487 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 160
% INFO    : Updated Thermal Rating: on transformer 4867-8193 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 137
% INFO    : Updated Thermal Rating: on transformer 6791-8385 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 62
% INFO    : Updated Thermal Rating: on transformer 6791-11281 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 36
% INFO    : Updated Thermal Rating: on transformer 5266-6132 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 55
% INFO    : Updated Thermal Rating: on transformer 7868-9722 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 446
% INFO    : Updated Thermal Rating: on transformer 7868-10825 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 446
% INFO    : Updated Thermal Rating: on transformer 10758-2912 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 172
% INFO    : Updated Thermal Rating: on transformer 10758-11502 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 87
% INFO    : Updated Thermal Rating: on transformer 8508-10368 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 395
% INFO    : Updated Thermal Rating: on transformer 7720-7255 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 677
% INFO    : Updated Thermal Rating: on transformer 7720-8846 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 470
% INFO    : Updated Thermal Rating: on transformer 7720-9972 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 470
% INFO    : Updated Thermal Rating: on transformer 10885-13630 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 447
% INFO    : Updated Thermal Rating: on transformer 10885-13630 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 440
% INFO    : Updated Thermal Rating: on transformer 10885-2990 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 474
% INFO    : Updated Thermal Rating: on transformer 11555-6383 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 93
% INFO    : Updated Thermal Rating: on transformer 11555-7250 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 44
% INFO    : Updated Thermal Rating: on transformer 11555-10409 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17
% INFO    : Updated Thermal Rating: on transformer 11555-6009 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11
% INFO    : Updated Thermal Rating: on transformer 11555-432 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11
% INFO    : Updated Thermal Rating: on transformer 7255-4208 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 438
% INFO    : Updated Thermal Rating: on transformer 10397-7340 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 517
% INFO    : Updated Thermal Rating: on transformer 6771-6171 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 72
% INFO    : Updated Thermal Rating: on transformer 6771-4235 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 72
% INFO    : Updated Thermal Rating: on transformer 6771-13447 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 72
% INFO    : Updated Thermal Rating: on transformer 13258-1551 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 642
% INFO    : Updated Thermal Rating: on transformer 13258-1551 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 642
% INFO    : Updated Thermal Rating: on transformer 13258-1551 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 642
% INFO    : Updated Thermal Rating: on transformer 10601-5397 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 149
% INFO    : Updated Thermal Rating: on transformer 10601-3432 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 149
% INFO    : Updated Thermal Rating: on transformer 10601-12687 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 149
% INFO    : Updated Thermal Rating: on transformer 8778-9735 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 626
% INFO    : Updated Thermal Rating: on transformer 8778-9735 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 626
% INFO    : Updated Thermal Rating: on transformer 8778-6152 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 675
% INFO    : Updated Thermal Rating: on transformer 8778-6152 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 675
% INFO    : Updated Thermal Rating: on transformer 8778-4408 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 642
% INFO    : Updated Thermal Rating: on transformer 8778-4408 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 642
% INFO    : Updated Thermal Rating: on transformer 6700-3920 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on transformer 6700-3920 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on transformer 6700-13624 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 626
% INFO    : Updated Thermal Rating: on transformer 6700-13624 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 626
% INFO    : Updated Thermal Rating: on transformer 3808-4320 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on transformer 3808-4320 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on transformer 3808-4320 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on transformer 3808-4320 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on transformer 9735-7857 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 64
% INFO    : Updated Thermal Rating: on transformer 9735-6784 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 64
% INFO    : Updated Thermal Rating: on transformer 9735-1469 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 38
% INFO    : Updated Thermal Rating: on transformer 9735-2397 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 38
% INFO    : Updated Thermal Rating: on transformer 3370-2645 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 106
% INFO    : Updated Thermal Rating: on transformer 3370-9466 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 55
% INFO    : Updated Thermal Rating: on transformer 3370-9223 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9
% INFO    : Updated Thermal Rating: on transformer 4565-12657 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13
% INFO    : Updated Thermal Rating: on transformer 4565-4643 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23
% INFO    : Updated Thermal Rating: on transformer 4565-10010 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23
% INFO    : Updated Thermal Rating: on transformer 4565-11945 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23
% INFO    : Updated Thermal Rating: on transformer 4565-7768 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27
% INFO    : Updated Thermal Rating: on transformer 4565-2278 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 12
% INFO    : Updated Thermal Rating: on transformer 4565-10693 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13
% INFO    : Updated Thermal Rating: on transformer 4565-6942 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13
% INFO    : Updated Thermal Rating: on transformer 12068-1594 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 158
% INFO    : Updated Thermal Rating: on transformer 12068-2603 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 158
% INFO    : Updated Thermal Rating: on transformer 12068-7921 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 50
% INFO    : Updated Thermal Rating: on transformer 12068-7009 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 50
% INFO    : Updated Thermal Rating: on transformer 12251-13090 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 717
% INFO    : Updated Thermal Rating: on transformer 12251-11492 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 717
% INFO    : Updated Thermal Rating: on transformer 12251-3179 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 766
% INFO    : Updated Thermal Rating: on transformer 12251-1150 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 717
% INFO    : Updated Thermal Rating: on transformer 12251-9364 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 717
% INFO    : Updated Thermal Rating: on transformer 12251-7489 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 766
% INFO    : Updated Thermal Rating: on transformer 11740-12873 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 73
% INFO    : Updated Thermal Rating: on transformer 11740-7213 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 73
% INFO    : Updated Thermal Rating: on transformer 11740-11138 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 154
% INFO    : Updated Thermal Rating: on transformer 11740-10006 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 154
% INFO    : Updated Thermal Rating: on transformer 11740-958 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 154
% INFO    : Updated Thermal Rating: on transformer 11740-13550 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 154
% INFO    : Updated Thermal Rating: on transformer 11740-8141 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 77
% INFO    : Updated Thermal Rating: on transformer 11740-7068 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 77
% INFO    : Updated Thermal Rating: on transformer 11740-12375 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 547
% INFO    : Updated Thermal Rating: on transformer 3973-10061 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 560
% INFO    : Updated Thermal Rating: on transformer 3973-10061 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 778
% INFO    : Updated Thermal Rating: on transformer 3973-3178 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 560
% INFO    : Updated Thermal Rating: on transformer 3973-8499 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 560
% INFO    : Updated Thermal Rating: on transformer 3973-10473 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 560
% INFO    : Updated Thermal Rating: on transformer 3973-2106 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 560
% INFO    : Updated Thermal Rating: on transformer 12660-12989 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 123
% INFO    : Updated Thermal Rating: on transformer 12660-717 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 88
% INFO    : Updated Thermal Rating: on transformer 12660-2268 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 55
% INFO    : Updated Thermal Rating: on transformer 1280-6199 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 101
% INFO    : Updated Thermal Rating: on transformer 6755-2223 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 99
% INFO    : Updated Thermal Rating: on transformer 6755-8157 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 99
% INFO    : Updated Thermal Rating: on transformer 6755-13549 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 99
% INFO    : Updated Thermal Rating: on transformer 3841-602 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 642
% INFO    : Updated Thermal Rating: on transformer 3841-602 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 642
% INFO    : Updated Thermal Rating: on transformer 602-12189 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 53
% INFO    : Updated Thermal Rating: on transformer 602-3880 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 53
% INFO    : Updated Thermal Rating: on transformer 602-1907 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 53
% INFO    : Updated Thermal Rating: on transformer 602-4196 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14
% INFO    : Updated Thermal Rating: on transformer 602-6130 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14
% INFO    : Updated Thermal Rating: on transformer 6504-1526 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 67
% INFO    : Updated Thermal Rating: on transformer 6504-4823 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 67
% INFO    : Updated Thermal Rating: on transformer 10586-6038 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 527
% INFO    : Updated Thermal Rating: on transformer 10586-3926 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 527
% INFO    : Updated Thermal Rating: on transformer 10586-12367 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 527
% INFO    : Updated Thermal Rating: on transformer 1297-5818 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 341
% INFO    : Updated Thermal Rating: on transformer 1297-5818 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 341
% INFO    : Updated Thermal Rating: on transformer 1297-5818 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 584
% INFO    : Updated Thermal Rating: on transformer 1297-12199 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 577
% INFO    : Updated Thermal Rating: on transformer 1297-6822 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 577
% INFO    : Updated Thermal Rating: on transformer 12110-2567 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 711
% INFO    : Updated Thermal Rating: on transformer 12110-2567 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 711
% INFO    : Updated Thermal Rating: on transformer 12110-9195 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 581
% INFO    : Updated Thermal Rating: on transformer 12110-3939 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 581
% INFO    : Updated Thermal Rating: on transformer 6037-5202 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 110
% INFO    : Updated Thermal Rating: on transformer 6037-552 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 110
% INFO    : Updated Thermal Rating: on transformer 10259-4423 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8
% INFO    : Updated Thermal Rating: on transformer 10259-8010 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 44
% INFO    : Updated Thermal Rating: on transformer 10259-6200 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22
% INFO    : Updated Thermal Rating: on transformer 10259-6864 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8
% INFO    : Updated Thermal Rating: on transformer 10259-8654 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8
% INFO    : Updated Thermal Rating: on transformer 10259-7261 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8
% INFO    : Updated Thermal Rating: on transformer 10259-9413 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8
% INFO    : Updated Thermal Rating: on transformer 10259-2341 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8
% INFO    : Updated Thermal Rating: on transformer 10259-13551 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8
% INFO    : Updated Thermal Rating: on transformer 10259-11440 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8
% INFO    : Updated Thermal Rating: on transformer 10259-8916 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8
% INFO    : Updated Thermal Rating: on transformer 10259-6314 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8
% INFO    : Updated Thermal Rating: on transformer 10259-8122 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8
% INFO    : Updated Thermal Rating: on transformer 10259-12748 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8
% INFO    : Updated Thermal Rating: on transformer 10259-11311 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9
% INFO    : Updated Thermal Rating: on transformer 10259-4488 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9
% INFO    : Updated Thermal Rating: on transformer 10259-9748 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9
% INFO    : Updated Thermal Rating: on transformer 2096-1642 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 44
% INFO    : Updated Thermal Rating: on transformer 12975-10988 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on transformer 12975-10988 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on transformer 12975-10988 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on transformer 10988-94 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 85
% INFO    : Updated Thermal Rating: on transformer 1579-9166 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 64
% INFO    : Updated Thermal Rating: on transformer 6966-7416 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 84
% INFO    : Updated Thermal Rating: on transformer 6966-12816 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 84
% INFO    : Updated Thermal Rating: on transformer 6966-270 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 84
% INFO    : Updated Thermal Rating: on transformer 484-12499 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 44
% INFO    : Updated Thermal Rating: on transformer 2188-2721 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 46
% INFO    : Updated Thermal Rating: on transformer 10975-7879 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on transformer 10975-7879 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on transformer 10975-7879 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on transformer 10975-4085 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13
% INFO    : Updated Thermal Rating: on transformer 10975-11859 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13
% INFO    : Updated Thermal Rating: on transformer 10975-1329 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13
% INFO    : Updated Thermal Rating: on transformer 10975-9804 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 44
% INFO    : Updated Thermal Rating: on transformer 10975-9638 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 44
% INFO    : Updated Thermal Rating: on transformer 2037-8559 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 198
% INFO    : Updated Thermal Rating: on transformer 2037-13200 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 198
% INFO    : Updated Thermal Rating: on transformer 2824-11990 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 66
% INFO    : Updated Thermal Rating: on transformer 2824-3371 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 66
% INFO    : Updated Thermal Rating: on transformer 10109-779 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 66
% INFO    : Updated Thermal Rating: on transformer 10109-8980 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 66
% INFO    : Updated Thermal Rating: on transformer 215-8514 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 482
% INFO    : Updated Thermal Rating: on transformer 215-8514 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 670
% INFO    : Updated Thermal Rating: on transformer 215-13218 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 402
% INFO    : Updated Thermal Rating: on transformer 215-7751 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 402
% INFO    : Updated Thermal Rating: on transformer 215-5964 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 402
% INFO    : Updated Thermal Rating: on transformer 215-12050 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 402
% INFO    : Updated Thermal Rating: on transformer 7953-9965 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 420
% INFO    : Updated Thermal Rating: on transformer 7953-9965 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 719
% INFO    : Updated Thermal Rating: on transformer 7953-9965 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 719
% INFO    : Updated Thermal Rating: on transformer 7953-9965 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 719
% INFO    : Updated Thermal Rating: on transformer 10274-746 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 53
% INFO    : Updated Thermal Rating: on transformer 10274-13112 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 53
% INFO    : Updated Thermal Rating: on transformer 10490-10955 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 662
% INFO    : Updated Thermal Rating: on transformer 10490-10955 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 675
% INFO    : Updated Thermal Rating: on transformer 11742-6042 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 445
% INFO    : Updated Thermal Rating: on transformer 11742-6042 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 445
% INFO    : Updated Thermal Rating: on transformer 11742-6042 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 406
% INFO    : Updated Thermal Rating: on transformer 11742-6042 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 406
% INFO    : Updated Thermal Rating: on transformer 1569-8488 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 41
% INFO    : Updated Thermal Rating: on transformer 1569-6192 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 64
% INFO    : Updated Thermal Rating: on transformer 1569-4796 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 55
% INFO    : Updated Thermal Rating: on transformer 1119-9504 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 177
% INFO    : Updated Thermal Rating: on transformer 1119-11630 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 177
% INFO    : Updated Thermal Rating: on transformer 1119-2237 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 177
% INFO    : Updated Thermal Rating: on transformer 2589-10783 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 241
% INFO    : Updated Thermal Rating: on transformer 2765-10814 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 494
% INFO    : Updated Thermal Rating: on transformer 2765-5576 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 494
% INFO    : Updated Thermal Rating: on transformer 2765-7381 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 494
% INFO    : Updated Thermal Rating: on transformer 10781-2428 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 172
% INFO    : Updated Thermal Rating: on transformer 10781-6680 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 172
% INFO    : Updated Thermal Rating: on transformer 10781-11935 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 172
% INFO    : Updated Thermal Rating: on transformer 8624-4124 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 677
% INFO    : Updated Thermal Rating: on transformer 4124-2131 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 119
% INFO    : Updated Thermal Rating: on transformer 4124-3968 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 119
% INFO    : Updated Thermal Rating: on transformer 4124-12398 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 119
% INFO    : Updated Thermal Rating: on transformer 4124-296 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 193
% INFO    : Updated Thermal Rating: on transformer 4124-4917 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 216
% INFO    : Updated Thermal Rating: on transformer 4124-2933 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 108
% INFO    : Updated Thermal Rating: on transformer 7292-12829 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 200
% INFO    : Updated Thermal Rating: on transformer 7292-10298 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 200
% INFO    : Updated Thermal Rating: on transformer 9639-10376 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 215
% INFO    : Updated Thermal Rating: on transformer 4017-7556 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 270
% INFO    : Updated Thermal Rating: on transformer 4017-8644 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 270
% INFO    : Updated Thermal Rating: on transformer 4017-400 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 270
% INFO    : Updated Thermal Rating: on transformer 10018-8485 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on transformer 10018-278 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1254
% INFO    : Updated Thermal Rating: on transformer 10018-12579 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1254
% INFO    : Updated Thermal Rating: on transformer 191-3200 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 677
% INFO    : Updated Thermal Rating: on transformer 3200-3738 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 90
% INFO    : Updated Thermal Rating: on transformer 2762-7705 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 175
% INFO    : Updated Thermal Rating: on transformer 2762-5826 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 85
% INFO    : Updated Thermal Rating: on transformer 11766-2215 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 172
% INFO    : Updated Thermal Rating: on transformer 11766-10295 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 172
% INFO    : Updated Thermal Rating: on transformer 11766-12949 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 172
% INFO    : Updated Thermal Rating: on transformer 7883-2270 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 66
% INFO    : Updated Thermal Rating: on transformer 13168-8413 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 132
% INFO    : Updated Thermal Rating: on transformer 2477-13 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 677
% INFO    : Updated Thermal Rating: on transformer 2477-7743 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 474
% INFO    : Updated Thermal Rating: on transformer 2477-12287 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 474
% INFO    : Updated Thermal Rating: on transformer 2477-539 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 474
% INFO    : Updated Thermal Rating: on transformer 2477-8830 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 474
% INFO    : Updated Thermal Rating: on transformer 9769-2071 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 235
% INFO    : Updated Thermal Rating: on transformer 9769-294 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 235
% INFO    : Updated Thermal Rating: on transformer 3045-3562 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 376
% INFO    : Updated Thermal Rating: on transformer 3045-3562 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 376
% INFO    : Updated Thermal Rating: on transformer 3045-3562 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 376
% INFO    : Updated Thermal Rating: on transformer 7209-8808 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 631
% INFO    : Updated Thermal Rating: on transformer 7209-8808 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 631
% INFO    : Updated Thermal Rating: on transformer 7209-5233 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 670
% INFO    : Updated Thermal Rating: on transformer 7209-5233 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 670
% INFO    : Updated Thermal Rating: on transformer 7769-8166 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 677
% INFO    : Updated Thermal Rating: on transformer 7769-6958 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 677
% INFO    : Updated Thermal Rating: on transformer 11188-10433 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25
% INFO    : Updated Thermal Rating: on transformer 11188-10237 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9
% INFO    : Updated Thermal Rating: on transformer 11188-5000 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9
% INFO    : Updated Thermal Rating: on transformer 3317-3315 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 594
% INFO    : Updated Thermal Rating: on transformer 3317-3315 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 594
% INFO    : Updated Thermal Rating: on transformer 3317-3315 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 594
% INFO    : Updated Thermal Rating: on transformer 2704-11970 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 69
% INFO    : Updated Thermal Rating: on transformer 2704-11329 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 69
% INFO    : Updated Thermal Rating: on transformer 9369-7577 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 67
% INFO    : Updated Thermal Rating: on transformer 9369-12966 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 67
% INFO    : Updated Thermal Rating: on transformer 9369-1245 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 67
% INFO    : Updated Thermal Rating: on transformer 6730-12658 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 156
% INFO    : Updated Thermal Rating: on transformer 6730-5484 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 156
% INFO    : Updated Thermal Rating: on transformer 6730-9975 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 138
% INFO    : Updated Thermal Rating: on transformer 6730-12736 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 138
% INFO    : Updated Thermal Rating: on transformer 8166-3294 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 623
% INFO    : Updated Thermal Rating: on transformer 6958-10211 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 623
% INFO    : Updated Thermal Rating: on transformer 6958-12204 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 871
% INFO    : Updated Thermal Rating: on transformer 5533-10951 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 160
% INFO    : Updated Thermal Rating: on transformer 5533-9836 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52
% INFO    : Updated Thermal Rating: on transformer 1652-12608 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 626
% INFO    : Updated Thermal Rating: on transformer 1652-12608 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 626
% INFO    : Updated Thermal Rating: on transformer 11647-12154 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 264
% INFO    : Updated Thermal Rating: on transformer 11647-12154 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 264
% INFO    : Updated Thermal Rating: on transformer 10880-10276 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 36
% INFO    : Updated Thermal Rating: on transformer 10880-9151 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 36
% INFO    : Updated Thermal Rating: on transformer 10880-3848 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 36
% INFO    : Updated Thermal Rating: on transformer 10777-4704 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 277
% INFO    : Updated Thermal Rating: on transformer 10777-8060 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 277
% INFO    : Updated Thermal Rating: on transformer 639-11020 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24
% INFO    : Updated Thermal Rating: on transformer 639-10114 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24
% INFO    : Updated Thermal Rating: on transformer 639-13617 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24
% INFO    : Updated Thermal Rating: on transformer 5985-4331 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 166
% INFO    : Updated Thermal Rating: on transformer 5985-3567 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 166
% INFO    : Updated Thermal Rating: on transformer 6395-6396 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 424
% INFO    : Updated Thermal Rating: on transformer 6395-6396 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 424
% INFO    : Updated Thermal Rating: on transformer 6395-6396 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 424
% INFO    : Updated Thermal Rating: on transformer 6395-6396 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 404
% INFO    : Updated Thermal Rating: on transformer 13337-7710 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 687
% INFO    : Updated Thermal Rating: on transformer 13337-7710 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 375
% INFO    : Updated Thermal Rating: on transformer 5684-7641 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 118
% INFO    : Updated Thermal Rating: on transformer 5684-1059 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 118
% INFO    : Updated Thermal Rating: on transformer 5684-4267 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 118
% INFO    : Updated Thermal Rating: on transformer 5684-13195 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 118
% INFO    : Updated Thermal Rating: on transformer 12215-8023 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 127
% INFO    : Updated Thermal Rating: on transformer 12215-13096 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 127
% INFO    : Updated Thermal Rating: on transformer 598-13159 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22
% INFO    : Updated Thermal Rating: on transformer 11683-3184 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 85
% INFO    : Updated Thermal Rating: on transformer 11683-2122 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 85
% INFO    : Updated Thermal Rating: on transformer 11683-10501 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 85
% INFO    : Updated Thermal Rating: on transformer 1942-11059 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 158
% INFO    : Updated Thermal Rating: on transformer 1942-9995 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 158
% INFO    : Updated Thermal Rating: on transformer 1942-4775 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 158
% INFO    : Updated Thermal Rating: on transformer 1942-7329 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 132
% INFO    : Updated Thermal Rating: on transformer 2748-12569 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 482
% INFO    : Updated Thermal Rating: on transformer 2748-12569 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 431
% INFO    : Updated Thermal Rating: on transformer 2748-5418 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 40
% INFO    : Updated Thermal Rating: on transformer 6270-10057 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 190
% INFO    : Updated Thermal Rating: on transformer 6270-5645 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 190
% INFO    : Updated Thermal Rating: on transformer 6270-3686 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 190
% INFO    : Updated Thermal Rating: on transformer 2162-8728 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 642
% INFO    : Updated Thermal Rating: on transformer 2162-8728 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 642
% INFO    : Updated Thermal Rating: on transformer 13050-2566 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 158
% INFO    : Updated Thermal Rating: on transformer 8641-8930 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on transformer 8641-8930 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 385
% INFO    : Updated Thermal Rating: on transformer 8641-8930 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on transformer 4474-13087 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 56
% INFO    : Updated Thermal Rating: on transformer 4474-3488 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 56
% INFO    : Updated Thermal Rating: on transformer 7119-7430 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 102
% INFO    : Updated Thermal Rating: on transformer 7119-5494 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 102
% INFO    : Updated Thermal Rating: on transformer 8539-8896 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 92
% INFO    : Updated Thermal Rating: on transformer 8539-7052 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 93
% INFO    : Updated Thermal Rating: on transformer 8026-9927 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 412
% INFO    : Updated Thermal Rating: on transformer 8026-9927 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 636
% INFO    : Updated Thermal Rating: on transformer 8026-51 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 488
% INFO    : Updated Thermal Rating: on transformer 8026-1821 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 488
% INFO    : Updated Thermal Rating: on transformer 8026-10177 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 488
% INFO    : Updated Thermal Rating: on transformer 2129-8449 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 391
% INFO    : Updated Thermal Rating: on transformer 2129-8449 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 431
% INFO    : Updated Thermal Rating: on transformer 2129-8449 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 374
% INFO    : Updated Thermal Rating: on transformer 2129-8449 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 431
% INFO    : Updated Thermal Rating: on transformer 2129-4261 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 711
% INFO    : Updated Thermal Rating: on transformer 2129-299 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 711
% INFO    : Updated Thermal Rating: on transformer 2129-8561 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 764
% INFO    : Updated Thermal Rating: on transformer 10819-2860 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on transformer 10819-2860 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on transformer 4820-8179 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 274
% INFO    : Updated Thermal Rating: on transformer 4820-2717 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 274
% INFO    : Updated Thermal Rating: on transformer 4820-5905 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 274
% INFO    : Updated Thermal Rating: on transformer 11964-4983 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 33
% INFO    : Updated Thermal Rating: on transformer 5820-671 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 71
% INFO    : Updated Thermal Rating: on transformer 5820-1180 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 71
% INFO    : Updated Thermal Rating: on transformer 5820-12558 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26
% INFO    : Updated Thermal Rating: on transformer 4-8857 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 66
% INFO    : Updated Thermal Rating: on transformer 4-572 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 66
% INFO    : Updated Thermal Rating: on transformer 4-2460 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 132
% INFO    : Updated Thermal Rating: on transformer 4-7777 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 132
% INFO    : Updated Thermal Rating: on transformer 12356-3385 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 53
% INFO    : Updated Thermal Rating: on transformer 12356-8837 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 53
% INFO    : Updated Thermal Rating: on transformer 12356-10945 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 41
% INFO    : Updated Thermal Rating: on transformer 767-9227 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 128
% INFO    : Updated Thermal Rating: on transformer 767-8121 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 128
% INFO    : Updated Thermal Rating: on transformer 767-2831 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 128
% INFO    : Updated Thermal Rating: on transformer 9300-10156 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 474
% INFO    : Updated Thermal Rating: on transformer 9300-9054 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 474
% INFO    : Updated Thermal Rating: on transformer 3507-331 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 132
% INFO    : Updated Thermal Rating: on transformer 3507-5716 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 132
% INFO    : Updated Thermal Rating: on transformer 5088-5574 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 447
% INFO    : Updated Thermal Rating: on transformer 5088-5574 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 436
% INFO    : Updated Thermal Rating: on transformer 7658-6649 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 36
% INFO    : Updated Thermal Rating: on transformer 7658-11850 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 36
% INFO    : Updated Thermal Rating: on transformer 7658-258 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 36
% INFO    : Updated Thermal Rating: on transformer 7658-6952 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 36
% INFO    : Updated Thermal Rating: on transformer 7658-10940 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 153
% INFO    : Updated Thermal Rating: on transformer 5363-4918 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 127
% INFO    : Updated Thermal Rating: on transformer 5363-13222 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 127
% INFO    : Updated Thermal Rating: on transformer 3513-7707 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 172
% INFO    : Updated Thermal Rating: on transformer 3513-559 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 172
% INFO    : Updated Thermal Rating: on transformer 10067-10572 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on transformer 10067-10572 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on transformer 10067-12603 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 514
% INFO    : Updated Thermal Rating: on transformer 10067-11665 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 514
% INFO    : Updated Thermal Rating: on transformer 2629-3948 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 198
% INFO    : Updated Thermal Rating: on transformer 2629-13238 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 198
% INFO    : Updated Thermal Rating: on transformer 8462-8252 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 417
% INFO    : Updated Thermal Rating: on transformer 8462-8252 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 642
% INFO    : Updated Thermal Rating: on transformer 8462-8252 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 711
% INFO    : Updated Thermal Rating: on transformer 8462-9049 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 711
% INFO    : Updated Thermal Rating: on transformer 8462-12775 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 711
% INFO    : Updated Thermal Rating: on transformer 8462-8635 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 764
% INFO    : Updated Thermal Rating: on transformer 10673-10153 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 385
% INFO    : Updated Thermal Rating: on transformer 10673-10153 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 677
% INFO    : Updated Thermal Rating: on transformer 7680-1985 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 166
% INFO    : Updated Thermal Rating: on transformer 7680-954 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 163
% INFO    : Updated Thermal Rating: on transformer 931-10557 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 32
% INFO    : Updated Thermal Rating: on transformer 931-5384 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 32
% INFO    : Updated Thermal Rating: on transformer 931-7186 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 32
% INFO    : Updated Thermal Rating: on transformer 931-9554 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 32
% INFO    : Updated Thermal Rating: on transformer 10266-8584 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 431
% INFO    : Updated Thermal Rating: on transformer 10266-8584 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 415
% INFO    : Updated Thermal Rating: on transformer 474-25 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 909
% INFO    : Updated Thermal Rating: on transformer 474-25 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 757
% INFO    : Updated Thermal Rating: on transformer 474-1264 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 664
% INFO    : Updated Thermal Rating: on transformer 474-10554 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 664
% INFO    : Updated Thermal Rating: on transformer 474-8483 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 664
% INFO    : Updated Thermal Rating: on transformer 474-12688 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 664
% INFO    : Updated Thermal Rating: on transformer 474-4202 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 664
% INFO    : Updated Thermal Rating: on transformer 474-2308 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 664
% INFO    : Updated Thermal Rating: on transformer 1036-1510 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 376
% INFO    : Updated Thermal Rating: on transformer 1036-1510 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 376
% INFO    : Updated Thermal Rating: on transformer 1036-8453 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 732
% INFO    : Updated Thermal Rating: on transformer 4116-5403 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on transformer 4116-5403 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on transformer 4116-5403 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on transformer 4116-5403 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on transformer 5743-11594 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 392
% INFO    : Updated Thermal Rating: on transformer 5743-7750 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 438
% INFO    : Updated Thermal Rating: on transformer 5743-2430 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 438
% INFO    : Updated Thermal Rating: on transformer 3198-3713 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 932
% INFO    : Updated Thermal Rating: on transformer 3198-1138 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 711
% INFO    : Updated Thermal Rating: on transformer 3198-11987 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 711
% INFO    : Updated Thermal Rating: on transformer 3198-4517 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 711
% INFO    : Updated Thermal Rating: on transformer 3198-9889 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 711
% INFO    : Updated Thermal Rating: on transformer 8751-9253 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 417
% INFO    : Updated Thermal Rating: on transformer 8751-9253 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 417
% INFO    : Updated Thermal Rating: on transformer 8751-9253 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 374
% INFO    : Updated Thermal Rating: on transformer 10807-1644 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 51
% INFO    : Updated Thermal Rating: on transformer 10807-9853 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 51
% INFO    : Updated Thermal Rating: on transformer 7569-7677 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 78
% INFO    : Updated Thermal Rating: on transformer 11594-916 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 445
% INFO    : Updated Thermal Rating: on transformer 12098-1562 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14
% INFO    : Updated Thermal Rating: on transformer 12098-13312 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14
% INFO    : Updated Thermal Rating: on transformer 12098-10580 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on transformer 12098-1488 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on transformer 12098-13193 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4
% INFO    : Updated Thermal Rating: on transformer 12098-2139 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 198
% INFO    : Updated Thermal Rating: on transformer 13473-8052 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 385
% INFO    : Updated Thermal Rating: on transformer 13473-8052 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 677
% INFO    : Updated Thermal Rating: on transformer 13473-8052 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 677
% INFO    : Updated Thermal Rating: on transformer 10828-13514 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 105
% INFO    : Updated Thermal Rating: on transformer 10828-3236 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 105
% INFO    : Updated Thermal Rating: on transformer 10828-8555 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 105
% INFO    : Updated Thermal Rating: on transformer 10828-7568 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 105
% INFO    : Updated Thermal Rating: on transformer 7800-8138 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 681
% INFO    : Updated Thermal Rating: on transformer 7800-8138 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 681
% INFO    : Updated Thermal Rating: on transformer 9507-4668 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 111
% INFO    : Updated Thermal Rating: on transformer 9507-3499 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 111
% INFO    : Updated Thermal Rating: on transformer 9507-11920 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 111
% INFO    : Updated Thermal Rating: on transformer 9507-12946 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 111
% INFO    : Updated Thermal Rating: on transformer 9507-7585 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 111
% INFO    : Updated Thermal Rating: on transformer 9507-6563 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 111
% INFO    : Updated Thermal Rating: on transformer 7448-6558 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 409
% INFO    : Updated Thermal Rating: on transformer 7448-6558 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 681
% INFO    : Updated Thermal Rating: on transformer 7448-13590 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 341
% INFO    : Updated Thermal Rating: on transformer 7448-1845 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 341
% INFO    : Updated Thermal Rating: on transformer 7448-7148 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 341
% INFO    : Updated Thermal Rating: on transformer 7448-11170 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 341
% INFO    : Updated Thermal Rating: on transformer 7448-8394 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 341
% INFO    : Updated Thermal Rating: on transformer 7448-1010 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 341
% INFO    : Updated Thermal Rating: on transformer 1608-2180 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 508
% INFO    : Updated Thermal Rating: on transformer 1608-5158 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 508
% INFO    : Updated Thermal Rating: on transformer 1608-9457 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 508
% INFO    : Updated Thermal Rating: on transformer 1608-6871 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 508
% INFO    : Updated Thermal Rating: on transformer 1608-5281 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 508
% INFO    : Updated Thermal Rating: on transformer 13612-13493 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 980
% INFO    : Updated Thermal Rating: on transformer 13612-3797 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 980
% INFO    : Updated Thermal Rating: on transformer 4624-2227 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 677
% INFO    : Updated Thermal Rating: on transformer 466-11158 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13
% INFO    : Updated Thermal Rating: on transformer 466-12285 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13
% INFO    : Updated Thermal Rating: on transformer 466-3842 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13
% INFO    : Updated Thermal Rating: on transformer 11262-8656 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 53
% INFO    : Updated Thermal Rating: on transformer 11262-4259 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 40
% INFO    : Updated Thermal Rating: on transformer 11262-695 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 40
% INFO    : Updated Thermal Rating: on transformer 11262-10678 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 58
% INFO    : Updated Thermal Rating: on transformer 7090-8299 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 53
% INFO    : Updated Thermal Rating: on transformer 3669-1049 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 442
% INFO    : Updated Thermal Rating: on transformer 3669-1049 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 442
% INFO    : Updated Thermal Rating: on transformer 3669-1049 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 737
% INFO    : Updated Thermal Rating: on transformer 3669-1049 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 737
% INFO    : Updated Thermal Rating: on transformer 8874-8346 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 399
% INFO    : Updated Thermal Rating: on transformer 3203-9902 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 249
% INFO    : Updated Thermal Rating: on transformer 3203-11953 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 249
% INFO    : Updated Thermal Rating: on transformer 3203-8091 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 249
% INFO    : Updated Thermal Rating: on transformer 3203-3872 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24
% INFO    : Updated Thermal Rating: on transformer 741-3082 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 206
% INFO    : Updated Thermal Rating: on transformer 741-12286 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 206
% INFO    : Updated Thermal Rating: on transformer 3443-10835 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 175
% INFO    : Updated Thermal Rating: on transformer 3443-2506 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 175
% INFO    : Updated Thermal Rating: on transformer 8738-7243 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25
% INFO    : Updated Thermal Rating: on transformer 8738-2357 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25
% INFO    : Updated Thermal Rating: on transformer 8738-10650 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25
% INFO    : Updated Thermal Rating: on transformer 2175-11789 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27
% INFO    : Updated Thermal Rating: on transformer 2175-4237 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 31
% INFO    : Updated Thermal Rating: on transformer 2175-7918 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 31
% INFO    : Updated Thermal Rating: on transformer 2175-7066 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 31
% INFO    : Updated Thermal Rating: on transformer 2175-8893 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 31
% INFO    : Updated Thermal Rating: on transformer 2175-13556 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 31
% INFO    : Updated Thermal Rating: on transformer 2175-12616 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27
% INFO    : Updated Thermal Rating: on transformer 2175-7877 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27
% INFO    : Updated Thermal Rating: on transformer 2175-5408 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27
% INFO    : Updated Thermal Rating: on transformer 2175-132 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27
% INFO    : Updated Thermal Rating: on transformer 2175-7267 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27
% INFO    : Updated Thermal Rating: on transformer 2175-5111 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27
% INFO    : Updated Thermal Rating: on transformer 8892-2175 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 695
% INFO    : Updated Thermal Rating: on transformer 11184-11684 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 695
% INFO    : Updated Thermal Rating: on transformer 11184-11684 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 695
% INFO    : Updated Thermal Rating: on transformer 8119-7642 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 695
% INFO    : Updated Thermal Rating: on transformer 402-5679 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27
% INFO    : Updated Thermal Rating: on transformer 402-325 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27
% INFO    : Updated Thermal Rating: on transformer 402-12060 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27
% INFO    : Updated Thermal Rating: on transformer 12408-4748 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on transformer 12408-4748 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on transformer 5949-11282 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 714
% INFO    : Updated Thermal Rating: on transformer 10314-12421 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 29
% INFO    : Updated Thermal Rating: on transformer 10314-13270 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 29
% INFO    : Updated Thermal Rating: on transformer 1056-11900 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 79
% INFO    : Updated Thermal Rating: on transformer 1056-10994 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 79
% INFO    : Updated Thermal Rating: on transformer 1056-9110 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 79
% INFO    : Updated Thermal Rating: on transformer 11432-12896 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 76
% INFO    : Updated Thermal Rating: on transformer 11432-13643 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 76
% INFO    : Updated Thermal Rating: on transformer 11432-3929 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 76
% INFO    : Updated Thermal Rating: on transformer 11432-6359 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 76
% INFO    : Updated Thermal Rating: on transformer 11432-10971 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 51
% INFO    : Updated Thermal Rating: on transformer 11432-2816 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 51
% INFO    : Updated Thermal Rating: on transformer 11432-8163 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 51
% INFO    : Updated Thermal Rating: on transformer 1178-5061 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 37
% INFO    : Updated Thermal Rating: on transformer 1178-6939 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 37
% INFO    : Updated Thermal Rating: on transformer 1178-1640 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 37
% INFO    : Updated Thermal Rating: on transformer 1178-13212 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22
% INFO    : Updated Thermal Rating: on transformer 1178-12277 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22
% INFO    : Updated Thermal Rating: on transformer 1178-10285 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22
% INFO    : Updated Thermal Rating: on transformer 1178-12359 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22
% INFO    : Updated Thermal Rating: on transformer 12974-4392 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 153
% INFO    : Updated Thermal Rating: on transformer 12974-10938 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 110
% INFO    : Updated Thermal Rating: on transformer 12974-13037 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 96
% INFO    : Updated Thermal Rating: on transformer 12974-8393 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 92
% INFO    : Updated Thermal Rating: on transformer 10003-7742 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 88
% INFO    : Updated Thermal Rating: on transformer 4739-927 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 158
% INFO    : Updated Thermal Rating: on transformer 4739-8436 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 158
% INFO    : Updated Thermal Rating: on transformer 4739-10302 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 143
% INFO    : Updated Thermal Rating: on transformer 519-6686 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 135
% INFO    : Updated Thermal Rating: on transformer 519-11581 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 135
% INFO    : Updated Thermal Rating: on transformer 1064-4526 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 326
% INFO    : Updated Thermal Rating: on transformer 1064-7149 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 326
% INFO    : Updated Thermal Rating: on transformer 2885-3392 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on transformer 2885-3392 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on transformer 2885-3392 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on transformer 5794-13634 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 677
% INFO    : Updated Thermal Rating: on transformer 5794-13634 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 677
% INFO    : Updated Thermal Rating: on transformer 5794-10588 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 229
% INFO    : Updated Thermal Rating: on transformer 5794-4786 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 229
% INFO    : Updated Thermal Rating: on transformer 5794-5681 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 229
% INFO    : Updated Thermal Rating: on transformer 5794-13338 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 229
% INFO    : Updated Thermal Rating: on transformer 4804-5313 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on transformer 4804-5313 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 659
% INFO    : Updated Thermal Rating: on transformer 4804-11047 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 443
% INFO    : Updated Thermal Rating: on transformer 4804-6584 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 443
% INFO    : Updated Thermal Rating: on transformer 2752-7439 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 626
% INFO    : Updated Thermal Rating: on transformer 2752-7439 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 626
% INFO    : Updated Thermal Rating: on transformer 2752-7439 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 626
% INFO    : Updated Thermal Rating: on transformer 4417-12572 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 527
% INFO    : Updated Thermal Rating: on transformer 4417-7170 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 527
% INFO    : Updated Thermal Rating: on transformer 3088-7681 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 490
% INFO    : Updated Thermal Rating: on transformer 3088-9553 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 490
% INFO    : Updated Thermal Rating: on transformer 3088-12625 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 490
% INFO    : Updated Thermal Rating: on transformer 11928-12438 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 450
% INFO    : Updated Thermal Rating: on transformer 13288-12730 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 237
% INFO    : Updated Thermal Rating: on transformer 10089-5464 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 395
% INFO    : Updated Thermal Rating: on transformer 9548-283 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27
% INFO    : Updated Thermal Rating: on transformer 9548-8476 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27
% INFO    : Updated Thermal Rating: on transformer 10582-6072 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 45
% INFO    : Updated Thermal Rating: on transformer 10582-11584 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 45
% INFO    : Updated Thermal Rating: on transformer 10582-13082 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 29
% INFO    : Updated Thermal Rating: on transformer 10582-1238 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 29
% INFO    : Updated Thermal Rating: on transformer 10582-9693 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 40
% INFO    : Updated Thermal Rating: on transformer 10582-12555 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 40
% INFO    : Updated Thermal Rating: on transformer 8876-11549 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 395
% INFO    : Updated Thermal Rating: on transformer 8165-11641 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 40
% INFO    : Updated Thermal Rating: on transformer 8165-13226 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 40
% INFO    : Updated Thermal Rating: on transformer 8165-5289 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 40
% INFO    : Updated Thermal Rating: on transformer 8165-6994 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27
% INFO    : Updated Thermal Rating: on transformer 8165-8595 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27
% INFO    : Updated Thermal Rating: on transformer 8165-621 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27
% INFO    : Updated Thermal Rating: on transformer 10549-2994 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 172
% INFO    : Updated Thermal Rating: on transformer 10549-4190 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 172
% INFO    : Updated Thermal Rating: on transformer 10549-9461 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 172
% INFO    : Updated Thermal Rating: on transformer 10441-42 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 79
% INFO    : Updated Thermal Rating: on transformer 12564-10365 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 85
% INFO    : Updated Thermal Rating: on transformer 12564-1961 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 85
% INFO    : Updated Thermal Rating: on transformer 12564-10598 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 48
% INFO    : Updated Thermal Rating: on transformer 11754-8202 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 198
% INFO    : Updated Thermal Rating: on transformer 6753-13407 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 119
% INFO    : Updated Thermal Rating: on transformer 3253-9906 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 461
% INFO    : Updated Thermal Rating: on transformer 4050-10652 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 132
% INFO    : Updated Thermal Rating: on transformer 4050-11273 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 132
% INFO    : Updated Thermal Rating: on transformer 4050-9016 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 132
% INFO    : Updated Thermal Rating: on transformer 4050-8776 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 132
% INFO    : Updated Thermal Rating: on transformer 7185-8709 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 119
% INFO    : 
% INFO    : === Line Capacity Monotonicity Notes ===
% INFO    : 
% INFO    : === Voltage Setpoint Replacement Notes ===
% INFO    : Bus 1	: V=1.031695, theta=0.0 -> V=1.0, theta=0.0
% INFO    : Bus 2	: V=1.00238, theta=-9.035194 -> V=1.0, theta=0.0
% INFO    : Bus 3	: V=0.989665, theta=-7.514519 -> V=1.0, theta=0.0
% INFO    : Bus 4	: V=1.005027, theta=12.325176 -> V=1.0, theta=0.0
% INFO    : Bus 5	: V=0.98998, theta=7.445755 -> V=1.0, theta=0.0
% INFO    : Bus 6	: V=1.004053, theta=22.504675 -> V=1.0, theta=0.0
% INFO    : Bus 7	: V=0.978685, theta=-21.610492 -> V=1.0, theta=0.0
% INFO    : Bus 8	: V=1.023941, theta=-13.3046 -> V=1.0, theta=0.0
% INFO    : Bus 9	: V=0.995208, theta=14.929241 -> V=1.0, theta=0.0
% INFO    : Bus 10	: V=0.935403, theta=-13.105656 -> V=1.0, theta=0.0
% INFO    : Bus 11	: V=1.038279, theta=3.372868 -> V=1.0, theta=0.0
% INFO    : Bus 12	: V=1.004054, theta=96.865589 -> V=1.0, theta=0.0
% INFO    : Bus 13	: V=1.046187, theta=21.142072 -> V=1.0, theta=0.0
% INFO    : Bus 14	: V=1.028056, theta=6.025887 -> V=1.0, theta=0.0
% INFO    : Bus 15	: V=0.966985, theta=-9.629605 -> V=1.0, theta=0.0
% INFO    : Bus 16	: V=1.048294, theta=-4.845447 -> V=1.0, theta=0.0
% INFO    : Bus 17	: V=1.01052, theta=-21.436889 -> V=1.0, theta=0.0
% INFO    : Bus 18	: V=1.043087, theta=11.638661 -> V=1.0, theta=0.0
% INFO    : Bus 19	: V=1.029741, theta=-21.109094 -> V=1.0, theta=0.0
% INFO    : Bus 20	: V=0.995795, theta=32.041235 -> V=1.0, theta=0.0
% INFO    : Bus 21	: V=1.024139, theta=-12.441425 -> V=1.0, theta=0.0
% INFO    : Bus 22	: V=1.012996, theta=31.441278 -> V=1.0, theta=0.0
% INFO    : Bus 23	: V=1.023227, theta=43.176177 -> V=1.0, theta=0.0
% INFO    : Bus 24	: V=0.977442, theta=-13.211902 -> V=1.0, theta=0.0
% INFO    : Bus 25	: V=1.01187, theta=32.552868 -> V=1.0, theta=0.0
% INFO    : Bus 26	: V=1.030926, theta=8.56355 -> V=1.0, theta=0.0
% INFO    : Bus 27	: V=1.032196, theta=11.548192 -> V=1.0, theta=0.0
% INFO    : Bus 28	: V=0.994911, theta=-5.413569 -> V=1.0, theta=0.0
% INFO    : Bus 29	: V=1.033319, theta=1.207015 -> V=1.0, theta=0.0
% INFO    : Bus 30	: V=1.014217, theta=-5.598531 -> V=1.0, theta=0.0
% INFO    : Bus 31	: V=1.029519, theta=36.693892 -> V=1.0, theta=0.0
% INFO    : Bus 32	: V=1.008442, theta=25.900391 -> V=1.0, theta=0.0
% INFO    : Bus 33	: V=1.018631, theta=-11.528817 -> V=1.0, theta=0.0
% INFO    : Bus 34	: V=1.050355, theta=40.500598 -> V=1.0, theta=0.0
% INFO    : Bus 35	: V=1.009463, theta=-9.554155 -> V=1.0, theta=0.0
% INFO    : Bus 36	: V=0.978505, theta=14.001978 -> V=1.0, theta=0.0
% INFO    : Bus 37	: V=1.027858, theta=-7.880552 -> V=1.0, theta=0.0
% INFO    : Bus 38	: V=0.914844, theta=-11.630868 -> V=1.0, theta=0.0
% INFO    : Bus 39	: V=1.073284, theta=1.2557 -> V=1.0, theta=0.0
% INFO    : Bus 40	: V=1.002842, theta=-15.045231 -> V=1.0, theta=0.0
% INFO    : Bus 41	: V=1.020848, theta=-10.580356 -> V=1.0, theta=0.0
% INFO    : Bus 42	: V=0.985213, theta=28.561806 -> V=1.0, theta=0.0
% INFO    : Bus 43	: V=1.021293, theta=-2.929459 -> V=1.0, theta=0.0
% INFO    : Bus 44	: V=0.990534, theta=-11.414462 -> V=1.0, theta=0.0
% INFO    : Bus 45	: V=1.012099, theta=-18.860818 -> V=1.0, theta=0.0
% INFO    : Bus 46	: V=1.039103, theta=0.763772 -> V=1.0, theta=0.0
% INFO    : Bus 47	: V=0.9757, theta=-6.904131 -> V=1.0, theta=0.0
% INFO    : Bus 48	: V=1.049416, theta=58.695823 -> V=1.0, theta=0.0
% INFO    : Bus 49	: V=0.998825, theta=-10.375539 -> V=1.0, theta=0.0
% INFO    : Bus 50	: V=0.983186, theta=-8.374635 -> V=1.0, theta=0.0
% INFO    : Bus 51	: V=1.011416, theta=44.498643 -> V=1.0, theta=0.0
% INFO    : Bus 52	: V=0.988125, theta=16.109775 -> V=1.0, theta=0.0
% INFO    : Bus 53	: V=1.016129, theta=-21.455497 -> V=1.0, theta=0.0
% INFO    : Bus 54	: V=1.021005, theta=21.987746 -> V=1.0, theta=0.0
% INFO    : Bus 55	: V=1.036171, theta=8.177694 -> V=1.0, theta=0.0
% INFO    : Bus 56	: V=1.04206, theta=-2.933811 -> V=1.0, theta=0.0
% INFO    : Bus 57	: V=0.954805, theta=-6.844584 -> V=1.0, theta=0.0
% INFO    : Bus 58	: V=0.981092, theta=-5.140628 -> V=1.0, theta=0.0
% INFO    : Bus 59	: V=1.038133, theta=-3.37057 -> V=1.0, theta=0.0
% INFO    : Bus 60	: V=1.006337, theta=-6.766633 -> V=1.0, theta=0.0
% INFO    : Bus 61	: V=1.047066, theta=36.05057 -> V=1.0, theta=0.0
% INFO    : Bus 62	: V=1.058268, theta=15.875889 -> V=1.0, theta=0.0
% INFO    : Bus 63	: V=1.058268, theta=15.875889 -> V=1.0, theta=0.0
% INFO    : Bus 64	: V=1.009945, theta=-20.345542 -> V=1.0, theta=0.0
% INFO    : Bus 65	: V=0.99193, theta=25.086276 -> V=1.0, theta=0.0
% INFO    : Bus 66	: V=1.034768, theta=8.492541 -> V=1.0, theta=0.0
% INFO    : Bus 67	: V=0.975466, theta=-6.422787 -> V=1.0, theta=0.0
% INFO    : Bus 68	: V=1.035023, theta=-10.739655 -> V=1.0, theta=0.0
% INFO    : Bus 69	: V=1.035023, theta=-10.739655 -> V=1.0, theta=0.0
% INFO    : Bus 70	: V=1.007417, theta=-5.990692 -> V=1.0, theta=0.0
% INFO    : Bus 71	: V=1.0206, theta=13.215214 -> V=1.0, theta=0.0
% INFO    : Bus 72	: V=1.0206, theta=13.215214 -> V=1.0, theta=0.0
% INFO    : Bus 73	: V=0.993601, theta=33.018065 -> V=1.0, theta=0.0
% INFO    : Bus 74	: V=1.024981, theta=18.183447 -> V=1.0, theta=0.0
% INFO    : Bus 75	: V=1.024981, theta=18.183447 -> V=1.0, theta=0.0
% INFO    : Bus 76	: V=1.024981, theta=18.183447 -> V=1.0, theta=0.0
% INFO    : Bus 77	: V=1.038344, theta=11.554722 -> V=1.0, theta=0.0
% INFO    : Bus 78	: V=1.027383, theta=17.740146 -> V=1.0, theta=0.0
% INFO    : Bus 79	: V=1.016716, theta=24.455607 -> V=1.0, theta=0.0
% INFO    : Bus 80	: V=1.009229, theta=11.978416 -> V=1.0, theta=0.0
% INFO    : Bus 81	: V=0.990476, theta=15.061407 -> V=1.0, theta=0.0
% INFO    : Bus 82	: V=1.005323, theta=7.725281 -> V=1.0, theta=0.0
% INFO    : Bus 83	: V=1.01756, theta=5.059048 -> V=1.0, theta=0.0
% INFO    : Bus 84	: V=0.989474, theta=-14.141367 -> V=1.0, theta=0.0
% INFO    : Bus 85	: V=1.024209, theta=3.944647 -> V=1.0, theta=0.0
% INFO    : Bus 86	: V=1.023881, theta=-4.354948 -> V=1.0, theta=0.0
% INFO    : Bus 87	: V=1.014629, theta=-9.004047 -> V=1.0, theta=0.0
% INFO    : Bus 88	: V=1.014629, theta=-9.004047 -> V=1.0, theta=0.0
% INFO    : Bus 89	: V=1.067567, theta=73.239254 -> V=1.0, theta=0.0
% INFO    : Bus 90	: V=0.965658, theta=-5.045088 -> V=1.0, theta=0.0
% INFO    : Bus 91	: V=1.016938, theta=32.836298 -> V=1.0, theta=0.0
% INFO    : Bus 92	: V=1.05599, theta=-0.961794 -> V=1.0, theta=0.0
% INFO    : Bus 93	: V=0.929361, theta=-10.259554 -> V=1.0, theta=0.0
% INFO    : Bus 94	: V=1.022611, theta=22.294732 -> V=1.0, theta=0.0
% INFO    : Bus 95	: V=0.989635, theta=-2.082376 -> V=1.0, theta=0.0
% INFO    : Bus 96	: V=1.043225, theta=-4.501166 -> V=1.0, theta=0.0
% INFO    : Bus 97	: V=1.043225, theta=-4.501166 -> V=1.0, theta=0.0
% INFO    : Bus 98	: V=1.043225, theta=-4.501166 -> V=1.0, theta=0.0
% INFO    : Bus 99	: V=1.031885, theta=-12.651409 -> V=1.0, theta=0.0
% INFO    : Bus 100	: V=1.031885, theta=-12.651409 -> V=1.0, theta=0.0
% INFO    : Bus 101	: V=1.043225, theta=-4.501166 -> V=1.0, theta=0.0
% INFO    : Bus 102	: V=1.043225, theta=-4.501166 -> V=1.0, theta=0.0
% INFO    : Bus 103	: V=0.989544, theta=23.826254 -> V=1.0, theta=0.0
% INFO    : Bus 104	: V=1.052257, theta=44.731305 -> V=1.0, theta=0.0
% INFO    : Bus 105	: V=1.141691, theta=0.929631 -> V=1.0, theta=0.0
% INFO    : Bus 106	: V=1.033923, theta=30.21213 -> V=1.0, theta=0.0
% INFO    : Bus 107	: V=1.028153, theta=78.700831 -> V=1.0, theta=0.0
% INFO    : Bus 108	: V=1.02024, theta=-13.484638 -> V=1.0, theta=0.0
% INFO    : Bus 109	: V=0.99755, theta=-13.611914 -> V=1.0, theta=0.0
% INFO    : Bus 110	: V=1.051233, theta=87.799236 -> V=1.0, theta=0.0
% INFO    : Bus 111	: V=1.040632, theta=-1.700832 -> V=1.0, theta=0.0
% INFO    : Bus 112	: V=1.014811, theta=-25.695432 -> V=1.0, theta=0.0
% INFO    : Bus 113	: V=1.049481, theta=58.705166 -> V=1.0, theta=0.0
% INFO    : Bus 114	: V=1.030832, theta=-9.752509 -> V=1.0, theta=0.0
% INFO    : Bus 115	: V=1.019, theta=-2.975058 -> V=1.0, theta=0.0
% INFO    : Bus 116	: V=1.01569, theta=-23.117496 -> V=1.0, theta=0.0
% INFO    : Bus 117	: V=0.98256, theta=1.655497 -> V=1.0, theta=0.0
% INFO    : Bus 118	: V=1.005586, theta=39.420522 -> V=1.0, theta=0.0
% INFO    : Bus 119	: V=1.047225, theta=-3.097806 -> V=1.0, theta=0.0
% INFO    : Bus 120	: V=0.992206, theta=88.681174 -> V=1.0, theta=0.0
% INFO    : Bus 121	: V=1.045359, theta=10.101302 -> V=1.0, theta=0.0
% INFO    : Bus 122	: V=0.989992, theta=37.681252 -> V=1.0, theta=0.0
% INFO    : Bus 123	: V=1.015598, theta=45.599895 -> V=1.0, theta=0.0
% INFO    : Bus 124	: V=1.046082, theta=-0.185974 -> V=1.0, theta=0.0
% INFO    : Bus 125	: V=0.979547, theta=43.485266 -> V=1.0, theta=0.0
% INFO    : Bus 126	: V=1.054143, theta=-2.947678 -> V=1.0, theta=0.0
% INFO    : Bus 127	: V=1.015831, theta=7.375377 -> V=1.0, theta=0.0
% INFO    : Bus 128	: V=0.992515, theta=-4.018187 -> V=1.0, theta=0.0
% INFO    : Bus 129	: V=0.992133, theta=32.281513 -> V=1.0, theta=0.0
% INFO    : Bus 130	: V=1.032584, theta=1.551181 -> V=1.0, theta=0.0
% INFO    : Bus 131	: V=1.01593, theta=31.223648 -> V=1.0, theta=0.0
% INFO    : Bus 132	: V=0.996117, theta=32.042491 -> V=1.0, theta=0.0
% INFO    : Bus 133	: V=1.042317, theta=14.274354 -> V=1.0, theta=0.0
% INFO    : Bus 134	: V=1.044129, theta=-4.738961 -> V=1.0, theta=0.0
% INFO    : Bus 135	: V=1.030832, theta=-9.752509 -> V=1.0, theta=0.0
% INFO    : Bus 136	: V=1.049674, theta=87.363329 -> V=1.0, theta=0.0
% INFO    : Bus 137	: V=1.033716, theta=0.043737 -> V=1.0, theta=0.0
% INFO    : Bus 138	: V=0.998323, theta=-1.616561 -> V=1.0, theta=0.0
% INFO    : Bus 139	: V=0.982498, theta=-8.529449 -> V=1.0, theta=0.0
% INFO    : Bus 140	: V=1.007093, theta=11.733465 -> V=1.0, theta=0.0
% INFO    : Bus 141	: V=1.086033, theta=24.723865 -> V=1.0, theta=0.0
% INFO    : Bus 142	: V=1.010147, theta=0.04267 -> V=1.0, theta=0.0
% INFO    : Bus 143	: V=1.041468, theta=-6.86067 -> V=1.0, theta=0.0
% INFO    : Bus 144	: V=1.034631, theta=4.683321 -> V=1.0, theta=0.0
% INFO    : Bus 145	: V=1.040587, theta=38.218788 -> V=1.0, theta=0.0
% INFO    : Bus 146	: V=1.044313, theta=37.077846 -> V=1.0, theta=0.0
% INFO    : Bus 147	: V=1.044313, theta=37.077846 -> V=1.0, theta=0.0
% INFO    : Bus 148	: V=1.01726, theta=31.78152 -> V=1.0, theta=0.0
% INFO    : Bus 149	: V=0.998552, theta=-23.031405 -> V=1.0, theta=0.0
% INFO    : Bus 150	: V=1.035657, theta=-6.436529 -> V=1.0, theta=0.0
% INFO    : Bus 151	: V=1.023215, theta=19.248221 -> V=1.0, theta=0.0
% INFO    : Bus 152	: V=0.957631, theta=-29.999659 -> V=1.0, theta=0.0
% INFO    : Bus 153	: V=1.027348, theta=16.396901 -> V=1.0, theta=0.0
% INFO    : Bus 154	: V=1.05252, theta=75.282812 -> V=1.0, theta=0.0
% INFO    : Bus 155	: V=1.018112, theta=-4.652605 -> V=1.0, theta=0.0
% INFO    : Bus 156	: V=1.034597, theta=19.022639 -> V=1.0, theta=0.0
% INFO    : Bus 157	: V=0.997201, theta=-11.924333 -> V=1.0, theta=0.0
% INFO    : Bus 158	: V=1.030319, theta=13.564017 -> V=1.0, theta=0.0
% INFO    : Bus 159	: V=1.003488, theta=6.243881 -> V=1.0, theta=0.0
% INFO    : Bus 160	: V=1.005167, theta=12.788654 -> V=1.0, theta=0.0
% INFO    : Bus 161	: V=1.034597, theta=19.022639 -> V=1.0, theta=0.0
% INFO    : Bus 162	: V=1.034597, theta=19.022639 -> V=1.0, theta=0.0
% INFO    : Bus 163	: V=0.998875, theta=-9.905754 -> V=1.0, theta=0.0
% INFO    : Bus 164	: V=1.048414, theta=5.258031 -> V=1.0, theta=0.0
% INFO    : Bus 165	: V=1.030832, theta=-9.752509 -> V=1.0, theta=0.0
% INFO    : Bus 166	: V=1.069303, theta=18.198045 -> V=1.0, theta=0.0
% INFO    : Bus 167	: V=1.025278, theta=15.598401 -> V=1.0, theta=0.0
% INFO    : Bus 168	: V=0.982808, theta=36.169129 -> V=1.0, theta=0.0
% INFO    : Bus 169	: V=1.043196, theta=10.569078 -> V=1.0, theta=0.0
% INFO    : Bus 170	: V=0.963316, theta=-5.114898 -> V=1.0, theta=0.0
% INFO    : Bus 171	: V=1.004078, theta=-8.960914 -> V=1.0, theta=0.0
% INFO    : Bus 172	: V=0.954773, theta=-7.079414 -> V=1.0, theta=0.0
% INFO    : Bus 173	: V=1.071275, theta=1.379824 -> V=1.0, theta=0.0
% INFO    : Bus 174	: V=0.982878, theta=-10.227511 -> V=1.0, theta=0.0
% INFO    : Bus 175	: V=1.055172, theta=-2.479395 -> V=1.0, theta=0.0
% INFO    : Bus 176	: V=0.995048, theta=32.610865 -> V=1.0, theta=0.0
% INFO    : Bus 177	: V=1.045733, theta=7.66394 -> V=1.0, theta=0.0
% INFO    : Bus 178	: V=1.066307, theta=38.390318 -> V=1.0, theta=0.0
% INFO    : Bus 179	: V=1.023144, theta=-9.538309 -> V=1.0, theta=0.0
% INFO    : Bus 180	: V=0.938533, theta=-9.006406 -> V=1.0, theta=0.0
% INFO    : Bus 181	: V=1.020557, theta=9.624602 -> V=1.0, theta=0.0
% INFO    : Bus 182	: V=1.054937, theta=4.624127 -> V=1.0, theta=0.0
% INFO    : Bus 183	: V=1.005985, theta=0.980119 -> V=1.0, theta=0.0
% INFO    : Bus 184	: V=1.018182, theta=14.939378 -> V=1.0, theta=0.0
% INFO    : Bus 185	: V=1.01375, theta=15.934135 -> V=1.0, theta=0.0
% INFO    : Bus 186	: V=1.043206, theta=-19.578893 -> V=1.0, theta=0.0
% INFO    : Bus 187	: V=1.0253, theta=-13.383559 -> V=1.0, theta=0.0
% INFO    : Bus 188	: V=1.021419, theta=-22.29244 -> V=1.0, theta=0.0
% INFO    : Bus 189	: V=1.043162, theta=-16.102529 -> V=1.0, theta=0.0
% INFO    : Bus 190	: V=1.000545, theta=26.619584 -> V=1.0, theta=0.0
% INFO    : Bus 191	: V=0.973826, theta=31.884786 -> V=1.0, theta=0.0
% INFO    : Bus 192	: V=1.007461, theta=6.385629 -> V=1.0, theta=0.0
% INFO    : Bus 193	: V=0.982641, theta=-11.113148 -> V=1.0, theta=0.0
% INFO    : Bus 194	: V=0.983941, theta=88.980027 -> V=1.0, theta=0.0
% INFO    : Bus 195	: V=1.058902, theta=-14.107366 -> V=1.0, theta=0.0
% INFO    : Bus 196	: V=1.021915, theta=-9.376379 -> V=1.0, theta=0.0
% INFO    : Bus 197	: V=1.005341, theta=-1.941399 -> V=1.0, theta=0.0
% INFO    : Bus 198	: V=1.002832, theta=0.458665 -> V=1.0, theta=0.0
% INFO    : Bus 199	: V=1.012917, theta=48.51202 -> V=1.0, theta=0.0
% INFO    : Bus 200	: V=0.982261, theta=24.304858 -> V=1.0, theta=0.0
% INFO    : Bus 201	: V=1.029747, theta=-0.920263 -> V=1.0, theta=0.0
% INFO    : Bus 202	: V=1.024001, theta=31.504337 -> V=1.0, theta=0.0
% INFO    : Bus 203	: V=1.026171, theta=18.685276 -> V=1.0, theta=0.0
% INFO    : Bus 204	: V=1.059773, theta=46.330163 -> V=1.0, theta=0.0
% INFO    : Bus 205	: V=1.032579, theta=-12.222514 -> V=1.0, theta=0.0
% INFO    : Bus 206	: V=1.028327, theta=20.28167 -> V=1.0, theta=0.0
% INFO    : Bus 207	: V=1.016461, theta=26.125945 -> V=1.0, theta=0.0
% INFO    : Bus 208	: V=1.094867, theta=0.194636 -> V=1.0, theta=0.0
% INFO    : Bus 209	: V=1.045186, theta=43.271639 -> V=1.0, theta=0.0
% INFO    : Bus 210	: V=1.041193, theta=12.289677 -> V=1.0, theta=0.0
% INFO    : Bus 211	: V=1.029639, theta=21.583329 -> V=1.0, theta=0.0
% INFO    : Bus 212	: V=1.006064, theta=-11.74724 -> V=1.0, theta=0.0
% INFO    : Bus 213	: V=1.047813, theta=32.292346 -> V=1.0, theta=0.0
% INFO    : Bus 214	: V=1.028798, theta=0.187665 -> V=1.0, theta=0.0
% INFO    : Bus 215	: V=0.965812, theta=24.322013 -> V=1.0, theta=0.0
% INFO    : Bus 216	: V=1.037755, theta=-15.333664 -> V=1.0, theta=0.0
% INFO    : Bus 217	: V=1.000388, theta=0.372092 -> V=1.0, theta=0.0
% INFO    : Bus 218	: V=0.994997, theta=-14.242668 -> V=1.0, theta=0.0
% INFO    : Bus 219	: V=0.994318, theta=-4.863546 -> V=1.0, theta=0.0
% INFO    : Bus 220	: V=1.055654, theta=39.981354 -> V=1.0, theta=0.0
% INFO    : Bus 221	: V=1.055654, theta=39.981354 -> V=1.0, theta=0.0
% INFO    : Bus 222	: V=1.051105, theta=39.960989 -> V=1.0, theta=0.0
% INFO    : Bus 223	: V=1.055654, theta=39.981354 -> V=1.0, theta=0.0
% INFO    : Bus 224	: V=1.051105, theta=39.960989 -> V=1.0, theta=0.0
% INFO    : Bus 225	: V=1.051105, theta=39.960989 -> V=1.0, theta=0.0
% INFO    : Bus 226	: V=1.009411, theta=7.858173 -> V=1.0, theta=0.0
% INFO    : Bus 227	: V=0.992431, theta=20.155304 -> V=1.0, theta=0.0
% INFO    : Bus 228	: V=1.006088, theta=31.382093 -> V=1.0, theta=0.0
% INFO    : Bus 229	: V=1.034441, theta=34.869174 -> V=1.0, theta=0.0
% INFO    : Bus 230	: V=1.029856, theta=-6.864459 -> V=1.0, theta=0.0
% INFO    : Bus 231	: V=1.010683, theta=26.224607 -> V=1.0, theta=0.0
% INFO    : Bus 232	: V=1.097619, theta=-4.744858 -> V=1.0, theta=0.0
% INFO    : Bus 233	: V=1.041056, theta=18.76151 -> V=1.0, theta=0.0
% INFO    : Bus 234	: V=1.038236, theta=23.896352 -> V=1.0, theta=0.0
% INFO    : Bus 235	: V=1.0473, theta=19.001366 -> V=1.0, theta=0.0
% INFO    : Bus 236	: V=1.021324, theta=26.421146 -> V=1.0, theta=0.0
% INFO    : Bus 237	: V=1.080332, theta=-2.610374 -> V=1.0, theta=0.0
% INFO    : Bus 238	: V=1.031593, theta=36.052809 -> V=1.0, theta=0.0
% INFO    : Bus 239	: V=1.029114, theta=25.227158 -> V=1.0, theta=0.0
% INFO    : Bus 240	: V=0.994895, theta=38.566247 -> V=1.0, theta=0.0
% INFO    : Bus 241	: V=1.037622, theta=28.736858 -> V=1.0, theta=0.0
% INFO    : Bus 242	: V=1.05291, theta=-6.33502 -> V=1.0, theta=0.0
% INFO    : Bus 243	: V=1.053647, theta=50.613884 -> V=1.0, theta=0.0
% INFO    : Bus 244	: V=1.083523, theta=3.965034 -> V=1.0, theta=0.0
% INFO    : Bus 245	: V=1.005919, theta=-19.363692 -> V=1.0, theta=0.0
% INFO    : Bus 246	: V=1.03892, theta=41.627356 -> V=1.0, theta=0.0
% INFO    : Bus 247	: V=1.041176, theta=1.637578 -> V=1.0, theta=0.0
% INFO    : Bus 248	: V=1.026279, theta=27.085932 -> V=1.0, theta=0.0
% INFO    : Bus 249	: V=1.056058, theta=3.848789 -> V=1.0, theta=0.0
% INFO    : Bus 250	: V=1.012099, theta=-18.860818 -> V=1.0, theta=0.0
% INFO    : Bus 251	: V=0.984854, theta=-15.499059 -> V=1.0, theta=0.0
% INFO    : Bus 252	: V=1.049653, theta=-5.686791 -> V=1.0, theta=0.0
% INFO    : Bus 253	: V=1.015243, theta=-27.279483 -> V=1.0, theta=0.0
% INFO    : Bus 254	: V=0.962719, theta=-15.482689 -> V=1.0, theta=0.0
% INFO    : Bus 255	: V=1.017585, theta=-8.578565 -> V=1.0, theta=0.0
% INFO    : Bus 256	: V=1.085688, theta=7.234194 -> V=1.0, theta=0.0
% INFO    : Bus 257	: V=1.018032, theta=-22.27659 -> V=1.0, theta=0.0
% INFO    : Bus 258	: V=0.955439, theta=48.700819 -> V=1.0, theta=0.0
% INFO    : Bus 259	: V=1.03425, theta=8.859346 -> V=1.0, theta=0.0
% INFO    : Bus 260	: V=1.034249, theta=65.998285 -> V=1.0, theta=0.0
% INFO    : Bus 261	: V=1.024115, theta=3.443986 -> V=1.0, theta=0.0
% INFO    : Bus 262	: V=1.035138, theta=19.25936 -> V=1.0, theta=0.0
% INFO    : Bus 263	: V=1.007769, theta=17.657973 -> V=1.0, theta=0.0
% INFO    : Bus 264	: V=0.98382, theta=-7.354011 -> V=1.0, theta=0.0
% INFO    : Bus 265	: V=0.978872, theta=-12.878729 -> V=1.0, theta=0.0
% INFO    : Bus 266	: V=1.005915, theta=0.12691 -> V=1.0, theta=0.0
% INFO    : Bus 267	: V=1.05264, theta=10.6209 -> V=1.0, theta=0.0
% INFO    : Bus 268	: V=0.992499, theta=-4.854035 -> V=1.0, theta=0.0
% INFO    : Bus 269	: V=0.994437, theta=-0.345088 -> V=1.0, theta=0.0
% INFO    : Bus 270	: V=1.003342, theta=23.89027 -> V=1.0, theta=0.0
% INFO    : Bus 271	: V=1.053159, theta=33.930403 -> V=1.0, theta=0.0
% INFO    : Bus 272	: V=1.050896, theta=93.317943 -> V=1.0, theta=0.0
% INFO    : Bus 273	: V=1.051456, theta=33.495027 -> V=1.0, theta=0.0
% INFO    : Bus 274	: V=1.051088, theta=33.437371 -> V=1.0, theta=0.0
% INFO    : Bus 275	: V=1.051088, theta=33.437371 -> V=1.0, theta=0.0
% INFO    : Bus 276	: V=1.050379, theta=33.293543 -> V=1.0, theta=0.0
% INFO    : Bus 277	: V=1.021851, theta=51.649183 -> V=1.0, theta=0.0
% INFO    : Bus 278	: V=0.960771, theta=44.51306 -> V=1.0, theta=0.0
% INFO    : Bus 279	: V=1.03301, theta=39.005968 -> V=1.0, theta=0.0
% INFO    : Bus 280	: V=1.024903, theta=-19.493228 -> V=1.0, theta=0.0
% INFO    : Bus 281	: V=1.027446, theta=20.01219 -> V=1.0, theta=0.0
% INFO    : Bus 282	: V=1.024187, theta=3.450586 -> V=1.0, theta=0.0
% INFO    : Bus 283	: V=1.000621, theta=19.05802 -> V=1.0, theta=0.0
% INFO    : Bus 284	: V=1.093767, theta=71.95923 -> V=1.0, theta=0.0
% INFO    : Bus 285	: V=1.015091, theta=14.638222 -> V=1.0, theta=0.0
% INFO    : Bus 286	: V=1.032642, theta=-19.048559 -> V=1.0, theta=0.0
% INFO    : Bus 287	: V=0.988052, theta=25.416707 -> V=1.0, theta=0.0
% INFO    : Bus 288	: V=1.007117, theta=-15.468653 -> V=1.0, theta=0.0
% INFO    : Bus 289	: V=1.040289, theta=49.685314 -> V=1.0, theta=0.0
% INFO    : Bus 290	: V=1.017529, theta=-23.903561 -> V=1.0, theta=0.0
% INFO    : Bus 291	: V=1.010616, theta=26.29288 -> V=1.0, theta=0.0
% INFO    : Bus 292	: V=0.996347, theta=39.809508 -> V=1.0, theta=0.0
% INFO    : Bus 293	: V=1.050988, theta=-0.863124 -> V=1.0, theta=0.0
% INFO    : Bus 294	: V=0.999187, theta=25.525754 -> V=1.0, theta=0.0
% INFO    : Bus 295	: V=1.020708, theta=32.06907 -> V=1.0, theta=0.0
% INFO    : Bus 296	: V=0.989117, theta=33.465932 -> V=1.0, theta=0.0
% INFO    : Bus 297	: V=1.029403, theta=-20.962021 -> V=1.0, theta=0.0
% INFO    : Bus 298	: V=1.038932, theta=0.095836 -> V=1.0, theta=0.0
% INFO    : Bus 299	: V=0.993468, theta=44.441311 -> V=1.0, theta=0.0
% INFO    : Bus 300	: V=1.018049, theta=17.631655 -> V=1.0, theta=0.0
% INFO    : Bus 301	: V=1.0319, theta=6.852205 -> V=1.0, theta=0.0
% INFO    : Bus 302	: V=1.012136, theta=-3.292816 -> V=1.0, theta=0.0
% INFO    : Bus 303	: V=0.995957, theta=-11.169142 -> V=1.0, theta=0.0
% INFO    : Bus 304	: V=1.037997, theta=-15.804853 -> V=1.0, theta=0.0
% INFO    : Bus 305	: V=1.030407, theta=32.510933 -> V=1.0, theta=0.0
% INFO    : Bus 306	: V=1.030407, theta=32.510933 -> V=1.0, theta=0.0
% INFO    : Bus 307	: V=1.049321, theta=25.075911 -> V=1.0, theta=0.0
% INFO    : Bus 308	: V=1.049321, theta=25.075911 -> V=1.0, theta=0.0
% INFO    : Bus 309	: V=1.05655, theta=34.123914 -> V=1.0, theta=0.0
% INFO    : Bus 310	: V=1.05655, theta=34.123914 -> V=1.0, theta=0.0
% INFO    : Bus 311	: V=1.05655, theta=34.123914 -> V=1.0, theta=0.0
% INFO    : Bus 312	: V=1.05655, theta=34.123914 -> V=1.0, theta=0.0
% INFO    : Bus 313	: V=1.08829, theta=70.695055 -> V=1.0, theta=0.0
% INFO    : Bus 314	: V=1.016819, theta=21.364532 -> V=1.0, theta=0.0
% INFO    : Bus 315	: V=1.021202, theta=7.512556 -> V=1.0, theta=0.0
% INFO    : Bus 316	: V=0.980529, theta=-11.005188 -> V=1.0, theta=0.0
% INFO    : Bus 317	: V=1.050755, theta=40.337803 -> V=1.0, theta=0.0
% INFO    : Bus 318	: V=1.053731, theta=-3.038033 -> V=1.0, theta=0.0
% INFO    : Bus 319	: V=1.025917, theta=5.589988 -> V=1.0, theta=0.0
% INFO    : Bus 320	: V=1.051242, theta=28.233863 -> V=1.0, theta=0.0
% INFO    : Bus 321	: V=1.028278, theta=16.095823 -> V=1.0, theta=0.0
% INFO    : Bus 322	: V=1.052181, theta=12.761421 -> V=1.0, theta=0.0
% INFO    : Bus 323	: V=1.016993, theta=30.047857 -> V=1.0, theta=0.0
% INFO    : Bus 324	: V=1.024179, theta=7.053021 -> V=1.0, theta=0.0
% INFO    : Bus 325	: V=0.996355, theta=28.771079 -> V=1.0, theta=0.0
% INFO    : Bus 326	: V=1.009826, theta=7.243886 -> V=1.0, theta=0.0
% INFO    : Bus 327	: V=1.021452, theta=91.885907 -> V=1.0, theta=0.0
% INFO    : Bus 328	: V=1.023168, theta=23.385838 -> V=1.0, theta=0.0
% INFO    : Bus 329	: V=1.016848, theta=2.25686 -> V=1.0, theta=0.0
% INFO    : Bus 330	: V=0.982988, theta=1.603555 -> V=1.0, theta=0.0
% INFO    : Bus 331	: V=1.006233, theta=16.146442 -> V=1.0, theta=0.0
% INFO    : Bus 332	: V=0.996766, theta=22.457835 -> V=1.0, theta=0.0
% INFO    : Bus 333	: V=1.040075, theta=10.160115 -> V=1.0, theta=0.0
% INFO    : Bus 334	: V=1.017664, theta=-15.016249 -> V=1.0, theta=0.0
% INFO    : Bus 335	: V=0.996984, theta=-8.982181 -> V=1.0, theta=0.0
% INFO    : Bus 336	: V=1.010862, theta=-10.418134 -> V=1.0, theta=0.0
% INFO    : Bus 337	: V=1.017664, theta=-15.016249 -> V=1.0, theta=0.0
% INFO    : Bus 338	: V=1.00038, theta=-5.809998 -> V=1.0, theta=0.0
% INFO    : Bus 339	: V=1.008279, theta=-10.478046 -> V=1.0, theta=0.0
% INFO    : Bus 340	: V=1.018948, theta=-16.326346 -> V=1.0, theta=0.0
% INFO    : Bus 341	: V=1.020054, theta=5.015345 -> V=1.0, theta=0.0
% INFO    : Bus 342	: V=1.059806, theta=27.195352 -> V=1.0, theta=0.0
% INFO    : Bus 343	: V=1.026432, theta=2.663199 -> V=1.0, theta=0.0
% INFO    : Bus 344	: V=0.99088, theta=-19.172603 -> V=1.0, theta=0.0
% INFO    : Bus 345	: V=1.030395, theta=-6.336516 -> V=1.0, theta=0.0
% INFO    : Bus 346	: V=1.030395, theta=-6.336516 -> V=1.0, theta=0.0
% INFO    : Bus 347	: V=1.016788, theta=-2.028229 -> V=1.0, theta=0.0
% INFO    : Bus 348	: V=0.951099, theta=-5.317252 -> V=1.0, theta=0.0
% INFO    : Bus 349	: V=1.02049, theta=11.872201 -> V=1.0, theta=0.0
% INFO    : Bus 350	: V=0.968384, theta=-15.748675 -> V=1.0, theta=0.0
% INFO    : Bus 351	: V=1.024484, theta=-6.060208 -> V=1.0, theta=0.0
% INFO    : Bus 352	: V=1.013376, theta=-26.727823 -> V=1.0, theta=0.0
% INFO    : Bus 353	: V=1.021444, theta=63.427508 -> V=1.0, theta=0.0
% INFO    : Bus 354	: V=1.029166, theta=13.522836 -> V=1.0, theta=0.0
% INFO    : Bus 355	: V=1.044995, theta=-0.245344 -> V=1.0, theta=0.0
% INFO    : Bus 356	: V=1.028324, theta=-8.261232 -> V=1.0, theta=0.0
% INFO    : Bus 357	: V=1.048037, theta=86.241564 -> V=1.0, theta=0.0
% INFO    : Bus 358	: V=1.050725, theta=42.166745 -> V=1.0, theta=0.0
% INFO    : Bus 359	: V=1.051074, theta=31.370584 -> V=1.0, theta=0.0
% INFO    : Bus 360	: V=1.028641, theta=-17.676734 -> V=1.0, theta=0.0
% INFO    : Bus 361	: V=1.028641, theta=-17.676734 -> V=1.0, theta=0.0
% INFO    : Bus 362	: V=1.028641, theta=-17.676734 -> V=1.0, theta=0.0
% INFO    : Bus 363	: V=1.028641, theta=-17.676734 -> V=1.0, theta=0.0
% INFO    : Bus 364	: V=1.00564, theta=-10.626942 -> V=1.0, theta=0.0
% INFO    : Bus 365	: V=0.997585, theta=4.636327 -> V=1.0, theta=0.0
% INFO    : Bus 366	: V=1.064626, theta=24.975015 -> V=1.0, theta=0.0
% INFO    : Bus 367	: V=1.021538, theta=43.092184 -> V=1.0, theta=0.0
% INFO    : Bus 368	: V=1.028641, theta=-17.676734 -> V=1.0, theta=0.0
% INFO    : Bus 369	: V=1.028641, theta=-17.676734 -> V=1.0, theta=0.0
% INFO    : Bus 370	: V=1.003889, theta=29.490383 -> V=1.0, theta=0.0
% INFO    : Bus 371	: V=0.977321, theta=-8.562505 -> V=1.0, theta=0.0
% INFO    : Bus 372	: V=1.044634, theta=1.324756 -> V=1.0, theta=0.0
% INFO    : Bus 373	: V=0.98721, theta=-1.170875 -> V=1.0, theta=0.0
% INFO    : Bus 374	: V=1.026096, theta=38.079369 -> V=1.0, theta=0.0
% INFO    : Bus 375	: V=1.002164, theta=-15.041903 -> V=1.0, theta=0.0
% INFO    : Bus 376	: V=1.031976, theta=45.925047 -> V=1.0, theta=0.0
% INFO    : Bus 377	: V=0.993504, theta=-13.39494 -> V=1.0, theta=0.0
% INFO    : Bus 378	: V=0.993504, theta=-13.39494 -> V=1.0, theta=0.0
% INFO    : Bus 379	: V=1.044274, theta=36.097767 -> V=1.0, theta=0.0
% INFO    : Bus 380	: V=0.987495, theta=35.201778 -> V=1.0, theta=0.0
% INFO    : Bus 381	: V=0.989227, theta=-9.859665 -> V=1.0, theta=0.0
% INFO    : Bus 382	: V=0.990596, theta=-4.984835 -> V=1.0, theta=0.0
% INFO    : Bus 383	: V=1.012482, theta=-8.65265 -> V=1.0, theta=0.0
% INFO    : Bus 384	: V=0.989227, theta=-9.859665 -> V=1.0, theta=0.0
% INFO    : Bus 385	: V=1.039191, theta=75.245398 -> V=1.0, theta=0.0
% INFO    : Bus 386	: V=1.036947, theta=7.315715 -> V=1.0, theta=0.0
% INFO    : Bus 387	: V=1.056459, theta=-2.614124 -> V=1.0, theta=0.0
% INFO    : Bus 388	: V=1.061652, theta=11.069394 -> V=1.0, theta=0.0
% INFO    : Bus 389	: V=1.024692, theta=-4.329904 -> V=1.0, theta=0.0
% INFO    : Bus 390	: V=1.011342, theta=-18.466433 -> V=1.0, theta=0.0
% INFO    : Bus 391	: V=1.024048, theta=-0.786284 -> V=1.0, theta=0.0
% INFO    : Bus 392	: V=1.030636, theta=1.593662 -> V=1.0, theta=0.0
% INFO    : Bus 393	: V=1.022918, theta=-10.902946 -> V=1.0, theta=0.0
% INFO    : Bus 394	: V=1.0326, theta=4.106738 -> V=1.0, theta=0.0
% INFO    : Bus 395	: V=1.028283, theta=16.586422 -> V=1.0, theta=0.0
% INFO    : Bus 396	: V=1.029542, theta=-3.096329 -> V=1.0, theta=0.0
% INFO    : Bus 397	: V=1.043272, theta=-18.000155 -> V=1.0, theta=0.0
% INFO    : Bus 398	: V=1.064278, theta=4.191179 -> V=1.0, theta=0.0
% INFO    : Bus 399	: V=1.013719, theta=35.800215 -> V=1.0, theta=0.0
% INFO    : Bus 400	: V=0.979015, theta=43.42213 -> V=1.0, theta=0.0
% INFO    : Bus 401	: V=1.015344, theta=-26.64921 -> V=1.0, theta=0.0
% INFO    : Bus 402	: V=1.00423, theta=25.494521 -> V=1.0, theta=0.0
% INFO    : Bus 403	: V=1.020174, theta=-19.057619 -> V=1.0, theta=0.0
% INFO    : Bus 404	: V=1.034858, theta=-0.227793 -> V=1.0, theta=0.0
% INFO    : Bus 405	: V=1.00773, theta=-6.62746 -> V=1.0, theta=0.0
% INFO    : Bus 406	: V=1.00773, theta=-6.62746 -> V=1.0, theta=0.0
% INFO    : Bus 407	: V=1.011745, theta=-24.157084 -> V=1.0, theta=0.0
% INFO    : Bus 408	: V=1.043492, theta=-15.322718 -> V=1.0, theta=0.0
% INFO    : Bus 409	: V=1.071256, theta=58.769025 -> V=1.0, theta=0.0
% INFO    : Bus 410	: V=0.999874, theta=-13.902635 -> V=1.0, theta=0.0
% INFO    : Bus 411	: V=1.042875, theta=93.821172 -> V=1.0, theta=0.0
% INFO    : Bus 412	: V=1.045353, theta=27.754007 -> V=1.0, theta=0.0
% INFO    : Bus 413	: V=1.067563, theta=-10.167624 -> V=1.0, theta=0.0
% INFO    : Bus 414	: V=1.040225, theta=-4.06361 -> V=1.0, theta=0.0
% INFO    : Bus 415	: V=0.988701, theta=-12.066079 -> V=1.0, theta=0.0
% INFO    : Bus 416	: V=0.995801, theta=-3.096316 -> V=1.0, theta=0.0
% INFO    : Bus 417	: V=0.994428, theta=26.055624 -> V=1.0, theta=0.0
% INFO    : Bus 418	: V=1.049988, theta=90.865555 -> V=1.0, theta=0.0
% INFO    : Bus 419	: V=1.020452, theta=-7.005782 -> V=1.0, theta=0.0
% INFO    : Bus 420	: V=1.004358, theta=-4.040243 -> V=1.0, theta=0.0
% INFO    : Bus 421	: V=1.030113, theta=-1.594177 -> V=1.0, theta=0.0
% INFO    : Bus 422	: V=1.035806, theta=18.542315 -> V=1.0, theta=0.0
% INFO    : Bus 423	: V=1.015919, theta=3.580325 -> V=1.0, theta=0.0
% INFO    : Bus 424	: V=1.034615, theta=39.288516 -> V=1.0, theta=0.0
% INFO    : Bus 425	: V=1.079277, theta=10.025709 -> V=1.0, theta=0.0
% INFO    : Bus 426	: V=1.026746, theta=18.911778 -> V=1.0, theta=0.0
% INFO    : Bus 427	: V=1.029484, theta=-21.160424 -> V=1.0, theta=0.0
% INFO    : Bus 428	: V=1.026931, theta=93.803559 -> V=1.0, theta=0.0
% INFO    : Bus 429	: V=0.998912, theta=29.803254 -> V=1.0, theta=0.0
% INFO    : Bus 430	: V=1.060659, theta=10.322664 -> V=1.0, theta=0.0
% INFO    : Bus 431	: V=1.069341, theta=1.460666 -> V=1.0, theta=0.0
% INFO    : Bus 432	: V=1.016602, theta=20.114087 -> V=1.0, theta=0.0
% INFO    : Bus 433	: V=1.011489, theta=10.204543 -> V=1.0, theta=0.0
% INFO    : Bus 434	: V=1.036946, theta=-2.421418 -> V=1.0, theta=0.0
% INFO    : Bus 435	: V=1.031463, theta=4.496802 -> V=1.0, theta=0.0
% INFO    : Bus 436	: V=1.023478, theta=31.01211 -> V=1.0, theta=0.0
% INFO    : Bus 437	: V=1.023529, theta=3.172519 -> V=1.0, theta=0.0
% INFO    : Bus 438	: V=1.016716, theta=24.455607 -> V=1.0, theta=0.0
% INFO    : Bus 439	: V=1.017888, theta=79.240726 -> V=1.0, theta=0.0
% INFO    : Bus 440	: V=1.076677, theta=0.280361 -> V=1.0, theta=0.0
% INFO    : Bus 441	: V=1.024987, theta=12.673591 -> V=1.0, theta=0.0
% INFO    : Bus 442	: V=1.043357, theta=16.76639 -> V=1.0, theta=0.0
% INFO    : Bus 443	: V=1.003413, theta=0.732744 -> V=1.0, theta=0.0
% INFO    : Bus 444	: V=0.996316, theta=47.58349 -> V=1.0, theta=0.0
% INFO    : Bus 445	: V=1.034044, theta=31.640506 -> V=1.0, theta=0.0
% INFO    : Bus 446	: V=1.017123, theta=-4.668405 -> V=1.0, theta=0.0
% INFO    : Bus 447	: V=1.0206, theta=13.215214 -> V=1.0, theta=0.0
% INFO    : Bus 448	: V=1.038795, theta=17.135422 -> V=1.0, theta=0.0
% INFO    : Bus 449	: V=1.02775, theta=-18.795505 -> V=1.0, theta=0.0
% INFO    : Bus 450	: V=1.021068, theta=-0.6916 -> V=1.0, theta=0.0
% INFO    : Bus 451	: V=1.002719, theta=-1.665851 -> V=1.0, theta=0.0
% INFO    : Bus 452	: V=1.013021, theta=33.465429 -> V=1.0, theta=0.0
% INFO    : Bus 453	: V=0.984948, theta=-4.258651 -> V=1.0, theta=0.0
% INFO    : Bus 454	: V=0.973833, theta=16.627296 -> V=1.0, theta=0.0
% INFO    : Bus 455	: V=0.988031, theta=-12.652652 -> V=1.0, theta=0.0
% INFO    : Bus 456	: V=1.046057, theta=-14.752144 -> V=1.0, theta=0.0
% INFO    : Bus 457	: V=1.029934, theta=-3.834541 -> V=1.0, theta=0.0
% INFO    : Bus 458	: V=1.009892, theta=4.868208 -> V=1.0, theta=0.0
% INFO    : Bus 459	: V=1.029914, theta=11.923984 -> V=1.0, theta=0.0
% INFO    : Bus 460	: V=1.078154, theta=0.918362 -> V=1.0, theta=0.0
% INFO    : Bus 461	: V=0.868495, theta=-15.380873 -> V=1.0, theta=0.0
% INFO    : Bus 462	: V=0.997808, theta=37.195998 -> V=1.0, theta=0.0
% INFO    : Bus 463	: V=1.126642, theta=-0.913545 -> V=1.0, theta=0.0
% INFO    : Bus 464	: V=1.023637, theta=24.670209 -> V=1.0, theta=0.0
% INFO    : Bus 465	: V=1.031718, theta=39.18761 -> V=1.0, theta=0.0
% INFO    : Bus 466	: V=1.007693, theta=31.850349 -> V=1.0, theta=0.0
% INFO    : Bus 467	: V=1.009138, theta=14.501366 -> V=1.0, theta=0.0
% INFO    : Bus 468	: V=1.020059, theta=-8.568677 -> V=1.0, theta=0.0
% INFO    : Bus 469	: V=1.067283, theta=22.816615 -> V=1.0, theta=0.0
% INFO    : Bus 470	: V=1.046905, theta=39.305577 -> V=1.0, theta=0.0
% INFO    : Bus 471	: V=1.044907, theta=35.76351 -> V=1.0, theta=0.0
% INFO    : Bus 472	: V=1.000606, theta=-9.570545 -> V=1.0, theta=0.0
% INFO    : Bus 473	: V=1.027549, theta=1.721949 -> V=1.0, theta=0.0
% INFO    : Bus 474	: V=0.970629, theta=34.677428 -> V=1.0, theta=0.0
% INFO    : Bus 475	: V=1.050845, theta=90.640831 -> V=1.0, theta=0.0
% INFO    : Bus 476	: V=1.029484, theta=52.40343 -> V=1.0, theta=0.0
% INFO    : Bus 477	: V=1.043087, theta=11.638661 -> V=1.0, theta=0.0
% INFO    : Bus 478	: V=1.060985, theta=79.464606 -> V=1.0, theta=0.0
% INFO    : Bus 479	: V=1.028161, theta=4.473394 -> V=1.0, theta=0.0
% INFO    : Bus 480	: V=1.033425, theta=29.680614 -> V=1.0, theta=0.0
% INFO    : Bus 481	: V=1.033425, theta=29.680614 -> V=1.0, theta=0.0
% INFO    : Bus 482	: V=1.033425, theta=29.680614 -> V=1.0, theta=0.0
% INFO    : Bus 483	: V=1.033425, theta=29.680614 -> V=1.0, theta=0.0
% INFO    : Bus 484	: V=1.016462, theta=21.52717 -> V=1.0, theta=0.0
% INFO    : Bus 485	: V=1.059619, theta=6.357453 -> V=1.0, theta=0.0
% INFO    : Bus 486	: V=1.071666, theta=58.820002 -> V=1.0, theta=0.0
% INFO    : Bus 487	: V=1.014191, theta=15.517546 -> V=1.0, theta=0.0
% INFO    : Bus 488	: V=1.004279, theta=49.93024 -> V=1.0, theta=0.0
% INFO    : Bus 489	: V=0.988321, theta=-4.477618 -> V=1.0, theta=0.0
% INFO    : Bus 490	: V=1.04238, theta=36.640438 -> V=1.0, theta=0.0
% INFO    : Bus 491	: V=0.981642, theta=-7.831663 -> V=1.0, theta=0.0
% INFO    : Bus 492	: V=1.041985, theta=31.793879 -> V=1.0, theta=0.0
% INFO    : Bus 493	: V=1.002503, theta=-5.375842 -> V=1.0, theta=0.0
% INFO    : Bus 494	: V=1.118986, theta=0.152255 -> V=1.0, theta=0.0
% INFO    : Bus 495	: V=0.991902, theta=-13.539498 -> V=1.0, theta=0.0
% INFO    : Bus 496	: V=1.00876, theta=0.250829 -> V=1.0, theta=0.0
% INFO    : Bus 497	: V=1.015717, theta=16.675593 -> V=1.0, theta=0.0
% INFO    : Bus 498	: V=0.955363, theta=-6.864987 -> V=1.0, theta=0.0
% INFO    : Bus 499	: V=1.008611, theta=2.339129 -> V=1.0, theta=0.0
% INFO    : Bus 500	: V=0.981895, theta=-2.975305 -> V=1.0, theta=0.0
% INFO    : Bus 501	: V=1.016425, theta=22.882064 -> V=1.0, theta=0.0
% INFO    : Bus 502	: V=1.022789, theta=-2.776784 -> V=1.0, theta=0.0
% INFO    : Bus 503	: V=0.963995, theta=-4.73909 -> V=1.0, theta=0.0
% INFO    : Bus 504	: V=0.989389, theta=-4.565793 -> V=1.0, theta=0.0
% INFO    : Bus 505	: V=0.99315, theta=0.886893 -> V=1.0, theta=0.0
% INFO    : Bus 506	: V=1.017162, theta=-1.318256 -> V=1.0, theta=0.0
% INFO    : Bus 507	: V=1.018067, theta=25.301446 -> V=1.0, theta=0.0
% INFO    : Bus 508	: V=1.044776, theta=37.116836 -> V=1.0, theta=0.0
% INFO    : Bus 509	: V=1.044388, theta=36.589282 -> V=1.0, theta=0.0
% INFO    : Bus 510	: V=1.044096, theta=37.018553 -> V=1.0, theta=0.0
% INFO    : Bus 511	: V=1.002012, theta=13.542185 -> V=1.0, theta=0.0
% INFO    : Bus 512	: V=1.002012, theta=13.542185 -> V=1.0, theta=0.0
% INFO    : Bus 513	: V=1.002012, theta=13.542185 -> V=1.0, theta=0.0
% INFO    : Bus 514	: V=1.044511, theta=37.099046 -> V=1.0, theta=0.0
% INFO    : Bus 515	: V=1.002012, theta=13.542185 -> V=1.0, theta=0.0
% INFO    : Bus 516	: V=1.041748, theta=29.3468 -> V=1.0, theta=0.0
% INFO    : Bus 517	: V=1.014573, theta=-5.773397 -> V=1.0, theta=0.0
% INFO    : Bus 518	: V=1.028486, theta=8.959933 -> V=1.0, theta=0.0
% INFO    : Bus 519	: V=1.005897, theta=20.492913 -> V=1.0, theta=0.0
% INFO    : Bus 520	: V=1.02668, theta=35.22961 -> V=1.0, theta=0.0
% INFO    : Bus 521	: V=1.024265, theta=6.009421 -> V=1.0, theta=0.0
% INFO    : Bus 522	: V=1.016294, theta=49.478494 -> V=1.0, theta=0.0
% INFO    : Bus 523	: V=1.055944, theta=31.159791 -> V=1.0, theta=0.0
% INFO    : Bus 524	: V=1.026439, theta=-4.895454 -> V=1.0, theta=0.0
% INFO    : Bus 525	: V=0.986332, theta=25.334582 -> V=1.0, theta=0.0
% INFO    : Bus 526	: V=0.988925, theta=-2.520654 -> V=1.0, theta=0.0
% INFO    : Bus 527	: V=1.034921, theta=6.905166 -> V=1.0, theta=0.0
% INFO    : Bus 528	: V=1.020703, theta=22.380203 -> V=1.0, theta=0.0
% INFO    : Bus 529	: V=1.023322, theta=-11.234733 -> V=1.0, theta=0.0
% INFO    : Bus 530	: V=1.06537, theta=47.218455 -> V=1.0, theta=0.0
% INFO    : Bus 531	: V=1.035838, theta=-5.172678 -> V=1.0, theta=0.0
% INFO    : Bus 532	: V=1.036699, theta=34.476926 -> V=1.0, theta=0.0
% INFO    : Bus 533	: V=1.016377, theta=7.336958 -> V=1.0, theta=0.0
% INFO    : Bus 534	: V=0.931414, theta=-8.249444 -> V=1.0, theta=0.0
% INFO    : Bus 535	: V=1.01686, theta=13.039574 -> V=1.0, theta=0.0
% INFO    : Bus 536	: V=1.023154, theta=38.809154 -> V=1.0, theta=0.0
% INFO    : Bus 537	: V=1.049545, theta=42.876879 -> V=1.0, theta=0.0
% INFO    : Bus 538	: V=0.991967, theta=89.112631 -> V=1.0, theta=0.0
% INFO    : Bus 539	: V=0.993492, theta=29.317066 -> V=1.0, theta=0.0
% INFO    : Bus 540	: V=1.102789, theta=-15.259978 -> V=1.0, theta=0.0
% INFO    : Bus 541	: V=0.995314, theta=-3.374716 -> V=1.0, theta=0.0
% INFO    : Bus 542	: V=1.013699, theta=-0.827325 -> V=1.0, theta=0.0
% INFO    : Bus 543	: V=0.988843, theta=-3.474628 -> V=1.0, theta=0.0
% INFO    : Bus 544	: V=1.023056, theta=6.428381 -> V=1.0, theta=0.0
% INFO    : Bus 545	: V=0.977758, theta=4.623964 -> V=1.0, theta=0.0
% INFO    : Bus 546	: V=0.998467, theta=-3.301764 -> V=1.0, theta=0.0
% INFO    : Bus 547	: V=0.998593, theta=42.474186 -> V=1.0, theta=0.0
% INFO    : Bus 548	: V=1.020988, theta=24.486279 -> V=1.0, theta=0.0
% INFO    : Bus 549	: V=1.04807, theta=86.165538 -> V=1.0, theta=0.0
% INFO    : Bus 550	: V=1.086334, theta=1.463858 -> V=1.0, theta=0.0
% INFO    : Bus 551	: V=0.995963, theta=-9.132106 -> V=1.0, theta=0.0
% INFO    : Bus 552	: V=0.99834, theta=24.249316 -> V=1.0, theta=0.0
% INFO    : Bus 553	: V=1.072559, theta=36.179181 -> V=1.0, theta=0.0
% INFO    : Bus 554	: V=0.980028, theta=-8.586818 -> V=1.0, theta=0.0
% INFO    : Bus 555	: V=1.023552, theta=-0.978719 -> V=1.0, theta=0.0
% INFO    : Bus 556	: V=1.02302, theta=79.89045 -> V=1.0, theta=0.0
% INFO    : Bus 557	: V=1.012671, theta=-2.175683 -> V=1.0, theta=0.0
% INFO    : Bus 558	: V=1.020181, theta=36.372744 -> V=1.0, theta=0.0
% INFO    : Bus 559	: V=0.954584, theta=49.806962 -> V=1.0, theta=0.0
% INFO    : Bus 560	: V=1.009937, theta=-13.160441 -> V=1.0, theta=0.0
% INFO    : Bus 561	: V=0.981754, theta=18.128137 -> V=1.0, theta=0.0
% INFO    : Bus 562	: V=0.968054, theta=-6.793963 -> V=1.0, theta=0.0
% INFO    : Bus 563	: V=0.997104, theta=-5.319336 -> V=1.0, theta=0.0
% INFO    : Bus 564	: V=1.024499, theta=-3.834468 -> V=1.0, theta=0.0
% INFO    : Bus 565	: V=0.983771, theta=-0.029864 -> V=1.0, theta=0.0
% INFO    : Bus 566	: V=1.050612, theta=5.201724 -> V=1.0, theta=0.0
% INFO    : Bus 567	: V=1.037403, theta=12.654648 -> V=1.0, theta=0.0
% INFO    : Bus 568	: V=0.995622, theta=27.676502 -> V=1.0, theta=0.0
% INFO    : Bus 569	: V=1.012073, theta=-8.225001 -> V=1.0, theta=0.0
% INFO    : Bus 570	: V=1.01609, theta=-22.212248 -> V=1.0, theta=0.0
% INFO    : Bus 571	: V=1.060426, theta=48.406404 -> V=1.0, theta=0.0
% INFO    : Bus 572	: V=1.004314, theta=14.241295 -> V=1.0, theta=0.0
% INFO    : Bus 573	: V=0.988321, theta=6.881414 -> V=1.0, theta=0.0
% INFO    : Bus 574	: V=1.011211, theta=-13.487557 -> V=1.0, theta=0.0
% INFO    : Bus 575	: V=1.016739, theta=22.326375 -> V=1.0, theta=0.0
% INFO    : Bus 576	: V=1.016739, theta=22.326375 -> V=1.0, theta=0.0
% INFO    : Bus 577	: V=1.016739, theta=22.326375 -> V=1.0, theta=0.0
% INFO    : Bus 578	: V=0.982939, theta=-5.438658 -> V=1.0, theta=0.0
% INFO    : Bus 579	: V=0.982134, theta=23.783698 -> V=1.0, theta=0.0
% INFO    : Bus 580	: V=1.028821, theta=-3.48117 -> V=1.0, theta=0.0
% INFO    : Bus 581	: V=1.016739, theta=22.326375 -> V=1.0, theta=0.0
% INFO    : Bus 582	: V=1.07923, theta=68.996986 -> V=1.0, theta=0.0
% INFO    : Bus 583	: V=1.033308, theta=40.656079 -> V=1.0, theta=0.0
% INFO    : Bus 584	: V=1.018412, theta=11.984544 -> V=1.0, theta=0.0
% INFO    : Bus 585	: V=1.041629, theta=38.466941 -> V=1.0, theta=0.0
% INFO    : Bus 586	: V=0.912043, theta=-12.081031 -> V=1.0, theta=0.0
% INFO    : Bus 587	: V=1.037667, theta=14.939315 -> V=1.0, theta=0.0
% INFO    : Bus 588	: V=1.012735, theta=9.265213 -> V=1.0, theta=0.0
% INFO    : Bus 589	: V=1.00755, theta=-13.681446 -> V=1.0, theta=0.0
% INFO    : Bus 590	: V=0.999923, theta=-3.039737 -> V=1.0, theta=0.0
% INFO    : Bus 591	: V=0.997618, theta=-7.177191 -> V=1.0, theta=0.0
% INFO    : Bus 592	: V=1.003147, theta=15.307317 -> V=1.0, theta=0.0
% INFO    : Bus 593	: V=1.020596, theta=-16.730831 -> V=1.0, theta=0.0
% INFO    : Bus 594	: V=1.020596, theta=-16.730831 -> V=1.0, theta=0.0
% INFO    : Bus 595	: V=1.055576, theta=-5.790807 -> V=1.0, theta=0.0
% INFO    : Bus 596	: V=1.008982, theta=-3.14743 -> V=1.0, theta=0.0
% INFO    : Bus 597	: V=1.004651, theta=-16.584297 -> V=1.0, theta=0.0
% INFO    : Bus 598	: V=0.985019, theta=22.550521 -> V=1.0, theta=0.0
% INFO    : Bus 599	: V=1.01493, theta=29.607123 -> V=1.0, theta=0.0
% INFO    : Bus 600	: V=1.032362, theta=39.964616 -> V=1.0, theta=0.0
% INFO    : Bus 601	: V=1.029876, theta=19.391484 -> V=1.0, theta=0.0
% INFO    : Bus 602	: V=1.015668, theta=18.412381 -> V=1.0, theta=0.0
% INFO    : Bus 603	: V=1.041573, theta=-0.003639 -> V=1.0, theta=0.0
% INFO    : Bus 604	: V=1.012186, theta=-11.629863 -> V=1.0, theta=0.0
% INFO    : Bus 605	: V=0.982106, theta=40.293349 -> V=1.0, theta=0.0
% INFO    : Bus 606	: V=1.02619, theta=24.279876 -> V=1.0, theta=0.0
% INFO    : Bus 607	: V=1.024665, theta=-10.538885 -> V=1.0, theta=0.0
% INFO    : Bus 608	: V=1.019224, theta=-24.665042 -> V=1.0, theta=0.0
% INFO    : Bus 609	: V=1.040938, theta=22.649998 -> V=1.0, theta=0.0
% INFO    : Bus 610	: V=1.019723, theta=-1.552655 -> V=1.0, theta=0.0
% INFO    : Bus 611	: V=0.985982, theta=40.427243 -> V=1.0, theta=0.0
% INFO    : Bus 612	: V=1.023098, theta=-4.178904 -> V=1.0, theta=0.0
% INFO    : Bus 613	: V=1.007942, theta=-10.569275 -> V=1.0, theta=0.0
% INFO    : Bus 614	: V=1.031902, theta=6.119938 -> V=1.0, theta=0.0
% INFO    : Bus 615	: V=1.031902, theta=6.119938 -> V=1.0, theta=0.0
% INFO    : Bus 616	: V=1.050465, theta=43.901371 -> V=1.0, theta=0.0
% INFO    : Bus 617	: V=1.030589, theta=4.0661 -> V=1.0, theta=0.0
% INFO    : Bus 618	: V=0.998875, theta=-9.905754 -> V=1.0, theta=0.0
% INFO    : Bus 619	: V=1.031502, theta=4.663459 -> V=1.0, theta=0.0
% INFO    : Bus 620	: V=1.022299, theta=0.336959 -> V=1.0, theta=0.0
% INFO    : Bus 621	: V=1.003942, theta=39.409116 -> V=1.0, theta=0.0
% INFO    : Bus 622	: V=1.020094, theta=47.941792 -> V=1.0, theta=0.0
% INFO    : Bus 623	: V=1.045359, theta=10.101302 -> V=1.0, theta=0.0
% INFO    : Bus 624	: V=1.020239, theta=32.099905 -> V=1.0, theta=0.0
% INFO    : Bus 625	: V=0.995856, theta=-9.114615 -> V=1.0, theta=0.0
% INFO    : Bus 626	: V=1.035771, theta=2.999441 -> V=1.0, theta=0.0
% INFO    : Bus 627	: V=1.037098, theta=11.171028 -> V=1.0, theta=0.0
% INFO    : Bus 628	: V=1.064436, theta=-8.048474 -> V=1.0, theta=0.0
% INFO    : Bus 629	: V=1.006004, theta=20.84448 -> V=1.0, theta=0.0
% INFO    : Bus 630	: V=0.980004, theta=1.020887 -> V=1.0, theta=0.0
% INFO    : Bus 631	: V=1.027192, theta=-22.090057 -> V=1.0, theta=0.0
% INFO    : Bus 632	: V=1.029976, theta=-3.543373 -> V=1.0, theta=0.0
% INFO    : Bus 633	: V=1.026706, theta=33.46792 -> V=1.0, theta=0.0
% INFO    : Bus 634	: V=1.024739, theta=32.215254 -> V=1.0, theta=0.0
% INFO    : Bus 635	: V=1.023511, theta=0.594852 -> V=1.0, theta=0.0
% INFO    : Bus 636	: V=1.004986, theta=-8.852574 -> V=1.0, theta=0.0
% INFO    : Bus 637	: V=1.04616, theta=-9.114978 -> V=1.0, theta=0.0
% INFO    : Bus 638	: V=1.024059, theta=44.846055 -> V=1.0, theta=0.0
% INFO    : Bus 639	: V=1.011245, theta=27.629302 -> V=1.0, theta=0.0
% INFO    : Bus 640	: V=1.004462, theta=-15.792016 -> V=1.0, theta=0.0
% INFO    : Bus 641	: V=1.057792, theta=0.42714 -> V=1.0, theta=0.0
% INFO    : Bus 642	: V=1.12305, theta=1.040238 -> V=1.0, theta=0.0
% INFO    : Bus 643	: V=1.003618, theta=-2.822895 -> V=1.0, theta=0.0
% INFO    : Bus 644	: V=1.049525, theta=86.868297 -> V=1.0, theta=0.0
% INFO    : Bus 645	: V=1.0826, theta=86.434281 -> V=1.0, theta=0.0
% INFO    : Bus 646	: V=1.030395, theta=-6.336516 -> V=1.0, theta=0.0
% INFO    : Bus 647	: V=1.020186, theta=-24.812762 -> V=1.0, theta=0.0
% INFO    : Bus 648	: V=1.007781, theta=59.664038 -> V=1.0, theta=0.0
% INFO    : Bus 649	: V=1.030395, theta=-6.336516 -> V=1.0, theta=0.0
% INFO    : Bus 650	: V=0.994655, theta=-18.823114 -> V=1.0, theta=0.0
% INFO    : Bus 651	: V=1.028351, theta=-2.802846 -> V=1.0, theta=0.0
% INFO    : Bus 652	: V=1.028351, theta=-2.802846 -> V=1.0, theta=0.0
% INFO    : Bus 653	: V=1.006947, theta=-5.91582 -> V=1.0, theta=0.0
% INFO    : Bus 654	: V=1.014507, theta=26.136069 -> V=1.0, theta=0.0
% INFO    : Bus 655	: V=1.027725, theta=18.930085 -> V=1.0, theta=0.0
% INFO    : Bus 656	: V=1.030053, theta=-17.261924 -> V=1.0, theta=0.0
% INFO    : Bus 657	: V=1.014108, theta=0.87733 -> V=1.0, theta=0.0
% INFO    : Bus 658	: V=0.995621, theta=14.139898 -> V=1.0, theta=0.0
% INFO    : Bus 659	: V=0.974088, theta=-8.221786 -> V=1.0, theta=0.0
% INFO    : Bus 660	: V=1.022689, theta=-16.891323 -> V=1.0, theta=0.0
% INFO    : Bus 661	: V=1.010252, theta=22.297225 -> V=1.0, theta=0.0
% INFO    : Bus 662	: V=1.080621, theta=-3.774626 -> V=1.0, theta=0.0
% INFO    : Bus 663	: V=1.061402, theta=49.738372 -> V=1.0, theta=0.0
% INFO    : Bus 664	: V=0.995363, theta=-14.400857 -> V=1.0, theta=0.0
% INFO    : Bus 665	: V=0.999024, theta=20.683055 -> V=1.0, theta=0.0
% INFO    : Bus 666	: V=1.018739, theta=-6.896129 -> V=1.0, theta=0.0
% INFO    : Bus 667	: V=1.010467, theta=35.110882 -> V=1.0, theta=0.0
% INFO    : Bus 668	: V=1.031848, theta=-1.87464 -> V=1.0, theta=0.0
% INFO    : Bus 669	: V=1.018382, theta=7.768221 -> V=1.0, theta=0.0
% INFO    : Bus 670	: V=0.980165, theta=3.066285 -> V=1.0, theta=0.0
% INFO    : Bus 671	: V=0.999061, theta=42.441878 -> V=1.0, theta=0.0
% INFO    : Bus 672	: V=1.027993, theta=3.626388 -> V=1.0, theta=0.0
% INFO    : Bus 673	: V=1.030324, theta=22.492733 -> V=1.0, theta=0.0
% INFO    : Bus 674	: V=0.994789, theta=-3.452739 -> V=1.0, theta=0.0
% INFO    : Bus 675	: V=1.017174, theta=-12.280888 -> V=1.0, theta=0.0
% INFO    : Bus 676	: V=1.018066, theta=-18.544118 -> V=1.0, theta=0.0
% INFO    : Bus 677	: V=0.976124, theta=0.454545 -> V=1.0, theta=0.0
% INFO    : Bus 678	: V=1.014364, theta=-8.724986 -> V=1.0, theta=0.0
% INFO    : Bus 679	: V=1.12555, theta=-0.331163 -> V=1.0, theta=0.0
% INFO    : Bus 680	: V=1.038504, theta=35.779711 -> V=1.0, theta=0.0
% INFO    : Bus 681	: V=1.00657, theta=25.464337 -> V=1.0, theta=0.0
% INFO    : Bus 682	: V=0.985728, theta=2.216033 -> V=1.0, theta=0.0
% INFO    : Bus 683	: V=1.034215, theta=12.306912 -> V=1.0, theta=0.0
% INFO    : Bus 684	: V=1.035618, theta=-0.462639 -> V=1.0, theta=0.0
% INFO    : Bus 685	: V=1.039652, theta=-6.424256 -> V=1.0, theta=0.0
% INFO    : Bus 686	: V=1.004715, theta=15.162759 -> V=1.0, theta=0.0
% INFO    : Bus 687	: V=1.0114, theta=31.187658 -> V=1.0, theta=0.0
% INFO    : Bus 688	: V=0.963906, theta=-6.15131 -> V=1.0, theta=0.0
% INFO    : Bus 689	: V=1.01888, theta=-8.431592 -> V=1.0, theta=0.0
% INFO    : Bus 690	: V=1.054345, theta=-5.313694 -> V=1.0, theta=0.0
% INFO    : Bus 691	: V=0.991725, theta=-13.734054 -> V=1.0, theta=0.0
% INFO    : Bus 692	: V=1.012011, theta=5.276376 -> V=1.0, theta=0.0
% INFO    : Bus 693	: V=1.038999, theta=38.995592 -> V=1.0, theta=0.0
% INFO    : Bus 694	: V=1.025884, theta=34.061261 -> V=1.0, theta=0.0
% INFO    : Bus 695	: V=1.010516, theta=39.993345 -> V=1.0, theta=0.0
% INFO    : Bus 696	: V=1.021643, theta=-18.319826 -> V=1.0, theta=0.0
% INFO    : Bus 697	: V=0.985966, theta=-13.767739 -> V=1.0, theta=0.0
% INFO    : Bus 698	: V=1.018527, theta=-13.24267 -> V=1.0, theta=0.0
% INFO    : Bus 699	: V=1.043232, theta=77.757181 -> V=1.0, theta=0.0
% INFO    : Bus 700	: V=0.971314, theta=29.785076 -> V=1.0, theta=0.0
% INFO    : Bus 701	: V=1.022096, theta=-14.512809 -> V=1.0, theta=0.0
% INFO    : Bus 702	: V=1.083955, theta=72.533534 -> V=1.0, theta=0.0
% INFO    : Bus 703	: V=1.005226, theta=6.168419 -> V=1.0, theta=0.0
% INFO    : Bus 704	: V=1.039757, theta=11.331045 -> V=1.0, theta=0.0
% INFO    : Bus 705	: V=1.047819, theta=-5.173347 -> V=1.0, theta=0.0
% INFO    : Bus 706	: V=1.028453, theta=-20.661313 -> V=1.0, theta=0.0
% INFO    : Bus 707	: V=1.058829, theta=21.8732 -> V=1.0, theta=0.0
% INFO    : Bus 708	: V=0.977623, theta=-2.554024 -> V=1.0, theta=0.0
% INFO    : Bus 709	: V=1.051727, theta=31.564136 -> V=1.0, theta=0.0
% INFO    : Bus 710	: V=0.996598, theta=8.383316 -> V=1.0, theta=0.0
% INFO    : Bus 711	: V=1.014587, theta=-22.560626 -> V=1.0, theta=0.0
% INFO    : Bus 712	: V=1.047436, theta=81.329599 -> V=1.0, theta=0.0
% INFO    : Bus 713	: V=0.997077, theta=26.794575 -> V=1.0, theta=0.0
% INFO    : Bus 714	: V=0.998982, theta=27.909753 -> V=1.0, theta=0.0
% INFO    : Bus 715	: V=1.007844, theta=10.25283 -> V=1.0, theta=0.0
% INFO    : Bus 716	: V=1.015981, theta=20.565424 -> V=1.0, theta=0.0
% INFO    : Bus 717	: V=1.027572, theta=24.287546 -> V=1.0, theta=0.0
% INFO    : Bus 718	: V=1.020115, theta=30.202806 -> V=1.0, theta=0.0
% INFO    : Bus 719	: V=1.013826, theta=-19.850393 -> V=1.0, theta=0.0
% INFO    : Bus 720	: V=1.029133, theta=7.492457 -> V=1.0, theta=0.0
% INFO    : Bus 721	: V=0.992442, theta=9.617717 -> V=1.0, theta=0.0
% INFO    : Bus 722	: V=1.026106, theta=61.149064 -> V=1.0, theta=0.0
% INFO    : Bus 723	: V=0.94297, theta=-17.488149 -> V=1.0, theta=0.0
% INFO    : Bus 724	: V=1.045213, theta=9.250128 -> V=1.0, theta=0.0
% INFO    : Bus 725	: V=0.95067, theta=-7.990035 -> V=1.0, theta=0.0
% INFO    : Bus 726	: V=0.998821, theta=-8.907903 -> V=1.0, theta=0.0
% INFO    : Bus 727	: V=1.068269, theta=74.52173 -> V=1.0, theta=0.0
% INFO    : Bus 728	: V=1.018461, theta=36.492173 -> V=1.0, theta=0.0
% INFO    : Bus 729	: V=1.000858, theta=34.472609 -> V=1.0, theta=0.0
% INFO    : Bus 730	: V=1.01458, theta=18.108546 -> V=1.0, theta=0.0
% INFO    : Bus 731	: V=1.01458, theta=18.108546 -> V=1.0, theta=0.0
% INFO    : Bus 732	: V=1.01458, theta=18.108546 -> V=1.0, theta=0.0
% INFO    : Bus 733	: V=0.990189, theta=21.27187 -> V=1.0, theta=0.0
% INFO    : Bus 734	: V=1.01458, theta=18.108546 -> V=1.0, theta=0.0
% INFO    : Bus 735	: V=1.027209, theta=14.05509 -> V=1.0, theta=0.0
% INFO    : Bus 736	: V=0.977249, theta=0.569527 -> V=1.0, theta=0.0
% INFO    : Bus 737	: V=1.008405, theta=-3.834733 -> V=1.0, theta=0.0
% INFO    : Bus 738	: V=1.02769, theta=23.00179 -> V=1.0, theta=0.0
% INFO    : Bus 739	: V=1.065043, theta=50.496306 -> V=1.0, theta=0.0
% INFO    : Bus 740	: V=0.970367, theta=-6.743137 -> V=1.0, theta=0.0
% INFO    : Bus 741	: V=0.999635, theta=35.983555 -> V=1.0, theta=0.0
% INFO    : Bus 742	: V=1.058599, theta=20.351147 -> V=1.0, theta=0.0
% INFO    : Bus 743	: V=1.040076, theta=-3.544332 -> V=1.0, theta=0.0
% INFO    : Bus 744	: V=0.989367, theta=-2.478771 -> V=1.0, theta=0.0
% INFO    : Bus 745	: V=1.018947, theta=-33.068169 -> V=1.0, theta=0.0
% INFO    : Bus 746	: V=0.994194, theta=24.952464 -> V=1.0, theta=0.0
% INFO    : Bus 747	: V=1.013353, theta=5.579718 -> V=1.0, theta=0.0
% INFO    : Bus 748	: V=1.082894, theta=85.120497 -> V=1.0, theta=0.0
% INFO    : Bus 749	: V=1.009791, theta=14.416544 -> V=1.0, theta=0.0
% INFO    : Bus 750	: V=1.009791, theta=14.416544 -> V=1.0, theta=0.0
% INFO    : Bus 751	: V=1.009791, theta=14.416544 -> V=1.0, theta=0.0
% INFO    : Bus 752	: V=1.00664, theta=31.182408 -> V=1.0, theta=0.0
% INFO    : Bus 753	: V=1.018866, theta=14.228745 -> V=1.0, theta=0.0
% INFO    : Bus 754	: V=1.009683, theta=1.076815 -> V=1.0, theta=0.0
% INFO    : Bus 755	: V=1.004347, theta=-13.085564 -> V=1.0, theta=0.0
% INFO    : Bus 756	: V=1.026914, theta=7.66077 -> V=1.0, theta=0.0
% INFO    : Bus 757	: V=1.016003, theta=2.506825 -> V=1.0, theta=0.0
% INFO    : Bus 758	: V=0.988701, theta=-12.066079 -> V=1.0, theta=0.0
% INFO    : Bus 759	: V=1.029997, theta=24.456838 -> V=1.0, theta=0.0
% INFO    : Bus 760	: V=1.014144, theta=-23.295024 -> V=1.0, theta=0.0
% INFO    : Bus 761	: V=1.036321, theta=1.925379 -> V=1.0, theta=0.0
% INFO    : Bus 762	: V=1.008774, theta=-3.324558 -> V=1.0, theta=0.0
% INFO    : Bus 763	: V=1.070453, theta=1.995467 -> V=1.0, theta=0.0
% INFO    : Bus 764	: V=1.024756, theta=-11.276001 -> V=1.0, theta=0.0
% INFO    : Bus 765	: V=1.032985, theta=-6.930528 -> V=1.0, theta=0.0
% INFO    : Bus 766	: V=1.019596, theta=33.38308 -> V=1.0, theta=0.0
% INFO    : Bus 767	: V=1.007718, theta=37.209288 -> V=1.0, theta=0.0
% INFO    : Bus 768	: V=1.044527, theta=23.855553 -> V=1.0, theta=0.0
% INFO    : Bus 769	: V=1.044527, theta=23.855553 -> V=1.0, theta=0.0
% INFO    : Bus 770	: V=1.039156, theta=19.470405 -> V=1.0, theta=0.0
% INFO    : Bus 771	: V=1.039156, theta=19.470405 -> V=1.0, theta=0.0
% INFO    : Bus 772	: V=0.97928, theta=37.684032 -> V=1.0, theta=0.0
% INFO    : Bus 773	: V=1.016081, theta=21.284924 -> V=1.0, theta=0.0
% INFO    : Bus 774	: V=1.007722, theta=14.132282 -> V=1.0, theta=0.0
% INFO    : Bus 775	: V=1.003456, theta=18.777669 -> V=1.0, theta=0.0
% INFO    : Bus 776	: V=1.039156, theta=19.470405 -> V=1.0, theta=0.0
% INFO    : Bus 777	: V=1.018902, theta=-18.885965 -> V=1.0, theta=0.0
% INFO    : Bus 778	: V=1.02868, theta=47.75243 -> V=1.0, theta=0.0
% INFO    : Bus 779	: V=0.9829, theta=25.033677 -> V=1.0, theta=0.0
% INFO    : Bus 780	: V=1.022808, theta=12.457089 -> V=1.0, theta=0.0
% INFO    : Bus 781	: V=1.046208, theta=1.751552 -> V=1.0, theta=0.0
% INFO    : Bus 782	: V=0.975786, theta=5.725108 -> V=1.0, theta=0.0
% INFO    : Bus 783	: V=1.027518, theta=-17.089784 -> V=1.0, theta=0.0
% INFO    : Bus 784	: V=1.008445, theta=33.79762 -> V=1.0, theta=0.0
% INFO    : Bus 785	: V=0.95552, theta=-7.1101 -> V=1.0, theta=0.0
% INFO    : Bus 786	: V=1.013792, theta=13.048881 -> V=1.0, theta=0.0
% INFO    : Bus 787	: V=0.9983, theta=26.918478 -> V=1.0, theta=0.0
% INFO    : Bus 788	: V=0.983092, theta=-11.324453 -> V=1.0, theta=0.0
% INFO    : Bus 789	: V=1.040763, theta=-20.963956 -> V=1.0, theta=0.0
% INFO    : Bus 790	: V=0.954084, theta=-7.518624 -> V=1.0, theta=0.0
% INFO    : Bus 791	: V=0.970954, theta=-14.134822 -> V=1.0, theta=0.0
% INFO    : Bus 792	: V=0.996611, theta=26.942681 -> V=1.0, theta=0.0
% INFO    : Bus 793	: V=0.981471, theta=34.867888 -> V=1.0, theta=0.0
% INFO    : Bus 794	: V=0.954505, theta=-7.782367 -> V=1.0, theta=0.0
% INFO    : Bus 795	: V=1.066578, theta=53.394043 -> V=1.0, theta=0.0
% INFO    : Bus 796	: V=0.978625, theta=-3.324992 -> V=1.0, theta=0.0
% INFO    : Bus 797	: V=1.011512, theta=30.216177 -> V=1.0, theta=0.0
% INFO    : Bus 798	: V=1.015954, theta=3.75914 -> V=1.0, theta=0.0
% INFO    : Bus 799	: V=0.990011, theta=1.446443 -> V=1.0, theta=0.0
% INFO    : Bus 800	: V=1.040587, theta=38.218788 -> V=1.0, theta=0.0
% INFO    : Bus 801	: V=1.022097, theta=-24.539739 -> V=1.0, theta=0.0
% INFO    : Bus 802	: V=1.063006, theta=0.575668 -> V=1.0, theta=0.0
% INFO    : Bus 803	: V=1.099039, theta=-14.346049 -> V=1.0, theta=0.0
% INFO    : Bus 804	: V=0.999004, theta=-3.134908 -> V=1.0, theta=0.0
% INFO    : Bus 805	: V=1.036024, theta=47.46783 -> V=1.0, theta=0.0
% INFO    : Bus 806	: V=1.032716, theta=17.680245 -> V=1.0, theta=0.0
% INFO    : Bus 807	: V=1.02396, theta=-18.053463 -> V=1.0, theta=0.0
% INFO    : Bus 808	: V=0.939327, theta=-13.271181 -> V=1.0, theta=0.0
% INFO    : Bus 809	: V=1.023128, theta=-17.667071 -> V=1.0, theta=0.0
% INFO    : Bus 810	: V=0.960507, theta=-15.710242 -> V=1.0, theta=0.0
% INFO    : Bus 811	: V=1.022192, theta=20.047374 -> V=1.0, theta=0.0
% INFO    : Bus 812	: V=1.02116, theta=9.225534 -> V=1.0, theta=0.0
% INFO    : Bus 813	: V=1.010866, theta=-10.017249 -> V=1.0, theta=0.0
% INFO    : Bus 814	: V=1.01249, theta=-3.900476 -> V=1.0, theta=0.0
% INFO    : Bus 815	: V=1.026207, theta=-11.793103 -> V=1.0, theta=0.0
% INFO    : Bus 816	: V=1.029733, theta=7.74677 -> V=1.0, theta=0.0
% INFO    : Bus 817	: V=1.001872, theta=5.9468 -> V=1.0, theta=0.0
% INFO    : Bus 818	: V=1.021546, theta=43.092206 -> V=1.0, theta=0.0
% INFO    : Bus 819	: V=1.048632, theta=39.237883 -> V=1.0, theta=0.0
% INFO    : Bus 820	: V=1.025508, theta=18.162907 -> V=1.0, theta=0.0
% INFO    : Bus 821	: V=1.015947, theta=22.790189 -> V=1.0, theta=0.0
% INFO    : Bus 822	: V=0.969735, theta=-9.642283 -> V=1.0, theta=0.0
% INFO    : Bus 823	: V=1.026078, theta=-19.617451 -> V=1.0, theta=0.0
% INFO    : Bus 824	: V=1.018739, theta=-6.896129 -> V=1.0, theta=0.0
% INFO    : Bus 825	: V=0.956703, theta=-9.070653 -> V=1.0, theta=0.0
% INFO    : Bus 826	: V=1.045563, theta=-9.81487 -> V=1.0, theta=0.0
% INFO    : Bus 827	: V=1.045872, theta=-0.227578 -> V=1.0, theta=0.0
% INFO    : Bus 828	: V=1.01121, theta=21.596284 -> V=1.0, theta=0.0
% INFO    : Bus 829	: V=1.089984, theta=2.669964 -> V=1.0, theta=0.0
% INFO    : Bus 830	: V=0.998601, theta=-10.373841 -> V=1.0, theta=0.0
% INFO    : Bus 831	: V=1.012387, theta=35.628558 -> V=1.0, theta=0.0
% INFO    : Bus 832	: V=1.022107, theta=3.77318 -> V=1.0, theta=0.0
% INFO    : Bus 833	: V=0.991892, theta=-13.719477 -> V=1.0, theta=0.0
% INFO    : Bus 834	: V=0.998019, theta=-5.508598 -> V=1.0, theta=0.0
% INFO    : Bus 835	: V=1.055149, theta=5.178292 -> V=1.0, theta=0.0
% INFO    : Bus 836	: V=1.015461, theta=-14.262307 -> V=1.0, theta=0.0
% INFO    : Bus 837	: V=1.005017, theta=-18.861992 -> V=1.0, theta=0.0
% INFO    : Bus 838	: V=1.001252, theta=3.505451 -> V=1.0, theta=0.0
% INFO    : Bus 839	: V=1.0079, theta=-15.676436 -> V=1.0, theta=0.0
% INFO    : Bus 840	: V=1.006753, theta=-20.322256 -> V=1.0, theta=0.0
% INFO    : Bus 841	: V=1.036065, theta=-16.582357 -> V=1.0, theta=0.0
% INFO    : Bus 842	: V=1.070032, theta=58.678343 -> V=1.0, theta=0.0
% INFO    : Bus 843	: V=1.019188, theta=45.616813 -> V=1.0, theta=0.0
% INFO    : Bus 844	: V=1.059427, theta=39.6916 -> V=1.0, theta=0.0
% INFO    : Bus 845	: V=1.059427, theta=39.6916 -> V=1.0, theta=0.0
% INFO    : Bus 846	: V=1.059427, theta=39.6916 -> V=1.0, theta=0.0
% INFO    : Bus 847	: V=1.00721, theta=-24.676363 -> V=1.0, theta=0.0
% INFO    : Bus 848	: V=0.984773, theta=-5.596227 -> V=1.0, theta=0.0
% INFO    : Bus 849	: V=1.028153, theta=78.700831 -> V=1.0, theta=0.0
% INFO    : Bus 850	: V=1.158733, theta=0.598452 -> V=1.0, theta=0.0
% INFO    : Bus 851	: V=1.033793, theta=0.608319 -> V=1.0, theta=0.0
% INFO    : Bus 852	: V=1.03046, theta=8.194629 -> V=1.0, theta=0.0
% INFO    : Bus 853	: V=1.093065, theta=68.734796 -> V=1.0, theta=0.0
% INFO    : Bus 854	: V=1.01458, theta=31.505458 -> V=1.0, theta=0.0
% INFO    : Bus 855	: V=1.046298, theta=0.868346 -> V=1.0, theta=0.0
% INFO    : Bus 856	: V=1.019323, theta=-2.576944 -> V=1.0, theta=0.0
% INFO    : Bus 857	: V=1.039468, theta=26.93922 -> V=1.0, theta=0.0
% INFO    : Bus 858	: V=1.021858, theta=-2.534901 -> V=1.0, theta=0.0
% INFO    : Bus 859	: V=1.037973, theta=11.471538 -> V=1.0, theta=0.0
% INFO    : Bus 860	: V=0.991857, theta=-3.017578 -> V=1.0, theta=0.0
% INFO    : Bus 861	: V=1.018125, theta=-0.191544 -> V=1.0, theta=0.0
% INFO    : Bus 862	: V=1.018125, theta=-0.191544 -> V=1.0, theta=0.0
% INFO    : Bus 863	: V=1.04402, theta=-4.498864 -> V=1.0, theta=0.0
% INFO    : Bus 864	: V=1.018125, theta=-0.191544 -> V=1.0, theta=0.0
% INFO    : Bus 865	: V=1.018125, theta=-0.191544 -> V=1.0, theta=0.0
% INFO    : Bus 866	: V=1.060805, theta=81.893945 -> V=1.0, theta=0.0
% INFO    : Bus 867	: V=0.987063, theta=-10.738282 -> V=1.0, theta=0.0
% INFO    : Bus 868	: V=0.977307, theta=-6.322138 -> V=1.0, theta=0.0
% INFO    : Bus 869	: V=1.0326, theta=4.106738 -> V=1.0, theta=0.0
% INFO    : Bus 870	: V=0.995628, theta=27.676458 -> V=1.0, theta=0.0
% INFO    : Bus 871	: V=1.054603, theta=34.712387 -> V=1.0, theta=0.0
% INFO    : Bus 872	: V=1.013659, theta=21.90913 -> V=1.0, theta=0.0
% INFO    : Bus 873	: V=0.994173, theta=92.075115 -> V=1.0, theta=0.0
% INFO    : Bus 874	: V=1.006137, theta=-0.690843 -> V=1.0, theta=0.0
% INFO    : Bus 875	: V=1.014427, theta=-23.263068 -> V=1.0, theta=0.0
% INFO    : Bus 876	: V=0.999588, theta=10.969176 -> V=1.0, theta=0.0
% INFO    : Bus 877	: V=1.03178, theta=-20.492791 -> V=1.0, theta=0.0
% INFO    : Bus 878	: V=0.99162, theta=-5.359677 -> V=1.0, theta=0.0
% INFO    : Bus 879	: V=0.984454, theta=4.505019 -> V=1.0, theta=0.0
% INFO    : Bus 880	: V=1.011853, theta=29.867832 -> V=1.0, theta=0.0
% INFO    : Bus 881	: V=1.019436, theta=14.909228 -> V=1.0, theta=0.0
% INFO    : Bus 882	: V=1.031652, theta=-19.696271 -> V=1.0, theta=0.0
% INFO    : Bus 883	: V=1.084383, theta=6.111699 -> V=1.0, theta=0.0
% INFO    : Bus 884	: V=1.132703, theta=1.05655 -> V=1.0, theta=0.0
% INFO    : Bus 885	: V=0.990361, theta=17.913132 -> V=1.0, theta=0.0
% INFO    : Bus 886	: V=1.002846, theta=19.38659 -> V=1.0, theta=0.0
% INFO    : Bus 887	: V=1.026473, theta=48.956035 -> V=1.0, theta=0.0
% INFO    : Bus 888	: V=1.055337, theta=0.681282 -> V=1.0, theta=0.0
% INFO    : Bus 889	: V=1.063608, theta=-3.825825 -> V=1.0, theta=0.0
% INFO    : Bus 890	: V=1.014413, theta=14.29141 -> V=1.0, theta=0.0
% INFO    : Bus 891	: V=0.973214, theta=-28.659481 -> V=1.0, theta=0.0
% INFO    : Bus 892	: V=1.004579, theta=18.223427 -> V=1.0, theta=0.0
% INFO    : Bus 893	: V=1.017581, theta=-1.849378 -> V=1.0, theta=0.0
% INFO    : Bus 894	: V=1.034239, theta=9.365432 -> V=1.0, theta=0.0
% INFO    : Bus 895	: V=0.966895, theta=-14.773838 -> V=1.0, theta=0.0
% INFO    : Bus 896	: V=1.061137, theta=18.700301 -> V=1.0, theta=0.0
% INFO    : Bus 897	: V=1.027683, theta=16.404202 -> V=1.0, theta=0.0
% INFO    : Bus 898	: V=1.058434, theta=6.52887 -> V=1.0, theta=0.0
% INFO    : Bus 899	: V=0.98985, theta=-3.297046 -> V=1.0, theta=0.0
% INFO    : Bus 900	: V=1.015391, theta=-21.569641 -> V=1.0, theta=0.0
% INFO    : Bus 901	: V=1.00657, theta=25.464337 -> V=1.0, theta=0.0
% INFO    : Bus 902	: V=1.03356, theta=4.612966 -> V=1.0, theta=0.0
% INFO    : Bus 903	: V=0.995983, theta=3.433584 -> V=1.0, theta=0.0
% INFO    : Bus 904	: V=1.028707, theta=4.250081 -> V=1.0, theta=0.0
% INFO    : Bus 905	: V=1.004501, theta=-24.623949 -> V=1.0, theta=0.0
% INFO    : Bus 906	: V=1.065604, theta=86.499709 -> V=1.0, theta=0.0
% INFO    : Bus 907	: V=1.028707, theta=4.250081 -> V=1.0, theta=0.0
% INFO    : Bus 908	: V=0.988945, theta=27.024845 -> V=1.0, theta=0.0
% INFO    : Bus 909	: V=1.019902, theta=16.981536 -> V=1.0, theta=0.0
% INFO    : Bus 910	: V=1.127961, theta=6.657565 -> V=1.0, theta=0.0
% INFO    : Bus 911	: V=0.936045, theta=-11.578054 -> V=1.0, theta=0.0
% INFO    : Bus 912	: V=1.015029, theta=3.043049 -> V=1.0, theta=0.0
% INFO    : Bus 913	: V=0.970063, theta=-11.531386 -> V=1.0, theta=0.0
% INFO    : Bus 914	: V=1.002176, theta=-13.481147 -> V=1.0, theta=0.0
% INFO    : Bus 915	: V=0.977393, theta=-7.174319 -> V=1.0, theta=0.0
% INFO    : Bus 916	: V=0.957523, theta=42.691932 -> V=1.0, theta=0.0
% INFO    : Bus 917	: V=1.061641, theta=9.414892 -> V=1.0, theta=0.0
% INFO    : Bus 918	: V=0.999527, theta=26.548017 -> V=1.0, theta=0.0
% INFO    : Bus 919	: V=1.022407, theta=34.785858 -> V=1.0, theta=0.0
% INFO    : Bus 920	: V=1.015029, theta=3.043049 -> V=1.0, theta=0.0
% INFO    : Bus 921	: V=1.018066, theta=-18.544118 -> V=1.0, theta=0.0
% INFO    : Bus 922	: V=0.996132, theta=-1.925907 -> V=1.0, theta=0.0
% INFO    : Bus 923	: V=1.094819, theta=-4.683784 -> V=1.0, theta=0.0
% INFO    : Bus 924	: V=0.975171, theta=15.860336 -> V=1.0, theta=0.0
% INFO    : Bus 925	: V=1.032265, theta=43.171125 -> V=1.0, theta=0.0
% INFO    : Bus 926	: V=1.005341, theta=-1.941399 -> V=1.0, theta=0.0
% INFO    : Bus 927	: V=1.007757, theta=23.409003 -> V=1.0, theta=0.0
% INFO    : Bus 928	: V=1.075021, theta=46.081147 -> V=1.0, theta=0.0
% INFO    : Bus 929	: V=1.033176, theta=-1.797358 -> V=1.0, theta=0.0
% INFO    : Bus 930	: V=1.015029, theta=3.043049 -> V=1.0, theta=0.0
% INFO    : Bus 931	: V=0.993788, theta=43.151154 -> V=1.0, theta=0.0
% INFO    : Bus 932	: V=1.023156, theta=37.450201 -> V=1.0, theta=0.0
% INFO    : Bus 933	: V=1.035445, theta=41.576564 -> V=1.0, theta=0.0
% INFO    : Bus 934	: V=0.99149, theta=-2.552543 -> V=1.0, theta=0.0
% INFO    : Bus 935	: V=1.014305, theta=63.297249 -> V=1.0, theta=0.0
% INFO    : Bus 936	: V=1.009981, theta=13.559945 -> V=1.0, theta=0.0
% INFO    : Bus 937	: V=1.026822, theta=-0.476726 -> V=1.0, theta=0.0
% INFO    : Bus 938	: V=1.019144, theta=17.562907 -> V=1.0, theta=0.0
% INFO    : Bus 939	: V=1.027438, theta=24.929731 -> V=1.0, theta=0.0
% INFO    : Bus 940	: V=0.981378, theta=4.54737 -> V=1.0, theta=0.0
% INFO    : Bus 941	: V=1.007452, theta=18.316005 -> V=1.0, theta=0.0
% INFO    : Bus 942	: V=1.009333, theta=-1.804582 -> V=1.0, theta=0.0
% INFO    : Bus 943	: V=1.05086, theta=0.067818 -> V=1.0, theta=0.0
% INFO    : Bus 944	: V=0.996221, theta=91.123997 -> V=1.0, theta=0.0
% INFO    : Bus 945	: V=1.03579, theta=79.927541 -> V=1.0, theta=0.0
% INFO    : Bus 946	: V=1.030451, theta=-20.972645 -> V=1.0, theta=0.0
% INFO    : Bus 947	: V=1.021721, theta=42.723795 -> V=1.0, theta=0.0
% INFO    : Bus 948	: V=1.00207, theta=91.511646 -> V=1.0, theta=0.0
% INFO    : Bus 949	: V=1.020449, theta=16.959464 -> V=1.0, theta=0.0
% INFO    : Bus 950	: V=1.008763, theta=4.218298 -> V=1.0, theta=0.0
% INFO    : Bus 951	: V=0.983636, theta=43.579066 -> V=1.0, theta=0.0
% INFO    : Bus 952	: V=1.016274, theta=49.480744 -> V=1.0, theta=0.0
% INFO    : Bus 953	: V=1.022132, theta=3.908599 -> V=1.0, theta=0.0
% INFO    : Bus 954	: V=0.961175, theta=47.68032 -> V=1.0, theta=0.0
% INFO    : Bus 955	: V=1.042596, theta=13.310389 -> V=1.0, theta=0.0
% INFO    : Bus 956	: V=1.044097, theta=40.791392 -> V=1.0, theta=0.0
% INFO    : Bus 957	: V=1.020566, theta=-15.909789 -> V=1.0, theta=0.0
% INFO    : Bus 958	: V=1.016735, theta=24.349916 -> V=1.0, theta=0.0
% INFO    : Bus 959	: V=1.005259, theta=33.167214 -> V=1.0, theta=0.0
% INFO    : Bus 960	: V=1.016898, theta=-5.759659 -> V=1.0, theta=0.0
% INFO    : Bus 961	: V=1.026224, theta=11.981429 -> V=1.0, theta=0.0
% INFO    : Bus 962	: V=1.044446, theta=35.667348 -> V=1.0, theta=0.0
% INFO    : Bus 963	: V=0.986552, theta=-16.814946 -> V=1.0, theta=0.0
% INFO    : Bus 964	: V=1.032136, theta=55.592104 -> V=1.0, theta=0.0
% INFO    : Bus 965	: V=1.040995, theta=33.204924 -> V=1.0, theta=0.0
% INFO    : Bus 966	: V=1.050778, theta=5.142571 -> V=1.0, theta=0.0
% INFO    : Bus 967	: V=0.984956, theta=-5.174055 -> V=1.0, theta=0.0
% INFO    : Bus 968	: V=0.989399, theta=-5.35447 -> V=1.0, theta=0.0
% INFO    : Bus 969	: V=1.029744, theta=-0.176276 -> V=1.0, theta=0.0
% INFO    : Bus 970	: V=1.035791, theta=23.926406 -> V=1.0, theta=0.0
% INFO    : Bus 971	: V=1.021972, theta=-27.551339 -> V=1.0, theta=0.0
% INFO    : Bus 972	: V=0.977721, theta=20.997949 -> V=1.0, theta=0.0
% INFO    : Bus 973	: V=1.035607, theta=-8.450105 -> V=1.0, theta=0.0
% INFO    : Bus 974	: V=1.01079, theta=-5.231958 -> V=1.0, theta=0.0
% INFO    : Bus 975	: V=1.042545, theta=18.989939 -> V=1.0, theta=0.0
% INFO    : Bus 976	: V=1.070058, theta=2.935613 -> V=1.0, theta=0.0
% INFO    : Bus 977	: V=1.070058, theta=2.935613 -> V=1.0, theta=0.0
% INFO    : Bus 978	: V=1.070058, theta=2.935613 -> V=1.0, theta=0.0
% INFO    : Bus 979	: V=1.032776, theta=38.238973 -> V=1.0, theta=0.0
% INFO    : Bus 980	: V=1.023796, theta=19.440568 -> V=1.0, theta=0.0
% INFO    : Bus 981	: V=1.018701, theta=14.159627 -> V=1.0, theta=0.0
% INFO    : Bus 982	: V=1.018701, theta=14.159627 -> V=1.0, theta=0.0
% INFO    : Bus 983	: V=1.018701, theta=14.159627 -> V=1.0, theta=0.0
% INFO    : Bus 984	: V=1.050192, theta=6.863532 -> V=1.0, theta=0.0
% INFO    : Bus 985	: V=1.050192, theta=6.863532 -> V=1.0, theta=0.0
% INFO    : Bus 986	: V=1.050192, theta=6.863532 -> V=1.0, theta=0.0
% INFO    : Bus 987	: V=1.050192, theta=6.863532 -> V=1.0, theta=0.0
% INFO    : Bus 988	: V=1.026665, theta=32.869784 -> V=1.0, theta=0.0
% INFO    : Bus 989	: V=0.996033, theta=-7.242929 -> V=1.0, theta=0.0
% INFO    : Bus 990	: V=0.964816, theta=9.741815 -> V=1.0, theta=0.0
% INFO    : Bus 991	: V=1.029738, theta=9.51492 -> V=1.0, theta=0.0
% INFO    : Bus 992	: V=1.035723, theta=34.688997 -> V=1.0, theta=0.0
% INFO    : Bus 993	: V=1.045616, theta=-9.82138 -> V=1.0, theta=0.0
% INFO    : Bus 994	: V=1.031548, theta=18.747231 -> V=1.0, theta=0.0
% INFO    : Bus 995	: V=1.028283, theta=16.586422 -> V=1.0, theta=0.0
% INFO    : Bus 996	: V=0.987703, theta=34.817014 -> V=1.0, theta=0.0
% INFO    : Bus 997	: V=0.981668, theta=-22.889071 -> V=1.0, theta=0.0
% INFO    : Bus 998	: V=1.034713, theta=19.620965 -> V=1.0, theta=0.0
% INFO    : Bus 999	: V=1.012803, theta=-19.145251 -> V=1.0, theta=0.0
% INFO    : Bus 1000	: V=1.052691, theta=28.640951 -> V=1.0, theta=0.0
% INFO    : Bus 1001	: V=1.018883, theta=4.573924 -> V=1.0, theta=0.0
% INFO    : Bus 1002	: V=1.026117, theta=25.086822 -> V=1.0, theta=0.0
% INFO    : Bus 1003	: V=1.008785, theta=-5.83331 -> V=1.0, theta=0.0
% INFO    : Bus 1004	: V=1.020732, theta=7.56493 -> V=1.0, theta=0.0
% INFO    : Bus 1005	: V=0.955499, theta=-2.810333 -> V=1.0, theta=0.0
% INFO    : Bus 1006	: V=0.994079, theta=27.998088 -> V=1.0, theta=0.0
% INFO    : Bus 1007	: V=1.009902, theta=7.124298 -> V=1.0, theta=0.0
% INFO    : Bus 1008	: V=1.053245, theta=-7.911014 -> V=1.0, theta=0.0
% INFO    : Bus 1009	: V=1.049527, theta=-12.606328 -> V=1.0, theta=0.0
% INFO    : Bus 1010	: V=0.962614, theta=39.578299 -> V=1.0, theta=0.0
% INFO    : Bus 1011	: V=1.015816, theta=0.326553 -> V=1.0, theta=0.0
% INFO    : Bus 1012	: V=1.001313, theta=-10.409452 -> V=1.0, theta=0.0
% INFO    : Bus 1013	: V=1.001252, theta=-14.682022 -> V=1.0, theta=0.0
% INFO    : Bus 1014	: V=1.059988, theta=0.149576 -> V=1.0, theta=0.0
% INFO    : Bus 1015	: V=1.027137, theta=-6.465563 -> V=1.0, theta=0.0
% INFO    : Bus 1016	: V=0.995069, theta=-1.871876 -> V=1.0, theta=0.0
% INFO    : Bus 1017	: V=1.022632, theta=4.381728 -> V=1.0, theta=0.0
% INFO    : Bus 1018	: V=1.026849, theta=-25.366304 -> V=1.0, theta=0.0
% INFO    : Bus 1019	: V=1.038108, theta=3.293597 -> V=1.0, theta=0.0
% INFO    : Bus 1020	: V=0.967495, theta=-6.844112 -> V=1.0, theta=0.0
% INFO    : Bus 1021	: V=0.97453, theta=-11.79808 -> V=1.0, theta=0.0
% INFO    : Bus 1022	: V=0.99761, theta=-7.841022 -> V=1.0, theta=0.0
% INFO    : Bus 1023	: V=1.122861, theta=-0.191999 -> V=1.0, theta=0.0
% INFO    : Bus 1024	: V=1.043672, theta=13.295119 -> V=1.0, theta=0.0
% INFO    : Bus 1025	: V=1.028176, theta=19.200425 -> V=1.0, theta=0.0
% INFO    : Bus 1026	: V=1.007223, theta=-16.523743 -> V=1.0, theta=0.0
% INFO    : Bus 1027	: V=1.062394, theta=3.693466 -> V=1.0, theta=0.0
% INFO    : Bus 1028	: V=0.984812, theta=-23.030576 -> V=1.0, theta=0.0
% INFO    : Bus 1029	: V=1.058308, theta=-14.57333 -> V=1.0, theta=0.0
% INFO    : Bus 1030	: V=1.022228, theta=-17.722424 -> V=1.0, theta=0.0
% INFO    : Bus 1031	: V=1.050891, theta=3.953704 -> V=1.0, theta=0.0
% INFO    : Bus 1032	: V=1.050032, theta=25.624075 -> V=1.0, theta=0.0
% INFO    : Bus 1033	: V=0.990296, theta=27.156206 -> V=1.0, theta=0.0
% INFO    : Bus 1034	: V=0.993023, theta=13.966977 -> V=1.0, theta=0.0
% INFO    : Bus 1035	: V=1.058705, theta=18.398371 -> V=1.0, theta=0.0
% INFO    : Bus 1036	: V=0.981526, theta=32.68627 -> V=1.0, theta=0.0
% INFO    : Bus 1037	: V=1.014304, theta=-3.233621 -> V=1.0, theta=0.0
% INFO    : Bus 1038	: V=1.013009, theta=-1.260469 -> V=1.0, theta=0.0
% INFO    : Bus 1039	: V=1.025298, theta=4.11833 -> V=1.0, theta=0.0
% INFO    : Bus 1040	: V=1.058232, theta=-0.595237 -> V=1.0, theta=0.0
% INFO    : Bus 1041	: V=0.922503, theta=1.030887 -> V=1.0, theta=0.0
% INFO    : Bus 1042	: V=1.026918, theta=3.536883 -> V=1.0, theta=0.0
% INFO    : Bus 1043	: V=1.010998, theta=1.300317 -> V=1.0, theta=0.0
% INFO    : Bus 1044	: V=1.019396, theta=-15.910525 -> V=1.0, theta=0.0
% INFO    : Bus 1045	: V=1.015757, theta=-19.850393 -> V=1.0, theta=0.0
% INFO    : Bus 1046	: V=1.014635, theta=-15.220088 -> V=1.0, theta=0.0
% INFO    : Bus 1047	: V=1.030726, theta=27.099334 -> V=1.0, theta=0.0
% INFO    : Bus 1048	: V=1.024095, theta=1.173322 -> V=1.0, theta=0.0
% INFO    : Bus 1049	: V=0.999693, theta=30.670692 -> V=1.0, theta=0.0
% INFO    : Bus 1050	: V=1.048227, theta=33.464235 -> V=1.0, theta=0.0
% INFO    : Bus 1051	: V=0.990482, theta=-14.344882 -> V=1.0, theta=0.0
% INFO    : Bus 1052	: V=1.126918, theta=-1.53611 -> V=1.0, theta=0.0
% INFO    : Bus 1053	: V=1.043296, theta=27.768258 -> V=1.0, theta=0.0
% INFO    : Bus 1054	: V=1.120384, theta=9.693407 -> V=1.0, theta=0.0
% INFO    : Bus 1055	: V=1.043492, theta=-15.322718 -> V=1.0, theta=0.0
% INFO    : Bus 1056	: V=0.995341, theta=38.515307 -> V=1.0, theta=0.0
% INFO    : Bus 1057	: V=1.055479, theta=63.485669 -> V=1.0, theta=0.0
% INFO    : Bus 1058	: V=0.988428, theta=-15.328352 -> V=1.0, theta=0.0
% INFO    : Bus 1059	: V=0.98379, theta=29.90696 -> V=1.0, theta=0.0
% INFO    : Bus 1060	: V=1.017165, theta=-22.642005 -> V=1.0, theta=0.0
% INFO    : Bus 1061	: V=1.028126, theta=44.738341 -> V=1.0, theta=0.0
% INFO    : Bus 1062	: V=1.006682, theta=35.480523 -> V=1.0, theta=0.0
% INFO    : Bus 1063	: V=1.022947, theta=24.940474 -> V=1.0, theta=0.0
% INFO    : Bus 1064	: V=0.997082, theta=42.307024 -> V=1.0, theta=0.0
% INFO    : Bus 1065	: V=0.988217, theta=88.927697 -> V=1.0, theta=0.0
% INFO    : Bus 1066	: V=0.99727, theta=-6.171382 -> V=1.0, theta=0.0
% INFO    : Bus 1067	: V=0.996576, theta=-13.394939 -> V=1.0, theta=0.0
% INFO    : Bus 1068	: V=1.032844, theta=-14.822365 -> V=1.0, theta=0.0
% INFO    : Bus 1069	: V=1.009755, theta=-7.535974 -> V=1.0, theta=0.0
% INFO    : Bus 1070	: V=1.01964, theta=-10.829105 -> V=1.0, theta=0.0
% INFO    : Bus 1071	: V=1.031397, theta=6.88995 -> V=1.0, theta=0.0
% INFO    : Bus 1072	: V=1.065506, theta=1.014062 -> V=1.0, theta=0.0
% INFO    : Bus 1073	: V=1.037189, theta=3.219879 -> V=1.0, theta=0.0
% INFO    : Bus 1074	: V=1.061099, theta=-1.375053 -> V=1.0, theta=0.0
% INFO    : Bus 1075	: V=1.05286, theta=28.639443 -> V=1.0, theta=0.0
% INFO    : Bus 1076	: V=1.044639, theta=-4.02157 -> V=1.0, theta=0.0
% INFO    : Bus 1077	: V=1.015556, theta=16.601372 -> V=1.0, theta=0.0
% INFO    : Bus 1078	: V=1.036704, theta=0.145279 -> V=1.0, theta=0.0
% INFO    : Bus 1079	: V=1.037501, theta=2.321125 -> V=1.0, theta=0.0
% INFO    : Bus 1080	: V=0.994214, theta=15.255805 -> V=1.0, theta=0.0
% INFO    : Bus 1081	: V=0.953342, theta=-6.246594 -> V=1.0, theta=0.0
% INFO    : Bus 1082	: V=1.02325, theta=3.383664 -> V=1.0, theta=0.0
% INFO    : Bus 1083	: V=1.035499, theta=26.862046 -> V=1.0, theta=0.0
% INFO    : Bus 1084	: V=1.045184, theta=-18.36115 -> V=1.0, theta=0.0
% INFO    : Bus 1085	: V=0.98883, theta=21.250891 -> V=1.0, theta=0.0
% INFO    : Bus 1086	: V=1.064193, theta=2.672742 -> V=1.0, theta=0.0
% INFO    : Bus 1087	: V=1.027715, theta=5.739639 -> V=1.0, theta=0.0
% INFO    : Bus 1088	: V=1.015045, theta=0.518146 -> V=1.0, theta=0.0
% INFO    : Bus 1089	: V=1.039754, theta=25.994186 -> V=1.0, theta=0.0
% INFO    : Bus 1090	: V=1.026413, theta=2.766853 -> V=1.0, theta=0.0
% INFO    : Bus 1091	: V=0.920705, theta=-7.854239 -> V=1.0, theta=0.0
% INFO    : Bus 1092	: V=1.039754, theta=25.994186 -> V=1.0, theta=0.0
% INFO    : Bus 1093	: V=1.039754, theta=25.994186 -> V=1.0, theta=0.0
% INFO    : Bus 1094	: V=1.021323, theta=0.157034 -> V=1.0, theta=0.0
% INFO    : Bus 1095	: V=0.996303, theta=-3.626208 -> V=1.0, theta=0.0
% INFO    : Bus 1096	: V=1.030566, theta=-6.658147 -> V=1.0, theta=0.0
% INFO    : Bus 1097	: V=1.027843, theta=-17.473372 -> V=1.0, theta=0.0
% INFO    : Bus 1098	: V=1.017668, theta=17.689564 -> V=1.0, theta=0.0
% INFO    : Bus 1099	: V=0.989962, theta=5.425776 -> V=1.0, theta=0.0
% INFO    : Bus 1100	: V=1.013156, theta=16.173778 -> V=1.0, theta=0.0
% INFO    : Bus 1101	: V=0.970954, theta=-14.134822 -> V=1.0, theta=0.0
% INFO    : Bus 1102	: V=1.012771, theta=10.113246 -> V=1.0, theta=0.0
% INFO    : Bus 1103	: V=1.033938, theta=7.498563 -> V=1.0, theta=0.0
% INFO    : Bus 1104	: V=1.043492, theta=-15.322718 -> V=1.0, theta=0.0
% INFO    : Bus 1105	: V=1.051619, theta=-6.41508 -> V=1.0, theta=0.0
% INFO    : Bus 1106	: V=1.030345, theta=-0.824449 -> V=1.0, theta=0.0
% INFO    : Bus 1107	: V=1.027071, theta=22.872057 -> V=1.0, theta=0.0
% INFO    : Bus 1108	: V=1.003921, theta=-2.768952 -> V=1.0, theta=0.0
% INFO    : Bus 1109	: V=0.988123, theta=9.386666 -> V=1.0, theta=0.0
% INFO    : Bus 1110	: V=0.92416, theta=-12.234897 -> V=1.0, theta=0.0
% INFO    : Bus 1111	: V=1.000291, theta=0.966435 -> V=1.0, theta=0.0
% INFO    : Bus 1112	: V=1.013882, theta=44.861905 -> V=1.0, theta=0.0
% INFO    : Bus 1113	: V=1.016356, theta=21.039881 -> V=1.0, theta=0.0
% INFO    : Bus 1114	: V=1.02902, theta=25.380845 -> V=1.0, theta=0.0
% INFO    : Bus 1115	: V=1.004379, theta=-14.102643 -> V=1.0, theta=0.0
% INFO    : Bus 1116	: V=1.022419, theta=14.92737 -> V=1.0, theta=0.0
% INFO    : Bus 1117	: V=1.020247, theta=-15.259037 -> V=1.0, theta=0.0
% INFO    : Bus 1118	: V=0.982088, theta=1.918784 -> V=1.0, theta=0.0
% INFO    : Bus 1119	: V=1.030206, theta=34.64258 -> V=1.0, theta=0.0
% INFO    : Bus 1120	: V=1.025958, theta=34.069666 -> V=1.0, theta=0.0
% INFO    : Bus 1121	: V=0.987687, theta=2.389894 -> V=1.0, theta=0.0
% INFO    : Bus 1122	: V=1.002251, theta=15.884286 -> V=1.0, theta=0.0
% INFO    : Bus 1123	: V=1.038747, theta=-8.642337 -> V=1.0, theta=0.0
% INFO    : Bus 1124	: V=1.029801, theta=7.874787 -> V=1.0, theta=0.0
% INFO    : Bus 1125	: V=1.018739, theta=-6.896129 -> V=1.0, theta=0.0
% INFO    : Bus 1126	: V=1.016001, theta=22.347716 -> V=1.0, theta=0.0
% INFO    : Bus 1127	: V=1.059631, theta=33.365886 -> V=1.0, theta=0.0
% INFO    : Bus 1128	: V=1.036479, theta=43.646869 -> V=1.0, theta=0.0
% INFO    : Bus 1129	: V=0.996569, theta=-17.371589 -> V=1.0, theta=0.0
% INFO    : Bus 1130	: V=0.988367, theta=-17.850399 -> V=1.0, theta=0.0
% INFO    : Bus 1131	: V=1.022658, theta=8.751926 -> V=1.0, theta=0.0
% INFO    : Bus 1132	: V=0.986182, theta=-8.108772 -> V=1.0, theta=0.0
% INFO    : Bus 1133	: V=1.033532, theta=31.669766 -> V=1.0, theta=0.0
% INFO    : Bus 1134	: V=1.02575, theta=-6.012669 -> V=1.0, theta=0.0
% INFO    : Bus 1135	: V=1.049746, theta=7.525607 -> V=1.0, theta=0.0
% INFO    : Bus 1136	: V=0.979901, theta=31.362904 -> V=1.0, theta=0.0
% INFO    : Bus 1137	: V=0.950327, theta=-6.911106 -> V=1.0, theta=0.0
% INFO    : Bus 1138	: V=0.971901, theta=45.235162 -> V=1.0, theta=0.0
% INFO    : Bus 1139	: V=1.044684, theta=23.296473 -> V=1.0, theta=0.0
% INFO    : Bus 1140	: V=1.01876, theta=2.813545 -> V=1.0, theta=0.0
% INFO    : Bus 1141	: V=1.054949, theta=20.005722 -> V=1.0, theta=0.0
% INFO    : Bus 1142	: V=1.053847, theta=28.546328 -> V=1.0, theta=0.0
% INFO    : Bus 1143	: V=0.993025, theta=40.432571 -> V=1.0, theta=0.0
% INFO    : Bus 1144	: V=0.982128, theta=10.906524 -> V=1.0, theta=0.0
% INFO    : Bus 1145	: V=1.021827, theta=60.814659 -> V=1.0, theta=0.0
% INFO    : Bus 1146	: V=1.004752, theta=-16.633178 -> V=1.0, theta=0.0
% INFO    : Bus 1147	: V=1.007501, theta=-12.066805 -> V=1.0, theta=0.0
% INFO    : Bus 1148	: V=1.020087, theta=-16.009175 -> V=1.0, theta=0.0
% INFO    : Bus 1149	: V=1.004523, theta=39.504964 -> V=1.0, theta=0.0
% INFO    : Bus 1150	: V=0.970854, theta=29.381452 -> V=1.0, theta=0.0
% INFO    : Bus 1151	: V=0.957655, theta=-8.78103 -> V=1.0, theta=0.0
% INFO    : Bus 1152	: V=1.028416, theta=4.295836 -> V=1.0, theta=0.0
% INFO    : Bus 1153	: V=1.037027, theta=21.722482 -> V=1.0, theta=0.0
% INFO    : Bus 1154	: V=0.98901, theta=-3.370618 -> V=1.0, theta=0.0
% INFO    : Bus 1155	: V=1.016314, theta=33.74591 -> V=1.0, theta=0.0
% INFO    : Bus 1156	: V=1.053231, theta=-10.776146 -> V=1.0, theta=0.0
% INFO    : Bus 1157	: V=1.012197, theta=-23.005874 -> V=1.0, theta=0.0
% INFO    : Bus 1158	: V=1.030199, theta=31.958924 -> V=1.0, theta=0.0
% INFO    : Bus 1159	: V=1.017792, theta=-5.319138 -> V=1.0, theta=0.0
% INFO    : Bus 1160	: V=1.01649, theta=6.344203 -> V=1.0, theta=0.0
% INFO    : Bus 1161	: V=1.033769, theta=4.919429 -> V=1.0, theta=0.0
% INFO    : Bus 1162	: V=1.068779, theta=5.406898 -> V=1.0, theta=0.0
% INFO    : Bus 1163	: V=1.009126, theta=-23.142825 -> V=1.0, theta=0.0
% INFO    : Bus 1164	: V=1.069974, theta=3.588654 -> V=1.0, theta=0.0
% INFO    : Bus 1165	: V=1.049403, theta=-6.829279 -> V=1.0, theta=0.0
% INFO    : Bus 1166	: V=0.996409, theta=-17.049556 -> V=1.0, theta=0.0
% INFO    : Bus 1167	: V=1.033993, theta=79.013264 -> V=1.0, theta=0.0
% INFO    : Bus 1168	: V=1.040321, theta=28.79688 -> V=1.0, theta=0.0
% INFO    : Bus 1169	: V=1.005897, theta=24.832965 -> V=1.0, theta=0.0
% INFO    : Bus 1170	: V=1.020687, theta=4.488546 -> V=1.0, theta=0.0
% INFO    : Bus 1171	: V=1.099354, theta=-14.35941 -> V=1.0, theta=0.0
% INFO    : Bus 1172	: V=1.025808, theta=70.814725 -> V=1.0, theta=0.0
% INFO    : Bus 1173	: V=1.04707, theta=28.776876 -> V=1.0, theta=0.0
% INFO    : Bus 1174	: V=0.998348, theta=22.168889 -> V=1.0, theta=0.0
% INFO    : Bus 1175	: V=0.999171, theta=-8.851257 -> V=1.0, theta=0.0
% INFO    : Bus 1176	: V=1.017158, theta=-5.196209 -> V=1.0, theta=0.0
% INFO    : Bus 1177	: V=1.00878, theta=14.885564 -> V=1.0, theta=0.0
% INFO    : Bus 1178	: V=1.003491, theta=27.632662 -> V=1.0, theta=0.0
% INFO    : Bus 1179	: V=1.010326, theta=40.703694 -> V=1.0, theta=0.0
% INFO    : Bus 1180	: V=0.999061, theta=42.441878 -> V=1.0, theta=0.0
% INFO    : Bus 1181	: V=0.999224, theta=-22.970532 -> V=1.0, theta=0.0
% INFO    : Bus 1182	: V=1.056688, theta=67.221009 -> V=1.0, theta=0.0
% INFO    : Bus 1183	: V=1.056688, theta=67.221009 -> V=1.0, theta=0.0
% INFO    : Bus 1184	: V=1.037346, theta=-2.833684 -> V=1.0, theta=0.0
% INFO    : Bus 1185	: V=1.011067, theta=18.293892 -> V=1.0, theta=0.0
% INFO    : Bus 1186	: V=0.985304, theta=-3.668301 -> V=1.0, theta=0.0
% INFO    : Bus 1187	: V=0.996718, theta=2.387562 -> V=1.0, theta=0.0
% INFO    : Bus 1188	: V=1.010639, theta=-8.661899 -> V=1.0, theta=0.0
% INFO    : Bus 1189	: V=1.029009, theta=32.575777 -> V=1.0, theta=0.0
% INFO    : Bus 1190	: V=1.025637, theta=30.618892 -> V=1.0, theta=0.0
% INFO    : Bus 1191	: V=1.026575, theta=-1.348248 -> V=1.0, theta=0.0
% INFO    : Bus 1192	: V=1.035838, theta=-5.172678 -> V=1.0, theta=0.0
% INFO    : Bus 1193	: V=1.080724, theta=1.741895 -> V=1.0, theta=0.0
% INFO    : Bus 1194	: V=1.017625, theta=5.374756 -> V=1.0, theta=0.0
% INFO    : Bus 1195	: V=1.022798, theta=25.191563 -> V=1.0, theta=0.0
% INFO    : Bus 1196	: V=0.994841, theta=-14.026789 -> V=1.0, theta=0.0
% INFO    : Bus 1197	: V=1.057724, theta=18.27348 -> V=1.0, theta=0.0
% INFO    : Bus 1198	: V=1.008562, theta=-8.919415 -> V=1.0, theta=0.0
% INFO    : Bus 1199	: V=1.055006, theta=11.790162 -> V=1.0, theta=0.0
% INFO    : Bus 1200	: V=0.987606, theta=46.494111 -> V=1.0, theta=0.0
% INFO    : Bus 1201	: V=0.993849, theta=89.074217 -> V=1.0, theta=0.0
% INFO    : Bus 1202	: V=1.045213, theta=9.250128 -> V=1.0, theta=0.0
% INFO    : Bus 1203	: V=1.031185, theta=-14.185965 -> V=1.0, theta=0.0
% INFO    : Bus 1204	: V=1.012343, theta=31.295134 -> V=1.0, theta=0.0
% INFO    : Bus 1205	: V=0.955981, theta=-5.03467 -> V=1.0, theta=0.0
% INFO    : Bus 1206	: V=0.979015, theta=11.019297 -> V=1.0, theta=0.0
% INFO    : Bus 1207	: V=1.034431, theta=-1.078525 -> V=1.0, theta=0.0
% INFO    : Bus 1208	: V=1.010291, theta=28.950447 -> V=1.0, theta=0.0
% INFO    : Bus 1209	: V=1.021946, theta=16.613523 -> V=1.0, theta=0.0
% INFO    : Bus 1210	: V=1.014877, theta=-26.886832 -> V=1.0, theta=0.0
% INFO    : Bus 1211	: V=0.999457, theta=-8.828526 -> V=1.0, theta=0.0
% INFO    : Bus 1212	: V=0.979058, theta=89.609227 -> V=1.0, theta=0.0
% INFO    : Bus 1213	: V=0.989029, theta=0.920029 -> V=1.0, theta=0.0
% INFO    : Bus 1214	: V=0.960525, theta=-8.071165 -> V=1.0, theta=0.0
% INFO    : Bus 1215	: V=1.036118, theta=33.13745 -> V=1.0, theta=0.0
% INFO    : Bus 1216	: V=1.099831, theta=-4.401904 -> V=1.0, theta=0.0
% INFO    : Bus 1217	: V=1.026955, theta=10.877686 -> V=1.0, theta=0.0
% INFO    : Bus 1218	: V=0.989939, theta=94.137681 -> V=1.0, theta=0.0
% INFO    : Bus 1219	: V=1.012402, theta=-5.282433 -> V=1.0, theta=0.0
% INFO    : Bus 1220	: V=0.970825, theta=-5.981165 -> V=1.0, theta=0.0
% INFO    : Bus 1221	: V=0.991182, theta=17.232684 -> V=1.0, theta=0.0
% INFO    : Bus 1222	: V=0.954047, theta=-6.852207 -> V=1.0, theta=0.0
% INFO    : Bus 1223	: V=1.090479, theta=-4.891767 -> V=1.0, theta=0.0
% INFO    : Bus 1224	: V=1.017267, theta=70.448807 -> V=1.0, theta=0.0
% INFO    : Bus 1225	: V=1.01747, theta=24.913441 -> V=1.0, theta=0.0
% INFO    : Bus 1226	: V=1.023929, theta=-0.379788 -> V=1.0, theta=0.0
% INFO    : Bus 1227	: V=1.033419, theta=-19.31843 -> V=1.0, theta=0.0
% INFO    : Bus 1228	: V=1.025589, theta=17.0989 -> V=1.0, theta=0.0
% INFO    : Bus 1229	: V=0.980304, theta=12.228304 -> V=1.0, theta=0.0
% INFO    : Bus 1230	: V=1.016217, theta=20.317809 -> V=1.0, theta=0.0
% INFO    : Bus 1231	: V=1.016217, theta=20.317809 -> V=1.0, theta=0.0
% INFO    : Bus 1232	: V=1.016217, theta=20.317809 -> V=1.0, theta=0.0
% INFO    : Bus 1233	: V=1.027014, theta=-3.607711 -> V=1.0, theta=0.0
% INFO    : Bus 1234	: V=0.999152, theta=-3.843739 -> V=1.0, theta=0.0
% INFO    : Bus 1235	: V=1.012217, theta=-15.655535 -> V=1.0, theta=0.0
% INFO    : Bus 1236	: V=1.033007, theta=35.671238 -> V=1.0, theta=0.0
% INFO    : Bus 1237	: V=1.038979, theta=-13.937788 -> V=1.0, theta=0.0
% INFO    : Bus 1238	: V=1.003807, theta=31.8753 -> V=1.0, theta=0.0
% INFO    : Bus 1239	: V=1.010888, theta=23.125198 -> V=1.0, theta=0.0
% INFO    : Bus 1240	: V=1.024087, theta=-0.54486 -> V=1.0, theta=0.0
% INFO    : Bus 1241	: V=1.00962, theta=-16.927071 -> V=1.0, theta=0.0
% INFO    : Bus 1242	: V=1.016551, theta=19.011695 -> V=1.0, theta=0.0
% INFO    : Bus 1243	: V=1.04846, theta=-0.047812 -> V=1.0, theta=0.0
% INFO    : Bus 1244	: V=1.001857, theta=-9.078486 -> V=1.0, theta=0.0
% INFO    : Bus 1245	: V=0.977562, theta=26.05322 -> V=1.0, theta=0.0
% INFO    : Bus 1246	: V=1.025868, theta=35.252167 -> V=1.0, theta=0.0
% INFO    : Bus 1247	: V=0.997624, theta=-3.342561 -> V=1.0, theta=0.0
% INFO    : Bus 1248	: V=1.037647, theta=0.367988 -> V=1.0, theta=0.0
% INFO    : Bus 1249	: V=1.023959, theta=-3.085896 -> V=1.0, theta=0.0
% INFO    : Bus 1250	: V=0.984611, theta=-5.611707 -> V=1.0, theta=0.0
% INFO    : Bus 1251	: V=1.047302, theta=10.700556 -> V=1.0, theta=0.0
% INFO    : Bus 1252	: V=1.034819, theta=1.718515 -> V=1.0, theta=0.0
% INFO    : Bus 1253	: V=1.024092, theta=-4.135271 -> V=1.0, theta=0.0
% INFO    : Bus 1254	: V=0.983565, theta=-8.783815 -> V=1.0, theta=0.0
% INFO    : Bus 1255	: V=1.064545, theta=-1.597101 -> V=1.0, theta=0.0
% INFO    : Bus 1256	: V=1.025328, theta=17.022252 -> V=1.0, theta=0.0
% INFO    : Bus 1257	: V=1.03036, theta=-6.512869 -> V=1.0, theta=0.0
% INFO    : Bus 1258	: V=1.034351, theta=3.127292 -> V=1.0, theta=0.0
% INFO    : Bus 1259	: V=1.016681, theta=43.976275 -> V=1.0, theta=0.0
% INFO    : Bus 1260	: V=1.026315, theta=15.249077 -> V=1.0, theta=0.0
% INFO    : Bus 1261	: V=1.01688, theta=13.461135 -> V=1.0, theta=0.0
% INFO    : Bus 1262	: V=1.048632, theta=39.237883 -> V=1.0, theta=0.0
% INFO    : Bus 1263	: V=1.017546, theta=-7.215576 -> V=1.0, theta=0.0
% INFO    : Bus 1264	: V=1.002671, theta=41.912372 -> V=1.0, theta=0.0
% INFO    : Bus 1265	: V=1.032343, theta=4.317268 -> V=1.0, theta=0.0
% INFO    : Bus 1266	: V=1.023208, theta=3.35577 -> V=1.0, theta=0.0
% INFO    : Bus 1267	: V=0.992997, theta=-3.956098 -> V=1.0, theta=0.0
% INFO    : Bus 1268	: V=1.050784, theta=25.734127 -> V=1.0, theta=0.0
% INFO    : Bus 1269	: V=1.031159, theta=14.124866 -> V=1.0, theta=0.0
% INFO    : Bus 1270	: V=0.964568, theta=-8.270907 -> V=1.0, theta=0.0
% INFO    : Bus 1271	: V=1.023486, theta=19.424705 -> V=1.0, theta=0.0
% INFO    : Bus 1272	: V=1.003523, theta=-3.772589 -> V=1.0, theta=0.0
% INFO    : Bus 1273	: V=1.044317, theta=35.206283 -> V=1.0, theta=0.0
% INFO    : Bus 1274	: V=1.036065, theta=-16.582357 -> V=1.0, theta=0.0
% INFO    : Bus 1275	: V=1.036266, theta=21.408499 -> V=1.0, theta=0.0
% INFO    : Bus 1276	: V=1.049499, theta=-1.562398 -> V=1.0, theta=0.0
% INFO    : Bus 1277	: V=1.014588, theta=19.116104 -> V=1.0, theta=0.0
% INFO    : Bus 1278	: V=1.055337, theta=0.681282 -> V=1.0, theta=0.0
% INFO    : Bus 1279	: V=0.998779, theta=-14.538696 -> V=1.0, theta=0.0
% INFO    : Bus 1280	: V=1.011658, theta=18.310559 -> V=1.0, theta=0.0
% INFO    : Bus 1281	: V=1.09787, theta=-4.489169 -> V=1.0, theta=0.0
% INFO    : Bus 1282	: V=1.02307, theta=35.928234 -> V=1.0, theta=0.0
% INFO    : Bus 1283	: V=1.080673, theta=-3.230149 -> V=1.0, theta=0.0
% INFO    : Bus 1284	: V=1.031863, theta=-3.799969 -> V=1.0, theta=0.0
% INFO    : Bus 1285	: V=1.011397, theta=-10.092906 -> V=1.0, theta=0.0
% INFO    : Bus 1286	: V=1.059588, theta=2.630814 -> V=1.0, theta=0.0
% INFO    : Bus 1287	: V=1.052164, theta=7.333527 -> V=1.0, theta=0.0
% INFO    : Bus 1288	: V=1.024762, theta=17.972121 -> V=1.0, theta=0.0
% INFO    : Bus 1289	: V=1.011456, theta=38.709997 -> V=1.0, theta=0.0
% INFO    : Bus 1290	: V=1.019482, theta=16.777108 -> V=1.0, theta=0.0
% INFO    : Bus 1291	: V=1.033392, theta=9.500925 -> V=1.0, theta=0.0
% INFO    : Bus 1292	: V=0.988535, theta=-1.526728 -> V=1.0, theta=0.0
% INFO    : Bus 1293	: V=0.978392, theta=5.399845 -> V=1.0, theta=0.0
% INFO    : Bus 1294	: V=1.024075, theta=6.410383 -> V=1.0, theta=0.0
% INFO    : Bus 1295	: V=0.987567, theta=-22.138945 -> V=1.0, theta=0.0
% INFO    : Bus 1296	: V=0.964203, theta=7.059293 -> V=1.0, theta=0.0
% INFO    : Bus 1297	: V=0.978053, theta=24.541317 -> V=1.0, theta=0.0
% INFO    : Bus 1298	: V=1.052164, theta=7.333527 -> V=1.0, theta=0.0
% INFO    : Bus 1299	: V=1.033373, theta=-18.785108 -> V=1.0, theta=0.0
% INFO    : Bus 1300	: V=0.99014, theta=24.93683 -> V=1.0, theta=0.0
% INFO    : Bus 1301	: V=1.032787, theta=-18.511488 -> V=1.0, theta=0.0
% INFO    : Bus 1302	: V=1.036835, theta=-1.697863 -> V=1.0, theta=0.0
% INFO    : Bus 1303	: V=1.040676, theta=-9.782077 -> V=1.0, theta=0.0
% INFO    : Bus 1304	: V=1.037973, theta=11.471538 -> V=1.0, theta=0.0
% INFO    : Bus 1305	: V=1.022099, theta=17.218586 -> V=1.0, theta=0.0
% INFO    : Bus 1306	: V=1.023144, theta=-9.538309 -> V=1.0, theta=0.0
% INFO    : Bus 1307	: V=0.977439, theta=38.340653 -> V=1.0, theta=0.0
% INFO    : Bus 1308	: V=1.127182, theta=5.800414 -> V=1.0, theta=0.0
% INFO    : Bus 1309	: V=1.013598, theta=-10.219682 -> V=1.0, theta=0.0
% INFO    : Bus 1310	: V=1.043619, theta=-8.436397 -> V=1.0, theta=0.0
% INFO    : Bus 1311	: V=1.013231, theta=-26.409956 -> V=1.0, theta=0.0
% INFO    : Bus 1312	: V=0.955741, theta=-10.11486 -> V=1.0, theta=0.0
% INFO    : Bus 1313	: V=1.025483, theta=1.905603 -> V=1.0, theta=0.0
% INFO    : Bus 1314	: V=0.994242, theta=7.715079 -> V=1.0, theta=0.0
% INFO    : Bus 1315	: V=1.02791, theta=-15.503278 -> V=1.0, theta=0.0
% INFO    : Bus 1316	: V=0.993604, theta=-4.183455 -> V=1.0, theta=0.0
% INFO    : Bus 1317	: V=1.037231, theta=5.419113 -> V=1.0, theta=0.0
% INFO    : Bus 1318	: V=1.003098, theta=-4.680224 -> V=1.0, theta=0.0
% INFO    : Bus 1319	: V=1.005178, theta=-10.412822 -> V=1.0, theta=0.0
% INFO    : Bus 1320	: V=1.063111, theta=64.17397 -> V=1.0, theta=0.0
% INFO    : Bus 1321	: V=1.009846, theta=4.913756 -> V=1.0, theta=0.0
% INFO    : Bus 1322	: V=1.022037, theta=-4.256844 -> V=1.0, theta=0.0
% INFO    : Bus 1323	: V=1.128032, theta=6.903218 -> V=1.0, theta=0.0
% INFO    : Bus 1324	: V=1.055337, theta=0.681282 -> V=1.0, theta=0.0
% INFO    : Bus 1325	: V=0.983431, theta=-1.771365 -> V=1.0, theta=0.0
% INFO    : Bus 1326	: V=1.066503, theta=7.436005 -> V=1.0, theta=0.0
% INFO    : Bus 1327	: V=1.016711, theta=6.114524 -> V=1.0, theta=0.0
% INFO    : Bus 1328	: V=1.024026, theta=0.390871 -> V=1.0, theta=0.0
% INFO    : Bus 1329	: V=1.009821, theta=29.021748 -> V=1.0, theta=0.0
% INFO    : Bus 1330	: V=1.024544, theta=18.974877 -> V=1.0, theta=0.0
% INFO    : Bus 1331	: V=1.005198, theta=-7.161553 -> V=1.0, theta=0.0
% INFO    : Bus 1332	: V=1.005039, theta=-20.950342 -> V=1.0, theta=0.0
% INFO    : Bus 1333	: V=1.005156, theta=-3.750223 -> V=1.0, theta=0.0
% INFO    : Bus 1334	: V=1.029972, theta=-21.872489 -> V=1.0, theta=0.0
% INFO    : Bus 1335	: V=1.0608, theta=42.720858 -> V=1.0, theta=0.0
% INFO    : Bus 1336	: V=0.95238, theta=-7.290511 -> V=1.0, theta=0.0
% INFO    : Bus 1337	: V=0.989854, theta=24.705399 -> V=1.0, theta=0.0
% INFO    : Bus 1338	: V=1.02611, theta=9.397426 -> V=1.0, theta=0.0
% INFO    : Bus 1339	: V=1.02611, theta=9.397426 -> V=1.0, theta=0.0
% INFO    : Bus 1340	: V=1.040865, theta=12.654119 -> V=1.0, theta=0.0
% INFO    : Bus 1341	: V=1.08342, theta=0.64159 -> V=1.0, theta=0.0
% INFO    : Bus 1342	: V=1.02611, theta=9.397426 -> V=1.0, theta=0.0
% INFO    : Bus 1343	: V=1.02611, theta=9.397426 -> V=1.0, theta=0.0
% INFO    : Bus 1344	: V=1.00657, theta=25.464337 -> V=1.0, theta=0.0
% INFO    : Bus 1345	: V=1.039121, theta=17.644693 -> V=1.0, theta=0.0
% INFO    : Bus 1346	: V=1.034028, theta=8.40309 -> V=1.0, theta=0.0
% INFO    : Bus 1347	: V=0.965753, theta=-9.552607 -> V=1.0, theta=0.0
% INFO    : Bus 1348	: V=1.02611, theta=9.397426 -> V=1.0, theta=0.0
% INFO    : Bus 1349	: V=1.031144, theta=-5.517648 -> V=1.0, theta=0.0
% INFO    : Bus 1350	: V=1.01497, theta=24.847751 -> V=1.0, theta=0.0
% INFO    : Bus 1351	: V=1.015493, theta=16.769648 -> V=1.0, theta=0.0
% INFO    : Bus 1352	: V=1.009437, theta=-18.638291 -> V=1.0, theta=0.0
% INFO    : Bus 1353	: V=1.051369, theta=-2.55004 -> V=1.0, theta=0.0
% INFO    : Bus 1354	: V=1.026675, theta=25.143797 -> V=1.0, theta=0.0
% INFO    : Bus 1355	: V=1.007341, theta=13.840393 -> V=1.0, theta=0.0
% INFO    : Bus 1356	: V=1.058598, theta=20.351152 -> V=1.0, theta=0.0
% INFO    : Bus 1357	: V=0.88398, theta=-14.103043 -> V=1.0, theta=0.0
% INFO    : Bus 1358	: V=1.014293, theta=-18.380601 -> V=1.0, theta=0.0
% INFO    : Bus 1359	: V=1.008948, theta=-4.613451 -> V=1.0, theta=0.0
% INFO    : Bus 1360	: V=1.003115, theta=-6.90371 -> V=1.0, theta=0.0
% INFO    : Bus 1361	: V=1.013428, theta=18.272141 -> V=1.0, theta=0.0
% INFO    : Bus 1362	: V=0.992611, theta=-14.416547 -> V=1.0, theta=0.0
% INFO    : Bus 1363	: V=0.994236, theta=40.473758 -> V=1.0, theta=0.0
% INFO    : Bus 1364	: V=0.981067, theta=1.057278 -> V=1.0, theta=0.0
% INFO    : Bus 1365	: V=0.964474, theta=34.963089 -> V=1.0, theta=0.0
% INFO    : Bus 1366	: V=1.017076, theta=57.811893 -> V=1.0, theta=0.0
% INFO    : Bus 1367	: V=1.031502, theta=0.465782 -> V=1.0, theta=0.0
% INFO    : Bus 1368	: V=1.008419, theta=-14.737948 -> V=1.0, theta=0.0
% INFO    : Bus 1369	: V=1.032265, theta=43.171125 -> V=1.0, theta=0.0
% INFO    : Bus 1370	: V=1.027241, theta=-22.307748 -> V=1.0, theta=0.0
% INFO    : Bus 1371	: V=1.078275, theta=5.990479 -> V=1.0, theta=0.0
% INFO    : Bus 1372	: V=1.018066, theta=-18.544118 -> V=1.0, theta=0.0
% INFO    : Bus 1373	: V=1.084648, theta=34.31875 -> V=1.0, theta=0.0
% INFO    : Bus 1374	: V=1.017753, theta=-8.026498 -> V=1.0, theta=0.0
% INFO    : Bus 1375	: V=1.006855, theta=-8.554992 -> V=1.0, theta=0.0
% INFO    : Bus 1376	: V=1.027131, theta=-1.211905 -> V=1.0, theta=0.0
% INFO    : Bus 1377	: V=1.014793, theta=-22.29244 -> V=1.0, theta=0.0
% INFO    : Bus 1378	: V=1.038249, theta=11.383163 -> V=1.0, theta=0.0
% INFO    : Bus 1379	: V=1.033035, theta=14.850214 -> V=1.0, theta=0.0
% INFO    : Bus 1380	: V=1.011107, theta=-2.897343 -> V=1.0, theta=0.0
% INFO    : Bus 1381	: V=1.030174, theta=-14.576007 -> V=1.0, theta=0.0
% INFO    : Bus 1382	: V=1.013179, theta=14.179628 -> V=1.0, theta=0.0
% INFO    : Bus 1383	: V=1.029442, theta=-1.667248 -> V=1.0, theta=0.0
% INFO    : Bus 1384	: V=0.94375, theta=-2.230118 -> V=1.0, theta=0.0
% INFO    : Bus 1385	: V=1.033997, theta=4.729511 -> V=1.0, theta=0.0
% INFO    : Bus 1386	: V=1.011473, theta=-16.503789 -> V=1.0, theta=0.0
% INFO    : Bus 1387	: V=0.994546, theta=32.929681 -> V=1.0, theta=0.0
% INFO    : Bus 1388	: V=1.033278, theta=-13.106385 -> V=1.0, theta=0.0
% INFO    : Bus 1389	: V=1.03558, theta=-5.743469 -> V=1.0, theta=0.0
% INFO    : Bus 1390	: V=1.03558, theta=-5.743469 -> V=1.0, theta=0.0
% INFO    : Bus 1391	: V=1.03558, theta=-5.743469 -> V=1.0, theta=0.0
% INFO    : Bus 1392	: V=1.0184, theta=-6.821964 -> V=1.0, theta=0.0
% INFO    : Bus 1393	: V=1.090026, theta=71.311631 -> V=1.0, theta=0.0
% INFO    : Bus 1394	: V=1.03858, theta=30.747075 -> V=1.0, theta=0.0
% INFO    : Bus 1395	: V=1.027954, theta=-6.383546 -> V=1.0, theta=0.0
% INFO    : Bus 1396	: V=1.030911, theta=-12.637403 -> V=1.0, theta=0.0
% INFO    : Bus 1397	: V=1.011721, theta=-25.197742 -> V=1.0, theta=0.0
% INFO    : Bus 1398	: V=0.993773, theta=-11.20036 -> V=1.0, theta=0.0
% INFO    : Bus 1399	: V=1.014538, theta=-25.40241 -> V=1.0, theta=0.0
% INFO    : Bus 1400	: V=0.957686, theta=-7.394537 -> V=1.0, theta=0.0
% INFO    : Bus 1401	: V=1.015161, theta=-11.543898 -> V=1.0, theta=0.0
% INFO    : Bus 1402	: V=0.996571, theta=-13.145129 -> V=1.0, theta=0.0
% INFO    : Bus 1403	: V=0.996751, theta=-1.363677 -> V=1.0, theta=0.0
% INFO    : Bus 1404	: V=1.010936, theta=2.529477 -> V=1.0, theta=0.0
% INFO    : Bus 1405	: V=0.990787, theta=28.512684 -> V=1.0, theta=0.0
% INFO    : Bus 1406	: V=1.029731, theta=25.844994 -> V=1.0, theta=0.0
% INFO    : Bus 1407	: V=1.042865, theta=51.92649 -> V=1.0, theta=0.0
% INFO    : Bus 1408	: V=1.042865, theta=51.92649 -> V=1.0, theta=0.0
% INFO    : Bus 1409	: V=1.003865, theta=-9.5568 -> V=1.0, theta=0.0
% INFO    : Bus 1410	: V=1.045666, theta=52.068402 -> V=1.0, theta=0.0
% INFO    : Bus 1411	: V=1.045666, theta=52.068402 -> V=1.0, theta=0.0
% INFO    : Bus 1412	: V=1.045666, theta=52.068402 -> V=1.0, theta=0.0
% INFO    : Bus 1413	: V=1.045666, theta=52.068402 -> V=1.0, theta=0.0
% INFO    : Bus 1414	: V=1.042865, theta=51.92649 -> V=1.0, theta=0.0
% INFO    : Bus 1415	: V=1.042865, theta=51.92649 -> V=1.0, theta=0.0
% INFO    : Bus 1416	: V=1.045666, theta=52.068402 -> V=1.0, theta=0.0
% INFO    : Bus 1417	: V=1.042865, theta=51.92649 -> V=1.0, theta=0.0
% INFO    : Bus 1418	: V=1.018252, theta=-5.565917 -> V=1.0, theta=0.0
% INFO    : Bus 1419	: V=1.03758, theta=22.028378 -> V=1.0, theta=0.0
% INFO    : Bus 1420	: V=1.046338, theta=-4.535742 -> V=1.0, theta=0.0
% INFO    : Bus 1421	: V=0.996766, theta=22.457835 -> V=1.0, theta=0.0
% INFO    : Bus 1422	: V=1.037267, theta=10.219486 -> V=1.0, theta=0.0
% INFO    : Bus 1423	: V=1.033534, theta=-10.544863 -> V=1.0, theta=0.0
% INFO    : Bus 1424	: V=0.953323, theta=-8.205349 -> V=1.0, theta=0.0
% INFO    : Bus 1425	: V=0.997713, theta=33.606331 -> V=1.0, theta=0.0
% INFO    : Bus 1426	: V=1.043663, theta=17.125447 -> V=1.0, theta=0.0
% INFO    : Bus 1427	: V=1.046359, theta=90.322887 -> V=1.0, theta=0.0
% INFO    : Bus 1428	: V=1.092968, theta=-0.268371 -> V=1.0, theta=0.0
% INFO    : Bus 1429	: V=1.020081, theta=-4.546391 -> V=1.0, theta=0.0
% INFO    : Bus 1430	: V=0.991566, theta=-24.906856 -> V=1.0, theta=0.0
% INFO    : Bus 1431	: V=1.017696, theta=24.858482 -> V=1.0, theta=0.0
% INFO    : Bus 1432	: V=1.020393, theta=17.568548 -> V=1.0, theta=0.0
% INFO    : Bus 1433	: V=1.033648, theta=19.100507 -> V=1.0, theta=0.0
% INFO    : Bus 1434	: V=1.033648, theta=19.100507 -> V=1.0, theta=0.0
% INFO    : Bus 1435	: V=1.048683, theta=24.799749 -> V=1.0, theta=0.0
% INFO    : Bus 1436	: V=1.048683, theta=24.799749 -> V=1.0, theta=0.0
% INFO    : Bus 1437	: V=1.033648, theta=19.100507 -> V=1.0, theta=0.0
% INFO    : Bus 1438	: V=1.033648, theta=19.100507 -> V=1.0, theta=0.0
% INFO    : Bus 1439	: V=1.040698, theta=17.14354 -> V=1.0, theta=0.0
% INFO    : Bus 1440	: V=1.04081, theta=21.523284 -> V=1.0, theta=0.0
% INFO    : Bus 1441	: V=1.048683, theta=24.799749 -> V=1.0, theta=0.0
% INFO    : Bus 1442	: V=1.040698, theta=17.14354 -> V=1.0, theta=0.0
% INFO    : Bus 1443	: V=0.992777, theta=-19.070079 -> V=1.0, theta=0.0
% INFO    : Bus 1444	: V=1.013902, theta=-8.72938 -> V=1.0, theta=0.0
% INFO    : Bus 1445	: V=1.047149, theta=23.914598 -> V=1.0, theta=0.0
% INFO    : Bus 1446	: V=0.993422, theta=-9.294213 -> V=1.0, theta=0.0
% INFO    : Bus 1447	: V=1.030174, theta=-14.576007 -> V=1.0, theta=0.0
% INFO    : Bus 1448	: V=1.030174, theta=-14.576007 -> V=1.0, theta=0.0
% INFO    : Bus 1449	: V=1.030174, theta=-14.576007 -> V=1.0, theta=0.0
% INFO    : Bus 1450	: V=1.030174, theta=-14.576007 -> V=1.0, theta=0.0
% INFO    : Bus 1451	: V=1.021906, theta=-21.605261 -> V=1.0, theta=0.0
% INFO    : Bus 1452	: V=0.99768, theta=60.908647 -> V=1.0, theta=0.0
% INFO    : Bus 1453	: V=1.021906, theta=-21.605261 -> V=1.0, theta=0.0
% INFO    : Bus 1454	: V=1.021906, theta=-21.605261 -> V=1.0, theta=0.0
% INFO    : Bus 1455	: V=1.009892, theta=4.868208 -> V=1.0, theta=0.0
% INFO    : Bus 1456	: V=1.055477, theta=33.90241 -> V=1.0, theta=0.0
% INFO    : Bus 1457	: V=1.007444, theta=-18.937606 -> V=1.0, theta=0.0
% INFO    : Bus 1458	: V=1.046359, theta=90.322887 -> V=1.0, theta=0.0
% INFO    : Bus 1459	: V=0.97474, theta=5.213673 -> V=1.0, theta=0.0
% INFO    : Bus 1460	: V=1.013161, theta=-26.710349 -> V=1.0, theta=0.0
% INFO    : Bus 1461	: V=1.004067, theta=12.245503 -> V=1.0, theta=0.0
% INFO    : Bus 1462	: V=1.036065, theta=-16.582357 -> V=1.0, theta=0.0
% INFO    : Bus 1463	: V=1.013499, theta=-24.806539 -> V=1.0, theta=0.0
% INFO    : Bus 1464	: V=1.022649, theta=0.085134 -> V=1.0, theta=0.0
% INFO    : Bus 1465	: V=0.977422, theta=12.295759 -> V=1.0, theta=0.0
% INFO    : Bus 1466	: V=1.008172, theta=-3.314025 -> V=1.0, theta=0.0
% INFO    : Bus 1467	: V=1.035848, theta=92.435397 -> V=1.0, theta=0.0
% INFO    : Bus 1468	: V=1.024015, theta=-15.769618 -> V=1.0, theta=0.0
% INFO    : Bus 1469	: V=1.01541, theta=24.000055 -> V=1.0, theta=0.0
% INFO    : Bus 1470	: V=1.06527, theta=-0.439984 -> V=1.0, theta=0.0
% INFO    : Bus 1471	: V=1.06527, theta=-0.439984 -> V=1.0, theta=0.0
% INFO    : Bus 1472	: V=1.010036, theta=-8.472091 -> V=1.0, theta=0.0
% INFO    : Bus 1473	: V=1.06527, theta=-0.439984 -> V=1.0, theta=0.0
% INFO    : Bus 1474	: V=1.06527, theta=-0.439984 -> V=1.0, theta=0.0
% INFO    : Bus 1475	: V=1.06527, theta=-0.439984 -> V=1.0, theta=0.0
% INFO    : Bus 1476	: V=1.06527, theta=-0.439984 -> V=1.0, theta=0.0
% INFO    : Bus 1477	: V=1.063432, theta=5.558066 -> V=1.0, theta=0.0
% INFO    : Bus 1478	: V=1.063432, theta=5.558066 -> V=1.0, theta=0.0
% INFO    : Bus 1479	: V=1.063432, theta=5.558066 -> V=1.0, theta=0.0
% INFO    : Bus 1480	: V=1.018379, theta=-11.027788 -> V=1.0, theta=0.0
% INFO    : Bus 1481	: V=1.007081, theta=13.329704 -> V=1.0, theta=0.0
% INFO    : Bus 1482	: V=1.007081, theta=13.329704 -> V=1.0, theta=0.0
% INFO    : Bus 1483	: V=1.007081, theta=13.329704 -> V=1.0, theta=0.0
% INFO    : Bus 1484	: V=1.060798, theta=-1.229323 -> V=1.0, theta=0.0
% INFO    : Bus 1485	: V=1.060798, theta=-1.229323 -> V=1.0, theta=0.0
% INFO    : Bus 1486	: V=1.060798, theta=-1.229323 -> V=1.0, theta=0.0
% INFO    : Bus 1487	: V=1.003412, theta=0.732753 -> V=1.0, theta=0.0
% INFO    : Bus 1488	: V=1.003171, theta=37.39829 -> V=1.0, theta=0.0
% INFO    : Bus 1489	: V=1.030584, theta=-3.714139 -> V=1.0, theta=0.0
% INFO    : Bus 1490	: V=1.032515, theta=-3.516223 -> V=1.0, theta=0.0
% INFO    : Bus 1491	: V=1.042169, theta=34.593975 -> V=1.0, theta=0.0
% INFO    : Bus 1492	: V=1.008724, theta=2.168065 -> V=1.0, theta=0.0
% INFO    : Bus 1493	: V=1.019002, theta=9.546797 -> V=1.0, theta=0.0
% INFO    : Bus 1494	: V=1.027605, theta=20.158794 -> V=1.0, theta=0.0
% INFO    : Bus 1495	: V=0.984285, theta=-17.22273 -> V=1.0, theta=0.0
% INFO    : Bus 1496	: V=0.979544, theta=-5.959906 -> V=1.0, theta=0.0
% INFO    : Bus 1497	: V=1.013843, theta=19.287793 -> V=1.0, theta=0.0
% INFO    : Bus 1498	: V=1.033336, theta=3.342046 -> V=1.0, theta=0.0
% INFO    : Bus 1499	: V=1.00705, theta=25.577191 -> V=1.0, theta=0.0
% INFO    : Bus 1500	: V=1.001203, theta=30.380734 -> V=1.0, theta=0.0
% INFO    : Bus 1501	: V=1.018456, theta=22.124078 -> V=1.0, theta=0.0
% INFO    : Bus 1502	: V=0.983972, theta=-5.211149 -> V=1.0, theta=0.0
% INFO    : Bus 1503	: V=0.98652, theta=-3.592922 -> V=1.0, theta=0.0
% INFO    : Bus 1504	: V=1.136154, theta=0.822895 -> V=1.0, theta=0.0
% INFO    : Bus 1505	: V=1.025426, theta=-15.273241 -> V=1.0, theta=0.0
% INFO    : Bus 1506	: V=1.046538, theta=34.171044 -> V=1.0, theta=0.0
% INFO    : Bus 1507	: V=1.018281, theta=16.808324 -> V=1.0, theta=0.0
% INFO    : Bus 1508	: V=1.043518, theta=54.330098 -> V=1.0, theta=0.0
% INFO    : Bus 1509	: V=1.023648, theta=3.396089 -> V=1.0, theta=0.0
% INFO    : Bus 1510	: V=1.017682, theta=29.642897 -> V=1.0, theta=0.0
% INFO    : Bus 1511	: V=1.018239, theta=-19.841296 -> V=1.0, theta=0.0
% INFO    : Bus 1512	: V=1.012964, theta=-12.27724 -> V=1.0, theta=0.0
% INFO    : Bus 1513	: V=0.963689, theta=-9.802775 -> V=1.0, theta=0.0
% INFO    : Bus 1514	: V=1.029166, theta=13.522836 -> V=1.0, theta=0.0
% INFO    : Bus 1515	: V=1.056035, theta=-6.130078 -> V=1.0, theta=0.0
% INFO    : Bus 1516	: V=1.035838, theta=-5.172678 -> V=1.0, theta=0.0
% INFO    : Bus 1517	: V=1.033944, theta=81.658005 -> V=1.0, theta=0.0
% INFO    : Bus 1518	: V=1.033944, theta=81.658005 -> V=1.0, theta=0.0
% INFO    : Bus 1519	: V=1.033944, theta=81.5989 -> V=1.0, theta=0.0
% INFO    : Bus 1520	: V=1.033944, theta=81.5989 -> V=1.0, theta=0.0
% INFO    : Bus 1521	: V=1.055774, theta=84.490729 -> V=1.0, theta=0.0
% INFO    : Bus 1522	: V=0.995923, theta=22.396868 -> V=1.0, theta=0.0
% INFO    : Bus 1523	: V=1.080104, theta=-3.304065 -> V=1.0, theta=0.0
% INFO    : Bus 1524	: V=1.053202, theta=-14.326704 -> V=1.0, theta=0.0
% INFO    : Bus 1525	: V=0.995889, theta=-9.119979 -> V=1.0, theta=0.0
% INFO    : Bus 1526	: V=1.014332, theta=26.817672 -> V=1.0, theta=0.0
% INFO    : Bus 1527	: V=1.019936, theta=7.010383 -> V=1.0, theta=0.0
% INFO    : Bus 1528	: V=1.004165, theta=-2.237835 -> V=1.0, theta=0.0
% INFO    : Bus 1529	: V=1.03218, theta=-19.625729 -> V=1.0, theta=0.0
% INFO    : Bus 1530	: V=1.014984, theta=-26.876942 -> V=1.0, theta=0.0
% INFO    : Bus 1531	: V=1.076788, theta=36.804416 -> V=1.0, theta=0.0
% INFO    : Bus 1532	: V=1.012556, theta=-8.920589 -> V=1.0, theta=0.0
% INFO    : Bus 1533	: V=1.010467, theta=48.767303 -> V=1.0, theta=0.0
% INFO    : Bus 1534	: V=1.053776, theta=40.435567 -> V=1.0, theta=0.0
% INFO    : Bus 1535	: V=1.069767, theta=18.174762 -> V=1.0, theta=0.0
% INFO    : Bus 1536	: V=0.995702, theta=-9.051189 -> V=1.0, theta=0.0
% INFO    : Bus 1537	: V=1.063704, theta=66.981987 -> V=1.0, theta=0.0
% INFO    : Bus 1538	: V=1.01392, theta=8.701747 -> V=1.0, theta=0.0
% INFO    : Bus 1539	: V=1.009185, theta=2.56099 -> V=1.0, theta=0.0
% INFO    : Bus 1540	: V=1.006756, theta=-15.1197 -> V=1.0, theta=0.0
% INFO    : Bus 1541	: V=1.027472, theta=15.203439 -> V=1.0, theta=0.0
% INFO    : Bus 1542	: V=1.065223, theta=1.152691 -> V=1.0, theta=0.0
% INFO    : Bus 1543	: V=1.036277, theta=-15.753777 -> V=1.0, theta=0.0
% INFO    : Bus 1544	: V=1.063704, theta=66.981987 -> V=1.0, theta=0.0
% INFO    : Bus 1545	: V=1.063704, theta=66.981987 -> V=1.0, theta=0.0
% INFO    : Bus 1546	: V=1.051916, theta=71.34914 -> V=1.0, theta=0.0
% INFO    : Bus 1547	: V=0.966992, theta=-14.766387 -> V=1.0, theta=0.0
% INFO    : Bus 1548	: V=1.026748, theta=18.911757 -> V=1.0, theta=0.0
% INFO    : Bus 1549	: V=1.055824, theta=25.80864 -> V=1.0, theta=0.0
% INFO    : Bus 1550	: V=1.009685, theta=30.34199 -> V=1.0, theta=0.0
% INFO    : Bus 1551	: V=1.029094, theta=15.098629 -> V=1.0, theta=0.0
% INFO    : Bus 1552	: V=1.043138, theta=41.982485 -> V=1.0, theta=0.0
% INFO    : Bus 1553	: V=1.027348, theta=16.396901 -> V=1.0, theta=0.0
% INFO    : Bus 1554	: V=1.032971, theta=19.158498 -> V=1.0, theta=0.0
% INFO    : Bus 1555	: V=1.01419, theta=-0.817409 -> V=1.0, theta=0.0
% INFO    : Bus 1556	: V=1.069569, theta=35.273027 -> V=1.0, theta=0.0
% INFO    : Bus 1557	: V=1.069569, theta=35.273027 -> V=1.0, theta=0.0
% INFO    : Bus 1558	: V=1.069569, theta=35.273027 -> V=1.0, theta=0.0
% INFO    : Bus 1559	: V=1.113563, theta=6.086123 -> V=1.0, theta=0.0
% INFO    : Bus 1560	: V=1.059142, theta=21.764381 -> V=1.0, theta=0.0
% INFO    : Bus 1561	: V=1.066067, theta=59.272605 -> V=1.0, theta=0.0
% INFO    : Bus 1562	: V=0.995346, theta=36.752154 -> V=1.0, theta=0.0
% INFO    : Bus 1563	: V=1.033443, theta=20.750736 -> V=1.0, theta=0.0
% INFO    : Bus 1564	: V=0.982474, theta=0.471501 -> V=1.0, theta=0.0
% INFO    : Bus 1565	: V=1.050774, theta=-0.576722 -> V=1.0, theta=0.0
% INFO    : Bus 1566	: V=1.04051, theta=19.367506 -> V=1.0, theta=0.0
% INFO    : Bus 1567	: V=1.003765, theta=-20.136541 -> V=1.0, theta=0.0
% INFO    : Bus 1568	: V=0.962628, theta=-7.419291 -> V=1.0, theta=0.0
% INFO    : Bus 1569	: V=1.01263, theta=30.120443 -> V=1.0, theta=0.0
% INFO    : Bus 1570	: V=1.03946, theta=-1.166173 -> V=1.0, theta=0.0
% INFO    : Bus 1571	: V=1.009978, theta=9.05433 -> V=1.0, theta=0.0
% INFO    : Bus 1572	: V=1.016271, theta=7.799267 -> V=1.0, theta=0.0
% INFO    : Bus 1573	: V=1.018638, theta=-8.917122 -> V=1.0, theta=0.0
% INFO    : Bus 1574	: V=1.026966, theta=21.39997 -> V=1.0, theta=0.0
% INFO    : Bus 1575	: V=1.049448, theta=33.310799 -> V=1.0, theta=0.0
% INFO    : Bus 1576	: V=1.107591, theta=6.852032 -> V=1.0, theta=0.0
% INFO    : Bus 1577	: V=1.026206, theta=-2.974992 -> V=1.0, theta=0.0
% INFO    : Bus 1578	: V=1.037603, theta=28.404087 -> V=1.0, theta=0.0
% INFO    : Bus 1579	: V=1.00483, theta=17.539976 -> V=1.0, theta=0.0
% INFO    : Bus 1580	: V=1.033691, theta=0.886126 -> V=1.0, theta=0.0
% INFO    : Bus 1581	: V=1.007312, theta=-8.549741 -> V=1.0, theta=0.0
% INFO    : Bus 1582	: V=1.027792, theta=25.041453 -> V=1.0, theta=0.0
% INFO    : Bus 1583	: V=1.024352, theta=14.858869 -> V=1.0, theta=0.0
% INFO    : Bus 1584	: V=0.982878, theta=-5.663054 -> V=1.0, theta=0.0
% INFO    : Bus 1585	: V=1.072416, theta=54.322097 -> V=1.0, theta=0.0
% INFO    : Bus 1586	: V=1.055063, theta=40.300168 -> V=1.0, theta=0.0
% INFO    : Bus 1587	: V=1.055063, theta=40.300168 -> V=1.0, theta=0.0
% INFO    : Bus 1588	: V=1.035624, theta=-7.38671 -> V=1.0, theta=0.0
% INFO    : Bus 1589	: V=1.034925, theta=31.775405 -> V=1.0, theta=0.0
% INFO    : Bus 1590	: V=0.948702, theta=-2.365664 -> V=1.0, theta=0.0
% INFO    : Bus 1591	: V=1.012625, theta=-16.317081 -> V=1.0, theta=0.0
% INFO    : Bus 1592	: V=1.014963, theta=35.494625 -> V=1.0, theta=0.0
% INFO    : Bus 1593	: V=1.033167, theta=35.997496 -> V=1.0, theta=0.0
% INFO    : Bus 1594	: V=1.004901, theta=24.768889 -> V=1.0, theta=0.0
% INFO    : Bus 1595	: V=1.050827, theta=-6.680648 -> V=1.0, theta=0.0
% INFO    : Bus 1596	: V=1.021094, theta=-7.217557 -> V=1.0, theta=0.0
% INFO    : Bus 1597	: V=1.020965, theta=38.434761 -> V=1.0, theta=0.0
% INFO    : Bus 1598	: V=1.013796, theta=21.907219 -> V=1.0, theta=0.0
% INFO    : Bus 1599	: V=1.030843, theta=4.085708 -> V=1.0, theta=0.0
% INFO    : Bus 1600	: V=1.005344, theta=-8.260142 -> V=1.0, theta=0.0
% INFO    : Bus 1601	: V=0.994517, theta=24.909354 -> V=1.0, theta=0.0
% INFO    : Bus 1602	: V=1.030956, theta=-10.923484 -> V=1.0, theta=0.0
% INFO    : Bus 1603	: V=1.004339, theta=0.968887 -> V=1.0, theta=0.0
% INFO    : Bus 1604	: V=1.027648, theta=-11.776071 -> V=1.0, theta=0.0
% INFO    : Bus 1605	: V=1.009428, theta=40.291154 -> V=1.0, theta=0.0
% INFO    : Bus 1606	: V=1.127948, theta=6.872839 -> V=1.0, theta=0.0
% INFO    : Bus 1607	: V=1.001877, theta=13.978057 -> V=1.0, theta=0.0
% INFO    : Bus 1608	: V=0.969986, theta=37.585796 -> V=1.0, theta=0.0
% INFO    : Bus 1609	: V=1.013688, theta=41.65503 -> V=1.0, theta=0.0
% INFO    : Bus 1610	: V=1.030589, theta=-7.348342 -> V=1.0, theta=0.0
% INFO    : Bus 1611	: V=1.016514, theta=14.597678 -> V=1.0, theta=0.0
% INFO    : Bus 1612	: V=1.024652, theta=-11.689645 -> V=1.0, theta=0.0
% INFO    : Bus 1613	: V=1.029447, theta=4.381728 -> V=1.0, theta=0.0
% INFO    : Bus 1614	: V=1.02904, theta=42.831627 -> V=1.0, theta=0.0
% INFO    : Bus 1615	: V=1.003602, theta=94.235585 -> V=1.0, theta=0.0
% INFO    : Bus 1616	: V=1.011301, theta=-5.438701 -> V=1.0, theta=0.0
% INFO    : Bus 1617	: V=1.018117, theta=-24.674837 -> V=1.0, theta=0.0
% INFO    : Bus 1618	: V=0.98032, theta=29.982954 -> V=1.0, theta=0.0
% INFO    : Bus 1619	: V=1.07975, theta=11.116625 -> V=1.0, theta=0.0
% INFO    : Bus 1620	: V=1.043596, theta=20.487381 -> V=1.0, theta=0.0
% INFO    : Bus 1621	: V=1.003202, theta=8.213746 -> V=1.0, theta=0.0
% INFO    : Bus 1622	: V=1.006471, theta=24.363227 -> V=1.0, theta=0.0
% INFO    : Bus 1623	: V=1.024326, theta=15.431611 -> V=1.0, theta=0.0
% INFO    : Bus 1624	: V=1.110428, theta=4.110338 -> V=1.0, theta=0.0
% INFO    : Bus 1625	: V=1.031122, theta=-16.175337 -> V=1.0, theta=0.0
% INFO    : Bus 1626	: V=0.999166, theta=6.82436 -> V=1.0, theta=0.0
% INFO    : Bus 1627	: V=1.050142, theta=-0.087597 -> V=1.0, theta=0.0
% INFO    : Bus 1628	: V=1.018402, theta=14.715203 -> V=1.0, theta=0.0
% INFO    : Bus 1629	: V=1.026298, theta=27.062483 -> V=1.0, theta=0.0
% INFO    : Bus 1630	: V=0.962206, theta=-0.774182 -> V=1.0, theta=0.0
% INFO    : Bus 1631	: V=1.052654, theta=21.51137 -> V=1.0, theta=0.0
% INFO    : Bus 1632	: V=1.031924, theta=11.492212 -> V=1.0, theta=0.0
% INFO    : Bus 1633	: V=1.03559, theta=5.457408 -> V=1.0, theta=0.0
% INFO    : Bus 1634	: V=1.098165, theta=34.420929 -> V=1.0, theta=0.0
% INFO    : Bus 1635	: V=1.026075, theta=0.540039 -> V=1.0, theta=0.0
% INFO    : Bus 1636	: V=1.033848, theta=35.240634 -> V=1.0, theta=0.0
% INFO    : Bus 1637	: V=1.005728, theta=-22.029535 -> V=1.0, theta=0.0
% INFO    : Bus 1638	: V=1.039203, theta=24.660347 -> V=1.0, theta=0.0
% INFO    : Bus 1639	: V=1.080579, theta=-2.979957 -> V=1.0, theta=0.0
% INFO    : Bus 1640	: V=0.994858, theta=32.812983 -> V=1.0, theta=0.0
% INFO    : Bus 1641	: V=1.01282, theta=1.386847 -> V=1.0, theta=0.0
% INFO    : Bus 1642	: V=1.012131, theta=24.048464 -> V=1.0, theta=0.0
% INFO    : Bus 1643	: V=1.026591, theta=-0.512107 -> V=1.0, theta=0.0
% INFO    : Bus 1644	: V=1.042135, theta=37.953176 -> V=1.0, theta=0.0
% INFO    : Bus 1645	: V=1.00771, theta=62.900668 -> V=1.0, theta=0.0
% INFO    : Bus 1646	: V=1.038782, theta=4.48626 -> V=1.0, theta=0.0
% INFO    : Bus 1647	: V=1.037487, theta=24.088495 -> V=1.0, theta=0.0
% INFO    : Bus 1648	: V=0.987725, theta=33.846731 -> V=1.0, theta=0.0
% INFO    : Bus 1649	: V=1.008538, theta=29.987076 -> V=1.0, theta=0.0
% INFO    : Bus 1650	: V=1.039688, theta=-10.445191 -> V=1.0, theta=0.0
% INFO    : Bus 1651	: V=1.028392, theta=52.702197 -> V=1.0, theta=0.0
% INFO    : Bus 1652	: V=0.948903, theta=26.443293 -> V=1.0, theta=0.0
% INFO    : Bus 1653	: V=1.029276, theta=26.312713 -> V=1.0, theta=0.0
% INFO    : Bus 1654	: V=1.029758, theta=-0.312213 -> V=1.0, theta=0.0
% INFO    : Bus 1655	: V=1.024295, theta=-24.350532 -> V=1.0, theta=0.0
% INFO    : Bus 1656	: V=1.062519, theta=23.472046 -> V=1.0, theta=0.0
% INFO    : Bus 1657	: V=1.031004, theta=8.006228 -> V=1.0, theta=0.0
% INFO    : Bus 1658	: V=1.000694, theta=-7.123335 -> V=1.0, theta=0.0
% INFO    : Bus 1659	: V=0.993012, theta=40.431099 -> V=1.0, theta=0.0
% INFO    : Bus 1660	: V=0.986622, theta=-8.004861 -> V=1.0, theta=0.0
% INFO    : Bus 1661	: V=1.051456, theta=33.495027 -> V=1.0, theta=0.0
% INFO    : Bus 1662	: V=1.027716, theta=27.965045 -> V=1.0, theta=0.0
% INFO    : Bus 1663	: V=1.022433, theta=23.470814 -> V=1.0, theta=0.0
% INFO    : Bus 1664	: V=0.995602, theta=27.675294 -> V=1.0, theta=0.0
% INFO    : Bus 1665	: V=1.031097, theta=34.909723 -> V=1.0, theta=0.0
% INFO    : Bus 1666	: V=1.017928, theta=7.402342 -> V=1.0, theta=0.0
% INFO    : Bus 1667	: V=1.015463, theta=32.987394 -> V=1.0, theta=0.0
% INFO    : Bus 1668	: V=1.007044, theta=32.287282 -> V=1.0, theta=0.0
% INFO    : Bus 1669	: V=0.997706, theta=-9.08371 -> V=1.0, theta=0.0
% INFO    : Bus 1670	: V=1.036348, theta=43.634336 -> V=1.0, theta=0.0
% INFO    : Bus 1671	: V=1.036105, theta=-7.389707 -> V=1.0, theta=0.0
% INFO    : Bus 1672	: V=1.023538, theta=-11.335143 -> V=1.0, theta=0.0
% INFO    : Bus 1673	: V=1.032768, theta=-14.901123 -> V=1.0, theta=0.0
% INFO    : Bus 1674	: V=1.027028, theta=1.510678 -> V=1.0, theta=0.0
% INFO    : Bus 1675	: V=1.050379, theta=33.293543 -> V=1.0, theta=0.0
% INFO    : Bus 1676	: V=0.989504, theta=-26.003725 -> V=1.0, theta=0.0
% INFO    : Bus 1677	: V=1.03233, theta=-3.90576 -> V=1.0, theta=0.0
% INFO    : Bus 1678	: V=1.026263, theta=-4.032324 -> V=1.0, theta=0.0
% INFO    : Bus 1679	: V=1.024381, theta=4.28593 -> V=1.0, theta=0.0
% INFO    : Bus 1680	: V=1.023576, theta=-14.051827 -> V=1.0, theta=0.0
% INFO    : Bus 1681	: V=0.998143, theta=-10.564266 -> V=1.0, theta=0.0
% INFO    : Bus 1682	: V=1.043684, theta=-12.356638 -> V=1.0, theta=0.0
% INFO    : Bus 1683	: V=1.016748, theta=-0.472433 -> V=1.0, theta=0.0
% INFO    : Bus 1684	: V=1.046981, theta=83.09022 -> V=1.0, theta=0.0
% INFO    : Bus 1685	: V=1.010291, theta=28.950447 -> V=1.0, theta=0.0
% INFO    : Bus 1686	: V=1.049391, theta=28.038123 -> V=1.0, theta=0.0
% INFO    : Bus 1687	: V=1.029649, theta=-5.32138 -> V=1.0, theta=0.0
% INFO    : Bus 1688	: V=1.010338, theta=7.101232 -> V=1.0, theta=0.0
% INFO    : Bus 1689	: V=1.043738, theta=28.126856 -> V=1.0, theta=0.0
% INFO    : Bus 1690	: V=1.019192, theta=18.214373 -> V=1.0, theta=0.0
% INFO    : Bus 1691	: V=1.030474, theta=19.396926 -> V=1.0, theta=0.0
% INFO    : Bus 1692	: V=1.007571, theta=-16.567631 -> V=1.0, theta=0.0
% INFO    : Bus 1693	: V=0.997319, theta=27.375421 -> V=1.0, theta=0.0
% INFO    : Bus 1694	: V=1.043979, theta=24.689649 -> V=1.0, theta=0.0
% INFO    : Bus 1695	: V=1.048376, theta=15.262753 -> V=1.0, theta=0.0
% INFO    : Bus 1696	: V=1.029257, theta=65.057244 -> V=1.0, theta=0.0
% INFO    : Bus 1697	: V=0.996164, theta=2.095783 -> V=1.0, theta=0.0
% INFO    : Bus 1698	: V=0.987249, theta=13.896936 -> V=1.0, theta=0.0
% INFO    : Bus 1699	: V=0.976428, theta=-3.019212 -> V=1.0, theta=0.0
% INFO    : Bus 1700	: V=1.034556, theta=18.42067 -> V=1.0, theta=0.0
% INFO    : Bus 1701	: V=1.036966, theta=15.051213 -> V=1.0, theta=0.0
% INFO    : Bus 1702	: V=1.030863, theta=14.68831 -> V=1.0, theta=0.0
% INFO    : Bus 1703	: V=1.006316, theta=26.135381 -> V=1.0, theta=0.0
% INFO    : Bus 1704	: V=1.08513, theta=1.171749 -> V=1.0, theta=0.0
% INFO    : Bus 1705	: V=1.035803, theta=-3.943509 -> V=1.0, theta=0.0
% INFO    : Bus 1706	: V=0.980003, theta=-5.079566 -> V=1.0, theta=0.0
% INFO    : Bus 1707	: V=0.974808, theta=13.364665 -> V=1.0, theta=0.0
% INFO    : Bus 1708	: V=1.052451, theta=2.236915 -> V=1.0, theta=0.0
% INFO    : Bus 1709	: V=1.006512, theta=-13.785134 -> V=1.0, theta=0.0
% INFO    : Bus 1710	: V=1.030846, theta=9.19717 -> V=1.0, theta=0.0
% INFO    : Bus 1711	: V=1.127285, theta=-1.495208 -> V=1.0, theta=0.0
% INFO    : Bus 1712	: V=1.015535, theta=16.842725 -> V=1.0, theta=0.0
% INFO    : Bus 1713	: V=1.06612, theta=-4.564989 -> V=1.0, theta=0.0
% INFO    : Bus 1714	: V=1.005239, theta=28.687581 -> V=1.0, theta=0.0
% INFO    : Bus 1715	: V=0.961566, theta=-8.310096 -> V=1.0, theta=0.0
% INFO    : Bus 1716	: V=1.022288, theta=26.268365 -> V=1.0, theta=0.0
% INFO    : Bus 1717	: V=1.006656, theta=17.569983 -> V=1.0, theta=0.0
% INFO    : Bus 1718	: V=0.984449, theta=-9.992776 -> V=1.0, theta=0.0
% INFO    : Bus 1719	: V=1.01352, theta=-5.029621 -> V=1.0, theta=0.0
% INFO    : Bus 1720	: V=1.085024, theta=10.7034 -> V=1.0, theta=0.0
% INFO    : Bus 1721	: V=1.150964, theta=0.206027 -> V=1.0, theta=0.0
% INFO    : Bus 1722	: V=1.007874, theta=18.273992 -> V=1.0, theta=0.0
% INFO    : Bus 1723	: V=1.017683, theta=43.672345 -> V=1.0, theta=0.0
% INFO    : Bus 1724	: V=1.03251, theta=-0.902957 -> V=1.0, theta=0.0
% INFO    : Bus 1725	: V=1.032164, theta=20.701685 -> V=1.0, theta=0.0
% INFO    : Bus 1726	: V=1.058676, theta=15.850616 -> V=1.0, theta=0.0
% INFO    : Bus 1727	: V=0.961076, theta=-15.147703 -> V=1.0, theta=0.0
% INFO    : Bus 1728	: V=0.975077, theta=-12.260891 -> V=1.0, theta=0.0
% INFO    : Bus 1729	: V=1.074971, theta=35.609269 -> V=1.0, theta=0.0
% INFO    : Bus 1730	: V=1.022999, theta=25.475204 -> V=1.0, theta=0.0
% INFO    : Bus 1731	: V=1.028604, theta=-12.690591 -> V=1.0, theta=0.0
% INFO    : Bus 1732	: V=1.03036, theta=-6.512869 -> V=1.0, theta=0.0
% INFO    : Bus 1733	: V=1.000553, theta=15.509241 -> V=1.0, theta=0.0
% INFO    : Bus 1734	: V=1.068377, theta=26.459749 -> V=1.0, theta=0.0
% INFO    : Bus 1735	: V=1.068377, theta=26.459749 -> V=1.0, theta=0.0
% INFO    : Bus 1736	: V=1.042308, theta=10.509848 -> V=1.0, theta=0.0
% INFO    : Bus 1737	: V=1.096519, theta=-4.58332 -> V=1.0, theta=0.0
% INFO    : Bus 1738	: V=1.020198, theta=36.372942 -> V=1.0, theta=0.0
% INFO    : Bus 1739	: V=0.978756, theta=-8.89294 -> V=1.0, theta=0.0
% INFO    : Bus 1740	: V=0.975704, theta=5.743947 -> V=1.0, theta=0.0
% INFO    : Bus 1741	: V=1.023788, theta=-1.119868 -> V=1.0, theta=0.0
% INFO    : Bus 1742	: V=1.00201, theta=-7.836312 -> V=1.0, theta=0.0
% INFO    : Bus 1743	: V=1.019118, theta=-22.616319 -> V=1.0, theta=0.0
% INFO    : Bus 1744	: V=1.014828, theta=22.549373 -> V=1.0, theta=0.0
% INFO    : Bus 1745	: V=1.039129, theta=13.113694 -> V=1.0, theta=0.0
% INFO    : Bus 1746	: V=0.997864, theta=19.705031 -> V=1.0, theta=0.0
% INFO    : Bus 1747	: V=1.02833, theta=44.732893 -> V=1.0, theta=0.0
% INFO    : Bus 1748	: V=1.081511, theta=24.720091 -> V=1.0, theta=0.0
% INFO    : Bus 1749	: V=1.009892, theta=4.868208 -> V=1.0, theta=0.0
% INFO    : Bus 1750	: V=1.061222, theta=57.751527 -> V=1.0, theta=0.0
% INFO    : Bus 1751	: V=1.061222, theta=57.751527 -> V=1.0, theta=0.0
% INFO    : Bus 1752	: V=1.042878, theta=84.226782 -> V=1.0, theta=0.0
% INFO    : Bus 1753	: V=1.055148, theta=5.178293 -> V=1.0, theta=0.0
% INFO    : Bus 1754	: V=0.986144, theta=-28.039313 -> V=1.0, theta=0.0
% INFO    : Bus 1755	: V=1.016839, theta=-13.978622 -> V=1.0, theta=0.0
% INFO    : Bus 1756	: V=1.004472, theta=-10.478046 -> V=1.0, theta=0.0
% INFO    : Bus 1757	: V=1.024762, theta=17.972121 -> V=1.0, theta=0.0
% INFO    : Bus 1758	: V=1.071437, theta=24.004582 -> V=1.0, theta=0.0
% INFO    : Bus 1759	: V=1.080236, theta=84.291341 -> V=1.0, theta=0.0
% INFO    : Bus 1760	: V=1.026126, theta=7.522777 -> V=1.0, theta=0.0
% INFO    : Bus 1761	: V=1.011735, theta=-3.055011 -> V=1.0, theta=0.0
% INFO    : Bus 1762	: V=0.988344, theta=-4.51079 -> V=1.0, theta=0.0
% INFO    : Bus 1763	: V=1.022099, theta=17.218586 -> V=1.0, theta=0.0
% INFO    : Bus 1764	: V=1.015505, theta=-3.112218 -> V=1.0, theta=0.0
% INFO    : Bus 1765	: V=1.047457, theta=18.999824 -> V=1.0, theta=0.0
% INFO    : Bus 1766	: V=1.005802, theta=18.488347 -> V=1.0, theta=0.0
% INFO    : Bus 1767	: V=0.983671, theta=-7.624866 -> V=1.0, theta=0.0
% INFO    : Bus 1768	: V=1.02702, theta=21.390252 -> V=1.0, theta=0.0
% INFO    : Bus 1769	: V=1.002913, theta=-8.664264 -> V=1.0, theta=0.0
% INFO    : Bus 1770	: V=1.040009, theta=86.062395 -> V=1.0, theta=0.0
% INFO    : Bus 1771	: V=1.008369, theta=47.486691 -> V=1.0, theta=0.0
% INFO    : Bus 1772	: V=1.040009, theta=86.062395 -> V=1.0, theta=0.0
% INFO    : Bus 1773	: V=0.982965, theta=-6.219482 -> V=1.0, theta=0.0
% INFO    : Bus 1774	: V=1.043619, theta=-8.436397 -> V=1.0, theta=0.0
% INFO    : Bus 1775	: V=1.024001, theta=31.504337 -> V=1.0, theta=0.0
% INFO    : Bus 1776	: V=1.055355, theta=-2.286835 -> V=1.0, theta=0.0
% INFO    : Bus 1777	: V=0.992335, theta=-2.275176 -> V=1.0, theta=0.0
% INFO    : Bus 1778	: V=1.017294, theta=-9.17725 -> V=1.0, theta=0.0
% INFO    : Bus 1779	: V=1.03133, theta=64.946605 -> V=1.0, theta=0.0
% INFO    : Bus 1780	: V=1.126128, theta=-1.959378 -> V=1.0, theta=0.0
% INFO    : Bus 1781	: V=1.01137, theta=41.620925 -> V=1.0, theta=0.0
% INFO    : Bus 1782	: V=1.008994, theta=-13.540968 -> V=1.0, theta=0.0
% INFO    : Bus 1783	: V=1.03164, theta=8.485177 -> V=1.0, theta=0.0
% INFO    : Bus 1784	: V=1.005587, theta=10.408982 -> V=1.0, theta=0.0
% INFO    : Bus 1785	: V=1.014214, theta=1.008491 -> V=1.0, theta=0.0
% INFO    : Bus 1786	: V=1.022087, theta=-22.528665 -> V=1.0, theta=0.0
% INFO    : Bus 1787	: V=0.977544, theta=-15.597058 -> V=1.0, theta=0.0
% INFO    : Bus 1788	: V=1.026706, theta=3.473674 -> V=1.0, theta=0.0
% INFO    : Bus 1789	: V=0.998882, theta=24.025243 -> V=1.0, theta=0.0
% INFO    : Bus 1790	: V=0.997327, theta=-7.348981 -> V=1.0, theta=0.0
% INFO    : Bus 1791	: V=1.016081, theta=21.284924 -> V=1.0, theta=0.0
% INFO    : Bus 1792	: V=1.019347, theta=-2.997978 -> V=1.0, theta=0.0
% INFO    : Bus 1793	: V=0.994612, theta=-18.861992 -> V=1.0, theta=0.0
% INFO    : Bus 1794	: V=1.024544, theta=18.974877 -> V=1.0, theta=0.0
% INFO    : Bus 1795	: V=1.020774, theta=-8.3858 -> V=1.0, theta=0.0
% INFO    : Bus 1796	: V=1.008485, theta=2.759897 -> V=1.0, theta=0.0
% INFO    : Bus 1797	: V=0.993529, theta=-10.710423 -> V=1.0, theta=0.0
% INFO    : Bus 1798	: V=0.998219, theta=11.690674 -> V=1.0, theta=0.0
% INFO    : Bus 1799	: V=0.95548, theta=0.062075 -> V=1.0, theta=0.0
% INFO    : Bus 1800	: V=0.992174, theta=-3.580764 -> V=1.0, theta=0.0
% INFO    : Bus 1801	: V=1.058149, theta=41.053759 -> V=1.0, theta=0.0
% INFO    : Bus 1802	: V=0.990018, theta=-6.93099 -> V=1.0, theta=0.0
% INFO    : Bus 1803	: V=1.018554, theta=-1.801383 -> V=1.0, theta=0.0
% INFO    : Bus 1804	: V=1.018603, theta=25.307117 -> V=1.0, theta=0.0
% INFO    : Bus 1805	: V=1.023695, theta=-0.879651 -> V=1.0, theta=0.0
% INFO    : Bus 1806	: V=1.035794, theta=12.685893 -> V=1.0, theta=0.0
% INFO    : Bus 1807	: V=1.023695, theta=-0.879651 -> V=1.0, theta=0.0
% INFO    : Bus 1808	: V=1.018554, theta=-1.801383 -> V=1.0, theta=0.0
% INFO    : Bus 1809	: V=0.987681, theta=-22.129778 -> V=1.0, theta=0.0
% INFO    : Bus 1810	: V=1.061635, theta=-9.161951 -> V=1.0, theta=0.0
% INFO    : Bus 1811	: V=0.98112, theta=0.528152 -> V=1.0, theta=0.0
% INFO    : Bus 1812	: V=1.031971, theta=-3.542743 -> V=1.0, theta=0.0
% INFO    : Bus 1813	: V=1.012457, theta=-4.968966 -> V=1.0, theta=0.0
% INFO    : Bus 1814	: V=1.031498, theta=-19.60853 -> V=1.0, theta=0.0
% INFO    : Bus 1815	: V=1.007614, theta=14.656778 -> V=1.0, theta=0.0
% INFO    : Bus 1816	: V=1.042445, theta=10.433315 -> V=1.0, theta=0.0
% INFO    : Bus 1817	: V=1.046727, theta=-2.648573 -> V=1.0, theta=0.0
% INFO    : Bus 1818	: V=0.991625, theta=-3.871698 -> V=1.0, theta=0.0
% INFO    : Bus 1819	: V=1.043584, theta=8.515333 -> V=1.0, theta=0.0
% INFO    : Bus 1820	: V=1.013812, theta=18.281622 -> V=1.0, theta=0.0
% INFO    : Bus 1821	: V=1.011416, theta=44.498643 -> V=1.0, theta=0.0
% INFO    : Bus 1822	: V=1.035162, theta=21.902936 -> V=1.0, theta=0.0
% INFO    : Bus 1823	: V=1.046766, theta=42.710463 -> V=1.0, theta=0.0
% INFO    : Bus 1824	: V=1.01493, theta=-10.961932 -> V=1.0, theta=0.0
% INFO    : Bus 1825	: V=1.025109, theta=-10.517266 -> V=1.0, theta=0.0
% INFO    : Bus 1826	: V=0.936118, theta=-10.724498 -> V=1.0, theta=0.0
% INFO    : Bus 1827	: V=0.982566, theta=-11.168107 -> V=1.0, theta=0.0
% INFO    : Bus 1828	: V=0.993076, theta=11.776433 -> V=1.0, theta=0.0
% INFO    : Bus 1829	: V=1.053882, theta=4.374174 -> V=1.0, theta=0.0
% INFO    : Bus 1830	: V=1.00348, theta=19.229454 -> V=1.0, theta=0.0
% INFO    : Bus 1831	: V=1.043059, theta=9.285297 -> V=1.0, theta=0.0
% INFO    : Bus 1832	: V=0.989657, theta=-1.540359 -> V=1.0, theta=0.0
% INFO    : Bus 1833	: V=1.019509, theta=-20.798895 -> V=1.0, theta=0.0
% INFO    : Bus 1834	: V=0.998251, theta=7.060817 -> V=1.0, theta=0.0
% INFO    : Bus 1835	: V=0.995787, theta=20.301147 -> V=1.0, theta=0.0
% INFO    : Bus 1836	: V=1.006718, theta=-12.119029 -> V=1.0, theta=0.0
% INFO    : Bus 1837	: V=1.019633, theta=-8.384664 -> V=1.0, theta=0.0
% INFO    : Bus 1838	: V=1.001725, theta=-3.617498 -> V=1.0, theta=0.0
% INFO    : Bus 1839	: V=1.019231, theta=22.327173 -> V=1.0, theta=0.0
% INFO    : Bus 1840	: V=1.033947, theta=-9.228621 -> V=1.0, theta=0.0
% INFO    : Bus 1841	: V=0.974052, theta=-15.620125 -> V=1.0, theta=0.0
% INFO    : Bus 1842	: V=0.950524, theta=-8.554178 -> V=1.0, theta=0.0
% INFO    : Bus 1843	: V=0.923452, theta=-12.26721 -> V=1.0, theta=0.0
% INFO    : Bus 1844	: V=1.027844, theta=0.686907 -> V=1.0, theta=0.0
% INFO    : Bus 1845	: V=0.962614, theta=39.578299 -> V=1.0, theta=0.0
% INFO    : Bus 1846	: V=0.99762, theta=-1.846002 -> V=1.0, theta=0.0
% INFO    : Bus 1847	: V=1.00818, theta=22.120561 -> V=1.0, theta=0.0
% INFO    : Bus 1848	: V=1.028496, theta=44.093107 -> V=1.0, theta=0.0
% INFO    : Bus 1849	: V=0.981635, theta=-15.100371 -> V=1.0, theta=0.0
% INFO    : Bus 1850	: V=1.032021, theta=6.627548 -> V=1.0, theta=0.0
% INFO    : Bus 1851	: V=1.058231, theta=41.885187 -> V=1.0, theta=0.0
% INFO    : Bus 1852	: V=0.973955, theta=-7.167886 -> V=1.0, theta=0.0
% INFO    : Bus 1853	: V=1.031737, theta=11.756042 -> V=1.0, theta=0.0
% INFO    : Bus 1854	: V=1.047805, theta=17.179536 -> V=1.0, theta=0.0
% INFO    : Bus 1855	: V=0.984485, theta=-4.527908 -> V=1.0, theta=0.0
% INFO    : Bus 1856	: V=1.025593, theta=-0.389646 -> V=1.0, theta=0.0
% INFO    : Bus 1857	: V=0.955374, theta=-4.828749 -> V=1.0, theta=0.0
% INFO    : Bus 1858	: V=0.942852, theta=-11.019109 -> V=1.0, theta=0.0
% INFO    : Bus 1859	: V=1.008235, theta=8.191752 -> V=1.0, theta=0.0
% INFO    : Bus 1860	: V=1.013247, theta=13.29657 -> V=1.0, theta=0.0
% INFO    : Bus 1861	: V=1.010307, theta=-11.825094 -> V=1.0, theta=0.0
% INFO    : Bus 1862	: V=1.013327, theta=-1.436043 -> V=1.0, theta=0.0
% INFO    : Bus 1863	: V=0.981273, theta=-7.052661 -> V=1.0, theta=0.0
% INFO    : Bus 1864	: V=1.021349, theta=-2.688037 -> V=1.0, theta=0.0
% INFO    : Bus 1865	: V=0.996575, theta=38.818652 -> V=1.0, theta=0.0
% INFO    : Bus 1866	: V=1.054745, theta=-6.214548 -> V=1.0, theta=0.0
% INFO    : Bus 1867	: V=1.007945, theta=-21.264125 -> V=1.0, theta=0.0
% INFO    : Bus 1868	: V=0.989649, theta=6.296698 -> V=1.0, theta=0.0
% INFO    : Bus 1869	: V=1.017464, theta=-4.981811 -> V=1.0, theta=0.0
% INFO    : Bus 1870	: V=1.017517, theta=3.740543 -> V=1.0, theta=0.0
% INFO    : Bus 1871	: V=0.990878, theta=-13.512721 -> V=1.0, theta=0.0
% INFO    : Bus 1872	: V=1.009026, theta=29.741759 -> V=1.0, theta=0.0
% INFO    : Bus 1873	: V=1.024193, theta=-3.16787 -> V=1.0, theta=0.0
% INFO    : Bus 1874	: V=1.026773, theta=-4.248659 -> V=1.0, theta=0.0
% INFO    : Bus 1875	: V=1.039974, theta=-6.001274 -> V=1.0, theta=0.0
% INFO    : Bus 1876	: V=1.024324, theta=-10.377063 -> V=1.0, theta=0.0
% INFO    : Bus 1877	: V=1.024324, theta=-10.377063 -> V=1.0, theta=0.0
% INFO    : Bus 1878	: V=1.024324, theta=-10.377063 -> V=1.0, theta=0.0
% INFO    : Bus 1879	: V=1.024324, theta=-10.377063 -> V=1.0, theta=0.0
% INFO    : Bus 1880	: V=1.024324, theta=-10.377063 -> V=1.0, theta=0.0
% INFO    : Bus 1881	: V=1.024324, theta=-10.377063 -> V=1.0, theta=0.0
% INFO    : Bus 1882	: V=1.015006, theta=-6.446837 -> V=1.0, theta=0.0
% INFO    : Bus 1883	: V=1.015006, theta=-6.446837 -> V=1.0, theta=0.0
% INFO    : Bus 1884	: V=1.015006, theta=-6.446837 -> V=1.0, theta=0.0
% INFO    : Bus 1885	: V=1.026524, theta=-6.800114 -> V=1.0, theta=0.0
% INFO    : Bus 1886	: V=1.005046, theta=28.526638 -> V=1.0, theta=0.0
% INFO    : Bus 1887	: V=0.96929, theta=22.580591 -> V=1.0, theta=0.0
% INFO    : Bus 1888	: V=1.02223, theta=-11.03513 -> V=1.0, theta=0.0
% INFO    : Bus 1889	: V=1.022889, theta=18.879559 -> V=1.0, theta=0.0
% INFO    : Bus 1890	: V=0.99663, theta=-4.736881 -> V=1.0, theta=0.0
% INFO    : Bus 1891	: V=1.016347, theta=-11.53137 -> V=1.0, theta=0.0
% INFO    : Bus 1892	: V=1.059249, theta=20.524844 -> V=1.0, theta=0.0
% INFO    : Bus 1893	: V=1.042632, theta=13.310034 -> V=1.0, theta=0.0
% INFO    : Bus 1894	: V=1.04959, theta=20.547418 -> V=1.0, theta=0.0
% INFO    : Bus 1895	: V=1.029146, theta=3.188044 -> V=1.0, theta=0.0
% INFO    : Bus 1896	: V=1.012991, theta=3.357398 -> V=1.0, theta=0.0
% INFO    : Bus 1897	: V=1.00589, theta=17.856342 -> V=1.0, theta=0.0
% INFO    : Bus 1898	: V=1.060486, theta=9.337743 -> V=1.0, theta=0.0
% INFO    : Bus 1899	: V=1.022122, theta=38.733805 -> V=1.0, theta=0.0
% INFO    : Bus 1900	: V=1.040198, theta=-18.927563 -> V=1.0, theta=0.0
% INFO    : Bus 1901	: V=0.923978, theta=-8.123126 -> V=1.0, theta=0.0
% INFO    : Bus 1902	: V=1.023748, theta=14.863019 -> V=1.0, theta=0.0
% INFO    : Bus 1903	: V=1.031159, theta=7.793526 -> V=1.0, theta=0.0
% INFO    : Bus 1904	: V=0.999453, theta=-5.145639 -> V=1.0, theta=0.0
% INFO    : Bus 1905	: V=0.983412, theta=14.056335 -> V=1.0, theta=0.0
% INFO    : Bus 1906	: V=0.999838, theta=14.362863 -> V=1.0, theta=0.0
% INFO    : Bus 1907	: V=1.007227, theta=24.551226 -> V=1.0, theta=0.0
% INFO    : Bus 1908	: V=1.033278, theta=-18.937067 -> V=1.0, theta=0.0
% INFO    : Bus 1909	: V=0.984339, theta=88.942359 -> V=1.0, theta=0.0
% INFO    : Bus 1910	: V=1.00975, theta=7.1093 -> V=1.0, theta=0.0
% INFO    : Bus 1911	: V=1.015708, theta=-26.173758 -> V=1.0, theta=0.0
% INFO    : Bus 1912	: V=1.011379, theta=19.937648 -> V=1.0, theta=0.0
% INFO    : Bus 1913	: V=1.042096, theta=35.548796 -> V=1.0, theta=0.0
% INFO    : Bus 1914	: V=1.042096, theta=35.548796 -> V=1.0, theta=0.0
% INFO    : Bus 1915	: V=1.024484, theta=26.245019 -> V=1.0, theta=0.0
% INFO    : Bus 1916	: V=0.948801, theta=6.067726 -> V=1.0, theta=0.0
% INFO    : Bus 1917	: V=1.03672, theta=25.549676 -> V=1.0, theta=0.0
% INFO    : Bus 1918	: V=0.996071, theta=-1.070853 -> V=1.0, theta=0.0
% INFO    : Bus 1919	: V=1.021438, theta=22.294536 -> V=1.0, theta=0.0
% INFO    : Bus 1920	: V=1.022555, theta=21.016577 -> V=1.0, theta=0.0
% INFO    : Bus 1921	: V=1.011947, theta=-10.122615 -> V=1.0, theta=0.0
% INFO    : Bus 1922	: V=1.002616, theta=29.478033 -> V=1.0, theta=0.0
% INFO    : Bus 1923	: V=0.968083, theta=-11.943757 -> V=1.0, theta=0.0
% INFO    : Bus 1924	: V=1.017203, theta=24.892446 -> V=1.0, theta=0.0
% INFO    : Bus 1925	: V=1.077741, theta=1.680409 -> V=1.0, theta=0.0
% INFO    : Bus 1926	: V=0.984054, theta=-2.85841 -> V=1.0, theta=0.0
% INFO    : Bus 1927	: V=1.069883, theta=58.677401 -> V=1.0, theta=0.0
% INFO    : Bus 1928	: V=0.999593, theta=27.016686 -> V=1.0, theta=0.0
% INFO    : Bus 1929	: V=0.974224, theta=7.613845 -> V=1.0, theta=0.0
% INFO    : Bus 1930	: V=1.039102, theta=17.583714 -> V=1.0, theta=0.0
% INFO    : Bus 1931	: V=1.031453, theta=-10.473783 -> V=1.0, theta=0.0
% INFO    : Bus 1932	: V=1.016993, theta=30.047809 -> V=1.0, theta=0.0
% INFO    : Bus 1933	: V=0.963828, theta=-9.831601 -> V=1.0, theta=0.0
% INFO    : Bus 1934	: V=1.036112, theta=19.191894 -> V=1.0, theta=0.0
% INFO    : Bus 1935	: V=1.048808, theta=20.576441 -> V=1.0, theta=0.0
% INFO    : Bus 1936	: V=1.048808, theta=20.576441 -> V=1.0, theta=0.0
% INFO    : Bus 1937	: V=1.028386, theta=33.436937 -> V=1.0, theta=0.0
% INFO    : Bus 1938	: V=1.007899, theta=-8.721694 -> V=1.0, theta=0.0
% INFO    : Bus 1939	: V=1.024597, theta=3.62755 -> V=1.0, theta=0.0
% INFO    : Bus 1940	: V=1.061603, theta=44.385823 -> V=1.0, theta=0.0
% INFO    : Bus 1941	: V=1.029562, theta=-6.831163 -> V=1.0, theta=0.0
% INFO    : Bus 1942	: V=1.004021, theta=26.366061 -> V=1.0, theta=0.0
% INFO    : Bus 1943	: V=0.998756, theta=-10.351408 -> V=1.0, theta=0.0
% INFO    : Bus 1944	: V=1.045322, theta=15.214941 -> V=1.0, theta=0.0
% INFO    : Bus 1945	: V=0.953415, theta=-6.243675 -> V=1.0, theta=0.0
% INFO    : Bus 1946	: V=1.014073, theta=1.963772 -> V=1.0, theta=0.0
% INFO    : Bus 1947	: V=1.007442, theta=-12.200575 -> V=1.0, theta=0.0
% INFO    : Bus 1948	: V=0.962245, theta=-6.704835 -> V=1.0, theta=0.0
% INFO    : Bus 1949	: V=1.00597, theta=27.345397 -> V=1.0, theta=0.0
% INFO    : Bus 1950	: V=0.990306, theta=33.144365 -> V=1.0, theta=0.0
% INFO    : Bus 1951	: V=1.035714, theta=-6.509155 -> V=1.0, theta=0.0
% INFO    : Bus 1952	: V=1.01008, theta=26.93927 -> V=1.0, theta=0.0
% INFO    : Bus 1953	: V=1.023321, theta=-15.334384 -> V=1.0, theta=0.0
% INFO    : Bus 1954	: V=1.023321, theta=-15.334384 -> V=1.0, theta=0.0
% INFO    : Bus 1955	: V=1.026243, theta=6.043442 -> V=1.0, theta=0.0
% INFO    : Bus 1956	: V=0.980421, theta=27.054435 -> V=1.0, theta=0.0
% INFO    : Bus 1957	: V=1.019066, theta=-10.738952 -> V=1.0, theta=0.0
% INFO    : Bus 1958	: V=0.991285, theta=-10.566094 -> V=1.0, theta=0.0
% INFO    : Bus 1959	: V=1.023372, theta=9.393826 -> V=1.0, theta=0.0
% INFO    : Bus 1960	: V=1.019, theta=-2.975058 -> V=1.0, theta=0.0
% INFO    : Bus 1961	: V=0.996564, theta=21.128006 -> V=1.0, theta=0.0
% INFO    : Bus 1962	: V=0.98563, theta=89.067595 -> V=1.0, theta=0.0
% INFO    : Bus 1963	: V=1.015227, theta=-3.436884 -> V=1.0, theta=0.0
% INFO    : Bus 1964	: V=1.08603, theta=72.320383 -> V=1.0, theta=0.0
% INFO    : Bus 1965	: V=0.980905, theta=89.087518 -> V=1.0, theta=0.0
% INFO    : Bus 1966	: V=1.051329, theta=90.483342 -> V=1.0, theta=0.0
% INFO    : Bus 1967	: V=1.051329, theta=90.483342 -> V=1.0, theta=0.0
% INFO    : Bus 1968	: V=1.001857, theta=-9.078486 -> V=1.0, theta=0.0
% INFO    : Bus 1969	: V=1.01993, theta=9.094543 -> V=1.0, theta=0.0
% INFO    : Bus 1970	: V=0.990503, theta=-9.05799 -> V=1.0, theta=0.0
% INFO    : Bus 1971	: V=1.006782, theta=-15.116007 -> V=1.0, theta=0.0
% INFO    : Bus 1972	: V=1.029166, theta=13.522836 -> V=1.0, theta=0.0
% INFO    : Bus 1973	: V=1.022205, theta=-9.782228 -> V=1.0, theta=0.0
% INFO    : Bus 1974	: V=1.01575, theta=49.478918 -> V=1.0, theta=0.0
% INFO    : Bus 1975	: V=1.022085, theta=-18.016691 -> V=1.0, theta=0.0
% INFO    : Bus 1976	: V=1.024032, theta=3.456517 -> V=1.0, theta=0.0
% INFO    : Bus 1977	: V=1.046561, theta=-20.234799 -> V=1.0, theta=0.0
% INFO    : Bus 1978	: V=1.012723, theta=-6.930307 -> V=1.0, theta=0.0
% INFO    : Bus 1979	: V=1.032253, theta=-8.120405 -> V=1.0, theta=0.0
% INFO    : Bus 1980	: V=1.027181, theta=16.66973 -> V=1.0, theta=0.0
% INFO    : Bus 1981	: V=1.002482, theta=10.277586 -> V=1.0, theta=0.0
% INFO    : Bus 1982	: V=1.017507, theta=-21.662554 -> V=1.0, theta=0.0
% INFO    : Bus 1983	: V=1.011147, theta=29.27305 -> V=1.0, theta=0.0
% INFO    : Bus 1984	: V=1.033515, theta=14.852151 -> V=1.0, theta=0.0
% INFO    : Bus 1985	: V=0.961956, theta=47.51733 -> V=1.0, theta=0.0
% INFO    : Bus 1986	: V=1.025692, theta=6.014725 -> V=1.0, theta=0.0
% INFO    : Bus 1987	: V=1.060928, theta=81.98539 -> V=1.0, theta=0.0
% INFO    : Bus 1988	: V=1.027807, theta=-10.041134 -> V=1.0, theta=0.0
% INFO    : Bus 1989	: V=1.010825, theta=30.668863 -> V=1.0, theta=0.0
% INFO    : Bus 1990	: V=1.056256, theta=29.122283 -> V=1.0, theta=0.0
% INFO    : Bus 1991	: V=1.021956, theta=-10.101004 -> V=1.0, theta=0.0
% INFO    : Bus 1992	: V=1.011131, theta=4.479816 -> V=1.0, theta=0.0
% INFO    : Bus 1993	: V=0.976411, theta=-22.233533 -> V=1.0, theta=0.0
% INFO    : Bus 1994	: V=0.966913, theta=-9.382322 -> V=1.0, theta=0.0
% INFO    : Bus 1995	: V=0.989323, theta=97.08776 -> V=1.0, theta=0.0
% INFO    : Bus 1996	: V=1.030347, theta=-20.964804 -> V=1.0, theta=0.0
% INFO    : Bus 1997	: V=1.044265, theta=38.235788 -> V=1.0, theta=0.0
% INFO    : Bus 1998	: V=1.04895, theta=37.800634 -> V=1.0, theta=0.0
% INFO    : Bus 1999	: V=1.058091, theta=39.373985 -> V=1.0, theta=0.0
% INFO    : Bus 2000	: V=1.058091, theta=39.373985 -> V=1.0, theta=0.0
% INFO    : Bus 2001	: V=1.038561, theta=17.439863 -> V=1.0, theta=0.0
% INFO    : Bus 2002	: V=1.001121, theta=-3.440015 -> V=1.0, theta=0.0
% INFO    : Bus 2003	: V=1.0385, theta=19.998666 -> V=1.0, theta=0.0
% INFO    : Bus 2004	: V=1.0385, theta=19.998666 -> V=1.0, theta=0.0
% INFO    : Bus 2005	: V=1.0385, theta=19.998666 -> V=1.0, theta=0.0
% INFO    : Bus 2006	: V=1.053599, theta=21.197213 -> V=1.0, theta=0.0
% INFO    : Bus 2007	: V=0.998972, theta=2.227611 -> V=1.0, theta=0.0
% INFO    : Bus 2008	: V=1.032008, theta=18.368955 -> V=1.0, theta=0.0
% INFO    : Bus 2009	: V=0.995927, theta=-1.680715 -> V=1.0, theta=0.0
% INFO    : Bus 2010	: V=0.986291, theta=10.017412 -> V=1.0, theta=0.0
% INFO    : Bus 2011	: V=1.058091, theta=39.373985 -> V=1.0, theta=0.0
% INFO    : Bus 2012	: V=1.040793, theta=26.940223 -> V=1.0, theta=0.0
% INFO    : Bus 2013	: V=1.040793, theta=26.940223 -> V=1.0, theta=0.0
% INFO    : Bus 2014	: V=1.040793, theta=26.940223 -> V=1.0, theta=0.0
% INFO    : Bus 2015	: V=1.014279, theta=-24.903336 -> V=1.0, theta=0.0
% INFO    : Bus 2016	: V=1.023472, theta=8.423098 -> V=1.0, theta=0.0
% INFO    : Bus 2017	: V=1.005826, theta=-2.715534 -> V=1.0, theta=0.0
% INFO    : Bus 2018	: V=1.008644, theta=-0.910004 -> V=1.0, theta=0.0
% INFO    : Bus 2019	: V=1.015484, theta=31.289514 -> V=1.0, theta=0.0
% INFO    : Bus 2020	: V=1.040793, theta=26.940223 -> V=1.0, theta=0.0
% INFO    : Bus 2021	: V=1.069232, theta=53.740618 -> V=1.0, theta=0.0
% INFO    : Bus 2022	: V=0.976329, theta=-6.685752 -> V=1.0, theta=0.0
% INFO    : Bus 2023	: V=0.978493, theta=-11.442138 -> V=1.0, theta=0.0
% INFO    : Bus 2024	: V=1.03921, theta=-8.713669 -> V=1.0, theta=0.0
% INFO    : Bus 2025	: V=1.011495, theta=-23.598553 -> V=1.0, theta=0.0
% INFO    : Bus 2026	: V=0.981238, theta=-8.016126 -> V=1.0, theta=0.0
% INFO    : Bus 2027	: V=1.01658, theta=19.6589 -> V=1.0, theta=0.0
% INFO    : Bus 2028	: V=1.020551, theta=-1.791743 -> V=1.0, theta=0.0
% INFO    : Bus 2029	: V=1.017947, theta=-17.668188 -> V=1.0, theta=0.0
% INFO    : Bus 2030	: V=1.015266, theta=3.283199 -> V=1.0, theta=0.0
% INFO    : Bus 2031	: V=1.045752, theta=2.640675 -> V=1.0, theta=0.0
% INFO    : Bus 2032	: V=1.021846, theta=5.833793 -> V=1.0, theta=0.0
% INFO    : Bus 2033	: V=1.033157, theta=16.61434 -> V=1.0, theta=0.0
% INFO    : Bus 2034	: V=0.988998, theta=-10.568899 -> V=1.0, theta=0.0
% INFO    : Bus 2035	: V=1.030155, theta=-0.095505 -> V=1.0, theta=0.0
% INFO    : Bus 2036	: V=1.030761, theta=-20.945532 -> V=1.0, theta=0.0
% INFO    : Bus 2037	: V=0.991062, theta=20.818561 -> V=1.0, theta=0.0
% INFO    : Bus 2038	: V=1.030023, theta=-18.736805 -> V=1.0, theta=0.0
% INFO    : Bus 2039	: V=1.007012, theta=18.351122 -> V=1.0, theta=0.0
% INFO    : Bus 2040	: V=1.027588, theta=18.766692 -> V=1.0, theta=0.0
% INFO    : Bus 2041	: V=1.016874, theta=18.929174 -> V=1.0, theta=0.0
% INFO    : Bus 2042	: V=1.027071, theta=15.95651 -> V=1.0, theta=0.0
% INFO    : Bus 2043	: V=1.051863, theta=6.942059 -> V=1.0, theta=0.0
% INFO    : Bus 2044	: V=1.053612, theta=29.620375 -> V=1.0, theta=0.0
% INFO    : Bus 2045	: V=0.996044, theta=89.673422 -> V=1.0, theta=0.0
% INFO    : Bus 2046	: V=0.930348, theta=-9.655565 -> V=1.0, theta=0.0
% INFO    : Bus 2047	: V=1.05948, theta=38.842339 -> V=1.0, theta=0.0
% INFO    : Bus 2048	: V=1.047307, theta=6.762881 -> V=1.0, theta=0.0
% INFO    : Bus 2049	: V=1.056048, theta=54.150215 -> V=1.0, theta=0.0
% INFO    : Bus 2050	: V=1.058485, theta=15.237211 -> V=1.0, theta=0.0
% INFO    : Bus 2051	: V=1.034192, theta=-10.845742 -> V=1.0, theta=0.0
% INFO    : Bus 2052	: V=1.033742, theta=-16.886752 -> V=1.0, theta=0.0
% INFO    : Bus 2053	: V=1.039038, theta=39.160421 -> V=1.0, theta=0.0
% INFO    : Bus 2054	: V=1.014955, theta=-9.020008 -> V=1.0, theta=0.0
% INFO    : Bus 2055	: V=1.009821, theta=31.22273 -> V=1.0, theta=0.0
% INFO    : Bus 2056	: V=1.03472, theta=7.897462 -> V=1.0, theta=0.0
% INFO    : Bus 2057	: V=0.987847, theta=-10.788419 -> V=1.0, theta=0.0
% INFO    : Bus 2058	: V=1.028259, theta=18.983679 -> V=1.0, theta=0.0
% INFO    : Bus 2059	: V=1.018557, theta=-14.385235 -> V=1.0, theta=0.0
% INFO    : Bus 2060	: V=0.956784, theta=-8.620578 -> V=1.0, theta=0.0
% INFO    : Bus 2061	: V=0.977222, theta=-12.558727 -> V=1.0, theta=0.0
% INFO    : Bus 2062	: V=1.011552, theta=-11.845244 -> V=1.0, theta=0.0
% INFO    : Bus 2063	: V=1.013208, theta=-8.664527 -> V=1.0, theta=0.0
% INFO    : Bus 2064	: V=1.024743, theta=-10.705998 -> V=1.0, theta=0.0
% INFO    : Bus 2065	: V=1.032593, theta=8.105588 -> V=1.0, theta=0.0
% INFO    : Bus 2066	: V=1.032856, theta=3.083067 -> V=1.0, theta=0.0
% INFO    : Bus 2067	: V=1.099592, theta=65.127951 -> V=1.0, theta=0.0
% INFO    : Bus 2068	: V=1.046448, theta=-13.015813 -> V=1.0, theta=0.0
% INFO    : Bus 2069	: V=1.019153, theta=9.002657 -> V=1.0, theta=0.0
% INFO    : Bus 2070	: V=0.987889, theta=-10.352859 -> V=1.0, theta=0.0
% INFO    : Bus 2071	: V=0.999187, theta=25.525754 -> V=1.0, theta=0.0
% INFO    : Bus 2072	: V=1.013096, theta=32.553236 -> V=1.0, theta=0.0
% INFO    : Bus 2073	: V=1.001714, theta=3.036512 -> V=1.0, theta=0.0
% INFO    : Bus 2074	: V=1.006549, theta=30.289156 -> V=1.0, theta=0.0
% INFO    : Bus 2075	: V=0.982274, theta=15.279996 -> V=1.0, theta=0.0
% INFO    : Bus 2076	: V=1.091249, theta=-4.873838 -> V=1.0, theta=0.0
% INFO    : Bus 2077	: V=1.011712, theta=-8.997116 -> V=1.0, theta=0.0
% INFO    : Bus 2078	: V=1.011712, theta=-8.997116 -> V=1.0, theta=0.0
% INFO    : Bus 2079	: V=0.970356, theta=-6.496627 -> V=1.0, theta=0.0
% INFO    : Bus 2080	: V=1.043665, theta=14.930439 -> V=1.0, theta=0.0
% INFO    : Bus 2081	: V=1.02378, theta=-11.347601 -> V=1.0, theta=0.0
% INFO    : Bus 2082	: V=1.034376, theta=-4.403708 -> V=1.0, theta=0.0
% INFO    : Bus 2083	: V=0.990663, theta=15.887389 -> V=1.0, theta=0.0
% INFO    : Bus 2084	: V=1.033042, theta=-4.165701 -> V=1.0, theta=0.0
% INFO    : Bus 2085	: V=1.03432, theta=-4.425322 -> V=1.0, theta=0.0
% INFO    : Bus 2086	: V=1.03432, theta=-4.425322 -> V=1.0, theta=0.0
% INFO    : Bus 2087	: V=1.01167, theta=-8.995127 -> V=1.0, theta=0.0
% INFO    : Bus 2088	: V=1.01167, theta=-8.995127 -> V=1.0, theta=0.0
% INFO    : Bus 2089	: V=1.038677, theta=-3.733513 -> V=1.0, theta=0.0
% INFO    : Bus 2090	: V=1.030138, theta=25.689742 -> V=1.0, theta=0.0
% INFO    : Bus 2091	: V=1.030138, theta=25.689742 -> V=1.0, theta=0.0
% INFO    : Bus 2092	: V=0.989306, theta=-22.035267 -> V=1.0, theta=0.0
% INFO    : Bus 2093	: V=1.030138, theta=25.689742 -> V=1.0, theta=0.0
% INFO    : Bus 2094	: V=0.982509, theta=-2.834787 -> V=1.0, theta=0.0
% INFO    : Bus 2095	: V=0.978202, theta=-5.335353 -> V=1.0, theta=0.0
% INFO    : Bus 2096	: V=0.987179, theta=19.019867 -> V=1.0, theta=0.0
% INFO    : Bus 2097	: V=1.024484, theta=-6.060208 -> V=1.0, theta=0.0
% INFO    : Bus 2098	: V=1.01394, theta=6.023647 -> V=1.0, theta=0.0
% INFO    : Bus 2099	: V=0.966304, theta=-5.236521 -> V=1.0, theta=0.0
% INFO    : Bus 2100	: V=0.868495, theta=-15.380873 -> V=1.0, theta=0.0
% INFO    : Bus 2101	: V=1.023051, theta=34.780864 -> V=1.0, theta=0.0
% INFO    : Bus 2102	: V=1.012679, theta=-1.92622 -> V=1.0, theta=0.0
% INFO    : Bus 2103	: V=0.976063, theta=-6.122796 -> V=1.0, theta=0.0
% INFO    : Bus 2104	: V=1.035226, theta=13.284427 -> V=1.0, theta=0.0
% INFO    : Bus 2105	: V=1.021039, theta=-15.662962 -> V=1.0, theta=0.0
% INFO    : Bus 2106	: V=0.962508, theta=28.579218 -> V=1.0, theta=0.0
% INFO    : Bus 2107	: V=1.022583, theta=-10.419342 -> V=1.0, theta=0.0
% INFO    : Bus 2108	: V=0.990372, theta=-19.213624 -> V=1.0, theta=0.0
% INFO    : Bus 2109	: V=1.033996, theta=28.695012 -> V=1.0, theta=0.0
% INFO    : Bus 2110	: V=1.027323, theta=-4.289105 -> V=1.0, theta=0.0
% INFO    : Bus 2111	: V=1.027234, theta=16.676769 -> V=1.0, theta=0.0
% INFO    : Bus 2112	: V=1.036635, theta=-21.205229 -> V=1.0, theta=0.0
% INFO    : Bus 2113	: V=1.036582, theta=80.128108 -> V=1.0, theta=0.0
% INFO    : Bus 2114	: V=0.998509, theta=12.552323 -> V=1.0, theta=0.0
% INFO    : Bus 2115	: V=1.02775, theta=7.156287 -> V=1.0, theta=0.0
% INFO    : Bus 2116	: V=1.040298, theta=14.848896 -> V=1.0, theta=0.0
% INFO    : Bus 2117	: V=0.997409, theta=27.546763 -> V=1.0, theta=0.0
% INFO    : Bus 2118	: V=1.019995, theta=-8.583845 -> V=1.0, theta=0.0
% INFO    : Bus 2119	: V=1.048702, theta=40.981802 -> V=1.0, theta=0.0
% INFO    : Bus 2120	: V=1.025293, theta=-19.876992 -> V=1.0, theta=0.0
% INFO    : Bus 2121	: V=1.029357, theta=20.473844 -> V=1.0, theta=0.0
% INFO    : Bus 2122	: V=0.993105, theta=34.379244 -> V=1.0, theta=0.0
% INFO    : Bus 2123	: V=0.994655, theta=21.997919 -> V=1.0, theta=0.0
% INFO    : Bus 2124	: V=1.030794, theta=17.671729 -> V=1.0, theta=0.0
% INFO    : Bus 2125	: V=1.016921, theta=-12.573705 -> V=1.0, theta=0.0
% INFO    : Bus 2126	: V=1.019395, theta=8.024298 -> V=1.0, theta=0.0
% INFO    : Bus 2127	: V=1.004219, theta=-8.787097 -> V=1.0, theta=0.0
% INFO    : Bus 2128	: V=0.978447, theta=49.743461 -> V=1.0, theta=0.0
% INFO    : Bus 2129	: V=0.96807, theta=40.282968 -> V=1.0, theta=0.0
% INFO    : Bus 2130	: V=1.055919, theta=-12.348545 -> V=1.0, theta=0.0
% INFO    : Bus 2131	: V=0.988831, theta=38.418014 -> V=1.0, theta=0.0
% INFO    : Bus 2132	: V=0.990911, theta=-11.398259 -> V=1.0, theta=0.0
% INFO    : Bus 2133	: V=0.987324, theta=-2.421606 -> V=1.0, theta=0.0
% INFO    : Bus 2134	: V=1.015672, theta=-26.779891 -> V=1.0, theta=0.0
% INFO    : Bus 2135	: V=1.035502, theta=32.502703 -> V=1.0, theta=0.0
% INFO    : Bus 2136	: V=1.035502, theta=32.502796 -> V=1.0, theta=0.0
% INFO    : Bus 2137	: V=1.035502, theta=32.502796 -> V=1.0, theta=0.0
% INFO    : Bus 2138	: V=1.035502, theta=32.502703 -> V=1.0, theta=0.0
% INFO    : Bus 2139	: V=1.003313, theta=37.135409 -> V=1.0, theta=0.0
% INFO    : Bus 2140	: V=1.008457, theta=-16.144565 -> V=1.0, theta=0.0
% INFO    : Bus 2141	: V=1.019922, theta=17.052804 -> V=1.0, theta=0.0
% INFO    : Bus 2142	: V=0.99793, theta=-4.757094 -> V=1.0, theta=0.0
% INFO    : Bus 2143	: V=1.017546, theta=-7.215576 -> V=1.0, theta=0.0
% INFO    : Bus 2144	: V=1.017546, theta=-7.215576 -> V=1.0, theta=0.0
% INFO    : Bus 2145	: V=1.067958, theta=2.705618 -> V=1.0, theta=0.0
% INFO    : Bus 2146	: V=1.017546, theta=-7.215576 -> V=1.0, theta=0.0
% INFO    : Bus 2147	: V=1.019095, theta=-7.960677 -> V=1.0, theta=0.0
% INFO    : Bus 2148	: V=1.046243, theta=23.151951 -> V=1.0, theta=0.0
% INFO    : Bus 2149	: V=1.046243, theta=23.151951 -> V=1.0, theta=0.0
% INFO    : Bus 2150	: V=1.030941, theta=29.790909 -> V=1.0, theta=0.0
% INFO    : Bus 2151	: V=1.026477, theta=-3.548893 -> V=1.0, theta=0.0
% INFO    : Bus 2152	: V=0.990583, theta=0.504532 -> V=1.0, theta=0.0
% INFO    : Bus 2153	: V=1.01017, theta=15.666854 -> V=1.0, theta=0.0
% INFO    : Bus 2154	: V=1.04545, theta=17.664921 -> V=1.0, theta=0.0
% INFO    : Bus 2155	: V=1.030117, theta=31.43919 -> V=1.0, theta=0.0
% INFO    : Bus 2156	: V=1.049836, theta=11.857105 -> V=1.0, theta=0.0
% INFO    : Bus 2157	: V=1.030852, theta=14.833561 -> V=1.0, theta=0.0
% INFO    : Bus 2158	: V=1.030117, theta=31.43919 -> V=1.0, theta=0.0
% INFO    : Bus 2159	: V=1.011607, theta=-13.743323 -> V=1.0, theta=0.0
% INFO    : Bus 2160	: V=1.035657, theta=77.742691 -> V=1.0, theta=0.0
% INFO    : Bus 2161	: V=1.007469, theta=-1.437468 -> V=1.0, theta=0.0
% INFO    : Bus 2162	: V=0.965839, theta=24.000238 -> V=1.0, theta=0.0
% INFO    : Bus 2163	: V=1.019372, theta=-15.361499 -> V=1.0, theta=0.0
% INFO    : Bus 2164	: V=1.019372, theta=-15.361499 -> V=1.0, theta=0.0
% INFO    : Bus 2165	: V=1.041679, theta=26.199412 -> V=1.0, theta=0.0
% INFO    : Bus 2166	: V=1.02436, theta=-12.195994 -> V=1.0, theta=0.0
% INFO    : Bus 2167	: V=1.022192, theta=20.047374 -> V=1.0, theta=0.0
% INFO    : Bus 2168	: V=1.003941, theta=-4.688236 -> V=1.0, theta=0.0
% INFO    : Bus 2169	: V=1.001706, theta=-10.006824 -> V=1.0, theta=0.0
% INFO    : Bus 2170	: V=1.01079, theta=-5.231958 -> V=1.0, theta=0.0
% INFO    : Bus 2171	: V=1.006201, theta=-19.200996 -> V=1.0, theta=0.0
% INFO    : Bus 2172	: V=1.04914, theta=42.65185 -> V=1.0, theta=0.0
% INFO    : Bus 2173	: V=0.993439, theta=-9.302864 -> V=1.0, theta=0.0
% INFO    : Bus 2174	: V=1.014044, theta=47.531028 -> V=1.0, theta=0.0
% INFO    : Bus 2175	: V=1.00349, theta=27.619503 -> V=1.0, theta=0.0
% INFO    : Bus 2176	: V=1.054354, theta=23.084216 -> V=1.0, theta=0.0
% INFO    : Bus 2177	: V=1.054354, theta=23.084216 -> V=1.0, theta=0.0
% INFO    : Bus 2178	: V=1.054354, theta=23.084216 -> V=1.0, theta=0.0
% INFO    : Bus 2179	: V=1.054354, theta=23.084216 -> V=1.0, theta=0.0
% INFO    : Bus 2180	: V=0.985554, theta=42.387961 -> V=1.0, theta=0.0
% INFO    : Bus 2181	: V=1.009209, theta=5.096099 -> V=1.0, theta=0.0
% INFO    : Bus 2182	: V=1.051605, theta=44.804322 -> V=1.0, theta=0.0
% INFO    : Bus 2183	: V=1.015185, theta=-4.986575 -> V=1.0, theta=0.0
% INFO    : Bus 2184	: V=1.035121, theta=19.25997 -> V=1.0, theta=0.0
% INFO    : Bus 2185	: V=0.91885, theta=-12.405973 -> V=1.0, theta=0.0
% INFO    : Bus 2186	: V=1.05594, theta=38.382088 -> V=1.0, theta=0.0
% INFO    : Bus 2187	: V=0.97676, theta=-5.773301 -> V=1.0, theta=0.0
% INFO    : Bus 2188	: V=1.004763, theta=17.696683 -> V=1.0, theta=0.0
% INFO    : Bus 2189	: V=1.033472, theta=-6.583857 -> V=1.0, theta=0.0
% INFO    : Bus 2190	: V=1.033542, theta=1.716976 -> V=1.0, theta=0.0
% INFO    : Bus 2191	: V=1.004923, theta=27.003315 -> V=1.0, theta=0.0
% INFO    : Bus 2192	: V=1.015919, theta=3.580325 -> V=1.0, theta=0.0
% INFO    : Bus 2193	: V=0.994926, theta=3.247305 -> V=1.0, theta=0.0
% INFO    : Bus 2194	: V=1.07972, theta=-3.354891 -> V=1.0, theta=0.0
% INFO    : Bus 2195	: V=1.071315, theta=-1.316775 -> V=1.0, theta=0.0
% INFO    : Bus 2196	: V=1.025646, theta=6.556766 -> V=1.0, theta=0.0
% INFO    : Bus 2197	: V=1.024678, theta=4.335626 -> V=1.0, theta=0.0
% INFO    : Bus 2198	: V=1.033735, theta=-14.68008 -> V=1.0, theta=0.0
% INFO    : Bus 2199	: V=1.003276, theta=4.030994 -> V=1.0, theta=0.0
% INFO    : Bus 2200	: V=0.971722, theta=-11.45905 -> V=1.0, theta=0.0
% INFO    : Bus 2201	: V=1.048558, theta=30.218377 -> V=1.0, theta=0.0
% INFO    : Bus 2202	: V=0.979797, theta=29.825191 -> V=1.0, theta=0.0
% INFO    : Bus 2203	: V=1.058269, theta=14.205436 -> V=1.0, theta=0.0
% INFO    : Bus 2204	: V=1.08089, theta=6.292575 -> V=1.0, theta=0.0
% INFO    : Bus 2205	: V=1.010845, theta=-15.053498 -> V=1.0, theta=0.0
% INFO    : Bus 2206	: V=1.05891, theta=5.576137 -> V=1.0, theta=0.0
% INFO    : Bus 2207	: V=0.997627, theta=15.442845 -> V=1.0, theta=0.0
% INFO    : Bus 2208	: V=0.984148, theta=-22.31072 -> V=1.0, theta=0.0
% INFO    : Bus 2209	: V=1.122892, theta=-2.324184 -> V=1.0, theta=0.0
% INFO    : Bus 2210	: V=1.024762, theta=17.972121 -> V=1.0, theta=0.0
% INFO    : Bus 2211	: V=1.029792, theta=-11.449739 -> V=1.0, theta=0.0
% INFO    : Bus 2212	: V=1.030503, theta=26.412296 -> V=1.0, theta=0.0
% INFO    : Bus 2213	: V=0.962326, theta=5.494068 -> V=1.0, theta=0.0
% INFO    : Bus 2214	: V=1.005604, theta=-25.891381 -> V=1.0, theta=0.0
% INFO    : Bus 2215	: V=1.003014, theta=30.196256 -> V=1.0, theta=0.0
% INFO    : Bus 2216	: V=1.085672, theta=8.755816 -> V=1.0, theta=0.0
% INFO    : Bus 2217	: V=1.037968, theta=10.118901 -> V=1.0, theta=0.0
% INFO    : Bus 2218	: V=1.031688, theta=13.151537 -> V=1.0, theta=0.0
% INFO    : Bus 2219	: V=1.030191, theta=9.268782 -> V=1.0, theta=0.0
% INFO    : Bus 2220	: V=1.018429, theta=14.959406 -> V=1.0, theta=0.0
% INFO    : Bus 2221	: V=1.058715, theta=18.400691 -> V=1.0, theta=0.0
% INFO    : Bus 2222	: V=1.019405, theta=-14.419189 -> V=1.0, theta=0.0
% INFO    : Bus 2223	: V=0.996935, theta=21.950327 -> V=1.0, theta=0.0
% INFO    : Bus 2224	: V=1.035309, theta=-11.752272 -> V=1.0, theta=0.0
% INFO    : Bus 2225	: V=1.031496, theta=10.828188 -> V=1.0, theta=0.0
% INFO    : Bus 2226	: V=1.02273, theta=18.752443 -> V=1.0, theta=0.0
% INFO    : Bus 2227	: V=1.010154, theta=33.063453 -> V=1.0, theta=0.0
% INFO    : Bus 2228	: V=1.013501, theta=-1.43555 -> V=1.0, theta=0.0
% INFO    : Bus 2229	: V=1.009721, theta=-8.747532 -> V=1.0, theta=0.0
% INFO    : Bus 2230	: V=1.029803, theta=4.001005 -> V=1.0, theta=0.0
% INFO    : Bus 2231	: V=0.99691, theta=-4.56571 -> V=1.0, theta=0.0
% INFO    : Bus 2232	: V=1.005956, theta=32.719778 -> V=1.0, theta=0.0
% INFO    : Bus 2233	: V=1.006552, theta=27.185653 -> V=1.0, theta=0.0
% INFO    : Bus 2234	: V=1.02641, theta=5.55336 -> V=1.0, theta=0.0
% INFO    : Bus 2235	: V=1.027955, theta=-2.520583 -> V=1.0, theta=0.0
% INFO    : Bus 2236	: V=1.062896, theta=-0.392816 -> V=1.0, theta=0.0
% INFO    : Bus 2237	: V=0.991989, theta=39.317054 -> V=1.0, theta=0.0
% INFO    : Bus 2238	: V=1.033687, theta=4.712833 -> V=1.0, theta=0.0
% INFO    : Bus 2239	: V=1.034072, theta=-10.492546 -> V=1.0, theta=0.0
% INFO    : Bus 2240	: V=1.065871, theta=-7.624412 -> V=1.0, theta=0.0
% INFO    : Bus 2241	: V=1.030878, theta=-0.616064 -> V=1.0, theta=0.0
% INFO    : Bus 2242	: V=1.024544, theta=18.974877 -> V=1.0, theta=0.0
% INFO    : Bus 2243	: V=0.976528, theta=39.092265 -> V=1.0, theta=0.0
% INFO    : Bus 2244	: V=0.99004, theta=-14.379986 -> V=1.0, theta=0.0
% INFO    : Bus 2245	: V=0.97777, theta=-8.392336 -> V=1.0, theta=0.0
% INFO    : Bus 2246	: V=1.005775, theta=-8.537815 -> V=1.0, theta=0.0
% INFO    : Bus 2247	: V=1.019723, theta=-1.552655 -> V=1.0, theta=0.0
% INFO    : Bus 2248	: V=1.019723, theta=-1.552655 -> V=1.0, theta=0.0
% INFO    : Bus 2249	: V=1.019723, theta=-1.552655 -> V=1.0, theta=0.0
% INFO    : Bus 2250	: V=1.058721, theta=-0.102635 -> V=1.0, theta=0.0
% INFO    : Bus 2251	: V=1.029067, theta=19.246507 -> V=1.0, theta=0.0
% INFO    : Bus 2252	: V=1.019723, theta=-1.552655 -> V=1.0, theta=0.0
% INFO    : Bus 2253	: V=1.052369, theta=0.152148 -> V=1.0, theta=0.0
% INFO    : Bus 2254	: V=0.993075, theta=42.619453 -> V=1.0, theta=0.0
% INFO    : Bus 2255	: V=1.016806, theta=-0.631712 -> V=1.0, theta=0.0
% INFO    : Bus 2256	: V=1.047504, theta=13.147125 -> V=1.0, theta=0.0
% INFO    : Bus 2257	: V=1.046454, theta=93.889744 -> V=1.0, theta=0.0
% INFO    : Bus 2258	: V=1.0026, theta=-1.481173 -> V=1.0, theta=0.0
% INFO    : Bus 2259	: V=1.003601, theta=15.328145 -> V=1.0, theta=0.0
% INFO    : Bus 2260	: V=1.001531, theta=8.966652 -> V=1.0, theta=0.0
% INFO    : Bus 2261	: V=1.03277, theta=12.252895 -> V=1.0, theta=0.0
% INFO    : Bus 2262	: V=1.023482, theta=0.234518 -> V=1.0, theta=0.0
% INFO    : Bus 2263	: V=1.006414, theta=-4.037915 -> V=1.0, theta=0.0
% INFO    : Bus 2264	: V=1.028156, theta=82.753284 -> V=1.0, theta=0.0
% INFO    : Bus 2265	: V=1.033153, theta=19.747498 -> V=1.0, theta=0.0
% INFO    : Bus 2266	: V=1.006784, theta=17.600399 -> V=1.0, theta=0.0
% INFO    : Bus 2267	: V=1.043069, theta=-2.696955 -> V=1.0, theta=0.0
% INFO    : Bus 2268	: V=1.037301, theta=24.456545 -> V=1.0, theta=0.0
% INFO    : Bus 2269	: V=1.012368, theta=45.757755 -> V=1.0, theta=0.0
% INFO    : Bus 2270	: V=0.99902, theta=31.838047 -> V=1.0, theta=0.0
% INFO    : Bus 2271	: V=1.051812, theta=30.353844 -> V=1.0, theta=0.0
% INFO    : Bus 2272	: V=1.067986, theta=87.275457 -> V=1.0, theta=0.0
% INFO    : Bus 2273	: V=0.977674, theta=13.494685 -> V=1.0, theta=0.0
% INFO    : Bus 2274	: V=0.991864, theta=0.773119 -> V=1.0, theta=0.0
% INFO    : Bus 2275	: V=1.046417, theta=67.606979 -> V=1.0, theta=0.0
% INFO    : Bus 2276	: V=1.02565, theta=45.340429 -> V=1.0, theta=0.0
% INFO    : Bus 2277	: V=0.953175, theta=-4.97832 -> V=1.0, theta=0.0
% INFO    : Bus 2278	: V=1.018046, theta=26.61034 -> V=1.0, theta=0.0
% INFO    : Bus 2279	: V=1.010213, theta=-20.852 -> V=1.0, theta=0.0
% INFO    : Bus 2280	: V=1.014992, theta=-26.755976 -> V=1.0, theta=0.0
% INFO    : Bus 2281	: V=1.008045, theta=29.243998 -> V=1.0, theta=0.0
% INFO    : Bus 2282	: V=1.022192, theta=20.047374 -> V=1.0, theta=0.0
% INFO    : Bus 2283	: V=1.022192, theta=20.047374 -> V=1.0, theta=0.0
% INFO    : Bus 2284	: V=1.022192, theta=20.047374 -> V=1.0, theta=0.0
% INFO    : Bus 2285	: V=1.022192, theta=20.047374 -> V=1.0, theta=0.0
% INFO    : Bus 2286	: V=1.000084, theta=9.446263 -> V=1.0, theta=0.0
% INFO    : Bus 2287	: V=1.000084, theta=9.446263 -> V=1.0, theta=0.0
% INFO    : Bus 2288	: V=1.019235, theta=-32.702004 -> V=1.0, theta=0.0
% INFO    : Bus 2289	: V=1.000465, theta=12.056714 -> V=1.0, theta=0.0
% INFO    : Bus 2290	: V=1.011343, theta=3.613636 -> V=1.0, theta=0.0
% INFO    : Bus 2291	: V=1.028027, theta=23.037833 -> V=1.0, theta=0.0
% INFO    : Bus 2292	: V=1.024089, theta=38.406443 -> V=1.0, theta=0.0
% INFO    : Bus 2293	: V=1.074566, theta=35.543789 -> V=1.0, theta=0.0
% INFO    : Bus 2294	: V=1.035703, theta=23.827158 -> V=1.0, theta=0.0
% INFO    : Bus 2295	: V=1.047679, theta=-11.39683 -> V=1.0, theta=0.0
% INFO    : Bus 2296	: V=1.039935, theta=9.269401 -> V=1.0, theta=0.0
% INFO    : Bus 2297	: V=1.014053, theta=-16.759949 -> V=1.0, theta=0.0
% INFO    : Bus 2298	: V=1.049907, theta=29.51908 -> V=1.0, theta=0.0
% INFO    : Bus 2299	: V=1.002675, theta=33.754879 -> V=1.0, theta=0.0
% INFO    : Bus 2300	: V=1.028161, theta=19.306285 -> V=1.0, theta=0.0
% INFO    : Bus 2301	: V=1.033551, theta=29.956876 -> V=1.0, theta=0.0
% INFO    : Bus 2302	: V=1.058231, theta=41.885187 -> V=1.0, theta=0.0
% INFO    : Bus 2303	: V=1.005693, theta=-4.241388 -> V=1.0, theta=0.0
% INFO    : Bus 2304	: V=0.99958, theta=33.087313 -> V=1.0, theta=0.0
% INFO    : Bus 2305	: V=1.026161, theta=17.223291 -> V=1.0, theta=0.0
% INFO    : Bus 2306	: V=1.028005, theta=-16.294789 -> V=1.0, theta=0.0
% INFO    : Bus 2307	: V=0.994621, theta=93.255028 -> V=1.0, theta=0.0
% INFO    : Bus 2308	: V=1.001855, theta=42.457602 -> V=1.0, theta=0.0
% INFO    : Bus 2309	: V=0.925212, theta=-7.995152 -> V=1.0, theta=0.0
% INFO    : Bus 2310	: V=1.012673, theta=-2.175699 -> V=1.0, theta=0.0
% INFO    : Bus 2311	: V=0.996151, theta=22.304241 -> V=1.0, theta=0.0
% INFO    : Bus 2312	: V=1.030371, theta=22.492325 -> V=1.0, theta=0.0
% INFO    : Bus 2313	: V=1.026872, theta=64.663279 -> V=1.0, theta=0.0
% INFO    : Bus 2314	: V=1.045287, theta=11.803747 -> V=1.0, theta=0.0
% INFO    : Bus 2315	: V=0.992463, theta=89.041689 -> V=1.0, theta=0.0
% INFO    : Bus 2316	: V=0.988006, theta=9.38833 -> V=1.0, theta=0.0
% INFO    : Bus 2317	: V=1.01362, theta=-27.364061 -> V=1.0, theta=0.0
% INFO    : Bus 2318	: V=1.025724, theta=-14.139236 -> V=1.0, theta=0.0
% INFO    : Bus 2319	: V=1.035932, theta=17.18209 -> V=1.0, theta=0.0
% INFO    : Bus 2320	: V=1.037448, theta=20.429836 -> V=1.0, theta=0.0
% INFO    : Bus 2321	: V=1.025724, theta=-14.139236 -> V=1.0, theta=0.0
% INFO    : Bus 2322	: V=1.025724, theta=-14.139236 -> V=1.0, theta=0.0
% INFO    : Bus 2323	: V=1.007398, theta=55.223677 -> V=1.0, theta=0.0
% INFO    : Bus 2324	: V=1.015556, theta=16.601372 -> V=1.0, theta=0.0
% INFO    : Bus 2325	: V=1.015556, theta=16.601372 -> V=1.0, theta=0.0
% INFO    : Bus 2326	: V=0.986681, theta=-9.116329 -> V=1.0, theta=0.0
% INFO    : Bus 2327	: V=1.016009, theta=-25.270754 -> V=1.0, theta=0.0
% INFO    : Bus 2328	: V=1.038216, theta=15.918534 -> V=1.0, theta=0.0
% INFO    : Bus 2329	: V=1.038216, theta=15.918534 -> V=1.0, theta=0.0
% INFO    : Bus 2330	: V=1.038216, theta=15.918534 -> V=1.0, theta=0.0
% INFO    : Bus 2331	: V=1.038216, theta=15.918534 -> V=1.0, theta=0.0
% INFO    : Bus 2332	: V=1.022889, theta=18.879559 -> V=1.0, theta=0.0
% INFO    : Bus 2333	: V=1.015556, theta=16.601372 -> V=1.0, theta=0.0
% INFO    : Bus 2334	: V=0.967527, theta=7.346013 -> V=1.0, theta=0.0
% INFO    : Bus 2335	: V=1.014893, theta=-9.156289 -> V=1.0, theta=0.0
% INFO    : Bus 2336	: V=1.015412, theta=36.155986 -> V=1.0, theta=0.0
% INFO    : Bus 2337	: V=1.023977, theta=94.20243 -> V=1.0, theta=0.0
% INFO    : Bus 2338	: V=1.050498, theta=-5.356327 -> V=1.0, theta=0.0
% INFO    : Bus 2339	: V=1.0677, theta=-2.868433 -> V=1.0, theta=0.0
% INFO    : Bus 2340	: V=1.0146, theta=-26.896818 -> V=1.0, theta=0.0
% INFO    : Bus 2341	: V=0.9846, theta=26.113191 -> V=1.0, theta=0.0
% INFO    : Bus 2342	: V=1.027637, theta=71.016364 -> V=1.0, theta=0.0
% INFO    : Bus 2343	: V=1.014803, theta=-26.035801 -> V=1.0, theta=0.0
% INFO    : Bus 2344	: V=1.021485, theta=33.002348 -> V=1.0, theta=0.0
% INFO    : Bus 2345	: V=1.035781, theta=10.208476 -> V=1.0, theta=0.0
% INFO    : Bus 2346	: V=1.045938, theta=0.131246 -> V=1.0, theta=0.0
% INFO    : Bus 2347	: V=1.043619, theta=-8.436397 -> V=1.0, theta=0.0
% INFO    : Bus 2348	: V=1.032069, theta=32.464552 -> V=1.0, theta=0.0
% INFO    : Bus 2349	: V=1.029855, theta=3.966773 -> V=1.0, theta=0.0
% INFO    : Bus 2350	: V=1.063743, theta=32.498552 -> V=1.0, theta=0.0
% INFO    : Bus 2351	: V=1.015932, theta=-1.816542 -> V=1.0, theta=0.0
% INFO    : Bus 2352	: V=1.01263, theta=-27.102961 -> V=1.0, theta=0.0
% INFO    : Bus 2353	: V=0.998554, theta=89.915574 -> V=1.0, theta=0.0
% INFO    : Bus 2354	: V=1.034241, theta=21.237398 -> V=1.0, theta=0.0
% INFO    : Bus 2355	: V=1.039543, theta=0.151979 -> V=1.0, theta=0.0
% INFO    : Bus 2356	: V=1.022416, theta=2.327808 -> V=1.0, theta=0.0
% INFO    : Bus 2357	: V=0.958146, theta=44.224727 -> V=1.0, theta=0.0
% INFO    : Bus 2358	: V=1.035093, theta=-4.093903 -> V=1.0, theta=0.0
% INFO    : Bus 2359	: V=1.056528, theta=16.073477 -> V=1.0, theta=0.0
% INFO    : Bus 2360	: V=1.05106, theta=28.445589 -> V=1.0, theta=0.0
% INFO    : Bus 2361	: V=0.981068, theta=-8.315885 -> V=1.0, theta=0.0
% INFO    : Bus 2362	: V=0.996546, theta=-0.46454 -> V=1.0, theta=0.0
% INFO    : Bus 2363	: V=1.102599, theta=-3.769686 -> V=1.0, theta=0.0
% INFO    : Bus 2364	: V=0.968379, theta=9.315915 -> V=1.0, theta=0.0
% INFO    : Bus 2365	: V=1.010427, theta=25.129998 -> V=1.0, theta=0.0
% INFO    : Bus 2366	: V=1.028299, theta=7.415194 -> V=1.0, theta=0.0
% INFO    : Bus 2367	: V=1.009453, theta=14.280459 -> V=1.0, theta=0.0
% INFO    : Bus 2368	: V=1.046905, theta=39.305577 -> V=1.0, theta=0.0
% INFO    : Bus 2369	: V=1.03654, theta=20.486651 -> V=1.0, theta=0.0
% INFO    : Bus 2370	: V=1.03654, theta=20.486651 -> V=1.0, theta=0.0
% INFO    : Bus 2371	: V=1.03654, theta=20.486651 -> V=1.0, theta=0.0
% INFO    : Bus 2372	: V=1.05433, theta=78.959661 -> V=1.0, theta=0.0
% INFO    : Bus 2373	: V=1.05433, theta=78.959661 -> V=1.0, theta=0.0
% INFO    : Bus 2374	: V=0.990002, theta=-4.642297 -> V=1.0, theta=0.0
% INFO    : Bus 2375	: V=1.034078, theta=9.468305 -> V=1.0, theta=0.0
% INFO    : Bus 2376	: V=1.035818, theta=19.272279 -> V=1.0, theta=0.0
% INFO    : Bus 2377	: V=1.05433, theta=78.959661 -> V=1.0, theta=0.0
% INFO    : Bus 2378	: V=1.091952, theta=-4.839993 -> V=1.0, theta=0.0
% INFO    : Bus 2379	: V=1.034179, theta=0.653604 -> V=1.0, theta=0.0
% INFO    : Bus 2380	: V=0.951872, theta=-8.263509 -> V=1.0, theta=0.0
% INFO    : Bus 2381	: V=1.01137, theta=-20.329813 -> V=1.0, theta=0.0
% INFO    : Bus 2382	: V=1.07309, theta=71.208471 -> V=1.0, theta=0.0
% INFO    : Bus 2383	: V=1.010623, theta=-20.466016 -> V=1.0, theta=0.0
% INFO    : Bus 2384	: V=1.05688, theta=2.348638 -> V=1.0, theta=0.0
% INFO    : Bus 2385	: V=1.089079, theta=12.928353 -> V=1.0, theta=0.0
% INFO    : Bus 2386	: V=1.042431, theta=26.262064 -> V=1.0, theta=0.0
% INFO    : Bus 2387	: V=1.000873, theta=-13.941582 -> V=1.0, theta=0.0
% INFO    : Bus 2388	: V=1.026764, theta=35.146887 -> V=1.0, theta=0.0
% INFO    : Bus 2389	: V=1.00773, theta=-6.62746 -> V=1.0, theta=0.0
% INFO    : Bus 2390	: V=1.058617, theta=17.901573 -> V=1.0, theta=0.0
% INFO    : Bus 2391	: V=0.99298, theta=89.197377 -> V=1.0, theta=0.0
% INFO    : Bus 2392	: V=1.026376, theta=19.236355 -> V=1.0, theta=0.0
% INFO    : Bus 2393	: V=1.020078, theta=16.65542 -> V=1.0, theta=0.0
% INFO    : Bus 2394	: V=1.006316, theta=32.241424 -> V=1.0, theta=0.0
% INFO    : Bus 2395	: V=1.044734, theta=-14.530759 -> V=1.0, theta=0.0
% INFO    : Bus 2396	: V=1.032306, theta=1.092988 -> V=1.0, theta=0.0
% INFO    : Bus 2397	: V=1.01541, theta=24.000055 -> V=1.0, theta=0.0
% INFO    : Bus 2398	: V=1.099009, theta=-14.343804 -> V=1.0, theta=0.0
% INFO    : Bus 2399	: V=1.006179, theta=-4.430856 -> V=1.0, theta=0.0
% INFO    : Bus 2400	: V=0.958965, theta=-1.951824 -> V=1.0, theta=0.0
% INFO    : Bus 2401	: V=1.0264, theta=-0.200844 -> V=1.0, theta=0.0
% INFO    : Bus 2402	: V=0.993935, theta=6.959387 -> V=1.0, theta=0.0
% INFO    : Bus 2403	: V=1.01934, theta=-7.045149 -> V=1.0, theta=0.0
% INFO    : Bus 2404	: V=0.999094, theta=-10.340628 -> V=1.0, theta=0.0
% INFO    : Bus 2405	: V=1.058808, theta=-0.196718 -> V=1.0, theta=0.0
% INFO    : Bus 2406	: V=0.940227, theta=-11.17719 -> V=1.0, theta=0.0
% INFO    : Bus 2407	: V=1.010562, theta=-8.673231 -> V=1.0, theta=0.0
% INFO    : Bus 2408	: V=1.036065, theta=-16.582357 -> V=1.0, theta=0.0
% INFO    : Bus 2409	: V=1.032898, theta=35.871615 -> V=1.0, theta=0.0
% INFO    : Bus 2410	: V=1.034871, theta=5.967043 -> V=1.0, theta=0.0
% INFO    : Bus 2411	: V=1.020161, theta=16.222206 -> V=1.0, theta=0.0
% INFO    : Bus 2412	: V=1.005589, theta=18.229827 -> V=1.0, theta=0.0
% INFO    : Bus 2413	: V=1.035366, theta=21.028956 -> V=1.0, theta=0.0
% INFO    : Bus 2414	: V=0.953878, theta=-6.48994 -> V=1.0, theta=0.0
% INFO    : Bus 2415	: V=0.980354, theta=-5.292423 -> V=1.0, theta=0.0
% INFO    : Bus 2416	: V=1.049098, theta=-1.034667 -> V=1.0, theta=0.0
% INFO    : Bus 2417	: V=1.019402, theta=-2.700194 -> V=1.0, theta=0.0
% INFO    : Bus 2418	: V=1.015136, theta=-23.064206 -> V=1.0, theta=0.0
% INFO    : Bus 2419	: V=1.034936, theta=19.380328 -> V=1.0, theta=0.0
% INFO    : Bus 2420	: V=1.014957, theta=-4.634794 -> V=1.0, theta=0.0
% INFO    : Bus 2421	: V=1.014035, theta=-6.298865 -> V=1.0, theta=0.0
% INFO    : Bus 2422	: V=1.03091, theta=3.948229 -> V=1.0, theta=0.0
% INFO    : Bus 2423	: V=1.030882, theta=31.218703 -> V=1.0, theta=0.0
% INFO    : Bus 2424	: V=1.056671, theta=13.173411 -> V=1.0, theta=0.0
% INFO    : Bus 2425	: V=1.030156, theta=18.368221 -> V=1.0, theta=0.0
% INFO    : Bus 2426	: V=1.025121, theta=-0.421457 -> V=1.0, theta=0.0
% INFO    : Bus 2427	: V=1.020357, theta=44.124293 -> V=1.0, theta=0.0
% INFO    : Bus 2428	: V=0.994234, theta=37.670381 -> V=1.0, theta=0.0
% INFO    : Bus 2429	: V=1.040642, theta=8.532255 -> V=1.0, theta=0.0
% INFO    : Bus 2430	: V=1.008982, theta=42.351688 -> V=1.0, theta=0.0
% INFO    : Bus 2431	: V=0.97922, theta=35.097859 -> V=1.0, theta=0.0
% INFO    : Bus 2432	: V=1.032532, theta=16.666699 -> V=1.0, theta=0.0
% INFO    : Bus 2433	: V=0.994714, theta=14.910429 -> V=1.0, theta=0.0
% INFO    : Bus 2434	: V=1.035431, theta=26.859737 -> V=1.0, theta=0.0
% INFO    : Bus 2435	: V=1.052787, theta=84.55589 -> V=1.0, theta=0.0
% INFO    : Bus 2436	: V=1.052787, theta=84.55589 -> V=1.0, theta=0.0
% INFO    : Bus 2437	: V=1.052787, theta=84.55589 -> V=1.0, theta=0.0
% INFO    : Bus 2438	: V=1.052787, theta=84.55589 -> V=1.0, theta=0.0
% INFO    : Bus 2439	: V=1.052787, theta=84.55589 -> V=1.0, theta=0.0
% INFO    : Bus 2440	: V=1.059619, theta=48.79156 -> V=1.0, theta=0.0
% INFO    : Bus 2441	: V=0.992448, theta=18.912893 -> V=1.0, theta=0.0
% INFO    : Bus 2442	: V=0.985787, theta=-4.747483 -> V=1.0, theta=0.0
% INFO    : Bus 2443	: V=0.968592, theta=-8.970276 -> V=1.0, theta=0.0
% INFO    : Bus 2444	: V=0.999525, theta=-7.285883 -> V=1.0, theta=0.0
% INFO    : Bus 2445	: V=1.002746, theta=-5.871327 -> V=1.0, theta=0.0
% INFO    : Bus 2446	: V=1.031971, theta=-3.542743 -> V=1.0, theta=0.0
% INFO    : Bus 2447	: V=1.031971, theta=-3.542743 -> V=1.0, theta=0.0
% INFO    : Bus 2448	: V=1.031971, theta=-3.542743 -> V=1.0, theta=0.0
% INFO    : Bus 2449	: V=0.996275, theta=-13.083407 -> V=1.0, theta=0.0
% INFO    : Bus 2450	: V=1.010365, theta=-1.148729 -> V=1.0, theta=0.0
% INFO    : Bus 2451	: V=0.988455, theta=-9.696508 -> V=1.0, theta=0.0
% INFO    : Bus 2452	: V=1.062716, theta=50.740342 -> V=1.0, theta=0.0
% INFO    : Bus 2453	: V=1.060805, theta=38.8513 -> V=1.0, theta=0.0
% INFO    : Bus 2454	: V=1.047172, theta=32.227056 -> V=1.0, theta=0.0
% INFO    : Bus 2455	: V=1.018412, theta=31.685509 -> V=1.0, theta=0.0
% INFO    : Bus 2456	: V=1.051156, theta=7.856494 -> V=1.0, theta=0.0
% INFO    : Bus 2457	: V=0.987908, theta=-7.451534 -> V=1.0, theta=0.0
% INFO    : Bus 2458	: V=1.020659, theta=-5.050211 -> V=1.0, theta=0.0
% INFO    : Bus 2459	: V=1.037973, theta=11.471538 -> V=1.0, theta=0.0
% INFO    : Bus 2460	: V=1.011637, theta=15.19334 -> V=1.0, theta=0.0
% INFO    : Bus 2461	: V=1.057377, theta=6.088258 -> V=1.0, theta=0.0
% INFO    : Bus 2462	: V=1.033042, theta=-4.165701 -> V=1.0, theta=0.0
% INFO    : Bus 2463	: V=0.985529, theta=-4.986197 -> V=1.0, theta=0.0
% INFO    : Bus 2464	: V=1.011692, theta=-19.302078 -> V=1.0, theta=0.0
% INFO    : Bus 2465	: V=1.019953, theta=-21.391835 -> V=1.0, theta=0.0
% INFO    : Bus 2466	: V=1.013533, theta=-4.833141 -> V=1.0, theta=0.0
% INFO    : Bus 2467	: V=1.005681, theta=16.085441 -> V=1.0, theta=0.0
% INFO    : Bus 2468	: V=0.989597, theta=-8.414096 -> V=1.0, theta=0.0
% INFO    : Bus 2469	: V=1.072267, theta=-1.044825 -> V=1.0, theta=0.0
% INFO    : Bus 2470	: V=0.994222, theta=-11.370405 -> V=1.0, theta=0.0
% INFO    : Bus 2471	: V=0.977418, theta=-27.229276 -> V=1.0, theta=0.0
% INFO    : Bus 2472	: V=1.06633, theta=0.67803 -> V=1.0, theta=0.0
% INFO    : Bus 2473	: V=1.035838, theta=-5.172678 -> V=1.0, theta=0.0
% INFO    : Bus 2474	: V=1.06026, theta=-1.965756 -> V=1.0, theta=0.0
% INFO    : Bus 2475	: V=1.033543, theta=-0.572386 -> V=1.0, theta=0.0
% INFO    : Bus 2476	: V=1.053994, theta=-17.781594 -> V=1.0, theta=0.0
% INFO    : Bus 2477	: V=0.975014, theta=23.320703 -> V=1.0, theta=0.0
% INFO    : Bus 2478	: V=1.069032, theta=17.910132 -> V=1.0, theta=0.0
% INFO    : Bus 2479	: V=0.995942, theta=-4.331716 -> V=1.0, theta=0.0
% INFO    : Bus 2480	: V=1.078638, theta=63.716182 -> V=1.0, theta=0.0
% INFO    : Bus 2481	: V=1.078638, theta=63.716182 -> V=1.0, theta=0.0
% INFO    : Bus 2482	: V=1.02424, theta=84.887043 -> V=1.0, theta=0.0
% INFO    : Bus 2483	: V=1.026073, theta=-2.579002 -> V=1.0, theta=0.0
% INFO    : Bus 2484	: V=1.017615, theta=25.421095 -> V=1.0, theta=0.0
% INFO    : Bus 2485	: V=1.015531, theta=4.163384 -> V=1.0, theta=0.0
% INFO    : Bus 2486	: V=1.04434, theta=27.891337 -> V=1.0, theta=0.0
% INFO    : Bus 2487	: V=1.04434, theta=27.891337 -> V=1.0, theta=0.0
% INFO    : Bus 2488	: V=1.055727, theta=25.429279 -> V=1.0, theta=0.0
% INFO    : Bus 2489	: V=1.055727, theta=25.429279 -> V=1.0, theta=0.0
% INFO    : Bus 2490	: V=1.04434, theta=27.891337 -> V=1.0, theta=0.0
% INFO    : Bus 2491	: V=0.966548, theta=-5.661815 -> V=1.0, theta=0.0
% INFO    : Bus 2492	: V=1.03632, theta=5.804646 -> V=1.0, theta=0.0
% INFO    : Bus 2493	: V=1.055063, theta=34.721991 -> V=1.0, theta=0.0
% INFO    : Bus 2494	: V=1.023762, theta=-7.315358 -> V=1.0, theta=0.0
% INFO    : Bus 2495	: V=1.016491, theta=-11.127263 -> V=1.0, theta=0.0
% INFO    : Bus 2496	: V=1.03472, theta=7.897462 -> V=1.0, theta=0.0
% INFO    : Bus 2497	: V=1.027844, theta=11.224092 -> V=1.0, theta=0.0
% INFO    : Bus 2498	: V=0.99908, theta=-9.995212 -> V=1.0, theta=0.0
% INFO    : Bus 2499	: V=1.001143, theta=3.67274 -> V=1.0, theta=0.0
% INFO    : Bus 2500	: V=1.030227, theta=6.942059 -> V=1.0, theta=0.0
% INFO    : Bus 2501	: V=1.030227, theta=6.942059 -> V=1.0, theta=0.0
% INFO    : Bus 2502	: V=1.030227, theta=6.942059 -> V=1.0, theta=0.0
% INFO    : Bus 2503	: V=1.023024, theta=-25.867914 -> V=1.0, theta=0.0
% INFO    : Bus 2504	: V=1.014237, theta=-26.217572 -> V=1.0, theta=0.0
% INFO    : Bus 2505	: V=1.000523, theta=-2.320988 -> V=1.0, theta=0.0
% INFO    : Bus 2506	: V=0.990208, theta=39.96266 -> V=1.0, theta=0.0
% INFO    : Bus 2507	: V=1.031983, theta=12.039209 -> V=1.0, theta=0.0
% INFO    : Bus 2508	: V=1.041513, theta=-3.711399 -> V=1.0, theta=0.0
% INFO    : Bus 2509	: V=1.056029, theta=48.463068 -> V=1.0, theta=0.0
% INFO    : Bus 2510	: V=1.026207, theta=-11.793103 -> V=1.0, theta=0.0
% INFO    : Bus 2511	: V=1.0377, theta=-0.080977 -> V=1.0, theta=0.0
% INFO    : Bus 2512	: V=1.016536, theta=42.941822 -> V=1.0, theta=0.0
% INFO    : Bus 2513	: V=1.033542, theta=1.716976 -> V=1.0, theta=0.0
% INFO    : Bus 2514	: V=1.033552, theta=1.72662 -> V=1.0, theta=0.0
% INFO    : Bus 2515	: V=1.033552, theta=1.72662 -> V=1.0, theta=0.0
% INFO    : Bus 2516	: V=1.033552, theta=1.72662 -> V=1.0, theta=0.0
% INFO    : Bus 2517	: V=1.081376, theta=9.242874 -> V=1.0, theta=0.0
% INFO    : Bus 2518	: V=1.026319, theta=-4.093349 -> V=1.0, theta=0.0
% INFO    : Bus 2519	: V=1.039767, theta=-3.494237 -> V=1.0, theta=0.0
% INFO    : Bus 2520	: V=1.025946, theta=-14.450303 -> V=1.0, theta=0.0
% INFO    : Bus 2521	: V=1.024048, theta=-7.803527 -> V=1.0, theta=0.0
% INFO    : Bus 2522	: V=1.009827, theta=3.156346 -> V=1.0, theta=0.0
% INFO    : Bus 2523	: V=0.991127, theta=-1.59697 -> V=1.0, theta=0.0
% INFO    : Bus 2524	: V=1.057969, theta=-0.595757 -> V=1.0, theta=0.0
% INFO    : Bus 2525	: V=1.036911, theta=18.978271 -> V=1.0, theta=0.0
% INFO    : Bus 2526	: V=1.01592, theta=3.179112 -> V=1.0, theta=0.0
% INFO    : Bus 2527	: V=0.986413, theta=-2.111327 -> V=1.0, theta=0.0
% INFO    : Bus 2528	: V=1.010953, theta=-17.43421 -> V=1.0, theta=0.0
% INFO    : Bus 2529	: V=1.043181, theta=18.536382 -> V=1.0, theta=0.0
% INFO    : Bus 2530	: V=1.023175, theta=-5.240961 -> V=1.0, theta=0.0
% INFO    : Bus 2531	: V=1.006174, theta=-13.997849 -> V=1.0, theta=0.0
% INFO    : Bus 2532	: V=0.999111, theta=-3.504719 -> V=1.0, theta=0.0
% INFO    : Bus 2533	: V=1.014104, theta=26.485556 -> V=1.0, theta=0.0
% INFO    : Bus 2534	: V=1.046641, theta=37.417065 -> V=1.0, theta=0.0
% INFO    : Bus 2535	: V=1.004397, theta=16.235341 -> V=1.0, theta=0.0
% INFO    : Bus 2536	: V=0.993039, theta=48.679905 -> V=1.0, theta=0.0
% INFO    : Bus 2537	: V=1.009987, theta=-18.52003 -> V=1.0, theta=0.0
% INFO    : Bus 2538	: V=1.050999, theta=4.005332 -> V=1.0, theta=0.0
% INFO    : Bus 2539	: V=1.000445, theta=95.959998 -> V=1.0, theta=0.0
% INFO    : Bus 2540	: V=1.046641, theta=37.417065 -> V=1.0, theta=0.0
% INFO    : Bus 2541	: V=1.010105, theta=-20.870277 -> V=1.0, theta=0.0
% INFO    : Bus 2542	: V=1.017997, theta=42.29957 -> V=1.0, theta=0.0
% INFO    : Bus 2543	: V=1.046641, theta=37.417065 -> V=1.0, theta=0.0
% INFO    : Bus 2544	: V=0.993408, theta=-5.133948 -> V=1.0, theta=0.0
% INFO    : Bus 2545	: V=1.05382, theta=-3.028079 -> V=1.0, theta=0.0
% INFO    : Bus 2546	: V=1.009455, theta=-6.474424 -> V=1.0, theta=0.0
% INFO    : Bus 2547	: V=0.994668, theta=-2.235494 -> V=1.0, theta=0.0
% INFO    : Bus 2548	: V=1.036036, theta=25.403437 -> V=1.0, theta=0.0
% INFO    : Bus 2549	: V=0.999524, theta=-9.834457 -> V=1.0, theta=0.0
% INFO    : Bus 2550	: V=1.027588, theta=-1.88516 -> V=1.0, theta=0.0
% INFO    : Bus 2551	: V=1.097221, theta=2.395495 -> V=1.0, theta=0.0
% INFO    : Bus 2552	: V=1.014815, theta=43.027357 -> V=1.0, theta=0.0
% INFO    : Bus 2553	: V=1.013365, theta=43.78577 -> V=1.0, theta=0.0
% INFO    : Bus 2554	: V=1.072967, theta=24.077735 -> V=1.0, theta=0.0
% INFO    : Bus 2555	: V=1.043042, theta=-1.38939 -> V=1.0, theta=0.0
% INFO    : Bus 2556	: V=1.017559, theta=41.986243 -> V=1.0, theta=0.0
% INFO    : Bus 2557	: V=1.010888, theta=-16.54274 -> V=1.0, theta=0.0
% INFO    : Bus 2558	: V=1.053981, theta=30.656361 -> V=1.0, theta=0.0
% INFO    : Bus 2559	: V=1.029344, theta=21.964639 -> V=1.0, theta=0.0
% INFO    : Bus 2560	: V=0.98751, theta=-4.706892 -> V=1.0, theta=0.0
% INFO    : Bus 2561	: V=1.024067, theta=20.713541 -> V=1.0, theta=0.0
% INFO    : Bus 2562	: V=0.986502, theta=-4.442456 -> V=1.0, theta=0.0
% INFO    : Bus 2563	: V=1.00122, theta=-3.581791 -> V=1.0, theta=0.0
% INFO    : Bus 2564	: V=0.986561, theta=22.995822 -> V=1.0, theta=0.0
% INFO    : Bus 2565	: V=1.027161, theta=2.397403 -> V=1.0, theta=0.0
% INFO    : Bus 2566	: V=1.002755, theta=40.303215 -> V=1.0, theta=0.0
% INFO    : Bus 2567	: V=1.018406, theta=22.88777 -> V=1.0, theta=0.0
% INFO    : Bus 2568	: V=1.029368, theta=-2.3572 -> V=1.0, theta=0.0
% INFO    : Bus 2569	: V=1.030434, theta=0.665089 -> V=1.0, theta=0.0
% INFO    : Bus 2570	: V=0.990186, theta=-18.851277 -> V=1.0, theta=0.0
% INFO    : Bus 2571	: V=1.046641, theta=37.417065 -> V=1.0, theta=0.0
% INFO    : Bus 2572	: V=1.014104, theta=26.485556 -> V=1.0, theta=0.0
% INFO    : Bus 2573	: V=1.014104, theta=26.485556 -> V=1.0, theta=0.0
% INFO    : Bus 2574	: V=1.031914, theta=8.483142 -> V=1.0, theta=0.0
% INFO    : Bus 2575	: V=1.000415, theta=-3.000786 -> V=1.0, theta=0.0
% INFO    : Bus 2576	: V=1.011272, theta=29.276423 -> V=1.0, theta=0.0
% INFO    : Bus 2577	: V=1.046641, theta=37.417065 -> V=1.0, theta=0.0
% INFO    : Bus 2578	: V=1.003204, theta=-1.650544 -> V=1.0, theta=0.0
% INFO    : Bus 2579	: V=0.929204, theta=-10.397849 -> V=1.0, theta=0.0
% INFO    : Bus 2580	: V=1.009101, theta=27.36724 -> V=1.0, theta=0.0
% INFO    : Bus 2581	: V=1.027592, theta=28.817146 -> V=1.0, theta=0.0
% INFO    : Bus 2582	: V=1.007085, theta=5.065757 -> V=1.0, theta=0.0
% INFO    : Bus 2583	: V=0.989033, theta=-4.933794 -> V=1.0, theta=0.0
% INFO    : Bus 2584	: V=1.031301, theta=-10.495578 -> V=1.0, theta=0.0
% INFO    : Bus 2585	: V=1.03974, theta=48.885471 -> V=1.0, theta=0.0
% INFO    : Bus 2586	: V=1.038712, theta=59.525463 -> V=1.0, theta=0.0
% INFO    : Bus 2587	: V=1.034957, theta=4.77046 -> V=1.0, theta=0.0
% INFO    : Bus 2588	: V=1.031813, theta=4.43475 -> V=1.0, theta=0.0
% INFO    : Bus 2589	: V=1.029269, theta=36.020984 -> V=1.0, theta=0.0
% INFO    : Bus 2590	: V=1.008801, theta=22.021191 -> V=1.0, theta=0.0
% INFO    : Bus 2591	: V=1.024105, theta=8.131913 -> V=1.0, theta=0.0
% INFO    : Bus 2592	: V=1.014299, theta=9.180056 -> V=1.0, theta=0.0
% INFO    : Bus 2593	: V=1.063957, theta=30.159406 -> V=1.0, theta=0.0
% INFO    : Bus 2594	: V=1.037812, theta=4.529303 -> V=1.0, theta=0.0
% INFO    : Bus 2595	: V=1.042511, theta=18.111486 -> V=1.0, theta=0.0
% INFO    : Bus 2596	: V=1.009993, theta=-5.164253 -> V=1.0, theta=0.0
% INFO    : Bus 2597	: V=1.026857, theta=15.275337 -> V=1.0, theta=0.0
% INFO    : Bus 2598	: V=0.998698, theta=2.211508 -> V=1.0, theta=0.0
% INFO    : Bus 2599	: V=1.088032, theta=11.809018 -> V=1.0, theta=0.0
% INFO    : Bus 2600	: V=1.030403, theta=18.225281 -> V=1.0, theta=0.0
% INFO    : Bus 2601	: V=1.027954, theta=-13.585392 -> V=1.0, theta=0.0
% INFO    : Bus 2602	: V=1.015817, theta=42.07164 -> V=1.0, theta=0.0
% INFO    : Bus 2603	: V=1.004901, theta=24.768889 -> V=1.0, theta=0.0
% INFO    : Bus 2604	: V=1.086546, theta=-3.616335 -> V=1.0, theta=0.0
% INFO    : Bus 2605	: V=1.036591, theta=27.54814 -> V=1.0, theta=0.0
% INFO    : Bus 2606	: V=1.033036, theta=-3.138558 -> V=1.0, theta=0.0
% INFO    : Bus 2607	: V=1.033036, theta=-3.138558 -> V=1.0, theta=0.0
% INFO    : Bus 2608	: V=1.014963, theta=-11.37104 -> V=1.0, theta=0.0
% INFO    : Bus 2609	: V=0.98271, theta=5.157436 -> V=1.0, theta=0.0
% INFO    : Bus 2610	: V=1.017828, theta=-6.986287 -> V=1.0, theta=0.0
% INFO    : Bus 2611	: V=1.015852, theta=3.041504 -> V=1.0, theta=0.0
% INFO    : Bus 2612	: V=1.054932, theta=-1.045505 -> V=1.0, theta=0.0
% INFO    : Bus 2613	: V=1.024786, theta=-10.50186 -> V=1.0, theta=0.0
% INFO    : Bus 2614	: V=0.963689, theta=-9.802775 -> V=1.0, theta=0.0
% INFO    : Bus 2615	: V=1.021143, theta=7.911593 -> V=1.0, theta=0.0
% INFO    : Bus 2616	: V=1.006569, theta=-1.11117 -> V=1.0, theta=0.0
% INFO    : Bus 2617	: V=0.996039, theta=26.252459 -> V=1.0, theta=0.0
% INFO    : Bus 2618	: V=1.032639, theta=25.002791 -> V=1.0, theta=0.0
% INFO    : Bus 2619	: V=1.025318, theta=25.079708 -> V=1.0, theta=0.0
% INFO    : Bus 2620	: V=1.044314, theta=12.69888 -> V=1.0, theta=0.0
% INFO    : Bus 2621	: V=1.028919, theta=7.369747 -> V=1.0, theta=0.0
% INFO    : Bus 2622	: V=0.96688, theta=-9.635467 -> V=1.0, theta=0.0
% INFO    : Bus 2623	: V=1.052837, theta=28.078372 -> V=1.0, theta=0.0
% INFO    : Bus 2624	: V=1.045696, theta=14.309815 -> V=1.0, theta=0.0
% INFO    : Bus 2625	: V=1.039006, theta=38.999932 -> V=1.0, theta=0.0
% INFO    : Bus 2626	: V=0.978212, theta=-2.836179 -> V=1.0, theta=0.0
% INFO    : Bus 2627	: V=1.042062, theta=24.663334 -> V=1.0, theta=0.0
% INFO    : Bus 2628	: V=1.02517, theta=17.079665 -> V=1.0, theta=0.0
% INFO    : Bus 2629	: V=0.989897, theta=48.462007 -> V=1.0, theta=0.0
% INFO    : Bus 2630	: V=1.017958, theta=-24.080211 -> V=1.0, theta=0.0
% INFO    : Bus 2631	: V=1.025806, theta=-5.755511 -> V=1.0, theta=0.0
% INFO    : Bus 2632	: V=0.992408, theta=13.822029 -> V=1.0, theta=0.0
% INFO    : Bus 2633	: V=1.009876, theta=-24.041959 -> V=1.0, theta=0.0
% INFO    : Bus 2634	: V=1.033067, theta=16.604846 -> V=1.0, theta=0.0
% INFO    : Bus 2635	: V=1.028604, theta=-12.690591 -> V=1.0, theta=0.0
% INFO    : Bus 2636	: V=0.982579, theta=1.681904 -> V=1.0, theta=0.0
% INFO    : Bus 2637	: V=1.047829, theta=86.05075 -> V=1.0, theta=0.0
% INFO    : Bus 2638	: V=0.97736, theta=31.54763 -> V=1.0, theta=0.0
% INFO    : Bus 2639	: V=1.037572, theta=-0.519639 -> V=1.0, theta=0.0
% INFO    : Bus 2640	: V=1.040335, theta=20.591441 -> V=1.0, theta=0.0
% INFO    : Bus 2641	: V=0.992684, theta=17.756538 -> V=1.0, theta=0.0
% INFO    : Bus 2642	: V=1.030658, theta=49.902414 -> V=1.0, theta=0.0
% INFO    : Bus 2643	: V=0.979525, theta=7.924919 -> V=1.0, theta=0.0
% INFO    : Bus 2644	: V=0.995624, theta=19.508108 -> V=1.0, theta=0.0
% INFO    : Bus 2645	: V=1.013484, theta=22.942549 -> V=1.0, theta=0.0
% INFO    : Bus 2646	: V=1.037142, theta=24.334502 -> V=1.0, theta=0.0
% INFO    : Bus 2647	: V=1.0136, theta=-3.104621 -> V=1.0, theta=0.0
% INFO    : Bus 2648	: V=1.025366, theta=45.298404 -> V=1.0, theta=0.0
% INFO    : Bus 2649	: V=0.979734, theta=-12.99789 -> V=1.0, theta=0.0
% INFO    : Bus 2650	: V=1.0608, theta=42.720858 -> V=1.0, theta=0.0
% INFO    : Bus 2651	: V=1.0608, theta=42.720858 -> V=1.0, theta=0.0
% INFO    : Bus 2652	: V=1.058549, theta=46.919585 -> V=1.0, theta=0.0
% INFO    : Bus 2653	: V=1.058549, theta=46.919585 -> V=1.0, theta=0.0
% INFO    : Bus 2654	: V=1.058549, theta=46.919585 -> V=1.0, theta=0.0
% INFO    : Bus 2655	: V=1.058549, theta=46.919585 -> V=1.0, theta=0.0
% INFO    : Bus 2656	: V=1.058549, theta=46.919585 -> V=1.0, theta=0.0
% INFO    : Bus 2657	: V=1.058549, theta=46.919585 -> V=1.0, theta=0.0
% INFO    : Bus 2658	: V=1.05595, theta=-6.533405 -> V=1.0, theta=0.0
% INFO    : Bus 2659	: V=1.031923, theta=-1.472759 -> V=1.0, theta=0.0
% INFO    : Bus 2660	: V=1.051111, theta=1.167386 -> V=1.0, theta=0.0
% INFO    : Bus 2661	: V=1.024083, theta=-4.130597 -> V=1.0, theta=0.0
% INFO    : Bus 2662	: V=1.055337, theta=0.681282 -> V=1.0, theta=0.0
% INFO    : Bus 2663	: V=1.011735, theta=11.840184 -> V=1.0, theta=0.0
% INFO    : Bus 2664	: V=1.016944, theta=-15.006207 -> V=1.0, theta=0.0
% INFO    : Bus 2665	: V=1.016944, theta=-15.006207 -> V=1.0, theta=0.0
% INFO    : Bus 2666	: V=1.027807, theta=-10.041134 -> V=1.0, theta=0.0
% INFO    : Bus 2667	: V=1.027807, theta=-10.041134 -> V=1.0, theta=0.0
% INFO    : Bus 2668	: V=0.991249, theta=25.858246 -> V=1.0, theta=0.0
% INFO    : Bus 2669	: V=1.027807, theta=-10.041134 -> V=1.0, theta=0.0
% INFO    : Bus 2670	: V=1.024891, theta=10.992359 -> V=1.0, theta=0.0
% INFO    : Bus 2671	: V=1.01802, theta=8.028494 -> V=1.0, theta=0.0
% INFO    : Bus 2672	: V=1.015027, theta=-26.995567 -> V=1.0, theta=0.0
% INFO    : Bus 2673	: V=0.976247, theta=-1.700019 -> V=1.0, theta=0.0
% INFO    : Bus 2674	: V=1.037377, theta=-7.9846 -> V=1.0, theta=0.0
% INFO    : Bus 2675	: V=0.999171, theta=-8.851257 -> V=1.0, theta=0.0
% INFO    : Bus 2676	: V=1.012735, theta=-8.652706 -> V=1.0, theta=0.0
% INFO    : Bus 2677	: V=1.025349, theta=15.599134 -> V=1.0, theta=0.0
% INFO    : Bus 2678	: V=1.055434, theta=0.517348 -> V=1.0, theta=0.0
% INFO    : Bus 2679	: V=0.995829, theta=-3.792126 -> V=1.0, theta=0.0
% INFO    : Bus 2680	: V=1.020153, theta=-10.106982 -> V=1.0, theta=0.0
% INFO    : Bus 2681	: V=1.043665, theta=14.930439 -> V=1.0, theta=0.0
% INFO    : Bus 2682	: V=0.985714, theta=25.1639 -> V=1.0, theta=0.0
% INFO    : Bus 2683	: V=0.984403, theta=20.182088 -> V=1.0, theta=0.0
% INFO    : Bus 2684	: V=1.07544, theta=81.399784 -> V=1.0, theta=0.0
% INFO    : Bus 2685	: V=1.036282, theta=13.112105 -> V=1.0, theta=0.0
% INFO    : Bus 2686	: V=1.021606, theta=-18.065799 -> V=1.0, theta=0.0
% INFO    : Bus 2687	: V=1.034314, theta=-10.021136 -> V=1.0, theta=0.0
% INFO    : Bus 2688	: V=1.021208, theta=-7.595433 -> V=1.0, theta=0.0
% INFO    : Bus 2689	: V=0.996623, theta=-13.551816 -> V=1.0, theta=0.0
% INFO    : Bus 2690	: V=1.034314, theta=-10.021136 -> V=1.0, theta=0.0
% INFO    : Bus 2691	: V=1.01939, theta=-11.773065 -> V=1.0, theta=0.0
% INFO    : Bus 2692	: V=1.013327, theta=-8.475961 -> V=1.0, theta=0.0
% INFO    : Bus 2693	: V=1.021055, theta=-14.38773 -> V=1.0, theta=0.0
% INFO    : Bus 2694	: V=1.021055, theta=-14.38773 -> V=1.0, theta=0.0
% INFO    : Bus 2695	: V=1.030241, theta=-13.589685 -> V=1.0, theta=0.0
% INFO    : Bus 2696	: V=1.049033, theta=30.517749 -> V=1.0, theta=0.0
% INFO    : Bus 2697	: V=1.025817, theta=39.935591 -> V=1.0, theta=0.0
% INFO    : Bus 2698	: V=1.03058, theta=15.553508 -> V=1.0, theta=0.0
% INFO    : Bus 2699	: V=1.059225, theta=86.44158 -> V=1.0, theta=0.0
% INFO    : Bus 2700	: V=1.024762, theta=17.972121 -> V=1.0, theta=0.0
% INFO    : Bus 2701	: V=1.008172, theta=-8.50998 -> V=1.0, theta=0.0
% INFO    : Bus 2702	: V=1.013686, theta=-8.216227 -> V=1.0, theta=0.0
% INFO    : Bus 2703	: V=1.031603, theta=9.382948 -> V=1.0, theta=0.0
% INFO    : Bus 2704	: V=0.991906, theta=20.94822 -> V=1.0, theta=0.0
% INFO    : Bus 2705	: V=1.031603, theta=9.382948 -> V=1.0, theta=0.0
% INFO    : Bus 2706	: V=1.000198, theta=-1.38798 -> V=1.0, theta=0.0
% INFO    : Bus 2707	: V=1.028806, theta=-20.398353 -> V=1.0, theta=0.0
% INFO    : Bus 2708	: V=1.066367, theta=6.221208 -> V=1.0, theta=0.0
% INFO    : Bus 2709	: V=1.063696, theta=0.616025 -> V=1.0, theta=0.0
% INFO    : Bus 2710	: V=1.055275, theta=37.598344 -> V=1.0, theta=0.0
% INFO    : Bus 2711	: V=1.042669, theta=14.686826 -> V=1.0, theta=0.0
% INFO    : Bus 2712	: V=1.016984, theta=26.026364 -> V=1.0, theta=0.0
% INFO    : Bus 2713	: V=1.01779, theta=-32.964038 -> V=1.0, theta=0.0
% INFO    : Bus 2714	: V=1.062807, theta=-8.18081 -> V=1.0, theta=0.0
% INFO    : Bus 2715	: V=1.049679, theta=-19.588649 -> V=1.0, theta=0.0
% INFO    : Bus 2716	: V=1.082729, theta=86.239056 -> V=1.0, theta=0.0
% INFO    : Bus 2717	: V=0.996677, theta=47.723917 -> V=1.0, theta=0.0
% INFO    : Bus 2718	: V=1.003112, theta=32.826245 -> V=1.0, theta=0.0
% INFO    : Bus 2719	: V=1.031244, theta=39.254249 -> V=1.0, theta=0.0
% INFO    : Bus 2720	: V=1.016666, theta=-11.633661 -> V=1.0, theta=0.0
% INFO    : Bus 2721	: V=1.029248, theta=22.566355 -> V=1.0, theta=0.0
% INFO    : Bus 2722	: V=1.019828, theta=-10.992526 -> V=1.0, theta=0.0
% INFO    : Bus 2723	: V=0.983665, theta=-13.090398 -> V=1.0, theta=0.0
% INFO    : Bus 2724	: V=1.099472, theta=10.206014 -> V=1.0, theta=0.0
% INFO    : Bus 2725	: V=0.976233, theta=42.311602 -> V=1.0, theta=0.0
% INFO    : Bus 2726	: V=1.049529, theta=86.878119 -> V=1.0, theta=0.0
% INFO    : Bus 2727	: V=1.013271, theta=-0.962724 -> V=1.0, theta=0.0
% INFO    : Bus 2728	: V=1.043768, theta=39.249593 -> V=1.0, theta=0.0
% INFO    : Bus 2729	: V=1.040621, theta=17.754771 -> V=1.0, theta=0.0
% INFO    : Bus 2730	: V=1.030248, theta=-2.052544 -> V=1.0, theta=0.0
% INFO    : Bus 2731	: V=1.027632, theta=-14.918109 -> V=1.0, theta=0.0
% INFO    : Bus 2732	: V=0.980785, theta=-17.6427 -> V=1.0, theta=0.0
% INFO    : Bus 2733	: V=1.028095, theta=35.299342 -> V=1.0, theta=0.0
% INFO    : Bus 2734	: V=1.025803, theta=97.507727 -> V=1.0, theta=0.0
% INFO    : Bus 2735	: V=1.03532, theta=8.357264 -> V=1.0, theta=0.0
% INFO    : Bus 2736	: V=1.026937, theta=0.980466 -> V=1.0, theta=0.0
% INFO    : Bus 2737	: V=1.084215, theta=30.391991 -> V=1.0, theta=0.0
% INFO    : Bus 2738	: V=0.980974, theta=-14.106135 -> V=1.0, theta=0.0
% INFO    : Bus 2739	: V=1.010421, theta=31.816906 -> V=1.0, theta=0.0
% INFO    : Bus 2740	: V=1.038514, theta=4.74121 -> V=1.0, theta=0.0
% INFO    : Bus 2741	: V=1.02475, theta=27.384949 -> V=1.0, theta=0.0
% INFO    : Bus 2742	: V=1.021263, theta=23.715333 -> V=1.0, theta=0.0
% INFO    : Bus 2743	: V=1.021295, theta=7.910264 -> V=1.0, theta=0.0
% INFO    : Bus 2744	: V=1.003913, theta=7.649642 -> V=1.0, theta=0.0
% INFO    : Bus 2745	: V=1.078554, theta=4.187041 -> V=1.0, theta=0.0
% INFO    : Bus 2746	: V=0.996714, theta=19.141779 -> V=1.0, theta=0.0
% INFO    : Bus 2747	: V=1.017811, theta=4.765995 -> V=1.0, theta=0.0
% INFO    : Bus 2748	: V=0.964803, theta=22.614166 -> V=1.0, theta=0.0
% INFO    : Bus 2749	: V=1.020315, theta=57.22313 -> V=1.0, theta=0.0
% INFO    : Bus 2750	: V=1.03288, theta=23.275029 -> V=1.0, theta=0.0
% INFO    : Bus 2751	: V=1.003553, theta=-12.572953 -> V=1.0, theta=0.0
% INFO    : Bus 2752	: V=0.951282, theta=29.908619 -> V=1.0, theta=0.0
% INFO    : Bus 2753	: V=1.121048, theta=-0.477263 -> V=1.0, theta=0.0
% INFO    : Bus 2754	: V=0.982851, theta=19.049233 -> V=1.0, theta=0.0
% INFO    : Bus 2755	: V=0.972195, theta=-12.166593 -> V=1.0, theta=0.0
% INFO    : Bus 2756	: V=0.998215, theta=12.734047 -> V=1.0, theta=0.0
% INFO    : Bus 2757	: V=1.052606, theta=2.644204 -> V=1.0, theta=0.0
% INFO    : Bus 2758	: V=1.022049, theta=-13.383678 -> V=1.0, theta=0.0
% INFO    : Bus 2759	: V=0.990464, theta=21.09396 -> V=1.0, theta=0.0
% INFO    : Bus 2760	: V=1.058355, theta=41.76159 -> V=1.0, theta=0.0
% INFO    : Bus 2761	: V=1.025265, theta=-10.510786 -> V=1.0, theta=0.0
% INFO    : Bus 2762	: V=1.004778, theta=27.105564 -> V=1.0, theta=0.0
% INFO    : Bus 2763	: V=1.015003, theta=31.694995 -> V=1.0, theta=0.0
% INFO    : Bus 2764	: V=1.048333, theta=57.693081 -> V=1.0, theta=0.0
% INFO    : Bus 2765	: V=1.028071, theta=36.87365 -> V=1.0, theta=0.0
% INFO    : Bus 2766	: V=1.012041, theta=5.279989 -> V=1.0, theta=0.0
% INFO    : Bus 2767	: V=1.003847, theta=10.087109 -> V=1.0, theta=0.0
% INFO    : Bus 2768	: V=1.063889, theta=11.960574 -> V=1.0, theta=0.0
% INFO    : Bus 2769	: V=1.051211, theta=1.426245 -> V=1.0, theta=0.0
% INFO    : Bus 2770	: V=1.021137, theta=-31.689864 -> V=1.0, theta=0.0
% INFO    : Bus 2771	: V=1.042717, theta=32.921323 -> V=1.0, theta=0.0
% INFO    : Bus 2772	: V=1.042842, theta=84.150417 -> V=1.0, theta=0.0
% INFO    : Bus 2773	: V=0.969729, theta=-14.732562 -> V=1.0, theta=0.0
% INFO    : Bus 2774	: V=1.034866, theta=65.764397 -> V=1.0, theta=0.0
% INFO    : Bus 2775	: V=1.050756, theta=-12.792959 -> V=1.0, theta=0.0
% INFO    : Bus 2776	: V=1.03265, theta=18.464929 -> V=1.0, theta=0.0
% INFO    : Bus 2777	: V=1.009892, theta=4.868208 -> V=1.0, theta=0.0
% INFO    : Bus 2778	: V=0.99744, theta=33.84332 -> V=1.0, theta=0.0
% INFO    : Bus 2779	: V=1.008162, theta=19.967949 -> V=1.0, theta=0.0
% INFO    : Bus 2780	: V=1.006374, theta=26.856693 -> V=1.0, theta=0.0
% INFO    : Bus 2781	: V=1.049701, theta=7.525621 -> V=1.0, theta=0.0
% INFO    : Bus 2782	: V=1.020405, theta=-1.824814 -> V=1.0, theta=0.0
% INFO    : Bus 2783	: V=1.040793, theta=26.940223 -> V=1.0, theta=0.0
% INFO    : Bus 2784	: V=1.019419, theta=6.474548 -> V=1.0, theta=0.0
% INFO    : Bus 2785	: V=1.003847, theta=10.087109 -> V=1.0, theta=0.0
% INFO    : Bus 2786	: V=1.035838, theta=-5.172678 -> V=1.0, theta=0.0
% INFO    : Bus 2787	: V=1.017845, theta=-4.792355 -> V=1.0, theta=0.0
% INFO    : Bus 2788	: V=1.017792, theta=-5.319138 -> V=1.0, theta=0.0
% INFO    : Bus 2789	: V=1.011998, theta=0.419036 -> V=1.0, theta=0.0
% INFO    : Bus 2790	: V=1.031726, theta=-2.251951 -> V=1.0, theta=0.0
% INFO    : Bus 2791	: V=1.019413, theta=41.884948 -> V=1.0, theta=0.0
% INFO    : Bus 2792	: V=1.086757, theta=63.706535 -> V=1.0, theta=0.0
% INFO    : Bus 2793	: V=1.020424, theta=-20.573487 -> V=1.0, theta=0.0
% INFO    : Bus 2794	: V=1.021416, theta=-21.165213 -> V=1.0, theta=0.0
% INFO    : Bus 2795	: V=1.003987, theta=-6.326655 -> V=1.0, theta=0.0
% INFO    : Bus 2796	: V=1.022889, theta=18.879559 -> V=1.0, theta=0.0
% INFO    : Bus 2797	: V=1.061902, theta=18.798237 -> V=1.0, theta=0.0
% INFO    : Bus 2798	: V=0.996885, theta=-3.778126 -> V=1.0, theta=0.0
% INFO    : Bus 2799	: V=1.040793, theta=26.940223 -> V=1.0, theta=0.0
% INFO    : Bus 2800	: V=0.968535, theta=5.04654 -> V=1.0, theta=0.0
% INFO    : Bus 2801	: V=1.047904, theta=84.142942 -> V=1.0, theta=0.0
% INFO    : Bus 2802	: V=0.982717, theta=19.046316 -> V=1.0, theta=0.0
% INFO    : Bus 2803	: V=1.015042, theta=-0.37136 -> V=1.0, theta=0.0
% INFO    : Bus 2804	: V=1.021573, theta=-22.183058 -> V=1.0, theta=0.0
% INFO    : Bus 2805	: V=1.02996, theta=-10.060779 -> V=1.0, theta=0.0
% INFO    : Bus 2806	: V=0.973439, theta=-3.167151 -> V=1.0, theta=0.0
% INFO    : Bus 2807	: V=0.987767, theta=-5.2323 -> V=1.0, theta=0.0
% INFO    : Bus 2808	: V=1.013167, theta=-26.447449 -> V=1.0, theta=0.0
% INFO    : Bus 2809	: V=1.021419, theta=-22.29244 -> V=1.0, theta=0.0
% INFO    : Bus 2810	: V=1.040793, theta=26.940223 -> V=1.0, theta=0.0
% INFO    : Bus 2811	: V=1.022087, theta=-3.367486 -> V=1.0, theta=0.0
% INFO    : Bus 2812	: V=1.117558, theta=-2.51737 -> V=1.0, theta=0.0
% INFO    : Bus 2813	: V=1.024123, theta=3.471914 -> V=1.0, theta=0.0
% INFO    : Bus 2814	: V=0.956074, theta=-16.770188 -> V=1.0, theta=0.0
% INFO    : Bus 2815	: V=1.026048, theta=31.606612 -> V=1.0, theta=0.0
% INFO    : Bus 2816	: V=0.992395, theta=35.295433 -> V=1.0, theta=0.0
% INFO    : Bus 2817	: V=1.030487, theta=33.829091 -> V=1.0, theta=0.0
% INFO    : Bus 2818	: V=1.085877, theta=-0.824855 -> V=1.0, theta=0.0
% INFO    : Bus 2819	: V=1.031736, theta=41.040722 -> V=1.0, theta=0.0
% INFO    : Bus 2820	: V=1.046339, theta=-4.535747 -> V=1.0, theta=0.0
% INFO    : Bus 2821	: V=1.030407, theta=4.051965 -> V=1.0, theta=0.0
% INFO    : Bus 2822	: V=1.015223, theta=-8.707967 -> V=1.0, theta=0.0
% INFO    : Bus 2823	: V=1.013354, theta=-0.836591 -> V=1.0, theta=0.0
% INFO    : Bus 2824	: V=1.010914, theta=19.579521 -> V=1.0, theta=0.0
% INFO    : Bus 2825	: V=1.033805, theta=-1.24014 -> V=1.0, theta=0.0
% INFO    : Bus 2826	: V=1.029765, theta=-2.314086 -> V=1.0, theta=0.0
% INFO    : Bus 2827	: V=1.031122, theta=31.502598 -> V=1.0, theta=0.0
% INFO    : Bus 2828	: V=1.017638, theta=-6.936102 -> V=1.0, theta=0.0
% INFO    : Bus 2829	: V=1.01075, theta=-22.689555 -> V=1.0, theta=0.0
% INFO    : Bus 2830	: V=1.040594, theta=-6.46768 -> V=1.0, theta=0.0
% INFO    : Bus 2831	: V=0.989469, theta=40.488685 -> V=1.0, theta=0.0
% INFO    : Bus 2832	: V=0.99781, theta=-5.781696 -> V=1.0, theta=0.0
% INFO    : Bus 2833	: V=1.000328, theta=-3.366901 -> V=1.0, theta=0.0
% INFO    : Bus 2834	: V=1.032192, theta=45.944685 -> V=1.0, theta=0.0
% INFO    : Bus 2835	: V=0.992019, theta=-3.212205 -> V=1.0, theta=0.0
% INFO    : Bus 2836	: V=1.061581, theta=6.921348 -> V=1.0, theta=0.0
% INFO    : Bus 2837	: V=1.010638, theta=-8.662097 -> V=1.0, theta=0.0
% INFO    : Bus 2838	: V=1.064384, theta=12.999659 -> V=1.0, theta=0.0
% INFO    : Bus 2839	: V=0.995336, theta=33.541224 -> V=1.0, theta=0.0
% INFO    : Bus 2840	: V=1.027968, theta=24.05088 -> V=1.0, theta=0.0
% INFO    : Bus 2841	: V=1.027968, theta=24.05088 -> V=1.0, theta=0.0
% INFO    : Bus 2842	: V=1.061581, theta=6.921348 -> V=1.0, theta=0.0
% INFO    : Bus 2843	: V=1.043628, theta=20.270583 -> V=1.0, theta=0.0
% INFO    : Bus 2844	: V=1.070991, theta=7.604863 -> V=1.0, theta=0.0
% INFO    : Bus 2845	: V=1.064384, theta=12.999659 -> V=1.0, theta=0.0
% INFO    : Bus 2846	: V=0.988251, theta=-9.325342 -> V=1.0, theta=0.0
% INFO    : Bus 2847	: V=1.024475, theta=10.258345 -> V=1.0, theta=0.0
% INFO    : Bus 2848	: V=1.068587, theta=-12.198559 -> V=1.0, theta=0.0
% INFO    : Bus 2849	: V=1.047582, theta=31.453215 -> V=1.0, theta=0.0
% INFO    : Bus 2850	: V=1.079367, theta=-3.384889 -> V=1.0, theta=0.0
% INFO    : Bus 2851	: V=1.005848, theta=0.866704 -> V=1.0, theta=0.0
% INFO    : Bus 2852	: V=1.013948, theta=12.809021 -> V=1.0, theta=0.0
% INFO    : Bus 2853	: V=1.097846, theta=65.011121 -> V=1.0, theta=0.0
% INFO    : Bus 2854	: V=0.996972, theta=32.605519 -> V=1.0, theta=0.0
% INFO    : Bus 2855	: V=1.028082, theta=-7.262597 -> V=1.0, theta=0.0
% INFO    : Bus 2856	: V=1.077186, theta=0.891513 -> V=1.0, theta=0.0
% INFO    : Bus 2857	: V=1.013816, theta=4.686922 -> V=1.0, theta=0.0
% INFO    : Bus 2858	: V=1.044939, theta=29.387061 -> V=1.0, theta=0.0
% INFO    : Bus 2859	: V=1.014283, theta=-10.876603 -> V=1.0, theta=0.0
% INFO    : Bus 2860	: V=1.006131, theta=12.49776 -> V=1.0, theta=0.0
% INFO    : Bus 2861	: V=0.993839, theta=-3.903185 -> V=1.0, theta=0.0
% INFO    : Bus 2862	: V=0.999754, theta=-4.31743 -> V=1.0, theta=0.0
% INFO    : Bus 2863	: V=1.035883, theta=9.357223 -> V=1.0, theta=0.0
% INFO    : Bus 2864	: V=0.957345, theta=-9.979812 -> V=1.0, theta=0.0
% INFO    : Bus 2865	: V=1.011456, theta=-3.024872 -> V=1.0, theta=0.0
% INFO    : Bus 2866	: V=1.029821, theta=11.74799 -> V=1.0, theta=0.0
% INFO    : Bus 2867	: V=1.037736, theta=21.469997 -> V=1.0, theta=0.0
% INFO    : Bus 2868	: V=1.088981, theta=9.07002 -> V=1.0, theta=0.0
% INFO    : Bus 2869	: V=1.020944, theta=-1.99455 -> V=1.0, theta=0.0
% INFO    : Bus 2870	: V=1.030832, theta=-9.752509 -> V=1.0, theta=0.0
% INFO    : Bus 2871	: V=1.044924, theta=29.406092 -> V=1.0, theta=0.0
% INFO    : Bus 2872	: V=1.030825, theta=34.272754 -> V=1.0, theta=0.0
% INFO    : Bus 2873	: V=1.027005, theta=1.029856 -> V=1.0, theta=0.0
% INFO    : Bus 2874	: V=1.005971, theta=11.672077 -> V=1.0, theta=0.0
% INFO    : Bus 2875	: V=1.032338, theta=9.184881 -> V=1.0, theta=0.0
% INFO    : Bus 2876	: V=1.038018, theta=5.797275 -> V=1.0, theta=0.0
% INFO    : Bus 2877	: V=1.029166, theta=13.522836 -> V=1.0, theta=0.0
% INFO    : Bus 2878	: V=1.038131, theta=4.912288 -> V=1.0, theta=0.0
% INFO    : Bus 2879	: V=0.992496, theta=-1.791255 -> V=1.0, theta=0.0
% INFO    : Bus 2880	: V=1.028088, theta=-13.031645 -> V=1.0, theta=0.0
% INFO    : Bus 2881	: V=1.028088, theta=-13.031645 -> V=1.0, theta=0.0
% INFO    : Bus 2882	: V=0.989155, theta=-22.138997 -> V=1.0, theta=0.0
% INFO    : Bus 2883	: V=1.048247, theta=-8.989717 -> V=1.0, theta=0.0
% INFO    : Bus 2884	: V=1.021395, theta=2.988226 -> V=1.0, theta=0.0
% INFO    : Bus 2885	: V=1.01021, theta=4.316508 -> V=1.0, theta=0.0
% INFO    : Bus 2886	: V=1.006203, theta=33.698504 -> V=1.0, theta=0.0
% INFO    : Bus 2887	: V=1.071397, theta=40.134574 -> V=1.0, theta=0.0
% INFO    : Bus 2888	: V=1.024582, theta=0.545384 -> V=1.0, theta=0.0
% INFO    : Bus 2889	: V=1.0227, theta=0.37135 -> V=1.0, theta=0.0
% INFO    : Bus 2890	: V=1.020294, theta=26.013319 -> V=1.0, theta=0.0
% INFO    : Bus 2891	: V=1.001933, theta=0.520394 -> V=1.0, theta=0.0
% INFO    : Bus 2892	: V=1.034652, theta=32.708036 -> V=1.0, theta=0.0
% INFO    : Bus 2893	: V=1.008604, theta=-3.447075 -> V=1.0, theta=0.0
% INFO    : Bus 2894	: V=1.045516, theta=41.754111 -> V=1.0, theta=0.0
% INFO    : Bus 2895	: V=1.126501, theta=-1.915268 -> V=1.0, theta=0.0
% INFO    : Bus 2896	: V=0.976336, theta=-9.661402 -> V=1.0, theta=0.0
% INFO    : Bus 2897	: V=1.036344, theta=43.587167 -> V=1.0, theta=0.0
% INFO    : Bus 2898	: V=1.036237, theta=19.120016 -> V=1.0, theta=0.0
% INFO    : Bus 2899	: V=1.005957, theta=-18.039574 -> V=1.0, theta=0.0
% INFO    : Bus 2900	: V=1.0554, theta=5.332672 -> V=1.0, theta=0.0
% INFO    : Bus 2901	: V=1.039232, theta=7.281291 -> V=1.0, theta=0.0
% INFO    : Bus 2902	: V=1.039232, theta=7.281291 -> V=1.0, theta=0.0
% INFO    : Bus 2903	: V=1.023458, theta=8.422084 -> V=1.0, theta=0.0
% INFO    : Bus 2904	: V=1.016396, theta=18.8779 -> V=1.0, theta=0.0
% INFO    : Bus 2905	: V=0.969903, theta=-8.40306 -> V=1.0, theta=0.0
% INFO    : Bus 2906	: V=1.026436, theta=2.785646 -> V=1.0, theta=0.0
% INFO    : Bus 2907	: V=1.014613, theta=-26.808033 -> V=1.0, theta=0.0
% INFO    : Bus 2908	: V=1.039793, theta=-6.423412 -> V=1.0, theta=0.0
% INFO    : Bus 2909	: V=1.085162, theta=1.341951 -> V=1.0, theta=0.0
% INFO    : Bus 2910	: V=0.996191, theta=18.211728 -> V=1.0, theta=0.0
% INFO    : Bus 2911	: V=1.004491, theta=-12.436802 -> V=1.0, theta=0.0
% INFO    : Bus 2912	: V=1.020176, theta=20.468258 -> V=1.0, theta=0.0
% INFO    : Bus 2913	: V=1.051252, theta=7.897462 -> V=1.0, theta=0.0
% INFO    : Bus 2914	: V=1.019441, theta=-3.771239 -> V=1.0, theta=0.0
% INFO    : Bus 2915	: V=0.965144, theta=-10.373275 -> V=1.0, theta=0.0
% INFO    : Bus 2916	: V=1.021714, theta=-0.968124 -> V=1.0, theta=0.0
% INFO    : Bus 2917	: V=1.04687, theta=5.192474 -> V=1.0, theta=0.0
% INFO    : Bus 2918	: V=1.019459, theta=22.105369 -> V=1.0, theta=0.0
% INFO    : Bus 2919	: V=0.981514, theta=20.291106 -> V=1.0, theta=0.0
% INFO    : Bus 2920	: V=0.989503, theta=-3.363256 -> V=1.0, theta=0.0
% INFO    : Bus 2921	: V=1.043272, theta=-18.000164 -> V=1.0, theta=0.0
% INFO    : Bus 2922	: V=1.111192, theta=0.559337 -> V=1.0, theta=0.0
% INFO    : Bus 2923	: V=1.018011, theta=-30.733354 -> V=1.0, theta=0.0
% INFO    : Bus 2924	: V=0.978502, theta=5.404407 -> V=1.0, theta=0.0
% INFO    : Bus 2925	: V=1.054212, theta=-0.245142 -> V=1.0, theta=0.0
% INFO    : Bus 2926	: V=1.01782, theta=13.626458 -> V=1.0, theta=0.0
% INFO    : Bus 2927	: V=0.995079, theta=17.378652 -> V=1.0, theta=0.0
% INFO    : Bus 2928	: V=1.001808, theta=17.707788 -> V=1.0, theta=0.0
% INFO    : Bus 2929	: V=1.008479, theta=-10.420579 -> V=1.0, theta=0.0
% INFO    : Bus 2930	: V=1.043805, theta=-6.740275 -> V=1.0, theta=0.0
% INFO    : Bus 2931	: V=1.051506, theta=0.116562 -> V=1.0, theta=0.0
% INFO    : Bus 2932	: V=1.022012, theta=92.365113 -> V=1.0, theta=0.0
% INFO    : Bus 2933	: V=0.989831, theta=32.095099 -> V=1.0, theta=0.0
% INFO    : Bus 2934	: V=1.033975, theta=-14.23689 -> V=1.0, theta=0.0
% INFO    : Bus 2935	: V=1.040896, theta=75.624353 -> V=1.0, theta=0.0
% INFO    : Bus 2936	: V=1.026327, theta=21.205564 -> V=1.0, theta=0.0
% INFO    : Bus 2937	: V=1.0563, theta=11.740795 -> V=1.0, theta=0.0
% INFO    : Bus 2938	: V=1.025389, theta=30.951659 -> V=1.0, theta=0.0
% INFO    : Bus 2939	: V=1.041371, theta=-2.347999 -> V=1.0, theta=0.0
% INFO    : Bus 2940	: V=1.019671, theta=-32.938285 -> V=1.0, theta=0.0
% INFO    : Bus 2941	: V=0.909658, theta=-12.472146 -> V=1.0, theta=0.0
% INFO    : Bus 2942	: V=0.991779, theta=-19.092039 -> V=1.0, theta=0.0
% INFO    : Bus 2943	: V=1.022404, theta=-12.286706 -> V=1.0, theta=0.0
% INFO    : Bus 2944	: V=0.994725, theta=33.286745 -> V=1.0, theta=0.0
% INFO    : Bus 2945	: V=1.042125, theta=-13.973553 -> V=1.0, theta=0.0
% INFO    : Bus 2946	: V=0.978089, theta=13.519151 -> V=1.0, theta=0.0
% INFO    : Bus 2947	: V=1.000392, theta=-8.664731 -> V=1.0, theta=0.0
% INFO    : Bus 2948	: V=1.006167, theta=19.203386 -> V=1.0, theta=0.0
% INFO    : Bus 2949	: V=1.030428, theta=-21.332673 -> V=1.0, theta=0.0
% INFO    : Bus 2950	: V=1.006699, theta=27.063644 -> V=1.0, theta=0.0
% INFO    : Bus 2951	: V=1.032138, theta=11.548616 -> V=1.0, theta=0.0
% INFO    : Bus 2952	: V=1.059984, theta=46.329026 -> V=1.0, theta=0.0
% INFO    : Bus 2953	: V=1.04137, theta=33.25698 -> V=1.0, theta=0.0
% INFO    : Bus 2954	: V=1.052423, theta=4.564159 -> V=1.0, theta=0.0
% INFO    : Bus 2955	: V=1.054489, theta=6.09839 -> V=1.0, theta=0.0
% INFO    : Bus 2956	: V=1.015553, theta=5.973983 -> V=1.0, theta=0.0
% INFO    : Bus 2957	: V=1.030714, theta=4.086976 -> V=1.0, theta=0.0
% INFO    : Bus 2958	: V=1.011483, theta=-11.28309 -> V=1.0, theta=0.0
% INFO    : Bus 2959	: V=1.016528, theta=-8.99771 -> V=1.0, theta=0.0
% INFO    : Bus 2960	: V=0.966387, theta=0.261157 -> V=1.0, theta=0.0
% INFO    : Bus 2961	: V=1.021332, theta=21.250094 -> V=1.0, theta=0.0
% INFO    : Bus 2962	: V=1.116078, theta=70.148814 -> V=1.0, theta=0.0
% INFO    : Bus 2963	: V=1.035406, theta=21.74444 -> V=1.0, theta=0.0
% INFO    : Bus 2964	: V=1.036949, theta=12.275543 -> V=1.0, theta=0.0
% INFO    : Bus 2965	: V=1.018688, theta=-18.692878 -> V=1.0, theta=0.0
% INFO    : Bus 2966	: V=1.016599, theta=6.103548 -> V=1.0, theta=0.0
% INFO    : Bus 2967	: V=1.053421, theta=28.464675 -> V=1.0, theta=0.0
% INFO    : Bus 2968	: V=1.03481, theta=9.302046 -> V=1.0, theta=0.0
% INFO    : Bus 2969	: V=1.03481, theta=9.302046 -> V=1.0, theta=0.0
% INFO    : Bus 2970	: V=1.030988, theta=2.394145 -> V=1.0, theta=0.0
% INFO    : Bus 2971	: V=1.01275, theta=1.829725 -> V=1.0, theta=0.0
% INFO    : Bus 2972	: V=1.044543, theta=-2.917968 -> V=1.0, theta=0.0
% INFO    : Bus 2973	: V=1.03481, theta=9.302046 -> V=1.0, theta=0.0
% INFO    : Bus 2974	: V=1.03481, theta=9.302046 -> V=1.0, theta=0.0
% INFO    : Bus 2975	: V=1.006502, theta=23.545534 -> V=1.0, theta=0.0
% INFO    : Bus 2976	: V=1.00657, theta=25.464337 -> V=1.0, theta=0.0
% INFO    : Bus 2977	: V=0.967193, theta=48.296353 -> V=1.0, theta=0.0
% INFO    : Bus 2978	: V=1.027523, theta=-21.832316 -> V=1.0, theta=0.0
% INFO    : Bus 2979	: V=1.027523, theta=-21.832316 -> V=1.0, theta=0.0
% INFO    : Bus 2980	: V=1.027523, theta=-21.832316 -> V=1.0, theta=0.0
% INFO    : Bus 2981	: V=1.024756, theta=1.450408 -> V=1.0, theta=0.0
% INFO    : Bus 2982	: V=1.024756, theta=1.450408 -> V=1.0, theta=0.0
% INFO    : Bus 2983	: V=1.043072, theta=93.88678 -> V=1.0, theta=0.0
% INFO    : Bus 2984	: V=1.024833, theta=-17.429341 -> V=1.0, theta=0.0
% INFO    : Bus 2985	: V=1.030141, theta=39.290649 -> V=1.0, theta=0.0
% INFO    : Bus 2986	: V=1.047584, theta=-0.741816 -> V=1.0, theta=0.0
% INFO    : Bus 2987	: V=1.014067, theta=-13.863803 -> V=1.0, theta=0.0
% INFO    : Bus 2988	: V=0.92396, theta=-11.623321 -> V=1.0, theta=0.0
% INFO    : Bus 2989	: V=1.008539, theta=3.062301 -> V=1.0, theta=0.0
% INFO    : Bus 2990	: V=1.016588, theta=24.927519 -> V=1.0, theta=0.0
% INFO    : Bus 2991	: V=1.032132, theta=-3.910762 -> V=1.0, theta=0.0
% INFO    : Bus 2992	: V=1.012722, theta=-8.876216 -> V=1.0, theta=0.0
% INFO    : Bus 2993	: V=1.127982, theta=-0.363224 -> V=1.0, theta=0.0
% INFO    : Bus 2994	: V=0.985642, theta=34.609787 -> V=1.0, theta=0.0
% INFO    : Bus 2995	: V=0.950784, theta=-0.403765 -> V=1.0, theta=0.0
% INFO    : Bus 2996	: V=0.948638, theta=-1.282439 -> V=1.0, theta=0.0
% INFO    : Bus 2997	: V=1.010472, theta=-18.912844 -> V=1.0, theta=0.0
% INFO    : Bus 2998	: V=1.018613, theta=25.307234 -> V=1.0, theta=0.0
% INFO    : Bus 2999	: V=0.991684, theta=-11.480713 -> V=1.0, theta=0.0
% INFO    : Bus 3000	: V=0.996058, theta=20.763579 -> V=1.0, theta=0.0
% INFO    : Bus 3001	: V=1.028103, theta=35.299364 -> V=1.0, theta=0.0
% INFO    : Bus 3002	: V=0.993999, theta=-13.385176 -> V=1.0, theta=0.0
% INFO    : Bus 3003	: V=1.00749, theta=31.832433 -> V=1.0, theta=0.0
% INFO    : Bus 3004	: V=0.961256, theta=-8.218502 -> V=1.0, theta=0.0
% INFO    : Bus 3005	: V=1.014074, theta=90.565376 -> V=1.0, theta=0.0
% INFO    : Bus 3006	: V=0.993474, theta=-9.319885 -> V=1.0, theta=0.0
% INFO    : Bus 3007	: V=1.013906, theta=-25.46217 -> V=1.0, theta=0.0
% INFO    : Bus 3008	: V=1.039582, theta=1.171175 -> V=1.0, theta=0.0
% INFO    : Bus 3009	: V=1.028638, theta=7.443496 -> V=1.0, theta=0.0
% INFO    : Bus 3010	: V=0.99539, theta=20.289767 -> V=1.0, theta=0.0
% INFO    : Bus 3011	: V=1.050792, theta=2.691479 -> V=1.0, theta=0.0
% INFO    : Bus 3012	: V=1.024412, theta=23.818834 -> V=1.0, theta=0.0
% INFO    : Bus 3013	: V=1.041662, theta=8.678673 -> V=1.0, theta=0.0
% INFO    : Bus 3014	: V=1.0963, theta=-4.854397 -> V=1.0, theta=0.0
% INFO    : Bus 3015	: V=1.033334, theta=3.429229 -> V=1.0, theta=0.0
% INFO    : Bus 3016	: V=0.954853, theta=-4.912864 -> V=1.0, theta=0.0
% INFO    : Bus 3017	: V=1.014104, theta=26.485556 -> V=1.0, theta=0.0
% INFO    : Bus 3018	: V=1.026992, theta=13.603011 -> V=1.0, theta=0.0
% INFO    : Bus 3019	: V=1.060003, theta=79.42593 -> V=1.0, theta=0.0
% INFO    : Bus 3020	: V=1.053608, theta=28.092308 -> V=1.0, theta=0.0
% INFO    : Bus 3021	: V=1.014104, theta=26.485556 -> V=1.0, theta=0.0
% INFO    : Bus 3022	: V=1.014104, theta=26.485556 -> V=1.0, theta=0.0
% INFO    : Bus 3023	: V=1.001872, theta=0.589968 -> V=1.0, theta=0.0
% INFO    : Bus 3024	: V=1.005994, theta=30.332283 -> V=1.0, theta=0.0
% INFO    : Bus 3025	: V=1.019586, theta=29.439072 -> V=1.0, theta=0.0
% INFO    : Bus 3026	: V=1.009419, theta=16.230861 -> V=1.0, theta=0.0
% INFO    : Bus 3027	: V=1.012463, theta=-5.993975 -> V=1.0, theta=0.0
% INFO    : Bus 3028	: V=1.031926, theta=9.191503 -> V=1.0, theta=0.0
% INFO    : Bus 3029	: V=1.043665, theta=14.930439 -> V=1.0, theta=0.0
% INFO    : Bus 3030	: V=0.974652, theta=-25.839438 -> V=1.0, theta=0.0
% INFO    : Bus 3031	: V=1.018242, theta=17.423399 -> V=1.0, theta=0.0
% INFO    : Bus 3032	: V=1.0352, theta=-3.530694 -> V=1.0, theta=0.0
% INFO    : Bus 3033	: V=1.004662, theta=26.192512 -> V=1.0, theta=0.0
% INFO    : Bus 3034	: V=1.033962, theta=21.349108 -> V=1.0, theta=0.0
% INFO    : Bus 3035	: V=0.987509, theta=-15.826529 -> V=1.0, theta=0.0
% INFO    : Bus 3036	: V=1.041806, theta=4.567962 -> V=1.0, theta=0.0
% INFO    : Bus 3037	: V=1.019828, theta=21.769526 -> V=1.0, theta=0.0
% INFO    : Bus 3038	: V=1.015717, theta=14.479145 -> V=1.0, theta=0.0
% INFO    : Bus 3039	: V=1.012677, theta=-20.123731 -> V=1.0, theta=0.0
% INFO    : Bus 3040	: V=1.049836, theta=-6.49771 -> V=1.0, theta=0.0
% INFO    : Bus 3041	: V=0.920298, theta=-11.220957 -> V=1.0, theta=0.0
% INFO    : Bus 3042	: V=1.032426, theta=18.042041 -> V=1.0, theta=0.0
% INFO    : Bus 3043	: V=1.07085, theta=72.829731 -> V=1.0, theta=0.0
% INFO    : Bus 3044	: V=1.067115, theta=48.55262 -> V=1.0, theta=0.0
% INFO    : Bus 3045	: V=0.963367, theta=24.301846 -> V=1.0, theta=0.0
% INFO    : Bus 3046	: V=1.027641, theta=-16.751919 -> V=1.0, theta=0.0
% INFO    : Bus 3047	: V=1.047872, theta=-1.209101 -> V=1.0, theta=0.0
% INFO    : Bus 3048	: V=1.085973, theta=-3.616211 -> V=1.0, theta=0.0
% INFO    : Bus 3049	: V=1.034082, theta=31.667909 -> V=1.0, theta=0.0
% INFO    : Bus 3050	: V=1.033768, theta=14.596978 -> V=1.0, theta=0.0
% INFO    : Bus 3051	: V=0.977685, theta=10.299801 -> V=1.0, theta=0.0
% INFO    : Bus 3052	: V=1.020565, theta=30.713834 -> V=1.0, theta=0.0
% INFO    : Bus 3053	: V=1.003915, theta=-5.029519 -> V=1.0, theta=0.0
% INFO    : Bus 3054	: V=0.834005, theta=-17.59375 -> V=1.0, theta=0.0
% INFO    : Bus 3055	: V=1.011139, theta=-15.286107 -> V=1.0, theta=0.0
% INFO    : Bus 3056	: V=1.081964, theta=13.95024 -> V=1.0, theta=0.0
% INFO    : Bus 3057	: V=1.072158, theta=0.502654 -> V=1.0, theta=0.0
% INFO    : Bus 3058	: V=1.021353, theta=-16.057707 -> V=1.0, theta=0.0
% INFO    : Bus 3059	: V=1.010498, theta=-17.064676 -> V=1.0, theta=0.0
% INFO    : Bus 3060	: V=1.008604, theta=-1.974044 -> V=1.0, theta=0.0
% INFO    : Bus 3061	: V=1.041842, theta=41.954443 -> V=1.0, theta=0.0
% INFO    : Bus 3062	: V=1.041842, theta=41.954443 -> V=1.0, theta=0.0
% INFO    : Bus 3063	: V=1.05544, theta=46.172493 -> V=1.0, theta=0.0
% INFO    : Bus 3064	: V=1.051779, theta=-6.398929 -> V=1.0, theta=0.0
% INFO    : Bus 3065	: V=1.048637, theta=18.752224 -> V=1.0, theta=0.0
% INFO    : Bus 3066	: V=0.983472, theta=31.050625 -> V=1.0, theta=0.0
% INFO    : Bus 3067	: V=1.042065, theta=14.434339 -> V=1.0, theta=0.0
% INFO    : Bus 3068	: V=1.043939, theta=36.504273 -> V=1.0, theta=0.0
% INFO    : Bus 3069	: V=1.023764, theta=-3.675899 -> V=1.0, theta=0.0
% INFO    : Bus 3070	: V=1.023596, theta=21.694368 -> V=1.0, theta=0.0
% INFO    : Bus 3071	: V=1.0132, theta=-13.74777 -> V=1.0, theta=0.0
% INFO    : Bus 3072	: V=1.023058, theta=6.860658 -> V=1.0, theta=0.0
% INFO    : Bus 3073	: V=1.01869, theta=3.847783 -> V=1.0, theta=0.0
% INFO    : Bus 3074	: V=1.023058, theta=6.860658 -> V=1.0, theta=0.0
% INFO    : Bus 3075	: V=1.030804, theta=-0.760296 -> V=1.0, theta=0.0
% INFO    : Bus 3076	: V=1.019117, theta=-22.580163 -> V=1.0, theta=0.0
% INFO    : Bus 3077	: V=1.062348, theta=-1.257926 -> V=1.0, theta=0.0
% INFO    : Bus 3078	: V=1.002012, theta=13.542185 -> V=1.0, theta=0.0
% INFO    : Bus 3079	: V=1.020527, theta=-4.053254 -> V=1.0, theta=0.0
% INFO    : Bus 3080	: V=0.983365, theta=-23.074447 -> V=1.0, theta=0.0
% INFO    : Bus 3081	: V=1.028955, theta=49.734107 -> V=1.0, theta=0.0
% INFO    : Bus 3082	: V=0.959658, theta=41.263569 -> V=1.0, theta=0.0
% INFO    : Bus 3083	: V=1.068316, theta=1.198768 -> V=1.0, theta=0.0
% INFO    : Bus 3084	: V=1.008605, theta=-6.77169 -> V=1.0, theta=0.0
% INFO    : Bus 3085	: V=1.028133, theta=8.275168 -> V=1.0, theta=0.0
% INFO    : Bus 3086	: V=1.027606, theta=28.817047 -> V=1.0, theta=0.0
% INFO    : Bus 3087	: V=1.066871, theta=-5.364063 -> V=1.0, theta=0.0
% INFO    : Bus 3088	: V=0.948425, theta=51.609641 -> V=1.0, theta=0.0
% INFO    : Bus 3089	: V=0.996361, theta=-17.3888 -> V=1.0, theta=0.0
% INFO    : Bus 3090	: V=0.989513, theta=14.286196 -> V=1.0, theta=0.0
% INFO    : Bus 3091	: V=1.00244, theta=-9.914239 -> V=1.0, theta=0.0
% INFO    : Bus 3092	: V=1.054244, theta=8.966818 -> V=1.0, theta=0.0
% INFO    : Bus 3093	: V=1.062094, theta=84.081646 -> V=1.0, theta=0.0
% INFO    : Bus 3094	: V=1.048559, theta=90.431059 -> V=1.0, theta=0.0
% INFO    : Bus 3095	: V=1.050106, theta=73.063142 -> V=1.0, theta=0.0
% INFO    : Bus 3096	: V=1.048559, theta=90.431059 -> V=1.0, theta=0.0
% INFO    : Bus 3097	: V=1.050106, theta=73.063142 -> V=1.0, theta=0.0
% INFO    : Bus 3098	: V=1.050106, theta=73.063142 -> V=1.0, theta=0.0
% INFO    : Bus 3099	: V=1.034913, theta=19.583318 -> V=1.0, theta=0.0
% INFO    : Bus 3100	: V=1.062073, theta=84.08696 -> V=1.0, theta=0.0
% INFO    : Bus 3101	: V=1.062094, theta=84.081646 -> V=1.0, theta=0.0
% INFO    : Bus 3102	: V=1.02653, theta=21.638239 -> V=1.0, theta=0.0
% INFO    : Bus 3103	: V=1.040259, theta=34.3106 -> V=1.0, theta=0.0
% INFO    : Bus 3104	: V=1.040259, theta=34.3106 -> V=1.0, theta=0.0
% INFO    : Bus 3105	: V=1.015795, theta=22.756039 -> V=1.0, theta=0.0
% INFO    : Bus 3106	: V=1.060487, theta=48.408157 -> V=1.0, theta=0.0
% INFO    : Bus 3107	: V=1.023574, theta=3.735821 -> V=1.0, theta=0.0
% INFO    : Bus 3108	: V=1.023574, theta=3.735821 -> V=1.0, theta=0.0
% INFO    : Bus 3109	: V=1.0234, theta=3.527787 -> V=1.0, theta=0.0
% INFO    : Bus 3110	: V=1.026902, theta=3.580533 -> V=1.0, theta=0.0
% INFO    : Bus 3111	: V=1.0234, theta=3.527787 -> V=1.0, theta=0.0
% INFO    : Bus 3112	: V=1.030367, theta=0.220716 -> V=1.0, theta=0.0
% INFO    : Bus 3113	: V=1.030443, theta=-1.752265 -> V=1.0, theta=0.0
% INFO    : Bus 3114	: V=1.00571, theta=1.688469 -> V=1.0, theta=0.0
% INFO    : Bus 3115	: V=1.096855, theta=60.617 -> V=1.0, theta=0.0
% INFO    : Bus 3116	: V=1.009609, theta=-19.661174 -> V=1.0, theta=0.0
% INFO    : Bus 3117	: V=0.99314, theta=-9.90363 -> V=1.0, theta=0.0
% INFO    : Bus 3118	: V=0.963262, theta=-9.644491 -> V=1.0, theta=0.0
% INFO    : Bus 3119	: V=1.035147, theta=65.857496 -> V=1.0, theta=0.0
% INFO    : Bus 3120	: V=1.034839, theta=0.308162 -> V=1.0, theta=0.0
% INFO    : Bus 3121	: V=1.057682, theta=40.579523 -> V=1.0, theta=0.0
% INFO    : Bus 3122	: V=1.057682, theta=40.579523 -> V=1.0, theta=0.0
% INFO    : Bus 3123	: V=1.050841, theta=90.684517 -> V=1.0, theta=0.0
% INFO    : Bus 3124	: V=1.050841, theta=90.684517 -> V=1.0, theta=0.0
% INFO    : Bus 3125	: V=0.960854, theta=-4.989884 -> V=1.0, theta=0.0
% INFO    : Bus 3126	: V=0.990358, theta=-22.741184 -> V=1.0, theta=0.0
% INFO    : Bus 3127	: V=1.050579, theta=35.320834 -> V=1.0, theta=0.0
% INFO    : Bus 3128	: V=1.045612, theta=86.470349 -> V=1.0, theta=0.0
% INFO    : Bus 3129	: V=1.005101, theta=0.818924 -> V=1.0, theta=0.0
% INFO    : Bus 3130	: V=1.045612, theta=86.470349 -> V=1.0, theta=0.0
% INFO    : Bus 3131	: V=0.948542, theta=-8.803724 -> V=1.0, theta=0.0
% INFO    : Bus 3132	: V=1.012469, theta=-22.467823 -> V=1.0, theta=0.0
% INFO    : Bus 3133	: V=0.972032, theta=7.622339 -> V=1.0, theta=0.0
% INFO    : Bus 3134	: V=1.055592, theta=83.040122 -> V=1.0, theta=0.0
% INFO    : Bus 3135	: V=1.055592, theta=83.040122 -> V=1.0, theta=0.0
% INFO    : Bus 3136	: V=1.055592, theta=83.040122 -> V=1.0, theta=0.0
% INFO    : Bus 3137	: V=1.055592, theta=83.040122 -> V=1.0, theta=0.0
% INFO    : Bus 3138	: V=0.975876, theta=-11.404679 -> V=1.0, theta=0.0
% INFO    : Bus 3139	: V=1.033768, theta=14.596978 -> V=1.0, theta=0.0
% INFO    : Bus 3140	: V=1.013004, theta=-6.672823 -> V=1.0, theta=0.0
% INFO    : Bus 3141	: V=1.03603, theta=78.293887 -> V=1.0, theta=0.0
% INFO    : Bus 3142	: V=1.03603, theta=78.293887 -> V=1.0, theta=0.0
% INFO    : Bus 3143	: V=1.034933, theta=81.348467 -> V=1.0, theta=0.0
% INFO    : Bus 3144	: V=0.996071, theta=-7.239259 -> V=1.0, theta=0.0
% INFO    : Bus 3145	: V=1.034547, theta=81.296442 -> V=1.0, theta=0.0
% INFO    : Bus 3146	: V=1.028604, theta=-12.690591 -> V=1.0, theta=0.0
% INFO    : Bus 3147	: V=1.021721, theta=15.54218 -> V=1.0, theta=0.0
% INFO    : Bus 3148	: V=1.017868, theta=-15.794755 -> V=1.0, theta=0.0
% INFO    : Bus 3149	: V=0.964033, theta=-6.241528 -> V=1.0, theta=0.0
% INFO    : Bus 3150	: V=1.004597, theta=-15.207244 -> V=1.0, theta=0.0
% INFO    : Bus 3151	: V=0.923941, theta=-1.894529 -> V=1.0, theta=0.0
% INFO    : Bus 3152	: V=1.05813, theta=5.10364 -> V=1.0, theta=0.0
% INFO    : Bus 3153	: V=0.986936, theta=36.296305 -> V=1.0, theta=0.0
% INFO    : Bus 3154	: V=1.041223, theta=4.865379 -> V=1.0, theta=0.0
% INFO    : Bus 3155	: V=1.001884, theta=-10.143098 -> V=1.0, theta=0.0
% INFO    : Bus 3156	: V=1.012113, theta=93.904214 -> V=1.0, theta=0.0
% INFO    : Bus 3157	: V=0.947288, theta=-10.924648 -> V=1.0, theta=0.0
% INFO    : Bus 3158	: V=1.00507, theta=17.0212 -> V=1.0, theta=0.0
% INFO    : Bus 3159	: V=1.064147, theta=34.611639 -> V=1.0, theta=0.0
% INFO    : Bus 3160	: V=0.98633, theta=-2.201471 -> V=1.0, theta=0.0
% INFO    : Bus 3161	: V=0.963134, theta=-9.751258 -> V=1.0, theta=0.0
% INFO    : Bus 3162	: V=0.994543, theta=-3.850432 -> V=1.0, theta=0.0
% INFO    : Bus 3163	: V=0.983836, theta=-11.332269 -> V=1.0, theta=0.0
% INFO    : Bus 3164	: V=1.01814, theta=-7.851847 -> V=1.0, theta=0.0
% INFO    : Bus 3165	: V=1.029459, theta=27.896063 -> V=1.0, theta=0.0
% INFO    : Bus 3166	: V=1.014154, theta=-7.89767 -> V=1.0, theta=0.0
% INFO    : Bus 3167	: V=1.022861, theta=4.217398 -> V=1.0, theta=0.0
% INFO    : Bus 3168	: V=1.022861, theta=4.217398 -> V=1.0, theta=0.0
% INFO    : Bus 3169	: V=1.022861, theta=4.217398 -> V=1.0, theta=0.0
% INFO    : Bus 3170	: V=1.065913, theta=74.319622 -> V=1.0, theta=0.0
% INFO    : Bus 3171	: V=1.010695, theta=28.760676 -> V=1.0, theta=0.0
% INFO    : Bus 3172	: V=0.991482, theta=-25.02317 -> V=1.0, theta=0.0
% INFO    : Bus 3173	: V=1.022913, theta=-16.933536 -> V=1.0, theta=0.0
% INFO    : Bus 3174	: V=1.031132, theta=-7.749155 -> V=1.0, theta=0.0
% INFO    : Bus 3175	: V=1.006756, theta=-15.1197 -> V=1.0, theta=0.0
% INFO    : Bus 3176	: V=1.03058, theta=15.553508 -> V=1.0, theta=0.0
% INFO    : Bus 3177	: V=1.020476, theta=55.380688 -> V=1.0, theta=0.0
% INFO    : Bus 3178	: V=0.962508, theta=28.579218 -> V=1.0, theta=0.0
% INFO    : Bus 3179	: V=0.969605, theta=29.504132 -> V=1.0, theta=0.0
% INFO    : Bus 3180	: V=1.051606, theta=16.05419 -> V=1.0, theta=0.0
% INFO    : Bus 3181	: V=1.021283, theta=7.910363 -> V=1.0, theta=0.0
% INFO    : Bus 3182	: V=1.036145, theta=30.869082 -> V=1.0, theta=0.0
% INFO    : Bus 3183	: V=1.033937, theta=31.845751 -> V=1.0, theta=0.0
% INFO    : Bus 3184	: V=0.993105, theta=34.379244 -> V=1.0, theta=0.0
% INFO    : Bus 3185	: V=1.064935, theta=-7.972259 -> V=1.0, theta=0.0
% INFO    : Bus 3186	: V=1.048808, theta=68.937466 -> V=1.0, theta=0.0
% INFO    : Bus 3187	: V=1.032021, theta=3.020299 -> V=1.0, theta=0.0
% INFO    : Bus 3188	: V=1.06045, theta=-6.223335 -> V=1.0, theta=0.0
% INFO    : Bus 3189	: V=1.024334, theta=-19.631844 -> V=1.0, theta=0.0
% INFO    : Bus 3190	: V=1.009114, theta=34.555955 -> V=1.0, theta=0.0
% INFO    : Bus 3191	: V=1.026175, theta=-15.073177 -> V=1.0, theta=0.0
% INFO    : Bus 3192	: V=1.023187, theta=36.942852 -> V=1.0, theta=0.0
% INFO    : Bus 3193	: V=1.043327, theta=79.313508 -> V=1.0, theta=0.0
% INFO    : Bus 3194	: V=1.042014, theta=29.50224 -> V=1.0, theta=0.0
% INFO    : Bus 3195	: V=0.969914, theta=7.06577 -> V=1.0, theta=0.0
% INFO    : Bus 3196	: V=0.99471, theta=-3.303459 -> V=1.0, theta=0.0
% INFO    : Bus 3197	: V=0.996125, theta=26.875266 -> V=1.0, theta=0.0
% INFO    : Bus 3198	: V=0.966153, theta=37.549398 -> V=1.0, theta=0.0
% INFO    : Bus 3199	: V=1.058579, theta=11.117197 -> V=1.0, theta=0.0
% INFO    : Bus 3200	: V=1.013174, theta=29.812789 -> V=1.0, theta=0.0
% INFO    : Bus 3201	: V=1.034282, theta=8.113127 -> V=1.0, theta=0.0
% INFO    : Bus 3202	: V=1.039109, theta=-1.110008 -> V=1.0, theta=0.0
% INFO    : Bus 3203	: V=0.989027, theta=33.433286 -> V=1.0, theta=0.0
% INFO    : Bus 3204	: V=0.992836, theta=90.007676 -> V=1.0, theta=0.0
% INFO    : Bus 3205	: V=1.021971, theta=-18.847648 -> V=1.0, theta=0.0
% INFO    : Bus 3206	: V=1.018631, theta=-11.528817 -> V=1.0, theta=0.0
% INFO    : Bus 3207	: V=1.08011, theta=1.741777 -> V=1.0, theta=0.0
% INFO    : Bus 3208	: V=0.982791, theta=19.076224 -> V=1.0, theta=0.0
% INFO    : Bus 3209	: V=1.040256, theta=43.019104 -> V=1.0, theta=0.0
% INFO    : Bus 3210	: V=1.016876, theta=22.252733 -> V=1.0, theta=0.0
% INFO    : Bus 3211	: V=1.024174, theta=-20.53005 -> V=1.0, theta=0.0
% INFO    : Bus 3212	: V=1.114099, theta=0.152522 -> V=1.0, theta=0.0
% INFO    : Bus 3213	: V=1.016868, theta=22.255371 -> V=1.0, theta=0.0
% INFO    : Bus 3214	: V=1.016876, theta=22.252733 -> V=1.0, theta=0.0
% INFO    : Bus 3215	: V=1.016876, theta=22.252733 -> V=1.0, theta=0.0
% INFO    : Bus 3216	: V=1.016876, theta=22.252733 -> V=1.0, theta=0.0
% INFO    : Bus 3217	: V=1.063297, theta=57.37246 -> V=1.0, theta=0.0
% INFO    : Bus 3218	: V=1.001825, theta=-12.546618 -> V=1.0, theta=0.0
% INFO    : Bus 3219	: V=1.016868, theta=22.255371 -> V=1.0, theta=0.0
% INFO    : Bus 3220	: V=1.016868, theta=22.255371 -> V=1.0, theta=0.0
% INFO    : Bus 3221	: V=0.957465, theta=-0.98431 -> V=1.0, theta=0.0
% INFO    : Bus 3222	: V=1.009445, theta=4.392906 -> V=1.0, theta=0.0
% INFO    : Bus 3223	: V=1.069984, theta=-1.843245 -> V=1.0, theta=0.0
% INFO    : Bus 3224	: V=1.034075, theta=49.875441 -> V=1.0, theta=0.0
% INFO    : Bus 3225	: V=1.034314, theta=-10.021136 -> V=1.0, theta=0.0
% INFO    : Bus 3226	: V=1.03499, theta=-19.617451 -> V=1.0, theta=0.0
% INFO    : Bus 3227	: V=1.002095, theta=34.235111 -> V=1.0, theta=0.0
% INFO    : Bus 3228	: V=1.027518, theta=-17.089784 -> V=1.0, theta=0.0
% INFO    : Bus 3229	: V=1.014562, theta=32.096227 -> V=1.0, theta=0.0
% INFO    : Bus 3230	: V=1.055461, theta=-13.247245 -> V=1.0, theta=0.0
% INFO    : Bus 3231	: V=0.981328, theta=-8.077724 -> V=1.0, theta=0.0
% INFO    : Bus 3232	: V=0.961557, theta=-5.026887 -> V=1.0, theta=0.0
% INFO    : Bus 3233	: V=1.034314, theta=-10.021136 -> V=1.0, theta=0.0
% INFO    : Bus 3234	: V=1.014559, theta=-1.055158 -> V=1.0, theta=0.0
% INFO    : Bus 3235	: V=0.996619, theta=17.584415 -> V=1.0, theta=0.0
% INFO    : Bus 3236	: V=1.000449, theta=37.338871 -> V=1.0, theta=0.0
% INFO    : Bus 3237	: V=1.025252, theta=2.340914 -> V=1.0, theta=0.0
% INFO    : Bus 3238	: V=1.040701, theta=35.174448 -> V=1.0, theta=0.0
% INFO    : Bus 3239	: V=0.985476, theta=31.316276 -> V=1.0, theta=0.0
% INFO    : Bus 3240	: V=1.054736, theta=8.161866 -> V=1.0, theta=0.0
% INFO    : Bus 3241	: V=1.068493, theta=1.28496 -> V=1.0, theta=0.0
% INFO    : Bus 3242	: V=1.03499, theta=-19.617451 -> V=1.0, theta=0.0
% INFO    : Bus 3243	: V=1.012445, theta=4.699137 -> V=1.0, theta=0.0
% INFO    : Bus 3244	: V=1.051753, theta=14.759663 -> V=1.0, theta=0.0
% INFO    : Bus 3245	: V=1.03499, theta=-19.617451 -> V=1.0, theta=0.0
% INFO    : Bus 3246	: V=1.023718, theta=3.428847 -> V=1.0, theta=0.0
% INFO    : Bus 3247	: V=0.993427, theta=-9.324273 -> V=1.0, theta=0.0
% INFO    : Bus 3248	: V=1.037973, theta=11.471538 -> V=1.0, theta=0.0
% INFO    : Bus 3249	: V=1.009126, theta=-1.40707 -> V=1.0, theta=0.0
% INFO    : Bus 3250	: V=1.0082, theta=-1.533549 -> V=1.0, theta=0.0
% INFO    : Bus 3251	: V=1.054383, theta=5.160988 -> V=1.0, theta=0.0
% INFO    : Bus 3252	: V=1.032515, theta=74.532787 -> V=1.0, theta=0.0
% INFO    : Bus 3253	: V=0.999445, theta=44.319644 -> V=1.0, theta=0.0
% INFO    : Bus 3254	: V=0.982412, theta=-1.783489 -> V=1.0, theta=0.0
% INFO    : Bus 3255	: V=1.058355, theta=41.76159 -> V=1.0, theta=0.0
% INFO    : Bus 3256	: V=1.024264, theta=-3.679291 -> V=1.0, theta=0.0
% INFO    : Bus 3257	: V=1.017591, theta=16.020058 -> V=1.0, theta=0.0
% INFO    : Bus 3258	: V=0.986619, theta=-13.452821 -> V=1.0, theta=0.0
% INFO    : Bus 3259	: V=1.023766, theta=-2.523865 -> V=1.0, theta=0.0
% INFO    : Bus 3260	: V=1.045984, theta=36.938005 -> V=1.0, theta=0.0
% INFO    : Bus 3261	: V=1.010819, theta=90.346267 -> V=1.0, theta=0.0
% INFO    : Bus 3262	: V=1.016747, theta=23.522042 -> V=1.0, theta=0.0
% INFO    : Bus 3263	: V=1.051248, theta=-5.705729 -> V=1.0, theta=0.0
% INFO    : Bus 3264	: V=0.997223, theta=-9.751241 -> V=1.0, theta=0.0
% INFO    : Bus 3265	: V=1.05787, theta=-5.405768 -> V=1.0, theta=0.0
% INFO    : Bus 3266	: V=1.001352, theta=-15.450636 -> V=1.0, theta=0.0
% INFO    : Bus 3267	: V=1.030691, theta=13.607772 -> V=1.0, theta=0.0
% INFO    : Bus 3268	: V=1.033013, theta=18.139955 -> V=1.0, theta=0.0
% INFO    : Bus 3269	: V=1.028324, theta=-8.261232 -> V=1.0, theta=0.0
% INFO    : Bus 3270	: V=0.98472, theta=-1.315224 -> V=1.0, theta=0.0
% INFO    : Bus 3271	: V=1.041611, theta=-6.848028 -> V=1.0, theta=0.0
% INFO    : Bus 3272	: V=1.051683, theta=13.028435 -> V=1.0, theta=0.0
% INFO    : Bus 3273	: V=0.996835, theta=-3.084223 -> V=1.0, theta=0.0
% INFO    : Bus 3274	: V=0.989931, theta=-17.785937 -> V=1.0, theta=0.0
% INFO    : Bus 3275	: V=1.013363, theta=-27.00617 -> V=1.0, theta=0.0
% INFO    : Bus 3276	: V=1.023041, theta=-1.733209 -> V=1.0, theta=0.0
% INFO    : Bus 3277	: V=1.035066, theta=25.308502 -> V=1.0, theta=0.0
% INFO    : Bus 3278	: V=1.022381, theta=6.286187 -> V=1.0, theta=0.0
% INFO    : Bus 3279	: V=1.014258, theta=-26.848945 -> V=1.0, theta=0.0
% INFO    : Bus 3280	: V=1.041353, theta=7.871779 -> V=1.0, theta=0.0
% INFO    : Bus 3281	: V=0.988563, theta=-22.912606 -> V=1.0, theta=0.0
% INFO    : Bus 3282	: V=1.039025, theta=12.06939 -> V=1.0, theta=0.0
% INFO    : Bus 3283	: V=1.039025, theta=12.06939 -> V=1.0, theta=0.0
% INFO    : Bus 3284	: V=1.039025, theta=12.06939 -> V=1.0, theta=0.0
% INFO    : Bus 3285	: V=1.028692, theta=13.638716 -> V=1.0, theta=0.0
% INFO    : Bus 3286	: V=1.063544, theta=3.36992 -> V=1.0, theta=0.0
% INFO    : Bus 3287	: V=1.027757, theta=27.328033 -> V=1.0, theta=0.0
% INFO    : Bus 3288	: V=1.063031, theta=70.16259 -> V=1.0, theta=0.0
% INFO    : Bus 3289	: V=0.990129, theta=-5.911249 -> V=1.0, theta=0.0
% INFO    : Bus 3290	: V=1.028836, theta=6.244416 -> V=1.0, theta=0.0
% INFO    : Bus 3291	: V=1.064525, theta=50.433275 -> V=1.0, theta=0.0
% INFO    : Bus 3292	: V=1.035771, theta=2.999441 -> V=1.0, theta=0.0
% INFO    : Bus 3293	: V=0.986524, theta=-6.192619 -> V=1.0, theta=0.0
% INFO    : Bus 3294	: V=0.974759, theta=32.169943 -> V=1.0, theta=0.0
% INFO    : Bus 3295	: V=1.049444, theta=-6.481726 -> V=1.0, theta=0.0
% INFO    : Bus 3296	: V=1.041629, theta=38.466941 -> V=1.0, theta=0.0
% INFO    : Bus 3297	: V=1.048358, theta=31.36576 -> V=1.0, theta=0.0
% INFO    : Bus 3298	: V=1.048358, theta=31.36576 -> V=1.0, theta=0.0
% INFO    : Bus 3299	: V=1.048358, theta=31.36576 -> V=1.0, theta=0.0
% INFO    : Bus 3300	: V=1.006064, theta=27.970425 -> V=1.0, theta=0.0
% INFO    : Bus 3301	: V=1.001167, theta=22.914164 -> V=1.0, theta=0.0
% INFO    : Bus 3302	: V=1.027866, theta=16.538428 -> V=1.0, theta=0.0
% INFO    : Bus 3303	: V=1.027866, theta=16.538428 -> V=1.0, theta=0.0
% INFO    : Bus 3304	: V=1.027866, theta=16.538428 -> V=1.0, theta=0.0
% INFO    : Bus 3305	: V=1.027866, theta=16.538428 -> V=1.0, theta=0.0
% INFO    : Bus 3306	: V=1.048358, theta=31.36576 -> V=1.0, theta=0.0
% INFO    : Bus 3307	: V=1.048358, theta=31.36576 -> V=1.0, theta=0.0
% INFO    : Bus 3308	: V=1.054031, theta=9.216302 -> V=1.0, theta=0.0
% INFO    : Bus 3309	: V=1.054031, theta=9.216302 -> V=1.0, theta=0.0
% INFO    : Bus 3310	: V=1.029961, theta=20.347416 -> V=1.0, theta=0.0
% INFO    : Bus 3311	: V=0.992991, theta=15.869625 -> V=1.0, theta=0.0
% INFO    : Bus 3312	: V=1.007186, theta=-12.965964 -> V=1.0, theta=0.0
% INFO    : Bus 3313	: V=0.993675, theta=90.655341 -> V=1.0, theta=0.0
% INFO    : Bus 3314	: V=0.989667, theta=4.466255 -> V=1.0, theta=0.0
% INFO    : Bus 3315	: V=1.009646, theta=18.952981 -> V=1.0, theta=0.0
% INFO    : Bus 3316	: V=0.992991, theta=15.869625 -> V=1.0, theta=0.0
% INFO    : Bus 3317	: V=0.951009, theta=24.174308 -> V=1.0, theta=0.0
% INFO    : Bus 3318	: V=0.998359, theta=-14.319232 -> V=1.0, theta=0.0
% INFO    : Bus 3319	: V=1.03403, theta=4.734221 -> V=1.0, theta=0.0
% INFO    : Bus 3320	: V=1.021206, theta=16.043182 -> V=1.0, theta=0.0
% INFO    : Bus 3321	: V=1.010822, theta=15.191231 -> V=1.0, theta=0.0
% INFO    : Bus 3322	: V=1.04126, theta=36.379724 -> V=1.0, theta=0.0
% INFO    : Bus 3323	: V=1.019144, theta=17.562907 -> V=1.0, theta=0.0
% INFO    : Bus 3324	: V=0.990299, theta=27.156239 -> V=1.0, theta=0.0
% INFO    : Bus 3325	: V=1.03955, theta=19.355753 -> V=1.0, theta=0.0
% INFO    : Bus 3326	: V=1.03955, theta=19.355753 -> V=1.0, theta=0.0
% INFO    : Bus 3327	: V=1.039449, theta=19.583781 -> V=1.0, theta=0.0
% INFO    : Bus 3328	: V=1.039449, theta=19.583781 -> V=1.0, theta=0.0
% INFO    : Bus 3329	: V=1.017638, theta=-6.936102 -> V=1.0, theta=0.0
% INFO    : Bus 3330	: V=1.062419, theta=33.93163 -> V=1.0, theta=0.0
% INFO    : Bus 3331	: V=1.012867, theta=-2.151125 -> V=1.0, theta=0.0
% INFO    : Bus 3332	: V=0.967733, theta=-4.938733 -> V=1.0, theta=0.0
% INFO    : Bus 3333	: V=1.079271, theta=0.453859 -> V=1.0, theta=0.0
% INFO    : Bus 3334	: V=1.031677, theta=20.632573 -> V=1.0, theta=0.0
% INFO    : Bus 3335	: V=1.031677, theta=20.632573 -> V=1.0, theta=0.0
% INFO    : Bus 3336	: V=1.031677, theta=20.632573 -> V=1.0, theta=0.0
% INFO    : Bus 3337	: V=1.031677, theta=20.632573 -> V=1.0, theta=0.0
% INFO    : Bus 3338	: V=0.997985, theta=14.815692 -> V=1.0, theta=0.0
% INFO    : Bus 3339	: V=1.031677, theta=20.632573 -> V=1.0, theta=0.0
% INFO    : Bus 3340	: V=1.05284, theta=27.865674 -> V=1.0, theta=0.0
% INFO    : Bus 3341	: V=1.020439, theta=-0.4141 -> V=1.0, theta=0.0
% INFO    : Bus 3342	: V=0.953092, theta=-6.861044 -> V=1.0, theta=0.0
% INFO    : Bus 3343	: V=1.044129, theta=-4.738961 -> V=1.0, theta=0.0
% INFO    : Bus 3344	: V=1.062747, theta=39.318661 -> V=1.0, theta=0.0
% INFO    : Bus 3345	: V=1.031794, theta=-20.193093 -> V=1.0, theta=0.0
% INFO    : Bus 3346	: V=1.013615, theta=22.347716 -> V=1.0, theta=0.0
% INFO    : Bus 3347	: V=1.01361, theta=-2.270783 -> V=1.0, theta=0.0
% INFO    : Bus 3348	: V=1.02922, theta=2.854759 -> V=1.0, theta=0.0
% INFO    : Bus 3349	: V=1.02814, theta=19.066088 -> V=1.0, theta=0.0
% INFO    : Bus 3350	: V=1.078042, theta=3.076046 -> V=1.0, theta=0.0
% INFO    : Bus 3351	: V=1.049756, theta=20.130595 -> V=1.0, theta=0.0
% INFO    : Bus 3352	: V=1.035421, theta=27.235973 -> V=1.0, theta=0.0
% INFO    : Bus 3353	: V=1.054494, theta=82.561024 -> V=1.0, theta=0.0
% INFO    : Bus 3354	: V=1.02386, theta=-15.308152 -> V=1.0, theta=0.0
% INFO    : Bus 3355	: V=1.042858, theta=18.670383 -> V=1.0, theta=0.0
% INFO    : Bus 3356	: V=1.004221, theta=-1.833701 -> V=1.0, theta=0.0
% INFO    : Bus 3357	: V=0.997701, theta=34.849551 -> V=1.0, theta=0.0
% INFO    : Bus 3358	: V=1.008545, theta=-7.681908 -> V=1.0, theta=0.0
% INFO    : Bus 3359	: V=1.054031, theta=28.07277 -> V=1.0, theta=0.0
% INFO    : Bus 3360	: V=1.024095, theta=1.435812 -> V=1.0, theta=0.0
% INFO    : Bus 3361	: V=1.026025, theta=16.98036 -> V=1.0, theta=0.0
% INFO    : Bus 3362	: V=1.029604, theta=-21.160918 -> V=1.0, theta=0.0
% INFO    : Bus 3363	: V=1.01349, theta=41.769888 -> V=1.0, theta=0.0
% INFO    : Bus 3364	: V=0.990936, theta=89.584804 -> V=1.0, theta=0.0
% INFO    : Bus 3365	: V=1.060605, theta=43.468335 -> V=1.0, theta=0.0
% INFO    : Bus 3366	: V=1.060605, theta=43.468335 -> V=1.0, theta=0.0
% INFO    : Bus 3367	: V=1.060605, theta=43.468335 -> V=1.0, theta=0.0
% INFO    : Bus 3368	: V=1.060605, theta=43.468335 -> V=1.0, theta=0.0
% INFO    : Bus 3369	: V=1.000957, theta=10.706535 -> V=1.0, theta=0.0
% INFO    : Bus 3370	: V=1.004978, theta=16.730285 -> V=1.0, theta=0.0
% INFO    : Bus 3371	: V=1.002465, theta=24.966083 -> V=1.0, theta=0.0
% INFO    : Bus 3372	: V=1.014893, theta=-23.853656 -> V=1.0, theta=0.0
% INFO    : Bus 3373	: V=0.979844, theta=-8.592076 -> V=1.0, theta=0.0
% INFO    : Bus 3374	: V=1.047328, theta=23.171061 -> V=1.0, theta=0.0
% INFO    : Bus 3375	: V=1.014647, theta=-26.875031 -> V=1.0, theta=0.0
% INFO    : Bus 3376	: V=1.014113, theta=19.61214 -> V=1.0, theta=0.0
% INFO    : Bus 3377	: V=1.025023, theta=7.688637 -> V=1.0, theta=0.0
% INFO    : Bus 3378	: V=0.993261, theta=-1.484639 -> V=1.0, theta=0.0
% INFO    : Bus 3379	: V=1.010215, theta=-20.850901 -> V=1.0, theta=0.0
% INFO    : Bus 3380	: V=1.029748, theta=23.417775 -> V=1.0, theta=0.0
% INFO    : Bus 3381	: V=0.99291, theta=4.092686 -> V=1.0, theta=0.0
% INFO    : Bus 3382	: V=1.024269, theta=33.869817 -> V=1.0, theta=0.0
% INFO    : Bus 3383	: V=1.00224, theta=7.728333 -> V=1.0, theta=0.0
% INFO    : Bus 3384	: V=1.015185, theta=-4.986575 -> V=1.0, theta=0.0
% INFO    : Bus 3385	: V=0.988654, theta=21.137466 -> V=1.0, theta=0.0
% INFO    : Bus 3386	: V=0.993023, theta=-22.088253 -> V=1.0, theta=0.0
% INFO    : Bus 3387	: V=1.007717, theta=20.315673 -> V=1.0, theta=0.0
% INFO    : Bus 3388	: V=1.052287, theta=-6.250178 -> V=1.0, theta=0.0
% INFO    : Bus 3389	: V=1.058741, theta=-0.618359 -> V=1.0, theta=0.0
% INFO    : Bus 3390	: V=1.05585, theta=4.663945 -> V=1.0, theta=0.0
% INFO    : Bus 3391	: V=1.038039, theta=28.384829 -> V=1.0, theta=0.0
% INFO    : Bus 3392	: V=1.050098, theta=2.549535 -> V=1.0, theta=0.0
% INFO    : Bus 3393	: V=1.022635, theta=59.948045 -> V=1.0, theta=0.0
% INFO    : Bus 3394	: V=1.015601, theta=-16.259088 -> V=1.0, theta=0.0
% INFO    : Bus 3395	: V=0.979972, theta=13.126418 -> V=1.0, theta=0.0
% INFO    : Bus 3396	: V=1.017601, theta=-9.8258 -> V=1.0, theta=0.0
% INFO    : Bus 3397	: V=1.041041, theta=-0.264253 -> V=1.0, theta=0.0
% INFO    : Bus 3398	: V=1.008563, theta=-8.920839 -> V=1.0, theta=0.0
% INFO    : Bus 3399	: V=1.036457, theta=-1.746896 -> V=1.0, theta=0.0
% INFO    : Bus 3400	: V=0.990509, theta=-4.575961 -> V=1.0, theta=0.0
% INFO    : Bus 3401	: V=1.027046, theta=14.54611 -> V=1.0, theta=0.0
% INFO    : Bus 3402	: V=1.047034, theta=-4.588658 -> V=1.0, theta=0.0
% INFO    : Bus 3403	: V=1.017078, theta=-0.332817 -> V=1.0, theta=0.0
% INFO    : Bus 3404	: V=1.024544, theta=18.974877 -> V=1.0, theta=0.0
% INFO    : Bus 3405	: V=1.02403, theta=-2.72839 -> V=1.0, theta=0.0
% INFO    : Bus 3406	: V=1.038025, theta=5.013821 -> V=1.0, theta=0.0
% INFO    : Bus 3407	: V=1.017179, theta=-1.184569 -> V=1.0, theta=0.0
% INFO    : Bus 3408	: V=1.042118, theta=32.286272 -> V=1.0, theta=0.0
% INFO    : Bus 3409	: V=1.016693, theta=-11.720572 -> V=1.0, theta=0.0
% INFO    : Bus 3410	: V=1.031553, theta=24.597119 -> V=1.0, theta=0.0
% INFO    : Bus 3411	: V=1.052352, theta=7.80343 -> V=1.0, theta=0.0
% INFO    : Bus 3412	: V=1.031898, theta=-9.317211 -> V=1.0, theta=0.0
% INFO    : Bus 3413	: V=1.025829, theta=-8.115294 -> V=1.0, theta=0.0
% INFO    : Bus 3414	: V=1.031898, theta=-9.317211 -> V=1.0, theta=0.0
% INFO    : Bus 3415	: V=1.031898, theta=-9.317211 -> V=1.0, theta=0.0
% INFO    : Bus 3416	: V=1.031898, theta=-9.317211 -> V=1.0, theta=0.0
% INFO    : Bus 3417	: V=1.027663, theta=19.154658 -> V=1.0, theta=0.0
% INFO    : Bus 3418	: V=1.023338, theta=0.199966 -> V=1.0, theta=0.0
% INFO    : Bus 3419	: V=1.023338, theta=0.199966 -> V=1.0, theta=0.0
% INFO    : Bus 3420	: V=1.037361, theta=0.630863 -> V=1.0, theta=0.0
% INFO    : Bus 3421	: V=0.987799, theta=33.84916 -> V=1.0, theta=0.0
% INFO    : Bus 3422	: V=0.993355, theta=-4.276195 -> V=1.0, theta=0.0
% INFO    : Bus 3423	: V=1.014991, theta=-2.708292 -> V=1.0, theta=0.0
% INFO    : Bus 3424	: V=0.974881, theta=5.633736 -> V=1.0, theta=0.0
% INFO    : Bus 3425	: V=0.993608, theta=33.340436 -> V=1.0, theta=0.0
% INFO    : Bus 3426	: V=0.980816, theta=-7.972115 -> V=1.0, theta=0.0
% INFO    : Bus 3427	: V=1.014031, theta=3.520682 -> V=1.0, theta=0.0
% INFO    : Bus 3428	: V=1.055428, theta=37.715156 -> V=1.0, theta=0.0
% INFO    : Bus 3429	: V=1.060842, theta=81.899171 -> V=1.0, theta=0.0
% INFO    : Bus 3430	: V=1.014486, theta=0.895655 -> V=1.0, theta=0.0
% INFO    : Bus 3431	: V=0.996638, theta=31.225259 -> V=1.0, theta=0.0
% INFO    : Bus 3432	: V=1.01809, theta=15.340169 -> V=1.0, theta=0.0
% INFO    : Bus 3433	: V=1.001679, theta=-9.728984 -> V=1.0, theta=0.0
% INFO    : Bus 3434	: V=1.039787, theta=-14.573329 -> V=1.0, theta=0.0
% INFO    : Bus 3435	: V=1.014242, theta=3.601829 -> V=1.0, theta=0.0
% INFO    : Bus 3436	: V=0.970063, theta=-11.531386 -> V=1.0, theta=0.0
% INFO    : Bus 3437	: V=0.994775, theta=39.043524 -> V=1.0, theta=0.0
% INFO    : Bus 3438	: V=0.970327, theta=-8.450148 -> V=1.0, theta=0.0
% INFO    : Bus 3439	: V=1.050577, theta=5.678636 -> V=1.0, theta=0.0
% INFO    : Bus 3440	: V=0.963419, theta=-11.658198 -> V=1.0, theta=0.0
% INFO    : Bus 3441	: V=1.020428, theta=-20.356315 -> V=1.0, theta=0.0
% INFO    : Bus 3442	: V=0.92804, theta=-9.859715 -> V=1.0, theta=0.0
% INFO    : Bus 3443	: V=0.997356, theta=34.995095 -> V=1.0, theta=0.0
% INFO    : Bus 3444	: V=1.03559, theta=5.45741 -> V=1.0, theta=0.0
% INFO    : Bus 3445	: V=0.987953, theta=-12.008273 -> V=1.0, theta=0.0
% INFO    : Bus 3446	: V=1.031452, theta=-2.009965 -> V=1.0, theta=0.0
% INFO    : Bus 3447	: V=1.046044, theta=37.014055 -> V=1.0, theta=0.0
% INFO    : Bus 3448	: V=1.061419, theta=31.294242 -> V=1.0, theta=0.0
% INFO    : Bus 3449	: V=0.996656, theta=89.663571 -> V=1.0, theta=0.0
% INFO    : Bus 3450	: V=1.024316, theta=-15.494313 -> V=1.0, theta=0.0
% INFO    : Bus 3451	: V=1.032321, theta=27.942406 -> V=1.0, theta=0.0
% INFO    : Bus 3452	: V=0.994252, theta=33.32759 -> V=1.0, theta=0.0
% INFO    : Bus 3453	: V=0.975542, theta=41.132827 -> V=1.0, theta=0.0
% INFO    : Bus 3454	: V=1.022093, theta=-1.298193 -> V=1.0, theta=0.0
% INFO    : Bus 3455	: V=1.036969, theta=8.807607 -> V=1.0, theta=0.0
% INFO    : Bus 3456	: V=1.022332, theta=-0.918362 -> V=1.0, theta=0.0
% INFO    : Bus 3457	: V=1.022727, theta=-22.069659 -> V=1.0, theta=0.0
% INFO    : Bus 3458	: V=1.051628, theta=2.2953 -> V=1.0, theta=0.0
% INFO    : Bus 3459	: V=0.966758, theta=19.018606 -> V=1.0, theta=0.0
% INFO    : Bus 3460	: V=0.982006, theta=31.373859 -> V=1.0, theta=0.0
% INFO    : Bus 3461	: V=1.021236, theta=-10.829774 -> V=1.0, theta=0.0
% INFO    : Bus 3462	: V=1.010426, theta=10.003085 -> V=1.0, theta=0.0
% INFO    : Bus 3463	: V=1.063388, theta=34.050037 -> V=1.0, theta=0.0
% INFO    : Bus 3464	: V=1.012147, theta=29.950952 -> V=1.0, theta=0.0
% INFO    : Bus 3465	: V=1.024265, theta=-24.35039 -> V=1.0, theta=0.0
% INFO    : Bus 3466	: V=1.025014, theta=6.614618 -> V=1.0, theta=0.0
% INFO    : Bus 3467	: V=0.987196, theta=-9.010973 -> V=1.0, theta=0.0
% INFO    : Bus 3468	: V=1.028283, theta=16.586422 -> V=1.0, theta=0.0
% INFO    : Bus 3469	: V=1.034629, theta=40.948139 -> V=1.0, theta=0.0
% INFO    : Bus 3470	: V=1.006421, theta=-16.70944 -> V=1.0, theta=0.0
% INFO    : Bus 3471	: V=1.060112, theta=4.394131 -> V=1.0, theta=0.0
% INFO    : Bus 3472	: V=1.027981, theta=8.098574 -> V=1.0, theta=0.0
% INFO    : Bus 3473	: V=1.059962, theta=21.272506 -> V=1.0, theta=0.0
% INFO    : Bus 3474	: V=1.03472, theta=7.897462 -> V=1.0, theta=0.0
% INFO    : Bus 3475	: V=1.012584, theta=13.76329 -> V=1.0, theta=0.0
% INFO    : Bus 3476	: V=1.080752, theta=1.771085 -> V=1.0, theta=0.0
% INFO    : Bus 3477	: V=1.069676, theta=18.142683 -> V=1.0, theta=0.0
% INFO    : Bus 3478	: V=0.978974, theta=-1.90048 -> V=1.0, theta=0.0
% INFO    : Bus 3479	: V=0.993763, theta=25.0541 -> V=1.0, theta=0.0
% INFO    : Bus 3480	: V=1.010314, theta=-12.093155 -> V=1.0, theta=0.0
% INFO    : Bus 3481	: V=1.040138, theta=32.45384 -> V=1.0, theta=0.0
% INFO    : Bus 3482	: V=1.00657, theta=25.464337 -> V=1.0, theta=0.0
% INFO    : Bus 3483	: V=0.96217, theta=-9.934797 -> V=1.0, theta=0.0
% INFO    : Bus 3484	: V=1.026623, theta=-2.535644 -> V=1.0, theta=0.0
% INFO    : Bus 3485	: V=1.023602, theta=23.130323 -> V=1.0, theta=0.0
% INFO    : Bus 3486	: V=1.006606, theta=31.420169 -> V=1.0, theta=0.0
% INFO    : Bus 3487	: V=1.023603, theta=23.127902 -> V=1.0, theta=0.0
% INFO    : Bus 3488	: V=0.975077, theta=24.924484 -> V=1.0, theta=0.0
% INFO    : Bus 3489	: V=1.023602, theta=23.130323 -> V=1.0, theta=0.0
% INFO    : Bus 3490	: V=1.023602, theta=23.130323 -> V=1.0, theta=0.0
% INFO    : Bus 3491	: V=1.037557, theta=26.827154 -> V=1.0, theta=0.0
% INFO    : Bus 3492	: V=1.036951, theta=-14.261938 -> V=1.0, theta=0.0
% INFO    : Bus 3493	: V=1.036353, theta=8.668859 -> V=1.0, theta=0.0
% INFO    : Bus 3494	: V=1.036517, theta=-13.684117 -> V=1.0, theta=0.0
% INFO    : Bus 3495	: V=1.036517, theta=-13.684117 -> V=1.0, theta=0.0
% INFO    : Bus 3496	: V=1.036517, theta=-13.684117 -> V=1.0, theta=0.0
% INFO    : Bus 3497	: V=1.027593, theta=45.337586 -> V=1.0, theta=0.0
% INFO    : Bus 3498	: V=1.012828, theta=30.519623 -> V=1.0, theta=0.0
% INFO    : Bus 3499	: V=0.998951, theta=38.095582 -> V=1.0, theta=0.0
% INFO    : Bus 3500	: V=0.982498, theta=31.482622 -> V=1.0, theta=0.0
% INFO    : Bus 3501	: V=0.996236, theta=-3.764714 -> V=1.0, theta=0.0
% INFO    : Bus 3502	: V=1.050951, theta=24.745156 -> V=1.0, theta=0.0
% INFO    : Bus 3503	: V=1.023975, theta=33.808211 -> V=1.0, theta=0.0
% INFO    : Bus 3504	: V=1.016408, theta=34.721433 -> V=1.0, theta=0.0
% INFO    : Bus 3505	: V=0.96416, theta=-9.80938 -> V=1.0, theta=0.0
% INFO    : Bus 3506	: V=1.065819, theta=38.30131 -> V=1.0, theta=0.0
% INFO    : Bus 3507	: V=1.005241, theta=12.365918 -> V=1.0, theta=0.0
% INFO    : Bus 3508	: V=1.01212, theta=1.557585 -> V=1.0, theta=0.0
% INFO    : Bus 3509	: V=1.071621, theta=58.815915 -> V=1.0, theta=0.0
% INFO    : Bus 3510	: V=1.106046, theta=27.40938 -> V=1.0, theta=0.0
% INFO    : Bus 3511	: V=1.00261, theta=29.643643 -> V=1.0, theta=0.0
% INFO    : Bus 3512	: V=1.043163, theta=0.620392 -> V=1.0, theta=0.0
% INFO    : Bus 3513	: V=0.977145, theta=43.93916 -> V=1.0, theta=0.0
% INFO    : Bus 3514	: V=1.032796, theta=24.345595 -> V=1.0, theta=0.0
% INFO    : Bus 3515	: V=1.045647, theta=-10.158279 -> V=1.0, theta=0.0
% INFO    : Bus 3516	: V=1.031876, theta=-8.151731 -> V=1.0, theta=0.0
% INFO    : Bus 3517	: V=1.005112, theta=-1.198328 -> V=1.0, theta=0.0
% INFO    : Bus 3518	: V=1.021184, theta=-3.795612 -> V=1.0, theta=0.0
% INFO    : Bus 3519	: V=1.016509, theta=21.315301 -> V=1.0, theta=0.0
% INFO    : Bus 3520	: V=1.046665, theta=36.809947 -> V=1.0, theta=0.0
% INFO    : Bus 3521	: V=1.046665, theta=36.809947 -> V=1.0, theta=0.0
% INFO    : Bus 3522	: V=1.026609, theta=5.560793 -> V=1.0, theta=0.0
% INFO    : Bus 3523	: V=1.046665, theta=36.809947 -> V=1.0, theta=0.0
% INFO    : Bus 3524	: V=1.046665, theta=36.809947 -> V=1.0, theta=0.0
% INFO    : Bus 3525	: V=1.046665, theta=36.809947 -> V=1.0, theta=0.0
% INFO    : Bus 3526	: V=1.046665, theta=36.809947 -> V=1.0, theta=0.0
% INFO    : Bus 3527	: V=1.00273, theta=9.696275 -> V=1.0, theta=0.0
% INFO    : Bus 3528	: V=1.031098, theta=31.248826 -> V=1.0, theta=0.0
% INFO    : Bus 3529	: V=1.031098, theta=31.248826 -> V=1.0, theta=0.0
% INFO    : Bus 3530	: V=1.031098, theta=31.248826 -> V=1.0, theta=0.0
% INFO    : Bus 3531	: V=1.019147, theta=-15.161399 -> V=1.0, theta=0.0
% INFO    : Bus 3532	: V=0.971988, theta=-12.365085 -> V=1.0, theta=0.0
% INFO    : Bus 3533	: V=1.035099, theta=12.647063 -> V=1.0, theta=0.0
% INFO    : Bus 3534	: V=1.009, theta=-3.635217 -> V=1.0, theta=0.0
% INFO    : Bus 3535	: V=1.043665, theta=14.930439 -> V=1.0, theta=0.0
% INFO    : Bus 3536	: V=1.083932, theta=72.529665 -> V=1.0, theta=0.0
% INFO    : Bus 3537	: V=0.970818, theta=-10.152793 -> V=1.0, theta=0.0
% INFO    : Bus 3538	: V=1.052634, theta=28.316735 -> V=1.0, theta=0.0
% INFO    : Bus 3539	: V=0.935866, theta=-7.822814 -> V=1.0, theta=0.0
% INFO    : Bus 3540	: V=1.022458, theta=16.340229 -> V=1.0, theta=0.0
% INFO    : Bus 3541	: V=1.016192, theta=22.827293 -> V=1.0, theta=0.0
% INFO    : Bus 3542	: V=1.008608, theta=-8.684052 -> V=1.0, theta=0.0
% INFO    : Bus 3543	: V=1.051307, theta=2.565569 -> V=1.0, theta=0.0
% INFO    : Bus 3544	: V=1.023752, theta=-4.194406 -> V=1.0, theta=0.0
% INFO    : Bus 3545	: V=1.004518, theta=-19.968461 -> V=1.0, theta=0.0
% INFO    : Bus 3546	: V=0.981021, theta=28.816632 -> V=1.0, theta=0.0
% INFO    : Bus 3547	: V=1.02717, theta=5.529453 -> V=1.0, theta=0.0
% INFO    : Bus 3548	: V=0.919642, theta=-11.307959 -> V=1.0, theta=0.0
% INFO    : Bus 3549	: V=1.047536, theta=-3.624886 -> V=1.0, theta=0.0
% INFO    : Bus 3550	: V=1.036635, theta=21.536239 -> V=1.0, theta=0.0
% INFO    : Bus 3551	: V=1.045549, theta=56.658865 -> V=1.0, theta=0.0
% INFO    : Bus 3552	: V=0.982474, theta=0.471501 -> V=1.0, theta=0.0
% INFO    : Bus 3553	: V=1.048632, theta=39.237883 -> V=1.0, theta=0.0
% INFO    : Bus 3554	: V=0.993719, theta=14.993796 -> V=1.0, theta=0.0
% INFO    : Bus 3555	: V=1.032921, theta=46.915222 -> V=1.0, theta=0.0
% INFO    : Bus 3556	: V=0.99438, theta=26.585157 -> V=1.0, theta=0.0
% INFO    : Bus 3557	: V=1.066429, theta=42.054161 -> V=1.0, theta=0.0
% INFO    : Bus 3558	: V=1.06254, theta=42.153021 -> V=1.0, theta=0.0
% INFO    : Bus 3559	: V=1.028344, theta=10.931458 -> V=1.0, theta=0.0
% INFO    : Bus 3560	: V=1.017793, theta=13.597911 -> V=1.0, theta=0.0
% INFO    : Bus 3561	: V=1.009695, theta=30.943238 -> V=1.0, theta=0.0
% INFO    : Bus 3562	: V=1.011684, theta=22.030289 -> V=1.0, theta=0.0
% INFO    : Bus 3563	: V=1.021046, theta=-19.851631 -> V=1.0, theta=0.0
% INFO    : Bus 3564	: V=0.995074, theta=-7.669658 -> V=1.0, theta=0.0
% INFO    : Bus 3565	: V=1.001548, theta=34.654477 -> V=1.0, theta=0.0
% INFO    : Bus 3566	: V=1.033327, theta=38.101688 -> V=1.0, theta=0.0
% INFO    : Bus 3567	: V=0.992476, theta=33.395862 -> V=1.0, theta=0.0
% INFO    : Bus 3568	: V=1.03441, theta=8.755896 -> V=1.0, theta=0.0
% INFO    : Bus 3569	: V=1.056202, theta=-3.897592 -> V=1.0, theta=0.0
% INFO    : Bus 3570	: V=1.025816, theta=-8.26672 -> V=1.0, theta=0.0
% INFO    : Bus 3571	: V=1.043771, theta=22.935303 -> V=1.0, theta=0.0
% INFO    : Bus 3572	: V=1.03612, theta=30.869394 -> V=1.0, theta=0.0
% INFO    : Bus 3573	: V=0.994784, theta=23.512593 -> V=1.0, theta=0.0
% INFO    : Bus 3574	: V=0.984061, theta=32.874687 -> V=1.0, theta=0.0
% INFO    : Bus 3575	: V=1.025816, theta=-8.26672 -> V=1.0, theta=0.0
% INFO    : Bus 3576	: V=1.036937, theta=17.554732 -> V=1.0, theta=0.0
% INFO    : Bus 3577	: V=1.035838, theta=-5.172678 -> V=1.0, theta=0.0
% INFO    : Bus 3578	: V=0.99193, theta=25.086276 -> V=1.0, theta=0.0
% INFO    : Bus 3579	: V=1.003099, theta=31.233662 -> V=1.0, theta=0.0
% INFO    : Bus 3580	: V=1.054138, theta=25.098015 -> V=1.0, theta=0.0
% INFO    : Bus 3581	: V=1.087145, theta=1.037104 -> V=1.0, theta=0.0
% INFO    : Bus 3582	: V=1.054138, theta=25.098015 -> V=1.0, theta=0.0
% INFO    : Bus 3583	: V=1.021252, theta=4.698139 -> V=1.0, theta=0.0
% INFO    : Bus 3584	: V=0.967704, theta=-29.098732 -> V=1.0, theta=0.0
% INFO    : Bus 3585	: V=1.037254, theta=4.793274 -> V=1.0, theta=0.0
% INFO    : Bus 3586	: V=1.037254, theta=4.793274 -> V=1.0, theta=0.0
% INFO    : Bus 3587	: V=1.033975, theta=-14.23689 -> V=1.0, theta=0.0
% INFO    : Bus 3588	: V=1.033975, theta=-14.23689 -> V=1.0, theta=0.0
% INFO    : Bus 3589	: V=1.019797, theta=-29.648677 -> V=1.0, theta=0.0
% INFO    : Bus 3590	: V=1.009359, theta=-12.831934 -> V=1.0, theta=0.0
% INFO    : Bus 3591	: V=1.030391, theta=4.513136 -> V=1.0, theta=0.0
% INFO    : Bus 3592	: V=1.043945, theta=-12.163947 -> V=1.0, theta=0.0
% INFO    : Bus 3593	: V=1.017275, theta=5.427076 -> V=1.0, theta=0.0
% INFO    : Bus 3594	: V=0.977983, theta=1.255828 -> V=1.0, theta=0.0
% INFO    : Bus 3595	: V=1.003565, theta=-17.947547 -> V=1.0, theta=0.0
% INFO    : Bus 3596	: V=1.015526, theta=5.219003 -> V=1.0, theta=0.0
% INFO    : Bus 3597	: V=0.965234, theta=-12.021644 -> V=1.0, theta=0.0
% INFO    : Bus 3598	: V=0.964011, theta=0.683582 -> V=1.0, theta=0.0
% INFO    : Bus 3599	: V=1.037334, theta=-14.082496 -> V=1.0, theta=0.0
% INFO    : Bus 3600	: V=0.979489, theta=33.786715 -> V=1.0, theta=0.0
% INFO    : Bus 3601	: V=1.015973, theta=11.841244 -> V=1.0, theta=0.0
% INFO    : Bus 3602	: V=1.028369, theta=17.782814 -> V=1.0, theta=0.0
% INFO    : Bus 3603	: V=1.041768, theta=42.609741 -> V=1.0, theta=0.0
% INFO    : Bus 3604	: V=1.010833, theta=-9.547443 -> V=1.0, theta=0.0
% INFO    : Bus 3605	: V=1.033512, theta=60.138665 -> V=1.0, theta=0.0
% INFO    : Bus 3606	: V=1.012302, theta=18.270868 -> V=1.0, theta=0.0
% INFO    : Bus 3607	: V=1.039371, theta=7.907608 -> V=1.0, theta=0.0
% INFO    : Bus 3608	: V=1.029635, theta=34.5439 -> V=1.0, theta=0.0
% INFO    : Bus 3609	: V=1.013143, theta=25.793225 -> V=1.0, theta=0.0
% INFO    : Bus 3610	: V=1.068762, theta=42.463865 -> V=1.0, theta=0.0
% INFO    : Bus 3611	: V=1.068762, theta=42.463865 -> V=1.0, theta=0.0
% INFO    : Bus 3612	: V=0.996474, theta=-3.242785 -> V=1.0, theta=0.0
% INFO    : Bus 3613	: V=1.060493, theta=15.281688 -> V=1.0, theta=0.0
% INFO    : Bus 3614	: V=1.020596, theta=-16.730831 -> V=1.0, theta=0.0
% INFO    : Bus 3615	: V=1.021029, theta=-18.0658 -> V=1.0, theta=0.0
% INFO    : Bus 3616	: V=0.984779, theta=17.794275 -> V=1.0, theta=0.0
% INFO    : Bus 3617	: V=1.024499, theta=-3.834468 -> V=1.0, theta=0.0
% INFO    : Bus 3618	: V=0.993659, theta=32.238381 -> V=1.0, theta=0.0
% INFO    : Bus 3619	: V=1.043657, theta=3.510271 -> V=1.0, theta=0.0
% INFO    : Bus 3620	: V=1.043657, theta=3.510271 -> V=1.0, theta=0.0
% INFO    : Bus 3621	: V=1.030254, theta=1.875231 -> V=1.0, theta=0.0
% INFO    : Bus 3622	: V=1.001093, theta=-2.661671 -> V=1.0, theta=0.0
% INFO    : Bus 3623	: V=1.003215, theta=16.411463 -> V=1.0, theta=0.0
% INFO    : Bus 3624	: V=0.969701, theta=20.289409 -> V=1.0, theta=0.0
% INFO    : Bus 3625	: V=1.022039, theta=16.134374 -> V=1.0, theta=0.0
% INFO    : Bus 3626	: V=0.997548, theta=-6.641209 -> V=1.0, theta=0.0
% INFO    : Bus 3627	: V=1.011158, theta=10.497232 -> V=1.0, theta=0.0
% INFO    : Bus 3628	: V=1.04549, theta=24.880973 -> V=1.0, theta=0.0
% INFO    : Bus 3629	: V=1.03845, theta=-0.981126 -> V=1.0, theta=0.0
% INFO    : Bus 3630	: V=1.029562, theta=-6.831163 -> V=1.0, theta=0.0
% INFO    : Bus 3631	: V=1.050006, theta=39.688536 -> V=1.0, theta=0.0
% INFO    : Bus 3632	: V=0.990319, theta=-5.145593 -> V=1.0, theta=0.0
% INFO    : Bus 3633	: V=1.024572, theta=-13.995277 -> V=1.0, theta=0.0
% INFO    : Bus 3634	: V=0.985279, theta=-0.58714 -> V=1.0, theta=0.0
% INFO    : Bus 3635	: V=1.063829, theta=73.160942 -> V=1.0, theta=0.0
% INFO    : Bus 3636	: V=1.001427, theta=20.99492 -> V=1.0, theta=0.0
% INFO    : Bus 3637	: V=1.064717, theta=0.810879 -> V=1.0, theta=0.0
% INFO    : Bus 3638	: V=1.047953, theta=30.002755 -> V=1.0, theta=0.0
% INFO    : Bus 3639	: V=1.00818, theta=-9.064966 -> V=1.0, theta=0.0
% INFO    : Bus 3640	: V=1.002688, theta=-1.315468 -> V=1.0, theta=0.0
% INFO    : Bus 3641	: V=1.03809, theta=81.248194 -> V=1.0, theta=0.0
% INFO    : Bus 3642	: V=1.03809, theta=81.248194 -> V=1.0, theta=0.0
% INFO    : Bus 3643	: V=1.014073, theta=-16.400343 -> V=1.0, theta=0.0
% INFO    : Bus 3644	: V=1.033768, theta=14.596978 -> V=1.0, theta=0.0
% INFO    : Bus 3645	: V=0.986182, theta=-8.108772 -> V=1.0, theta=0.0
% INFO    : Bus 3646	: V=1.01964, theta=-10.829105 -> V=1.0, theta=0.0
% INFO    : Bus 3647	: V=1.055981, theta=85.333831 -> V=1.0, theta=0.0
% INFO    : Bus 3648	: V=0.983213, theta=-3.233177 -> V=1.0, theta=0.0
% INFO    : Bus 3649	: V=1.024836, theta=0.177514 -> V=1.0, theta=0.0
% INFO    : Bus 3650	: V=1.03285, theta=5.192474 -> V=1.0, theta=0.0
% INFO    : Bus 3651	: V=1.037131, theta=84.517509 -> V=1.0, theta=0.0
% INFO    : Bus 3652	: V=1.002482, theta=-9.023078 -> V=1.0, theta=0.0
% INFO    : Bus 3653	: V=1.014031, theta=-11.505239 -> V=1.0, theta=0.0
% INFO    : Bus 3654	: V=0.998271, theta=89.04279 -> V=1.0, theta=0.0
% INFO    : Bus 3655	: V=1.048808, theta=68.937466 -> V=1.0, theta=0.0
% INFO    : Bus 3656	: V=1.037131, theta=84.517509 -> V=1.0, theta=0.0
% INFO    : Bus 3657	: V=1.027845, theta=44.66359 -> V=1.0, theta=0.0
% INFO    : Bus 3658	: V=1.071505, theta=-2.602415 -> V=1.0, theta=0.0
% INFO    : Bus 3659	: V=0.987125, theta=-10.738282 -> V=1.0, theta=0.0
% INFO    : Bus 3660	: V=1.006782, theta=-15.116007 -> V=1.0, theta=0.0
% INFO    : Bus 3661	: V=1.055822, theta=28.547053 -> V=1.0, theta=0.0
% INFO    : Bus 3662	: V=1.016459, theta=22.356581 -> V=1.0, theta=0.0
% INFO    : Bus 3663	: V=1.028091, theta=-15.249181 -> V=1.0, theta=0.0
% INFO    : Bus 3664	: V=1.014379, theta=-16.62541 -> V=1.0, theta=0.0
% INFO    : Bus 3665	: V=1.014379, theta=-16.62541 -> V=1.0, theta=0.0
% INFO    : Bus 3666	: V=1.032339, theta=31.528476 -> V=1.0, theta=0.0
% INFO    : Bus 3667	: V=1.048078, theta=39.856974 -> V=1.0, theta=0.0
% INFO    : Bus 3668	: V=1.026038, theta=-10.378066 -> V=1.0, theta=0.0
% INFO    : Bus 3669	: V=0.964668, theta=33.685037 -> V=1.0, theta=0.0
% INFO    : Bus 3670	: V=1.037142, theta=8.484027 -> V=1.0, theta=0.0
% INFO    : Bus 3671	: V=1.038581, theta=90.625252 -> V=1.0, theta=0.0
% INFO    : Bus 3672	: V=1.038581, theta=90.625252 -> V=1.0, theta=0.0
% INFO    : Bus 3673	: V=1.014379, theta=-16.62541 -> V=1.0, theta=0.0
% INFO    : Bus 3674	: V=1.021115, theta=-13.977656 -> V=1.0, theta=0.0
% INFO    : Bus 3675	: V=1.025842, theta=-13.216265 -> V=1.0, theta=0.0
% INFO    : Bus 3676	: V=1.007888, theta=-3.514467 -> V=1.0, theta=0.0
% INFO    : Bus 3677	: V=0.987529, theta=-2.60863 -> V=1.0, theta=0.0
% INFO    : Bus 3678	: V=1.029714, theta=0.22642 -> V=1.0, theta=0.0
% INFO    : Bus 3679	: V=0.990688, theta=-24.46203 -> V=1.0, theta=0.0
% INFO    : Bus 3680	: V=1.014154, theta=-7.89767 -> V=1.0, theta=0.0
% INFO    : Bus 3681	: V=0.991422, theta=-17.579363 -> V=1.0, theta=0.0
% INFO    : Bus 3682	: V=1.023493, theta=7.689974 -> V=1.0, theta=0.0
% INFO    : Bus 3683	: V=1.03058, theta=15.553508 -> V=1.0, theta=0.0
% INFO    : Bus 3684	: V=1.014246, theta=-26.213478 -> V=1.0, theta=0.0
% INFO    : Bus 3685	: V=0.977248, theta=8.573334 -> V=1.0, theta=0.0
% INFO    : Bus 3686	: V=1.003179, theta=38.552189 -> V=1.0, theta=0.0
% INFO    : Bus 3687	: V=1.036572, theta=-17.33246 -> V=1.0, theta=0.0
% INFO    : Bus 3688	: V=0.993874, theta=-4.949615 -> V=1.0, theta=0.0
% INFO    : Bus 3689	: V=0.986667, theta=-5.290434 -> V=1.0, theta=0.0
% INFO    : Bus 3690	: V=0.991862, theta=90.288614 -> V=1.0, theta=0.0
% INFO    : Bus 3691	: V=1.037397, theta=-18.746774 -> V=1.0, theta=0.0
% INFO    : Bus 3692	: V=1.026617, theta=-7.205824 -> V=1.0, theta=0.0
% INFO    : Bus 3693	: V=1.060844, theta=39.586385 -> V=1.0, theta=0.0
% INFO    : Bus 3694	: V=0.994502, theta=22.334869 -> V=1.0, theta=0.0
% INFO    : Bus 3695	: V=1.047752, theta=29.881973 -> V=1.0, theta=0.0
% INFO    : Bus 3696	: V=1.047752, theta=29.881973 -> V=1.0, theta=0.0
% INFO    : Bus 3697	: V=1.047752, theta=29.881973 -> V=1.0, theta=0.0
% INFO    : Bus 3698	: V=1.047752, theta=29.881973 -> V=1.0, theta=0.0
% INFO    : Bus 3699	: V=1.047752, theta=29.881973 -> V=1.0, theta=0.0
% INFO    : Bus 3700	: V=1.047752, theta=29.881973 -> V=1.0, theta=0.0
% INFO    : Bus 3701	: V=1.047752, theta=29.881973 -> V=1.0, theta=0.0
% INFO    : Bus 3702	: V=1.05008, theta=28.114519 -> V=1.0, theta=0.0
% INFO    : Bus 3703	: V=1.052063, theta=-6.604376 -> V=1.0, theta=0.0
% INFO    : Bus 3704	: V=1.018219, theta=-4.488219 -> V=1.0, theta=0.0
% INFO    : Bus 3705	: V=0.999493, theta=-22.903814 -> V=1.0, theta=0.0
% INFO    : Bus 3706	: V=0.981241, theta=-4.030762 -> V=1.0, theta=0.0
% INFO    : Bus 3707	: V=0.980046, theta=-3.760338 -> V=1.0, theta=0.0
% INFO    : Bus 3708	: V=0.927075, theta=-12.034628 -> V=1.0, theta=0.0
% INFO    : Bus 3709	: V=0.966332, theta=-8.051077 -> V=1.0, theta=0.0
% INFO    : Bus 3710	: V=1.023144, theta=-9.538309 -> V=1.0, theta=0.0
% INFO    : Bus 3711	: V=1.028269, theta=-1.177972 -> V=1.0, theta=0.0
% INFO    : Bus 3712	: V=1.027328, theta=-11.116661 -> V=1.0, theta=0.0
% INFO    : Bus 3713	: V=1.001857, theta=35.141479 -> V=1.0, theta=0.0
% INFO    : Bus 3714	: V=1.027328, theta=-11.116661 -> V=1.0, theta=0.0
% INFO    : Bus 3715	: V=1.074416, theta=-1.545428 -> V=1.0, theta=0.0
% INFO    : Bus 3716	: V=1.066366, theta=1.241813 -> V=1.0, theta=0.0
% INFO    : Bus 3717	: V=1.020566, theta=-15.965907 -> V=1.0, theta=0.0
% INFO    : Bus 3718	: V=1.020566, theta=-15.965907 -> V=1.0, theta=0.0
% INFO    : Bus 3719	: V=1.02378, theta=-11.347601 -> V=1.0, theta=0.0
% INFO    : Bus 3720	: V=1.020566, theta=-15.965907 -> V=1.0, theta=0.0
% INFO    : Bus 3721	: V=1.002241, theta=13.029504 -> V=1.0, theta=0.0
% INFO    : Bus 3722	: V=1.017794, theta=22.007307 -> V=1.0, theta=0.0
% INFO    : Bus 3723	: V=1.023167, theta=30.670615 -> V=1.0, theta=0.0
% INFO    : Bus 3724	: V=1.052406, theta=15.378216 -> V=1.0, theta=0.0
% INFO    : Bus 3725	: V=1.027461, theta=15.874106 -> V=1.0, theta=0.0
% INFO    : Bus 3726	: V=0.974623, theta=0.373543 -> V=1.0, theta=0.0
% INFO    : Bus 3727	: V=0.971118, theta=-5.043555 -> V=1.0, theta=0.0
% INFO    : Bus 3728	: V=1.041161, theta=15.301508 -> V=1.0, theta=0.0
% INFO    : Bus 3729	: V=1.041161, theta=15.301508 -> V=1.0, theta=0.0
% INFO    : Bus 3730	: V=0.994136, theta=2.381519 -> V=1.0, theta=0.0
% INFO    : Bus 3731	: V=1.025789, theta=37.325871 -> V=1.0, theta=0.0
% INFO    : Bus 3732	: V=1.056986, theta=40.11833 -> V=1.0, theta=0.0
% INFO    : Bus 3733	: V=1.043418, theta=-6.197364 -> V=1.0, theta=0.0
% INFO    : Bus 3734	: V=1.012816, theta=18.331432 -> V=1.0, theta=0.0
% INFO    : Bus 3735	: V=1.023095, theta=14.051895 -> V=1.0, theta=0.0
% INFO    : Bus 3736	: V=0.991819, theta=41.572318 -> V=1.0, theta=0.0
% INFO    : Bus 3737	: V=1.01362, theta=13.891163 -> V=1.0, theta=0.0
% INFO    : Bus 3738	: V=1.024613, theta=34.717073 -> V=1.0, theta=0.0
% INFO    : Bus 3739	: V=0.988327, theta=-11.84474 -> V=1.0, theta=0.0
% INFO    : Bus 3740	: V=1.048922, theta=-4.155024 -> V=1.0, theta=0.0
% INFO    : Bus 3741	: V=0.998862, theta=-13.022323 -> V=1.0, theta=0.0
% INFO    : Bus 3742	: V=1.016197, theta=16.501286 -> V=1.0, theta=0.0
% INFO    : Bus 3743	: V=1.074827, theta=17.162744 -> V=1.0, theta=0.0
% INFO    : Bus 3744	: V=1.031927, theta=36.078435 -> V=1.0, theta=0.0
% INFO    : Bus 3745	: V=1.0605, theta=6.755748 -> V=1.0, theta=0.0
% INFO    : Bus 3746	: V=0.994397, theta=45.599039 -> V=1.0, theta=0.0
% INFO    : Bus 3747	: V=0.9722, theta=-5.625129 -> V=1.0, theta=0.0
% INFO    : Bus 3748	: V=1.031194, theta=34.071272 -> V=1.0, theta=0.0
% INFO    : Bus 3749	: V=1.080084, theta=-12.975193 -> V=1.0, theta=0.0
% INFO    : Bus 3750	: V=0.991611, theta=-11.55884 -> V=1.0, theta=0.0
% INFO    : Bus 3751	: V=1.010898, theta=21.592721 -> V=1.0, theta=0.0
% INFO    : Bus 3752	: V=1.012062, theta=-17.461214 -> V=1.0, theta=0.0
% INFO    : Bus 3753	: V=1.048282, theta=32.763091 -> V=1.0, theta=0.0
% INFO    : Bus 3754	: V=1.04459, theta=35.949142 -> V=1.0, theta=0.0
% INFO    : Bus 3755	: V=1.056035, theta=-6.130078 -> V=1.0, theta=0.0
% INFO    : Bus 3756	: V=0.99107, theta=11.907024 -> V=1.0, theta=0.0
% INFO    : Bus 3757	: V=1.04459, theta=35.949142 -> V=1.0, theta=0.0
% INFO    : Bus 3758	: V=1.001985, theta=28.995572 -> V=1.0, theta=0.0
% INFO    : Bus 3759	: V=0.996863, theta=-6.046226 -> V=1.0, theta=0.0
% INFO    : Bus 3760	: V=1.035602, theta=1.219734 -> V=1.0, theta=0.0
% INFO    : Bus 3761	: V=1.018383, theta=-22.418329 -> V=1.0, theta=0.0
% INFO    : Bus 3762	: V=1.002985, theta=17.450922 -> V=1.0, theta=0.0
% INFO    : Bus 3763	: V=1.048358, theta=31.36576 -> V=1.0, theta=0.0
% INFO    : Bus 3764	: V=1.023597, theta=2.686954 -> V=1.0, theta=0.0
% INFO    : Bus 3765	: V=0.991176, theta=37.934917 -> V=1.0, theta=0.0
% INFO    : Bus 3766	: V=1.000539, theta=-8.686801 -> V=1.0, theta=0.0
% INFO    : Bus 3767	: V=0.975165, theta=-3.346759 -> V=1.0, theta=0.0
% INFO    : Bus 3768	: V=1.065932, theta=38.264905 -> V=1.0, theta=0.0
% INFO    : Bus 3769	: V=0.982575, theta=-7.71788 -> V=1.0, theta=0.0
% INFO    : Bus 3770	: V=1.032419, theta=5.391576 -> V=1.0, theta=0.0
% INFO    : Bus 3771	: V=1.002675, theta=8.668171 -> V=1.0, theta=0.0
% INFO    : Bus 3772	: V=1.008525, theta=14.844609 -> V=1.0, theta=0.0
% INFO    : Bus 3773	: V=1.007386, theta=62.981368 -> V=1.0, theta=0.0
% INFO    : Bus 3774	: V=1.048023, theta=-2.69037 -> V=1.0, theta=0.0
% INFO    : Bus 3775	: V=1.008333, theta=17.437603 -> V=1.0, theta=0.0
% INFO    : Bus 3776	: V=0.954138, theta=-8.142046 -> V=1.0, theta=0.0
% INFO    : Bus 3777	: V=1.006789, theta=-9.025473 -> V=1.0, theta=0.0
% INFO    : Bus 3778	: V=0.859522, theta=-15.937191 -> V=1.0, theta=0.0
% INFO    : Bus 3779	: V=0.995427, theta=-25.228844 -> V=1.0, theta=0.0
% INFO    : Bus 3780	: V=0.984021, theta=-14.70471 -> V=1.0, theta=0.0
% INFO    : Bus 3781	: V=1.045647, theta=-10.158279 -> V=1.0, theta=0.0
% INFO    : Bus 3782	: V=1.045647, theta=-10.158279 -> V=1.0, theta=0.0
% INFO    : Bus 3783	: V=1.031984, theta=-4.06316 -> V=1.0, theta=0.0
% INFO    : Bus 3784	: V=0.993915, theta=19.983753 -> V=1.0, theta=0.0
% INFO    : Bus 3785	: V=1.03532, theta=20.235996 -> V=1.0, theta=0.0
% INFO    : Bus 3786	: V=1.056058, theta=-9.799792 -> V=1.0, theta=0.0
% INFO    : Bus 3787	: V=1.045647, theta=-10.158279 -> V=1.0, theta=0.0
% INFO    : Bus 3788	: V=1.031603, theta=19.976423 -> V=1.0, theta=0.0
% INFO    : Bus 3789	: V=1.02417, theta=5.104899 -> V=1.0, theta=0.0
% INFO    : Bus 3790	: V=1.028141, theta=7.209486 -> V=1.0, theta=0.0
% INFO    : Bus 3791	: V=1.05732, theta=15.310719 -> V=1.0, theta=0.0
% INFO    : Bus 3792	: V=1.041629, theta=38.466941 -> V=1.0, theta=0.0
% INFO    : Bus 3793	: V=0.994331, theta=27.571319 -> V=1.0, theta=0.0
% INFO    : Bus 3794	: V=1.025166, theta=38.583294 -> V=1.0, theta=0.0
% INFO    : Bus 3795	: V=1.06046, theta=-9.926529 -> V=1.0, theta=0.0
% INFO    : Bus 3796	: V=1.024926, theta=-4.261057 -> V=1.0, theta=0.0
% INFO    : Bus 3797	: V=0.97953, theta=39.88697 -> V=1.0, theta=0.0
% INFO    : Bus 3798	: V=0.987713, theta=-4.372476 -> V=1.0, theta=0.0
% INFO    : Bus 3799	: V=1.010942, theta=25.120376 -> V=1.0, theta=0.0
% INFO    : Bus 3800	: V=1.034738, theta=85.578957 -> V=1.0, theta=0.0
% INFO    : Bus 3801	: V=1.018264, theta=-24.474933 -> V=1.0, theta=0.0
% INFO    : Bus 3802	: V=1.029199, theta=7.499056 -> V=1.0, theta=0.0
% INFO    : Bus 3803	: V=1.004636, theta=10.522343 -> V=1.0, theta=0.0
% INFO    : Bus 3804	: V=0.987933, theta=33.848491 -> V=1.0, theta=0.0
% INFO    : Bus 3805	: V=1.037622, theta=6.656996 -> V=1.0, theta=0.0
% INFO    : Bus 3806	: V=1.024055, theta=78.99349 -> V=1.0, theta=0.0
% INFO    : Bus 3807	: V=1.017888, theta=-21.976636 -> V=1.0, theta=0.0
% INFO    : Bus 3808	: V=0.973113, theta=20.532216 -> V=1.0, theta=0.0
% INFO    : Bus 3809	: V=1.007265, theta=-3.961623 -> V=1.0, theta=0.0
% INFO    : Bus 3810	: V=1.043637, theta=16.74073 -> V=1.0, theta=0.0
% INFO    : Bus 3811	: V=1.037557, theta=26.827154 -> V=1.0, theta=0.0
% INFO    : Bus 3812	: V=1.037557, theta=26.827154 -> V=1.0, theta=0.0
% INFO    : Bus 3813	: V=0.990954, theta=87.918132 -> V=1.0, theta=0.0
% INFO    : Bus 3814	: V=0.990319, theta=27.296201 -> V=1.0, theta=0.0
% INFO    : Bus 3815	: V=1.038225, theta=16.178789 -> V=1.0, theta=0.0
% INFO    : Bus 3816	: V=1.038225, theta=16.178789 -> V=1.0, theta=0.0
% INFO    : Bus 3817	: V=1.002497, theta=5.433967 -> V=1.0, theta=0.0
% INFO    : Bus 3818	: V=1.052683, theta=-2.999217 -> V=1.0, theta=0.0
% INFO    : Bus 3819	: V=0.987464, theta=34.509556 -> V=1.0, theta=0.0
% INFO    : Bus 3820	: V=1.043637, theta=16.74073 -> V=1.0, theta=0.0
% INFO    : Bus 3821	: V=1.000644, theta=13.734227 -> V=1.0, theta=0.0
% INFO    : Bus 3822	: V=1.014986, theta=-26.081164 -> V=1.0, theta=0.0
% INFO    : Bus 3823	: V=1.046905, theta=39.305577 -> V=1.0, theta=0.0
% INFO    : Bus 3824	: V=0.9933, theta=-21.265596 -> V=1.0, theta=0.0
% INFO    : Bus 3825	: V=0.998239, theta=-16.359764 -> V=1.0, theta=0.0
% INFO    : Bus 3826	: V=0.998667, theta=-8.872941 -> V=1.0, theta=0.0
% INFO    : Bus 3827	: V=0.953224, theta=-17.045665 -> V=1.0, theta=0.0
% INFO    : Bus 3828	: V=0.959197, theta=-14.465123 -> V=1.0, theta=0.0
% INFO    : Bus 3829	: V=0.966718, theta=-9.612211 -> V=1.0, theta=0.0
% INFO    : Bus 3830	: V=1.015509, theta=-13.056484 -> V=1.0, theta=0.0
% INFO    : Bus 3831	: V=1.052987, theta=3.642006 -> V=1.0, theta=0.0
% INFO    : Bus 3832	: V=1.028263, theta=14.542009 -> V=1.0, theta=0.0
% INFO    : Bus 3833	: V=1.008916, theta=-9.196952 -> V=1.0, theta=0.0
% INFO    : Bus 3834	: V=1.001521, theta=1.510049 -> V=1.0, theta=0.0
% INFO    : Bus 3835	: V=1.057805, theta=-3.449537 -> V=1.0, theta=0.0
% INFO    : Bus 3836	: V=1.020046, theta=-0.776938 -> V=1.0, theta=0.0
% INFO    : Bus 3837	: V=1.023558, theta=-4.113173 -> V=1.0, theta=0.0
% INFO    : Bus 3838	: V=1.004212, theta=-7.923304 -> V=1.0, theta=0.0
% INFO    : Bus 3839	: V=1.081422, theta=65.714745 -> V=1.0, theta=0.0
% INFO    : Bus 3840	: V=0.996192, theta=-6.458913 -> V=1.0, theta=0.0
% INFO    : Bus 3841	: V=0.971137, theta=21.534292 -> V=1.0, theta=0.0
% INFO    : Bus 3842	: V=0.991765, theta=36.62363 -> V=1.0, theta=0.0
% INFO    : Bus 3843	: V=1.002541, theta=-8.381312 -> V=1.0, theta=0.0
% INFO    : Bus 3844	: V=1.011328, theta=-24.089806 -> V=1.0, theta=0.0
% INFO    : Bus 3845	: V=1.021005, theta=21.987746 -> V=1.0, theta=0.0
% INFO    : Bus 3846	: V=1.025029, theta=-15.361499 -> V=1.0, theta=0.0
% INFO    : Bus 3847	: V=0.973572, theta=-6.558893 -> V=1.0, theta=0.0
% INFO    : Bus 3848	: V=0.943602, theta=40.868468 -> V=1.0, theta=0.0
% INFO    : Bus 3849	: V=0.923452, theta=-12.26721 -> V=1.0, theta=0.0
% INFO    : Bus 3850	: V=1.044453, theta=29.691902 -> V=1.0, theta=0.0
% INFO    : Bus 3851	: V=1.036804, theta=-4.012085 -> V=1.0, theta=0.0
% INFO    : Bus 3852	: V=0.997494, theta=-4.67416 -> V=1.0, theta=0.0
% INFO    : Bus 3853	: V=0.999522, theta=92.907532 -> V=1.0, theta=0.0
% INFO    : Bus 3854	: V=1.015954, theta=3.75914 -> V=1.0, theta=0.0
% INFO    : Bus 3855	: V=1.024245, theta=2.286767 -> V=1.0, theta=0.0
% INFO    : Bus 3856	: V=1.007272, theta=-15.666097 -> V=1.0, theta=0.0
% INFO    : Bus 3857	: V=1.015006, theta=-6.446837 -> V=1.0, theta=0.0
% INFO    : Bus 3858	: V=1.055068, theta=-6.456273 -> V=1.0, theta=0.0
% INFO    : Bus 3859	: V=1.001697, theta=-10.005429 -> V=1.0, theta=0.0
% INFO    : Bus 3860	: V=1.020631, theta=58.183176 -> V=1.0, theta=0.0
% INFO    : Bus 3861	: V=1.011146, theta=4.249813 -> V=1.0, theta=0.0
% INFO    : Bus 3862	: V=1.018959, theta=-11.528438 -> V=1.0, theta=0.0
% INFO    : Bus 3863	: V=1.002114, theta=-15.311194 -> V=1.0, theta=0.0
% INFO    : Bus 3864	: V=1.04125, theta=-15.47147 -> V=1.0, theta=0.0
% INFO    : Bus 3865	: V=1.03117, theta=4.253385 -> V=1.0, theta=0.0
% INFO    : Bus 3866	: V=1.032762, theta=-8.550207 -> V=1.0, theta=0.0
% INFO    : Bus 3867	: V=1.032762, theta=-8.550207 -> V=1.0, theta=0.0
% INFO    : Bus 3868	: V=1.021788, theta=34.479059 -> V=1.0, theta=0.0
% INFO    : Bus 3869	: V=1.025944, theta=-5.850714 -> V=1.0, theta=0.0
% INFO    : Bus 3870	: V=1.005382, theta=32.91492 -> V=1.0, theta=0.0
% INFO    : Bus 3871	: V=1.001258, theta=3.503927 -> V=1.0, theta=0.0
% INFO    : Bus 3872	: V=0.972026, theta=38.478023 -> V=1.0, theta=0.0
% INFO    : Bus 3873	: V=0.955741, theta=-10.11486 -> V=1.0, theta=0.0
% INFO    : Bus 3874	: V=1.020898, theta=26.410473 -> V=1.0, theta=0.0
% INFO    : Bus 3875	: V=1.004746, theta=-16.601417 -> V=1.0, theta=0.0
% INFO    : Bus 3876	: V=1.015194, theta=-3.247167 -> V=1.0, theta=0.0
% INFO    : Bus 3877	: V=1.015185, theta=-4.986575 -> V=1.0, theta=0.0
% INFO    : Bus 3878	: V=1.027132, theta=31.963051 -> V=1.0, theta=0.0
% INFO    : Bus 3879	: V=1.039223, theta=17.370871 -> V=1.0, theta=0.0
% INFO    : Bus 3880	: V=1.007227, theta=24.551226 -> V=1.0, theta=0.0
% INFO    : Bus 3881	: V=1.004302, theta=30.940698 -> V=1.0, theta=0.0
% INFO    : Bus 3882	: V=1.022362, theta=13.99707 -> V=1.0, theta=0.0
% INFO    : Bus 3883	: V=1.033444, theta=-6.578835 -> V=1.0, theta=0.0
% INFO    : Bus 3884	: V=1.025704, theta=9.945964 -> V=1.0, theta=0.0
% INFO    : Bus 3885	: V=1.031155, theta=-14.651392 -> V=1.0, theta=0.0
% INFO    : Bus 3886	: V=1.023287, theta=-16.294788 -> V=1.0, theta=0.0
% INFO    : Bus 3887	: V=1.04812, theta=-1.694954 -> V=1.0, theta=0.0
% INFO    : Bus 3888	: V=1.007881, theta=34.678063 -> V=1.0, theta=0.0
% INFO    : Bus 3889	: V=1.010373, theta=12.216216 -> V=1.0, theta=0.0
% INFO    : Bus 3890	: V=1.021497, theta=43.08635 -> V=1.0, theta=0.0
% INFO    : Bus 3891	: V=0.924209, theta=5.916211 -> V=1.0, theta=0.0
% INFO    : Bus 3892	: V=1.023447, theta=33.261963 -> V=1.0, theta=0.0
% INFO    : Bus 3893	: V=1.025595, theta=-10.129182 -> V=1.0, theta=0.0
% INFO    : Bus 3894	: V=1.030843, theta=4.085708 -> V=1.0, theta=0.0
% INFO    : Bus 3895	: V=1.02364, theta=36.454073 -> V=1.0, theta=0.0
% INFO    : Bus 3896	: V=1.022852, theta=-10.893 -> V=1.0, theta=0.0
% INFO    : Bus 3897	: V=1.021979, theta=42.562188 -> V=1.0, theta=0.0
% INFO    : Bus 3898	: V=1.031562, theta=0.150715 -> V=1.0, theta=0.0
% INFO    : Bus 3899	: V=1.029166, theta=13.522836 -> V=1.0, theta=0.0
% INFO    : Bus 3900	: V=1.071255, theta=58.769096 -> V=1.0, theta=0.0
% INFO    : Bus 3901	: V=1.025753, theta=-6.323962 -> V=1.0, theta=0.0
% INFO    : Bus 3902	: V=1.025331, theta=0.441862 -> V=1.0, theta=0.0
% INFO    : Bus 3903	: V=0.988537, theta=92.030569 -> V=1.0, theta=0.0
% INFO    : Bus 3904	: V=1.054388, theta=47.373035 -> V=1.0, theta=0.0
% INFO    : Bus 3905	: V=1.013951, theta=-16.487085 -> V=1.0, theta=0.0
% INFO    : Bus 3906	: V=1.019357, theta=22.943488 -> V=1.0, theta=0.0
% INFO    : Bus 3907	: V=1.019357, theta=22.943488 -> V=1.0, theta=0.0
% INFO    : Bus 3908	: V=1.019357, theta=22.943488 -> V=1.0, theta=0.0
% INFO    : Bus 3909	: V=1.019357, theta=22.943488 -> V=1.0, theta=0.0
% INFO    : Bus 3910	: V=1.019357, theta=22.943488 -> V=1.0, theta=0.0
% INFO    : Bus 3911	: V=1.019357, theta=22.943488 -> V=1.0, theta=0.0
% INFO    : Bus 3912	: V=1.034597, theta=19.022639 -> V=1.0, theta=0.0
% INFO    : Bus 3913	: V=1.008149, theta=95.140553 -> V=1.0, theta=0.0
% INFO    : Bus 3914	: V=1.054388, theta=47.373035 -> V=1.0, theta=0.0
% INFO    : Bus 3915	: V=1.042317, theta=14.274354 -> V=1.0, theta=0.0
% INFO    : Bus 3916	: V=1.028994, theta=35.401004 -> V=1.0, theta=0.0
% INFO    : Bus 3917	: V=1.014686, theta=19.975313 -> V=1.0, theta=0.0
% INFO    : Bus 3918	: V=0.976747, theta=2.601981 -> V=1.0, theta=0.0
% INFO    : Bus 3919	: V=0.977157, theta=-20.730202 -> V=1.0, theta=0.0
% INFO    : Bus 3920	: V=1.019428, theta=17.336764 -> V=1.0, theta=0.0
% INFO    : Bus 3921	: V=1.039625, theta=75.551848 -> V=1.0, theta=0.0
% INFO    : Bus 3922	: V=1.064335, theta=2.396339 -> V=1.0, theta=0.0
% INFO    : Bus 3923	: V=1.105017, theta=-0.734092 -> V=1.0, theta=0.0
% INFO    : Bus 3924	: V=0.995921, theta=-9.125342 -> V=1.0, theta=0.0
% INFO    : Bus 3925	: V=0.967568, theta=-8.292964 -> V=1.0, theta=0.0
% INFO    : Bus 3926	: V=0.984593, theta=34.337885 -> V=1.0, theta=0.0
% INFO    : Bus 3927	: V=0.975764, theta=-8.269344 -> V=1.0, theta=0.0
% INFO    : Bus 3928	: V=1.013428, theta=-26.985431 -> V=1.0, theta=0.0
% INFO    : Bus 3929	: V=0.995077, theta=34.268512 -> V=1.0, theta=0.0
% INFO    : Bus 3930	: V=1.017816, theta=14.353588 -> V=1.0, theta=0.0
% INFO    : Bus 3931	: V=1.057526, theta=-6.024854 -> V=1.0, theta=0.0
% INFO    : Bus 3932	: V=1.040088, theta=77.795929 -> V=1.0, theta=0.0
% INFO    : Bus 3933	: V=1.01076, theta=-0.654704 -> V=1.0, theta=0.0
% INFO    : Bus 3934	: V=0.997643, theta=-5.902274 -> V=1.0, theta=0.0
% INFO    : Bus 3935	: V=1.029049, theta=23.334025 -> V=1.0, theta=0.0
% INFO    : Bus 3936	: V=1.013604, theta=14.122748 -> V=1.0, theta=0.0
% INFO    : Bus 3937	: V=1.015977, theta=-2.619697 -> V=1.0, theta=0.0
% INFO    : Bus 3938	: V=1.025102, theta=22.870461 -> V=1.0, theta=0.0
% INFO    : Bus 3939	: V=0.980209, theta=32.361809 -> V=1.0, theta=0.0
% INFO    : Bus 3940	: V=0.989944, theta=-2.693359 -> V=1.0, theta=0.0
% INFO    : Bus 3941	: V=1.046885, theta=2.545883 -> V=1.0, theta=0.0
% INFO    : Bus 3942	: V=1.031813, theta=8.024995 -> V=1.0, theta=0.0
% INFO    : Bus 3943	: V=1.046877, theta=41.968115 -> V=1.0, theta=0.0
% INFO    : Bus 3944	: V=0.983686, theta=-5.932747 -> V=1.0, theta=0.0
% INFO    : Bus 3945	: V=0.940212, theta=-11.535774 -> V=1.0, theta=0.0
% INFO    : Bus 3946	: V=1.039621, theta=15.763593 -> V=1.0, theta=0.0
% INFO    : Bus 3947	: V=1.058835, theta=5.385711 -> V=1.0, theta=0.0
% INFO    : Bus 3948	: V=0.9646, theta=54.13357 -> V=1.0, theta=0.0
% INFO    : Bus 3949	: V=1.016389, theta=18.498708 -> V=1.0, theta=0.0
% INFO    : Bus 3950	: V=0.994916, theta=-0.136436 -> V=1.0, theta=0.0
% INFO    : Bus 3951	: V=1.032756, theta=21.238112 -> V=1.0, theta=0.0
% INFO    : Bus 3952	: V=1.039539, theta=40.11205 -> V=1.0, theta=0.0
% INFO    : Bus 3953	: V=1.051684, theta=27.644505 -> V=1.0, theta=0.0
% INFO    : Bus 3954	: V=1.027371, theta=31.740459 -> V=1.0, theta=0.0
% INFO    : Bus 3955	: V=1.002954, theta=-7.59108 -> V=1.0, theta=0.0
% INFO    : Bus 3956	: V=0.993705, theta=27.251449 -> V=1.0, theta=0.0
% INFO    : Bus 3957	: V=1.014973, theta=-3.123764 -> V=1.0, theta=0.0
% INFO    : Bus 3958	: V=1.020294, theta=-21.912903 -> V=1.0, theta=0.0
% INFO    : Bus 3959	: V=0.973285, theta=31.740546 -> V=1.0, theta=0.0
% INFO    : Bus 3960	: V=1.005221, theta=50.42174 -> V=1.0, theta=0.0
% INFO    : Bus 3961	: V=1.019851, theta=10.317448 -> V=1.0, theta=0.0
% INFO    : Bus 3962	: V=1.127961, theta=6.657565 -> V=1.0, theta=0.0
% INFO    : Bus 3963	: V=0.983047, theta=-6.236385 -> V=1.0, theta=0.0
% INFO    : Bus 3964	: V=0.992968, theta=17.488668 -> V=1.0, theta=0.0
% INFO    : Bus 3965	: V=1.048896, theta=58.644273 -> V=1.0, theta=0.0
% INFO    : Bus 3966	: V=1.037509, theta=21.307632 -> V=1.0, theta=0.0
% INFO    : Bus 3967	: V=1.045866, theta=32.653982 -> V=1.0, theta=0.0
% INFO    : Bus 3968	: V=0.988831, theta=38.418014 -> V=1.0, theta=0.0
% INFO    : Bus 3969	: V=1.050617, theta=-2.825003 -> V=1.0, theta=0.0
% INFO    : Bus 3970	: V=0.96994, theta=7.065764 -> V=1.0, theta=0.0
% INFO    : Bus 3971	: V=1.019231, theta=22.327173 -> V=1.0, theta=0.0
% INFO    : Bus 3972	: V=0.996945, theta=-3.705224 -> V=1.0, theta=0.0
% INFO    : Bus 3973	: V=0.992697, theta=22.713113 -> V=1.0, theta=0.0
% INFO    : Bus 3974	: V=1.021843, theta=-3.697729 -> V=1.0, theta=0.0
% INFO    : Bus 3975	: V=1.045434, theta=6.466231 -> V=1.0, theta=0.0
% INFO    : Bus 3976	: V=1.008172, theta=-8.50998 -> V=1.0, theta=0.0
% INFO    : Bus 3977	: V=0.940462, theta=-11.519394 -> V=1.0, theta=0.0
% INFO    : Bus 3978	: V=0.971768, theta=-4.92158 -> V=1.0, theta=0.0
% INFO    : Bus 3979	: V=0.997595, theta=-6.3622 -> V=1.0, theta=0.0
% INFO    : Bus 3980	: V=1.058636, theta=17.902405 -> V=1.0, theta=0.0
% INFO    : Bus 3981	: V=1.032156, theta=4.284671 -> V=1.0, theta=0.0
% INFO    : Bus 3982	: V=1.002071, theta=34.234835 -> V=1.0, theta=0.0
% INFO    : Bus 3983	: V=1.026894, theta=-22.417254 -> V=1.0, theta=0.0
% INFO    : Bus 3984	: V=1.028414, theta=-6.287287 -> V=1.0, theta=0.0
% INFO    : Bus 3985	: V=0.993185, theta=32.487862 -> V=1.0, theta=0.0
% INFO    : Bus 3986	: V=0.999796, theta=46.140349 -> V=1.0, theta=0.0
% INFO    : Bus 3987	: V=1.0014, theta=-12.664749 -> V=1.0, theta=0.0
% INFO    : Bus 3988	: V=1.081845, theta=64.335223 -> V=1.0, theta=0.0
% INFO    : Bus 3989	: V=0.976827, theta=-2.952988 -> V=1.0, theta=0.0
% INFO    : Bus 3990	: V=1.014542, theta=2.91424 -> V=1.0, theta=0.0
% INFO    : Bus 3991	: V=0.978995, theta=-5.776233 -> V=1.0, theta=0.0
% INFO    : Bus 3992	: V=0.983142, theta=-2.827838 -> V=1.0, theta=0.0
% INFO    : Bus 3993	: V=1.009288, theta=12.462553 -> V=1.0, theta=0.0
% INFO    : Bus 3994	: V=1.032143, theta=11.548575 -> V=1.0, theta=0.0
% INFO    : Bus 3995	: V=1.044996, theta=-3.065495 -> V=1.0, theta=0.0
% INFO    : Bus 3996	: V=1.021209, theta=34.440022 -> V=1.0, theta=0.0
% INFO    : Bus 3997	: V=1.033735, theta=-14.68008 -> V=1.0, theta=0.0
% INFO    : Bus 3998	: V=1.027268, theta=24.902116 -> V=1.0, theta=0.0
% INFO    : Bus 3999	: V=0.991303, theta=-5.167444 -> V=1.0, theta=0.0
% INFO    : Bus 4000	: V=1.038747, theta=-8.642337 -> V=1.0, theta=0.0
% INFO    : Bus 4001	: V=0.982862, theta=-1.448349 -> V=1.0, theta=0.0
% INFO    : Bus 4002	: V=1.04374, theta=17.148861 -> V=1.0, theta=0.0
% INFO    : Bus 4003	: V=1.016745, theta=-21.316913 -> V=1.0, theta=0.0
% INFO    : Bus 4004	: V=1.043665, theta=14.930439 -> V=1.0, theta=0.0
% INFO    : Bus 4005	: V=1.027589, theta=5.680135 -> V=1.0, theta=0.0
% INFO    : Bus 4006	: V=0.966005, theta=-6.185631 -> V=1.0, theta=0.0
% INFO    : Bus 4007	: V=0.99605, theta=-7.338816 -> V=1.0, theta=0.0
% INFO    : Bus 4008	: V=1.022605, theta=43.459728 -> V=1.0, theta=0.0
% INFO    : Bus 4009	: V=1.016106, theta=0.556804 -> V=1.0, theta=0.0
% INFO    : Bus 4010	: V=1.025555, theta=-13.384562 -> V=1.0, theta=0.0
% INFO    : Bus 4011	: V=1.045295, theta=35.245517 -> V=1.0, theta=0.0
% INFO    : Bus 4012	: V=1.034685, theta=29.873888 -> V=1.0, theta=0.0
% INFO    : Bus 4013	: V=1.024096, theta=61.613978 -> V=1.0, theta=0.0
% INFO    : Bus 4014	: V=1.048336, theta=10.601474 -> V=1.0, theta=0.0
% INFO    : Bus 4015	: V=1.00785, theta=17.28578 -> V=1.0, theta=0.0
% INFO    : Bus 4016	: V=0.94325, theta=-17.454758 -> V=1.0, theta=0.0
% INFO    : Bus 4017	: V=1.02334, theta=36.751236 -> V=1.0, theta=0.0
% INFO    : Bus 4018	: V=0.987618, theta=-10.736749 -> V=1.0, theta=0.0
% INFO    : Bus 4019	: V=1.017989, theta=42.299548 -> V=1.0, theta=0.0
% INFO    : Bus 4020	: V=1.035469, theta=23.613483 -> V=1.0, theta=0.0
% INFO    : Bus 4021	: V=1.035469, theta=23.613483 -> V=1.0, theta=0.0
% INFO    : Bus 4022	: V=1.048029, theta=9.440891 -> V=1.0, theta=0.0
% INFO    : Bus 4023	: V=1.021457, theta=0.097153 -> V=1.0, theta=0.0
% INFO    : Bus 4024	: V=1.049669, theta=23.260983 -> V=1.0, theta=0.0
% INFO    : Bus 4025	: V=1.049669, theta=23.260983 -> V=1.0, theta=0.0
% INFO    : Bus 4026	: V=1.045658, theta=29.191718 -> V=1.0, theta=0.0
% INFO    : Bus 4027	: V=1.045658, theta=29.191718 -> V=1.0, theta=0.0
% INFO    : Bus 4028	: V=1.047384, theta=5.160988 -> V=1.0, theta=0.0
% INFO    : Bus 4029	: V=1.047384, theta=5.160988 -> V=1.0, theta=0.0
% INFO    : Bus 4030	: V=1.044254, theta=35.795297 -> V=1.0, theta=0.0
% INFO    : Bus 4031	: V=1.053588, theta=30.508882 -> V=1.0, theta=0.0
% INFO    : Bus 4032	: V=0.995355, theta=0.982197 -> V=1.0, theta=0.0
% INFO    : Bus 4033	: V=0.976468, theta=-19.018776 -> V=1.0, theta=0.0
% INFO    : Bus 4034	: V=1.019562, theta=6.13255 -> V=1.0, theta=0.0
% INFO    : Bus 4035	: V=1.01212, theta=-14.62095 -> V=1.0, theta=0.0
% INFO    : Bus 4036	: V=0.994207, theta=-7.173177 -> V=1.0, theta=0.0
% INFO    : Bus 4037	: V=0.978444, theta=-23.811182 -> V=1.0, theta=0.0
% INFO    : Bus 4038	: V=1.017934, theta=-20.325334 -> V=1.0, theta=0.0
% INFO    : Bus 4039	: V=1.040404, theta=13.619935 -> V=1.0, theta=0.0
% INFO    : Bus 4040	: V=1.040404, theta=13.619935 -> V=1.0, theta=0.0
% INFO    : Bus 4041	: V=1.066829, theta=5.050047 -> V=1.0, theta=0.0
% INFO    : Bus 4042	: V=1.040404, theta=13.619935 -> V=1.0, theta=0.0
% INFO    : Bus 4043	: V=1.048055, theta=45.108406 -> V=1.0, theta=0.0
% INFO    : Bus 4044	: V=1.048055, theta=45.108406 -> V=1.0, theta=0.0
% INFO    : Bus 4045	: V=1.022502, theta=19.424113 -> V=1.0, theta=0.0
% INFO    : Bus 4046	: V=1.037914, theta=-10.199077 -> V=1.0, theta=0.0
% INFO    : Bus 4047	: V=1.048211, theta=53.23324 -> V=1.0, theta=0.0
% INFO    : Bus 4048	: V=1.049221, theta=26.031718 -> V=1.0, theta=0.0
% INFO    : Bus 4049	: V=1.041409, theta=32.91812 -> V=1.0, theta=0.0
% INFO    : Bus 4050	: V=0.980747, theta=40.789038 -> V=1.0, theta=0.0
% INFO    : Bus 4051	: V=1.02423, theta=25.85169 -> V=1.0, theta=0.0
% INFO    : Bus 4052	: V=1.001216, theta=-0.162465 -> V=1.0, theta=0.0
% INFO    : Bus 4053	: V=1.035102, theta=5.926523 -> V=1.0, theta=0.0
% INFO    : Bus 4054	: V=1.035102, theta=5.926523 -> V=1.0, theta=0.0
% INFO    : Bus 4055	: V=1.029081, theta=8.308248 -> V=1.0, theta=0.0
% INFO    : Bus 4056	: V=1.035102, theta=5.926523 -> V=1.0, theta=0.0
% INFO    : Bus 4057	: V=1.028397, theta=-15.822938 -> V=1.0, theta=0.0
% INFO    : Bus 4058	: V=1.028397, theta=-15.822938 -> V=1.0, theta=0.0
% INFO    : Bus 4059	: V=1.028397, theta=-15.822938 -> V=1.0, theta=0.0
% INFO    : Bus 4060	: V=1.028397, theta=-15.822938 -> V=1.0, theta=0.0
% INFO    : Bus 4061	: V=1.028397, theta=-15.822938 -> V=1.0, theta=0.0
% INFO    : Bus 4062	: V=1.028397, theta=-15.822938 -> V=1.0, theta=0.0
% INFO    : Bus 4063	: V=1.035771, theta=2.999441 -> V=1.0, theta=0.0
% INFO    : Bus 4064	: V=0.95793, theta=-5.946482 -> V=1.0, theta=0.0
% INFO    : Bus 4065	: V=1.059908, theta=0.316663 -> V=1.0, theta=0.0
% INFO    : Bus 4066	: V=1.013219, theta=-5.540854 -> V=1.0, theta=0.0
% INFO    : Bus 4067	: V=1.013219, theta=-5.540854 -> V=1.0, theta=0.0
% INFO    : Bus 4068	: V=1.013219, theta=-5.540854 -> V=1.0, theta=0.0
% INFO    : Bus 4069	: V=1.013219, theta=-5.540854 -> V=1.0, theta=0.0
% INFO    : Bus 4070	: V=0.974324, theta=5.178453 -> V=1.0, theta=0.0
% INFO    : Bus 4071	: V=1.038223, theta=21.742293 -> V=1.0, theta=0.0
% INFO    : Bus 4072	: V=0.992435, theta=89.610855 -> V=1.0, theta=0.0
% INFO    : Bus 4073	: V=0.978133, theta=-14.543133 -> V=1.0, theta=0.0
% INFO    : Bus 4074	: V=1.027264, theta=14.46311 -> V=1.0, theta=0.0
% INFO    : Bus 4075	: V=1.017898, theta=93.587736 -> V=1.0, theta=0.0
% INFO    : Bus 4076	: V=1.082295, theta=2.293173 -> V=1.0, theta=0.0
% INFO    : Bus 4077	: V=1.080027, theta=3.379229 -> V=1.0, theta=0.0
% INFO    : Bus 4078	: V=1.02787, theta=23.027691 -> V=1.0, theta=0.0
% INFO    : Bus 4079	: V=0.979844, theta=-8.592076 -> V=1.0, theta=0.0
% INFO    : Bus 4080	: V=1.008626, theta=-19.001337 -> V=1.0, theta=0.0
% INFO    : Bus 4081	: V=0.985866, theta=-4.420012 -> V=1.0, theta=0.0
% INFO    : Bus 4082	: V=0.934743, theta=6.163013 -> V=1.0, theta=0.0
% INFO    : Bus 4083	: V=1.023361, theta=29.828652 -> V=1.0, theta=0.0
% INFO    : Bus 4084	: V=1.023418, theta=29.920304 -> V=1.0, theta=0.0
% INFO    : Bus 4085	: V=1.009821, theta=29.021748 -> V=1.0, theta=0.0
% INFO    : Bus 4086	: V=1.054801, theta=25.441411 -> V=1.0, theta=0.0
% INFO    : Bus 4087	: V=1.023418, theta=29.920304 -> V=1.0, theta=0.0
% INFO    : Bus 4088	: V=0.992612, theta=23.761381 -> V=1.0, theta=0.0
% INFO    : Bus 4089	: V=1.009928, theta=-15.578396 -> V=1.0, theta=0.0
% INFO    : Bus 4090	: V=1.028835, theta=11.150593 -> V=1.0, theta=0.0
% INFO    : Bus 4091	: V=1.020153, theta=-7.766804 -> V=1.0, theta=0.0
% INFO    : Bus 4092	: V=1.068646, theta=82.428858 -> V=1.0, theta=0.0
% INFO    : Bus 4093	: V=0.991175, theta=-8.351367 -> V=1.0, theta=0.0
% INFO    : Bus 4094	: V=1.038965, theta=18.786912 -> V=1.0, theta=0.0
% INFO    : Bus 4095	: V=1.081382, theta=4.111262 -> V=1.0, theta=0.0
% INFO    : Bus 4096	: V=0.975223, theta=-5.552476 -> V=1.0, theta=0.0
% INFO    : Bus 4097	: V=0.979572, theta=1.145757 -> V=1.0, theta=0.0
% INFO    : Bus 4098	: V=1.029964, theta=-7.491249 -> V=1.0, theta=0.0
% INFO    : Bus 4099	: V=1.01787, theta=4.463063 -> V=1.0, theta=0.0
% INFO    : Bus 4100	: V=0.961663, theta=-9.848287 -> V=1.0, theta=0.0
% INFO    : Bus 4101	: V=1.00818, theta=-9.064966 -> V=1.0, theta=0.0
% INFO    : Bus 4102	: V=1.026027, theta=-7.002651 -> V=1.0, theta=0.0
% INFO    : Bus 4103	: V=0.975776, theta=-8.68967 -> V=1.0, theta=0.0
% INFO    : Bus 4104	: V=1.017398, theta=17.982008 -> V=1.0, theta=0.0
% INFO    : Bus 4105	: V=0.992471, theta=17.736413 -> V=1.0, theta=0.0
% INFO    : Bus 4106	: V=0.959874, theta=-6.874073 -> V=1.0, theta=0.0
% INFO    : Bus 4107	: V=1.034789, theta=0.003882 -> V=1.0, theta=0.0
% INFO    : Bus 4108	: V=1.020027, theta=22.344668 -> V=1.0, theta=0.0
% INFO    : Bus 4109	: V=1.027725, theta=4.463602 -> V=1.0, theta=0.0
% INFO    : Bus 4110	: V=1.029048, theta=6.157125 -> V=1.0, theta=0.0
% INFO    : Bus 4111	: V=1.130975, theta=-0.154886 -> V=1.0, theta=0.0
% INFO    : Bus 4112	: V=1.042169, theta=34.593973 -> V=1.0, theta=0.0
% INFO    : Bus 4113	: V=1.008635, theta=-21.730038 -> V=1.0, theta=0.0
% INFO    : Bus 4114	: V=1.028891, theta=18.463948 -> V=1.0, theta=0.0
% INFO    : Bus 4115	: V=1.103517, theta=-15.031183 -> V=1.0, theta=0.0
% INFO    : Bus 4116	: V=0.96498, theta=32.264881 -> V=1.0, theta=0.0
% INFO    : Bus 4117	: V=1.005204, theta=-14.148568 -> V=1.0, theta=0.0
% INFO    : Bus 4118	: V=1.042943, theta=-7.588989 -> V=1.0, theta=0.0
% INFO    : Bus 4119	: V=1.022047, theta=14.401509 -> V=1.0, theta=0.0
% INFO    : Bus 4120	: V=1.04914, theta=42.65185 -> V=1.0, theta=0.0
% INFO    : Bus 4121	: V=1.026554, theta=18.183448 -> V=1.0, theta=0.0
% INFO    : Bus 4122	: V=1.033358, theta=12.070407 -> V=1.0, theta=0.0
% INFO    : Bus 4123	: V=0.988687, theta=-22.211081 -> V=1.0, theta=0.0
% INFO    : Bus 4124	: V=1.012789, theta=31.444759 -> V=1.0, theta=0.0
% INFO    : Bus 4125	: V=0.992828, theta=-5.901404 -> V=1.0, theta=0.0
% INFO    : Bus 4126	: V=1.013384, theta=-6.332412 -> V=1.0, theta=0.0
% INFO    : Bus 4127	: V=1.032447, theta=15.783395 -> V=1.0, theta=0.0
% INFO    : Bus 4128	: V=1.001526, theta=-10.113049 -> V=1.0, theta=0.0
% INFO    : Bus 4129	: V=1.071869, theta=-2.308956 -> V=1.0, theta=0.0
% INFO    : Bus 4130	: V=0.992143, theta=-13.076815 -> V=1.0, theta=0.0
% INFO    : Bus 4131	: V=0.997814, theta=-14.774542 -> V=1.0, theta=0.0
% INFO    : Bus 4132	: V=1.011581, theta=3.186067 -> V=1.0, theta=0.0
% INFO    : Bus 4133	: V=1.03058, theta=15.553508 -> V=1.0, theta=0.0
% INFO    : Bus 4134	: V=1.0376, theta=28.404116 -> V=1.0, theta=0.0
% INFO    : Bus 4135	: V=1.036966, theta=15.051213 -> V=1.0, theta=0.0
% INFO    : Bus 4136	: V=1.060489, theta=63.22043 -> V=1.0, theta=0.0
% INFO    : Bus 4137	: V=1.025746, theta=97.376396 -> V=1.0, theta=0.0
% INFO    : Bus 4138	: V=1.025746, theta=97.376396 -> V=1.0, theta=0.0
% INFO    : Bus 4139	: V=1.025746, theta=97.376396 -> V=1.0, theta=0.0
% INFO    : Bus 4140	: V=1.025803, theta=97.507727 -> V=1.0, theta=0.0
% INFO    : Bus 4141	: V=1.025803, theta=97.507727 -> V=1.0, theta=0.0
% INFO    : Bus 4142	: V=0.971681, theta=-8.335279 -> V=1.0, theta=0.0
% INFO    : Bus 4143	: V=1.025803, theta=97.507727 -> V=1.0, theta=0.0
% INFO    : Bus 4144	: V=1.027882, theta=90.395237 -> V=1.0, theta=0.0
% INFO    : Bus 4145	: V=1.057682, theta=40.579523 -> V=1.0, theta=0.0
% INFO    : Bus 4146	: V=0.994482, theta=-11.263795 -> V=1.0, theta=0.0
% INFO    : Bus 4147	: V=1.062128, theta=13.395699 -> V=1.0, theta=0.0
% INFO    : Bus 4148	: V=1.029293, theta=-6.89657 -> V=1.0, theta=0.0
% INFO    : Bus 4149	: V=0.999603, theta=-16.851733 -> V=1.0, theta=0.0
% INFO    : Bus 4150	: V=1.056565, theta=2.913111 -> V=1.0, theta=0.0
% INFO    : Bus 4151	: V=1.008035, theta=95.91491 -> V=1.0, theta=0.0
% INFO    : Bus 4152	: V=1.015318, theta=96.999592 -> V=1.0, theta=0.0
% INFO    : Bus 4153	: V=1.030882, theta=31.218703 -> V=1.0, theta=0.0
% INFO    : Bus 4154	: V=1.016616, theta=-4.658699 -> V=1.0, theta=0.0
% INFO    : Bus 4155	: V=1.02424, theta=84.887043 -> V=1.0, theta=0.0
% INFO    : Bus 4156	: V=1.02424, theta=84.887043 -> V=1.0, theta=0.0
% INFO    : Bus 4157	: V=1.026566, theta=74.36307 -> V=1.0, theta=0.0
% INFO    : Bus 4158	: V=1.026566, theta=74.36307 -> V=1.0, theta=0.0
% INFO    : Bus 4159	: V=1.041381, theta=77.156696 -> V=1.0, theta=0.0
% INFO    : Bus 4160	: V=1.026566, theta=74.36307 -> V=1.0, theta=0.0
% INFO    : Bus 4161	: V=1.041381, theta=77.156696 -> V=1.0, theta=0.0
% INFO    : Bus 4162	: V=0.997106, theta=93.076376 -> V=1.0, theta=0.0
% INFO    : Bus 4163	: V=1.027512, theta=78.665189 -> V=1.0, theta=0.0
% INFO    : Bus 4164	: V=1.027512, theta=78.665189 -> V=1.0, theta=0.0
% INFO    : Bus 4165	: V=1.059061, theta=5.657484 -> V=1.0, theta=0.0
% INFO    : Bus 4166	: V=1.061581, theta=6.921348 -> V=1.0, theta=0.0
% INFO    : Bus 4167	: V=1.008948, theta=-4.613451 -> V=1.0, theta=0.0
% INFO    : Bus 4168	: V=0.977908, theta=32.002635 -> V=1.0, theta=0.0
% INFO    : Bus 4169	: V=1.081804, theta=7.236687 -> V=1.0, theta=0.0
% INFO    : Bus 4170	: V=0.999986, theta=-3.034835 -> V=1.0, theta=0.0
% INFO    : Bus 4171	: V=1.016461, theta=26.125945 -> V=1.0, theta=0.0
% INFO    : Bus 4172	: V=1.015162, theta=17.478726 -> V=1.0, theta=0.0
% INFO    : Bus 4173	: V=1.029349, theta=-20.926602 -> V=1.0, theta=0.0
% INFO    : Bus 4174	: V=1.034716, theta=26.159333 -> V=1.0, theta=0.0
% INFO    : Bus 4175	: V=0.992998, theta=-2.167744 -> V=1.0, theta=0.0
% INFO    : Bus 4176	: V=1.038979, theta=-13.937788 -> V=1.0, theta=0.0
% INFO    : Bus 4177	: V=1.000365, theta=-6.940098 -> V=1.0, theta=0.0
% INFO    : Bus 4178	: V=1.054815, theta=30.42484 -> V=1.0, theta=0.0
% INFO    : Bus 4179	: V=0.997573, theta=-8.894797 -> V=1.0, theta=0.0
% INFO    : Bus 4180	: V=1.033244, theta=65.697923 -> V=1.0, theta=0.0
% INFO    : Bus 4181	: V=1.021987, theta=8.5782 -> V=1.0, theta=0.0
% INFO    : Bus 4182	: V=1.061099, theta=-1.375053 -> V=1.0, theta=0.0
% INFO    : Bus 4183	: V=1.061099, theta=-1.375053 -> V=1.0, theta=0.0
% INFO    : Bus 4184	: V=1.053208, theta=-14.335191 -> V=1.0, theta=0.0
% INFO    : Bus 4185	: V=1.061099, theta=-1.375053 -> V=1.0, theta=0.0
% INFO    : Bus 4186	: V=1.025849, theta=0.594473 -> V=1.0, theta=0.0
% INFO    : Bus 4187	: V=1.061099, theta=-1.375053 -> V=1.0, theta=0.0
% INFO    : Bus 4188	: V=0.991689, theta=-5.052309 -> V=1.0, theta=0.0
% INFO    : Bus 4189	: V=1.031654, theta=-10.43315 -> V=1.0, theta=0.0
% INFO    : Bus 4190	: V=0.985642, theta=34.609787 -> V=1.0, theta=0.0
% INFO    : Bus 4191	: V=1.03058, theta=15.553508 -> V=1.0, theta=0.0
% INFO    : Bus 4192	: V=0.971128, theta=-15.83459 -> V=1.0, theta=0.0
% INFO    : Bus 4193	: V=1.03425, theta=8.859346 -> V=1.0, theta=0.0
% INFO    : Bus 4194	: V=0.979837, theta=12.086573 -> V=1.0, theta=0.0
% INFO    : Bus 4195	: V=1.049436, theta=-0.226153 -> V=1.0, theta=0.0
% INFO    : Bus 4196	: V=1.019692, theta=25.075054 -> V=1.0, theta=0.0
% INFO    : Bus 4197	: V=1.005717, theta=-1.442301 -> V=1.0, theta=0.0
% INFO    : Bus 4198	: V=1.017124, theta=-13.230084 -> V=1.0, theta=0.0
% INFO    : Bus 4199	: V=0.986732, theta=64.355646 -> V=1.0, theta=0.0
% INFO    : Bus 4200	: V=1.070991, theta=7.604863 -> V=1.0, theta=0.0
% INFO    : Bus 4201	: V=1.073256, theta=-2.406789 -> V=1.0, theta=0.0
% INFO    : Bus 4202	: V=1.001419, theta=42.731033 -> V=1.0, theta=0.0
% INFO    : Bus 4203	: V=1.046905, theta=39.305577 -> V=1.0, theta=0.0
% INFO    : Bus 4204	: V=1.026932, theta=-12.933112 -> V=1.0, theta=0.0
% INFO    : Bus 4205	: V=1.012014, theta=-5.390975 -> V=1.0, theta=0.0
% INFO    : Bus 4206	: V=1.031165, theta=-7.839877 -> V=1.0, theta=0.0
% INFO    : Bus 4207	: V=1.030656, theta=3.405373 -> V=1.0, theta=0.0
% INFO    : Bus 4208	: V=1.017341, theta=23.332363 -> V=1.0, theta=0.0
% INFO    : Bus 4209	: V=1.023144, theta=-9.538309 -> V=1.0, theta=0.0
% INFO    : Bus 4210	: V=1.029437, theta=8.424708 -> V=1.0, theta=0.0
% INFO    : Bus 4211	: V=1.050322, theta=43.725557 -> V=1.0, theta=0.0
% INFO    : Bus 4212	: V=1.023935, theta=3.432539 -> V=1.0, theta=0.0
% INFO    : Bus 4213	: V=1.054004, theta=-6.505281 -> V=1.0, theta=0.0
% INFO    : Bus 4214	: V=1.030656, theta=3.405373 -> V=1.0, theta=0.0
% INFO    : Bus 4215	: V=1.033173, theta=16.619807 -> V=1.0, theta=0.0
% INFO    : Bus 4216	: V=1.011721, theta=-3.14251 -> V=1.0, theta=0.0
% INFO    : Bus 4217	: V=1.018631, theta=-11.528817 -> V=1.0, theta=0.0
% INFO    : Bus 4218	: V=1.049394, theta=44.617258 -> V=1.0, theta=0.0
% INFO    : Bus 4219	: V=1.05329, theta=-4.134432 -> V=1.0, theta=0.0
% INFO    : Bus 4220	: V=1.016739, theta=22.52849 -> V=1.0, theta=0.0
% INFO    : Bus 4221	: V=1.027135, theta=-4.081656 -> V=1.0, theta=0.0
% INFO    : Bus 4222	: V=1.106791, theta=7.64715 -> V=1.0, theta=0.0
% INFO    : Bus 4223	: V=1.040272, theta=1.405241 -> V=1.0, theta=0.0
% INFO    : Bus 4224	: V=0.923737, theta=-1.526105 -> V=1.0, theta=0.0
% INFO    : Bus 4225	: V=1.000923, theta=24.053391 -> V=1.0, theta=0.0
% INFO    : Bus 4226	: V=1.027461, theta=-17.241264 -> V=1.0, theta=0.0
% INFO    : Bus 4227	: V=1.014959, theta=-1.062228 -> V=1.0, theta=0.0
% INFO    : Bus 4228	: V=1.019954, theta=15.839816 -> V=1.0, theta=0.0
% INFO    : Bus 4229	: V=1.047325, theta=-7.65973 -> V=1.0, theta=0.0
% INFO    : Bus 4230	: V=1.099512, theta=10.203054 -> V=1.0, theta=0.0
% INFO    : Bus 4231	: V=1.024031, theta=-6.855341 -> V=1.0, theta=0.0
% INFO    : Bus 4232	: V=0.959513, theta=-9.813499 -> V=1.0, theta=0.0
% INFO    : Bus 4233	: V=1.006575, theta=31.414598 -> V=1.0, theta=0.0
% INFO    : Bus 4234	: V=0.990977, theta=91.853031 -> V=1.0, theta=0.0
% INFO    : Bus 4235	: V=1.011745, theta=17.062335 -> V=1.0, theta=0.0
% INFO    : Bus 4236	: V=1.022953, theta=-11.439051 -> V=1.0, theta=0.0
% INFO    : Bus 4237	: V=0.994601, theta=31.575691 -> V=1.0, theta=0.0
% INFO    : Bus 4238	: V=1.020557, theta=9.624602 -> V=1.0, theta=0.0
% INFO    : Bus 4239	: V=0.988795, theta=89.074217 -> V=1.0, theta=0.0
% INFO    : Bus 4240	: V=0.992643, theta=93.936649 -> V=1.0, theta=0.0
% INFO    : Bus 4241	: V=1.043238, theta=-2.647032 -> V=1.0, theta=0.0
% INFO    : Bus 4242	: V=1.022616, theta=65.87032 -> V=1.0, theta=0.0
% INFO    : Bus 4243	: V=1.001805, theta=26.013339 -> V=1.0, theta=0.0
% INFO    : Bus 4244	: V=1.027589, theta=42.943439 -> V=1.0, theta=0.0
% INFO    : Bus 4245	: V=1.063358, theta=20.842529 -> V=1.0, theta=0.0
% INFO    : Bus 4246	: V=1.046251, theta=24.813234 -> V=1.0, theta=0.0
% INFO    : Bus 4247	: V=1.075059, theta=0.395845 -> V=1.0, theta=0.0
% INFO    : Bus 4248	: V=1.02437, theta=-26.534792 -> V=1.0, theta=0.0
% INFO    : Bus 4249	: V=0.987295, theta=23.502088 -> V=1.0, theta=0.0
% INFO    : Bus 4250	: V=1.016491, theta=-11.127263 -> V=1.0, theta=0.0
% INFO    : Bus 4251	: V=0.972913, theta=-28.926073 -> V=1.0, theta=0.0
% INFO    : Bus 4252	: V=1.050901, theta=18.201002 -> V=1.0, theta=0.0
% INFO    : Bus 4253	: V=1.077217, theta=12.558971 -> V=1.0, theta=0.0
% INFO    : Bus 4254	: V=1.077217, theta=12.558971 -> V=1.0, theta=0.0
% INFO    : Bus 4255	: V=0.998069, theta=-6.301264 -> V=1.0, theta=0.0
% INFO    : Bus 4256	: V=1.011374, theta=-9.719553 -> V=1.0, theta=0.0
% INFO    : Bus 4257	: V=1.028997, theta=-11.598749 -> V=1.0, theta=0.0
% INFO    : Bus 4258	: V=0.998306, theta=-13.674263 -> V=1.0, theta=0.0
% INFO    : Bus 4259	: V=1.010516, theta=39.993345 -> V=1.0, theta=0.0
% INFO    : Bus 4260	: V=1.003361, theta=2.504232 -> V=1.0, theta=0.0
% INFO    : Bus 4261	: V=0.993468, theta=44.441311 -> V=1.0, theta=0.0
% INFO    : Bus 4262	: V=1.029319, theta=65.07377 -> V=1.0, theta=0.0
% INFO    : Bus 4263	: V=1.034894, theta=-0.627901 -> V=1.0, theta=0.0
% INFO    : Bus 4264	: V=1.029166, theta=13.522836 -> V=1.0, theta=0.0
% INFO    : Bus 4265	: V=1.02267, theta=55.287657 -> V=1.0, theta=0.0
% INFO    : Bus 4266	: V=0.999811, theta=25.88942 -> V=1.0, theta=0.0
% INFO    : Bus 4267	: V=0.98379, theta=29.90696 -> V=1.0, theta=0.0
% INFO    : Bus 4268	: V=1.040643, theta=-15.185394 -> V=1.0, theta=0.0
% INFO    : Bus 4269	: V=1.017835, theta=3.93041 -> V=1.0, theta=0.0
% INFO    : Bus 4270	: V=1.002594, theta=-8.605101 -> V=1.0, theta=0.0
% INFO    : Bus 4271	: V=0.983757, theta=23.92604 -> V=1.0, theta=0.0
% INFO    : Bus 4272	: V=0.961186, theta=-0.841341 -> V=1.0, theta=0.0
% INFO    : Bus 4273	: V=1.034197, theta=12.040084 -> V=1.0, theta=0.0
% INFO    : Bus 4274	: V=1.063453, theta=20.858871 -> V=1.0, theta=0.0
% INFO    : Bus 4275	: V=1.068148, theta=22.122368 -> V=1.0, theta=0.0
% INFO    : Bus 4276	: V=1.017443, theta=-8.966772 -> V=1.0, theta=0.0
% INFO    : Bus 4277	: V=0.97714, theta=-3.397693 -> V=1.0, theta=0.0
% INFO    : Bus 4278	: V=0.982175, theta=-5.537714 -> V=1.0, theta=0.0
% INFO    : Bus 4279	: V=1.022, theta=14.080066 -> V=1.0, theta=0.0
% INFO    : Bus 4280	: V=1.098116, theta=34.412051 -> V=1.0, theta=0.0
% INFO    : Bus 4281	: V=1.029441, theta=24.255246 -> V=1.0, theta=0.0
% INFO    : Bus 4282	: V=1.003847, theta=10.087109 -> V=1.0, theta=0.0
% INFO    : Bus 4283	: V=1.020394, theta=-7.926604 -> V=1.0, theta=0.0
% INFO    : Bus 4284	: V=1.058465, theta=72.88019 -> V=1.0, theta=0.0
% INFO    : Bus 4285	: V=1.058465, theta=72.88019 -> V=1.0, theta=0.0
% INFO    : Bus 4286	: V=1.058465, theta=72.88019 -> V=1.0, theta=0.0
% INFO    : Bus 4287	: V=1.058465, theta=72.88019 -> V=1.0, theta=0.0
% INFO    : Bus 4288	: V=1.058465, theta=72.88019 -> V=1.0, theta=0.0
% INFO    : Bus 4289	: V=0.95762, theta=-7.505197 -> V=1.0, theta=0.0
% INFO    : Bus 4290	: V=1.058465, theta=72.88019 -> V=1.0, theta=0.0
% INFO    : Bus 4291	: V=0.961115, theta=-7.106834 -> V=1.0, theta=0.0
% INFO    : Bus 4292	: V=1.030191, theta=-20.990522 -> V=1.0, theta=0.0
% INFO    : Bus 4293	: V=1.009078, theta=32.145889 -> V=1.0, theta=0.0
% INFO    : Bus 4294	: V=1.0586, theta=20.351145 -> V=1.0, theta=0.0
% INFO    : Bus 4295	: V=1.008299, theta=-3.139528 -> V=1.0, theta=0.0
% INFO    : Bus 4296	: V=0.98083, theta=15.703111 -> V=1.0, theta=0.0
% INFO    : Bus 4297	: V=0.979476, theta=-3.862218 -> V=1.0, theta=0.0
% INFO    : Bus 4298	: V=1.035838, theta=-5.172678 -> V=1.0, theta=0.0
% INFO    : Bus 4299	: V=1.02699, theta=20.317809 -> V=1.0, theta=0.0
% INFO    : Bus 4300	: V=1.023774, theta=-11.345098 -> V=1.0, theta=0.0
% INFO    : Bus 4301	: V=1.017638, theta=-6.936102 -> V=1.0, theta=0.0
% INFO    : Bus 4302	: V=1.031992, theta=-0.42865 -> V=1.0, theta=0.0
% INFO    : Bus 4303	: V=1.04343, theta=12.362636 -> V=1.0, theta=0.0
% INFO    : Bus 4304	: V=0.96385, theta=-8.844238 -> V=1.0, theta=0.0
% INFO    : Bus 4305	: V=1.032706, theta=34.192137 -> V=1.0, theta=0.0
% INFO    : Bus 4306	: V=1.03513, theta=18.037725 -> V=1.0, theta=0.0
% INFO    : Bus 4307	: V=1.032787, theta=34.953885 -> V=1.0, theta=0.0
% INFO    : Bus 4308	: V=0.859522, theta=-15.937191 -> V=1.0, theta=0.0
% INFO    : Bus 4309	: V=1.041629, theta=38.466941 -> V=1.0, theta=0.0
% INFO    : Bus 4310	: V=1.059635, theta=3.783182 -> V=1.0, theta=0.0
% INFO    : Bus 4311	: V=1.073959, theta=-3.242981 -> V=1.0, theta=0.0
% INFO    : Bus 4312	: V=0.96058, theta=-5.579673 -> V=1.0, theta=0.0
% INFO    : Bus 4313	: V=0.998654, theta=-9.322995 -> V=1.0, theta=0.0
% INFO    : Bus 4314	: V=1.017273, theta=-4.353956 -> V=1.0, theta=0.0
% INFO    : Bus 4315	: V=1.054119, theta=25.676484 -> V=1.0, theta=0.0
% INFO    : Bus 4316	: V=0.996114, theta=26.265826 -> V=1.0, theta=0.0
% INFO    : Bus 4317	: V=0.974827, theta=5.219098 -> V=1.0, theta=0.0
% INFO    : Bus 4318	: V=1.067942, theta=38.350166 -> V=1.0, theta=0.0
% INFO    : Bus 4319	: V=1.022689, theta=2.947261 -> V=1.0, theta=0.0
% INFO    : Bus 4320	: V=1.025787, theta=17.322493 -> V=1.0, theta=0.0
% INFO    : Bus 4321	: V=1.042801, theta=40.432398 -> V=1.0, theta=0.0
% INFO    : Bus 4322	: V=1.010966, theta=27.093735 -> V=1.0, theta=0.0
% INFO    : Bus 4323	: V=1.015646, theta=-23.160808 -> V=1.0, theta=0.0
% INFO    : Bus 4324	: V=1.016415, theta=0.018865 -> V=1.0, theta=0.0
% INFO    : Bus 4325	: V=1.04515, theta=31.525887 -> V=1.0, theta=0.0
% INFO    : Bus 4326	: V=1.028438, theta=-19.446471 -> V=1.0, theta=0.0
% INFO    : Bus 4327	: V=1.053918, theta=0.437976 -> V=1.0, theta=0.0
% INFO    : Bus 4328	: V=1.027693, theta=19.154508 -> V=1.0, theta=0.0
% INFO    : Bus 4329	: V=1.016631, theta=11.070367 -> V=1.0, theta=0.0
% INFO    : Bus 4330	: V=1.016453, theta=-24.792837 -> V=1.0, theta=0.0
% INFO    : Bus 4331	: V=0.992476, theta=33.395862 -> V=1.0, theta=0.0
% INFO    : Bus 4332	: V=1.021799, theta=-18.657358 -> V=1.0, theta=0.0
% INFO    : Bus 4333	: V=1.001355, theta=87.992692 -> V=1.0, theta=0.0
% INFO    : Bus 4334	: V=1.001352, theta=-15.450636 -> V=1.0, theta=0.0
% INFO    : Bus 4335	: V=0.998851, theta=33.48563 -> V=1.0, theta=0.0
% INFO    : Bus 4336	: V=0.908524, theta=-12.499757 -> V=1.0, theta=0.0
% INFO    : Bus 4337	: V=1.020298, theta=7.297911 -> V=1.0, theta=0.0
% INFO    : Bus 4338	: V=1.033139, theta=21.557753 -> V=1.0, theta=0.0
% INFO    : Bus 4339	: V=1.027032, theta=8.891931 -> V=1.0, theta=0.0
% INFO    : Bus 4340	: V=1.042471, theta=24.42381 -> V=1.0, theta=0.0
% INFO    : Bus 4341	: V=1.062686, theta=0.108075 -> V=1.0, theta=0.0
% INFO    : Bus 4342	: V=1.046959, theta=83.086248 -> V=1.0, theta=0.0
% INFO    : Bus 4343	: V=1.017273, theta=-4.353956 -> V=1.0, theta=0.0
% INFO    : Bus 4344	: V=1.02868, theta=47.75243 -> V=1.0, theta=0.0
% INFO    : Bus 4345	: V=1.017273, theta=-4.353956 -> V=1.0, theta=0.0
% INFO    : Bus 4346	: V=1.010548, theta=-2.153324 -> V=1.0, theta=0.0
% INFO    : Bus 4347	: V=1.033534, theta=-10.544863 -> V=1.0, theta=0.0
% INFO    : Bus 4348	: V=1.081404, theta=3.81443 -> V=1.0, theta=0.0
% INFO    : Bus 4349	: V=1.018458, theta=16.838869 -> V=1.0, theta=0.0
% INFO    : Bus 4350	: V=1.029633, theta=7.746571 -> V=1.0, theta=0.0
% INFO    : Bus 4351	: V=1.01891, theta=-9.219346 -> V=1.0, theta=0.0
% INFO    : Bus 4352	: V=1.031515, theta=19.736436 -> V=1.0, theta=0.0
% INFO    : Bus 4353	: V=1.012422, theta=6.125903 -> V=1.0, theta=0.0
% INFO    : Bus 4354	: V=1.021005, theta=21.987746 -> V=1.0, theta=0.0
% INFO    : Bus 4355	: V=1.014876, theta=35.516812 -> V=1.0, theta=0.0
% INFO    : Bus 4356	: V=0.99339, theta=-1.893366 -> V=1.0, theta=0.0
% INFO    : Bus 4357	: V=1.022735, theta=8.384385 -> V=1.0, theta=0.0
% INFO    : Bus 4358	: V=0.961398, theta=-7.399041 -> V=1.0, theta=0.0
% INFO    : Bus 4359	: V=1.014444, theta=-26.228611 -> V=1.0, theta=0.0
% INFO    : Bus 4360	: V=1.034319, theta=32.619872 -> V=1.0, theta=0.0
% INFO    : Bus 4361	: V=1.010026, theta=-1.361937 -> V=1.0, theta=0.0
% INFO    : Bus 4362	: V=0.953397, theta=-6.241067 -> V=1.0, theta=0.0
% INFO    : Bus 4363	: V=0.993713, theta=-7.604821 -> V=1.0, theta=0.0
% INFO    : Bus 4364	: V=1.011131, theta=34.830175 -> V=1.0, theta=0.0
% INFO    : Bus 4365	: V=0.990699, theta=-4.540509 -> V=1.0, theta=0.0
% INFO    : Bus 4366	: V=0.999838, theta=14.362863 -> V=1.0, theta=0.0
% INFO    : Bus 4367	: V=1.037481, theta=12.714126 -> V=1.0, theta=0.0
% INFO    : Bus 4368	: V=1.022351, theta=-16.833971 -> V=1.0, theta=0.0
% INFO    : Bus 4369	: V=1.033639, theta=4.691084 -> V=1.0, theta=0.0
% INFO    : Bus 4370	: V=1.02692, theta=24.279743 -> V=1.0, theta=0.0
% INFO    : Bus 4371	: V=1.031705, theta=39.244941 -> V=1.0, theta=0.0
% INFO    : Bus 4372	: V=1.028903, theta=35.575869 -> V=1.0, theta=0.0
% INFO    : Bus 4373	: V=1.018131, theta=13.098639 -> V=1.0, theta=0.0
% INFO    : Bus 4374	: V=0.966228, theta=-9.704952 -> V=1.0, theta=0.0
% INFO    : Bus 4375	: V=1.042435, theta=10.508967 -> V=1.0, theta=0.0
% INFO    : Bus 4376	: V=1.05097, theta=72.632097 -> V=1.0, theta=0.0
% INFO    : Bus 4377	: V=1.020557, theta=9.624602 -> V=1.0, theta=0.0
% INFO    : Bus 4378	: V=1.05097, theta=72.632097 -> V=1.0, theta=0.0
% INFO    : Bus 4379	: V=1.05097, theta=72.632097 -> V=1.0, theta=0.0
% INFO    : Bus 4380	: V=1.05097, theta=72.632097 -> V=1.0, theta=0.0
% INFO    : Bus 4381	: V=1.03193, theta=23.513612 -> V=1.0, theta=0.0
% INFO    : Bus 4382	: V=1.01901, theta=4.536634 -> V=1.0, theta=0.0
% INFO    : Bus 4383	: V=0.989359, theta=-1.825 -> V=1.0, theta=0.0
% INFO    : Bus 4384	: V=1.043087, theta=11.638661 -> V=1.0, theta=0.0
% INFO    : Bus 4385	: V=1.056129, theta=3.755647 -> V=1.0, theta=0.0
% INFO    : Bus 4386	: V=1.056129, theta=3.755647 -> V=1.0, theta=0.0
% INFO    : Bus 4387	: V=1.056129, theta=3.755647 -> V=1.0, theta=0.0
% INFO    : Bus 4388	: V=0.96614, theta=1.586225 -> V=1.0, theta=0.0
% INFO    : Bus 4389	: V=1.027342, theta=2.330121 -> V=1.0, theta=0.0
% INFO    : Bus 4390	: V=0.979195, theta=-8.157227 -> V=1.0, theta=0.0
% INFO    : Bus 4391	: V=1.000762, theta=26.627945 -> V=1.0, theta=0.0
% INFO    : Bus 4392	: V=1.034872, theta=3.134864 -> V=1.0, theta=0.0
% INFO    : Bus 4393	: V=1.034646, theta=-0.807488 -> V=1.0, theta=0.0
% INFO    : Bus 4394	: V=1.006945, theta=-3.256973 -> V=1.0, theta=0.0
% INFO    : Bus 4395	: V=1.053877, theta=-6.619644 -> V=1.0, theta=0.0
% INFO    : Bus 4396	: V=1.069904, theta=5.784464 -> V=1.0, theta=0.0
% INFO    : Bus 4397	: V=1.025298, theta=4.11833 -> V=1.0, theta=0.0
% INFO    : Bus 4398	: V=1.017859, theta=30.171289 -> V=1.0, theta=0.0
% INFO    : Bus 4399	: V=1.016319, theta=3.592341 -> V=1.0, theta=0.0
% INFO    : Bus 4400	: V=1.04876, theta=45.73683 -> V=1.0, theta=0.0
% INFO    : Bus 4401	: V=0.990365, theta=-24.372042 -> V=1.0, theta=0.0
% INFO    : Bus 4402	: V=0.993799, theta=38.541357 -> V=1.0, theta=0.0
% INFO    : Bus 4403	: V=1.029323, theta=-3.215687 -> V=1.0, theta=0.0
% INFO    : Bus 4404	: V=1.126478, theta=-1.587109 -> V=1.0, theta=0.0
% INFO    : Bus 4405	: V=1.038344, theta=11.554722 -> V=1.0, theta=0.0
% INFO    : Bus 4406	: V=0.980316, theta=12.22824 -> V=1.0, theta=0.0
% INFO    : Bus 4407	: V=1.025451, theta=-11.135864 -> V=1.0, theta=0.0
% INFO    : Bus 4408	: V=1.018686, theta=19.883168 -> V=1.0, theta=0.0
% INFO    : Bus 4409	: V=0.996887, theta=-1.878265 -> V=1.0, theta=0.0
% INFO    : Bus 4410	: V=1.001018, theta=29.463147 -> V=1.0, theta=0.0
% INFO    : Bus 4411	: V=1.017582, theta=-1.17871 -> V=1.0, theta=0.0
% INFO    : Bus 4412	: V=1.01959, theta=-20.768164 -> V=1.0, theta=0.0
% INFO    : Bus 4413	: V=1.022516, theta=9.26728 -> V=1.0, theta=0.0
% INFO    : Bus 4414	: V=1.018843, theta=-26.434948 -> V=1.0, theta=0.0
% INFO    : Bus 4415	: V=1.016672, theta=-25.102813 -> V=1.0, theta=0.0
% INFO    : Bus 4416	: V=1.00644, theta=12.404584 -> V=1.0, theta=0.0
% INFO    : Bus 4417	: V=0.982329, theta=32.021815 -> V=1.0, theta=0.0
% INFO    : Bus 4418	: V=1.013605, theta=-27.369953 -> V=1.0, theta=0.0
% INFO    : Bus 4419	: V=1.012569, theta=-27.123986 -> V=1.0, theta=0.0
% INFO    : Bus 4420	: V=1.009664, theta=-14.472462 -> V=1.0, theta=0.0
% INFO    : Bus 4421	: V=0.998549, theta=-19.873954 -> V=1.0, theta=0.0
% INFO    : Bus 4422	: V=1.062896, theta=-0.392816 -> V=1.0, theta=0.0
% INFO    : Bus 4423	: V=0.984601, theta=26.113187 -> V=1.0, theta=0.0
% INFO    : Bus 4424	: V=1.062896, theta=-0.392816 -> V=1.0, theta=0.0
% INFO    : Bus 4425	: V=1.062896, theta=-0.392816 -> V=1.0, theta=0.0
% INFO    : Bus 4426	: V=1.029009, theta=32.575777 -> V=1.0, theta=0.0
% INFO    : Bus 4427	: V=1.029009, theta=32.575777 -> V=1.0, theta=0.0
% INFO    : Bus 4428	: V=0.992666, theta=12.175779 -> V=1.0, theta=0.0
% INFO    : Bus 4429	: V=0.992666, theta=12.175779 -> V=1.0, theta=0.0
% INFO    : Bus 4430	: V=1.033479, theta=18.956983 -> V=1.0, theta=0.0
% INFO    : Bus 4431	: V=0.992666, theta=12.175779 -> V=1.0, theta=0.0
% INFO    : Bus 4432	: V=1.030407, theta=32.510933 -> V=1.0, theta=0.0
% INFO    : Bus 4433	: V=1.030407, theta=32.510933 -> V=1.0, theta=0.0
% INFO    : Bus 4434	: V=1.030407, theta=32.510933 -> V=1.0, theta=0.0
% INFO    : Bus 4435	: V=1.029551, theta=20.015518 -> V=1.0, theta=0.0
% INFO    : Bus 4436	: V=1.013595, theta=9.488984 -> V=1.0, theta=0.0
% INFO    : Bus 4437	: V=1.011826, theta=21.695695 -> V=1.0, theta=0.0
% INFO    : Bus 4438	: V=0.990734, theta=-2.662187 -> V=1.0, theta=0.0
% INFO    : Bus 4439	: V=0.987781, theta=23.062889 -> V=1.0, theta=0.0
% INFO    : Bus 4440	: V=1.042317, theta=14.274354 -> V=1.0, theta=0.0
% INFO    : Bus 4441	: V=1.019093, theta=5.814914 -> V=1.0, theta=0.0
% INFO    : Bus 4442	: V=1.01963, theta=-10.13352 -> V=1.0, theta=0.0
% INFO    : Bus 4443	: V=1.128032, theta=6.903218 -> V=1.0, theta=0.0
% INFO    : Bus 4444	: V=0.97207, theta=-13.128881 -> V=1.0, theta=0.0
% INFO    : Bus 4445	: V=1.038188, theta=12.744727 -> V=1.0, theta=0.0
% INFO    : Bus 4446	: V=1.001673, theta=-20.498177 -> V=1.0, theta=0.0
% INFO    : Bus 4447	: V=1.003507, theta=6.361923 -> V=1.0, theta=0.0
% INFO    : Bus 4448	: V=1.127182, theta=5.800414 -> V=1.0, theta=0.0
% INFO    : Bus 4449	: V=1.035406, theta=21.74444 -> V=1.0, theta=0.0
% INFO    : Bus 4450	: V=1.00848, theta=1.492828 -> V=1.0, theta=0.0
% INFO    : Bus 4451	: V=1.026147, theta=8.391166 -> V=1.0, theta=0.0
% INFO    : Bus 4452	: V=1.044746, theta=-1.000699 -> V=1.0, theta=0.0
% INFO    : Bus 4453	: V=1.026147, theta=8.391166 -> V=1.0, theta=0.0
% INFO    : Bus 4454	: V=1.026722, theta=7.499091 -> V=1.0, theta=0.0
% INFO    : Bus 4455	: V=1.025977, theta=8.588106 -> V=1.0, theta=0.0
% INFO    : Bus 4456	: V=1.026722, theta=7.499091 -> V=1.0, theta=0.0
% INFO    : Bus 4457	: V=1.026722, theta=7.499091 -> V=1.0, theta=0.0
% INFO    : Bus 4458	: V=1.031695, theta=0.0 -> V=1.0, theta=0.0
% INFO    : Bus 4459	: V=1.084051, theta=0.578262 -> V=1.0, theta=0.0
% INFO    : Bus 4460	: V=1.02748, theta=-20.019397 -> V=1.0, theta=0.0
% INFO    : Bus 4461	: V=1.026147, theta=8.391166 -> V=1.0, theta=0.0
% INFO    : Bus 4462	: V=1.037705, theta=1.765872 -> V=1.0, theta=0.0
% INFO    : Bus 4463	: V=1.034718, theta=27.446584 -> V=1.0, theta=0.0
% INFO    : Bus 4464	: V=1.036487, theta=1.705969 -> V=1.0, theta=0.0
% INFO    : Bus 4465	: V=1.008461, theta=-8.488351 -> V=1.0, theta=0.0
% INFO    : Bus 4466	: V=1.014786, theta=-14.560212 -> V=1.0, theta=0.0
% INFO    : Bus 4467	: V=0.994359, theta=-11.554653 -> V=1.0, theta=0.0
% INFO    : Bus 4468	: V=1.027351, theta=14.976779 -> V=1.0, theta=0.0
% INFO    : Bus 4469	: V=1.027797, theta=5.798068 -> V=1.0, theta=0.0
% INFO    : Bus 4470	: V=1.057682, theta=40.579523 -> V=1.0, theta=0.0
% INFO    : Bus 4471	: V=0.994801, theta=-10.572755 -> V=1.0, theta=0.0
% INFO    : Bus 4472	: V=1.030888, theta=22.528343 -> V=1.0, theta=0.0
% INFO    : Bus 4473	: V=1.037029, theta=34.381584 -> V=1.0, theta=0.0
% INFO    : Bus 4474	: V=0.999778, theta=19.659402 -> V=1.0, theta=0.0
% INFO    : Bus 4475	: V=0.998935, theta=-13.055396 -> V=1.0, theta=0.0
% INFO    : Bus 4476	: V=1.020321, theta=-7.162256 -> V=1.0, theta=0.0
% INFO    : Bus 4477	: V=0.997236, theta=-1.693587 -> V=1.0, theta=0.0
% INFO    : Bus 4478	: V=1.021495, theta=-26.750182 -> V=1.0, theta=0.0
% INFO    : Bus 4479	: V=0.987011, theta=11.817348 -> V=1.0, theta=0.0
% INFO    : Bus 4480	: V=1.031189, theta=-1.476188 -> V=1.0, theta=0.0
% INFO    : Bus 4481	: V=1.025116, theta=-16.986526 -> V=1.0, theta=0.0
% INFO    : Bus 4482	: V=1.040694, theta=34.393917 -> V=1.0, theta=0.0
% INFO    : Bus 4483	: V=1.054159, theta=6.298568 -> V=1.0, theta=0.0
% INFO    : Bus 4484	: V=1.022819, theta=-18.100331 -> V=1.0, theta=0.0
% INFO    : Bus 4485	: V=0.982602, theta=-7.019601 -> V=1.0, theta=0.0
% INFO    : Bus 4486	: V=1.020213, theta=2.674933 -> V=1.0, theta=0.0
% INFO    : Bus 4487	: V=1.014397, theta=-8.790084 -> V=1.0, theta=0.0
% INFO    : Bus 4488	: V=0.982004, theta=27.243336 -> V=1.0, theta=0.0
% INFO    : Bus 4489	: V=1.001803, theta=-12.546618 -> V=1.0, theta=0.0
% INFO    : Bus 4490	: V=1.025377, theta=37.825766 -> V=1.0, theta=0.0
% INFO    : Bus 4491	: V=1.032325, theta=1.535915 -> V=1.0, theta=0.0
% INFO    : Bus 4492	: V=0.984733, theta=-11.498484 -> V=1.0, theta=0.0
% INFO    : Bus 4493	: V=1.026169, theta=-17.870685 -> V=1.0, theta=0.0
% INFO    : Bus 4494	: V=1.031757, theta=29.291677 -> V=1.0, theta=0.0
% INFO    : Bus 4495	: V=1.038747, theta=-8.642337 -> V=1.0, theta=0.0
% INFO    : Bus 4496	: V=1.025271, theta=-7.114844 -> V=1.0, theta=0.0
% INFO    : Bus 4497	: V=1.013359, theta=-15.130671 -> V=1.0, theta=0.0
% INFO    : Bus 4498	: V=1.046775, theta=42.710459 -> V=1.0, theta=0.0
% INFO    : Bus 4499	: V=1.019231, theta=22.327173 -> V=1.0, theta=0.0
% INFO    : Bus 4500	: V=0.998219, theta=19.035279 -> V=1.0, theta=0.0
% INFO    : Bus 4501	: V=1.028707, theta=4.250081 -> V=1.0, theta=0.0
% INFO    : Bus 4502	: V=1.033547, theta=32.215254 -> V=1.0, theta=0.0
% INFO    : Bus 4503	: V=1.020461, theta=-10.378065 -> V=1.0, theta=0.0
% INFO    : Bus 4504	: V=1.030095, theta=17.157141 -> V=1.0, theta=0.0
% INFO    : Bus 4505	: V=1.028414, theta=-6.287287 -> V=1.0, theta=0.0
% INFO    : Bus 4506	: V=1.013391, theta=26.007892 -> V=1.0, theta=0.0
% INFO    : Bus 4507	: V=1.006727, theta=63.076151 -> V=1.0, theta=0.0
% INFO    : Bus 4508	: V=1.018251, theta=31.685041 -> V=1.0, theta=0.0
% INFO    : Bus 4509	: V=1.061212, theta=43.548638 -> V=1.0, theta=0.0
% INFO    : Bus 4510	: V=1.057573, theta=-0.339331 -> V=1.0, theta=0.0
% INFO    : Bus 4511	: V=1.027331, theta=22.416711 -> V=1.0, theta=0.0
% INFO    : Bus 4512	: V=1.028707, theta=4.250081 -> V=1.0, theta=0.0
% INFO    : Bus 4513	: V=0.990908, theta=15.83898 -> V=1.0, theta=0.0
% INFO    : Bus 4514	: V=0.996914, theta=3.406076 -> V=1.0, theta=0.0
% INFO    : Bus 4515	: V=1.018221, theta=13.018444 -> V=1.0, theta=0.0
% INFO    : Bus 4516	: V=1.020049, theta=4.294635 -> V=1.0, theta=0.0
% INFO    : Bus 4517	: V=0.971901, theta=45.235162 -> V=1.0, theta=0.0
% INFO    : Bus 4518	: V=1.022517, theta=-12.397149 -> V=1.0, theta=0.0
% INFO    : Bus 4519	: V=1.004938, theta=11.405014 -> V=1.0, theta=0.0
% INFO    : Bus 4520	: V=1.072885, theta=81.684684 -> V=1.0, theta=0.0
% INFO    : Bus 4521	: V=1.031572, theta=19.723822 -> V=1.0, theta=0.0
% INFO    : Bus 4522	: V=1.017389, theta=-26.420667 -> V=1.0, theta=0.0
% INFO    : Bus 4523	: V=1.047656, theta=5.772198 -> V=1.0, theta=0.0
% INFO    : Bus 4524	: V=0.962181, theta=-11.221239 -> V=1.0, theta=0.0
% INFO    : Bus 4525	: V=1.030304, theta=9.376935 -> V=1.0, theta=0.0
% INFO    : Bus 4526	: V=0.969146, theta=47.259579 -> V=1.0, theta=0.0
% INFO    : Bus 4527	: V=0.986146, theta=2.115148 -> V=1.0, theta=0.0
% INFO    : Bus 4528	: V=1.031064, theta=19.661973 -> V=1.0, theta=0.0
% INFO    : Bus 4529	: V=0.972301, theta=13.963846 -> V=1.0, theta=0.0
% INFO    : Bus 4530	: V=1.032296, theta=-9.89235 -> V=1.0, theta=0.0
% INFO    : Bus 4531	: V=1.018762, theta=-7.534283 -> V=1.0, theta=0.0
% INFO    : Bus 4532	: V=0.988864, theta=-4.94572 -> V=1.0, theta=0.0
% INFO    : Bus 4533	: V=1.078042, theta=3.076045 -> V=1.0, theta=0.0
% INFO    : Bus 4534	: V=1.011489, theta=10.204543 -> V=1.0, theta=0.0
% INFO    : Bus 4535	: V=1.011489, theta=10.204543 -> V=1.0, theta=0.0
% INFO    : Bus 4536	: V=1.044785, theta=-3.114997 -> V=1.0, theta=0.0
% INFO    : Bus 4537	: V=1.011489, theta=10.204543 -> V=1.0, theta=0.0
% INFO    : Bus 4538	: V=1.023441, theta=-1.107233 -> V=1.0, theta=0.0
% INFO    : Bus 4539	: V=1.043357, theta=16.76639 -> V=1.0, theta=0.0
% INFO    : Bus 4540	: V=1.026425, theta=15.756693 -> V=1.0, theta=0.0
% INFO    : Bus 4541	: V=1.016652, theta=-0.629448 -> V=1.0, theta=0.0
% INFO    : Bus 4542	: V=0.996006, theta=-5.352503 -> V=1.0, theta=0.0
% INFO    : Bus 4543	: V=0.997607, theta=-13.44051 -> V=1.0, theta=0.0
% INFO    : Bus 4544	: V=1.030425, theta=-20.977234 -> V=1.0, theta=0.0
% INFO    : Bus 4545	: V=1.010169, theta=13.76329 -> V=1.0, theta=0.0
% INFO    : Bus 4546	: V=1.010169, theta=13.76329 -> V=1.0, theta=0.0
% INFO    : Bus 4547	: V=1.040215, theta=27.967812 -> V=1.0, theta=0.0
% INFO    : Bus 4548	: V=1.040215, theta=27.967812 -> V=1.0, theta=0.0
% INFO    : Bus 4549	: V=1.040215, theta=27.967812 -> V=1.0, theta=0.0
% INFO    : Bus 4550	: V=1.040215, theta=27.967812 -> V=1.0, theta=0.0
% INFO    : Bus 4551	: V=1.040215, theta=27.967812 -> V=1.0, theta=0.0
% INFO    : Bus 4552	: V=1.040215, theta=27.967812 -> V=1.0, theta=0.0
% INFO    : Bus 4553	: V=1.01638, theta=20.943598 -> V=1.0, theta=0.0
% INFO    : Bus 4554	: V=1.040215, theta=27.967812 -> V=1.0, theta=0.0
% INFO    : Bus 4555	: V=1.026869, theta=30.816332 -> V=1.0, theta=0.0
% INFO    : Bus 4556	: V=1.020128, theta=43.998857 -> V=1.0, theta=0.0
% INFO    : Bus 4557	: V=1.018198, theta=-20.573487 -> V=1.0, theta=0.0
% INFO    : Bus 4558	: V=0.990232, theta=-4.199522 -> V=1.0, theta=0.0
% INFO    : Bus 4559	: V=1.064625, theta=6.448089 -> V=1.0, theta=0.0
% INFO    : Bus 4560	: V=0.995572, theta=2.058235 -> V=1.0, theta=0.0
% INFO    : Bus 4561	: V=0.949812, theta=-10.547801 -> V=1.0, theta=0.0
% INFO    : Bus 4562	: V=0.996004, theta=-9.138869 -> V=1.0, theta=0.0
% INFO    : Bus 4563	: V=1.019144, theta=17.562907 -> V=1.0, theta=0.0
% INFO    : Bus 4564	: V=1.017686, theta=23.465014 -> V=1.0, theta=0.0
% INFO    : Bus 4565	: V=1.014404, theta=18.336432 -> V=1.0, theta=0.0
% INFO    : Bus 4566	: V=1.010193, theta=-10.142395 -> V=1.0, theta=0.0
% INFO    : Bus 4567	: V=0.996683, theta=91.121691 -> V=1.0, theta=0.0
% INFO    : Bus 4568	: V=1.089177, theta=-1.019557 -> V=1.0, theta=0.0
% INFO    : Bus 4569	: V=1.016432, theta=13.735608 -> V=1.0, theta=0.0
% INFO    : Bus 4570	: V=1.028256, theta=38.376915 -> V=1.0, theta=0.0
% INFO    : Bus 4571	: V=0.995186, theta=-1.259042 -> V=1.0, theta=0.0
% INFO    : Bus 4572	: V=1.04927, theta=45.669864 -> V=1.0, theta=0.0
% INFO    : Bus 4573	: V=1.043665, theta=14.930439 -> V=1.0, theta=0.0
% INFO    : Bus 4574	: V=1.001175, theta=0.04192 -> V=1.0, theta=0.0
% INFO    : Bus 4575	: V=1.011461, theta=-19.855402 -> V=1.0, theta=0.0
% INFO    : Bus 4576	: V=1.02421, theta=5.097202 -> V=1.0, theta=0.0
% INFO    : Bus 4577	: V=1.02421, theta=5.097202 -> V=1.0, theta=0.0
% INFO    : Bus 4578	: V=1.02421, theta=5.097202 -> V=1.0, theta=0.0
% INFO    : Bus 4579	: V=1.025301, theta=-10.504175 -> V=1.0, theta=0.0
% INFO    : Bus 4580	: V=1.02421, theta=5.097202 -> V=1.0, theta=0.0
% INFO    : Bus 4581	: V=1.037006, theta=12.001931 -> V=1.0, theta=0.0
% INFO    : Bus 4582	: V=0.997762, theta=-9.31689 -> V=1.0, theta=0.0
% INFO    : Bus 4583	: V=1.027652, theta=1.721221 -> V=1.0, theta=0.0
% INFO    : Bus 4584	: V=1.016467, theta=30.168856 -> V=1.0, theta=0.0
% INFO    : Bus 4585	: V=1.014507, theta=26.136069 -> V=1.0, theta=0.0
% INFO    : Bus 4586	: V=0.976931, theta=-18.3327 -> V=1.0, theta=0.0
% INFO    : Bus 4587	: V=0.981444, theta=-1.785435 -> V=1.0, theta=0.0
% INFO    : Bus 4588	: V=0.974931, theta=-5.066414 -> V=1.0, theta=0.0
% INFO    : Bus 4589	: V=1.010439, theta=-1.609642 -> V=1.0, theta=0.0
% INFO    : Bus 4590	: V=1.000808, theta=-3.647252 -> V=1.0, theta=0.0
% INFO    : Bus 4591	: V=1.013455, theta=-8.739663 -> V=1.0, theta=0.0
% INFO    : Bus 4592	: V=1.043782, theta=-6.737508 -> V=1.0, theta=0.0
% INFO    : Bus 4593	: V=1.001733, theta=30.653349 -> V=1.0, theta=0.0
% INFO    : Bus 4594	: V=1.027264, theta=14.46311 -> V=1.0, theta=0.0
% INFO    : Bus 4595	: V=1.004092, theta=29.986156 -> V=1.0, theta=0.0
% INFO    : Bus 4596	: V=1.015556, theta=-17.99129 -> V=1.0, theta=0.0
% INFO    : Bus 4597	: V=1.009547, theta=-9.013371 -> V=1.0, theta=0.0
% INFO    : Bus 4598	: V=1.032985, theta=-6.930528 -> V=1.0, theta=0.0
% INFO    : Bus 4599	: V=1.017889, theta=-9.346836 -> V=1.0, theta=0.0
% INFO    : Bus 4600	: V=0.946679, theta=-10.89634 -> V=1.0, theta=0.0
% INFO    : Bus 4601	: V=1.031122, theta=31.502598 -> V=1.0, theta=0.0
% INFO    : Bus 4602	: V=1.032985, theta=-6.930528 -> V=1.0, theta=0.0
% INFO    : Bus 4603	: V=1.032985, theta=-6.930528 -> V=1.0, theta=0.0
% INFO    : Bus 4604	: V=1.032985, theta=-6.930528 -> V=1.0, theta=0.0
% INFO    : Bus 4605	: V=1.045802, theta=17.677058 -> V=1.0, theta=0.0
% INFO    : Bus 4606	: V=0.986696, theta=-2.173717 -> V=1.0, theta=0.0
% INFO    : Bus 4607	: V=1.026025, theta=92.46745 -> V=1.0, theta=0.0
% INFO    : Bus 4608	: V=1.028083, theta=8.918743 -> V=1.0, theta=0.0
% INFO    : Bus 4609	: V=1.01663, theta=-5.817088 -> V=1.0, theta=0.0
% INFO    : Bus 4610	: V=1.030733, theta=16.163563 -> V=1.0, theta=0.0
% INFO    : Bus 4611	: V=1.015919, theta=3.580325 -> V=1.0, theta=0.0
% INFO    : Bus 4612	: V=1.033649, theta=3.915318 -> V=1.0, theta=0.0
% INFO    : Bus 4613	: V=1.014648, theta=-11.384785 -> V=1.0, theta=0.0
% INFO    : Bus 4614	: V=1.039055, theta=4.342555 -> V=1.0, theta=0.0
% INFO    : Bus 4615	: V=1.030556, theta=74.673405 -> V=1.0, theta=0.0
% INFO    : Bus 4616	: V=1.026027, theta=-7.002651 -> V=1.0, theta=0.0
% INFO    : Bus 4617	: V=1.041665, theta=2.506214 -> V=1.0, theta=0.0
% INFO    : Bus 4618	: V=1.024278, theta=13.272885 -> V=1.0, theta=0.0
% INFO    : Bus 4619	: V=1.024278, theta=13.272885 -> V=1.0, theta=0.0
% INFO    : Bus 4620	: V=1.0394, theta=27.763701 -> V=1.0, theta=0.0
% INFO    : Bus 4621	: V=1.029352, theta=19.23476 -> V=1.0, theta=0.0
% INFO    : Bus 4622	: V=1.054046, theta=31.44229 -> V=1.0, theta=0.0
% INFO    : Bus 4623	: V=1.041519, theta=-15.897906 -> V=1.0, theta=0.0
% INFO    : Bus 4624	: V=0.970562, theta=35.740322 -> V=1.0, theta=0.0
% INFO    : Bus 4625	: V=0.992529, theta=-4.178433 -> V=1.0, theta=0.0
% INFO    : Bus 4626	: V=1.015029, theta=3.043049 -> V=1.0, theta=0.0
% INFO    : Bus 4627	: V=1.015029, theta=3.043049 -> V=1.0, theta=0.0
% INFO    : Bus 4628	: V=1.017578, theta=-4.847153 -> V=1.0, theta=0.0
% INFO    : Bus 4629	: V=0.949924, theta=12.732443 -> V=1.0, theta=0.0
% INFO    : Bus 4630	: V=1.015029, theta=3.043049 -> V=1.0, theta=0.0
% INFO    : Bus 4631	: V=1.015029, theta=3.043049 -> V=1.0, theta=0.0
% INFO    : Bus 4632	: V=1.028847, theta=7.452884 -> V=1.0, theta=0.0
% INFO    : Bus 4633	: V=1.015029, theta=3.043049 -> V=1.0, theta=0.0
% INFO    : Bus 4634	: V=1.015029, theta=3.043049 -> V=1.0, theta=0.0
% INFO    : Bus 4635	: V=1.015029, theta=3.043049 -> V=1.0, theta=0.0
% INFO    : Bus 4636	: V=1.047643, theta=-4.357333 -> V=1.0, theta=0.0
% INFO    : Bus 4637	: V=1.020805, theta=17.057331 -> V=1.0, theta=0.0
% INFO    : Bus 4638	: V=1.049155, theta=27.915801 -> V=1.0, theta=0.0
% INFO    : Bus 4639	: V=1.084959, theta=51.860986 -> V=1.0, theta=0.0
% INFO    : Bus 4640	: V=1.037956, theta=35.654623 -> V=1.0, theta=0.0
% INFO    : Bus 4641	: V=0.936442, theta=-4.804 -> V=1.0, theta=0.0
% INFO    : Bus 4642	: V=1.06598, theta=-3.21968 -> V=1.0, theta=0.0
% INFO    : Bus 4643	: V=1.012893, theta=26.368849 -> V=1.0, theta=0.0
% INFO    : Bus 4644	: V=1.011577, theta=-11.964199 -> V=1.0, theta=0.0
% INFO    : Bus 4645	: V=0.985531, theta=-15.362323 -> V=1.0, theta=0.0
% INFO    : Bus 4646	: V=1.017233, theta=-16.531897 -> V=1.0, theta=0.0
% INFO    : Bus 4647	: V=1.017233, theta=-16.531897 -> V=1.0, theta=0.0
% INFO    : Bus 4648	: V=1.032267, theta=-6.990671 -> V=1.0, theta=0.0
% INFO    : Bus 4649	: V=1.034774, theta=-11.388611 -> V=1.0, theta=0.0
% INFO    : Bus 4650	: V=1.034774, theta=-11.388611 -> V=1.0, theta=0.0
% INFO    : Bus 4651	: V=1.034774, theta=-11.388611 -> V=1.0, theta=0.0
% INFO    : Bus 4652	: V=1.037564, theta=83.849724 -> V=1.0, theta=0.0
% INFO    : Bus 4653	: V=1.025357, theta=33.219063 -> V=1.0, theta=0.0
% INFO    : Bus 4654	: V=0.997462, theta=-17.125727 -> V=1.0, theta=0.0
% INFO    : Bus 4655	: V=1.042492, theta=18.795962 -> V=1.0, theta=0.0
% INFO    : Bus 4656	: V=1.042492, theta=18.795962 -> V=1.0, theta=0.0
% INFO    : Bus 4657	: V=1.026117, theta=25.086822 -> V=1.0, theta=0.0
% INFO    : Bus 4658	: V=1.026117, theta=25.086822 -> V=1.0, theta=0.0
% INFO    : Bus 4659	: V=0.976593, theta=-5.482851 -> V=1.0, theta=0.0
% INFO    : Bus 4660	: V=1.024738, theta=22.795258 -> V=1.0, theta=0.0
% INFO    : Bus 4661	: V=1.023633, theta=22.672364 -> V=1.0, theta=0.0
% INFO    : Bus 4662	: V=1.055425, theta=81.529284 -> V=1.0, theta=0.0
% INFO    : Bus 4663	: V=1.055425, theta=81.529284 -> V=1.0, theta=0.0
% INFO    : Bus 4664	: V=1.053529, theta=75.167292 -> V=1.0, theta=0.0
% INFO    : Bus 4665	: V=1.053529, theta=75.167292 -> V=1.0, theta=0.0
% INFO    : Bus 4666	: V=1.055479, theta=63.485669 -> V=1.0, theta=0.0
% INFO    : Bus 4667	: V=0.991538, theta=17.560846 -> V=1.0, theta=0.0
% INFO    : Bus 4668	: V=0.998951, theta=38.095582 -> V=1.0, theta=0.0
% INFO    : Bus 4669	: V=1.046994, theta=35.737826 -> V=1.0, theta=0.0
% INFO    : Bus 4670	: V=1.043049, theta=13.489159 -> V=1.0, theta=0.0
% INFO    : Bus 4671	: V=1.035838, theta=-5.172678 -> V=1.0, theta=0.0
% INFO    : Bus 4672	: V=1.029878, theta=17.097079 -> V=1.0, theta=0.0
% INFO    : Bus 4673	: V=1.014846, theta=-20.345542 -> V=1.0, theta=0.0
% INFO    : Bus 4674	: V=0.991989, theta=-14.512462 -> V=1.0, theta=0.0
% INFO    : Bus 4675	: V=1.036966, theta=15.051213 -> V=1.0, theta=0.0
% INFO    : Bus 4676	: V=1.059275, theta=72.522304 -> V=1.0, theta=0.0
% INFO    : Bus 4677	: V=1.059275, theta=72.522304 -> V=1.0, theta=0.0
% INFO    : Bus 4678	: V=1.059275, theta=72.522304 -> V=1.0, theta=0.0
% INFO    : Bus 4679	: V=1.052163, theta=86.031538 -> V=1.0, theta=0.0
% INFO    : Bus 4680	: V=1.052163, theta=86.031538 -> V=1.0, theta=0.0
% INFO    : Bus 4681	: V=1.01164, theta=-7.354502 -> V=1.0, theta=0.0
% INFO    : Bus 4682	: V=1.010452, theta=12.228523 -> V=1.0, theta=0.0
% INFO    : Bus 4683	: V=1.047117, theta=89.983578 -> V=1.0, theta=0.0
% INFO    : Bus 4684	: V=1.028781, theta=8.833625 -> V=1.0, theta=0.0
% INFO    : Bus 4685	: V=1.030939, theta=38.422518 -> V=1.0, theta=0.0
% INFO    : Bus 4686	: V=1.028648, theta=-14.669346 -> V=1.0, theta=0.0
% INFO    : Bus 4687	: V=1.034213, theta=1.500755 -> V=1.0, theta=0.0
% INFO    : Bus 4688	: V=1.010532, theta=22.946012 -> V=1.0, theta=0.0
% INFO    : Bus 4689	: V=1.018486, theta=23.539639 -> V=1.0, theta=0.0
% INFO    : Bus 4690	: V=1.041748, theta=29.3468 -> V=1.0, theta=0.0
% INFO    : Bus 4691	: V=1.037993, theta=28.716517 -> V=1.0, theta=0.0
% INFO    : Bus 4692	: V=1.026746, theta=3.870557 -> V=1.0, theta=0.0
% INFO    : Bus 4693	: V=1.01339, theta=-8.814025 -> V=1.0, theta=0.0
% INFO    : Bus 4694	: V=1.041748, theta=29.3468 -> V=1.0, theta=0.0
% INFO    : Bus 4695	: V=1.038587, theta=-4.268876 -> V=1.0, theta=0.0
% INFO    : Bus 4696	: V=1.01339, theta=-8.814025 -> V=1.0, theta=0.0
% INFO    : Bus 4697	: V=1.039251, theta=-4.888975 -> V=1.0, theta=0.0
% INFO    : Bus 4698	: V=1.037993, theta=28.716517 -> V=1.0, theta=0.0
% INFO    : Bus 4699	: V=1.037993, theta=28.716517 -> V=1.0, theta=0.0
% INFO    : Bus 4700	: V=1.019762, theta=17.054946 -> V=1.0, theta=0.0
% INFO    : Bus 4701	: V=0.99113, theta=-5.121845 -> V=1.0, theta=0.0
% INFO    : Bus 4702	: V=1.041748, theta=29.3468 -> V=1.0, theta=0.0
% INFO    : Bus 4703	: V=1.017828, theta=-6.986287 -> V=1.0, theta=0.0
% INFO    : Bus 4704	: V=0.939142, theta=40.851376 -> V=1.0, theta=0.0
% INFO    : Bus 4705	: V=1.010022, theta=-18.844281 -> V=1.0, theta=0.0
% INFO    : Bus 4706	: V=1.017598, theta=3.454906 -> V=1.0, theta=0.0
% INFO    : Bus 4707	: V=1.041748, theta=29.3468 -> V=1.0, theta=0.0
% INFO    : Bus 4708	: V=1.022811, theta=3.980805 -> V=1.0, theta=0.0
% INFO    : Bus 4709	: V=1.033648, theta=19.100507 -> V=1.0, theta=0.0
% INFO    : Bus 4710	: V=1.0447, theta=34.637859 -> V=1.0, theta=0.0
% INFO    : Bus 4711	: V=0.990691, theta=-5.824455 -> V=1.0, theta=0.0
% INFO    : Bus 4712	: V=1.024664, theta=-3.951182 -> V=1.0, theta=0.0
% INFO    : Bus 4713	: V=1.024941, theta=-4.246073 -> V=1.0, theta=0.0
% INFO    : Bus 4714	: V=1.0463, theta=17.884755 -> V=1.0, theta=0.0
% INFO    : Bus 4715	: V=1.018631, theta=-11.528817 -> V=1.0, theta=0.0
% INFO    : Bus 4716	: V=1.008588, theta=11.184185 -> V=1.0, theta=0.0
% INFO    : Bus 4717	: V=1.033766, theta=7.242446 -> V=1.0, theta=0.0
% INFO    : Bus 4718	: V=1.045544, theta=14.333931 -> V=1.0, theta=0.0
% INFO    : Bus 4719	: V=0.977434, theta=12.295699 -> V=1.0, theta=0.0
% INFO    : Bus 4720	: V=0.967808, theta=-5.298475 -> V=1.0, theta=0.0
% INFO    : Bus 4721	: V=1.019917, theta=31.140334 -> V=1.0, theta=0.0
% INFO    : Bus 4722	: V=1.048656, theta=21.505608 -> V=1.0, theta=0.0
% INFO    : Bus 4723	: V=1.048656, theta=21.505608 -> V=1.0, theta=0.0
% INFO    : Bus 4724	: V=1.048656, theta=21.505608 -> V=1.0, theta=0.0
% INFO    : Bus 4725	: V=1.048656, theta=21.505608 -> V=1.0, theta=0.0
% INFO    : Bus 4726	: V=1.048656, theta=21.505608 -> V=1.0, theta=0.0
% INFO    : Bus 4727	: V=1.048656, theta=21.505608 -> V=1.0, theta=0.0
% INFO    : Bus 4728	: V=1.048656, theta=21.505608 -> V=1.0, theta=0.0
% INFO    : Bus 4729	: V=1.048656, theta=21.505608 -> V=1.0, theta=0.0
% INFO    : Bus 4730	: V=1.064094, theta=37.912708 -> V=1.0, theta=0.0
% INFO    : Bus 4731	: V=1.001491, theta=-13.031617 -> V=1.0, theta=0.0
% INFO    : Bus 4732	: V=1.045332, theta=19.973133 -> V=1.0, theta=0.0
% INFO    : Bus 4733	: V=1.043092, theta=17.519475 -> V=1.0, theta=0.0
% INFO    : Bus 4734	: V=1.013038, theta=26.570765 -> V=1.0, theta=0.0
% INFO    : Bus 4735	: V=0.970438, theta=49.384588 -> V=1.0, theta=0.0
% INFO    : Bus 4736	: V=1.062761, theta=50.754899 -> V=1.0, theta=0.0
% INFO    : Bus 4737	: V=0.997804, theta=1.009459 -> V=1.0, theta=0.0
% INFO    : Bus 4738	: V=1.043092, theta=17.519475 -> V=1.0, theta=0.0
% INFO    : Bus 4739	: V=1.014647, theta=18.500995 -> V=1.0, theta=0.0
% INFO    : Bus 4740	: V=1.017165, theta=12.422282 -> V=1.0, theta=0.0
% INFO    : Bus 4741	: V=1.031913, theta=8.483144 -> V=1.0, theta=0.0
% INFO    : Bus 4742	: V=1.024295, theta=-24.350529 -> V=1.0, theta=0.0
% INFO    : Bus 4743	: V=0.998781, theta=42.499423 -> V=1.0, theta=0.0
% INFO    : Bus 4744	: V=1.002639, theta=-10.11886 -> V=1.0, theta=0.0
% INFO    : Bus 4745	: V=1.04834, theta=88.719592 -> V=1.0, theta=0.0
% INFO    : Bus 4746	: V=1.026568, theta=1.551222 -> V=1.0, theta=0.0
% INFO    : Bus 4747	: V=1.13198, theta=-0.09724 -> V=1.0, theta=0.0
% INFO    : Bus 4748	: V=1.012174, theta=29.444069 -> V=1.0, theta=0.0
% INFO    : Bus 4749	: V=1.009602, theta=33.524231 -> V=1.0, theta=0.0
% INFO    : Bus 4750	: V=1.101029, theta=-0.788511 -> V=1.0, theta=0.0
% INFO    : Bus 4751	: V=1.046359, theta=90.322887 -> V=1.0, theta=0.0
% INFO    : Bus 4752	: V=1.032344, theta=9.093698 -> V=1.0, theta=0.0
% INFO    : Bus 4753	: V=1.046359, theta=90.322887 -> V=1.0, theta=0.0
% INFO    : Bus 4754	: V=1.059913, theta=0.520524 -> V=1.0, theta=0.0
% INFO    : Bus 4755	: V=1.017262, theta=9.223881 -> V=1.0, theta=0.0
% INFO    : Bus 4756	: V=1.036476, theta=43.598697 -> V=1.0, theta=0.0
% INFO    : Bus 4757	: V=1.027461, theta=-17.241264 -> V=1.0, theta=0.0
% INFO    : Bus 4758	: V=0.963378, theta=-9.81008 -> V=1.0, theta=0.0
% INFO    : Bus 4759	: V=0.977808, theta=-27.135545 -> V=1.0, theta=0.0
% INFO    : Bus 4760	: V=1.099212, theta=-4.426011 -> V=1.0, theta=0.0
% INFO    : Bus 4761	: V=1.020557, theta=9.624602 -> V=1.0, theta=0.0
% INFO    : Bus 4762	: V=1.02719, theta=47.01676 -> V=1.0, theta=0.0
% INFO    : Bus 4763	: V=1.024544, theta=18.974877 -> V=1.0, theta=0.0
% INFO    : Bus 4764	: V=1.030832, theta=-9.752509 -> V=1.0, theta=0.0
% INFO    : Bus 4765	: V=1.007992, theta=-20.693888 -> V=1.0, theta=0.0
% INFO    : Bus 4766	: V=1.008391, theta=-8.4759 -> V=1.0, theta=0.0
% INFO    : Bus 4767	: V=1.004933, theta=30.37899 -> V=1.0, theta=0.0
% INFO    : Bus 4768	: V=1.01753, theta=29.670296 -> V=1.0, theta=0.0
% INFO    : Bus 4769	: V=1.082014, theta=9.78954 -> V=1.0, theta=0.0
% INFO    : Bus 4770	: V=1.023397, theta=-17.3231 -> V=1.0, theta=0.0
% INFO    : Bus 4771	: V=1.022819, theta=-4.100145 -> V=1.0, theta=0.0
% INFO    : Bus 4772	: V=1.023397, theta=-17.3231 -> V=1.0, theta=0.0
% INFO    : Bus 4773	: V=1.023397, theta=-17.3231 -> V=1.0, theta=0.0
% INFO    : Bus 4774	: V=1.026206, theta=-2.974992 -> V=1.0, theta=0.0
% INFO    : Bus 4775	: V=0.993383, theta=32.126146 -> V=1.0, theta=0.0
% INFO    : Bus 4776	: V=1.025857, theta=24.243802 -> V=1.0, theta=0.0
% INFO    : Bus 4777	: V=1.050901, theta=18.201002 -> V=1.0, theta=0.0
% INFO    : Bus 4778	: V=1.05955, theta=-4.540924 -> V=1.0, theta=0.0
% INFO    : Bus 4779	: V=1.036248, theta=-15.392834 -> V=1.0, theta=0.0
% INFO    : Bus 4780	: V=1.033888, theta=21.355633 -> V=1.0, theta=0.0
% INFO    : Bus 4781	: V=1.039156, theta=19.470405 -> V=1.0, theta=0.0
% INFO    : Bus 4782	: V=1.039848, theta=12.278319 -> V=1.0, theta=0.0
% INFO    : Bus 4783	: V=1.010141, theta=-0.21068 -> V=1.0, theta=0.0
% INFO    : Bus 4784	: V=1.053999, theta=28.580111 -> V=1.0, theta=0.0
% INFO    : Bus 4785	: V=1.028555, theta=23.328029 -> V=1.0, theta=0.0
% INFO    : Bus 4786	: V=1.000057, theta=26.10357 -> V=1.0, theta=0.0
% INFO    : Bus 4787	: V=0.991747, theta=4.829091 -> V=1.0, theta=0.0
% INFO    : Bus 4788	: V=1.019129, theta=-0.189136 -> V=1.0, theta=0.0
% INFO    : Bus 4789	: V=1.026375, theta=-29.790551 -> V=1.0, theta=0.0
% INFO    : Bus 4790	: V=1.005495, theta=20.92235 -> V=1.0, theta=0.0
% INFO    : Bus 4791	: V=1.031502, theta=4.663459 -> V=1.0, theta=0.0
% INFO    : Bus 4792	: V=1.031502, theta=4.663459 -> V=1.0, theta=0.0
% INFO    : Bus 4793	: V=1.011478, theta=-0.639289 -> V=1.0, theta=0.0
% INFO    : Bus 4794	: V=1.015411, theta=-1.60616 -> V=1.0, theta=0.0
% INFO    : Bus 4795	: V=1.027302, theta=3.535768 -> V=1.0, theta=0.0
% INFO    : Bus 4796	: V=1.034961, theta=34.914591 -> V=1.0, theta=0.0
% INFO    : Bus 4797	: V=1.096479, theta=34.187198 -> V=1.0, theta=0.0
% INFO    : Bus 4798	: V=1.03203, theta=35.148877 -> V=1.0, theta=0.0
% INFO    : Bus 4799	: V=0.990537, theta=37.906966 -> V=1.0, theta=0.0
% INFO    : Bus 4800	: V=1.025342, theta=0.44206 -> V=1.0, theta=0.0
% INFO    : Bus 4801	: V=1.002965, theta=-9.338003 -> V=1.0, theta=0.0
% INFO    : Bus 4802	: V=1.073833, theta=35.411481 -> V=1.0, theta=0.0
% INFO    : Bus 4803	: V=1.022039, theta=-17.229409 -> V=1.0, theta=0.0
% INFO    : Bus 4804	: V=0.961385, theta=28.501592 -> V=1.0, theta=0.0
% INFO    : Bus 4805	: V=1.029498, theta=19.437343 -> V=1.0, theta=0.0
% INFO    : Bus 4806	: V=1.022695, theta=16.114493 -> V=1.0, theta=0.0
% INFO    : Bus 4807	: V=1.099343, theta=-14.359026 -> V=1.0, theta=0.0
% INFO    : Bus 4808	: V=1.053701, theta=-5.383885 -> V=1.0, theta=0.0
% INFO    : Bus 4809	: V=1.040009, theta=86.062395 -> V=1.0, theta=0.0
% INFO    : Bus 4810	: V=1.040009, theta=86.062395 -> V=1.0, theta=0.0
% INFO    : Bus 4811	: V=1.040009, theta=86.062395 -> V=1.0, theta=0.0
% INFO    : Bus 4812	: V=1.00402, theta=-8.963428 -> V=1.0, theta=0.0
% INFO    : Bus 4813	: V=1.079671, theta=-3.428225 -> V=1.0, theta=0.0
% INFO    : Bus 4814	: V=1.06019, theta=67.358874 -> V=1.0, theta=0.0
% INFO    : Bus 4815	: V=1.004083, theta=30.252992 -> V=1.0, theta=0.0
% INFO    : Bus 4816	: V=0.962276, theta=-9.765757 -> V=1.0, theta=0.0
% INFO    : Bus 4817	: V=1.028471, theta=23.568416 -> V=1.0, theta=0.0
% INFO    : Bus 4818	: V=0.985623, theta=34.062103 -> V=1.0, theta=0.0
% INFO    : Bus 4819	: V=1.028138, theta=17.58447 -> V=1.0, theta=0.0
% INFO    : Bus 4820	: V=0.967719, theta=40.671168 -> V=1.0, theta=0.0
% INFO    : Bus 4821	: V=1.02665, theta=-3.135251 -> V=1.0, theta=0.0
% INFO    : Bus 4822	: V=1.057748, theta=38.103723 -> V=1.0, theta=0.0
% INFO    : Bus 4823	: V=1.014332, theta=26.817672 -> V=1.0, theta=0.0
% INFO    : Bus 4824	: V=0.996149, theta=-9.146124 -> V=1.0, theta=0.0
% INFO    : Bus 4825	: V=1.052729, theta=7.447866 -> V=1.0, theta=0.0
% INFO    : Bus 4826	: V=1.038011, theta=34.413286 -> V=1.0, theta=0.0
% INFO    : Bus 4827	: V=0.993635, theta=13.821924 -> V=1.0, theta=0.0
% INFO    : Bus 4828	: V=1.069027, theta=17.921154 -> V=1.0, theta=0.0
% INFO    : Bus 4829	: V=1.0342, theta=0.003159 -> V=1.0, theta=0.0
% INFO    : Bus 4830	: V=1.0461, theta=10.881862 -> V=1.0, theta=0.0
% INFO    : Bus 4831	: V=1.02548, theta=6.087271 -> V=1.0, theta=0.0
% INFO    : Bus 4832	: V=1.01757, theta=30.154601 -> V=1.0, theta=0.0
% INFO    : Bus 4833	: V=1.014184, theta=-5.288127 -> V=1.0, theta=0.0
% INFO    : Bus 4834	: V=1.09564, theta=-4.636709 -> V=1.0, theta=0.0
% INFO    : Bus 4835	: V=1.078887, theta=-2.523292 -> V=1.0, theta=0.0
% INFO    : Bus 4836	: V=0.97179, theta=-11.726386 -> V=1.0, theta=0.0
% INFO    : Bus 4837	: V=1.026243, theta=6.043442 -> V=1.0, theta=0.0
% INFO    : Bus 4838	: V=1.01493, theta=-10.961932 -> V=1.0, theta=0.0
% INFO    : Bus 4839	: V=1.012555, theta=12.021501 -> V=1.0, theta=0.0
% INFO    : Bus 4840	: V=1.063837, theta=-4.873875 -> V=1.0, theta=0.0
% INFO    : Bus 4841	: V=1.024755, theta=36.25485 -> V=1.0, theta=0.0
% INFO    : Bus 4842	: V=1.01309, theta=92.614678 -> V=1.0, theta=0.0
% INFO    : Bus 4843	: V=1.026243, theta=6.043442 -> V=1.0, theta=0.0
% INFO    : Bus 4844	: V=1.026243, theta=6.043442 -> V=1.0, theta=0.0
% INFO    : Bus 4845	: V=1.026243, theta=6.043442 -> V=1.0, theta=0.0
% INFO    : Bus 4846	: V=1.026243, theta=6.043442 -> V=1.0, theta=0.0
% INFO    : Bus 4847	: V=1.026243, theta=6.043442 -> V=1.0, theta=0.0
% INFO    : Bus 4848	: V=0.998611, theta=13.238352 -> V=1.0, theta=0.0
% INFO    : Bus 4849	: V=1.025189, theta=10.345214 -> V=1.0, theta=0.0
% INFO    : Bus 4850	: V=1.0435, theta=33.060974 -> V=1.0, theta=0.0
% INFO    : Bus 4851	: V=1.020012, theta=17.086449 -> V=1.0, theta=0.0
% INFO    : Bus 4852	: V=0.996243, theta=-1.910178 -> V=1.0, theta=0.0
% INFO    : Bus 4853	: V=0.955883, theta=-1.464253 -> V=1.0, theta=0.0
% INFO    : Bus 4854	: V=1.041421, theta=-3.450344 -> V=1.0, theta=0.0
% INFO    : Bus 4855	: V=1.060956, theta=44.39088 -> V=1.0, theta=0.0
% INFO    : Bus 4856	: V=1.060956, theta=44.39088 -> V=1.0, theta=0.0
% INFO    : Bus 4857	: V=1.062536, theta=46.73809 -> V=1.0, theta=0.0
% INFO    : Bus 4858	: V=1.062536, theta=46.73809 -> V=1.0, theta=0.0
% INFO    : Bus 4859	: V=1.059942, theta=43.353318 -> V=1.0, theta=0.0
% INFO    : Bus 4860	: V=1.025165, theta=64.621612 -> V=1.0, theta=0.0
% INFO    : Bus 4861	: V=1.05948, theta=38.842339 -> V=1.0, theta=0.0
% INFO    : Bus 4862	: V=1.05948, theta=38.842339 -> V=1.0, theta=0.0
% INFO    : Bus 4863	: V=0.997923, theta=-14.24707 -> V=1.0, theta=0.0
% INFO    : Bus 4864	: V=1.059942, theta=43.353318 -> V=1.0, theta=0.0
% INFO    : Bus 4865	: V=1.020612, theta=-10.811239 -> V=1.0, theta=0.0
% INFO    : Bus 4866	: V=0.992519, theta=17.53406 -> V=1.0, theta=0.0
% INFO    : Bus 4867	: V=1.016484, theta=18.987706 -> V=1.0, theta=0.0
% INFO    : Bus 4868	: V=0.980935, theta=-5.899348 -> V=1.0, theta=0.0
% INFO    : Bus 4869	: V=1.046186, theta=-11.388611 -> V=1.0, theta=0.0
% INFO    : Bus 4870	: V=1.025271, theta=20.88058 -> V=1.0, theta=0.0
% INFO    : Bus 4871	: V=1.067428, theta=22.702865 -> V=1.0, theta=0.0
% INFO    : Bus 4872	: V=0.991109, theta=16.535153 -> V=1.0, theta=0.0
% INFO    : Bus 4873	: V=0.986934, theta=-15.934332 -> V=1.0, theta=0.0
% INFO    : Bus 4874	: V=0.993737, theta=-4.899565 -> V=1.0, theta=0.0
% INFO    : Bus 4875	: V=1.005551, theta=-5.201173 -> V=1.0, theta=0.0
% INFO    : Bus 4876	: V=1.019487, theta=-18.538846 -> V=1.0, theta=0.0
% INFO    : Bus 4877	: V=1.012173, theta=-17.563659 -> V=1.0, theta=0.0
% INFO    : Bus 4878	: V=1.025261, theta=12.50452 -> V=1.0, theta=0.0
% INFO    : Bus 4879	: V=0.991951, theta=-1.701584 -> V=1.0, theta=0.0
% INFO    : Bus 4880	: V=1.00528, theta=17.378627 -> V=1.0, theta=0.0
% INFO    : Bus 4881	: V=1.013234, theta=5.571068 -> V=1.0, theta=0.0
% INFO    : Bus 4882	: V=1.012673, theta=-2.175699 -> V=1.0, theta=0.0
% INFO    : Bus 4883	: V=1.05045, theta=93.240906 -> V=1.0, theta=0.0
% INFO    : Bus 4884	: V=0.986687, theta=-3.572455 -> V=1.0, theta=0.0
% INFO    : Bus 4885	: V=0.96819, theta=-4.809229 -> V=1.0, theta=0.0
% INFO    : Bus 4886	: V=1.019326, theta=37.994898 -> V=1.0, theta=0.0
% INFO    : Bus 4887	: V=1.01898, theta=27.302632 -> V=1.0, theta=0.0
% INFO    : Bus 4888	: V=1.01898, theta=27.302632 -> V=1.0, theta=0.0
% INFO    : Bus 4889	: V=1.027266, theta=14.054547 -> V=1.0, theta=0.0
% INFO    : Bus 4890	: V=1.033858, theta=-10.849314 -> V=1.0, theta=0.0
% INFO    : Bus 4891	: V=1.01396, theta=22.693254 -> V=1.0, theta=0.0
% INFO    : Bus 4892	: V=1.024711, theta=-14.053311 -> V=1.0, theta=0.0
% INFO    : Bus 4893	: V=1.024711, theta=-14.053311 -> V=1.0, theta=0.0
% INFO    : Bus 4894	: V=1.075595, theta=5.528103 -> V=1.0, theta=0.0
% INFO    : Bus 4895	: V=0.98599, theta=37.658867 -> V=1.0, theta=0.0
% INFO    : Bus 4896	: V=1.024711, theta=-14.053311 -> V=1.0, theta=0.0
% INFO    : Bus 4897	: V=1.024711, theta=-14.053311 -> V=1.0, theta=0.0
% INFO    : Bus 4898	: V=0.997952, theta=-4.752719 -> V=1.0, theta=0.0
% INFO    : Bus 4899	: V=1.027074, theta=3.213132 -> V=1.0, theta=0.0
% INFO    : Bus 4900	: V=1.014709, theta=31.598072 -> V=1.0, theta=0.0
% INFO    : Bus 4901	: V=1.000465, theta=12.056714 -> V=1.0, theta=0.0
% INFO    : Bus 4902	: V=1.045936, theta=19.626816 -> V=1.0, theta=0.0
% INFO    : Bus 4903	: V=1.045936, theta=19.626816 -> V=1.0, theta=0.0
% INFO    : Bus 4904	: V=1.058505, theta=17.418274 -> V=1.0, theta=0.0
% INFO    : Bus 4905	: V=1.058505, theta=17.418274 -> V=1.0, theta=0.0
% INFO    : Bus 4906	: V=0.99184, theta=26.455293 -> V=1.0, theta=0.0
% INFO    : Bus 4907	: V=1.043661, theta=17.14354 -> V=1.0, theta=0.0
% INFO    : Bus 4908	: V=1.056764, theta=-0.4217 -> V=1.0, theta=0.0
% INFO    : Bus 4909	: V=0.982654, theta=-4.138319 -> V=1.0, theta=0.0
% INFO    : Bus 4910	: V=1.040138, theta=32.45384 -> V=1.0, theta=0.0
% INFO    : Bus 4911	: V=1.042194, theta=18.137057 -> V=1.0, theta=0.0
% INFO    : Bus 4912	: V=0.966719, theta=-9.648099 -> V=1.0, theta=0.0
% INFO    : Bus 4913	: V=0.979117, theta=-2.898026 -> V=1.0, theta=0.0
% INFO    : Bus 4914	: V=1.050455, theta=44.07457 -> V=1.0, theta=0.0
% INFO    : Bus 4915	: V=1.009725, theta=-8.960644 -> V=1.0, theta=0.0
% INFO    : Bus 4916	: V=0.995163, theta=19.315344 -> V=1.0, theta=0.0
% INFO    : Bus 4917	: V=0.989071, theta=33.252478 -> V=1.0, theta=0.0
% INFO    : Bus 4918	: V=0.943436, theta=50.691637 -> V=1.0, theta=0.0
% INFO    : Bus 4919	: V=1.011297, theta=2.419482 -> V=1.0, theta=0.0
% INFO    : Bus 4920	: V=1.017154, theta=35.686623 -> V=1.0, theta=0.0
% INFO    : Bus 4921	: V=1.017104, theta=29.53828 -> V=1.0, theta=0.0
% INFO    : Bus 4922	: V=1.04826, theta=-8.707987 -> V=1.0, theta=0.0
% INFO    : Bus 4923	: V=0.935533, theta=-8.058668 -> V=1.0, theta=0.0
% INFO    : Bus 4924	: V=1.025724, theta=-14.139236 -> V=1.0, theta=0.0
% INFO    : Bus 4925	: V=1.017601, theta=-9.8258 -> V=1.0, theta=0.0
% INFO    : Bus 4926	: V=1.036433, theta=-0.581009 -> V=1.0, theta=0.0
% INFO    : Bus 4927	: V=1.026041, theta=18.668727 -> V=1.0, theta=0.0
% INFO    : Bus 4928	: V=1.04876, theta=45.73683 -> V=1.0, theta=0.0
% INFO    : Bus 4929	: V=1.02234, theta=-17.877403 -> V=1.0, theta=0.0
% INFO    : Bus 4930	: V=1.016405, theta=28.05316 -> V=1.0, theta=0.0
% INFO    : Bus 4931	: V=1.037501, theta=2.321125 -> V=1.0, theta=0.0
% INFO    : Bus 4932	: V=1.037501, theta=2.321125 -> V=1.0, theta=0.0
% INFO    : Bus 4933	: V=1.002517, theta=0.43526 -> V=1.0, theta=0.0
% INFO    : Bus 4934	: V=1.037973, theta=11.471538 -> V=1.0, theta=0.0
% INFO    : Bus 4935	: V=1.04852, theta=-4.374565 -> V=1.0, theta=0.0
% INFO    : Bus 4936	: V=0.953356, theta=-2.428855 -> V=1.0, theta=0.0
% INFO    : Bus 4937	: V=1.033465, theta=-19.461167 -> V=1.0, theta=0.0
% INFO    : Bus 4938	: V=1.027032, theta=8.891931 -> V=1.0, theta=0.0
% INFO    : Bus 4939	: V=1.03611, theta=8.921216 -> V=1.0, theta=0.0
% INFO    : Bus 4940	: V=0.964812, theta=-11.436007 -> V=1.0, theta=0.0
% INFO    : Bus 4941	: V=1.008296, theta=29.565359 -> V=1.0, theta=0.0
% INFO    : Bus 4942	: V=1.038474, theta=82.561969 -> V=1.0, theta=0.0
% INFO    : Bus 4943	: V=1.038474, theta=82.561969 -> V=1.0, theta=0.0
% INFO    : Bus 4944	: V=1.055417, theta=39.131981 -> V=1.0, theta=0.0
% INFO    : Bus 4945	: V=1.042258, theta=67.377104 -> V=1.0, theta=0.0
% INFO    : Bus 4946	: V=1.042258, theta=67.377104 -> V=1.0, theta=0.0
% INFO    : Bus 4947	: V=1.017976, theta=-2.931441 -> V=1.0, theta=0.0
% INFO    : Bus 4948	: V=1.02073, theta=-26.16821 -> V=1.0, theta=0.0
% INFO    : Bus 4949	: V=1.01601, theta=-0.145046 -> V=1.0, theta=0.0
% INFO    : Bus 4950	: V=1.01757, theta=30.154601 -> V=1.0, theta=0.0
% INFO    : Bus 4951	: V=1.018559, theta=23.073382 -> V=1.0, theta=0.0
% INFO    : Bus 4952	: V=1.03281, theta=29.803723 -> V=1.0, theta=0.0
% INFO    : Bus 4953	: V=1.030072, theta=19.446828 -> V=1.0, theta=0.0
% INFO    : Bus 4954	: V=1.051449, theta=3.601764 -> V=1.0, theta=0.0
% INFO    : Bus 4955	: V=1.008586, theta=35.815607 -> V=1.0, theta=0.0
% INFO    : Bus 4956	: V=1.0168, theta=34.173569 -> V=1.0, theta=0.0
% INFO    : Bus 4957	: V=1.001915, theta=-10.138862 -> V=1.0, theta=0.0
% INFO    : Bus 4958	: V=1.025082, theta=-16.616549 -> V=1.0, theta=0.0
% INFO    : Bus 4959	: V=1.024274, theta=-9.95923 -> V=1.0, theta=0.0
% INFO    : Bus 4960	: V=0.991219, theta=-5.133534 -> V=1.0, theta=0.0
% INFO    : Bus 4961	: V=1.002673, theta=-10.168847 -> V=1.0, theta=0.0
% INFO    : Bus 4962	: V=1.021606, theta=-18.065799 -> V=1.0, theta=0.0
% INFO    : Bus 4963	: V=1.019736, theta=17.906487 -> V=1.0, theta=0.0
% INFO    : Bus 4964	: V=1.019736, theta=17.906487 -> V=1.0, theta=0.0
% INFO    : Bus 4965	: V=1.005748, theta=25.955736 -> V=1.0, theta=0.0
% INFO    : Bus 4966	: V=1.034413, theta=4.784259 -> V=1.0, theta=0.0
% INFO    : Bus 4967	: V=1.013686, theta=-8.216227 -> V=1.0, theta=0.0
% INFO    : Bus 4968	: V=1.021606, theta=-18.065799 -> V=1.0, theta=0.0
% INFO    : Bus 4969	: V=1.008908, theta=13.390577 -> V=1.0, theta=0.0
% INFO    : Bus 4970	: V=1.028476, theta=2.26797 -> V=1.0, theta=0.0
% INFO    : Bus 4971	: V=1.035056, theta=1.123153 -> V=1.0, theta=0.0
% INFO    : Bus 4972	: V=1.034173, theta=26.119223 -> V=1.0, theta=0.0
% INFO    : Bus 4973	: V=1.003912, theta=-6.9049 -> V=1.0, theta=0.0
% INFO    : Bus 4974	: V=1.038699, theta=17.007141 -> V=1.0, theta=0.0
% INFO    : Bus 4975	: V=1.011379, theta=5.553053 -> V=1.0, theta=0.0
% INFO    : Bus 4976	: V=0.995518, theta=-13.198494 -> V=1.0, theta=0.0
% INFO    : Bus 4977	: V=0.997271, theta=-10.738639 -> V=1.0, theta=0.0
% INFO    : Bus 4978	: V=0.985966, theta=-4.894497 -> V=1.0, theta=0.0
% INFO    : Bus 4979	: V=0.984412, theta=-2.691034 -> V=1.0, theta=0.0
% INFO    : Bus 4980	: V=1.033951, theta=32.215255 -> V=1.0, theta=0.0
% INFO    : Bus 4981	: V=0.972225, theta=-21.169989 -> V=1.0, theta=0.0
% INFO    : Bus 4982	: V=1.01458, theta=18.108546 -> V=1.0, theta=0.0
% INFO    : Bus 4983	: V=0.995619, theta=18.792566 -> V=1.0, theta=0.0
% INFO    : Bus 4984	: V=1.01978, theta=-13.417385 -> V=1.0, theta=0.0
% INFO    : Bus 4985	: V=1.073911, theta=4.277217 -> V=1.0, theta=0.0
% INFO    : Bus 4986	: V=1.015712, theta=-3.141636 -> V=1.0, theta=0.0
% INFO    : Bus 4987	: V=1.020265, theta=-12.139526 -> V=1.0, theta=0.0
% INFO    : Bus 4988	: V=1.022099, theta=17.218586 -> V=1.0, theta=0.0
% INFO    : Bus 4989	: V=0.980508, theta=-10.597685 -> V=1.0, theta=0.0
% INFO    : Bus 4990	: V=1.065886, theta=-4.560143 -> V=1.0, theta=0.0
% INFO    : Bus 4991	: V=1.012934, theta=-4.995932 -> V=1.0, theta=0.0
% INFO    : Bus 4992	: V=1.015836, theta=-3.196121 -> V=1.0, theta=0.0
% INFO    : Bus 4993	: V=0.99786, theta=-1.75859 -> V=1.0, theta=0.0
% INFO    : Bus 4994	: V=1.014314, theta=9.813801 -> V=1.0, theta=0.0
% INFO    : Bus 4995	: V=1.061594, theta=9.387569 -> V=1.0, theta=0.0
% INFO    : Bus 4996	: V=0.966778, theta=18.754357 -> V=1.0, theta=0.0
% INFO    : Bus 4997	: V=1.046062, theta=93.758969 -> V=1.0, theta=0.0
% INFO    : Bus 4998	: V=1.019231, theta=22.327173 -> V=1.0, theta=0.0
% INFO    : Bus 4999	: V=1.002629, theta=28.069895 -> V=1.0, theta=0.0
% INFO    : Bus 5000	: V=1.008736, theta=24.556899 -> V=1.0, theta=0.0
% INFO    : Bus 5001	: V=1.014507, theta=-26.601129 -> V=1.0, theta=0.0
% INFO    : Bus 5002	: V=1.02876, theta=-17.22899 -> V=1.0, theta=0.0
% INFO    : Bus 5003	: V=1.039585, theta=62.096018 -> V=1.0, theta=0.0
% INFO    : Bus 5004	: V=1.007368, theta=14.66858 -> V=1.0, theta=0.0
% INFO    : Bus 5005	: V=1.035825, theta=92.435601 -> V=1.0, theta=0.0
% INFO    : Bus 5006	: V=1.030812, theta=9.540266 -> V=1.0, theta=0.0
% INFO    : Bus 5007	: V=1.035406, theta=21.74444 -> V=1.0, theta=0.0
% INFO    : Bus 5008	: V=1.035406, theta=21.74444 -> V=1.0, theta=0.0
% INFO    : Bus 5009	: V=1.035406, theta=21.74444 -> V=1.0, theta=0.0
% INFO    : Bus 5010	: V=0.989794, theta=-3.083252 -> V=1.0, theta=0.0
% INFO    : Bus 5011	: V=1.029063, theta=15.621241 -> V=1.0, theta=0.0
% INFO    : Bus 5012	: V=1.032132, theta=-3.910762 -> V=1.0, theta=0.0
% INFO    : Bus 5013	: V=1.032132, theta=-3.910762 -> V=1.0, theta=0.0
% INFO    : Bus 5014	: V=1.009216, theta=-1.923247 -> V=1.0, theta=0.0
% INFO    : Bus 5015	: V=1.041524, theta=28.972318 -> V=1.0, theta=0.0
% INFO    : Bus 5016	: V=1.000468, theta=19.917128 -> V=1.0, theta=0.0
% INFO    : Bus 5017	: V=1.032238, theta=-4.146012 -> V=1.0, theta=0.0
% INFO    : Bus 5018	: V=1.032238, theta=-4.146012 -> V=1.0, theta=0.0
% INFO    : Bus 5019	: V=1.059485, theta=4.79611 -> V=1.0, theta=0.0
% INFO    : Bus 5020	: V=1.057905, theta=7.307607 -> V=1.0, theta=0.0
% INFO    : Bus 5021	: V=1.016921, theta=-26.232106 -> V=1.0, theta=0.0
% INFO    : Bus 5022	: V=1.003914, theta=29.484531 -> V=1.0, theta=0.0
% INFO    : Bus 5023	: V=1.052394, theta=33.692026 -> V=1.0, theta=0.0
% INFO    : Bus 5024	: V=0.98053, theta=-5.939116 -> V=1.0, theta=0.0
% INFO    : Bus 5025	: V=1.050987, theta=40.998977 -> V=1.0, theta=0.0
% INFO    : Bus 5026	: V=0.993198, theta=26.13824 -> V=1.0, theta=0.0
% INFO    : Bus 5027	: V=1.043019, theta=20.310505 -> V=1.0, theta=0.0
% INFO    : Bus 5028	: V=1.034668, theta=17.194328 -> V=1.0, theta=0.0
% INFO    : Bus 5029	: V=1.005112, theta=-1.198328 -> V=1.0, theta=0.0
% INFO    : Bus 5030	: V=1.021232, theta=26.399346 -> V=1.0, theta=0.0
% INFO    : Bus 5031	: V=1.038979, theta=-13.937788 -> V=1.0, theta=0.0
% INFO    : Bus 5032	: V=1.032656, theta=9.024375 -> V=1.0, theta=0.0
% INFO    : Bus 5033	: V=0.956433, theta=1.124618 -> V=1.0, theta=0.0
% INFO    : Bus 5034	: V=1.019932, theta=23.482162 -> V=1.0, theta=0.0
% INFO    : Bus 5035	: V=0.949685, theta=-7.51879 -> V=1.0, theta=0.0
% INFO    : Bus 5036	: V=1.038011, theta=31.920163 -> V=1.0, theta=0.0
% INFO    : Bus 5037	: V=1.030988, theta=2.394145 -> V=1.0, theta=0.0
% INFO    : Bus 5038	: V=1.043059, theta=9.285297 -> V=1.0, theta=0.0
% INFO    : Bus 5039	: V=1.032774, theta=20.844648 -> V=1.0, theta=0.0
% INFO    : Bus 5040	: V=1.03749, theta=-6.683276 -> V=1.0, theta=0.0
% INFO    : Bus 5041	: V=1.019746, theta=-12.030982 -> V=1.0, theta=0.0
% INFO    : Bus 5042	: V=1.018079, theta=-13.446069 -> V=1.0, theta=0.0
% INFO    : Bus 5043	: V=0.994733, theta=38.659408 -> V=1.0, theta=0.0
% INFO    : Bus 5044	: V=1.031478, theta=18.798826 -> V=1.0, theta=0.0
% INFO    : Bus 5045	: V=1.047292, theta=-2.403002 -> V=1.0, theta=0.0
% INFO    : Bus 5046	: V=1.033166, theta=16.613981 -> V=1.0, theta=0.0
% INFO    : Bus 5047	: V=1.020262, theta=-10.694863 -> V=1.0, theta=0.0
% INFO    : Bus 5048	: V=1.019623, theta=31.518845 -> V=1.0, theta=0.0
% INFO    : Bus 5049	: V=1.017537, theta=36.998934 -> V=1.0, theta=0.0
% INFO    : Bus 5050	: V=0.987146, theta=20.677409 -> V=1.0, theta=0.0
% INFO    : Bus 5051	: V=1.035412, theta=11.75856 -> V=1.0, theta=0.0
% INFO    : Bus 5052	: V=1.035412, theta=11.75856 -> V=1.0, theta=0.0
% INFO    : Bus 5053	: V=1.035412, theta=11.75856 -> V=1.0, theta=0.0
% INFO    : Bus 5054	: V=1.05667, theta=-2.722877 -> V=1.0, theta=0.0
% INFO    : Bus 5055	: V=1.05667, theta=-2.722877 -> V=1.0, theta=0.0
% INFO    : Bus 5056	: V=1.05667, theta=-2.722877 -> V=1.0, theta=0.0
% INFO    : Bus 5057	: V=1.05667, theta=-2.722877 -> V=1.0, theta=0.0
% INFO    : Bus 5058	: V=1.049254, theta=8.363188 -> V=1.0, theta=0.0
% INFO    : Bus 5059	: V=1.083018, theta=11.899545 -> V=1.0, theta=0.0
% INFO    : Bus 5060	: V=1.083018, theta=11.899545 -> V=1.0, theta=0.0
% INFO    : Bus 5061	: V=0.994858, theta=32.812983 -> V=1.0, theta=0.0
% INFO    : Bus 5062	: V=1.056742, theta=8.416383 -> V=1.0, theta=0.0
% INFO    : Bus 5063	: V=1.056742, theta=8.416383 -> V=1.0, theta=0.0
% INFO    : Bus 5064	: V=1.056742, theta=8.416383 -> V=1.0, theta=0.0
% INFO    : Bus 5065	: V=1.049254, theta=8.363188 -> V=1.0, theta=0.0
% INFO    : Bus 5066	: V=1.000777, theta=-7.436122 -> V=1.0, theta=0.0
% INFO    : Bus 5067	: V=1.019774, theta=-9.023427 -> V=1.0, theta=0.0
% INFO    : Bus 5068	: V=0.998339, theta=6.169569 -> V=1.0, theta=0.0
% INFO    : Bus 5069	: V=0.995797, theta=13.295176 -> V=1.0, theta=0.0
% INFO    : Bus 5070	: V=0.999202, theta=27.044594 -> V=1.0, theta=0.0
% INFO    : Bus 5071	: V=0.995797, theta=13.295176 -> V=1.0, theta=0.0
% INFO    : Bus 5072	: V=0.995797, theta=13.295176 -> V=1.0, theta=0.0
% INFO    : Bus 5073	: V=0.995797, theta=13.295176 -> V=1.0, theta=0.0
% INFO    : Bus 5074	: V=0.995797, theta=13.295176 -> V=1.0, theta=0.0
% INFO    : Bus 5075	: V=1.015605, theta=-7.523526 -> V=1.0, theta=0.0
% INFO    : Bus 5076	: V=1.049756, theta=20.130595 -> V=1.0, theta=0.0
% INFO    : Bus 5077	: V=1.049756, theta=20.130595 -> V=1.0, theta=0.0
% INFO    : Bus 5078	: V=1.049756, theta=20.130595 -> V=1.0, theta=0.0
% INFO    : Bus 5079	: V=0.997034, theta=-2.86835 -> V=1.0, theta=0.0
% INFO    : Bus 5080	: V=1.020965, theta=-7.890322 -> V=1.0, theta=0.0
% INFO    : Bus 5081	: V=1.045031, theta=-0.976333 -> V=1.0, theta=0.0
% INFO    : Bus 5082	: V=1.029323, theta=-7.468239 -> V=1.0, theta=0.0
% INFO    : Bus 5083	: V=1.003491, theta=-10.282006 -> V=1.0, theta=0.0
% INFO    : Bus 5084	: V=1.06339, theta=20.87235 -> V=1.0, theta=0.0
% INFO    : Bus 5085	: V=1.041566, theta=-8.637491 -> V=1.0, theta=0.0
% INFO    : Bus 5086	: V=1.041566, theta=-8.637491 -> V=1.0, theta=0.0
% INFO    : Bus 5087	: V=1.023477, theta=-4.753253 -> V=1.0, theta=0.0
% INFO    : Bus 5088	: V=0.95519, theta=43.97653 -> V=1.0, theta=0.0
% INFO    : Bus 5089	: V=1.039883, theta=-8.632286 -> V=1.0, theta=0.0
% INFO    : Bus 5090	: V=1.039883, theta=-8.632286 -> V=1.0, theta=0.0
% INFO    : Bus 5091	: V=1.041566, theta=-8.637491 -> V=1.0, theta=0.0
% INFO    : Bus 5092	: V=1.041566, theta=-8.637491 -> V=1.0, theta=0.0
% INFO    : Bus 5093	: V=0.987249, theta=-1.003496 -> V=1.0, theta=0.0
% INFO    : Bus 5094	: V=0.997504, theta=-17.119751 -> V=1.0, theta=0.0
% INFO    : Bus 5095	: V=0.990391, theta=33.947064 -> V=1.0, theta=0.0
% INFO    : Bus 5096	: V=1.028111, theta=19.436473 -> V=1.0, theta=0.0
% INFO    : Bus 5097	: V=1.020692, theta=9.229442 -> V=1.0, theta=0.0
% INFO    : Bus 5098	: V=0.964149, theta=-15.086645 -> V=1.0, theta=0.0
% INFO    : Bus 5099	: V=1.015374, theta=8.632692 -> V=1.0, theta=0.0
% INFO    : Bus 5100	: V=1.019657, theta=-9.251983 -> V=1.0, theta=0.0
% INFO    : Bus 5101	: V=1.031272, theta=39.234703 -> V=1.0, theta=0.0
% INFO    : Bus 5102	: V=0.980589, theta=1.375059 -> V=1.0, theta=0.0
% INFO    : Bus 5103	: V=1.018365, theta=-12.87646 -> V=1.0, theta=0.0
% INFO    : Bus 5104	: V=0.996198, theta=-5.152317 -> V=1.0, theta=0.0
% INFO    : Bus 5105	: V=1.027523, theta=18.894424 -> V=1.0, theta=0.0
% INFO    : Bus 5106	: V=1.005261, theta=28.683345 -> V=1.0, theta=0.0
% INFO    : Bus 5107	: V=1.015718, theta=-26.178986 -> V=1.0, theta=0.0
% INFO    : Bus 5108	: V=0.982029, theta=-11.79148 -> V=1.0, theta=0.0
% INFO    : Bus 5109	: V=1.048748, theta=7.516157 -> V=1.0, theta=0.0
% INFO    : Bus 5110	: V=0.997358, theta=-13.357973 -> V=1.0, theta=0.0
% INFO    : Bus 5111	: V=0.996117, theta=32.042491 -> V=1.0, theta=0.0
% INFO    : Bus 5112	: V=1.032187, theta=20.798472 -> V=1.0, theta=0.0
% INFO    : Bus 5113	: V=0.985135, theta=-2.653308 -> V=1.0, theta=0.0
% INFO    : Bus 5114	: V=1.036024, theta=25.906454 -> V=1.0, theta=0.0
% INFO    : Bus 5115	: V=1.027659, theta=8.695729 -> V=1.0, theta=0.0
% INFO    : Bus 5116	: V=1.013887, theta=22.6309 -> V=1.0, theta=0.0
% INFO    : Bus 5117	: V=1.123141, theta=-2.325257 -> V=1.0, theta=0.0
% INFO    : Bus 5118	: V=1.030789, theta=9.190472 -> V=1.0, theta=0.0
% INFO    : Bus 5119	: V=1.028814, theta=31.142822 -> V=1.0, theta=0.0
% INFO    : Bus 5120	: V=1.041517, theta=19.441981 -> V=1.0, theta=0.0
% INFO    : Bus 5121	: V=1.024166, theta=5.104934 -> V=1.0, theta=0.0
% INFO    : Bus 5122	: V=1.030744, theta=-0.382174 -> V=1.0, theta=0.0
% INFO    : Bus 5123	: V=1.043216, theta=17.315526 -> V=1.0, theta=0.0
% INFO    : Bus 5124	: V=1.017243, theta=-25.297769 -> V=1.0, theta=0.0
% INFO    : Bus 5125	: V=1.069866, theta=58.675575 -> V=1.0, theta=0.0
% INFO    : Bus 5126	: V=1.045141, theta=25.131975 -> V=1.0, theta=0.0
% INFO    : Bus 5127	: V=1.045141, theta=25.131975 -> V=1.0, theta=0.0
% INFO    : Bus 5128	: V=1.030744, theta=-0.382174 -> V=1.0, theta=0.0
% INFO    : Bus 5129	: V=1.030744, theta=-0.382174 -> V=1.0, theta=0.0
% INFO    : Bus 5130	: V=1.030744, theta=-0.382174 -> V=1.0, theta=0.0
% INFO    : Bus 5131	: V=1.030744, theta=-0.382174 -> V=1.0, theta=0.0
% INFO    : Bus 5132	: V=1.031995, theta=18.369092 -> V=1.0, theta=0.0
% INFO    : Bus 5133	: V=1.030744, theta=-0.382174 -> V=1.0, theta=0.0
% INFO    : Bus 5134	: V=1.035888, theta=21.491029 -> V=1.0, theta=0.0
% INFO    : Bus 5135	: V=1.026027, theta=-7.002651 -> V=1.0, theta=0.0
% INFO    : Bus 5136	: V=1.006075, theta=9.474182 -> V=1.0, theta=0.0
% INFO    : Bus 5137	: V=1.015209, theta=24.887597 -> V=1.0, theta=0.0
% INFO    : Bus 5138	: V=1.024572, theta=-13.995277 -> V=1.0, theta=0.0
% INFO    : Bus 5139	: V=0.995796, theta=-3.341236 -> V=1.0, theta=0.0
% INFO    : Bus 5140	: V=1.039721, theta=3.497796 -> V=1.0, theta=0.0
% INFO    : Bus 5141	: V=1.023365, theta=36.901836 -> V=1.0, theta=0.0
% INFO    : Bus 5142	: V=1.07771, theta=2.6181 -> V=1.0, theta=0.0
% INFO    : Bus 5143	: V=1.033735, theta=-14.68008 -> V=1.0, theta=0.0
% INFO    : Bus 5144	: V=1.017192, theta=-7.434926 -> V=1.0, theta=0.0
% INFO    : Bus 5145	: V=1.01785, theta=-2.67748 -> V=1.0, theta=0.0
% INFO    : Bus 5146	: V=1.01785, theta=-2.67748 -> V=1.0, theta=0.0
% INFO    : Bus 5147	: V=1.01785, theta=-2.67748 -> V=1.0, theta=0.0
% INFO    : Bus 5148	: V=1.024966, theta=-4.448719 -> V=1.0, theta=0.0
% INFO    : Bus 5149	: V=1.007011, theta=-25.858855 -> V=1.0, theta=0.0
% INFO    : Bus 5150	: V=1.006731, theta=25.484118 -> V=1.0, theta=0.0
% INFO    : Bus 5151	: V=1.015505, theta=-3.112218 -> V=1.0, theta=0.0
% INFO    : Bus 5152	: V=1.073042, theta=71.1915 -> V=1.0, theta=0.0
% INFO    : Bus 5153	: V=1.007003, theta=25.797244 -> V=1.0, theta=0.0
% INFO    : Bus 5154	: V=1.0811, theta=64.133926 -> V=1.0, theta=0.0
% INFO    : Bus 5155	: V=1.044772, theta=4.847391 -> V=1.0, theta=0.0
% INFO    : Bus 5156	: V=1.064971, theta=0.399978 -> V=1.0, theta=0.0
% INFO    : Bus 5157	: V=1.055228, theta=32.49598 -> V=1.0, theta=0.0
% INFO    : Bus 5158	: V=0.98522, theta=42.733784 -> V=1.0, theta=0.0
% INFO    : Bus 5159	: V=1.033735, theta=-14.68008 -> V=1.0, theta=0.0
% INFO    : Bus 5160	: V=1.037151, theta=6.605163 -> V=1.0, theta=0.0
% INFO    : Bus 5161	: V=1.016177, theta=-5.241408 -> V=1.0, theta=0.0
% INFO    : Bus 5162	: V=1.008964, theta=6.659925 -> V=1.0, theta=0.0
% INFO    : Bus 5163	: V=1.033735, theta=-14.68008 -> V=1.0, theta=0.0
% INFO    : Bus 5164	: V=1.040039, theta=-14.484778 -> V=1.0, theta=0.0
% INFO    : Bus 5165	: V=1.040039, theta=-14.484778 -> V=1.0, theta=0.0
% INFO    : Bus 5166	: V=1.017024, theta=16.872664 -> V=1.0, theta=0.0
% INFO    : Bus 5167	: V=1.040039, theta=-14.484778 -> V=1.0, theta=0.0
% INFO    : Bus 5168	: V=1.017812, theta=-14.560212 -> V=1.0, theta=0.0
% INFO    : Bus 5169	: V=1.040788, theta=-10.098416 -> V=1.0, theta=0.0
% INFO    : Bus 5170	: V=1.017812, theta=-14.560212 -> V=1.0, theta=0.0
% INFO    : Bus 5171	: V=1.017812, theta=-14.560212 -> V=1.0, theta=0.0
% INFO    : Bus 5172	: V=1.027506, theta=-4.211385 -> V=1.0, theta=0.0
% INFO    : Bus 5173	: V=1.016815, theta=92.165392 -> V=1.0, theta=0.0
% INFO    : Bus 5174	: V=1.052139, theta=28.580107 -> V=1.0, theta=0.0
% INFO    : Bus 5175	: V=0.98591, theta=-3.871199 -> V=1.0, theta=0.0
% INFO    : Bus 5176	: V=1.052015, theta=-6.377282 -> V=1.0, theta=0.0
% INFO    : Bus 5177	: V=1.023095, theta=-15.63004 -> V=1.0, theta=0.0
% INFO    : Bus 5178	: V=1.023095, theta=-15.63004 -> V=1.0, theta=0.0
% INFO    : Bus 5179	: V=1.031323, theta=8.512702 -> V=1.0, theta=0.0
% INFO    : Bus 5180	: V=0.986332, theta=25.334582 -> V=1.0, theta=0.0
% INFO    : Bus 5181	: V=1.027796, theta=-1.101464 -> V=1.0, theta=0.0
% INFO    : Bus 5182	: V=0.925713, theta=-12.097092 -> V=1.0, theta=0.0
% INFO    : Bus 5183	: V=1.068162, theta=14.967776 -> V=1.0, theta=0.0
% INFO    : Bus 5184	: V=1.044865, theta=-2.820297 -> V=1.0, theta=0.0
% INFO    : Bus 5185	: V=1.025971, theta=5.864981 -> V=1.0, theta=0.0
% INFO    : Bus 5186	: V=1.039505, theta=-2.381498 -> V=1.0, theta=0.0
% INFO    : Bus 5187	: V=1.021005, theta=21.987746 -> V=1.0, theta=0.0
% INFO    : Bus 5188	: V=1.036966, theta=15.051213 -> V=1.0, theta=0.0
% INFO    : Bus 5189	: V=1.015752, theta=49.476558 -> V=1.0, theta=0.0
% INFO    : Bus 5190	: V=1.019429, theta=16.445362 -> V=1.0, theta=0.0
% INFO    : Bus 5191	: V=0.999899, theta=-3.041462 -> V=1.0, theta=0.0
% INFO    : Bus 5192	: V=1.044001, theta=-0.389429 -> V=1.0, theta=0.0
% INFO    : Bus 5193	: V=0.979776, theta=-5.820604 -> V=1.0, theta=0.0
% INFO    : Bus 5194	: V=1.029423, theta=6.341302 -> V=1.0, theta=0.0
% INFO    : Bus 5195	: V=0.994848, theta=33.393544 -> V=1.0, theta=0.0
% INFO    : Bus 5196	: V=1.028002, theta=7.184716 -> V=1.0, theta=0.0
% INFO    : Bus 5197	: V=0.98388, theta=13.009881 -> V=1.0, theta=0.0
% INFO    : Bus 5198	: V=1.040272, theta=-16.192477 -> V=1.0, theta=0.0
% INFO    : Bus 5199	: V=0.979851, theta=-8.587269 -> V=1.0, theta=0.0
% INFO    : Bus 5200	: V=1.02816, theta=16.70904 -> V=1.0, theta=0.0
% INFO    : Bus 5201	: V=1.040106, theta=-14.883171 -> V=1.0, theta=0.0
% INFO    : Bus 5202	: V=0.99834, theta=24.249316 -> V=1.0, theta=0.0
% INFO    : Bus 5203	: V=1.040622, theta=20.300906 -> V=1.0, theta=0.0
% INFO    : Bus 5204	: V=1.019678, theta=-23.024367 -> V=1.0, theta=0.0
% INFO    : Bus 5205	: V=0.981836, theta=1.606593 -> V=1.0, theta=0.0
% INFO    : Bus 5206	: V=1.01681, theta=-14.76301 -> V=1.0, theta=0.0
% INFO    : Bus 5207	: V=1.047444, theta=6.684923 -> V=1.0, theta=0.0
% INFO    : Bus 5208	: V=1.047444, theta=6.684923 -> V=1.0, theta=0.0
% INFO    : Bus 5209	: V=1.036607, theta=7.408678 -> V=1.0, theta=0.0
% INFO    : Bus 5210	: V=1.029935, theta=1.106697 -> V=1.0, theta=0.0
% INFO    : Bus 5211	: V=1.023026, theta=30.671726 -> V=1.0, theta=0.0
% INFO    : Bus 5212	: V=1.021725, theta=-10.876959 -> V=1.0, theta=0.0
% INFO    : Bus 5213	: V=1.019792, theta=-15.494313 -> V=1.0, theta=0.0
% INFO    : Bus 5214	: V=1.024726, theta=45.414901 -> V=1.0, theta=0.0
% INFO    : Bus 5215	: V=1.019792, theta=-15.494313 -> V=1.0, theta=0.0
% INFO    : Bus 5216	: V=1.019792, theta=-15.494313 -> V=1.0, theta=0.0
% INFO    : Bus 5217	: V=0.994437, theta=15.297275 -> V=1.0, theta=0.0
% INFO    : Bus 5218	: V=1.020144, theta=-4.540428 -> V=1.0, theta=0.0
% INFO    : Bus 5219	: V=1.009761, theta=-21.023168 -> V=1.0, theta=0.0
% INFO    : Bus 5220	: V=0.988915, theta=-3.063974 -> V=1.0, theta=0.0
% INFO    : Bus 5221	: V=0.97237, theta=-6.977885 -> V=1.0, theta=0.0
% INFO    : Bus 5222	: V=1.047099, theta=32.217182 -> V=1.0, theta=0.0
% INFO    : Bus 5223	: V=1.054235, theta=39.510254 -> V=1.0, theta=0.0
% INFO    : Bus 5224	: V=0.99685, theta=-7.213455 -> V=1.0, theta=0.0
% INFO    : Bus 5225	: V=1.037142, theta=24.334502 -> V=1.0, theta=0.0
% INFO    : Bus 5226	: V=1.037142, theta=24.334502 -> V=1.0, theta=0.0
% INFO    : Bus 5227	: V=1.013023, theta=31.438752 -> V=1.0, theta=0.0
% INFO    : Bus 5228	: V=1.037142, theta=24.334502 -> V=1.0, theta=0.0
% INFO    : Bus 5229	: V=1.037142, theta=24.334502 -> V=1.0, theta=0.0
% INFO    : Bus 5230	: V=1.021677, theta=7.174807 -> V=1.0, theta=0.0
% INFO    : Bus 5231	: V=0.929626, theta=-8.481962 -> V=1.0, theta=0.0
% INFO    : Bus 5232	: V=1.012195, theta=-6.68477 -> V=1.0, theta=0.0
% INFO    : Bus 5233	: V=1.019848, theta=22.321936 -> V=1.0, theta=0.0
% INFO    : Bus 5234	: V=1.078665, theta=3.17763 -> V=1.0, theta=0.0
% INFO    : Bus 5235	: V=0.951897, theta=-5.655079 -> V=1.0, theta=0.0
% INFO    : Bus 5236	: V=1.018217, theta=0.541576 -> V=1.0, theta=0.0
% INFO    : Bus 5237	: V=1.012824, theta=28.22011 -> V=1.0, theta=0.0
% INFO    : Bus 5238	: V=1.024109, theta=7.923737 -> V=1.0, theta=0.0
% INFO    : Bus 5239	: V=1.027323, theta=-4.289105 -> V=1.0, theta=0.0
% INFO    : Bus 5240	: V=0.988395, theta=-21.929683 -> V=1.0, theta=0.0
% INFO    : Bus 5241	: V=0.986972, theta=4.191813 -> V=1.0, theta=0.0
% INFO    : Bus 5242	: V=1.022616, theta=65.87032 -> V=1.0, theta=0.0
% INFO    : Bus 5243	: V=1.003094, theta=94.404188 -> V=1.0, theta=0.0
% INFO    : Bus 5244	: V=0.981817, theta=-5.453509 -> V=1.0, theta=0.0
% INFO    : Bus 5245	: V=0.993793, theta=93.000413 -> V=1.0, theta=0.0
% INFO    : Bus 5246	: V=1.022616, theta=65.87032 -> V=1.0, theta=0.0
% INFO    : Bus 5247	: V=1.024461, theta=-4.101161 -> V=1.0, theta=0.0
% INFO    : Bus 5248	: V=1.000505, theta=-2.078746 -> V=1.0, theta=0.0
% INFO    : Bus 5249	: V=1.028566, theta=25.71228 -> V=1.0, theta=0.0
% INFO    : Bus 5250	: V=1.024655, theta=48.619208 -> V=1.0, theta=0.0
% INFO    : Bus 5251	: V=1.030893, theta=-12.424281 -> V=1.0, theta=0.0
% INFO    : Bus 5252	: V=1.017273, theta=-4.353956 -> V=1.0, theta=0.0
% INFO    : Bus 5253	: V=1.047882, theta=-4.305097 -> V=1.0, theta=0.0
% INFO    : Bus 5254	: V=1.024094, theta=0.934183 -> V=1.0, theta=0.0
% INFO    : Bus 5255	: V=0.959894, theta=-10.038785 -> V=1.0, theta=0.0
% INFO    : Bus 5256	: V=1.014605, theta=-21.99726 -> V=1.0, theta=0.0
% INFO    : Bus 5257	: V=1.02887, theta=49.205594 -> V=1.0, theta=0.0
% INFO    : Bus 5258	: V=1.009593, theta=-17.836874 -> V=1.0, theta=0.0
% INFO    : Bus 5259	: V=0.996526, theta=-17.372997 -> V=1.0, theta=0.0
% INFO    : Bus 5260	: V=1.028088, theta=-13.031645 -> V=1.0, theta=0.0
% INFO    : Bus 5261	: V=1.017273, theta=-4.353956 -> V=1.0, theta=0.0
% INFO    : Bus 5262	: V=1.017273, theta=-4.353956 -> V=1.0, theta=0.0
% INFO    : Bus 5263	: V=1.062003, theta=-12.552832 -> V=1.0, theta=0.0
% INFO    : Bus 5264	: V=0.978669, theta=-7.861808 -> V=1.0, theta=0.0
% INFO    : Bus 5265	: V=1.027054, theta=22.947359 -> V=1.0, theta=0.0
% INFO    : Bus 5266	: V=1.013859, theta=18.447376 -> V=1.0, theta=0.0
% INFO    : Bus 5267	: V=0.957532, theta=-11.597741 -> V=1.0, theta=0.0
% INFO    : Bus 5268	: V=0.995085, theta=12.187928 -> V=1.0, theta=0.0
% INFO    : Bus 5269	: V=0.921793, theta=-12.253668 -> V=1.0, theta=0.0
% INFO    : Bus 5270	: V=1.029323, theta=-3.215687 -> V=1.0, theta=0.0
% INFO    : Bus 5271	: V=1.029323, theta=-3.215687 -> V=1.0, theta=0.0
% INFO    : Bus 5272	: V=1.015467, theta=-22.677921 -> V=1.0, theta=0.0
% INFO    : Bus 5273	: V=1.110897, theta=70.705716 -> V=1.0, theta=0.0
% INFO    : Bus 5274	: V=1.023803, theta=-2.474109 -> V=1.0, theta=0.0
% INFO    : Bus 5275	: V=1.023803, theta=-2.474109 -> V=1.0, theta=0.0
% INFO    : Bus 5276	: V=1.023803, theta=-2.474109 -> V=1.0, theta=0.0
% INFO    : Bus 5277	: V=1.023803, theta=-2.474109 -> V=1.0, theta=0.0
% INFO    : Bus 5278	: V=1.029323, theta=-3.215687 -> V=1.0, theta=0.0
% INFO    : Bus 5279	: V=1.029323, theta=-3.215687 -> V=1.0, theta=0.0
% INFO    : Bus 5280	: V=1.029562, theta=10.160061 -> V=1.0, theta=0.0
% INFO    : Bus 5281	: V=0.98306, theta=43.226184 -> V=1.0, theta=0.0
% INFO    : Bus 5282	: V=1.038028, theta=5.797119 -> V=1.0, theta=0.0
% INFO    : Bus 5283	: V=1.000423, theta=5.18281 -> V=1.0, theta=0.0
% INFO    : Bus 5284	: V=1.025331, theta=0.441857 -> V=1.0, theta=0.0
% INFO    : Bus 5285	: V=1.029928, theta=-21.084434 -> V=1.0, theta=0.0
% INFO    : Bus 5286	: V=1.023526, theta=23.555243 -> V=1.0, theta=0.0
% INFO    : Bus 5287	: V=1.023526, theta=23.555243 -> V=1.0, theta=0.0
% INFO    : Bus 5288	: V=1.015912, theta=22.790588 -> V=1.0, theta=0.0
% INFO    : Bus 5289	: V=1.00746, theta=39.171104 -> V=1.0, theta=0.0
% INFO    : Bus 5290	: V=1.045177, theta=-4.513312 -> V=1.0, theta=0.0
% INFO    : Bus 5291	: V=1.028189, theta=8.896679 -> V=1.0, theta=0.0
% INFO    : Bus 5292	: V=1.050901, theta=18.201002 -> V=1.0, theta=0.0
% INFO    : Bus 5293	: V=1.029206, theta=11.095284 -> V=1.0, theta=0.0
% INFO    : Bus 5294	: V=1.057852, theta=-6.001761 -> V=1.0, theta=0.0
% INFO    : Bus 5295	: V=1.039938, theta=4.268956 -> V=1.0, theta=0.0
% INFO    : Bus 5296	: V=1.028062, theta=-8.182777 -> V=1.0, theta=0.0
% INFO    : Bus 5297	: V=1.11636, theta=70.15342 -> V=1.0, theta=0.0
% INFO    : Bus 5298	: V=1.042365, theta=38.732833 -> V=1.0, theta=0.0
% INFO    : Bus 5299	: V=0.96454, theta=-13.395209 -> V=1.0, theta=0.0
% INFO    : Bus 5300	: V=1.058631, theta=17.901103 -> V=1.0, theta=0.0
% INFO    : Bus 5301	: V=1.021316, theta=-4.288887 -> V=1.0, theta=0.0
% INFO    : Bus 5302	: V=1.017834, theta=1.692627 -> V=1.0, theta=0.0
% INFO    : Bus 5303	: V=1.024054, theta=-16.964783 -> V=1.0, theta=0.0
% INFO    : Bus 5304	: V=1.024054, theta=-16.964783 -> V=1.0, theta=0.0
% INFO    : Bus 5305	: V=1.03032, theta=28.518041 -> V=1.0, theta=0.0
% INFO    : Bus 5306	: V=1.03032, theta=28.518041 -> V=1.0, theta=0.0
% INFO    : Bus 5307	: V=1.030262, theta=28.566856 -> V=1.0, theta=0.0
% INFO    : Bus 5308	: V=1.030262, theta=28.566856 -> V=1.0, theta=0.0
% INFO    : Bus 5309	: V=1.033768, theta=-2.92291 -> V=1.0, theta=0.0
% INFO    : Bus 5310	: V=1.033768, theta=-2.92291 -> V=1.0, theta=0.0
% INFO    : Bus 5311	: V=1.057062, theta=4.322623 -> V=1.0, theta=0.0
% INFO    : Bus 5312	: V=1.02263, theta=10.160081 -> V=1.0, theta=0.0
% INFO    : Bus 5313	: V=1.023815, theta=28.570167 -> V=1.0, theta=0.0
% INFO    : Bus 5314	: V=0.984098, theta=4.477364 -> V=1.0, theta=0.0
% INFO    : Bus 5315	: V=0.990143, theta=1.402472 -> V=1.0, theta=0.0
% INFO    : Bus 5316	: V=1.002922, theta=32.371982 -> V=1.0, theta=0.0
% INFO    : Bus 5317	: V=1.034048, theta=-9.733404 -> V=1.0, theta=0.0
% INFO    : Bus 5318	: V=0.965112, theta=-4.13419 -> V=1.0, theta=0.0
% INFO    : Bus 5319	: V=1.071081, theta=3.910791 -> V=1.0, theta=0.0
% INFO    : Bus 5320	: V=0.999808, theta=-10.542975 -> V=1.0, theta=0.0
% INFO    : Bus 5321	: V=1.023031, theta=24.952149 -> V=1.0, theta=0.0
% INFO    : Bus 5322	: V=0.99879, theta=3.61899 -> V=1.0, theta=0.0
% INFO    : Bus 5323	: V=1.011203, theta=-2.333775 -> V=1.0, theta=0.0
% INFO    : Bus 5324	: V=1.011203, theta=-2.333775 -> V=1.0, theta=0.0
% INFO    : Bus 5325	: V=1.011203, theta=-2.333775 -> V=1.0, theta=0.0
% INFO    : Bus 5326	: V=1.011203, theta=-2.333775 -> V=1.0, theta=0.0
% INFO    : Bus 5327	: V=1.011203, theta=-2.333775 -> V=1.0, theta=0.0
% INFO    : Bus 5328	: V=1.011203, theta=-2.333775 -> V=1.0, theta=0.0
% INFO    : Bus 5329	: V=1.056832, theta=2.726838 -> V=1.0, theta=0.0
% INFO    : Bus 5330	: V=1.029009, theta=32.575777 -> V=1.0, theta=0.0
% INFO    : Bus 5331	: V=1.019753, theta=-24.135214 -> V=1.0, theta=0.0
% INFO    : Bus 5332	: V=1.028002, theta=7.184716 -> V=1.0, theta=0.0
% INFO    : Bus 5333	: V=1.03063, theta=1.723631 -> V=1.0, theta=0.0
% INFO    : Bus 5334	: V=1.02129, theta=29.063688 -> V=1.0, theta=0.0
% INFO    : Bus 5335	: V=1.033768, theta=14.596978 -> V=1.0, theta=0.0
% INFO    : Bus 5336	: V=1.015825, theta=-25.064254 -> V=1.0, theta=0.0
% INFO    : Bus 5337	: V=1.026869, theta=30.816332 -> V=1.0, theta=0.0
% INFO    : Bus 5338	: V=1.067711, theta=-6.48805 -> V=1.0, theta=0.0
% INFO    : Bus 5339	: V=1.025694, theta=-6.021941 -> V=1.0, theta=0.0
% INFO    : Bus 5340	: V=1.001756, theta=-10.041769 -> V=1.0, theta=0.0
% INFO    : Bus 5341	: V=1.065506, theta=1.014062 -> V=1.0, theta=0.0
% INFO    : Bus 5342	: V=1.019736, theta=17.906487 -> V=1.0, theta=0.0
% INFO    : Bus 5343	: V=1.000957, theta=10.706535 -> V=1.0, theta=0.0
% INFO    : Bus 5344	: V=1.051774, theta=91.644565 -> V=1.0, theta=0.0
% INFO    : Bus 5345	: V=1.035666, theta=-7.386962 -> V=1.0, theta=0.0
% INFO    : Bus 5346	: V=1.011158, theta=-5.202412 -> V=1.0, theta=0.0
% INFO    : Bus 5347	: V=1.043665, theta=14.930439 -> V=1.0, theta=0.0
% INFO    : Bus 5348	: V=0.993916, theta=5.014657 -> V=1.0, theta=0.0
% INFO    : Bus 5349	: V=1.005644, theta=-16.679897 -> V=1.0, theta=0.0
% INFO    : Bus 5350	: V=1.021475, theta=28.018024 -> V=1.0, theta=0.0
% INFO    : Bus 5351	: V=0.952457, theta=-5.260666 -> V=1.0, theta=0.0
% INFO    : Bus 5352	: V=1.007679, theta=-4.961668 -> V=1.0, theta=0.0
% INFO    : Bus 5353	: V=1.053771, theta=81.870655 -> V=1.0, theta=0.0
% INFO    : Bus 5354	: V=1.039621, theta=10.691121 -> V=1.0, theta=0.0
% INFO    : Bus 5355	: V=1.084788, theta=-3.606185 -> V=1.0, theta=0.0
% INFO    : Bus 5356	: V=1.041223, theta=4.865379 -> V=1.0, theta=0.0
% INFO    : Bus 5357	: V=1.016884, theta=-1.962084 -> V=1.0, theta=0.0
% INFO    : Bus 5358	: V=1.030402, theta=-27.749342 -> V=1.0, theta=0.0
% INFO    : Bus 5359	: V=1.054892, theta=7.069138 -> V=1.0, theta=0.0
% INFO    : Bus 5360	: V=1.023166, theta=4.463602 -> V=1.0, theta=0.0
% INFO    : Bus 5361	: V=1.023166, theta=4.463602 -> V=1.0, theta=0.0
% INFO    : Bus 5362	: V=1.023166, theta=4.463602 -> V=1.0, theta=0.0
% INFO    : Bus 5363	: V=0.979016, theta=44.462885 -> V=1.0, theta=0.0
% INFO    : Bus 5364	: V=1.017741, theta=41.666685 -> V=1.0, theta=0.0
% INFO    : Bus 5365	: V=1.03611, theta=8.921216 -> V=1.0, theta=0.0
% INFO    : Bus 5366	: V=1.03611, theta=8.921216 -> V=1.0, theta=0.0
% INFO    : Bus 5367	: V=1.010305, theta=12.204616 -> V=1.0, theta=0.0
% INFO    : Bus 5368	: V=1.023161, theta=-12.168584 -> V=1.0, theta=0.0
% INFO    : Bus 5369	: V=1.023161, theta=-12.168584 -> V=1.0, theta=0.0
% INFO    : Bus 5370	: V=1.023161, theta=-12.168584 -> V=1.0, theta=0.0
% INFO    : Bus 5371	: V=1.023161, theta=-12.168584 -> V=1.0, theta=0.0
% INFO    : Bus 5372	: V=1.038719, theta=-0.876477 -> V=1.0, theta=0.0
% INFO    : Bus 5373	: V=1.072551, theta=-2.385083 -> V=1.0, theta=0.0
% INFO    : Bus 5374	: V=1.012325, theta=4.838884 -> V=1.0, theta=0.0
% INFO    : Bus 5375	: V=1.061002, theta=18.625585 -> V=1.0, theta=0.0
% INFO    : Bus 5376	: V=1.005051, theta=-5.039137 -> V=1.0, theta=0.0
% INFO    : Bus 5377	: V=1.019643, theta=-16.147917 -> V=1.0, theta=0.0
% INFO    : Bus 5378	: V=1.011669, theta=-5.415058 -> V=1.0, theta=0.0
% INFO    : Bus 5379	: V=1.025372, theta=-4.086848 -> V=1.0, theta=0.0
% INFO    : Bus 5380	: V=1.040126, theta=59.677576 -> V=1.0, theta=0.0
% INFO    : Bus 5381	: V=0.98156, theta=-6.430337 -> V=1.0, theta=0.0
% INFO    : Bus 5382	: V=1.019736, theta=17.906487 -> V=1.0, theta=0.0
% INFO    : Bus 5383	: V=1.050924, theta=32.263423 -> V=1.0, theta=0.0
% INFO    : Bus 5384	: V=0.962211, theta=47.074823 -> V=1.0, theta=0.0
% INFO    : Bus 5385	: V=1.018125, theta=-0.191544 -> V=1.0, theta=0.0
% INFO    : Bus 5386	: V=1.009475, theta=-1.839005 -> V=1.0, theta=0.0
% INFO    : Bus 5387	: V=1.021639, theta=-15.781645 -> V=1.0, theta=0.0
% INFO    : Bus 5388	: V=1.033359, theta=20.594354 -> V=1.0, theta=0.0
% INFO    : Bus 5389	: V=1.070228, theta=-0.629475 -> V=1.0, theta=0.0
% INFO    : Bus 5390	: V=1.024683, theta=17.0095 -> V=1.0, theta=0.0
% INFO    : Bus 5391	: V=1.043492, theta=-15.322718 -> V=1.0, theta=0.0
% INFO    : Bus 5392	: V=0.99768, theta=-9.077286 -> V=1.0, theta=0.0
% INFO    : Bus 5393	: V=1.023492, theta=3.369288 -> V=1.0, theta=0.0
% INFO    : Bus 5394	: V=1.00901, theta=29.747481 -> V=1.0, theta=0.0
% INFO    : Bus 5395	: V=1.029146, theta=16.996023 -> V=1.0, theta=0.0
% INFO    : Bus 5396	: V=1.025143, theta=3.709433 -> V=1.0, theta=0.0
% INFO    : Bus 5397	: V=1.01809, theta=15.340169 -> V=1.0, theta=0.0
% INFO    : Bus 5398	: V=1.065863, theta=-4.559857 -> V=1.0, theta=0.0
% INFO    : Bus 5399	: V=1.019678, theta=-23.024367 -> V=1.0, theta=0.0
% INFO    : Bus 5400	: V=1.019678, theta=-23.024367 -> V=1.0, theta=0.0
% INFO    : Bus 5401	: V=1.028342, theta=-18.47093 -> V=1.0, theta=0.0
% INFO    : Bus 5402	: V=1.046795, theta=41.135123 -> V=1.0, theta=0.0
% INFO    : Bus 5403	: V=1.018098, theta=29.808617 -> V=1.0, theta=0.0
% INFO    : Bus 5404	: V=1.03936, theta=34.351848 -> V=1.0, theta=0.0
% INFO    : Bus 5405	: V=1.019678, theta=-23.024367 -> V=1.0, theta=0.0
% INFO    : Bus 5406	: V=1.007636, theta=96.580359 -> V=1.0, theta=0.0
% INFO    : Bus 5407	: V=1.002675, theta=25.619018 -> V=1.0, theta=0.0
% INFO    : Bus 5408	: V=0.996117, theta=32.042491 -> V=1.0, theta=0.0
% INFO    : Bus 5409	: V=1.026365, theta=-15.128429 -> V=1.0, theta=0.0
% INFO    : Bus 5410	: V=1.034682, theta=-7.443278 -> V=1.0, theta=0.0
% INFO    : Bus 5411	: V=0.991559, theta=90.791769 -> V=1.0, theta=0.0
% INFO    : Bus 5412	: V=1.005549, theta=11.254419 -> V=1.0, theta=0.0
% INFO    : Bus 5413	: V=1.042695, theta=35.810054 -> V=1.0, theta=0.0
% INFO    : Bus 5414	: V=1.084115, theta=1.981553 -> V=1.0, theta=0.0
% INFO    : Bus 5415	: V=1.030851, theta=8.542661 -> V=1.0, theta=0.0
% INFO    : Bus 5416	: V=1.024669, theta=12.739456 -> V=1.0, theta=0.0
% INFO    : Bus 5417	: V=0.923632, theta=-8.085026 -> V=1.0, theta=0.0
% INFO    : Bus 5418	: V=0.978998, theta=26.658997 -> V=1.0, theta=0.0
% INFO    : Bus 5419	: V=1.008248, theta=-11.333077 -> V=1.0, theta=0.0
% INFO    : Bus 5420	: V=1.015531, theta=4.163384 -> V=1.0, theta=0.0
% INFO    : Bus 5421	: V=1.048791, theta=17.954078 -> V=1.0, theta=0.0
% INFO    : Bus 5422	: V=0.988176, theta=-11.073965 -> V=1.0, theta=0.0
% INFO    : Bus 5423	: V=1.010477, theta=-20.953094 -> V=1.0, theta=0.0
% INFO    : Bus 5424	: V=0.967393, theta=-6.460925 -> V=1.0, theta=0.0
% INFO    : Bus 5425	: V=0.974289, theta=-7.210672 -> V=1.0, theta=0.0
% INFO    : Bus 5426	: V=0.926207, theta=-12.070366 -> V=1.0, theta=0.0
% INFO    : Bus 5427	: V=0.964213, theta=-6.205379 -> V=1.0, theta=0.0
% INFO    : Bus 5428	: V=1.041265, theta=2.248937 -> V=1.0, theta=0.0
% INFO    : Bus 5429	: V=1.000285, theta=-3.353486 -> V=1.0, theta=0.0
% INFO    : Bus 5430	: V=1.080601, theta=0.695571 -> V=1.0, theta=0.0
% INFO    : Bus 5431	: V=0.936417, theta=-4.834215 -> V=1.0, theta=0.0
% INFO    : Bus 5432	: V=1.001979, theta=-7.828523 -> V=1.0, theta=0.0
% INFO    : Bus 5433	: V=1.017043, theta=-22.798983 -> V=1.0, theta=0.0
% INFO    : Bus 5434	: V=1.007403, theta=-6.121058 -> V=1.0, theta=0.0
% INFO    : Bus 5435	: V=1.033263, theta=-17.887254 -> V=1.0, theta=0.0
% INFO    : Bus 5436	: V=1.023839, theta=-7.475146 -> V=1.0, theta=0.0
% INFO    : Bus 5437	: V=1.033003, theta=38.705858 -> V=1.0, theta=0.0
% INFO    : Bus 5438	: V=1.006737, theta=-14.697123 -> V=1.0, theta=0.0
% INFO    : Bus 5439	: V=1.037973, theta=11.471538 -> V=1.0, theta=0.0
% INFO    : Bus 5440	: V=0.99939, theta=28.980276 -> V=1.0, theta=0.0
% INFO    : Bus 5441	: V=1.008389, theta=18.986342 -> V=1.0, theta=0.0
% INFO    : Bus 5442	: V=1.019446, theta=-6.719975 -> V=1.0, theta=0.0
% INFO    : Bus 5443	: V=1.031638, theta=2.949928 -> V=1.0, theta=0.0
% INFO    : Bus 5444	: V=1.017679, theta=10.590328 -> V=1.0, theta=0.0
% INFO    : Bus 5445	: V=1.030228, theta=9.043792 -> V=1.0, theta=0.0
% INFO    : Bus 5446	: V=1.028368, theta=5.87542 -> V=1.0, theta=0.0
% INFO    : Bus 5447	: V=1.032604, theta=-19.07465 -> V=1.0, theta=0.0
% INFO    : Bus 5448	: V=0.995449, theta=-2.100907 -> V=1.0, theta=0.0
% INFO    : Bus 5449	: V=1.034882, theta=4.848076 -> V=1.0, theta=0.0
% INFO    : Bus 5450	: V=1.038472, theta=4.437466 -> V=1.0, theta=0.0
% INFO    : Bus 5451	: V=1.021105, theta=-0.682824 -> V=1.0, theta=0.0
% INFO    : Bus 5452	: V=1.013387, theta=-2.934412 -> V=1.0, theta=0.0
% INFO    : Bus 5453	: V=0.999883, theta=-7.177022 -> V=1.0, theta=0.0
% INFO    : Bus 5454	: V=1.010163, theta=2.244387 -> V=1.0, theta=0.0
% INFO    : Bus 5455	: V=1.018325, theta=9.145355 -> V=1.0, theta=0.0
% INFO    : Bus 5456	: V=1.009683, theta=1.076815 -> V=1.0, theta=0.0
% INFO    : Bus 5457	: V=1.023874, theta=-12.218924 -> V=1.0, theta=0.0
% INFO    : Bus 5458	: V=0.999498, theta=29.48892 -> V=1.0, theta=0.0
% INFO    : Bus 5459	: V=1.017517, theta=24.916531 -> V=1.0, theta=0.0
% INFO    : Bus 5460	: V=1.025654, theta=-0.361056 -> V=1.0, theta=0.0
% INFO    : Bus 5461	: V=0.994387, theta=-11.289887 -> V=1.0, theta=0.0
% INFO    : Bus 5462	: V=1.007118, theta=30.130445 -> V=1.0, theta=0.0
% INFO    : Bus 5463	: V=1.054031, theta=9.216302 -> V=1.0, theta=0.0
% INFO    : Bus 5464	: V=1.011467, theta=18.152933 -> V=1.0, theta=0.0
% INFO    : Bus 5465	: V=1.002052, theta=0.724345 -> V=1.0, theta=0.0
% INFO    : Bus 5466	: V=1.021987, theta=8.5782 -> V=1.0, theta=0.0
% INFO    : Bus 5467	: V=1.021987, theta=8.5782 -> V=1.0, theta=0.0
% INFO    : Bus 5468	: V=1.021987, theta=8.5782 -> V=1.0, theta=0.0
% INFO    : Bus 5469	: V=1.009591, theta=18.431924 -> V=1.0, theta=0.0
% INFO    : Bus 5470	: V=1.00951, theta=14.111952 -> V=1.0, theta=0.0
% INFO    : Bus 5471	: V=1.038952, theta=-3.685101 -> V=1.0, theta=0.0
% INFO    : Bus 5472	: V=1.032584, theta=4.617096 -> V=1.0, theta=0.0
% INFO    : Bus 5473	: V=1.034048, theta=-9.733404 -> V=1.0, theta=0.0
% INFO    : Bus 5474	: V=0.982293, theta=24.305163 -> V=1.0, theta=0.0
% INFO    : Bus 5475	: V=1.015359, theta=-20.625876 -> V=1.0, theta=0.0
% INFO    : Bus 5476	: V=1.058287, theta=5.521142 -> V=1.0, theta=0.0
% INFO    : Bus 5477	: V=0.999998, theta=-7.478578 -> V=1.0, theta=0.0
% INFO    : Bus 5478	: V=1.065239, theta=82.186971 -> V=1.0, theta=0.0
% INFO    : Bus 5479	: V=1.020383, theta=19.713555 -> V=1.0, theta=0.0
% INFO    : Bus 5480	: V=1.03358, theta=4.727162 -> V=1.0, theta=0.0
% INFO    : Bus 5481	: V=0.995881, theta=-14.296589 -> V=1.0, theta=0.0
% INFO    : Bus 5482	: V=1.026776, theta=33.821305 -> V=1.0, theta=0.0
% INFO    : Bus 5483	: V=1.043257, theta=-18.000081 -> V=1.0, theta=0.0
% INFO    : Bus 5484	: V=0.956073, theta=24.685075 -> V=1.0, theta=0.0
% INFO    : Bus 5485	: V=0.954523, theta=-1.873735 -> V=1.0, theta=0.0
% INFO    : Bus 5486	: V=1.038771, theta=7.75297 -> V=1.0, theta=0.0
% INFO    : Bus 5487	: V=1.023609, theta=8.435988 -> V=1.0, theta=0.0
% INFO    : Bus 5488	: V=1.002597, theta=-1.485346 -> V=1.0, theta=0.0
% INFO    : Bus 5489	: V=1.032625, theta=-19.504367 -> V=1.0, theta=0.0
% INFO    : Bus 5490	: V=1.028982, theta=-17.79027 -> V=1.0, theta=0.0
% INFO    : Bus 5491	: V=0.997947, theta=-10.410664 -> V=1.0, theta=0.0
% INFO    : Bus 5492	: V=1.013587, theta=-30.743973 -> V=1.0, theta=0.0
% INFO    : Bus 5493	: V=1.047324, theta=29.965681 -> V=1.0, theta=0.0
% INFO    : Bus 5494	: V=0.991002, theta=22.274075 -> V=1.0, theta=0.0
% INFO    : Bus 5495	: V=0.942228, theta=-8.841529 -> V=1.0, theta=0.0
% INFO    : Bus 5496	: V=1.043448, theta=79.328992 -> V=1.0, theta=0.0
% INFO    : Bus 5497	: V=1.068116, theta=5.359204 -> V=1.0, theta=0.0
% INFO    : Bus 5498	: V=1.041198, theta=4.140848 -> V=1.0, theta=0.0
% INFO    : Bus 5499	: V=1.033521, theta=9.078689 -> V=1.0, theta=0.0
% INFO    : Bus 5500	: V=1.034725, theta=32.734841 -> V=1.0, theta=0.0
% INFO    : Bus 5501	: V=1.012878, theta=6.54106 -> V=1.0, theta=0.0
% INFO    : Bus 5502	: V=1.001698, theta=92.057182 -> V=1.0, theta=0.0
% INFO    : Bus 5503	: V=1.032124, theta=21.999225 -> V=1.0, theta=0.0
% INFO    : Bus 5504	: V=1.03277, theta=-19.320799 -> V=1.0, theta=0.0
% INFO    : Bus 5505	: V=0.985939, theta=-2.873709 -> V=1.0, theta=0.0
% INFO    : Bus 5506	: V=1.026291, theta=-4.491374 -> V=1.0, theta=0.0
% INFO    : Bus 5507	: V=1.014219, theta=-26.03395 -> V=1.0, theta=0.0
% INFO    : Bus 5508	: V=1.000405, theta=-4.7006 -> V=1.0, theta=0.0
% INFO    : Bus 5509	: V=1.039944, theta=-3.443809 -> V=1.0, theta=0.0
% INFO    : Bus 5510	: V=1.05632, theta=32.386122 -> V=1.0, theta=0.0
% INFO    : Bus 5511	: V=1.031703, theta=-3.136077 -> V=1.0, theta=0.0
% INFO    : Bus 5512	: V=1.014266, theta=27.581576 -> V=1.0, theta=0.0
% INFO    : Bus 5513	: V=0.966548, theta=-0.111776 -> V=1.0, theta=0.0
% INFO    : Bus 5514	: V=1.05632, theta=32.386122 -> V=1.0, theta=0.0
% INFO    : Bus 5515	: V=1.04787, theta=36.346539 -> V=1.0, theta=0.0
% INFO    : Bus 5516	: V=1.046421, theta=-13.009884 -> V=1.0, theta=0.0
% INFO    : Bus 5517	: V=1.03284, theta=28.489594 -> V=1.0, theta=0.0
% INFO    : Bus 5518	: V=0.990205, theta=-4.49642 -> V=1.0, theta=0.0
% INFO    : Bus 5519	: V=0.981793, theta=-11.284467 -> V=1.0, theta=0.0
% INFO    : Bus 5520	: V=1.057585, theta=11.125317 -> V=1.0, theta=0.0
% INFO    : Bus 5521	: V=1.037504, theta=75.247519 -> V=1.0, theta=0.0
% INFO    : Bus 5522	: V=0.993993, theta=29.495121 -> V=1.0, theta=0.0
% INFO    : Bus 5523	: V=1.037993, theta=28.716517 -> V=1.0, theta=0.0
% INFO    : Bus 5524	: V=1.025446, theta=11.298124 -> V=1.0, theta=0.0
% INFO    : Bus 5525	: V=0.997105, theta=20.026989 -> V=1.0, theta=0.0
% INFO    : Bus 5526	: V=1.042313, theta=-6.262534 -> V=1.0, theta=0.0
% INFO    : Bus 5527	: V=1.002937, theta=-4.683269 -> V=1.0, theta=0.0
% INFO    : Bus 5528	: V=1.009486, theta=16.888084 -> V=1.0, theta=0.0
% INFO    : Bus 5529	: V=1.053958, theta=-6.513606 -> V=1.0, theta=0.0
% INFO    : Bus 5530	: V=1.037993, theta=28.716517 -> V=1.0, theta=0.0
% INFO    : Bus 5531	: V=1.017681, theta=78.940855 -> V=1.0, theta=0.0
% INFO    : Bus 5532	: V=1.025267, theta=-2.273267 -> V=1.0, theta=0.0
% INFO    : Bus 5533	: V=1.015563, theta=19.169778 -> V=1.0, theta=0.0
% INFO    : Bus 5534	: V=1.020332, theta=23.152992 -> V=1.0, theta=0.0
% INFO    : Bus 5535	: V=1.038002, theta=-21.381787 -> V=1.0, theta=0.0
% INFO    : Bus 5536	: V=1.019573, theta=-23.233961 -> V=1.0, theta=0.0
% INFO    : Bus 5537	: V=1.031681, theta=8.016407 -> V=1.0, theta=0.0
% INFO    : Bus 5538	: V=1.018608, theta=-18.078221 -> V=1.0, theta=0.0
% INFO    : Bus 5539	: V=1.020643, theta=26.34871 -> V=1.0, theta=0.0
% INFO    : Bus 5540	: V=1.045359, theta=9.917398 -> V=1.0, theta=0.0
% INFO    : Bus 5541	: V=1.04929, theta=32.879646 -> V=1.0, theta=0.0
% INFO    : Bus 5542	: V=1.010203, theta=8.259748 -> V=1.0, theta=0.0
% INFO    : Bus 5543	: V=1.052316, theta=-5.470021 -> V=1.0, theta=0.0
% INFO    : Bus 5544	: V=0.944329, theta=-10.949935 -> V=1.0, theta=0.0
% INFO    : Bus 5545	: V=1.033232, theta=20.726267 -> V=1.0, theta=0.0
% INFO    : Bus 5546	: V=1.026207, theta=-11.793103 -> V=1.0, theta=0.0
% INFO    : Bus 5547	: V=1.004093, theta=46.303458 -> V=1.0, theta=0.0
% INFO    : Bus 5548	: V=1.030988, theta=2.394145 -> V=1.0, theta=0.0
% INFO    : Bus 5549	: V=1.022765, theta=36.791666 -> V=1.0, theta=0.0
% INFO    : Bus 5550	: V=0.991249, theta=31.489724 -> V=1.0, theta=0.0
% INFO    : Bus 5551	: V=1.033986, theta=-0.883818 -> V=1.0, theta=0.0
% INFO    : Bus 5552	: V=1.097818, theta=-4.717769 -> V=1.0, theta=0.0
% INFO    : Bus 5553	: V=0.987058, theta=-8.963027 -> V=1.0, theta=0.0
% INFO    : Bus 5554	: V=1.0273, theta=-4.462847 -> V=1.0, theta=0.0
% INFO    : Bus 5555	: V=0.993552, theta=21.325826 -> V=1.0, theta=0.0
% INFO    : Bus 5556	: V=1.030728, theta=9.614364 -> V=1.0, theta=0.0
% INFO    : Bus 5557	: V=1.045313, theta=37.497254 -> V=1.0, theta=0.0
% INFO    : Bus 5558	: V=0.968669, theta=19.556191 -> V=1.0, theta=0.0
% INFO    : Bus 5559	: V=0.992104, theta=9.370388 -> V=1.0, theta=0.0
% INFO    : Bus 5560	: V=0.994311, theta=40.473761 -> V=1.0, theta=0.0
% INFO    : Bus 5561	: V=1.041016, theta=-3.593429 -> V=1.0, theta=0.0
% INFO    : Bus 5562	: V=1.02065, theta=42.452202 -> V=1.0, theta=0.0
% INFO    : Bus 5563	: V=1.03097, theta=-5.06415 -> V=1.0, theta=0.0
% INFO    : Bus 5564	: V=1.033422, theta=-6.60149 -> V=1.0, theta=0.0
% INFO    : Bus 5565	: V=0.990674, theta=-12.457063 -> V=1.0, theta=0.0
% INFO    : Bus 5566	: V=1.029668, theta=-16.520796 -> V=1.0, theta=0.0
% INFO    : Bus 5567	: V=1.039509, theta=27.773539 -> V=1.0, theta=0.0
% INFO    : Bus 5568	: V=1.054612, theta=-13.021657 -> V=1.0, theta=0.0
% INFO    : Bus 5569	: V=1.038162, theta=75.883553 -> V=1.0, theta=0.0
% INFO    : Bus 5570	: V=0.985969, theta=-5.347667 -> V=1.0, theta=0.0
% INFO    : Bus 5571	: V=1.047477, theta=-2.055486 -> V=1.0, theta=0.0
% INFO    : Bus 5572	: V=1.028225, theta=45.555177 -> V=1.0, theta=0.0
% INFO    : Bus 5573	: V=1.053988, theta=-13.855785 -> V=1.0, theta=0.0
% INFO    : Bus 5574	: V=0.984528, theta=42.045502 -> V=1.0, theta=0.0
% INFO    : Bus 5575	: V=1.031736, theta=41.040722 -> V=1.0, theta=0.0
% INFO    : Bus 5576	: V=0.976475, theta=43.406918 -> V=1.0, theta=0.0
% INFO    : Bus 5577	: V=1.035016, theta=0.8172 -> V=1.0, theta=0.0
% INFO    : Bus 5578	: V=0.999568, theta=-12.992092 -> V=1.0, theta=0.0
% INFO    : Bus 5579	: V=1.059024, theta=-2.926118 -> V=1.0, theta=0.0
% INFO    : Bus 5580	: V=1.006276, theta=16.36648 -> V=1.0, theta=0.0
% INFO    : Bus 5581	: V=1.063714, theta=6.510197 -> V=1.0, theta=0.0
% INFO    : Bus 5582	: V=1.009463, theta=-9.554155 -> V=1.0, theta=0.0
% INFO    : Bus 5583	: V=0.987706, theta=-3.303202 -> V=1.0, theta=0.0
% INFO    : Bus 5584	: V=0.979206, theta=-6.232471 -> V=1.0, theta=0.0
% INFO    : Bus 5585	: V=1.019792, theta=-15.494313 -> V=1.0, theta=0.0
% INFO    : Bus 5586	: V=1.025107, theta=-5.101065 -> V=1.0, theta=0.0
% INFO    : Bus 5587	: V=1.041875, theta=20.867491 -> V=1.0, theta=0.0
% INFO    : Bus 5588	: V=1.079463, theta=38.243221 -> V=1.0, theta=0.0
% INFO    : Bus 5589	: V=1.062436, theta=4.140276 -> V=1.0, theta=0.0
% INFO    : Bus 5590	: V=1.026131, theta=4.125771 -> V=1.0, theta=0.0
% INFO    : Bus 5591	: V=1.01737, theta=-3.57985 -> V=1.0, theta=0.0
% INFO    : Bus 5592	: V=1.00876, theta=0.250829 -> V=1.0, theta=0.0
% INFO    : Bus 5593	: V=1.014635, theta=-0.980319 -> V=1.0, theta=0.0
% INFO    : Bus 5594	: V=1.028002, theta=7.184716 -> V=1.0, theta=0.0
% INFO    : Bus 5595	: V=1.014621, theta=-26.468886 -> V=1.0, theta=0.0
% INFO    : Bus 5596	: V=1.030843, theta=7.951587 -> V=1.0, theta=0.0
% INFO    : Bus 5597	: V=0.992031, theta=-1.689804 -> V=1.0, theta=0.0
% INFO    : Bus 5598	: V=1.017435, theta=13.5457 -> V=1.0, theta=0.0
% INFO    : Bus 5599	: V=0.998677, theta=-23.026413 -> V=1.0, theta=0.0
% INFO    : Bus 5600	: V=1.043652, theta=0.642216 -> V=1.0, theta=0.0
% INFO    : Bus 5601	: V=1.030483, theta=4.072037 -> V=1.0, theta=0.0
% INFO    : Bus 5602	: V=1.019321, theta=21.930962 -> V=1.0, theta=0.0
% INFO    : Bus 5603	: V=1.002126, theta=-8.787185 -> V=1.0, theta=0.0
% INFO    : Bus 5604	: V=1.029928, theta=-11.421758 -> V=1.0, theta=0.0
% INFO    : Bus 5605	: V=1.029028, theta=28.384829 -> V=1.0, theta=0.0
% INFO    : Bus 5606	: V=1.029028, theta=28.384829 -> V=1.0, theta=0.0
% INFO    : Bus 5607	: V=1.025746, theta=32.862676 -> V=1.0, theta=0.0
% INFO    : Bus 5608	: V=1.045989, theta=24.800863 -> V=1.0, theta=0.0
% INFO    : Bus 5609	: V=1.029028, theta=28.384829 -> V=1.0, theta=0.0
% INFO    : Bus 5610	: V=1.025746, theta=32.862676 -> V=1.0, theta=0.0
% INFO    : Bus 5611	: V=1.047982, theta=25.815744 -> V=1.0, theta=0.0
% INFO    : Bus 5612	: V=1.047982, theta=25.815744 -> V=1.0, theta=0.0
% INFO    : Bus 5613	: V=1.045989, theta=24.800863 -> V=1.0, theta=0.0
% INFO    : Bus 5614	: V=1.047806, theta=26.509997 -> V=1.0, theta=0.0
% INFO    : Bus 5615	: V=0.990005, theta=-9.648284 -> V=1.0, theta=0.0
% INFO    : Bus 5616	: V=1.048472, theta=3.178718 -> V=1.0, theta=0.0
% INFO    : Bus 5617	: V=1.077244, theta=-11.176288 -> V=1.0, theta=0.0
% INFO    : Bus 5618	: V=1.003124, theta=25.734388 -> V=1.0, theta=0.0
% INFO    : Bus 5619	: V=1.049918, theta=7.582329 -> V=1.0, theta=0.0
% INFO    : Bus 5620	: V=0.952596, theta=-2.388742 -> V=1.0, theta=0.0
% INFO    : Bus 5621	: V=0.946511, theta=-10.737395 -> V=1.0, theta=0.0
% INFO    : Bus 5622	: V=1.03975, theta=24.63487 -> V=1.0, theta=0.0
% INFO    : Bus 5623	: V=0.988243, theta=16.963551 -> V=1.0, theta=0.0
% INFO    : Bus 5624	: V=1.019792, theta=-15.494313 -> V=1.0, theta=0.0
% INFO    : Bus 5625	: V=0.978962, theta=7.657504 -> V=1.0, theta=0.0
% INFO    : Bus 5626	: V=0.989695, theta=-1.825556 -> V=1.0, theta=0.0
% INFO    : Bus 5627	: V=1.026746, theta=3.870557 -> V=1.0, theta=0.0
% INFO    : Bus 5628	: V=1.020137, theta=-11.623454 -> V=1.0, theta=0.0
% INFO    : Bus 5629	: V=1.020137, theta=-11.623454 -> V=1.0, theta=0.0
% INFO    : Bus 5630	: V=0.976217, theta=-9.446382 -> V=1.0, theta=0.0
% INFO    : Bus 5631	: V=1.009821, theta=-5.315519 -> V=1.0, theta=0.0
% INFO    : Bus 5632	: V=1.015993, theta=-9.375302 -> V=1.0, theta=0.0
% INFO    : Bus 5633	: V=1.001096, theta=16.815156 -> V=1.0, theta=0.0
% INFO    : Bus 5634	: V=1.009821, theta=-5.315519 -> V=1.0, theta=0.0
% INFO    : Bus 5635	: V=0.99051, theta=-17.628892 -> V=1.0, theta=0.0
% INFO    : Bus 5636	: V=1.001756, theta=-10.041769 -> V=1.0, theta=0.0
% INFO    : Bus 5637	: V=1.043748, theta=36.747443 -> V=1.0, theta=0.0
% INFO    : Bus 5638	: V=1.014728, theta=-11.054108 -> V=1.0, theta=0.0
% INFO    : Bus 5639	: V=0.949125, theta=-8.184163 -> V=1.0, theta=0.0
% INFO    : Bus 5640	: V=1.06339, theta=20.87235 -> V=1.0, theta=0.0
% INFO    : Bus 5641	: V=1.043087, theta=11.638661 -> V=1.0, theta=0.0
% INFO    : Bus 5642	: V=1.025062, theta=-16.730832 -> V=1.0, theta=0.0
% INFO    : Bus 5643	: V=1.028403, theta=19.42828 -> V=1.0, theta=0.0
% INFO    : Bus 5644	: V=0.963377, theta=-3.10766 -> V=1.0, theta=0.0
% INFO    : Bus 5645	: V=1.003179, theta=38.552189 -> V=1.0, theta=0.0
% INFO    : Bus 5646	: V=1.01326, theta=-17.047746 -> V=1.0, theta=0.0
% INFO    : Bus 5647	: V=1.031808, theta=17.017475 -> V=1.0, theta=0.0
% INFO    : Bus 5648	: V=1.002793, theta=28.630967 -> V=1.0, theta=0.0
% INFO    : Bus 5649	: V=1.01842, theta=36.689147 -> V=1.0, theta=0.0
% INFO    : Bus 5650	: V=0.98149, theta=-7.303136 -> V=1.0, theta=0.0
% INFO    : Bus 5651	: V=1.034087, theta=30.349767 -> V=1.0, theta=0.0
% INFO    : Bus 5652	: V=1.015014, theta=-12.066594 -> V=1.0, theta=0.0
% INFO    : Bus 5653	: V=1.01212, theta=1.557585 -> V=1.0, theta=0.0
% INFO    : Bus 5654	: V=1.063453, theta=20.858871 -> V=1.0, theta=0.0
% INFO    : Bus 5655	: V=0.989306, theta=90.493667 -> V=1.0, theta=0.0
% INFO    : Bus 5656	: V=1.014415, theta=46.434829 -> V=1.0, theta=0.0
% INFO    : Bus 5657	: V=1.048637, theta=18.752224 -> V=1.0, theta=0.0
% INFO    : Bus 5658	: V=1.015919, theta=3.580325 -> V=1.0, theta=0.0
% INFO    : Bus 5659	: V=1.080485, theta=11.132062 -> V=1.0, theta=0.0
% INFO    : Bus 5660	: V=1.05544, theta=46.172493 -> V=1.0, theta=0.0
% INFO    : Bus 5661	: V=0.987955, theta=35.791506 -> V=1.0, theta=0.0
% INFO    : Bus 5662	: V=1.024984, theta=3.613638 -> V=1.0, theta=0.0
% INFO    : Bus 5663	: V=0.998779, theta=-8.829037 -> V=1.0, theta=0.0
% INFO    : Bus 5664	: V=1.068809, theta=5.549085 -> V=1.0, theta=0.0
% INFO    : Bus 5665	: V=1.035449, theta=-4.107003 -> V=1.0, theta=0.0
% INFO    : Bus 5666	: V=1.069948, theta=21.128396 -> V=1.0, theta=0.0
% INFO    : Bus 5667	: V=1.047105, theta=87.088421 -> V=1.0, theta=0.0
% INFO    : Bus 5668	: V=1.028707, theta=4.250081 -> V=1.0, theta=0.0
% INFO    : Bus 5669	: V=1.045843, theta=-0.415561 -> V=1.0, theta=0.0
% INFO    : Bus 5670	: V=1.028707, theta=4.250081 -> V=1.0, theta=0.0
% INFO    : Bus 5671	: V=1.021296, theta=30.056732 -> V=1.0, theta=0.0
% INFO    : Bus 5672	: V=1.03058, theta=15.553508 -> V=1.0, theta=0.0
% INFO    : Bus 5673	: V=1.01606, theta=-7.943038 -> V=1.0, theta=0.0
% INFO    : Bus 5674	: V=1.043874, theta=15.587474 -> V=1.0, theta=0.0
% INFO    : Bus 5675	: V=1.016124, theta=2.135408 -> V=1.0, theta=0.0
% INFO    : Bus 5676	: V=1.025082, theta=-16.616549 -> V=1.0, theta=0.0
% INFO    : Bus 5677	: V=1.008845, theta=14.340823 -> V=1.0, theta=0.0
% INFO    : Bus 5678	: V=1.036144, theta=1.509807 -> V=1.0, theta=0.0
% INFO    : Bus 5679	: V=0.996318, theta=28.762446 -> V=1.0, theta=0.0
% INFO    : Bus 5680	: V=0.990521, theta=25.757347 -> V=1.0, theta=0.0
% INFO    : Bus 5681	: V=1.000057, theta=26.10357 -> V=1.0, theta=0.0
% INFO    : Bus 5682	: V=1.010703, theta=-2.718775 -> V=1.0, theta=0.0
% INFO    : Bus 5683	: V=1.036415, theta=33.220718 -> V=1.0, theta=0.0
% INFO    : Bus 5684	: V=0.99565, theta=24.118259 -> V=1.0, theta=0.0
% INFO    : Bus 5685	: V=0.977662, theta=-23.879736 -> V=1.0, theta=0.0
% INFO    : Bus 5686	: V=1.037302, theta=19.028226 -> V=1.0, theta=0.0
% INFO    : Bus 5687	: V=1.035473, theta=31.04393 -> V=1.0, theta=0.0
% INFO    : Bus 5688	: V=1.020772, theta=7.039712 -> V=1.0, theta=0.0
% INFO    : Bus 5689	: V=1.037277, theta=18.603106 -> V=1.0, theta=0.0
% INFO    : Bus 5690	: V=1.048282, theta=-1.885985 -> V=1.0, theta=0.0
% INFO    : Bus 5691	: V=1.034135, theta=20.861206 -> V=1.0, theta=0.0
% INFO    : Bus 5692	: V=1.015709, theta=7.345958 -> V=1.0, theta=0.0
% INFO    : Bus 5693	: V=1.043404, theta=54.291731 -> V=1.0, theta=0.0
% INFO    : Bus 5694	: V=1.053797, theta=-3.818548 -> V=1.0, theta=0.0
% INFO    : Bus 5695	: V=1.034646, theta=-0.807488 -> V=1.0, theta=0.0
% INFO    : Bus 5696	: V=1.058617, theta=17.901877 -> V=1.0, theta=0.0
% INFO    : Bus 5697	: V=1.002466, theta=-10.296121 -> V=1.0, theta=0.0
% INFO    : Bus 5698	: V=1.005121, theta=-15.045231 -> V=1.0, theta=0.0
% INFO    : Bus 5699	: V=0.988269, theta=-4.625892 -> V=1.0, theta=0.0
% INFO    : Bus 5700	: V=1.012126, theta=-1.815901 -> V=1.0, theta=0.0
% INFO    : Bus 5701	: V=1.015564, theta=-11.698808 -> V=1.0, theta=0.0
% INFO    : Bus 5702	: V=1.027418, theta=-10.310547 -> V=1.0, theta=0.0
% INFO    : Bus 5703	: V=1.03789, theta=-14.752144 -> V=1.0, theta=0.0
% INFO    : Bus 5704	: V=1.053462, theta=40.300443 -> V=1.0, theta=0.0
% INFO    : Bus 5705	: V=1.053459, theta=40.302912 -> V=1.0, theta=0.0
% INFO    : Bus 5706	: V=1.056281, theta=36.699329 -> V=1.0, theta=0.0
% INFO    : Bus 5707	: V=1.056281, theta=36.699329 -> V=1.0, theta=0.0
% INFO    : Bus 5708	: V=1.063449, theta=20.85668 -> V=1.0, theta=0.0
% INFO    : Bus 5709	: V=1.016072, theta=22.381001 -> V=1.0, theta=0.0
% INFO    : Bus 5710	: V=1.004588, theta=32.779584 -> V=1.0, theta=0.0
% INFO    : Bus 5711	: V=1.049141, theta=7.531626 -> V=1.0, theta=0.0
% INFO    : Bus 5712	: V=1.036026, theta=35.070334 -> V=1.0, theta=0.0
% INFO    : Bus 5713	: V=1.028846, theta=-5.79278 -> V=1.0, theta=0.0
% INFO    : Bus 5714	: V=1.041293, theta=27.016012 -> V=1.0, theta=0.0
% INFO    : Bus 5715	: V=1.019539, theta=-2.214354 -> V=1.0, theta=0.0
% INFO    : Bus 5716	: V=1.006233, theta=16.146442 -> V=1.0, theta=0.0
% INFO    : Bus 5717	: V=1.00657, theta=-1.131032 -> V=1.0, theta=0.0
% INFO    : Bus 5718	: V=1.043748, theta=36.747443 -> V=1.0, theta=0.0
% INFO    : Bus 5719	: V=1.024367, theta=-3.01161 -> V=1.0, theta=0.0
% INFO    : Bus 5720	: V=1.025855, theta=-3.600731 -> V=1.0, theta=0.0
% INFO    : Bus 5721	: V=1.033065, theta=16.599351 -> V=1.0, theta=0.0
% INFO    : Bus 5722	: V=1.005471, theta=13.874385 -> V=1.0, theta=0.0
% INFO    : Bus 5723	: V=1.042317, theta=14.274354 -> V=1.0, theta=0.0
% INFO    : Bus 5724	: V=1.066969, theta=53.426857 -> V=1.0, theta=0.0
% INFO    : Bus 5725	: V=1.022383, theta=5.236844 -> V=1.0, theta=0.0
% INFO    : Bus 5726	: V=0.9717, theta=-14.549319 -> V=1.0, theta=0.0
% INFO    : Bus 5727	: V=1.056156, theta=-2.309831 -> V=1.0, theta=0.0
% INFO    : Bus 5728	: V=1.044132, theta=13.300463 -> V=1.0, theta=0.0
% INFO    : Bus 5729	: V=1.044132, theta=13.300463 -> V=1.0, theta=0.0
% INFO    : Bus 5730	: V=1.044132, theta=13.300463 -> V=1.0, theta=0.0
% INFO    : Bus 5731	: V=1.044132, theta=13.300463 -> V=1.0, theta=0.0
% INFO    : Bus 5732	: V=1.034671, theta=8.05531 -> V=1.0, theta=0.0
% INFO    : Bus 5733	: V=0.973928, theta=22.692838 -> V=1.0, theta=0.0
% INFO    : Bus 5734	: V=0.951297, theta=-7.389214 -> V=1.0, theta=0.0
% INFO    : Bus 5735	: V=1.034875, theta=1.842217 -> V=1.0, theta=0.0
% INFO    : Bus 5736	: V=0.968092, theta=-10.363327 -> V=1.0, theta=0.0
% INFO    : Bus 5737	: V=0.990695, theta=-4.359908 -> V=1.0, theta=0.0
% INFO    : Bus 5738	: V=0.948716, theta=-0.128776 -> V=1.0, theta=0.0
% INFO    : Bus 5739	: V=1.038438, theta=0.065623 -> V=1.0, theta=0.0
% INFO    : Bus 5740	: V=1.049045, theta=7.495402 -> V=1.0, theta=0.0
% INFO    : Bus 5741	: V=1.045359, theta=10.101302 -> V=1.0, theta=0.0
% INFO    : Bus 5742	: V=0.973258, theta=21.632267 -> V=1.0, theta=0.0
% INFO    : Bus 5743	: V=0.978727, theta=35.787613 -> V=1.0, theta=0.0
% INFO    : Bus 5744	: V=0.988018, theta=-6.490165 -> V=1.0, theta=0.0
% INFO    : Bus 5745	: V=1.022914, theta=15.763597 -> V=1.0, theta=0.0
% INFO    : Bus 5746	: V=1.037284, theta=8.367307 -> V=1.0, theta=0.0
% INFO    : Bus 5747	: V=1.03026, theta=3.848789 -> V=1.0, theta=0.0
% INFO    : Bus 5748	: V=1.03026, theta=3.848789 -> V=1.0, theta=0.0
% INFO    : Bus 5749	: V=1.065613, theta=46.834612 -> V=1.0, theta=0.0
% INFO    : Bus 5750	: V=1.028771, theta=2.144472 -> V=1.0, theta=0.0
% INFO    : Bus 5751	: V=1.022435, theta=-15.897794 -> V=1.0, theta=0.0
% INFO    : Bus 5752	: V=1.085474, theta=1.430716 -> V=1.0, theta=0.0
% INFO    : Bus 5753	: V=1.033793, theta=9.21995 -> V=1.0, theta=0.0
% INFO    : Bus 5754	: V=1.040399, theta=19.36982 -> V=1.0, theta=0.0
% INFO    : Bus 5755	: V=1.020557, theta=9.624602 -> V=1.0, theta=0.0
% INFO    : Bus 5756	: V=0.946362, theta=-8.81689 -> V=1.0, theta=0.0
% INFO    : Bus 5757	: V=1.016262, theta=22.326539 -> V=1.0, theta=0.0
% INFO    : Bus 5758	: V=1.079673, theta=11.115093 -> V=1.0, theta=0.0
% INFO    : Bus 5759	: V=1.020477, theta=-11.022564 -> V=1.0, theta=0.0
% INFO    : Bus 5760	: V=1.038988, theta=17.120629 -> V=1.0, theta=0.0
% INFO    : Bus 5761	: V=1.054937, theta=4.624127 -> V=1.0, theta=0.0
% INFO    : Bus 5762	: V=0.964932, theta=-6.955073 -> V=1.0, theta=0.0
% INFO    : Bus 5763	: V=1.024798, theta=30.073669 -> V=1.0, theta=0.0
% INFO    : Bus 5764	: V=1.050901, theta=18.201002 -> V=1.0, theta=0.0
% INFO    : Bus 5765	: V=1.030566, theta=-6.658147 -> V=1.0, theta=0.0
% INFO    : Bus 5766	: V=1.016135, theta=-25.646727 -> V=1.0, theta=0.0
% INFO    : Bus 5767	: V=1.054759, theta=28.608378 -> V=1.0, theta=0.0
% INFO    : Bus 5768	: V=1.0003, theta=2.358032 -> V=1.0, theta=0.0
% INFO    : Bus 5769	: V=1.025333, theta=3.180104 -> V=1.0, theta=0.0
% INFO    : Bus 5770	: V=1.025019, theta=-12.264635 -> V=1.0, theta=0.0
% INFO    : Bus 5771	: V=1.025019, theta=-12.264635 -> V=1.0, theta=0.0
% INFO    : Bus 5772	: V=1.025333, theta=3.180104 -> V=1.0, theta=0.0
% INFO    : Bus 5773	: V=1.056553, theta=39.273401 -> V=1.0, theta=0.0
% INFO    : Bus 5774	: V=0.981267, theta=-2.841394 -> V=1.0, theta=0.0
% INFO    : Bus 5775	: V=1.025402, theta=-4.180541 -> V=1.0, theta=0.0
% INFO    : Bus 5776	: V=1.039438, theta=-12.890359 -> V=1.0, theta=0.0
% INFO    : Bus 5777	: V=1.039438, theta=-12.890359 -> V=1.0, theta=0.0
% INFO    : Bus 5778	: V=1.012762, theta=-16.416743 -> V=1.0, theta=0.0
% INFO    : Bus 5779	: V=1.015081, theta=16.352467 -> V=1.0, theta=0.0
% INFO    : Bus 5780	: V=1.021718, theta=-10.711519 -> V=1.0, theta=0.0
% INFO    : Bus 5781	: V=1.039438, theta=-12.890359 -> V=1.0, theta=0.0
% INFO    : Bus 5782	: V=1.039438, theta=-12.890359 -> V=1.0, theta=0.0
% INFO    : Bus 5783	: V=0.990994, theta=-16.127751 -> V=1.0, theta=0.0
% INFO    : Bus 5784	: V=1.026131, theta=33.839963 -> V=1.0, theta=0.0
% INFO    : Bus 5785	: V=1.050514, theta=24.699304 -> V=1.0, theta=0.0
% INFO    : Bus 5786	: V=1.055489, theta=5.337934 -> V=1.0, theta=0.0
% INFO    : Bus 5787	: V=1.01752, theta=-4.62634 -> V=1.0, theta=0.0
% INFO    : Bus 5788	: V=0.993679, theta=90.244767 -> V=1.0, theta=0.0
% INFO    : Bus 5789	: V=1.082373, theta=9.508502 -> V=1.0, theta=0.0
% INFO    : Bus 5790	: V=1.008391, theta=-8.4759 -> V=1.0, theta=0.0
% INFO    : Bus 5791	: V=1.045831, theta=-3.308284 -> V=1.0, theta=0.0
% INFO    : Bus 5792	: V=1.068636, theta=22.055101 -> V=1.0, theta=0.0
% INFO    : Bus 5793	: V=1.016584, theta=-8.474181 -> V=1.0, theta=0.0
% INFO    : Bus 5794	: V=0.976391, theta=21.084011 -> V=1.0, theta=0.0
% INFO    : Bus 5795	: V=1.014298, theta=-18.383692 -> V=1.0, theta=0.0
% INFO    : Bus 5796	: V=1.00485, theta=-15.564435 -> V=1.0, theta=0.0
% INFO    : Bus 5797	: V=1.042461, theta=6.951342 -> V=1.0, theta=0.0
% INFO    : Bus 5798	: V=1.01945, theta=6.119322 -> V=1.0, theta=0.0
% INFO    : Bus 5799	: V=1.020095, theta=18.921466 -> V=1.0, theta=0.0
% INFO    : Bus 5800	: V=1.007767, theta=-9.473275 -> V=1.0, theta=0.0
% INFO    : Bus 5801	: V=1.006593, theta=32.135135 -> V=1.0, theta=0.0
% INFO    : Bus 5802	: V=1.025117, theta=16.028526 -> V=1.0, theta=0.0
% INFO    : Bus 5803	: V=1.01388, theta=8.701007 -> V=1.0, theta=0.0
% INFO    : Bus 5804	: V=1.040138, theta=32.45384 -> V=1.0, theta=0.0
% INFO    : Bus 5805	: V=1.024788, theta=-12.464012 -> V=1.0, theta=0.0
% INFO    : Bus 5806	: V=0.987722, theta=33.845836 -> V=1.0, theta=0.0
% INFO    : Bus 5807	: V=1.0266, theta=-8.228562 -> V=1.0, theta=0.0
% INFO    : Bus 5808	: V=1.031067, theta=14.367272 -> V=1.0, theta=0.0
% INFO    : Bus 5809	: V=1.03095, theta=60.569539 -> V=1.0, theta=0.0
% INFO    : Bus 5810	: V=1.020064, theta=16.538428 -> V=1.0, theta=0.0
% INFO    : Bus 5811	: V=0.951832, theta=-5.449631 -> V=1.0, theta=0.0
% INFO    : Bus 5812	: V=1.027005, theta=59.333781 -> V=1.0, theta=0.0
% INFO    : Bus 5813	: V=0.966594, theta=-29.247887 -> V=1.0, theta=0.0
% INFO    : Bus 5814	: V=0.950338, theta=10.805302 -> V=1.0, theta=0.0
% INFO    : Bus 5815	: V=1.025886, theta=34.061284 -> V=1.0, theta=0.0
% INFO    : Bus 5816	: V=1.035914, theta=35.115322 -> V=1.0, theta=0.0
% INFO    : Bus 5817	: V=1.035449, theta=9.412244 -> V=1.0, theta=0.0
% INFO    : Bus 5818	: V=1.019498, theta=21.474685 -> V=1.0, theta=0.0
% INFO    : Bus 5819	: V=1.023278, theta=-2.708677 -> V=1.0, theta=0.0
% INFO    : Bus 5820	: V=1.013406, theta=36.020088 -> V=1.0, theta=0.0
% INFO    : Bus 5821	: V=1.135601, theta=0.615015 -> V=1.0, theta=0.0
% INFO    : Bus 5822	: V=1.023112, theta=34.781938 -> V=1.0, theta=0.0
% INFO    : Bus 5823	: V=1.012684, theta=-20.110839 -> V=1.0, theta=0.0
% INFO    : Bus 5824	: V=1.023298, theta=6.634271 -> V=1.0, theta=0.0
% INFO    : Bus 5825	: V=1.021452, theta=28.019771 -> V=1.0, theta=0.0
% INFO    : Bus 5826	: V=1.013783, theta=30.401512 -> V=1.0, theta=0.0
% INFO    : Bus 5827	: V=1.006104, theta=-16.109583 -> V=1.0, theta=0.0
% INFO    : Bus 5828	: V=0.993436, theta=-3.814152 -> V=1.0, theta=0.0
% INFO    : Bus 5829	: V=0.971881, theta=-8.50254 -> V=1.0, theta=0.0
% INFO    : Bus 5830	: V=1.030828, theta=-0.367949 -> V=1.0, theta=0.0
% INFO    : Bus 5831	: V=1.020161, theta=16.222206 -> V=1.0, theta=0.0
% INFO    : Bus 5832	: V=1.020161, theta=16.222206 -> V=1.0, theta=0.0
% INFO    : Bus 5833	: V=1.038306, theta=-15.533961 -> V=1.0, theta=0.0
% INFO    : Bus 5834	: V=1.049794, theta=0.17822 -> V=1.0, theta=0.0
% INFO    : Bus 5835	: V=1.050845, theta=44.075856 -> V=1.0, theta=0.0
% INFO    : Bus 5836	: V=1.026245, theta=18.684578 -> V=1.0, theta=0.0
% INFO    : Bus 5837	: V=0.958686, theta=-5.800294 -> V=1.0, theta=0.0
% INFO    : Bus 5838	: V=1.032652, theta=22.317624 -> V=1.0, theta=0.0
% INFO    : Bus 5839	: V=1.031387, theta=20.467452 -> V=1.0, theta=0.0
% INFO    : Bus 5840	: V=1.069097, theta=22.417608 -> V=1.0, theta=0.0
% INFO    : Bus 5841	: V=1.024467, theta=-0.601057 -> V=1.0, theta=0.0
% INFO    : Bus 5842	: V=1.024479, theta=-0.687261 -> V=1.0, theta=0.0
% INFO    : Bus 5843	: V=1.024282, theta=31.503415 -> V=1.0, theta=0.0
% INFO    : Bus 5844	: V=0.9664, theta=4.444682 -> V=1.0, theta=0.0
% INFO    : Bus 5845	: V=1.017777, theta=15.68236 -> V=1.0, theta=0.0
% INFO    : Bus 5846	: V=0.983943, theta=11.381087 -> V=1.0, theta=0.0
% INFO    : Bus 5847	: V=1.037296, theta=-1.6783 -> V=1.0, theta=0.0
% INFO    : Bus 5848	: V=1.06333, theta=-7.700665 -> V=1.0, theta=0.0
% INFO    : Bus 5849	: V=1.031737, theta=11.756042 -> V=1.0, theta=0.0
% INFO    : Bus 5850	: V=1.035207, theta=-6.870994 -> V=1.0, theta=0.0
% INFO    : Bus 5851	: V=0.988353, theta=22.737619 -> V=1.0, theta=0.0
% INFO    : Bus 5852	: V=1.054531, theta=2.335273 -> V=1.0, theta=0.0
% INFO    : Bus 5853	: V=1.01089, theta=27.117676 -> V=1.0, theta=0.0
% INFO    : Bus 5854	: V=1.012572, theta=-23.024367 -> V=1.0, theta=0.0
% INFO    : Bus 5855	: V=1.005005, theta=35.477455 -> V=1.0, theta=0.0
% INFO    : Bus 5856	: V=1.056042, theta=38.515188 -> V=1.0, theta=0.0
% INFO    : Bus 5857	: V=1.0313, theta=29.629994 -> V=1.0, theta=0.0
% INFO    : Bus 5858	: V=1.056042, theta=38.515188 -> V=1.0, theta=0.0
% INFO    : Bus 5859	: V=0.992724, theta=-4.117129 -> V=1.0, theta=0.0
% INFO    : Bus 5860	: V=1.018571, theta=-5.556974 -> V=1.0, theta=0.0
% INFO    : Bus 5861	: V=0.979237, theta=6.572803 -> V=1.0, theta=0.0
% INFO    : Bus 5862	: V=1.014975, theta=-2.046475 -> V=1.0, theta=0.0
% INFO    : Bus 5863	: V=1.012632, theta=-27.064346 -> V=1.0, theta=0.0
% INFO    : Bus 5864	: V=1.043738, theta=-8.975119 -> V=1.0, theta=0.0
% INFO    : Bus 5865	: V=0.994547, theta=1.423679 -> V=1.0, theta=0.0
% INFO    : Bus 5866	: V=1.037913, theta=-21.405342 -> V=1.0, theta=0.0
% INFO    : Bus 5867	: V=1.035807, theta=30.09497 -> V=1.0, theta=0.0
% INFO    : Bus 5868	: V=1.06019, theta=67.358874 -> V=1.0, theta=0.0
% INFO    : Bus 5869	: V=0.985529, theta=-4.986197 -> V=1.0, theta=0.0
% INFO    : Bus 5870	: V=1.015465, theta=17.28757 -> V=1.0, theta=0.0
% INFO    : Bus 5871	: V=1.066444, theta=-4.571592 -> V=1.0, theta=0.0
% INFO    : Bus 5872	: V=1.03628, theta=29.217017 -> V=1.0, theta=0.0
% INFO    : Bus 5873	: V=0.959562, theta=-9.810601 -> V=1.0, theta=0.0
% INFO    : Bus 5874	: V=1.029619, theta=20.011321 -> V=1.0, theta=0.0
% INFO    : Bus 5875	: V=1.034951, theta=19.251286 -> V=1.0, theta=0.0
% INFO    : Bus 5876	: V=1.002041, theta=-7.8441 -> V=1.0, theta=0.0
% INFO    : Bus 5877	: V=1.02758, theta=22.650628 -> V=1.0, theta=0.0
% INFO    : Bus 5878	: V=1.018599, theta=-22.400698 -> V=1.0, theta=0.0
% INFO    : Bus 5879	: V=0.985272, theta=39.219636 -> V=1.0, theta=0.0
% INFO    : Bus 5880	: V=1.021915, theta=-9.376379 -> V=1.0, theta=0.0
% INFO    : Bus 5881	: V=1.035485, theta=43.144579 -> V=1.0, theta=0.0
% INFO    : Bus 5882	: V=1.052667, theta=56.594903 -> V=1.0, theta=0.0
% INFO    : Bus 5883	: V=1.052667, theta=56.594903 -> V=1.0, theta=0.0
% INFO    : Bus 5884	: V=1.052667, theta=56.594903 -> V=1.0, theta=0.0
% INFO    : Bus 5885	: V=1.021915, theta=-9.376379 -> V=1.0, theta=0.0
% INFO    : Bus 5886	: V=1.021915, theta=-9.376379 -> V=1.0, theta=0.0
% INFO    : Bus 5887	: V=1.052481, theta=55.678412 -> V=1.0, theta=0.0
% INFO    : Bus 5888	: V=1.060323, theta=-2.554398 -> V=1.0, theta=0.0
% INFO    : Bus 5889	: V=1.052481, theta=55.678412 -> V=1.0, theta=0.0
% INFO    : Bus 5890	: V=1.020215, theta=36.373139 -> V=1.0, theta=0.0
% INFO    : Bus 5891	: V=1.028495, theta=1.853439 -> V=1.0, theta=0.0
% INFO    : Bus 5892	: V=1.131076, theta=7.162518 -> V=1.0, theta=0.0
% INFO    : Bus 5893	: V=1.035388, theta=12.710696 -> V=1.0, theta=0.0
% INFO    : Bus 5894	: V=0.998753, theta=12.721985 -> V=1.0, theta=0.0
% INFO    : Bus 5895	: V=1.01471, theta=-26.77008 -> V=1.0, theta=0.0
% INFO    : Bus 5896	: V=1.024375, theta=-1.976838 -> V=1.0, theta=0.0
% INFO    : Bus 5897	: V=1.054462, theta=48.756838 -> V=1.0, theta=0.0
% INFO    : Bus 5898	: V=1.054462, theta=48.756838 -> V=1.0, theta=0.0
% INFO    : Bus 5899	: V=1.047153, theta=89.840725 -> V=1.0, theta=0.0
% INFO    : Bus 5900	: V=1.05445, theta=48.75455 -> V=1.0, theta=0.0
% INFO    : Bus 5901	: V=1.05445, theta=48.75455 -> V=1.0, theta=0.0
% INFO    : Bus 5902	: V=1.054462, theta=48.756838 -> V=1.0, theta=0.0
% INFO    : Bus 5903	: V=1.012912, theta=-23.281628 -> V=1.0, theta=0.0
% INFO    : Bus 5904	: V=0.963348, theta=-6.444186 -> V=1.0, theta=0.0
% INFO    : Bus 5905	: V=0.994923, theta=49.296703 -> V=1.0, theta=0.0
% INFO    : Bus 5906	: V=1.025904, theta=-18.853098 -> V=1.0, theta=0.0
% INFO    : Bus 5907	: V=0.975223, theta=-5.552476 -> V=1.0, theta=0.0
% INFO    : Bus 5908	: V=1.01868, theta=-7.446296 -> V=1.0, theta=0.0
% INFO    : Bus 5909	: V=1.015628, theta=-22.718473 -> V=1.0, theta=0.0
% INFO    : Bus 5910	: V=1.017767, theta=42.2857 -> V=1.0, theta=0.0
% INFO    : Bus 5911	: V=1.037214, theta=32.974337 -> V=1.0, theta=0.0
% INFO    : Bus 5912	: V=1.020286, theta=29.155848 -> V=1.0, theta=0.0
% INFO    : Bus 5913	: V=1.041343, theta=33.230577 -> V=1.0, theta=0.0
% INFO    : Bus 5914	: V=1.036424, theta=29.228101 -> V=1.0, theta=0.0
% INFO    : Bus 5915	: V=1.051929, theta=-13.750141 -> V=1.0, theta=0.0
% INFO    : Bus 5916	: V=1.031135, theta=4.071247 -> V=1.0, theta=0.0
% INFO    : Bus 5917	: V=1.012556, theta=-5.179216 -> V=1.0, theta=0.0
% INFO    : Bus 5918	: V=0.956119, theta=-6.683602 -> V=1.0, theta=0.0
% INFO    : Bus 5919	: V=1.009506, theta=-11.672246 -> V=1.0, theta=0.0
% INFO    : Bus 5920	: V=1.090479, theta=-4.891767 -> V=1.0, theta=0.0
% INFO    : Bus 5921	: V=1.028879, theta=18.453528 -> V=1.0, theta=0.0
% INFO    : Bus 5922	: V=1.005029, theta=17.484263 -> V=1.0, theta=0.0
% INFO    : Bus 5923	: V=1.043233, theta=84.231609 -> V=1.0, theta=0.0
% INFO    : Bus 5924	: V=1.009892, theta=4.868208 -> V=1.0, theta=0.0
% INFO    : Bus 5925	: V=0.972084, theta=-6.601209 -> V=1.0, theta=0.0
% INFO    : Bus 5926	: V=1.017545, theta=6.135969 -> V=1.0, theta=0.0
% INFO    : Bus 5927	: V=1.028214, theta=5.959624 -> V=1.0, theta=0.0
% INFO    : Bus 5928	: V=1.044924, theta=29.406092 -> V=1.0, theta=0.0
% INFO    : Bus 5929	: V=1.032126, theta=34.816975 -> V=1.0, theta=0.0
% INFO    : Bus 5930	: V=1.032126, theta=34.816975 -> V=1.0, theta=0.0
% INFO    : Bus 5931	: V=1.0234, theta=3.527787 -> V=1.0, theta=0.0
% INFO    : Bus 5932	: V=1.032126, theta=34.816975 -> V=1.0, theta=0.0
% INFO    : Bus 5933	: V=1.032126, theta=34.816975 -> V=1.0, theta=0.0
% INFO    : Bus 5934	: V=1.032126, theta=34.816975 -> V=1.0, theta=0.0
% INFO    : Bus 5935	: V=1.03284, theta=33.745209 -> V=1.0, theta=0.0
% INFO    : Bus 5936	: V=1.03284, theta=33.745209 -> V=1.0, theta=0.0
% INFO    : Bus 5937	: V=1.030929, theta=7.980983 -> V=1.0, theta=0.0
% INFO    : Bus 5938	: V=1.019496, theta=15.814985 -> V=1.0, theta=0.0
% INFO    : Bus 5939	: V=1.030376, theta=55.872614 -> V=1.0, theta=0.0
% INFO    : Bus 5940	: V=1.020557, theta=9.624602 -> V=1.0, theta=0.0
% INFO    : Bus 5941	: V=1.015548, theta=14.593293 -> V=1.0, theta=0.0
% INFO    : Bus 5942	: V=1.015926, theta=14.190338 -> V=1.0, theta=0.0
% INFO    : Bus 5943	: V=1.021785, theta=5.75129 -> V=1.0, theta=0.0
% INFO    : Bus 5944	: V=0.964065, theta=-6.238285 -> V=1.0, theta=0.0
% INFO    : Bus 5945	: V=1.058336, theta=25.706117 -> V=1.0, theta=0.0
% INFO    : Bus 5946	: V=1.025378, theta=12.036667 -> V=1.0, theta=0.0
% INFO    : Bus 5947	: V=1.061006, theta=27.420501 -> V=1.0, theta=0.0
% INFO    : Bus 5948	: V=1.016554, theta=19.011609 -> V=1.0, theta=0.0
% INFO    : Bus 5949	: V=0.998206, theta=29.448628 -> V=1.0, theta=0.0
% INFO    : Bus 5950	: V=1.048029, theta=39.867702 -> V=1.0, theta=0.0
% INFO    : Bus 5951	: V=1.057237, theta=76.895536 -> V=1.0, theta=0.0
% INFO    : Bus 5952	: V=0.981012, theta=-5.330129 -> V=1.0, theta=0.0
% INFO    : Bus 5953	: V=1.049406, theta=-5.456139 -> V=1.0, theta=0.0
% INFO    : Bus 5954	: V=1.007312, theta=-8.549741 -> V=1.0, theta=0.0
% INFO    : Bus 5955	: V=1.013531, theta=-19.654143 -> V=1.0, theta=0.0
% INFO    : Bus 5956	: V=1.013531, theta=-19.654143 -> V=1.0, theta=0.0
% INFO    : Bus 5957	: V=1.013531, theta=-19.654143 -> V=1.0, theta=0.0
% INFO    : Bus 5958	: V=1.013531, theta=-19.654143 -> V=1.0, theta=0.0
% INFO    : Bus 5959	: V=1.045284, theta=8.595428 -> V=1.0, theta=0.0
% INFO    : Bus 5960	: V=1.023365, theta=19.406767 -> V=1.0, theta=0.0
% INFO    : Bus 5961	: V=1.022689, theta=-16.891323 -> V=1.0, theta=0.0
% INFO    : Bus 5962	: V=1.016779, theta=36.467514 -> V=1.0, theta=0.0
% INFO    : Bus 5963	: V=1.040642, theta=8.532255 -> V=1.0, theta=0.0
% INFO    : Bus 5964	: V=1.008348, theta=30.337205 -> V=1.0, theta=0.0
% INFO    : Bus 5965	: V=0.985995, theta=10.771118 -> V=1.0, theta=0.0
% INFO    : Bus 5966	: V=1.011585, theta=-20.232733 -> V=1.0, theta=0.0
% INFO    : Bus 5967	: V=1.097943, theta=64.987411 -> V=1.0, theta=0.0
% INFO    : Bus 5968	: V=1.046992, theta=24.651278 -> V=1.0, theta=0.0
% INFO    : Bus 5969	: V=1.034951, theta=-1.196557 -> V=1.0, theta=0.0
% INFO    : Bus 5970	: V=1.010211, theta=-20.853988 -> V=1.0, theta=0.0
% INFO    : Bus 5971	: V=1.000938, theta=3.696158 -> V=1.0, theta=0.0
% INFO    : Bus 5972	: V=1.036314, theta=28.432012 -> V=1.0, theta=0.0
% INFO    : Bus 5973	: V=1.066829, theta=5.050047 -> V=1.0, theta=0.0
% INFO    : Bus 5974	: V=1.064411, theta=1.408548 -> V=1.0, theta=0.0
% INFO    : Bus 5975	: V=1.014887, theta=-2.059817 -> V=1.0, theta=0.0
% INFO    : Bus 5976	: V=1.027966, theta=-0.065388 -> V=1.0, theta=0.0
% INFO    : Bus 5977	: V=1.028438, theta=-19.446471 -> V=1.0, theta=0.0
% INFO    : Bus 5978	: V=1.02806, theta=-6.75496 -> V=1.0, theta=0.0
% INFO    : Bus 5979	: V=1.028283, theta=16.586422 -> V=1.0, theta=0.0
% INFO    : Bus 5980	: V=0.968446, theta=-9.259647 -> V=1.0, theta=0.0
% INFO    : Bus 5981	: V=1.015899, theta=23.470813 -> V=1.0, theta=0.0
% INFO    : Bus 5982	: V=1.031159, theta=7.793526 -> V=1.0, theta=0.0
% INFO    : Bus 5983	: V=0.986074, theta=-5.521684 -> V=1.0, theta=0.0
% INFO    : Bus 5984	: V=1.016616, theta=-4.658699 -> V=1.0, theta=0.0
% INFO    : Bus 5985	: V=1.002412, theta=27.878654 -> V=1.0, theta=0.0
% INFO    : Bus 5986	: V=0.971925, theta=7.112503 -> V=1.0, theta=0.0
% INFO    : Bus 5987	: V=1.041616, theta=36.679648 -> V=1.0, theta=0.0
% INFO    : Bus 5988	: V=1.041616, theta=36.679648 -> V=1.0, theta=0.0
% INFO    : Bus 5989	: V=1.039304, theta=37.982317 -> V=1.0, theta=0.0
% INFO    : Bus 5990	: V=1.039304, theta=37.982317 -> V=1.0, theta=0.0
% INFO    : Bus 5991	: V=1.078833, theta=-3.907281 -> V=1.0, theta=0.0
% INFO    : Bus 5992	: V=1.015185, theta=-4.986575 -> V=1.0, theta=0.0
% INFO    : Bus 5993	: V=1.031888, theta=35.715294 -> V=1.0, theta=0.0
% INFO    : Bus 5994	: V=1.023642, theta=0.458031 -> V=1.0, theta=0.0
% INFO    : Bus 5995	: V=1.017687, theta=25.51753 -> V=1.0, theta=0.0
% INFO    : Bus 5996	: V=0.995065, theta=-3.415633 -> V=1.0, theta=0.0
% INFO    : Bus 5997	: V=1.029204, theta=31.870214 -> V=1.0, theta=0.0
% INFO    : Bus 5998	: V=1.044885, theta=42.101051 -> V=1.0, theta=0.0
% INFO    : Bus 5999	: V=1.03143, theta=0.621932 -> V=1.0, theta=0.0
% INFO    : Bus 6000	: V=1.003181, theta=0.104403 -> V=1.0, theta=0.0
% INFO    : Bus 6001	: V=1.071599, theta=-4.221692 -> V=1.0, theta=0.0
% INFO    : Bus 6002	: V=1.027152, theta=23.121261 -> V=1.0, theta=0.0
% INFO    : Bus 6003	: V=1.027152, theta=23.121261 -> V=1.0, theta=0.0
% INFO    : Bus 6004	: V=1.018643, theta=-25.676655 -> V=1.0, theta=0.0
% INFO    : Bus 6005	: V=1.027152, theta=23.121261 -> V=1.0, theta=0.0
% INFO    : Bus 6006	: V=1.027152, theta=23.121261 -> V=1.0, theta=0.0
% INFO    : Bus 6007	: V=1.027152, theta=23.121261 -> V=1.0, theta=0.0
% INFO    : Bus 6008	: V=1.027152, theta=23.121261 -> V=1.0, theta=0.0
% INFO    : Bus 6009	: V=1.016602, theta=20.114087 -> V=1.0, theta=0.0
% INFO    : Bus 6010	: V=1.016233, theta=-10.469824 -> V=1.0, theta=0.0
% INFO    : Bus 6011	: V=1.032195, theta=20.523086 -> V=1.0, theta=0.0
% INFO    : Bus 6012	: V=1.02714, theta=64.681878 -> V=1.0, theta=0.0
% INFO    : Bus 6013	: V=1.027412, theta=1.646975 -> V=1.0, theta=0.0
% INFO    : Bus 6014	: V=1.03143, theta=0.621932 -> V=1.0, theta=0.0
% INFO    : Bus 6015	: V=1.028327, theta=8.752555 -> V=1.0, theta=0.0
% INFO    : Bus 6016	: V=0.991806, theta=18.024083 -> V=1.0, theta=0.0
% INFO    : Bus 6017	: V=1.050579, theta=35.320834 -> V=1.0, theta=0.0
% INFO    : Bus 6018	: V=0.981626, theta=15.778389 -> V=1.0, theta=0.0
% INFO    : Bus 6019	: V=1.027596, theta=-0.273797 -> V=1.0, theta=0.0
% INFO    : Bus 6020	: V=1.10805, theta=-0.569645 -> V=1.0, theta=0.0
% INFO    : Bus 6021	: V=0.996578, theta=38.818649 -> V=1.0, theta=0.0
% INFO    : Bus 6022	: V=1.009788, theta=-5.34131 -> V=1.0, theta=0.0
% INFO    : Bus 6023	: V=1.045612, theta=86.470349 -> V=1.0, theta=0.0
% INFO    : Bus 6024	: V=0.998597, theta=-10.549173 -> V=1.0, theta=0.0
% INFO    : Bus 6025	: V=1.026207, theta=-11.793103 -> V=1.0, theta=0.0
% INFO    : Bus 6026	: V=1.022727, theta=-30.889809 -> V=1.0, theta=0.0
% INFO    : Bus 6027	: V=1.010815, theta=-20.730474 -> V=1.0, theta=0.0
% INFO    : Bus 6028	: V=0.982613, theta=18.688338 -> V=1.0, theta=0.0
% INFO    : Bus 6029	: V=0.955097, theta=-16.549447 -> V=1.0, theta=0.0
% INFO    : Bus 6030	: V=1.063003, theta=10.873519 -> V=1.0, theta=0.0
% INFO    : Bus 6031	: V=1.06091, theta=18.606651 -> V=1.0, theta=0.0
% INFO    : Bus 6032	: V=1.030262, theta=45.324578 -> V=1.0, theta=0.0
% INFO    : Bus 6033	: V=0.970512, theta=4.936778 -> V=1.0, theta=0.0
% INFO    : Bus 6034	: V=1.009892, theta=4.868208 -> V=1.0, theta=0.0
% INFO    : Bus 6035	: V=1.022485, theta=41.156373 -> V=1.0, theta=0.0
% INFO    : Bus 6036	: V=1.030326, theta=29.794757 -> V=1.0, theta=0.0
% INFO    : Bus 6037	: V=1.010682, theta=19.216431 -> V=1.0, theta=0.0
% INFO    : Bus 6038	: V=0.981513, theta=33.636923 -> V=1.0, theta=0.0
% INFO    : Bus 6039	: V=1.054609, theta=40.170592 -> V=1.0, theta=0.0
% INFO    : Bus 6040	: V=1.054609, theta=40.170592 -> V=1.0, theta=0.0
% INFO    : Bus 6041	: V=0.985319, theta=0.658331 -> V=1.0, theta=0.0
% INFO    : Bus 6042	: V=1.021057, theta=32.465877 -> V=1.0, theta=0.0
% INFO    : Bus 6043	: V=1.034131, theta=30.32841 -> V=1.0, theta=0.0
% INFO    : Bus 6044	: V=1.042458, theta=13.473477 -> V=1.0, theta=0.0
% INFO    : Bus 6045	: V=1.003423, theta=-17.153993 -> V=1.0, theta=0.0
% INFO    : Bus 6046	: V=1.008604, theta=11.47174 -> V=1.0, theta=0.0
% INFO    : Bus 6047	: V=1.036671, theta=5.406937 -> V=1.0, theta=0.0
% INFO    : Bus 6048	: V=1.055592, theta=83.040122 -> V=1.0, theta=0.0
% INFO    : Bus 6049	: V=1.035838, theta=-5.172678 -> V=1.0, theta=0.0
% INFO    : Bus 6050	: V=0.97203, theta=-23.552605 -> V=1.0, theta=0.0
% INFO    : Bus 6051	: V=1.01017, theta=51.775874 -> V=1.0, theta=0.0
% INFO    : Bus 6052	: V=1.009109, theta=14.405897 -> V=1.0, theta=0.0
% INFO    : Bus 6053	: V=1.063491, theta=70.230354 -> V=1.0, theta=0.0
% INFO    : Bus 6054	: V=1.046321, theta=-3.291866 -> V=1.0, theta=0.0
% INFO    : Bus 6055	: V=1.030356, theta=27.865848 -> V=1.0, theta=0.0
% INFO    : Bus 6056	: V=1.003143, theta=62.493742 -> V=1.0, theta=0.0
% INFO    : Bus 6057	: V=0.987794, theta=23.062821 -> V=1.0, theta=0.0
% INFO    : Bus 6058	: V=1.036943, theta=14.917752 -> V=1.0, theta=0.0
% INFO    : Bus 6059	: V=1.01934, theta=-18.297835 -> V=1.0, theta=0.0
% INFO    : Bus 6060	: V=0.927915, theta=-10.328649 -> V=1.0, theta=0.0
% INFO    : Bus 6061	: V=1.009529, theta=21.188144 -> V=1.0, theta=0.0
% INFO    : Bus 6062	: V=1.008772, theta=22.488054 -> V=1.0, theta=0.0
% INFO    : Bus 6063	: V=1.024416, theta=10.242461 -> V=1.0, theta=0.0
% INFO    : Bus 6064	: V=0.990322, theta=11.749369 -> V=1.0, theta=0.0
% INFO    : Bus 6065	: V=1.057121, theta=10.685511 -> V=1.0, theta=0.0
% INFO    : Bus 6066	: V=1.019403, theta=-19.675877 -> V=1.0, theta=0.0
% INFO    : Bus 6067	: V=1.015409, theta=36.155958 -> V=1.0, theta=0.0
% INFO    : Bus 6068	: V=1.037973, theta=11.471538 -> V=1.0, theta=0.0
% INFO    : Bus 6069	: V=1.015065, theta=-1.760043 -> V=1.0, theta=0.0
% INFO    : Bus 6070	: V=1.014621, theta=42.928119 -> V=1.0, theta=0.0
% INFO    : Bus 6071	: V=1.003711, theta=-22.214236 -> V=1.0, theta=0.0
% INFO    : Bus 6072	: V=1.00419, theta=31.464758 -> V=1.0, theta=0.0
% INFO    : Bus 6073	: V=1.046339, theta=-4.535753 -> V=1.0, theta=0.0
% INFO    : Bus 6074	: V=0.999472, theta=31.886733 -> V=1.0, theta=0.0
% INFO    : Bus 6075	: V=1.075296, theta=2.671869 -> V=1.0, theta=0.0
% INFO    : Bus 6076	: V=1.000808, theta=-3.647252 -> V=1.0, theta=0.0
% INFO    : Bus 6077	: V=1.015014, theta=-12.066594 -> V=1.0, theta=0.0
% INFO    : Bus 6078	: V=0.999152, theta=-2.431726 -> V=1.0, theta=0.0
% INFO    : Bus 6079	: V=1.015055, theta=32.061061 -> V=1.0, theta=0.0
% INFO    : Bus 6080	: V=1.004169, theta=6.716692 -> V=1.0, theta=0.0
% INFO    : Bus 6081	: V=1.011307, theta=8.711375 -> V=1.0, theta=0.0
% INFO    : Bus 6082	: V=1.063182, theta=4.144091 -> V=1.0, theta=0.0
% INFO    : Bus 6083	: V=1.037822, theta=28.36056 -> V=1.0, theta=0.0
% INFO    : Bus 6084	: V=0.988625, theta=9.51287 -> V=1.0, theta=0.0
% INFO    : Bus 6085	: V=1.061212, theta=43.548638 -> V=1.0, theta=0.0
% INFO    : Bus 6086	: V=0.992135, theta=88.958859 -> V=1.0, theta=0.0
% INFO    : Bus 6087	: V=1.044747, theta=17.319249 -> V=1.0, theta=0.0
% INFO    : Bus 6088	: V=1.016616, theta=-4.658699 -> V=1.0, theta=0.0
% INFO    : Bus 6089	: V=1.042545, theta=18.989939 -> V=1.0, theta=0.0
% INFO    : Bus 6090	: V=1.030904, theta=22.114026 -> V=1.0, theta=0.0
% INFO    : Bus 6091	: V=1.030904, theta=22.114026 -> V=1.0, theta=0.0
% INFO    : Bus 6092	: V=1.032747, theta=21.521572 -> V=1.0, theta=0.0
% INFO    : Bus 6093	: V=1.044747, theta=17.319249 -> V=1.0, theta=0.0
% INFO    : Bus 6094	: V=1.014655, theta=7.023289 -> V=1.0, theta=0.0
% INFO    : Bus 6095	: V=1.080121, theta=-12.378342 -> V=1.0, theta=0.0
% INFO    : Bus 6096	: V=1.022821, theta=44.842821 -> V=1.0, theta=0.0
% INFO    : Bus 6097	: V=1.042545, theta=18.989939 -> V=1.0, theta=0.0
% INFO    : Bus 6098	: V=1.042545, theta=18.989939 -> V=1.0, theta=0.0
% INFO    : Bus 6099	: V=1.023281, theta=24.830016 -> V=1.0, theta=0.0
% INFO    : Bus 6100	: V=1.013701, theta=-8.764256 -> V=1.0, theta=0.0
% INFO    : Bus 6101	: V=1.033145, theta=20.10233 -> V=1.0, theta=0.0
% INFO    : Bus 6102	: V=1.029399, theta=77.694517 -> V=1.0, theta=0.0
% INFO    : Bus 6103	: V=1.082967, theta=1.032196 -> V=1.0, theta=0.0
% INFO    : Bus 6104	: V=0.992505, theta=32.70807 -> V=1.0, theta=0.0
% INFO    : Bus 6105	: V=1.045772, theta=-14.51788 -> V=1.0, theta=0.0
% INFO    : Bus 6106	: V=1.076107, theta=86.31696 -> V=1.0, theta=0.0
% INFO    : Bus 6107	: V=1.043087, theta=11.638661 -> V=1.0, theta=0.0
% INFO    : Bus 6108	: V=1.012364, theta=11.991469 -> V=1.0, theta=0.0
% INFO    : Bus 6109	: V=1.013488, theta=15.812501 -> V=1.0, theta=0.0
% INFO    : Bus 6110	: V=0.994612, theta=-8.532772 -> V=1.0, theta=0.0
% INFO    : Bus 6111	: V=0.998443, theta=-1.488477 -> V=1.0, theta=0.0
% INFO    : Bus 6112	: V=1.123449, theta=-0.180616 -> V=1.0, theta=0.0
% INFO    : Bus 6113	: V=1.038344, theta=25.364547 -> V=1.0, theta=0.0
% INFO    : Bus 6114	: V=1.010168, theta=12.38255 -> V=1.0, theta=0.0
% INFO    : Bus 6115	: V=1.012394, theta=-17.98108 -> V=1.0, theta=0.0
% INFO    : Bus 6116	: V=1.0171, theta=-4.093262 -> V=1.0, theta=0.0
% INFO    : Bus 6117	: V=1.02244, theta=38.825086 -> V=1.0, theta=0.0
% INFO    : Bus 6118	: V=0.999051, theta=-22.980681 -> V=1.0, theta=0.0
% INFO    : Bus 6119	: V=0.953757, theta=-7.790324 -> V=1.0, theta=0.0
% INFO    : Bus 6120	: V=0.984959, theta=-4.457638 -> V=1.0, theta=0.0
% INFO    : Bus 6121	: V=1.029542, theta=-3.096329 -> V=1.0, theta=0.0
% INFO    : Bus 6122	: V=1.008844, theta=-3.098739 -> V=1.0, theta=0.0
% INFO    : Bus 6123	: V=1.021005, theta=21.987746 -> V=1.0, theta=0.0
% INFO    : Bus 6124	: V=0.998791, theta=-11.061968 -> V=1.0, theta=0.0
% INFO    : Bus 6125	: V=1.010111, theta=14.513609 -> V=1.0, theta=0.0
% INFO    : Bus 6126	: V=1.015624, theta=-8.566527 -> V=1.0, theta=0.0
% INFO    : Bus 6127	: V=1.010949, theta=-10.142394 -> V=1.0, theta=0.0
% INFO    : Bus 6128	: V=1.090805, theta=71.912751 -> V=1.0, theta=0.0
% INFO    : Bus 6129	: V=1.0104, theta=15.56306 -> V=1.0, theta=0.0
% INFO    : Bus 6130	: V=1.019692, theta=25.075054 -> V=1.0, theta=0.0
% INFO    : Bus 6131	: V=1.014679, theta=-17.550577 -> V=1.0, theta=0.0
% INFO    : Bus 6132	: V=1.033224, theta=23.231932 -> V=1.0, theta=0.0
% INFO    : Bus 6133	: V=1.027165, theta=-6.569477 -> V=1.0, theta=0.0
% INFO    : Bus 6134	: V=1.005425, theta=-4.989476 -> V=1.0, theta=0.0
% INFO    : Bus 6135	: V=1.031189, theta=-1.476188 -> V=1.0, theta=0.0
% INFO    : Bus 6136	: V=1.017021, theta=-18.281991 -> V=1.0, theta=0.0
% INFO    : Bus 6137	: V=1.019529, theta=-16.098943 -> V=1.0, theta=0.0
% INFO    : Bus 6138	: V=1.030727, theta=91.348864 -> V=1.0, theta=0.0
% INFO    : Bus 6139	: V=1.030727, theta=91.348864 -> V=1.0, theta=0.0
% INFO    : Bus 6140	: V=1.030727, theta=91.348864 -> V=1.0, theta=0.0
% INFO    : Bus 6141	: V=1.028568, theta=11.503252 -> V=1.0, theta=0.0
% INFO    : Bus 6142	: V=1.01831, theta=-6.363543 -> V=1.0, theta=0.0
% INFO    : Bus 6143	: V=0.98312, theta=-3.040745 -> V=1.0, theta=0.0
% INFO    : Bus 6144	: V=1.028983, theta=7.369286 -> V=1.0, theta=0.0
% INFO    : Bus 6145	: V=1.013987, theta=-14.578261 -> V=1.0, theta=0.0
% INFO    : Bus 6146	: V=1.053174, theta=4.050736 -> V=1.0, theta=0.0
% INFO    : Bus 6147	: V=0.980264, theta=24.515922 -> V=1.0, theta=0.0
% INFO    : Bus 6148	: V=1.019143, theta=2.631633 -> V=1.0, theta=0.0
% INFO    : Bus 6149	: V=1.04485, theta=18.305539 -> V=1.0, theta=0.0
% INFO    : Bus 6150	: V=0.977987, theta=-5.025449 -> V=1.0, theta=0.0
% INFO    : Bus 6151	: V=1.074706, theta=42.983853 -> V=1.0, theta=0.0
% INFO    : Bus 6152	: V=1.013998, theta=19.384747 -> V=1.0, theta=0.0
% INFO    : Bus 6153	: V=0.95811, theta=-5.43376 -> V=1.0, theta=0.0
% INFO    : Bus 6154	: V=1.068588, theta=31.972979 -> V=1.0, theta=0.0
% INFO    : Bus 6155	: V=1.018029, theta=-17.367562 -> V=1.0, theta=0.0
% INFO    : Bus 6156	: V=1.024861, theta=-2.735628 -> V=1.0, theta=0.0
% INFO    : Bus 6157	: V=1.027114, theta=22.163566 -> V=1.0, theta=0.0
% INFO    : Bus 6158	: V=1.065116, theta=30.409943 -> V=1.0, theta=0.0
% INFO    : Bus 6159	: V=1.015642, theta=-21.99726 -> V=1.0, theta=0.0
% INFO    : Bus 6160	: V=1.015642, theta=-21.99726 -> V=1.0, theta=0.0
% INFO    : Bus 6161	: V=1.035942, theta=7.607952 -> V=1.0, theta=0.0
% INFO    : Bus 6162	: V=1.035942, theta=7.607952 -> V=1.0, theta=0.0
% INFO    : Bus 6163	: V=1.024003, theta=-9.536137 -> V=1.0, theta=0.0
% INFO    : Bus 6164	: V=1.001961, theta=33.696499 -> V=1.0, theta=0.0
% INFO    : Bus 6165	: V=1.014678, theta=-19.145251 -> V=1.0, theta=0.0
% INFO    : Bus 6166	: V=1.014678, theta=-19.145251 -> V=1.0, theta=0.0
% INFO    : Bus 6167	: V=1.024289, theta=-14.563347 -> V=1.0, theta=0.0
% INFO    : Bus 6168	: V=1.014678, theta=-19.145251 -> V=1.0, theta=0.0
% INFO    : Bus 6169	: V=1.046319, theta=35.394029 -> V=1.0, theta=0.0
% INFO    : Bus 6170	: V=1.014678, theta=-19.145251 -> V=1.0, theta=0.0
% INFO    : Bus 6171	: V=1.011745, theta=17.062335 -> V=1.0, theta=0.0
% INFO    : Bus 6172	: V=0.99209, theta=89.123449 -> V=1.0, theta=0.0
% INFO    : Bus 6173	: V=1.026557, theta=7.921498 -> V=1.0, theta=0.0
% INFO    : Bus 6174	: V=1.003336, theta=-13.963068 -> V=1.0, theta=0.0
% INFO    : Bus 6175	: V=0.99484, theta=-3.165135 -> V=1.0, theta=0.0
% INFO    : Bus 6176	: V=0.976527, theta=-15.468409 -> V=1.0, theta=0.0
% INFO    : Bus 6177	: V=1.018651, theta=-12.512781 -> V=1.0, theta=0.0
% INFO    : Bus 6178	: V=1.024234, theta=16.336837 -> V=1.0, theta=0.0
% INFO    : Bus 6179	: V=1.018329, theta=-16.147917 -> V=1.0, theta=0.0
% INFO    : Bus 6180	: V=1.026563, theta=26.257444 -> V=1.0, theta=0.0
% INFO    : Bus 6181	: V=1.021802, theta=6.666844 -> V=1.0, theta=0.0
% INFO    : Bus 6182	: V=1.127406, theta=-0.281581 -> V=1.0, theta=0.0
% INFO    : Bus 6183	: V=1.050679, theta=44.063233 -> V=1.0, theta=0.0
% INFO    : Bus 6184	: V=1.044427, theta=-4.588031 -> V=1.0, theta=0.0
% INFO    : Bus 6185	: V=1.027975, theta=4.169052 -> V=1.0, theta=0.0
% INFO    : Bus 6186	: V=1.075847, theta=0.359401 -> V=1.0, theta=0.0
% INFO    : Bus 6187	: V=1.029931, theta=14.928203 -> V=1.0, theta=0.0
% INFO    : Bus 6188	: V=1.07128, theta=88.404374 -> V=1.0, theta=0.0
% INFO    : Bus 6189	: V=1.035738, theta=7.298143 -> V=1.0, theta=0.0
% INFO    : Bus 6190	: V=1.024006, theta=37.242884 -> V=1.0, theta=0.0
% INFO    : Bus 6191	: V=1.028754, theta=93.767882 -> V=1.0, theta=0.0
% INFO    : Bus 6192	: V=1.031157, theta=34.96917 -> V=1.0, theta=0.0
% INFO    : Bus 6193	: V=1.025991, theta=-18.980906 -> V=1.0, theta=0.0
% INFO    : Bus 6194	: V=1.025991, theta=-18.980906 -> V=1.0, theta=0.0
% INFO    : Bus 6195	: V=1.019411, theta=-14.420581 -> V=1.0, theta=0.0
% INFO    : Bus 6196	: V=1.026879, theta=64.663185 -> V=1.0, theta=0.0
% INFO    : Bus 6197	: V=0.978193, theta=-8.678554 -> V=1.0, theta=0.0
% INFO    : Bus 6198	: V=1.033645, theta=-10.792881 -> V=1.0, theta=0.0
% INFO    : Bus 6199	: V=1.021456, theta=23.220478 -> V=1.0, theta=0.0
% INFO    : Bus 6200	: V=0.98149, theta=26.04182 -> V=1.0, theta=0.0
% INFO    : Bus 6201	: V=1.048523, theta=41.360645 -> V=1.0, theta=0.0
% INFO    : Bus 6202	: V=1.048523, theta=41.360645 -> V=1.0, theta=0.0
% INFO    : Bus 6203	: V=1.050193, theta=41.315696 -> V=1.0, theta=0.0
% INFO    : Bus 6204	: V=1.050193, theta=41.315696 -> V=1.0, theta=0.0
% INFO    : Bus 6205	: V=1.013177, theta=2.793231 -> V=1.0, theta=0.0
% INFO    : Bus 6206	: V=1.010737, theta=-10.615253 -> V=1.0, theta=0.0
% INFO    : Bus 6207	: V=1.037904, theta=12.680695 -> V=1.0, theta=0.0
% INFO    : Bus 6208	: V=1.062519, theta=23.472046 -> V=1.0, theta=0.0
% INFO    : Bus 6209	: V=0.996523, theta=91.383121 -> V=1.0, theta=0.0
% INFO    : Bus 6210	: V=1.045359, theta=10.101302 -> V=1.0, theta=0.0
% INFO    : Bus 6211	: V=0.980902, theta=-17.246984 -> V=1.0, theta=0.0
% INFO    : Bus 6212	: V=1.021013, theta=29.620439 -> V=1.0, theta=0.0
% INFO    : Bus 6213	: V=1.029044, theta=-14.386411 -> V=1.0, theta=0.0
% INFO    : Bus 6214	: V=1.01222, theta=-5.332586 -> V=1.0, theta=0.0
% INFO    : Bus 6215	: V=1.023729, theta=-10.001413 -> V=1.0, theta=0.0
% INFO    : Bus 6216	: V=0.992242, theta=-4.42905 -> V=1.0, theta=0.0
% INFO    : Bus 6217	: V=1.064596, theta=12.664928 -> V=1.0, theta=0.0
% INFO    : Bus 6218	: V=1.029044, theta=-14.386411 -> V=1.0, theta=0.0
% INFO    : Bus 6219	: V=1.025649, theta=-20.066719 -> V=1.0, theta=0.0
% INFO    : Bus 6220	: V=1.023566, theta=-9.987944 -> V=1.0, theta=0.0
% INFO    : Bus 6221	: V=1.013445, theta=-14.636462 -> V=1.0, theta=0.0
% INFO    : Bus 6222	: V=1.049638, theta=-6.515397 -> V=1.0, theta=0.0
% INFO    : Bus 6223	: V=0.976033, theta=36.171732 -> V=1.0, theta=0.0
% INFO    : Bus 6224	: V=1.012976, theta=-20.015955 -> V=1.0, theta=0.0
% INFO    : Bus 6225	: V=1.035838, theta=-5.172678 -> V=1.0, theta=0.0
% INFO    : Bus 6226	: V=1.062007, theta=32.438041 -> V=1.0, theta=0.0
% INFO    : Bus 6227	: V=1.050331, theta=30.533232 -> V=1.0, theta=0.0
% INFO    : Bus 6228	: V=1.023396, theta=15.789487 -> V=1.0, theta=0.0
% INFO    : Bus 6229	: V=0.980794, theta=-8.763251 -> V=1.0, theta=0.0
% INFO    : Bus 6230	: V=1.01982, theta=-15.989494 -> V=1.0, theta=0.0
% INFO    : Bus 6231	: V=1.018103, theta=0.252161 -> V=1.0, theta=0.0
% INFO    : Bus 6232	: V=1.001314, theta=0.650862 -> V=1.0, theta=0.0
% INFO    : Bus 6233	: V=1.021333, theta=42.692724 -> V=1.0, theta=0.0
% INFO    : Bus 6234	: V=1.059812, theta=21.257384 -> V=1.0, theta=0.0
% INFO    : Bus 6235	: V=1.017659, theta=-13.828547 -> V=1.0, theta=0.0
% INFO    : Bus 6236	: V=0.86014, theta=-15.783699 -> V=1.0, theta=0.0
% INFO    : Bus 6237	: V=1.024959, theta=59.105911 -> V=1.0, theta=0.0
% INFO    : Bus 6238	: V=1.014402, theta=-27.500291 -> V=1.0, theta=0.0
% INFO    : Bus 6239	: V=1.0484, theta=-3.629317 -> V=1.0, theta=0.0
% INFO    : Bus 6240	: V=1.0128, theta=11.596616 -> V=1.0, theta=0.0
% INFO    : Bus 6241	: V=1.021588, theta=8.255339 -> V=1.0, theta=0.0
% INFO    : Bus 6242	: V=1.016154, theta=-27.023897 -> V=1.0, theta=0.0
% INFO    : Bus 6243	: V=1.031416, theta=-7.138703 -> V=1.0, theta=0.0
% INFO    : Bus 6244	: V=1.014131, theta=22.41328 -> V=1.0, theta=0.0
% INFO    : Bus 6245	: V=1.013743, theta=41.891899 -> V=1.0, theta=0.0
% INFO    : Bus 6246	: V=1.019224, theta=34.644067 -> V=1.0, theta=0.0
% INFO    : Bus 6247	: V=1.014677, theta=-8.666869 -> V=1.0, theta=0.0
% INFO    : Bus 6248	: V=1.004043, theta=-14.131992 -> V=1.0, theta=0.0
% INFO    : Bus 6249	: V=1.033678, theta=0.121424 -> V=1.0, theta=0.0
% INFO    : Bus 6250	: V=1.011682, theta=29.949869 -> V=1.0, theta=0.0
% INFO    : Bus 6251	: V=1.013533, theta=-4.833141 -> V=1.0, theta=0.0
% INFO    : Bus 6252	: V=1.017479, theta=-21.662554 -> V=1.0, theta=0.0
% INFO    : Bus 6253	: V=1.001763, theta=-1.609966 -> V=1.0, theta=0.0
% INFO    : Bus 6254	: V=1.051727, theta=31.564136 -> V=1.0, theta=0.0
% INFO    : Bus 6255	: V=0.991931, theta=48.589507 -> V=1.0, theta=0.0
% INFO    : Bus 6256	: V=1.024815, theta=-7.144323 -> V=1.0, theta=0.0
% INFO    : Bus 6257	: V=1.000676, theta=17.215156 -> V=1.0, theta=0.0
% INFO    : Bus 6258	: V=1.027842, theta=20.26667 -> V=1.0, theta=0.0
% INFO    : Bus 6259	: V=0.977081, theta=48.792581 -> V=1.0, theta=0.0
% INFO    : Bus 6260	: V=0.950103, theta=-7.728147 -> V=1.0, theta=0.0
% INFO    : Bus 6261	: V=1.067116, theta=5.990973 -> V=1.0, theta=0.0
% INFO    : Bus 6262	: V=1.055881, theta=11.701666 -> V=1.0, theta=0.0
% INFO    : Bus 6263	: V=0.927991, theta=5.596329 -> V=1.0, theta=0.0
% INFO    : Bus 6264	: V=1.005094, theta=28.687557 -> V=1.0, theta=0.0
% INFO    : Bus 6265	: V=1.015174, theta=15.585606 -> V=1.0, theta=0.0
% INFO    : Bus 6266	: V=1.013273, theta=-26.453738 -> V=1.0, theta=0.0
% INFO    : Bus 6267	: V=1.060164, theta=0.669784 -> V=1.0, theta=0.0
% INFO    : Bus 6268	: V=1.015951, theta=12.417775 -> V=1.0, theta=0.0
% INFO    : Bus 6269	: V=0.991926, theta=-11.44705 -> V=1.0, theta=0.0
% INFO    : Bus 6270	: V=1.013145, theta=33.554518 -> V=1.0, theta=0.0
% INFO    : Bus 6271	: V=1.015168, theta=-6.517912 -> V=1.0, theta=0.0
% INFO    : Bus 6272	: V=1.003919, theta=32.082214 -> V=1.0, theta=0.0
% INFO    : Bus 6273	: V=1.033074, theta=12.968949 -> V=1.0, theta=0.0
% INFO    : Bus 6274	: V=1.041697, theta=19.55122 -> V=1.0, theta=0.0
% INFO    : Bus 6275	: V=1.029062, theta=31.074575 -> V=1.0, theta=0.0
% INFO    : Bus 6276	: V=1.060659, theta=20.876727 -> V=1.0, theta=0.0
% INFO    : Bus 6277	: V=1.060659, theta=20.876838 -> V=1.0, theta=0.0
% INFO    : Bus 6278	: V=1.024788, theta=-12.464012 -> V=1.0, theta=0.0
% INFO    : Bus 6279	: V=1.060659, theta=20.876727 -> V=1.0, theta=0.0
% INFO    : Bus 6280	: V=1.022087, theta=-3.367486 -> V=1.0, theta=0.0
% INFO    : Bus 6281	: V=1.005114, theta=2.765793 -> V=1.0, theta=0.0
% INFO    : Bus 6282	: V=0.993797, theta=0.50435 -> V=1.0, theta=0.0
% INFO    : Bus 6283	: V=1.031273, theta=9.700247 -> V=1.0, theta=0.0
% INFO    : Bus 6284	: V=0.955228, theta=7.418913 -> V=1.0, theta=0.0
% INFO    : Bus 6285	: V=1.085917, theta=72.214157 -> V=1.0, theta=0.0
% INFO    : Bus 6286	: V=1.012925, theta=94.491383 -> V=1.0, theta=0.0
% INFO    : Bus 6287	: V=1.047273, theta=-2.403889 -> V=1.0, theta=0.0
% INFO    : Bus 6288	: V=1.069053, theta=21.801014 -> V=1.0, theta=0.0
% INFO    : Bus 6289	: V=1.00234, theta=-7.016126 -> V=1.0, theta=0.0
% INFO    : Bus 6290	: V=1.024233, theta=8.83079 -> V=1.0, theta=0.0
% INFO    : Bus 6291	: V=1.040138, theta=32.45384 -> V=1.0, theta=0.0
% INFO    : Bus 6292	: V=1.035813, theta=3.435348 -> V=1.0, theta=0.0
% INFO    : Bus 6293	: V=1.024188, theta=-27.15003 -> V=1.0, theta=0.0
% INFO    : Bus 6294	: V=1.016786, theta=-18.076679 -> V=1.0, theta=0.0
% INFO    : Bus 6295	: V=1.015829, theta=32.990745 -> V=1.0, theta=0.0
% INFO    : Bus 6296	: V=1.007268, theta=1.91796 -> V=1.0, theta=0.0
% INFO    : Bus 6297	: V=0.990524, theta=1.302692 -> V=1.0, theta=0.0
% INFO    : Bus 6298	: V=1.016891, theta=10.696134 -> V=1.0, theta=0.0
% INFO    : Bus 6299	: V=1.016891, theta=10.696134 -> V=1.0, theta=0.0
% INFO    : Bus 6300	: V=1.043493, theta=-1.226779 -> V=1.0, theta=0.0
% INFO    : Bus 6301	: V=1.018897, theta=7.480558 -> V=1.0, theta=0.0
% INFO    : Bus 6302	: V=1.02662, theta=-3.516785 -> V=1.0, theta=0.0
% INFO    : Bus 6303	: V=1.007406, theta=14.333514 -> V=1.0, theta=0.0
% INFO    : Bus 6304	: V=1.003487, theta=5.205063 -> V=1.0, theta=0.0
% INFO    : Bus 6305	: V=1.090507, theta=11.169589 -> V=1.0, theta=0.0
% INFO    : Bus 6306	: V=1.033802, theta=9.219584 -> V=1.0, theta=0.0
% INFO    : Bus 6307	: V=1.032903, theta=55.757518 -> V=1.0, theta=0.0
% INFO    : Bus 6308	: V=1.03125, theta=3.474686 -> V=1.0, theta=0.0
% INFO    : Bus 6309	: V=1.05329, theta=-2.80874 -> V=1.0, theta=0.0
% INFO    : Bus 6310	: V=1.054716, theta=-3.993237 -> V=1.0, theta=0.0
% INFO    : Bus 6311	: V=0.991127, theta=-1.596972 -> V=1.0, theta=0.0
% INFO    : Bus 6312	: V=1.041387, theta=-13.269592 -> V=1.0, theta=0.0
% INFO    : Bus 6313	: V=1.005819, theta=17.433285 -> V=1.0, theta=0.0
% INFO    : Bus 6314	: V=0.984601, theta=26.113186 -> V=1.0, theta=0.0
% INFO    : Bus 6315	: V=1.060094, theta=-2.00787 -> V=1.0, theta=0.0
% INFO    : Bus 6316	: V=1.018632, theta=-12.251956 -> V=1.0, theta=0.0
% INFO    : Bus 6317	: V=1.033042, theta=-4.165701 -> V=1.0, theta=0.0
% INFO    : Bus 6318	: V=0.981871, theta=1.723445 -> V=1.0, theta=0.0
% INFO    : Bus 6319	: V=1.012982, theta=-1.274503 -> V=1.0, theta=0.0
% INFO    : Bus 6320	: V=1.031351, theta=9.130329 -> V=1.0, theta=0.0
% INFO    : Bus 6321	: V=1.040814, theta=16.893773 -> V=1.0, theta=0.0
% INFO    : Bus 6322	: V=1.031589, theta=-10.695606 -> V=1.0, theta=0.0
% INFO    : Bus 6323	: V=0.967808, theta=-5.298475 -> V=1.0, theta=0.0
% INFO    : Bus 6324	: V=1.022288, theta=-13.543676 -> V=1.0, theta=0.0
% INFO    : Bus 6325	: V=1.043067, theta=14.485157 -> V=1.0, theta=0.0
% INFO    : Bus 6326	: V=1.043067, theta=14.485157 -> V=1.0, theta=0.0
% INFO    : Bus 6327	: V=1.043067, theta=14.485157 -> V=1.0, theta=0.0
% INFO    : Bus 6328	: V=1.043067, theta=14.485157 -> V=1.0, theta=0.0
% INFO    : Bus 6329	: V=1.043067, theta=14.485157 -> V=1.0, theta=0.0
% INFO    : Bus 6330	: V=1.022386, theta=38.742084 -> V=1.0, theta=0.0
% INFO    : Bus 6331	: V=1.035207, theta=-6.870994 -> V=1.0, theta=0.0
% INFO    : Bus 6332	: V=0.993205, theta=-6.773238 -> V=1.0, theta=0.0
% INFO    : Bus 6333	: V=1.025584, theta=59.039755 -> V=1.0, theta=0.0
% INFO    : Bus 6334	: V=1.039628, theta=-10.444432 -> V=1.0, theta=0.0
% INFO    : Bus 6335	: V=1.031942, theta=-8.549229 -> V=1.0, theta=0.0
% INFO    : Bus 6336	: V=1.031942, theta=-8.549229 -> V=1.0, theta=0.0
% INFO    : Bus 6337	: V=1.031942, theta=-8.549229 -> V=1.0, theta=0.0
% INFO    : Bus 6338	: V=1.007144, theta=-3.728197 -> V=1.0, theta=0.0
% INFO    : Bus 6339	: V=1.081416, theta=1.199061 -> V=1.0, theta=0.0
% INFO    : Bus 6340	: V=1.008398, theta=-23.683296 -> V=1.0, theta=0.0
% INFO    : Bus 6341	: V=1.045213, theta=9.250128 -> V=1.0, theta=0.0
% INFO    : Bus 6342	: V=0.992877, theta=-13.88975 -> V=1.0, theta=0.0
% INFO    : Bus 6343	: V=1.023125, theta=-2.909088 -> V=1.0, theta=0.0
% INFO    : Bus 6344	: V=1.054585, theta=82.616556 -> V=1.0, theta=0.0
% INFO    : Bus 6345	: V=0.967119, theta=-9.617679 -> V=1.0, theta=0.0
% INFO    : Bus 6346	: V=1.024479, theta=-0.687261 -> V=1.0, theta=0.0
% INFO    : Bus 6347	: V=1.02409, theta=0.237238 -> V=1.0, theta=0.0
% INFO    : Bus 6348	: V=1.005722, theta=-6.70794 -> V=1.0, theta=0.0
% INFO    : Bus 6349	: V=0.973116, theta=-28.905172 -> V=1.0, theta=0.0
% INFO    : Bus 6350	: V=0.992738, theta=17.76388 -> V=1.0, theta=0.0
% INFO    : Bus 6351	: V=1.055778, theta=36.671382 -> V=1.0, theta=0.0
% INFO    : Bus 6352	: V=1.055778, theta=36.671382 -> V=1.0, theta=0.0
% INFO    : Bus 6353	: V=1.070329, theta=49.112584 -> V=1.0, theta=0.0
% INFO    : Bus 6354	: V=1.070329, theta=49.112584 -> V=1.0, theta=0.0
% INFO    : Bus 6355	: V=1.0331, theta=60.584093 -> V=1.0, theta=0.0
% INFO    : Bus 6356	: V=0.992712, theta=-2.759259 -> V=1.0, theta=0.0
% INFO    : Bus 6357	: V=1.048705, theta=42.664255 -> V=1.0, theta=0.0
% INFO    : Bus 6358	: V=1.048705, theta=42.664255 -> V=1.0, theta=0.0
% INFO    : Bus 6359	: V=0.995077, theta=34.268512 -> V=1.0, theta=0.0
% INFO    : Bus 6360	: V=1.043227, theta=47.072253 -> V=1.0, theta=0.0
% INFO    : Bus 6361	: V=1.070329, theta=49.112584 -> V=1.0, theta=0.0
% INFO    : Bus 6362	: V=1.052114, theta=81.244934 -> V=1.0, theta=0.0
% INFO    : Bus 6363	: V=1.024375, theta=-1.976838 -> V=1.0, theta=0.0
% INFO    : Bus 6364	: V=1.070028, theta=2.099566 -> V=1.0, theta=0.0
% INFO    : Bus 6365	: V=1.017617, theta=-17.187976 -> V=1.0, theta=0.0
% INFO    : Bus 6366	: V=1.026296, theta=33.499485 -> V=1.0, theta=0.0
% INFO    : Bus 6367	: V=1.029058, theta=-20.283666 -> V=1.0, theta=0.0
% INFO    : Bus 6368	: V=1.032321, theta=27.942453 -> V=1.0, theta=0.0
% INFO    : Bus 6369	: V=1.014698, theta=-14.460554 -> V=1.0, theta=0.0
% INFO    : Bus 6370	: V=1.014698, theta=-14.460554 -> V=1.0, theta=0.0
% INFO    : Bus 6371	: V=1.014698, theta=-14.460554 -> V=1.0, theta=0.0
% INFO    : Bus 6372	: V=1.014698, theta=-14.460554 -> V=1.0, theta=0.0
% INFO    : Bus 6373	: V=1.072201, theta=58.84567 -> V=1.0, theta=0.0
% INFO    : Bus 6374	: V=0.955487, theta=-1.753626 -> V=1.0, theta=0.0
% INFO    : Bus 6375	: V=1.022492, theta=7.188929 -> V=1.0, theta=0.0
% INFO    : Bus 6376	: V=0.943205, theta=-12.984503 -> V=1.0, theta=0.0
% INFO    : Bus 6377	: V=0.979898, theta=-5.266097 -> V=1.0, theta=0.0
% INFO    : Bus 6378	: V=0.977474, theta=-26.890479 -> V=1.0, theta=0.0
% INFO    : Bus 6379	: V=0.983454, theta=-24.020982 -> V=1.0, theta=0.0
% INFO    : Bus 6380	: V=1.026259, theta=45.39552 -> V=1.0, theta=0.0
% INFO    : Bus 6381	: V=1.127748, theta=0.999187 -> V=1.0, theta=0.0
% INFO    : Bus 6382	: V=1.000814, theta=14.198741 -> V=1.0, theta=0.0
% INFO    : Bus 6383	: V=1.003111, theta=19.775229 -> V=1.0, theta=0.0
% INFO    : Bus 6384	: V=1.013502, theta=-11.0947 -> V=1.0, theta=0.0
% INFO    : Bus 6385	: V=1.077575, theta=72.579655 -> V=1.0, theta=0.0
% INFO    : Bus 6386	: V=1.037068, theta=80.040751 -> V=1.0, theta=0.0
% INFO    : Bus 6387	: V=0.959541, theta=-5.714015 -> V=1.0, theta=0.0
% INFO    : Bus 6388	: V=1.012813, theta=-1.040485 -> V=1.0, theta=0.0
% INFO    : Bus 6389	: V=1.062234, theta=2.581972 -> V=1.0, theta=0.0
% INFO    : Bus 6390	: V=0.991721, theta=-5.970433 -> V=1.0, theta=0.0
% INFO    : Bus 6391	: V=1.02421, theta=5.097202 -> V=1.0, theta=0.0
% INFO    : Bus 6392	: V=1.022789, theta=3.322967 -> V=1.0, theta=0.0
% INFO    : Bus 6393	: V=1.000284, theta=-9.091433 -> V=1.0, theta=0.0
% INFO    : Bus 6394	: V=1.013352, theta=12.865452 -> V=1.0, theta=0.0
% INFO    : Bus 6395	: V=0.974247, theta=28.9452 -> V=1.0, theta=0.0
% INFO    : Bus 6396	: V=1.017635, theta=26.849439 -> V=1.0, theta=0.0
% INFO    : Bus 6397	: V=0.980798, theta=11.596392 -> V=1.0, theta=0.0
% INFO    : Bus 6398	: V=1.044939, theta=29.387061 -> V=1.0, theta=0.0
% INFO    : Bus 6399	: V=1.001688, theta=-25.282589 -> V=1.0, theta=0.0
% INFO    : Bus 6400	: V=1.024694, theta=18.017866 -> V=1.0, theta=0.0
% INFO    : Bus 6401	: V=1.052205, theta=80.628473 -> V=1.0, theta=0.0
% INFO    : Bus 6402	: V=1.052231, theta=80.621613 -> V=1.0, theta=0.0
% INFO    : Bus 6403	: V=1.008601, theta=-11.667879 -> V=1.0, theta=0.0
% INFO    : Bus 6404	: V=1.052205, theta=80.628473 -> V=1.0, theta=0.0
% INFO    : Bus 6405	: V=1.047514, theta=68.881226 -> V=1.0, theta=0.0
% INFO    : Bus 6406	: V=1.040945, theta=-2.019998 -> V=1.0, theta=0.0
% INFO    : Bus 6407	: V=1.052231, theta=80.621613 -> V=1.0, theta=0.0
% INFO    : Bus 6408	: V=1.047514, theta=68.881226 -> V=1.0, theta=0.0
% INFO    : Bus 6409	: V=1.054213, theta=39.514325 -> V=1.0, theta=0.0
% INFO    : Bus 6410	: V=0.991877, theta=-1.750776 -> V=1.0, theta=0.0
% INFO    : Bus 6411	: V=0.976407, theta=-5.464167 -> V=1.0, theta=0.0
% INFO    : Bus 6412	: V=0.996489, theta=34.446399 -> V=1.0, theta=0.0
% INFO    : Bus 6413	: V=0.997389, theta=-8.959946 -> V=1.0, theta=0.0
% INFO    : Bus 6414	: V=1.064947, theta=81.922707 -> V=1.0, theta=0.0
% INFO    : Bus 6415	: V=1.061435, theta=-0.283673 -> V=1.0, theta=0.0
% INFO    : Bus 6416	: V=1.051836, theta=-4.896212 -> V=1.0, theta=0.0
% INFO    : Bus 6417	: V=1.054686, theta=33.79222 -> V=1.0, theta=0.0
% INFO    : Bus 6418	: V=1.054686, theta=33.79222 -> V=1.0, theta=0.0
% INFO    : Bus 6419	: V=1.02386, theta=-27.409382 -> V=1.0, theta=0.0
% INFO    : Bus 6420	: V=0.994392, theta=93.663435 -> V=1.0, theta=0.0
% INFO    : Bus 6421	: V=0.994839, theta=90.156106 -> V=1.0, theta=0.0
% INFO    : Bus 6422	: V=1.054686, theta=33.79222 -> V=1.0, theta=0.0
% INFO    : Bus 6423	: V=0.986477, theta=-6.386478 -> V=1.0, theta=0.0
% INFO    : Bus 6424	: V=1.045691, theta=-0.691332 -> V=1.0, theta=0.0
% INFO    : Bus 6425	: V=0.999966, theta=90.949741 -> V=1.0, theta=0.0
% INFO    : Bus 6426	: V=0.976525, theta=41.441914 -> V=1.0, theta=0.0
% INFO    : Bus 6427	: V=1.035283, theta=-13.067891 -> V=1.0, theta=0.0
% INFO    : Bus 6428	: V=1.035283, theta=-13.067891 -> V=1.0, theta=0.0
% INFO    : Bus 6429	: V=1.021473, theta=-8.614663 -> V=1.0, theta=0.0
% INFO    : Bus 6430	: V=1.018329, theta=-16.147917 -> V=1.0, theta=0.0
% INFO    : Bus 6431	: V=1.021729, theta=-11.056037 -> V=1.0, theta=0.0
% INFO    : Bus 6432	: V=1.013977, theta=-15.655534 -> V=1.0, theta=0.0
% INFO    : Bus 6433	: V=1.013977, theta=-15.655534 -> V=1.0, theta=0.0
% INFO    : Bus 6434	: V=0.972952, theta=7.217167 -> V=1.0, theta=0.0
% INFO    : Bus 6435	: V=1.056869, theta=30.897354 -> V=1.0, theta=0.0
% INFO    : Bus 6436	: V=1.063714, theta=6.510197 -> V=1.0, theta=0.0
% INFO    : Bus 6437	: V=0.99382, theta=25.664776 -> V=1.0, theta=0.0
% INFO    : Bus 6438	: V=1.014147, theta=-16.760348 -> V=1.0, theta=0.0
% INFO    : Bus 6439	: V=0.996102, theta=-10.239186 -> V=1.0, theta=0.0
% INFO    : Bus 6440	: V=1.000784, theta=-5.3448 -> V=1.0, theta=0.0
% INFO    : Bus 6441	: V=0.985655, theta=-5.031986 -> V=1.0, theta=0.0
% INFO    : Bus 6442	: V=1.033882, theta=-5.074867 -> V=1.0, theta=0.0
% INFO    : Bus 6443	: V=0.969413, theta=-12.083758 -> V=1.0, theta=0.0
% INFO    : Bus 6444	: V=0.981496, theta=25.250342 -> V=1.0, theta=0.0
% INFO    : Bus 6445	: V=0.977303, theta=-11.041494 -> V=1.0, theta=0.0
% INFO    : Bus 6446	: V=1.094333, theta=4.418276 -> V=1.0, theta=0.0
% INFO    : Bus 6447	: V=1.034404, theta=39.871817 -> V=1.0, theta=0.0
% INFO    : Bus 6448	: V=1.033845, theta=-11.409379 -> V=1.0, theta=0.0
% INFO    : Bus 6449	: V=0.999565, theta=4.245344 -> V=1.0, theta=0.0
% INFO    : Bus 6450	: V=1.012671, theta=-4.325832 -> V=1.0, theta=0.0
% INFO    : Bus 6451	: V=1.004119, theta=-8.128564 -> V=1.0, theta=0.0
% INFO    : Bus 6452	: V=1.004063, theta=-5.264305 -> V=1.0, theta=0.0
% INFO    : Bus 6453	: V=1.079919, theta=1.350644 -> V=1.0, theta=0.0
% INFO    : Bus 6454	: V=1.027739, theta=-17.648712 -> V=1.0, theta=0.0
% INFO    : Bus 6455	: V=1.012552, theta=-3.840911 -> V=1.0, theta=0.0
% INFO    : Bus 6456	: V=1.012552, theta=-3.840911 -> V=1.0, theta=0.0
% INFO    : Bus 6457	: V=1.091484, theta=80.814919 -> V=1.0, theta=0.0
% INFO    : Bus 6458	: V=1.088116, theta=75.264549 -> V=1.0, theta=0.0
% INFO    : Bus 6459	: V=1.105642, theta=4.175279 -> V=1.0, theta=0.0
% INFO    : Bus 6460	: V=1.011873, theta=-19.783189 -> V=1.0, theta=0.0
% INFO    : Bus 6461	: V=1.031847, theta=4.740375 -> V=1.0, theta=0.0
% INFO    : Bus 6462	: V=1.011513, theta=-20.230893 -> V=1.0, theta=0.0
% INFO    : Bus 6463	: V=1.074544, theta=35.547599 -> V=1.0, theta=0.0
% INFO    : Bus 6464	: V=1.053801, theta=7.308064 -> V=1.0, theta=0.0
% INFO    : Bus 6465	: V=1.050901, theta=18.201002 -> V=1.0, theta=0.0
% INFO    : Bus 6466	: V=1.081967, theta=13.950182 -> V=1.0, theta=0.0
% INFO    : Bus 6467	: V=0.995728, theta=-5.989622 -> V=1.0, theta=0.0
% INFO    : Bus 6468	: V=0.961566, theta=-8.310096 -> V=1.0, theta=0.0
% INFO    : Bus 6469	: V=0.997804, theta=1.009459 -> V=1.0, theta=0.0
% INFO    : Bus 6470	: V=1.02067, theta=-32.687496 -> V=1.0, theta=0.0
% INFO    : Bus 6471	: V=1.028916, theta=-13.292219 -> V=1.0, theta=0.0
% INFO    : Bus 6472	: V=1.041317, theta=-13.35377 -> V=1.0, theta=0.0
% INFO    : Bus 6473	: V=1.050245, theta=29.580149 -> V=1.0, theta=0.0
% INFO    : Bus 6474	: V=1.039387, theta=-2.383874 -> V=1.0, theta=0.0
% INFO    : Bus 6475	: V=1.021028, theta=-7.741887 -> V=1.0, theta=0.0
% INFO    : Bus 6476	: V=1.031498, theta=24.749019 -> V=1.0, theta=0.0
% INFO    : Bus 6477	: V=1.022447, theta=17.861755 -> V=1.0, theta=0.0
% INFO    : Bus 6478	: V=1.057304, theta=18.734409 -> V=1.0, theta=0.0
% INFO    : Bus 6479	: V=0.976882, theta=21.673666 -> V=1.0, theta=0.0
% INFO    : Bus 6480	: V=1.018888, theta=36.987079 -> V=1.0, theta=0.0
% INFO    : Bus 6481	: V=1.04035, theta=8.357264 -> V=1.0, theta=0.0
% INFO    : Bus 6482	: V=1.013426, theta=-0.97101 -> V=1.0, theta=0.0
% INFO    : Bus 6483	: V=1.009941, theta=36.737144 -> V=1.0, theta=0.0
% INFO    : Bus 6484	: V=1.010329, theta=15.30931 -> V=1.0, theta=0.0
% INFO    : Bus 6485	: V=1.021989, theta=-10.739532 -> V=1.0, theta=0.0
% INFO    : Bus 6486	: V=1.055149, theta=5.178292 -> V=1.0, theta=0.0
% INFO    : Bus 6487	: V=1.028283, theta=16.586422 -> V=1.0, theta=0.0
% INFO    : Bus 6488	: V=0.921315, theta=3.650781 -> V=1.0, theta=0.0
% INFO    : Bus 6489	: V=1.017525, theta=-4.63816 -> V=1.0, theta=0.0
% INFO    : Bus 6490	: V=1.012571, theta=-11.292378 -> V=1.0, theta=0.0
% INFO    : Bus 6491	: V=1.04554, theta=8.581299 -> V=1.0, theta=0.0
% INFO    : Bus 6492	: V=0.976911, theta=-5.807222 -> V=1.0, theta=0.0
% INFO    : Bus 6493	: V=0.985548, theta=-7.292905 -> V=1.0, theta=0.0
% INFO    : Bus 6494	: V=1.035156, theta=25.307552 -> V=1.0, theta=0.0
% INFO    : Bus 6495	: V=1.067715, theta=11.555887 -> V=1.0, theta=0.0
% INFO    : Bus 6496	: V=0.989037, theta=34.007972 -> V=1.0, theta=0.0
% INFO    : Bus 6497	: V=1.0248, theta=-18.844784 -> V=1.0, theta=0.0
% INFO    : Bus 6498	: V=1.016868, theta=22.255371 -> V=1.0, theta=0.0
% INFO    : Bus 6499	: V=1.037008, theta=26.476248 -> V=1.0, theta=0.0
% INFO    : Bus 6500	: V=1.034935, theta=24.924619 -> V=1.0, theta=0.0
% INFO    : Bus 6501	: V=1.016451, theta=-16.531897 -> V=1.0, theta=0.0
% INFO    : Bus 6502	: V=1.038846, theta=-2.91737 -> V=1.0, theta=0.0
% INFO    : Bus 6503	: V=0.971031, theta=-11.133184 -> V=1.0, theta=0.0
% INFO    : Bus 6504	: V=1.014673, theta=20.715481 -> V=1.0, theta=0.0
% INFO    : Bus 6505	: V=1.049745, theta=7.525677 -> V=1.0, theta=0.0
% INFO    : Bus 6506	: V=1.012636, theta=30.857104 -> V=1.0, theta=0.0
% INFO    : Bus 6507	: V=1.009892, theta=4.868208 -> V=1.0, theta=0.0
% INFO    : Bus 6508	: V=1.023937, theta=3.43247 -> V=1.0, theta=0.0
% INFO    : Bus 6509	: V=1.0402, theta=18.602574 -> V=1.0, theta=0.0
% INFO    : Bus 6510	: V=1.041758, theta=42.616765 -> V=1.0, theta=0.0
% INFO    : Bus 6511	: V=1.074626, theta=46.062649 -> V=1.0, theta=0.0
% INFO    : Bus 6512	: V=1.011748, theta=20.601504 -> V=1.0, theta=0.0
% INFO    : Bus 6513	: V=1.040904, theta=18.608226 -> V=1.0, theta=0.0
% INFO    : Bus 6514	: V=1.002206, theta=-2.183095 -> V=1.0, theta=0.0
% INFO    : Bus 6515	: V=1.057132, theta=-3.660314 -> V=1.0, theta=0.0
% INFO    : Bus 6516	: V=0.995974, theta=-9.032462 -> V=1.0, theta=0.0
% INFO    : Bus 6517	: V=0.988296, theta=89.600207 -> V=1.0, theta=0.0
% INFO    : Bus 6518	: V=0.988704, theta=12.931136 -> V=1.0, theta=0.0
% INFO    : Bus 6519	: V=1.016781, theta=-22.881448 -> V=1.0, theta=0.0
% INFO    : Bus 6520	: V=1.002202, theta=-5.307223 -> V=1.0, theta=0.0
% INFO    : Bus 6521	: V=0.992433, theta=-2.243554 -> V=1.0, theta=0.0
% INFO    : Bus 6522	: V=1.020074, theta=42.138042 -> V=1.0, theta=0.0
% INFO    : Bus 6523	: V=1.008427, theta=-8.814025 -> V=1.0, theta=0.0
% INFO    : Bus 6524	: V=1.022036, theta=-11.413747 -> V=1.0, theta=0.0
% INFO    : Bus 6525	: V=1.087524, theta=1.371618 -> V=1.0, theta=0.0
% INFO    : Bus 6526	: V=0.961031, theta=-1.92733 -> V=1.0, theta=0.0
% INFO    : Bus 6527	: V=1.035162, theta=21.902936 -> V=1.0, theta=0.0
% INFO    : Bus 6528	: V=1.008983, theta=30.24237 -> V=1.0, theta=0.0
% INFO    : Bus 6529	: V=1.014558, theta=-27.115835 -> V=1.0, theta=0.0
% INFO    : Bus 6530	: V=1.026433, theta=18.625558 -> V=1.0, theta=0.0
% INFO    : Bus 6531	: V=1.04041, theta=-1.359387 -> V=1.0, theta=0.0
% INFO    : Bus 6532	: V=1.021486, theta=33.002338 -> V=1.0, theta=0.0
% INFO    : Bus 6533	: V=1.020436, theta=16.327592 -> V=1.0, theta=0.0
% INFO    : Bus 6534	: V=0.966258, theta=9.890834 -> V=1.0, theta=0.0
% INFO    : Bus 6535	: V=0.985471, theta=14.787943 -> V=1.0, theta=0.0
% INFO    : Bus 6536	: V=1.010153, theta=-8.125449 -> V=1.0, theta=0.0
% INFO    : Bus 6537	: V=0.982509, theta=25.800974 -> V=1.0, theta=0.0
% INFO    : Bus 6538	: V=1.067699, theta=3.591344 -> V=1.0, theta=0.0
% INFO    : Bus 6539	: V=1.042166, theta=-4.652525 -> V=1.0, theta=0.0
% INFO    : Bus 6540	: V=1.021537, theta=9.115608 -> V=1.0, theta=0.0
% INFO    : Bus 6541	: V=1.024267, theta=0.497112 -> V=1.0, theta=0.0
% INFO    : Bus 6542	: V=1.024267, theta=0.497112 -> V=1.0, theta=0.0
% INFO    : Bus 6543	: V=1.024267, theta=0.497112 -> V=1.0, theta=0.0
% INFO    : Bus 6544	: V=1.023818, theta=-10.471889 -> V=1.0, theta=0.0
% INFO    : Bus 6545	: V=1.019094, theta=-5.889827 -> V=1.0, theta=0.0
% INFO    : Bus 6546	: V=1.106402, theta=-3.071016 -> V=1.0, theta=0.0
% INFO    : Bus 6547	: V=1.023818, theta=-10.471889 -> V=1.0, theta=0.0
% INFO    : Bus 6548	: V=1.023818, theta=-10.471889 -> V=1.0, theta=0.0
% INFO    : Bus 6549	: V=0.998877, theta=-5.06743 -> V=1.0, theta=0.0
% INFO    : Bus 6550	: V=1.028709, theta=44.833215 -> V=1.0, theta=0.0
% INFO    : Bus 6551	: V=1.053314, theta=-6.50391 -> V=1.0, theta=0.0
% INFO    : Bus 6552	: V=0.974467, theta=-6.132079 -> V=1.0, theta=0.0
% INFO    : Bus 6553	: V=0.989926, theta=-3.94964 -> V=1.0, theta=0.0
% INFO    : Bus 6554	: V=0.987546, theta=-24.919637 -> V=1.0, theta=0.0
% INFO    : Bus 6555	: V=0.99451, theta=-18.776597 -> V=1.0, theta=0.0
% INFO    : Bus 6556	: V=1.018762, theta=-7.534283 -> V=1.0, theta=0.0
% INFO    : Bus 6557	: V=1.023603, theta=23.127902 -> V=1.0, theta=0.0
% INFO    : Bus 6558	: V=1.008549, theta=32.542056 -> V=1.0, theta=0.0
% INFO    : Bus 6559	: V=1.018674, theta=-17.209554 -> V=1.0, theta=0.0
% INFO    : Bus 6560	: V=1.016289, theta=-11.291227 -> V=1.0, theta=0.0
% INFO    : Bus 6561	: V=1.02297, theta=32.327798 -> V=1.0, theta=0.0
% INFO    : Bus 6562	: V=1.01419, theta=29.738593 -> V=1.0, theta=0.0
% INFO    : Bus 6563	: V=0.998951, theta=38.095582 -> V=1.0, theta=0.0
% INFO    : Bus 6564	: V=1.018282, theta=43.66889 -> V=1.0, theta=0.0
% INFO    : Bus 6565	: V=0.936045, theta=-11.578054 -> V=1.0, theta=0.0
% INFO    : Bus 6566	: V=1.014865, theta=17.912579 -> V=1.0, theta=0.0
% INFO    : Bus 6567	: V=1.014865, theta=17.912579 -> V=1.0, theta=0.0
% INFO    : Bus 6568	: V=0.969729, theta=-14.732562 -> V=1.0, theta=0.0
% INFO    : Bus 6569	: V=1.01757, theta=30.154601 -> V=1.0, theta=0.0
% INFO    : Bus 6570	: V=1.057905, theta=79.411231 -> V=1.0, theta=0.0
% INFO    : Bus 6571	: V=0.963608, theta=-9.787433 -> V=1.0, theta=0.0
% INFO    : Bus 6572	: V=1.057634, theta=37.991837 -> V=1.0, theta=0.0
% INFO    : Bus 6573	: V=1.017763, theta=-5.85612 -> V=1.0, theta=0.0
% INFO    : Bus 6574	: V=1.0129, theta=-10.929789 -> V=1.0, theta=0.0
% INFO    : Bus 6575	: V=1.038086, theta=23.154703 -> V=1.0, theta=0.0
% INFO    : Bus 6576	: V=1.051779, theta=-6.398929 -> V=1.0, theta=0.0
% INFO    : Bus 6577	: V=1.022528, theta=15.642489 -> V=1.0, theta=0.0
% INFO    : Bus 6578	: V=1.041551, theta=41.353637 -> V=1.0, theta=0.0
% INFO    : Bus 6579	: V=1.026102, theta=-1.724689 -> V=1.0, theta=0.0
% INFO    : Bus 6580	: V=1.013214, theta=-9.554082 -> V=1.0, theta=0.0
% INFO    : Bus 6581	: V=1.053766, theta=7.292607 -> V=1.0, theta=0.0
% INFO    : Bus 6582	: V=1.031077, theta=-19.605096 -> V=1.0, theta=0.0
% INFO    : Bus 6583	: V=0.968466, theta=-12.007066 -> V=1.0, theta=0.0
% INFO    : Bus 6584	: V=0.956299, theta=35.305913 -> V=1.0, theta=0.0
% INFO    : Bus 6585	: V=0.989649, theta=6.296698 -> V=1.0, theta=0.0
% INFO    : Bus 6586	: V=1.018409, theta=-3.066024 -> V=1.0, theta=0.0
% INFO    : Bus 6587	: V=1.042629, theta=65.129501 -> V=1.0, theta=0.0
% INFO    : Bus 6588	: V=1.023758, theta=-12.955313 -> V=1.0, theta=0.0
% INFO    : Bus 6589	: V=1.023448, theta=30.391991 -> V=1.0, theta=0.0
% INFO    : Bus 6590	: V=1.039999, theta=25.6544 -> V=1.0, theta=0.0
% INFO    : Bus 6591	: V=1.009992, theta=35.445834 -> V=1.0, theta=0.0
% INFO    : Bus 6592	: V=1.0651, theta=-7.973645 -> V=1.0, theta=0.0
% INFO    : Bus 6593	: V=1.047126, theta=22.873876 -> V=1.0, theta=0.0
% INFO    : Bus 6594	: V=0.943618, theta=7.025726 -> V=1.0, theta=0.0
% INFO    : Bus 6595	: V=1.088261, theta=72.590393 -> V=1.0, theta=0.0
% INFO    : Bus 6596	: V=1.023753, theta=69.81304 -> V=1.0, theta=0.0
% INFO    : Bus 6597	: V=1.005645, theta=39.813001 -> V=1.0, theta=0.0
% INFO    : Bus 6598	: V=1.022364, theta=58.584365 -> V=1.0, theta=0.0
% INFO    : Bus 6599	: V=1.005609, theta=28.049125 -> V=1.0, theta=0.0
% INFO    : Bus 6600	: V=1.018103, theta=-17.745392 -> V=1.0, theta=0.0
% INFO    : Bus 6601	: V=1.012099, theta=-18.860818 -> V=1.0, theta=0.0
% INFO    : Bus 6602	: V=1.021005, theta=21.987746 -> V=1.0, theta=0.0
% INFO    : Bus 6603	: V=0.979933, theta=-12.309951 -> V=1.0, theta=0.0
% INFO    : Bus 6604	: V=1.030791, theta=-15.072577 -> V=1.0, theta=0.0
% INFO    : Bus 6605	: V=1.013631, theta=12.900828 -> V=1.0, theta=0.0
% INFO    : Bus 6606	: V=1.024151, theta=24.403529 -> V=1.0, theta=0.0
% INFO    : Bus 6607	: V=1.024151, theta=24.403529 -> V=1.0, theta=0.0
% INFO    : Bus 6608	: V=1.024151, theta=24.403529 -> V=1.0, theta=0.0
% INFO    : Bus 6609	: V=1.024151, theta=24.403529 -> V=1.0, theta=0.0
% INFO    : Bus 6610	: V=1.024151, theta=24.403529 -> V=1.0, theta=0.0
% INFO    : Bus 6611	: V=1.024151, theta=24.403529 -> V=1.0, theta=0.0
% INFO    : Bus 6612	: V=1.024151, theta=24.403529 -> V=1.0, theta=0.0
% INFO    : Bus 6613	: V=1.030105, theta=26.548864 -> V=1.0, theta=0.0
% INFO    : Bus 6614	: V=1.019216, theta=-14.137173 -> V=1.0, theta=0.0
% INFO    : Bus 6615	: V=0.991156, theta=88.859311 -> V=1.0, theta=0.0
% INFO    : Bus 6616	: V=1.029779, theta=8.046458 -> V=1.0, theta=0.0
% INFO    : Bus 6617	: V=1.02896, theta=-11.606592 -> V=1.0, theta=0.0
% INFO    : Bus 6618	: V=1.03097, theta=-5.06415 -> V=1.0, theta=0.0
% INFO    : Bus 6619	: V=1.006922, theta=-16.346989 -> V=1.0, theta=0.0
% INFO    : Bus 6620	: V=1.058114, theta=43.382414 -> V=1.0, theta=0.0
% INFO    : Bus 6621	: V=1.059543, theta=4.22325 -> V=1.0, theta=0.0
% INFO    : Bus 6622	: V=1.030338, theta=22.622295 -> V=1.0, theta=0.0
% INFO    : Bus 6623	: V=1.040509, theta=24.175107 -> V=1.0, theta=0.0
% INFO    : Bus 6624	: V=1.040509, theta=24.175107 -> V=1.0, theta=0.0
% INFO    : Bus 6625	: V=1.023453, theta=0.234493 -> V=1.0, theta=0.0
% INFO    : Bus 6626	: V=1.013779, theta=-20.268901 -> V=1.0, theta=0.0
% INFO    : Bus 6627	: V=0.982047, theta=26.53851 -> V=1.0, theta=0.0
% INFO    : Bus 6628	: V=1.041212, theta=-15.377355 -> V=1.0, theta=0.0
% INFO    : Bus 6629	: V=0.978503, theta=-1.75321 -> V=1.0, theta=0.0
% INFO    : Bus 6630	: V=1.040509, theta=24.175107 -> V=1.0, theta=0.0
% INFO    : Bus 6631	: V=1.04659, theta=30.049071 -> V=1.0, theta=0.0
% INFO    : Bus 6632	: V=1.029284, theta=8.268155 -> V=1.0, theta=0.0
% INFO    : Bus 6633	: V=0.976221, theta=-5.459556 -> V=1.0, theta=0.0
% INFO    : Bus 6634	: V=0.975002, theta=33.150591 -> V=1.0, theta=0.0
% INFO    : Bus 6635	: V=1.016554, theta=19.011605 -> V=1.0, theta=0.0
% INFO    : Bus 6636	: V=1.013938, theta=-10.330003 -> V=1.0, theta=0.0
% INFO    : Bus 6637	: V=0.979234, theta=35.087735 -> V=1.0, theta=0.0
% INFO    : Bus 6638	: V=1.006554, theta=28.610342 -> V=1.0, theta=0.0
% INFO    : Bus 6639	: V=1.031885, theta=-12.651409 -> V=1.0, theta=0.0
% INFO    : Bus 6640	: V=1.031885, theta=-12.651409 -> V=1.0, theta=0.0
% INFO    : Bus 6641	: V=1.031885, theta=-12.651409 -> V=1.0, theta=0.0
% INFO    : Bus 6642	: V=1.031885, theta=-12.651409 -> V=1.0, theta=0.0
% INFO    : Bus 6643	: V=1.023367, theta=-19.593969 -> V=1.0, theta=0.0
% INFO    : Bus 6644	: V=0.979542, theta=15.358319 -> V=1.0, theta=0.0
% INFO    : Bus 6645	: V=0.964386, theta=-8.067074 -> V=1.0, theta=0.0
% INFO    : Bus 6646	: V=1.05203, theta=14.372042 -> V=1.0, theta=0.0
% INFO    : Bus 6647	: V=1.009227, theta=21.977145 -> V=1.0, theta=0.0
% INFO    : Bus 6648	: V=0.986477, theta=-6.386478 -> V=1.0, theta=0.0
% INFO    : Bus 6649	: V=0.955439, theta=48.700819 -> V=1.0, theta=0.0
% INFO    : Bus 6650	: V=1.036065, theta=-16.582357 -> V=1.0, theta=0.0
% INFO    : Bus 6651	: V=1.04914, theta=42.65185 -> V=1.0, theta=0.0
% INFO    : Bus 6652	: V=0.969632, theta=6.466075 -> V=1.0, theta=0.0
% INFO    : Bus 6653	: V=1.069454, theta=39.838153 -> V=1.0, theta=0.0
% INFO    : Bus 6654	: V=1.043738, theta=-8.975119 -> V=1.0, theta=0.0
% INFO    : Bus 6655	: V=1.009163, theta=2.151893 -> V=1.0, theta=0.0
% INFO    : Bus 6656	: V=1.019587, theta=36.854451 -> V=1.0, theta=0.0
% INFO    : Bus 6657	: V=0.987522, theta=-8.995861 -> V=1.0, theta=0.0
% INFO    : Bus 6658	: V=1.012203, theta=-2.922462 -> V=1.0, theta=0.0
% INFO    : Bus 6659	: V=1.005863, theta=-11.937443 -> V=1.0, theta=0.0
% INFO    : Bus 6660	: V=1.021265, theta=4.517407 -> V=1.0, theta=0.0
% INFO    : Bus 6661	: V=1.002222, theta=19.480877 -> V=1.0, theta=0.0
% INFO    : Bus 6662	: V=1.039618, theta=-15.811939 -> V=1.0, theta=0.0
% INFO    : Bus 6663	: V=1.045666, theta=52.068402 -> V=1.0, theta=0.0
% INFO    : Bus 6664	: V=1.043316, theta=-18.000334 -> V=1.0, theta=0.0
% INFO    : Bus 6665	: V=1.005017, theta=-18.861992 -> V=1.0, theta=0.0
% INFO    : Bus 6666	: V=1.02671, theta=14.58169 -> V=1.0, theta=0.0
% INFO    : Bus 6667	: V=1.034595, theta=28.964131 -> V=1.0, theta=0.0
% INFO    : Bus 6668	: V=0.966548, theta=-5.661815 -> V=1.0, theta=0.0
% INFO    : Bus 6669	: V=0.996844, theta=-4.724158 -> V=1.0, theta=0.0
% INFO    : Bus 6670	: V=1.042317, theta=14.274354 -> V=1.0, theta=0.0
% INFO    : Bus 6671	: V=1.009689, theta=30.943205 -> V=1.0, theta=0.0
% INFO    : Bus 6672	: V=0.999657, theta=-7.602703 -> V=1.0, theta=0.0
% INFO    : Bus 6673	: V=1.005017, theta=-18.861992 -> V=1.0, theta=0.0
% INFO    : Bus 6674	: V=1.032007, theta=18.368937 -> V=1.0, theta=0.0
% INFO    : Bus 6675	: V=1.021005, theta=19.411039 -> V=1.0, theta=0.0
% INFO    : Bus 6676	: V=1.029293, theta=-6.917664 -> V=1.0, theta=0.0
% INFO    : Bus 6677	: V=0.959452, theta=-9.679922 -> V=1.0, theta=0.0
% INFO    : Bus 6678	: V=1.018742, theta=15.409657 -> V=1.0, theta=0.0
% INFO    : Bus 6679	: V=1.061515, theta=21.336436 -> V=1.0, theta=0.0
% INFO    : Bus 6680	: V=0.994234, theta=37.670381 -> V=1.0, theta=0.0
% INFO    : Bus 6681	: V=0.955296, theta=-7.17774 -> V=1.0, theta=0.0
% INFO    : Bus 6682	: V=1.029181, theta=-21.531084 -> V=1.0, theta=0.0
% INFO    : Bus 6683	: V=0.97968, theta=37.704964 -> V=1.0, theta=0.0
% INFO    : Bus 6684	: V=1.041238, theta=-3.488157 -> V=1.0, theta=0.0
% INFO    : Bus 6685	: V=1.016267, theta=-9.006082 -> V=1.0, theta=0.0
% INFO    : Bus 6686	: V=0.995022, theta=23.934845 -> V=1.0, theta=0.0
% INFO    : Bus 6687	: V=0.92232, theta=-8.785007 -> V=1.0, theta=0.0
% INFO    : Bus 6688	: V=1.012285, theta=-13.758635 -> V=1.0, theta=0.0
% INFO    : Bus 6689	: V=1.034597, theta=19.022639 -> V=1.0, theta=0.0
% INFO    : Bus 6690	: V=1.034597, theta=19.022639 -> V=1.0, theta=0.0
% INFO    : Bus 6691	: V=1.034597, theta=19.022639 -> V=1.0, theta=0.0
% INFO    : Bus 6692	: V=1.038983, theta=12.821442 -> V=1.0, theta=0.0
% INFO    : Bus 6693	: V=1.034532, theta=19.101591 -> V=1.0, theta=0.0
% INFO    : Bus 6694	: V=0.995478, theta=-2.011399 -> V=1.0, theta=0.0
% INFO    : Bus 6695	: V=1.011145, theta=22.97461 -> V=1.0, theta=0.0
% INFO    : Bus 6696	: V=1.023631, theta=36.965167 -> V=1.0, theta=0.0
% INFO    : Bus 6697	: V=1.034532, theta=19.101591 -> V=1.0, theta=0.0
% INFO    : Bus 6698	: V=1.026038, theta=-10.378066 -> V=1.0, theta=0.0
% INFO    : Bus 6699	: V=1.047642, theta=1.687712 -> V=1.0, theta=0.0
% INFO    : Bus 6700	: V=0.970463, theta=21.317703 -> V=1.0, theta=0.0
% INFO    : Bus 6701	: V=1.012648, theta=-12.139976 -> V=1.0, theta=0.0
% INFO    : Bus 6702	: V=1.025467, theta=4.507504 -> V=1.0, theta=0.0
% INFO    : Bus 6703	: V=0.9897, theta=-3.56235 -> V=1.0, theta=0.0
% INFO    : Bus 6704	: V=1.056943, theta=60.232085 -> V=1.0, theta=0.0
% INFO    : Bus 6705	: V=0.994609, theta=-3.609617 -> V=1.0, theta=0.0
% INFO    : Bus 6706	: V=1.021366, theta=16.94013 -> V=1.0, theta=0.0
% INFO    : Bus 6707	: V=1.00577, theta=-22.314337 -> V=1.0, theta=0.0
% INFO    : Bus 6708	: V=0.979823, theta=-11.301293 -> V=1.0, theta=0.0
% INFO    : Bus 6709	: V=1.021634, theta=-5.880743 -> V=1.0, theta=0.0
% INFO    : Bus 6710	: V=1.009255, theta=-15.636886 -> V=1.0, theta=0.0
% INFO    : Bus 6711	: V=0.972797, theta=-28.709094 -> V=1.0, theta=0.0
% INFO    : Bus 6712	: V=1.021983, theta=15.493568 -> V=1.0, theta=0.0
% INFO    : Bus 6713	: V=1.022626, theta=30.799151 -> V=1.0, theta=0.0
% INFO    : Bus 6714	: V=1.05121, theta=-6.447524 -> V=1.0, theta=0.0
% INFO    : Bus 6715	: V=1.036613, theta=19.194472 -> V=1.0, theta=0.0
% INFO    : Bus 6716	: V=1.053996, theta=37.457424 -> V=1.0, theta=0.0
% INFO    : Bus 6717	: V=0.996757, theta=22.457888 -> V=1.0, theta=0.0
% INFO    : Bus 6718	: V=1.004956, theta=28.372364 -> V=1.0, theta=0.0
% INFO    : Bus 6719	: V=1.028667, theta=-4.741858 -> V=1.0, theta=0.0
% INFO    : Bus 6720	: V=1.025277, theta=-5.231393 -> V=1.0, theta=0.0
% INFO    : Bus 6721	: V=1.028667, theta=-4.741858 -> V=1.0, theta=0.0
% INFO    : Bus 6722	: V=1.050523, theta=7.201001 -> V=1.0, theta=0.0
% INFO    : Bus 6723	: V=0.995804, theta=-4.792814 -> V=1.0, theta=0.0
% INFO    : Bus 6724	: V=1.043088, theta=25.157234 -> V=1.0, theta=0.0
% INFO    : Bus 6725	: V=0.978253, theta=12.237049 -> V=1.0, theta=0.0
% INFO    : Bus 6726	: V=1.016479, theta=49.02148 -> V=1.0, theta=0.0
% INFO    : Bus 6727	: V=1.017758, theta=-22.793685 -> V=1.0, theta=0.0
% INFO    : Bus 6728	: V=1.034504, theta=-7.558168 -> V=1.0, theta=0.0
% INFO    : Bus 6729	: V=1.058114, theta=43.382414 -> V=1.0, theta=0.0
% INFO    : Bus 6730	: V=1.034133, theta=19.549478 -> V=1.0, theta=0.0
% INFO    : Bus 6731	: V=1.043942, theta=17.353218 -> V=1.0, theta=0.0
% INFO    : Bus 6732	: V=0.999144, theta=-9.605939 -> V=1.0, theta=0.0
% INFO    : Bus 6733	: V=1.030889, theta=-21.232311 -> V=1.0, theta=0.0
% INFO    : Bus 6734	: V=1.005341, theta=-1.941399 -> V=1.0, theta=0.0
% INFO    : Bus 6735	: V=1.016536, theta=32.890325 -> V=1.0, theta=0.0
% INFO    : Bus 6736	: V=0.994332, theta=26.200415 -> V=1.0, theta=0.0
% INFO    : Bus 6737	: V=1.042294, theta=37.004115 -> V=1.0, theta=0.0
% INFO    : Bus 6738	: V=1.0297, theta=20.595183 -> V=1.0, theta=0.0
% INFO    : Bus 6739	: V=0.97387, theta=1.322165 -> V=1.0, theta=0.0
% INFO    : Bus 6740	: V=1.006743, theta=63.028253 -> V=1.0, theta=0.0
% INFO    : Bus 6741	: V=0.989853, theta=20.337179 -> V=1.0, theta=0.0
% INFO    : Bus 6742	: V=1.043229, theta=0.510669 -> V=1.0, theta=0.0
% INFO    : Bus 6743	: V=1.014159, theta=-22.67014 -> V=1.0, theta=0.0
% INFO    : Bus 6744	: V=0.998584, theta=90.169777 -> V=1.0, theta=0.0
% INFO    : Bus 6745	: V=1.090977, theta=1.75798 -> V=1.0, theta=0.0
% INFO    : Bus 6746	: V=1.009314, theta=-24.91449 -> V=1.0, theta=0.0
% INFO    : Bus 6747	: V=1.016595, theta=10.054092 -> V=1.0, theta=0.0
% INFO    : Bus 6748	: V=1.049409, theta=-5.379399 -> V=1.0, theta=0.0
% INFO    : Bus 6749	: V=1.046665, theta=36.809947 -> V=1.0, theta=0.0
% INFO    : Bus 6750	: V=1.057831, theta=-3.45976 -> V=1.0, theta=0.0
% INFO    : Bus 6751	: V=1.027117, theta=-8.230885 -> V=1.0, theta=0.0
% INFO    : Bus 6752	: V=1.007116, theta=2.912353 -> V=1.0, theta=0.0
% INFO    : Bus 6753	: V=0.992412, theta=40.794888 -> V=1.0, theta=0.0
% INFO    : Bus 6754	: V=1.073284, theta=1.2557 -> V=1.0, theta=0.0
% INFO    : Bus 6755	: V=1.009101, theta=17.686434 -> V=1.0, theta=0.0
% INFO    : Bus 6756	: V=1.027052, theta=-12.831896 -> V=1.0, theta=0.0
% INFO    : Bus 6757	: V=1.043178, theta=23.372652 -> V=1.0, theta=0.0
% INFO    : Bus 6758	: V=1.043178, theta=23.372652 -> V=1.0, theta=0.0
% INFO    : Bus 6759	: V=1.043178, theta=23.372652 -> V=1.0, theta=0.0
% INFO    : Bus 6760	: V=1.043178, theta=23.372652 -> V=1.0, theta=0.0
% INFO    : Bus 6761	: V=1.043178, theta=23.372652 -> V=1.0, theta=0.0
% INFO    : Bus 6762	: V=1.043178, theta=23.372652 -> V=1.0, theta=0.0
% INFO    : Bus 6763	: V=1.043178, theta=23.372652 -> V=1.0, theta=0.0
% INFO    : Bus 6764	: V=1.041274, theta=37.583261 -> V=1.0, theta=0.0
% INFO    : Bus 6765	: V=1.042697, theta=41.570544 -> V=1.0, theta=0.0
% INFO    : Bus 6766	: V=1.080871, theta=3.730594 -> V=1.0, theta=0.0
% INFO    : Bus 6767	: V=1.023409, theta=-7.389363 -> V=1.0, theta=0.0
% INFO    : Bus 6768	: V=1.050333, theta=36.708894 -> V=1.0, theta=0.0
% INFO    : Bus 6769	: V=1.034441, theta=34.869174 -> V=1.0, theta=0.0
% INFO    : Bus 6770	: V=0.973487, theta=-13.777021 -> V=1.0, theta=0.0
% INFO    : Bus 6771	: V=1.017201, theta=14.001757 -> V=1.0, theta=0.0
% INFO    : Bus 6772	: V=1.088891, theta=65.01165 -> V=1.0, theta=0.0
% INFO    : Bus 6773	: V=1.048358, theta=31.36576 -> V=1.0, theta=0.0
% INFO    : Bus 6774	: V=1.005097, theta=-2.034262 -> V=1.0, theta=0.0
% INFO    : Bus 6775	: V=1.020824, theta=-8.385682 -> V=1.0, theta=0.0
% INFO    : Bus 6776	: V=0.992389, theta=48.592226 -> V=1.0, theta=0.0
% INFO    : Bus 6777	: V=0.990041, theta=13.13447 -> V=1.0, theta=0.0
% INFO    : Bus 6778	: V=1.028164, theta=13.427248 -> V=1.0, theta=0.0
% INFO    : Bus 6779	: V=1.007318, theta=-7.256131 -> V=1.0, theta=0.0
% INFO    : Bus 6780	: V=1.035838, theta=-5.172678 -> V=1.0, theta=0.0
% INFO    : Bus 6781	: V=1.012828, theta=23.567387 -> V=1.0, theta=0.0
% INFO    : Bus 6782	: V=0.995095, theta=12.412171 -> V=1.0, theta=0.0
% INFO    : Bus 6783	: V=1.01937, theta=14.556113 -> V=1.0, theta=0.0
% INFO    : Bus 6784	: V=1.014368, theta=23.036796 -> V=1.0, theta=0.0
% INFO    : Bus 6785	: V=1.005097, theta=-2.034262 -> V=1.0, theta=0.0
% INFO    : Bus 6786	: V=1.024439, theta=14.22927 -> V=1.0, theta=0.0
% INFO    : Bus 6787	: V=1.029022, theta=2.955197 -> V=1.0, theta=0.0
% INFO    : Bus 6788	: V=0.967902, theta=-5.517482 -> V=1.0, theta=0.0
% INFO    : Bus 6789	: V=1.005097, theta=-2.034262 -> V=1.0, theta=0.0
% INFO    : Bus 6790	: V=1.021786, theta=-21.93928 -> V=1.0, theta=0.0
% INFO    : Bus 6791	: V=1.009835, theta=16.142687 -> V=1.0, theta=0.0
% INFO    : Bus 6792	: V=1.024356, theta=22.048022 -> V=1.0, theta=0.0
% INFO    : Bus 6793	: V=1.024356, theta=22.048022 -> V=1.0, theta=0.0
% INFO    : Bus 6794	: V=1.017963, theta=20.751946 -> V=1.0, theta=0.0
% INFO    : Bus 6795	: V=1.017963, theta=20.751946 -> V=1.0, theta=0.0
% INFO    : Bus 6796	: V=1.009503, theta=16.289821 -> V=1.0, theta=0.0
% INFO    : Bus 6797	: V=1.014343, theta=23.052749 -> V=1.0, theta=0.0
% INFO    : Bus 6798	: V=1.014343, theta=23.052749 -> V=1.0, theta=0.0
% INFO    : Bus 6799	: V=1.032132, theta=-0.658602 -> V=1.0, theta=0.0
% INFO    : Bus 6800	: V=1.055797, theta=-6.166252 -> V=1.0, theta=0.0
% INFO    : Bus 6801	: V=1.040566, theta=26.548404 -> V=1.0, theta=0.0
% INFO    : Bus 6802	: V=1.040566, theta=26.548404 -> V=1.0, theta=0.0
% INFO    : Bus 6803	: V=0.999928, theta=-8.812998 -> V=1.0, theta=0.0
% INFO    : Bus 6804	: V=1.011878, theta=14.800866 -> V=1.0, theta=0.0
% INFO    : Bus 6805	: V=1.046245, theta=19.550585 -> V=1.0, theta=0.0
% INFO    : Bus 6806	: V=1.021328, theta=-12.907544 -> V=1.0, theta=0.0
% INFO    : Bus 6807	: V=1.021328, theta=-12.907544 -> V=1.0, theta=0.0
% INFO    : Bus 6808	: V=1.021328, theta=-12.907544 -> V=1.0, theta=0.0
% INFO    : Bus 6809	: V=1.012736, theta=-19.855402 -> V=1.0, theta=0.0
% INFO    : Bus 6810	: V=1.012736, theta=-19.855402 -> V=1.0, theta=0.0
% INFO    : Bus 6811	: V=1.012736, theta=-19.855402 -> V=1.0, theta=0.0
% INFO    : Bus 6812	: V=1.012736, theta=-19.855402 -> V=1.0, theta=0.0
% INFO    : Bus 6813	: V=0.995335, theta=-4.631918 -> V=1.0, theta=0.0
% INFO    : Bus 6814	: V=1.021328, theta=-12.907544 -> V=1.0, theta=0.0
% INFO    : Bus 6815	: V=1.021328, theta=-12.907544 -> V=1.0, theta=0.0
% INFO    : Bus 6816	: V=1.01453, theta=29.775973 -> V=1.0, theta=0.0
% INFO    : Bus 6817	: V=0.990631, theta=-4.053386 -> V=1.0, theta=0.0
% INFO    : Bus 6818	: V=1.047319, theta=-3.179328 -> V=1.0, theta=0.0
% INFO    : Bus 6819	: V=1.035139, theta=-3.879299 -> V=1.0, theta=0.0
% INFO    : Bus 6820	: V=1.045213, theta=9.250128 -> V=1.0, theta=0.0
% INFO    : Bus 6821	: V=1.008047, theta=-17.105722 -> V=1.0, theta=0.0
% INFO    : Bus 6822	: V=0.991398, theta=31.360075 -> V=1.0, theta=0.0
% INFO    : Bus 6823	: V=1.019862, theta=29.08678 -> V=1.0, theta=0.0
% INFO    : Bus 6824	: V=1.029912, theta=29.766421 -> V=1.0, theta=0.0
% INFO    : Bus 6825	: V=1.027243, theta=48.935361 -> V=1.0, theta=0.0
% INFO    : Bus 6826	: V=1.016012, theta=-8.320606 -> V=1.0, theta=0.0
% INFO    : Bus 6827	: V=1.022241, theta=-5.274029 -> V=1.0, theta=0.0
% INFO    : Bus 6828	: V=1.017129, theta=-26.819281 -> V=1.0, theta=0.0
% INFO    : Bus 6829	: V=1.040686, theta=-17.485492 -> V=1.0, theta=0.0
% INFO    : Bus 6830	: V=0.969413, theta=5.081044 -> V=1.0, theta=0.0
% INFO    : Bus 6831	: V=1.045272, theta=2.414404 -> V=1.0, theta=0.0
% INFO    : Bus 6832	: V=0.975583, theta=-8.871913 -> V=1.0, theta=0.0
% INFO    : Bus 6833	: V=1.050095, theta=-2.695471 -> V=1.0, theta=0.0
% INFO    : Bus 6834	: V=1.03336, theta=9.2202 -> V=1.0, theta=0.0
% INFO    : Bus 6835	: V=1.033688, theta=-11.140358 -> V=1.0, theta=0.0
% INFO    : Bus 6836	: V=0.990475, theta=21.129805 -> V=1.0, theta=0.0
% INFO    : Bus 6837	: V=1.066325, theta=1.237267 -> V=1.0, theta=0.0
% INFO    : Bus 6838	: V=0.956799, theta=-6.8869 -> V=1.0, theta=0.0
% INFO    : Bus 6839	: V=1.041567, theta=2.843854 -> V=1.0, theta=0.0
% INFO    : Bus 6840	: V=1.082871, theta=70.71862 -> V=1.0, theta=0.0
% INFO    : Bus 6841	: V=1.014509, theta=-22.794624 -> V=1.0, theta=0.0
% INFO    : Bus 6842	: V=1.034464, theta=34.885068 -> V=1.0, theta=0.0
% INFO    : Bus 6843	: V=0.944554, theta=-8.604833 -> V=1.0, theta=0.0
% INFO    : Bus 6844	: V=1.039281, theta=25.115606 -> V=1.0, theta=0.0
% INFO    : Bus 6845	: V=0.99738, theta=13.433482 -> V=1.0, theta=0.0
% INFO    : Bus 6846	: V=1.029146, theta=3.188044 -> V=1.0, theta=0.0
% INFO    : Bus 6847	: V=1.024018, theta=19.935265 -> V=1.0, theta=0.0
% INFO    : Bus 6848	: V=1.015475, theta=-3.187287 -> V=1.0, theta=0.0
% INFO    : Bus 6849	: V=1.014697, theta=-0.819702 -> V=1.0, theta=0.0
% INFO    : Bus 6850	: V=1.068548, theta=77.186837 -> V=1.0, theta=0.0
% INFO    : Bus 6851	: V=0.980722, theta=-5.618401 -> V=1.0, theta=0.0
% INFO    : Bus 6852	: V=0.993093, theta=-2.60065 -> V=1.0, theta=0.0
% INFO    : Bus 6853	: V=0.940314, theta=-11.534037 -> V=1.0, theta=0.0
% INFO    : Bus 6854	: V=1.024423, theta=19.04153 -> V=1.0, theta=0.0
% INFO    : Bus 6855	: V=1.075022, theta=46.081152 -> V=1.0, theta=0.0
% INFO    : Bus 6856	: V=1.085669, theta=11.310275 -> V=1.0, theta=0.0
% INFO    : Bus 6857	: V=1.027676, theta=-4.853286 -> V=1.0, theta=0.0
% INFO    : Bus 6858	: V=1.036576, theta=5.994521 -> V=1.0, theta=0.0
% INFO    : Bus 6859	: V=1.035838, theta=9.663321 -> V=1.0, theta=0.0
% INFO    : Bus 6860	: V=1.026477, theta=14.511622 -> V=1.0, theta=0.0
% INFO    : Bus 6861	: V=1.027518, theta=-17.089784 -> V=1.0, theta=0.0
% INFO    : Bus 6862	: V=1.039025, theta=12.06939 -> V=1.0, theta=0.0
% INFO    : Bus 6863	: V=0.986618, theta=-2.650237 -> V=1.0, theta=0.0
% INFO    : Bus 6864	: V=0.984601, theta=26.113187 -> V=1.0, theta=0.0
% INFO    : Bus 6865	: V=1.036049, theta=1.565792 -> V=1.0, theta=0.0
% INFO    : Bus 6866	: V=1.022247, theta=8.824908 -> V=1.0, theta=0.0
% INFO    : Bus 6867	: V=1.014038, theta=-16.164128 -> V=1.0, theta=0.0
% INFO    : Bus 6868	: V=1.050781, theta=93.280802 -> V=1.0, theta=0.0
% INFO    : Bus 6869	: V=1.076798, theta=3.635802 -> V=1.0, theta=0.0
% INFO    : Bus 6870	: V=1.023144, theta=-9.538309 -> V=1.0, theta=0.0
% INFO    : Bus 6871	: V=0.984599, theta=43.311569 -> V=1.0, theta=0.0
% INFO    : Bus 6872	: V=1.008741, theta=36.754291 -> V=1.0, theta=0.0
% INFO    : Bus 6873	: V=1.039224, theta=12.699314 -> V=1.0, theta=0.0
% INFO    : Bus 6874	: V=0.977566, theta=23.48751 -> V=1.0, theta=0.0
% INFO    : Bus 6875	: V=1.024647, theta=-2.171451 -> V=1.0, theta=0.0
% INFO    : Bus 6876	: V=1.024647, theta=-2.171451 -> V=1.0, theta=0.0
% INFO    : Bus 6877	: V=1.024647, theta=-2.171451 -> V=1.0, theta=0.0
% INFO    : Bus 6878	: V=1.014043, theta=-17.464868 -> V=1.0, theta=0.0
% INFO    : Bus 6879	: V=1.066491, theta=41.851274 -> V=1.0, theta=0.0
% INFO    : Bus 6880	: V=1.066564, theta=41.739182 -> V=1.0, theta=0.0
% INFO    : Bus 6881	: V=1.102706, theta=-15.26137 -> V=1.0, theta=0.0
% INFO    : Bus 6882	: V=0.989077, theta=23.626111 -> V=1.0, theta=0.0
% INFO    : Bus 6883	: V=1.024983, theta=-1.567143 -> V=1.0, theta=0.0
% INFO    : Bus 6884	: V=1.039455, theta=-2.790506 -> V=1.0, theta=0.0
% INFO    : Bus 6885	: V=1.127948, theta=6.872839 -> V=1.0, theta=0.0
% INFO    : Bus 6886	: V=1.023096, theta=23.468478 -> V=1.0, theta=0.0
% INFO    : Bus 6887	: V=1.007022, theta=25.795589 -> V=1.0, theta=0.0
% INFO    : Bus 6888	: V=0.98601, theta=-3.642105 -> V=1.0, theta=0.0
% INFO    : Bus 6889	: V=1.088824, theta=9.099117 -> V=1.0, theta=0.0
% INFO    : Bus 6890	: V=0.998448, theta=-7.205564 -> V=1.0, theta=0.0
% INFO    : Bus 6891	: V=0.965152, theta=-9.606927 -> V=1.0, theta=0.0
% INFO    : Bus 6892	: V=1.028513, theta=-22.307748 -> V=1.0, theta=0.0
% INFO    : Bus 6893	: V=1.007942, theta=-10.569275 -> V=1.0, theta=0.0
% INFO    : Bus 6894	: V=0.964842, theta=-2.150668 -> V=1.0, theta=0.0
% INFO    : Bus 6895	: V=1.040858, theta=19.470405 -> V=1.0, theta=0.0
% INFO    : Bus 6896	: V=1.042756, theta=13.157799 -> V=1.0, theta=0.0
% INFO    : Bus 6897	: V=1.012562, theta=-1.688332 -> V=1.0, theta=0.0
% INFO    : Bus 6898	: V=1.021496, theta=-8.698463 -> V=1.0, theta=0.0
% INFO    : Bus 6899	: V=1.063802, theta=1.596336 -> V=1.0, theta=0.0
% INFO    : Bus 6900	: V=1.034333, theta=-18.758757 -> V=1.0, theta=0.0
% INFO    : Bus 6901	: V=1.004217, theta=26.321861 -> V=1.0, theta=0.0
% INFO    : Bus 6902	: V=0.999524, theta=-9.834457 -> V=1.0, theta=0.0
% INFO    : Bus 6903	: V=1.042446, theta=6.957021 -> V=1.0, theta=0.0
% INFO    : Bus 6904	: V=0.97934, theta=5.474588 -> V=1.0, theta=0.0
% INFO    : Bus 6905	: V=0.995712, theta=14.84413 -> V=1.0, theta=0.0
% INFO    : Bus 6906	: V=1.001417, theta=19.79822 -> V=1.0, theta=0.0
% INFO    : Bus 6907	: V=1.030589, theta=-7.348342 -> V=1.0, theta=0.0
% INFO    : Bus 6908	: V=1.044426, theta=-2.371415 -> V=1.0, theta=0.0
% INFO    : Bus 6909	: V=1.023155, theta=-9.729643 -> V=1.0, theta=0.0
% INFO    : Bus 6910	: V=1.023155, theta=-9.729643 -> V=1.0, theta=0.0
% INFO    : Bus 6911	: V=1.019724, theta=22.195041 -> V=1.0, theta=0.0
% INFO    : Bus 6912	: V=1.038747, theta=-8.642337 -> V=1.0, theta=0.0
% INFO    : Bus 6913	: V=1.035579, theta=-21.142018 -> V=1.0, theta=0.0
% INFO    : Bus 6914	: V=1.027597, theta=3.370206 -> V=1.0, theta=0.0
% INFO    : Bus 6915	: V=1.028275, theta=-14.834395 -> V=1.0, theta=0.0
% INFO    : Bus 6916	: V=1.018879, theta=16.2204 -> V=1.0, theta=0.0
% INFO    : Bus 6917	: V=0.996141, theta=-3.969887 -> V=1.0, theta=0.0
% INFO    : Bus 6918	: V=1.073133, theta=28.039751 -> V=1.0, theta=0.0
% INFO    : Bus 6919	: V=1.010871, theta=90.224838 -> V=1.0, theta=0.0
% INFO    : Bus 6920	: V=0.976017, theta=-27.442601 -> V=1.0, theta=0.0
% INFO    : Bus 6921	: V=0.926333, theta=5.238493 -> V=1.0, theta=0.0
% INFO    : Bus 6922	: V=1.018554, theta=4.748595 -> V=1.0, theta=0.0
% INFO    : Bus 6923	: V=1.021718, theta=-10.711519 -> V=1.0, theta=0.0
% INFO    : Bus 6924	: V=1.018374, theta=18.572044 -> V=1.0, theta=0.0
% INFO    : Bus 6925	: V=0.963581, theta=-5.373919 -> V=1.0, theta=0.0
% INFO    : Bus 6926	: V=0.947279, theta=-7.863736 -> V=1.0, theta=0.0
% INFO    : Bus 6927	: V=1.027734, theta=22.667054 -> V=1.0, theta=0.0
% INFO    : Bus 6928	: V=1.028182, theta=8.896762 -> V=1.0, theta=0.0
% INFO    : Bus 6929	: V=1.035431, theta=27.220462 -> V=1.0, theta=0.0
% INFO    : Bus 6930	: V=1.028641, theta=-17.676734 -> V=1.0, theta=0.0
% INFO    : Bus 6931	: V=1.028641, theta=-17.676734 -> V=1.0, theta=0.0
% INFO    : Bus 6932	: V=1.039723, theta=-1.23119 -> V=1.0, theta=0.0
% INFO    : Bus 6933	: V=1.051894, theta=44.335758 -> V=1.0, theta=0.0
% INFO    : Bus 6934	: V=1.05053, theta=43.952891 -> V=1.0, theta=0.0
% INFO    : Bus 6935	: V=1.075692, theta=2.382142 -> V=1.0, theta=0.0
% INFO    : Bus 6936	: V=0.967292, theta=-3.807226 -> V=1.0, theta=0.0
% INFO    : Bus 6937	: V=1.017088, theta=18.99512 -> V=1.0, theta=0.0
% INFO    : Bus 6938	: V=1.008996, theta=-16.587104 -> V=1.0, theta=0.0
% INFO    : Bus 6939	: V=0.994858, theta=32.812983 -> V=1.0, theta=0.0
% INFO    : Bus 6940	: V=0.996842, theta=-7.284318 -> V=1.0, theta=0.0
% INFO    : Bus 6941	: V=1.080967, theta=7.377587 -> V=1.0, theta=0.0
% INFO    : Bus 6942	: V=1.017532, theta=25.788753 -> V=1.0, theta=0.0
% INFO    : Bus 6943	: V=1.029906, theta=18.030995 -> V=1.0, theta=0.0
% INFO    : Bus 6944	: V=1.054031, theta=9.216302 -> V=1.0, theta=0.0
% INFO    : Bus 6945	: V=0.996333, theta=11.356692 -> V=1.0, theta=0.0
% INFO    : Bus 6946	: V=1.039744, theta=48.885504 -> V=1.0, theta=0.0
% INFO    : Bus 6947	: V=0.96407, theta=0.772625 -> V=1.0, theta=0.0
% INFO    : Bus 6948	: V=1.031397, theta=6.88995 -> V=1.0, theta=0.0
% INFO    : Bus 6949	: V=1.006367, theta=26.85524 -> V=1.0, theta=0.0
% INFO    : Bus 6950	: V=1.080244, theta=-12.388095 -> V=1.0, theta=0.0
% INFO    : Bus 6951	: V=0.968179, theta=-13.778323 -> V=1.0, theta=0.0
% INFO    : Bus 6952	: V=0.955439, theta=48.700819 -> V=1.0, theta=0.0
% INFO    : Bus 6953	: V=0.969766, theta=4.808904 -> V=1.0, theta=0.0
% INFO    : Bus 6954	: V=1.027988, theta=-1.986489 -> V=1.0, theta=0.0
% INFO    : Bus 6955	: V=1.027171, theta=18.782805 -> V=1.0, theta=0.0
% INFO    : Bus 6956	: V=1.020802, theta=17.057351 -> V=1.0, theta=0.0
% INFO    : Bus 6957	: V=1.007395, theta=-5.72667 -> V=1.0, theta=0.0
% INFO    : Bus 6958	: V=1.018519, theta=26.913419 -> V=1.0, theta=0.0
% INFO    : Bus 6959	: V=1.017566, theta=30.154577 -> V=1.0, theta=0.0
% INFO    : Bus 6960	: V=1.015516, theta=-17.663901 -> V=1.0, theta=0.0
% INFO    : Bus 6961	: V=1.025451, theta=-11.135864 -> V=1.0, theta=0.0
% INFO    : Bus 6962	: V=1.003289, theta=-20.416251 -> V=1.0, theta=0.0
% INFO    : Bus 6963	: V=1.029893, theta=-6.546635 -> V=1.0, theta=0.0
% INFO    : Bus 6964	: V=1.048554, theta=86.41124 -> V=1.0, theta=0.0
% INFO    : Bus 6965	: V=0.979077, theta=4.930838 -> V=1.0, theta=0.0
% INFO    : Bus 6966	: V=1.010708, theta=19.950213 -> V=1.0, theta=0.0
% INFO    : Bus 6967	: V=1.054031, theta=9.216302 -> V=1.0, theta=0.0
% INFO    : Bus 6968	: V=0.920281, theta=-11.399862 -> V=1.0, theta=0.0
% INFO    : Bus 6969	: V=1.054031, theta=9.216302 -> V=1.0, theta=0.0
% INFO    : Bus 6970	: V=1.063753, theta=11.961612 -> V=1.0, theta=0.0
% INFO    : Bus 6971	: V=1.048304, theta=39.358328 -> V=1.0, theta=0.0
% INFO    : Bus 6972	: V=0.97159, theta=-8.552571 -> V=1.0, theta=0.0
% INFO    : Bus 6973	: V=1.065197, theta=53.171221 -> V=1.0, theta=0.0
% INFO    : Bus 6974	: V=1.070029, theta=0.064588 -> V=1.0, theta=0.0
% INFO    : Bus 6975	: V=1.009578, theta=3.843937 -> V=1.0, theta=0.0
% INFO    : Bus 6976	: V=1.050684, theta=91.443424 -> V=1.0, theta=0.0
% INFO    : Bus 6977	: V=1.032362, theta=39.964728 -> V=1.0, theta=0.0
% INFO    : Bus 6978	: V=0.936583, theta=-8.21497 -> V=1.0, theta=0.0
% INFO    : Bus 6979	: V=0.983945, theta=-6.05191 -> V=1.0, theta=0.0
% INFO    : Bus 6980	: V=1.019273, theta=16.993216 -> V=1.0, theta=0.0
% INFO    : Bus 6981	: V=1.012504, theta=22.41158 -> V=1.0, theta=0.0
% INFO    : Bus 6982	: V=1.004156, theta=-13.474558 -> V=1.0, theta=0.0
% INFO    : Bus 6983	: V=1.019528, theta=43.583518 -> V=1.0, theta=0.0
% INFO    : Bus 6984	: V=1.02293, theta=-17.553442 -> V=1.0, theta=0.0
% INFO    : Bus 6985	: V=1.029991, theta=3.188016 -> V=1.0, theta=0.0
% INFO    : Bus 6986	: V=1.000178, theta=13.361626 -> V=1.0, theta=0.0
% INFO    : Bus 6987	: V=1.029991, theta=3.188016 -> V=1.0, theta=0.0
% INFO    : Bus 6988	: V=1.035766, theta=1.983491 -> V=1.0, theta=0.0
% INFO    : Bus 6989	: V=1.069722, theta=2.806287 -> V=1.0, theta=0.0
% INFO    : Bus 6990	: V=1.027131, theta=-1.211905 -> V=1.0, theta=0.0
% INFO    : Bus 6991	: V=1.026001, theta=0.562799 -> V=1.0, theta=0.0
% INFO    : Bus 6992	: V=1.034688, theta=8.184132 -> V=1.0, theta=0.0
% INFO    : Bus 6993	: V=1.019217, theta=-20.70702 -> V=1.0, theta=0.0
% INFO    : Bus 6994	: V=1.003942, theta=39.409116 -> V=1.0, theta=0.0
% INFO    : Bus 6995	: V=1.020015, theta=-15.016249 -> V=1.0, theta=0.0
% INFO    : Bus 6996	: V=1.0182, theta=22.6787 -> V=1.0, theta=0.0
% INFO    : Bus 6997	: V=1.020504, theta=28.639428 -> V=1.0, theta=0.0
% INFO    : Bus 6998	: V=1.033534, theta=-10.544863 -> V=1.0, theta=0.0
% INFO    : Bus 6999	: V=1.047214, theta=5.338776 -> V=1.0, theta=0.0
% INFO    : Bus 7000	: V=1.068832, theta=52.609074 -> V=1.0, theta=0.0
% INFO    : Bus 7001	: V=1.02173, theta=-0.10958 -> V=1.0, theta=0.0
% INFO    : Bus 7002	: V=0.981801, theta=-7.8197 -> V=1.0, theta=0.0
% INFO    : Bus 7003	: V=1.000892, theta=44.245377 -> V=1.0, theta=0.0
% INFO    : Bus 7004	: V=0.971372, theta=-5.891139 -> V=1.0, theta=0.0
% INFO    : Bus 7005	: V=1.04062, theta=33.045458 -> V=1.0, theta=0.0
% INFO    : Bus 7006	: V=0.963378, theta=-9.81008 -> V=1.0, theta=0.0
% INFO    : Bus 7007	: V=1.006897, theta=-8.792843 -> V=1.0, theta=0.0
% INFO    : Bus 7008	: V=1.058048, theta=38.30669 -> V=1.0, theta=0.0
% INFO    : Bus 7009	: V=1.023432, theta=25.118071 -> V=1.0, theta=0.0
% INFO    : Bus 7010	: V=0.958921, theta=-8.905383 -> V=1.0, theta=0.0
% INFO    : Bus 7011	: V=1.030485, theta=29.794078 -> V=1.0, theta=0.0
% INFO    : Bus 7012	: V=1.023179, theta=44.762006 -> V=1.0, theta=0.0
% INFO    : Bus 7013	: V=0.986883, theta=15.785624 -> V=1.0, theta=0.0
% INFO    : Bus 7014	: V=1.088419, theta=29.405227 -> V=1.0, theta=0.0
% INFO    : Bus 7015	: V=0.998601, theta=-10.373841 -> V=1.0, theta=0.0
% INFO    : Bus 7016	: V=0.999384, theta=-8.318633 -> V=1.0, theta=0.0
% INFO    : Bus 7017	: V=1.032373, theta=-8.516164 -> V=1.0, theta=0.0
% INFO    : Bus 7018	: V=1.011587, theta=23.671261 -> V=1.0, theta=0.0
% INFO    : Bus 7019	: V=1.057103, theta=7.110478 -> V=1.0, theta=0.0
% INFO    : Bus 7020	: V=1.033214, theta=-6.888934 -> V=1.0, theta=0.0
% INFO    : Bus 7021	: V=1.047209, theta=-16.441064 -> V=1.0, theta=0.0
% INFO    : Bus 7022	: V=0.995912, theta=22.400101 -> V=1.0, theta=0.0
% INFO    : Bus 7023	: V=1.103415, theta=-1.649909 -> V=1.0, theta=0.0
% INFO    : Bus 7024	: V=1.098193, theta=65.001322 -> V=1.0, theta=0.0
% INFO    : Bus 7025	: V=1.020824, theta=-8.385682 -> V=1.0, theta=0.0
% INFO    : Bus 7026	: V=1.027345, theta=33.608464 -> V=1.0, theta=0.0
% INFO    : Bus 7027	: V=1.046939, theta=-6.613174 -> V=1.0, theta=0.0
% INFO    : Bus 7028	: V=1.043087, theta=11.638661 -> V=1.0, theta=0.0
% INFO    : Bus 7029	: V=1.072481, theta=-0.655471 -> V=1.0, theta=0.0
% INFO    : Bus 7030	: V=0.984025, theta=-1.613209 -> V=1.0, theta=0.0
% INFO    : Bus 7031	: V=1.012542, theta=1.713537 -> V=1.0, theta=0.0
% INFO    : Bus 7032	: V=0.993843, theta=-5.877347 -> V=1.0, theta=0.0
% INFO    : Bus 7033	: V=0.978182, theta=-5.962125 -> V=1.0, theta=0.0
% INFO    : Bus 7034	: V=0.992755, theta=-14.102923 -> V=1.0, theta=0.0
% INFO    : Bus 7035	: V=1.012334, theta=7.544783 -> V=1.0, theta=0.0
% INFO    : Bus 7036	: V=1.007989, theta=4.843111 -> V=1.0, theta=0.0
% INFO    : Bus 7037	: V=1.033519, theta=-19.312338 -> V=1.0, theta=0.0
% INFO    : Bus 7038	: V=1.043944, theta=-14.401464 -> V=1.0, theta=0.0
% INFO    : Bus 7039	: V=1.022632, theta=4.381728 -> V=1.0, theta=0.0
% INFO    : Bus 7040	: V=1.011322, theta=-3.298846 -> V=1.0, theta=0.0
% INFO    : Bus 7041	: V=1.011233, theta=-18.289423 -> V=1.0, theta=0.0
% INFO    : Bus 7042	: V=1.030455, theta=21.683383 -> V=1.0, theta=0.0
% INFO    : Bus 7043	: V=1.005654, theta=21.004212 -> V=1.0, theta=0.0
% INFO    : Bus 7044	: V=0.982381, theta=-22.951765 -> V=1.0, theta=0.0
% INFO    : Bus 7045	: V=1.041985, theta=31.793879 -> V=1.0, theta=0.0
% INFO    : Bus 7046	: V=0.959203, theta=-6.211295 -> V=1.0, theta=0.0
% INFO    : Bus 7047	: V=1.012145, theta=-2.02475 -> V=1.0, theta=0.0
% INFO    : Bus 7048	: V=1.025542, theta=-7.188187 -> V=1.0, theta=0.0
% INFO    : Bus 7049	: V=1.067375, theta=2.210525 -> V=1.0, theta=0.0
% INFO    : Bus 7050	: V=1.011297, theta=28.945748 -> V=1.0, theta=0.0
% INFO    : Bus 7051	: V=1.036449, theta=33.240018 -> V=1.0, theta=0.0
% INFO    : Bus 7052	: V=0.99693, theta=24.855313 -> V=1.0, theta=0.0
% INFO    : Bus 7053	: V=1.002012, theta=13.542185 -> V=1.0, theta=0.0
% INFO    : Bus 7054	: V=1.002012, theta=13.542185 -> V=1.0, theta=0.0
% INFO    : Bus 7055	: V=1.046478, theta=33.359815 -> V=1.0, theta=0.0
% INFO    : Bus 7056	: V=1.028102, theta=1.989595 -> V=1.0, theta=0.0
% INFO    : Bus 7057	: V=1.040138, theta=32.45384 -> V=1.0, theta=0.0
% INFO    : Bus 7058	: V=1.085466, theta=-20.194962 -> V=1.0, theta=0.0
% INFO    : Bus 7059	: V=1.018502, theta=51.344505 -> V=1.0, theta=0.0
% INFO    : Bus 7060	: V=1.003292, theta=-9.321509 -> V=1.0, theta=0.0
% INFO    : Bus 7061	: V=1.005676, theta=-22.163188 -> V=1.0, theta=0.0
% INFO    : Bus 7062	: V=1.01975, theta=13.979643 -> V=1.0, theta=0.0
% INFO    : Bus 7063	: V=1.058676, theta=15.850616 -> V=1.0, theta=0.0
% INFO    : Bus 7064	: V=1.015531, theta=4.163384 -> V=1.0, theta=0.0
% INFO    : Bus 7065	: V=1.089137, theta=9.040939 -> V=1.0, theta=0.0
% INFO    : Bus 7066	: V=0.994601, theta=31.575691 -> V=1.0, theta=0.0
% INFO    : Bus 7067	: V=1.014955, theta=35.533143 -> V=1.0, theta=0.0
% INFO    : Bus 7068	: V=1.026372, theta=24.396837 -> V=1.0, theta=0.0
% INFO    : Bus 7069	: V=1.029226, theta=35.370949 -> V=1.0, theta=0.0
% INFO    : Bus 7070	: V=1.002967, theta=-14.170517 -> V=1.0, theta=0.0
% INFO    : Bus 7071	: V=1.058114, theta=43.382414 -> V=1.0, theta=0.0
% INFO    : Bus 7072	: V=1.036699, theta=34.476926 -> V=1.0, theta=0.0
% INFO    : Bus 7073	: V=1.034768, theta=8.492541 -> V=1.0, theta=0.0
% INFO    : Bus 7074	: V=1.047226, theta=85.684611 -> V=1.0, theta=0.0
% INFO    : Bus 7075	: V=1.042846, theta=0.690036 -> V=1.0, theta=0.0
% INFO    : Bus 7076	: V=1.031735, theta=-7.53735 -> V=1.0, theta=0.0
% INFO    : Bus 7077	: V=1.000639, theta=23.86914 -> V=1.0, theta=0.0
% INFO    : Bus 7078	: V=1.024673, theta=19.777124 -> V=1.0, theta=0.0
% INFO    : Bus 7079	: V=1.024254, theta=10.943171 -> V=1.0, theta=0.0
% INFO    : Bus 7080	: V=1.020703, theta=22.380203 -> V=1.0, theta=0.0
% INFO    : Bus 7081	: V=1.020703, theta=22.380203 -> V=1.0, theta=0.0
% INFO    : Bus 7082	: V=1.020703, theta=22.380203 -> V=1.0, theta=0.0
% INFO    : Bus 7083	: V=1.020703, theta=22.380203 -> V=1.0, theta=0.0
% INFO    : Bus 7084	: V=1.007614, theta=14.656778 -> V=1.0, theta=0.0
% INFO    : Bus 7085	: V=1.020703, theta=22.380203 -> V=1.0, theta=0.0
% INFO    : Bus 7086	: V=1.015038, theta=-11.388711 -> V=1.0, theta=0.0
% INFO    : Bus 7087	: V=1.007614, theta=14.656778 -> V=1.0, theta=0.0
% INFO    : Bus 7088	: V=1.013595, theta=22.381001 -> V=1.0, theta=0.0
% INFO    : Bus 7089	: V=0.925516, theta=-8.685239 -> V=1.0, theta=0.0
% INFO    : Bus 7090	: V=1.024048, theta=35.943886 -> V=1.0, theta=0.0
% INFO    : Bus 7091	: V=1.102719, theta=-15.262746 -> V=1.0, theta=0.0
% INFO    : Bus 7092	: V=1.033129, theta=-0.064448 -> V=1.0, theta=0.0
% INFO    : Bus 7093	: V=1.016327, theta=7.817231 -> V=1.0, theta=0.0
% INFO    : Bus 7094	: V=0.970506, theta=-5.960988 -> V=1.0, theta=0.0
% INFO    : Bus 7095	: V=0.972641, theta=29.929237 -> V=1.0, theta=0.0
% INFO    : Bus 7096	: V=1.009754, theta=12.380416 -> V=1.0, theta=0.0
% INFO    : Bus 7097	: V=1.008563, theta=-8.920839 -> V=1.0, theta=0.0
% INFO    : Bus 7098	: V=1.006535, theta=-14.099903 -> V=1.0, theta=0.0
% INFO    : Bus 7099	: V=1.055931, theta=33.95161 -> V=1.0, theta=0.0
% INFO    : Bus 7100	: V=1.041105, theta=-14.651391 -> V=1.0, theta=0.0
% INFO    : Bus 7101	: V=0.992834, theta=59.276406 -> V=1.0, theta=0.0
% INFO    : Bus 7102	: V=0.925181, theta=-12.121466 -> V=1.0, theta=0.0
% INFO    : Bus 7103	: V=1.033165, theta=38.744307 -> V=1.0, theta=0.0
% INFO    : Bus 7104	: V=1.049732, theta=40.027444 -> V=1.0, theta=0.0
% INFO    : Bus 7105	: V=1.035838, theta=-5.172678 -> V=1.0, theta=0.0
% INFO    : Bus 7106	: V=1.055771, theta=-2.521165 -> V=1.0, theta=0.0
% INFO    : Bus 7107	: V=1.024203, theta=1.49438 -> V=1.0, theta=0.0
% INFO    : Bus 7108	: V=1.021296, theta=19.962313 -> V=1.0, theta=0.0
% INFO    : Bus 7109	: V=1.001948, theta=-7.820734 -> V=1.0, theta=0.0
% INFO    : Bus 7110	: V=1.020566, theta=-15.965907 -> V=1.0, theta=0.0
% INFO    : Bus 7111	: V=0.995435, theta=4.377334 -> V=1.0, theta=0.0
% INFO    : Bus 7112	: V=1.036262, theta=9.976334 -> V=1.0, theta=0.0
% INFO    : Bus 7113	: V=1.034235, theta=2.214597 -> V=1.0, theta=0.0
% INFO    : Bus 7114	: V=1.014725, theta=27.348397 -> V=1.0, theta=0.0
% INFO    : Bus 7115	: V=1.040138, theta=32.45384 -> V=1.0, theta=0.0
% INFO    : Bus 7116	: V=1.042317, theta=14.274354 -> V=1.0, theta=0.0
% INFO    : Bus 7117	: V=1.015873, theta=20.575127 -> V=1.0, theta=0.0
% INFO    : Bus 7118	: V=1.021335, theta=-32.216893 -> V=1.0, theta=0.0
% INFO    : Bus 7119	: V=0.99907, theta=17.635445 -> V=1.0, theta=0.0
% INFO    : Bus 7120	: V=1.006299, theta=-4.259923 -> V=1.0, theta=0.0
% INFO    : Bus 7121	: V=1.012124, theta=39.690958 -> V=1.0, theta=0.0
% INFO    : Bus 7122	: V=1.03036, theta=-6.512869 -> V=1.0, theta=0.0
% INFO    : Bus 7123	: V=1.059752, theta=82.219607 -> V=1.0, theta=0.0
% INFO    : Bus 7124	: V=0.999402, theta=23.601458 -> V=1.0, theta=0.0
% INFO    : Bus 7125	: V=1.013229, theta=-2.688715 -> V=1.0, theta=0.0
% INFO    : Bus 7126	: V=1.013777, theta=35.825827 -> V=1.0, theta=0.0
% INFO    : Bus 7127	: V=0.995485, theta=-2.095523 -> V=1.0, theta=0.0
% INFO    : Bus 7128	: V=1.02227, theta=36.7768 -> V=1.0, theta=0.0
% INFO    : Bus 7129	: V=1.028248, theta=5.309757 -> V=1.0, theta=0.0
% INFO    : Bus 7130	: V=0.86014, theta=-15.783699 -> V=1.0, theta=0.0
% INFO    : Bus 7131	: V=1.024163, theta=46.575972 -> V=1.0, theta=0.0
% INFO    : Bus 7132	: V=1.035363, theta=9.414958 -> V=1.0, theta=0.0
% INFO    : Bus 7133	: V=1.044129, theta=-4.738961 -> V=1.0, theta=0.0
% INFO    : Bus 7134	: V=1.026317, theta=18.877265 -> V=1.0, theta=0.0
% INFO    : Bus 7135	: V=0.981282, theta=-20.456784 -> V=1.0, theta=0.0
% INFO    : Bus 7136	: V=1.011074, theta=22.948932 -> V=1.0, theta=0.0
% INFO    : Bus 7137	: V=1.062747, theta=39.318661 -> V=1.0, theta=0.0
% INFO    : Bus 7138	: V=0.99524, theta=-1.245843 -> V=1.0, theta=0.0
% INFO    : Bus 7139	: V=1.034631, theta=4.683321 -> V=1.0, theta=0.0
% INFO    : Bus 7140	: V=0.964795, theta=30.02488 -> V=1.0, theta=0.0
% INFO    : Bus 7141	: V=1.020596, theta=-16.730831 -> V=1.0, theta=0.0
% INFO    : Bus 7142	: V=1.033768, theta=14.596978 -> V=1.0, theta=0.0
% INFO    : Bus 7143	: V=1.017775, theta=-9.583337 -> V=1.0, theta=0.0
% INFO    : Bus 7144	: V=1.024103, theta=-14.185965 -> V=1.0, theta=0.0
% INFO    : Bus 7145	: V=1.012621, theta=36.142762 -> V=1.0, theta=0.0
% INFO    : Bus 7146	: V=1.017024, theta=16.872664 -> V=1.0, theta=0.0
% INFO    : Bus 7147	: V=0.972792, theta=-17.770017 -> V=1.0, theta=0.0
% INFO    : Bus 7148	: V=0.962614, theta=39.578299 -> V=1.0, theta=0.0
% INFO    : Bus 7149	: V=0.969146, theta=47.259579 -> V=1.0, theta=0.0
% INFO    : Bus 7150	: V=1.058684, theta=17.914192 -> V=1.0, theta=0.0
% INFO    : Bus 7151	: V=0.994222, theta=33.464801 -> V=1.0, theta=0.0
% INFO    : Bus 7152	: V=1.008396, theta=5.114162 -> V=1.0, theta=0.0
% INFO    : Bus 7153	: V=0.978315, theta=-3.345335 -> V=1.0, theta=0.0
% INFO    : Bus 7154	: V=1.000441, theta=-8.732796 -> V=1.0, theta=0.0
% INFO    : Bus 7155	: V=1.013461, theta=26.007513 -> V=1.0, theta=0.0
% INFO    : Bus 7156	: V=1.019539, theta=-2.214354 -> V=1.0, theta=0.0
% INFO    : Bus 7157	: V=1.007191, theta=11.825783 -> V=1.0, theta=0.0
% INFO    : Bus 7158	: V=0.953148, theta=-6.753445 -> V=1.0, theta=0.0
% INFO    : Bus 7159	: V=0.989224, theta=44.932169 -> V=1.0, theta=0.0
% INFO    : Bus 7160	: V=1.00838, theta=-9.715089 -> V=1.0, theta=0.0
% INFO    : Bus 7161	: V=1.050533, theta=36.718919 -> V=1.0, theta=0.0
% INFO    : Bus 7162	: V=1.068034, theta=87.318363 -> V=1.0, theta=0.0
% INFO    : Bus 7163	: V=1.025208, theta=-17.00361 -> V=1.0, theta=0.0
% INFO    : Bus 7164	: V=1.054937, theta=4.624127 -> V=1.0, theta=0.0
% INFO    : Bus 7165	: V=1.023258, theta=0.195954 -> V=1.0, theta=0.0
% INFO    : Bus 7166	: V=0.979125, theta=5.224833 -> V=1.0, theta=0.0
% INFO    : Bus 7167	: V=0.984641, theta=13.821924 -> V=1.0, theta=0.0
% INFO    : Bus 7168	: V=1.045359, theta=10.101302 -> V=1.0, theta=0.0
% INFO    : Bus 7169	: V=0.987683, theta=-14.465453 -> V=1.0, theta=0.0
% INFO    : Bus 7170	: V=0.989707, theta=35.937223 -> V=1.0, theta=0.0
% INFO    : Bus 7171	: V=1.025863, theta=-20.929808 -> V=1.0, theta=0.0
% INFO    : Bus 7172	: V=0.997885, theta=10.689103 -> V=1.0, theta=0.0
% INFO    : Bus 7173	: V=1.127961, theta=6.657565 -> V=1.0, theta=0.0
% INFO    : Bus 7174	: V=1.034257, theta=31.986033 -> V=1.0, theta=0.0
% INFO    : Bus 7175	: V=1.021239, theta=0.375074 -> V=1.0, theta=0.0
% INFO    : Bus 7176	: V=0.974695, theta=-8.316245 -> V=1.0, theta=0.0
% INFO    : Bus 7177	: V=1.043125, theta=0.745455 -> V=1.0, theta=0.0
% INFO    : Bus 7178	: V=1.037281, theta=-8.202796 -> V=1.0, theta=0.0
% INFO    : Bus 7179	: V=1.004576, theta=18.337057 -> V=1.0, theta=0.0
% INFO    : Bus 7180	: V=1.012085, theta=-31.074125 -> V=1.0, theta=0.0
% INFO    : Bus 7181	: V=1.013408, theta=-18.555259 -> V=1.0, theta=0.0
% INFO    : Bus 7182	: V=1.005335, theta=12.373439 -> V=1.0, theta=0.0
% INFO    : Bus 7183	: V=1.026147, theta=8.391166 -> V=1.0, theta=0.0
% INFO    : Bus 7184	: V=0.999967, theta=-2.971427 -> V=1.0, theta=0.0
% INFO    : Bus 7185	: V=0.994416, theta=41.167332 -> V=1.0, theta=0.0
% INFO    : Bus 7186	: V=0.962211, theta=47.074823 -> V=1.0, theta=0.0
% INFO    : Bus 7187	: V=1.003062, theta=-0.954541 -> V=1.0, theta=0.0
% INFO    : Bus 7188	: V=0.986782, theta=-9.062218 -> V=1.0, theta=0.0
% INFO    : Bus 7189	: V=1.032126, theta=26.472433 -> V=1.0, theta=0.0
% INFO    : Bus 7190	: V=0.992569, theta=-4.021009 -> V=1.0, theta=0.0
% INFO    : Bus 7191	: V=0.996019, theta=-9.034279 -> V=1.0, theta=0.0
% INFO    : Bus 7192	: V=1.011629, theta=21.659763 -> V=1.0, theta=0.0
% INFO    : Bus 7193	: V=1.018093, theta=-18.599118 -> V=1.0, theta=0.0
% INFO    : Bus 7194	: V=1.031969, theta=17.968997 -> V=1.0, theta=0.0
% INFO    : Bus 7195	: V=1.033222, theta=9.023837 -> V=1.0, theta=0.0
% INFO    : Bus 7196	: V=1.042863, theta=4.73746 -> V=1.0, theta=0.0
% INFO    : Bus 7197	: V=1.028985, theta=11.966174 -> V=1.0, theta=0.0
% INFO    : Bus 7198	: V=1.033128, theta=-19.384685 -> V=1.0, theta=0.0
% INFO    : Bus 7199	: V=1.050633, theta=-5.746947 -> V=1.0, theta=0.0
% INFO    : Bus 7200	: V=1.026147, theta=8.391166 -> V=1.0, theta=0.0
% INFO    : Bus 7201	: V=1.042328, theta=4.557376 -> V=1.0, theta=0.0
% INFO    : Bus 7202	: V=1.021843, theta=-4.315515 -> V=1.0, theta=0.0
% INFO    : Bus 7203	: V=1.029341, theta=7.526066 -> V=1.0, theta=0.0
% INFO    : Bus 7204	: V=1.003398, theta=-10.072574 -> V=1.0, theta=0.0
% INFO    : Bus 7205	: V=0.983301, theta=1.387697 -> V=1.0, theta=0.0
% INFO    : Bus 7206	: V=0.97201, theta=10.933304 -> V=1.0, theta=0.0
% INFO    : Bus 7207	: V=1.047655, theta=20.267424 -> V=1.0, theta=0.0
% INFO    : Bus 7208	: V=1.055797, theta=-6.166252 -> V=1.0, theta=0.0
% INFO    : Bus 7209	: V=0.960568, theta=24.073792 -> V=1.0, theta=0.0
% INFO    : Bus 7210	: V=1.04686, theta=27.640783 -> V=1.0, theta=0.0
% INFO    : Bus 7211	: V=1.016765, theta=34.240821 -> V=1.0, theta=0.0
% INFO    : Bus 7212	: V=1.041205, theta=12.505171 -> V=1.0, theta=0.0
% INFO    : Bus 7213	: V=1.014795, theta=23.808394 -> V=1.0, theta=0.0
% INFO    : Bus 7214	: V=1.018912, theta=10.542087 -> V=1.0, theta=0.0
% INFO    : Bus 7215	: V=1.026561, theta=-12.445623 -> V=1.0, theta=0.0
% INFO    : Bus 7216	: V=0.987802, theta=33.849156 -> V=1.0, theta=0.0
% INFO    : Bus 7217	: V=1.044684, theta=-14.421225 -> V=1.0, theta=0.0
% INFO    : Bus 7218	: V=0.991802, theta=1.432003 -> V=1.0, theta=0.0
% INFO    : Bus 7219	: V=1.031691, theta=16.4694 -> V=1.0, theta=0.0
% INFO    : Bus 7220	: V=1.00867, theta=-17.214347 -> V=1.0, theta=0.0
% INFO    : Bus 7221	: V=1.042167, theta=34.593988 -> V=1.0, theta=0.0
% INFO    : Bus 7222	: V=0.995355, theta=-3.371498 -> V=1.0, theta=0.0
% INFO    : Bus 7223	: V=1.03301, theta=-15.651629 -> V=1.0, theta=0.0
% INFO    : Bus 7224	: V=0.986074, theta=-5.521684 -> V=1.0, theta=0.0
% INFO    : Bus 7225	: V=0.981434, theta=-8.220208 -> V=1.0, theta=0.0
% INFO    : Bus 7226	: V=0.999121, theta=-13.152442 -> V=1.0, theta=0.0
% INFO    : Bus 7227	: V=1.009223, theta=-5.815173 -> V=1.0, theta=0.0
% INFO    : Bus 7228	: V=1.053647, theta=50.613884 -> V=1.0, theta=0.0
% INFO    : Bus 7229	: V=1.039036, theta=18.150633 -> V=1.0, theta=0.0
% INFO    : Bus 7230	: V=1.023464, theta=-6.251097 -> V=1.0, theta=0.0
% INFO    : Bus 7231	: V=1.043674, theta=25.996716 -> V=1.0, theta=0.0
% INFO    : Bus 7232	: V=1.045468, theta=24.966619 -> V=1.0, theta=0.0
% INFO    : Bus 7233	: V=1.038999, theta=38.995592 -> V=1.0, theta=0.0
% INFO    : Bus 7234	: V=0.926718, theta=-12.042081 -> V=1.0, theta=0.0
% INFO    : Bus 7235	: V=0.995493, theta=32.22324 -> V=1.0, theta=0.0
% INFO    : Bus 7236	: V=1.007821, theta=10.245998 -> V=1.0, theta=0.0
% INFO    : Bus 7237	: V=1.016923, theta=16.575462 -> V=1.0, theta=0.0
% INFO    : Bus 7238	: V=1.03456, theta=18.420655 -> V=1.0, theta=0.0
% INFO    : Bus 7239	: V=0.982727, theta=-1.783019 -> V=1.0, theta=0.0
% INFO    : Bus 7240	: V=1.043764, theta=37.173377 -> V=1.0, theta=0.0
% INFO    : Bus 7241	: V=1.039685, theta=-13.261568 -> V=1.0, theta=0.0
% INFO    : Bus 7242	: V=1.027264, theta=14.46311 -> V=1.0, theta=0.0
% INFO    : Bus 7243	: V=0.958146, theta=44.224727 -> V=1.0, theta=0.0
% INFO    : Bus 7244	: V=1.006661, theta=14.689505 -> V=1.0, theta=0.0
% INFO    : Bus 7245	: V=1.003591, theta=25.364085 -> V=1.0, theta=0.0
% INFO    : Bus 7246	: V=1.019342, theta=37.26415 -> V=1.0, theta=0.0
% INFO    : Bus 7247	: V=1.040082, theta=26.616011 -> V=1.0, theta=0.0
% INFO    : Bus 7248	: V=0.968489, theta=23.525802 -> V=1.0, theta=0.0
% INFO    : Bus 7249	: V=1.005915, theta=0.12691 -> V=1.0, theta=0.0
% INFO    : Bus 7250	: V=1.020233, theta=20.547626 -> V=1.0, theta=0.0
% INFO    : Bus 7251	: V=1.030935, theta=11.629416 -> V=1.0, theta=0.0
% INFO    : Bus 7252	: V=1.037622, theta=28.736858 -> V=1.0, theta=0.0
% INFO    : Bus 7253	: V=1.013702, theta=-24.444263 -> V=1.0, theta=0.0
% INFO    : Bus 7254	: V=1.017332, theta=-16.047972 -> V=1.0, theta=0.0
% INFO    : Bus 7255	: V=1.025494, theta=17.288026 -> V=1.0, theta=0.0
% INFO    : Bus 7256	: V=1.031224, theta=29.555502 -> V=1.0, theta=0.0
% INFO    : Bus 7257	: V=1.03161, theta=11.84227 -> V=1.0, theta=0.0
% INFO    : Bus 7258	: V=1.028323, theta=-11.00057 -> V=1.0, theta=0.0
% INFO    : Bus 7259	: V=1.022177, theta=-18.166654 -> V=1.0, theta=0.0
% INFO    : Bus 7260	: V=1.067355, theta=5.985102 -> V=1.0, theta=0.0
% INFO    : Bus 7261	: V=0.984601, theta=26.113186 -> V=1.0, theta=0.0
% INFO    : Bus 7262	: V=0.991024, theta=-5.15543 -> V=1.0, theta=0.0
% INFO    : Bus 7263	: V=0.956518, theta=-5.487802 -> V=1.0, theta=0.0
% INFO    : Bus 7264	: V=0.927744, theta=7.78192 -> V=1.0, theta=0.0
% INFO    : Bus 7265	: V=0.990005, theta=-9.648284 -> V=1.0, theta=0.0
% INFO    : Bus 7266	: V=0.997837, theta=-9.08488 -> V=1.0, theta=0.0
% INFO    : Bus 7267	: V=0.996117, theta=32.042491 -> V=1.0, theta=0.0
% INFO    : Bus 7268	: V=1.02094, theta=37.983713 -> V=1.0, theta=0.0
% INFO    : Bus 7269	: V=1.024048, theta=-7.803527 -> V=1.0, theta=0.0
% INFO    : Bus 7270	: V=1.002139, theta=-14.467046 -> V=1.0, theta=0.0
% INFO    : Bus 7271	: V=1.028435, theta=-14.827023 -> V=1.0, theta=0.0
% INFO    : Bus 7272	: V=1.044486, theta=33.222726 -> V=1.0, theta=0.0
% INFO    : Bus 7273	: V=1.058674, theta=18.383846 -> V=1.0, theta=0.0
% INFO    : Bus 7274	: V=1.055938, theta=11.437944 -> V=1.0, theta=0.0
% INFO    : Bus 7275	: V=1.011321, theta=14.23252 -> V=1.0, theta=0.0
% INFO    : Bus 7276	: V=1.005505, theta=17.153822 -> V=1.0, theta=0.0
% INFO    : Bus 7277	: V=1.032532, theta=-0.066659 -> V=1.0, theta=0.0
% INFO    : Bus 7278	: V=1.03347, theta=34.98236 -> V=1.0, theta=0.0
% INFO    : Bus 7279	: V=0.90264, theta=-12.097367 -> V=1.0, theta=0.0
% INFO    : Bus 7280	: V=0.936041, theta=10.852081 -> V=1.0, theta=0.0
% INFO    : Bus 7281	: V=1.051879, theta=-6.358399 -> V=1.0, theta=0.0
% INFO    : Bus 7282	: V=1.041421, theta=-15.253203 -> V=1.0, theta=0.0
% INFO    : Bus 7283	: V=1.03499, theta=-19.617451 -> V=1.0, theta=0.0
% INFO    : Bus 7284	: V=1.03499, theta=-19.617451 -> V=1.0, theta=0.0
% INFO    : Bus 7285	: V=0.964991, theta=-9.63915 -> V=1.0, theta=0.0
% INFO    : Bus 7286	: V=1.03499, theta=-19.617451 -> V=1.0, theta=0.0
% INFO    : Bus 7287	: V=1.03499, theta=-19.617451 -> V=1.0, theta=0.0
% INFO    : Bus 7288	: V=1.026857, theta=15.275337 -> V=1.0, theta=0.0
% INFO    : Bus 7289	: V=1.033768, theta=14.596978 -> V=1.0, theta=0.0
% INFO    : Bus 7290	: V=0.986547, theta=-15.19694 -> V=1.0, theta=0.0
% INFO    : Bus 7291	: V=1.00571, theta=1.688469 -> V=1.0, theta=0.0
% INFO    : Bus 7292	: V=1.012463, theta=27.539428 -> V=1.0, theta=0.0
% INFO    : Bus 7293	: V=1.034238, theta=-1.125368 -> V=1.0, theta=0.0
% INFO    : Bus 7294	: V=1.029767, theta=-14.92546 -> V=1.0, theta=0.0
% INFO    : Bus 7295	: V=1.003923, theta=-3.319875 -> V=1.0, theta=0.0
% INFO    : Bus 7296	: V=1.001715, theta=-1.126851 -> V=1.0, theta=0.0
% INFO    : Bus 7297	: V=1.034048, theta=-9.733404 -> V=1.0, theta=0.0
% INFO    : Bus 7298	: V=1.112059, theta=-0.97463 -> V=1.0, theta=0.0
% INFO    : Bus 7299	: V=1.052695, theta=-2.176957 -> V=1.0, theta=0.0
% INFO    : Bus 7300	: V=1.012727, theta=-2.819685 -> V=1.0, theta=0.0
% INFO    : Bus 7301	: V=1.017988, theta=3.774778 -> V=1.0, theta=0.0
% INFO    : Bus 7302	: V=0.991789, theta=-2.334341 -> V=1.0, theta=0.0
% INFO    : Bus 7303	: V=1.041313, theta=-3.543238 -> V=1.0, theta=0.0
% INFO    : Bus 7304	: V=1.03036, theta=-6.512869 -> V=1.0, theta=0.0
% INFO    : Bus 7305	: V=1.010597, theta=-16.590721 -> V=1.0, theta=0.0
% INFO    : Bus 7306	: V=0.939342, theta=5.315842 -> V=1.0, theta=0.0
% INFO    : Bus 7307	: V=1.100006, theta=65.129088 -> V=1.0, theta=0.0
% INFO    : Bus 7308	: V=1.0267, theta=1.766412 -> V=1.0, theta=0.0
% INFO    : Bus 7309	: V=0.986662, theta=-26.829415 -> V=1.0, theta=0.0
% INFO    : Bus 7310	: V=1.012714, theta=-7.579063 -> V=1.0, theta=0.0
% INFO    : Bus 7311	: V=1.032903, theta=-3.01883 -> V=1.0, theta=0.0
% INFO    : Bus 7312	: V=1.005455, theta=17.595107 -> V=1.0, theta=0.0
% INFO    : Bus 7313	: V=1.028058, theta=-1.961635 -> V=1.0, theta=0.0
% INFO    : Bus 7314	: V=1.058635, theta=17.90213 -> V=1.0, theta=0.0
% INFO    : Bus 7315	: V=1.005468, theta=-3.810857 -> V=1.0, theta=0.0
% INFO    : Bus 7316	: V=1.006171, theta=0.370886 -> V=1.0, theta=0.0
% INFO    : Bus 7317	: V=1.029166, theta=13.522836 -> V=1.0, theta=0.0
% INFO    : Bus 7318	: V=1.033283, theta=46.248802 -> V=1.0, theta=0.0
% INFO    : Bus 7319	: V=1.022762, theta=24.657166 -> V=1.0, theta=0.0
% INFO    : Bus 7320	: V=1.06258, theta=21.454963 -> V=1.0, theta=0.0
% INFO    : Bus 7321	: V=1.018001, theta=13.215213 -> V=1.0, theta=0.0
% INFO    : Bus 7322	: V=1.05612, theta=81.744333 -> V=1.0, theta=0.0
% INFO    : Bus 7323	: V=0.982662, theta=-9.442097 -> V=1.0, theta=0.0
% INFO    : Bus 7324	: V=1.002311, theta=14.090329 -> V=1.0, theta=0.0
% INFO    : Bus 7325	: V=1.012062, theta=38.612315 -> V=1.0, theta=0.0
% INFO    : Bus 7326	: V=1.080819, theta=8.237326 -> V=1.0, theta=0.0
% INFO    : Bus 7327	: V=1.020032, theta=8.963657 -> V=1.0, theta=0.0
% INFO    : Bus 7328	: V=1.05717, theta=53.317776 -> V=1.0, theta=0.0
% INFO    : Bus 7329	: V=0.992436, theta=31.623055 -> V=1.0, theta=0.0
% INFO    : Bus 7330	: V=1.0366, theta=38.640875 -> V=1.0, theta=0.0
% INFO    : Bus 7331	: V=0.955313, theta=-6.820872 -> V=1.0, theta=0.0
% INFO    : Bus 7332	: V=0.961011, theta=-6.504868 -> V=1.0, theta=0.0
% INFO    : Bus 7333	: V=1.042865, theta=51.92649 -> V=1.0, theta=0.0
% INFO    : Bus 7334	: V=1.033239, theta=35.570464 -> V=1.0, theta=0.0
% INFO    : Bus 7335	: V=0.962918, theta=-9.819129 -> V=1.0, theta=0.0
% INFO    : Bus 7336	: V=1.010435, theta=22.936576 -> V=1.0, theta=0.0
% INFO    : Bus 7337	: V=0.96354, theta=-4.229015 -> V=1.0, theta=0.0
% INFO    : Bus 7338	: V=0.999789, theta=98.512855 -> V=1.0, theta=0.0
% INFO    : Bus 7339	: V=0.992745, theta=24.126033 -> V=1.0, theta=0.0
% INFO    : Bus 7340	: V=0.938623, theta=24.03983 -> V=1.0, theta=0.0
% INFO    : Bus 7341	: V=1.023025, theta=8.747596 -> V=1.0, theta=0.0
% INFO    : Bus 7342	: V=1.044097, theta=40.791392 -> V=1.0, theta=0.0
% INFO    : Bus 7343	: V=1.019982, theta=14.451272 -> V=1.0, theta=0.0
% INFO    : Bus 7344	: V=1.042851, theta=-3.461128 -> V=1.0, theta=0.0
% INFO    : Bus 7345	: V=1.030841, theta=-16.24512 -> V=1.0, theta=0.0
% INFO    : Bus 7346	: V=1.027328, theta=-11.116661 -> V=1.0, theta=0.0
% INFO    : Bus 7347	: V=0.979537, theta=-10.799228 -> V=1.0, theta=0.0
% INFO    : Bus 7348	: V=0.990307, theta=46.2101 -> V=1.0, theta=0.0
% INFO    : Bus 7349	: V=1.040292, theta=-9.24091 -> V=1.0, theta=0.0
% INFO    : Bus 7350	: V=1.040292, theta=-9.24091 -> V=1.0, theta=0.0
% INFO    : Bus 7351	: V=1.036065, theta=-16.582357 -> V=1.0, theta=0.0
% INFO    : Bus 7352	: V=1.029893, theta=-6.546635 -> V=1.0, theta=0.0
% INFO    : Bus 7353	: V=1.002965, theta=-20.322256 -> V=1.0, theta=0.0
% INFO    : Bus 7354	: V=1.024274, theta=-9.95923 -> V=1.0, theta=0.0
% INFO    : Bus 7355	: V=1.040326, theta=2.497708 -> V=1.0, theta=0.0
% INFO    : Bus 7356	: V=1.038438, theta=0.065623 -> V=1.0, theta=0.0
% INFO    : Bus 7357	: V=1.005748, theta=16.065016 -> V=1.0, theta=0.0
% INFO    : Bus 7358	: V=1.018386, theta=8.832269 -> V=1.0, theta=0.0
% INFO    : Bus 7359	: V=0.965144, theta=-10.373275 -> V=1.0, theta=0.0
% INFO    : Bus 7360	: V=1.019462, theta=-18.827651 -> V=1.0, theta=0.0
% INFO    : Bus 7361	: V=1.04035, theta=8.357264 -> V=1.0, theta=0.0
% INFO    : Bus 7362	: V=1.008054, theta=30.667304 -> V=1.0, theta=0.0
% INFO    : Bus 7363	: V=0.992259, theta=-8.136274 -> V=1.0, theta=0.0
% INFO    : Bus 7364	: V=1.009651, theta=13.007592 -> V=1.0, theta=0.0
% INFO    : Bus 7365	: V=1.037973, theta=11.471538 -> V=1.0, theta=0.0
% INFO    : Bus 7366	: V=1.02223, theta=-11.03513 -> V=1.0, theta=0.0
% INFO    : Bus 7367	: V=1.014062, theta=-14.687051 -> V=1.0, theta=0.0
% INFO    : Bus 7368	: V=1.060019, theta=0.350257 -> V=1.0, theta=0.0
% INFO    : Bus 7369	: V=1.005303, theta=-3.689085 -> V=1.0, theta=0.0
% INFO    : Bus 7370	: V=1.007216, theta=-1.420425 -> V=1.0, theta=0.0
% INFO    : Bus 7371	: V=1.043492, theta=-15.322718 -> V=1.0, theta=0.0
% INFO    : Bus 7372	: V=1.007216, theta=-1.420425 -> V=1.0, theta=0.0
% INFO    : Bus 7373	: V=0.950412, theta=-5.365339 -> V=1.0, theta=0.0
% INFO    : Bus 7374	: V=1.005303, theta=-3.689085 -> V=1.0, theta=0.0
% INFO    : Bus 7375	: V=1.005303, theta=-3.689085 -> V=1.0, theta=0.0
% INFO    : Bus 7376	: V=1.005303, theta=-3.689085 -> V=1.0, theta=0.0
% INFO    : Bus 7377	: V=1.001397, theta=94.4747 -> V=1.0, theta=0.0
% INFO    : Bus 7378	: V=1.004934, theta=-5.075181 -> V=1.0, theta=0.0
% INFO    : Bus 7379	: V=1.004934, theta=-5.075181 -> V=1.0, theta=0.0
% INFO    : Bus 7380	: V=1.076757, theta=-9.360128 -> V=1.0, theta=0.0
% INFO    : Bus 7381	: V=0.976475, theta=43.406918 -> V=1.0, theta=0.0
% INFO    : Bus 7382	: V=1.019801, theta=-22.440546 -> V=1.0, theta=0.0
% INFO    : Bus 7383	: V=1.006546, theta=-11.697125 -> V=1.0, theta=0.0
% INFO    : Bus 7384	: V=1.049348, theta=-12.689887 -> V=1.0, theta=0.0
% INFO    : Bus 7385	: V=0.986576, theta=2.287295 -> V=1.0, theta=0.0
% INFO    : Bus 7386	: V=1.058287, theta=5.521142 -> V=1.0, theta=0.0
% INFO    : Bus 7387	: V=1.005095, theta=92.428959 -> V=1.0, theta=0.0
% INFO    : Bus 7388	: V=1.038881, theta=6.451637 -> V=1.0, theta=0.0
% INFO    : Bus 7389	: V=1.00316, theta=23.070314 -> V=1.0, theta=0.0
% INFO    : Bus 7390	: V=0.984518, theta=-6.510386 -> V=1.0, theta=0.0
% INFO    : Bus 7391	: V=1.025019, theta=-12.264635 -> V=1.0, theta=0.0
% INFO    : Bus 7392	: V=1.055337, theta=0.681282 -> V=1.0, theta=0.0
% INFO    : Bus 7393	: V=1.06184, theta=80.335931 -> V=1.0, theta=0.0
% INFO    : Bus 7394	: V=1.02091, theta=-7.970929 -> V=1.0, theta=0.0
% INFO    : Bus 7395	: V=1.043549, theta=3.22096 -> V=1.0, theta=0.0
% INFO    : Bus 7396	: V=1.011306, theta=13.237271 -> V=1.0, theta=0.0
% INFO    : Bus 7397	: V=0.971662, theta=4.274204 -> V=1.0, theta=0.0
% INFO    : Bus 7398	: V=0.993179, theta=-4.309492 -> V=1.0, theta=0.0
% INFO    : Bus 7399	: V=1.049444, theta=-6.481726 -> V=1.0, theta=0.0
% INFO    : Bus 7400	: V=1.0494, theta=25.484796 -> V=1.0, theta=0.0
% INFO    : Bus 7401	: V=0.992535, theta=-0.937169 -> V=1.0, theta=0.0
% INFO    : Bus 7402	: V=1.007335, theta=16.489323 -> V=1.0, theta=0.0
% INFO    : Bus 7403	: V=0.988449, theta=-4.637233 -> V=1.0, theta=0.0
% INFO    : Bus 7404	: V=1.014322, theta=-16.885153 -> V=1.0, theta=0.0
% INFO    : Bus 7405	: V=1.025141, theta=-10.524427 -> V=1.0, theta=0.0
% INFO    : Bus 7406	: V=1.015343, theta=-1.615945 -> V=1.0, theta=0.0
% INFO    : Bus 7407	: V=1.049351, theta=-13.067891 -> V=1.0, theta=0.0
% INFO    : Bus 7408	: V=1.029262, theta=7.522386 -> V=1.0, theta=0.0
% INFO    : Bus 7409	: V=1.064417, theta=0.577932 -> V=1.0, theta=0.0
% INFO    : Bus 7410	: V=0.974625, theta=-8.32398 -> V=1.0, theta=0.0
% INFO    : Bus 7411	: V=0.987278, theta=-11.720559 -> V=1.0, theta=0.0
% INFO    : Bus 7412	: V=1.07921, theta=54.070288 -> V=1.0, theta=0.0
% INFO    : Bus 7413	: V=0.92416, theta=-12.234897 -> V=1.0, theta=0.0
% INFO    : Bus 7414	: V=1.010408, theta=22.827203 -> V=1.0, theta=0.0
% INFO    : Bus 7415	: V=0.995248, theta=-4.048539 -> V=1.0, theta=0.0
% INFO    : Bus 7416	: V=1.003342, theta=23.89027 -> V=1.0, theta=0.0
% INFO    : Bus 7417	: V=1.004325, theta=-5.281581 -> V=1.0, theta=0.0
% INFO    : Bus 7418	: V=0.979437, theta=-10.944319 -> V=1.0, theta=0.0
% INFO    : Bus 7419	: V=0.978181, theta=-9.34911 -> V=1.0, theta=0.0
% INFO    : Bus 7420	: V=1.103483, theta=-15.025503 -> V=1.0, theta=0.0
% INFO    : Bus 7421	: V=1.013945, theta=18.92959 -> V=1.0, theta=0.0
% INFO    : Bus 7422	: V=0.930277, theta=-7.416239 -> V=1.0, theta=0.0
% INFO    : Bus 7423	: V=1.017402, theta=17.981879 -> V=1.0, theta=0.0
% INFO    : Bus 7424	: V=0.975147, theta=-7.162476 -> V=1.0, theta=0.0
% INFO    : Bus 7425	: V=1.047892, theta=7.785203 -> V=1.0, theta=0.0
% INFO    : Bus 7426	: V=1.030874, theta=24.601888 -> V=1.0, theta=0.0
% INFO    : Bus 7427	: V=1.032836, theta=-10.828842 -> V=1.0, theta=0.0
% INFO    : Bus 7428	: V=1.049495, theta=12.649819 -> V=1.0, theta=0.0
% INFO    : Bus 7429	: V=0.927616, theta=-1.873772 -> V=1.0, theta=0.0
% INFO    : Bus 7430	: V=0.991002, theta=22.274075 -> V=1.0, theta=0.0
% INFO    : Bus 7431	: V=1.027954, theta=19.079635 -> V=1.0, theta=0.0
% INFO    : Bus 7432	: V=1.023631, theta=36.965167 -> V=1.0, theta=0.0
% INFO    : Bus 7433	: V=0.993646, theta=-13.107606 -> V=1.0, theta=0.0
% INFO    : Bus 7434	: V=1.009631, theta=-16.516918 -> V=1.0, theta=0.0
% INFO    : Bus 7435	: V=1.000291, theta=1.096095 -> V=1.0, theta=0.0
% INFO    : Bus 7436	: V=1.045147, theta=8.735036 -> V=1.0, theta=0.0
% INFO    : Bus 7437	: V=1.027684, theta=6.13627 -> V=1.0, theta=0.0
% INFO    : Bus 7438	: V=0.980437, theta=-5.788214 -> V=1.0, theta=0.0
% INFO    : Bus 7439	: V=1.019063, theta=27.899716 -> V=1.0, theta=0.0
% INFO    : Bus 7440	: V=1.033627, theta=-11.381318 -> V=1.0, theta=0.0
% INFO    : Bus 7441	: V=1.059512, theta=17.119921 -> V=1.0, theta=0.0
% INFO    : Bus 7442	: V=1.035887, theta=43.5707 -> V=1.0, theta=0.0
% INFO    : Bus 7443	: V=1.022832, theta=-6.905618 -> V=1.0, theta=0.0
% INFO    : Bus 7444	: V=0.983585, theta=27.331059 -> V=1.0, theta=0.0
% INFO    : Bus 7445	: V=1.001491, theta=-13.031617 -> V=1.0, theta=0.0
% INFO    : Bus 7446	: V=1.027329, theta=-11.117382 -> V=1.0, theta=0.0
% INFO    : Bus 7447	: V=1.035838, theta=-5.172678 -> V=1.0, theta=0.0
% INFO    : Bus 7448	: V=0.965783, theta=34.653221 -> V=1.0, theta=0.0
% INFO    : Bus 7449	: V=0.990475, theta=21.129805 -> V=1.0, theta=0.0
% INFO    : Bus 7450	: V=1.041428, theta=31.297695 -> V=1.0, theta=0.0
% INFO    : Bus 7451	: V=1.033239, theta=19.752155 -> V=1.0, theta=0.0
% INFO    : Bus 7452	: V=1.035023, theta=-10.739655 -> V=1.0, theta=0.0
% INFO    : Bus 7453	: V=1.00276, theta=92.867423 -> V=1.0, theta=0.0
% INFO    : Bus 7454	: V=1.039213, theta=59.560635 -> V=1.0, theta=0.0
% INFO    : Bus 7455	: V=0.970971, theta=8.339669 -> V=1.0, theta=0.0
% INFO    : Bus 7456	: V=1.026603, theta=8.287587 -> V=1.0, theta=0.0
% INFO    : Bus 7457	: V=0.995497, theta=16.901519 -> V=1.0, theta=0.0
% INFO    : Bus 7458	: V=1.034461, theta=-2.846498 -> V=1.0, theta=0.0
% INFO    : Bus 7459	: V=1.048234, theta=8.13578 -> V=1.0, theta=0.0
% INFO    : Bus 7460	: V=1.043896, theta=46.673508 -> V=1.0, theta=0.0
% INFO    : Bus 7461	: V=1.026298, theta=3.000376 -> V=1.0, theta=0.0
% INFO    : Bus 7462	: V=0.996721, theta=18.292833 -> V=1.0, theta=0.0
% INFO    : Bus 7463	: V=1.001698, theta=-25.302194 -> V=1.0, theta=0.0
% INFO    : Bus 7464	: V=1.023246, theta=-4.014324 -> V=1.0, theta=0.0
% INFO    : Bus 7465	: V=1.023776, theta=-5.098586 -> V=1.0, theta=0.0
% INFO    : Bus 7466	: V=1.027457, theta=0.392065 -> V=1.0, theta=0.0
% INFO    : Bus 7467	: V=1.006837, theta=21.320742 -> V=1.0, theta=0.0
% INFO    : Bus 7468	: V=0.996113, theta=91.68458 -> V=1.0, theta=0.0
% INFO    : Bus 7469	: V=0.926519, theta=-12.060065 -> V=1.0, theta=0.0
% INFO    : Bus 7470	: V=1.060213, theta=11.478706 -> V=1.0, theta=0.0
% INFO    : Bus 7471	: V=1.030405, theta=-19.337916 -> V=1.0, theta=0.0
% INFO    : Bus 7472	: V=1.02918, theta=34.311008 -> V=1.0, theta=0.0
% INFO    : Bus 7473	: V=1.015521, theta=7.836059 -> V=1.0, theta=0.0
% INFO    : Bus 7474	: V=1.015682, theta=32.523561 -> V=1.0, theta=0.0
% INFO    : Bus 7475	: V=1.043764, theta=37.173377 -> V=1.0, theta=0.0
% INFO    : Bus 7476	: V=1.015161, theta=-11.543898 -> V=1.0, theta=0.0
% INFO    : Bus 7477	: V=1.015161, theta=-11.543898 -> V=1.0, theta=0.0
% INFO    : Bus 7478	: V=1.023844, theta=10.180784 -> V=1.0, theta=0.0
% INFO    : Bus 7479	: V=1.01549, theta=-16.739813 -> V=1.0, theta=0.0
% INFO    : Bus 7480	: V=1.026848, theta=-2.172567 -> V=1.0, theta=0.0
% INFO    : Bus 7481	: V=0.986796, theta=-8.205739 -> V=1.0, theta=0.0
% INFO    : Bus 7482	: V=1.012673, theta=-2.175699 -> V=1.0, theta=0.0
% INFO    : Bus 7483	: V=1.006165, theta=19.267453 -> V=1.0, theta=0.0
% INFO    : Bus 7484	: V=0.987767, theta=-4.687808 -> V=1.0, theta=0.0
% INFO    : Bus 7485	: V=1.000671, theta=-7.208347 -> V=1.0, theta=0.0
% INFO    : Bus 7486	: V=0.98001, theta=31.417055 -> V=1.0, theta=0.0
% INFO    : Bus 7487	: V=1.031445, theta=23.624078 -> V=1.0, theta=0.0
% INFO    : Bus 7488	: V=1.004387, theta=30.940233 -> V=1.0, theta=0.0
% INFO    : Bus 7489	: V=0.969605, theta=29.504132 -> V=1.0, theta=0.0
% INFO    : Bus 7490	: V=1.028453, theta=-12.903077 -> V=1.0, theta=0.0
% INFO    : Bus 7491	: V=1.022918, theta=-6.867161 -> V=1.0, theta=0.0
% INFO    : Bus 7492	: V=1.0082, theta=-3.889166 -> V=1.0, theta=0.0
% INFO    : Bus 7493	: V=1.024005, theta=3.431686 -> V=1.0, theta=0.0
% INFO    : Bus 7494	: V=0.976666, theta=29.531177 -> V=1.0, theta=0.0
% INFO    : Bus 7495	: V=0.966785, theta=-7.214159 -> V=1.0, theta=0.0
% INFO    : Bus 7496	: V=1.066456, theta=-4.571785 -> V=1.0, theta=0.0
% INFO    : Bus 7497	: V=0.971858, theta=-3.874575 -> V=1.0, theta=0.0
% INFO    : Bus 7498	: V=1.056333, theta=76.025167 -> V=1.0, theta=0.0
% INFO    : Bus 7499	: V=1.074058, theta=4.909711 -> V=1.0, theta=0.0
% INFO    : Bus 7500	: V=1.004576, theta=-15.207244 -> V=1.0, theta=0.0
% INFO    : Bus 7501	: V=1.050494, theta=10.971923 -> V=1.0, theta=0.0
% INFO    : Bus 7502	: V=1.044704, theta=16.811399 -> V=1.0, theta=0.0
% INFO    : Bus 7503	: V=1.042464, theta=13.256191 -> V=1.0, theta=0.0
% INFO    : Bus 7504	: V=1.044704, theta=16.811399 -> V=1.0, theta=0.0
% INFO    : Bus 7505	: V=1.033648, theta=19.100507 -> V=1.0, theta=0.0
% INFO    : Bus 7506	: V=1.03025, theta=4.714884 -> V=1.0, theta=0.0
% INFO    : Bus 7507	: V=1.050494, theta=10.971923 -> V=1.0, theta=0.0
% INFO    : Bus 7508	: V=1.036203, theta=12.985596 -> V=1.0, theta=0.0
% INFO    : Bus 7509	: V=1.036636, theta=21.536243 -> V=1.0, theta=0.0
% INFO    : Bus 7510	: V=1.026508, theta=-9.702337 -> V=1.0, theta=0.0
% INFO    : Bus 7511	: V=1.016367, theta=7.342385 -> V=1.0, theta=0.0
% INFO    : Bus 7512	: V=1.041748, theta=29.3468 -> V=1.0, theta=0.0
% INFO    : Bus 7513	: V=1.050204, theta=7.926973 -> V=1.0, theta=0.0
% INFO    : Bus 7514	: V=1.020185, theta=-9.133094 -> V=1.0, theta=0.0
% INFO    : Bus 7515	: V=1.015134, theta=26.112226 -> V=1.0, theta=0.0
% INFO    : Bus 7516	: V=1.050319, theta=7.519611 -> V=1.0, theta=0.0
% INFO    : Bus 7517	: V=1.009036, theta=-4.581287 -> V=1.0, theta=0.0
% INFO    : Bus 7518	: V=1.011944, theta=-15.886414 -> V=1.0, theta=0.0
% INFO    : Bus 7519	: V=1.04144, theta=33.928864 -> V=1.0, theta=0.0
% INFO    : Bus 7520	: V=0.966985, theta=-9.629605 -> V=1.0, theta=0.0
% INFO    : Bus 7521	: V=0.997786, theta=37.196075 -> V=1.0, theta=0.0
% INFO    : Bus 7522	: V=0.99887, theta=-8.910757 -> V=1.0, theta=0.0
% INFO    : Bus 7523	: V=1.046478, theta=33.359815 -> V=1.0, theta=0.0
% INFO    : Bus 7524	: V=1.046478, theta=33.359815 -> V=1.0, theta=0.0
% INFO    : Bus 7525	: V=1.051255, theta=-11.661899 -> V=1.0, theta=0.0
% INFO    : Bus 7526	: V=1.046478, theta=33.359815 -> V=1.0, theta=0.0
% INFO    : Bus 7527	: V=1.075024, theta=46.081157 -> V=1.0, theta=0.0
% INFO    : Bus 7528	: V=1.046478, theta=33.359815 -> V=1.0, theta=0.0
% INFO    : Bus 7529	: V=0.927084, theta=-10.698244 -> V=1.0, theta=0.0
% INFO    : Bus 7530	: V=1.011686, theta=94.331837 -> V=1.0, theta=0.0
% INFO    : Bus 7531	: V=1.048637, theta=18.752224 -> V=1.0, theta=0.0
% INFO    : Bus 7532	: V=1.016071, theta=-5.447511 -> V=1.0, theta=0.0
% INFO    : Bus 7533	: V=1.009464, theta=-1.490677 -> V=1.0, theta=0.0
% INFO    : Bus 7534	: V=1.048061, theta=37.584997 -> V=1.0, theta=0.0
% INFO    : Bus 7535	: V=1.04554, theta=8.581299 -> V=1.0, theta=0.0
% INFO    : Bus 7536	: V=1.033157, theta=12.58568 -> V=1.0, theta=0.0
% INFO    : Bus 7537	: V=1.001278, theta=5.844525 -> V=1.0, theta=0.0
% INFO    : Bus 7538	: V=0.974828, theta=-2.630234 -> V=1.0, theta=0.0
% INFO    : Bus 7539	: V=1.026207, theta=-11.793103 -> V=1.0, theta=0.0
% INFO    : Bus 7540	: V=1.016705, theta=-7.501421 -> V=1.0, theta=0.0
% INFO    : Bus 7541	: V=1.024052, theta=-20.491624 -> V=1.0, theta=0.0
% INFO    : Bus 7542	: V=1.046479, theta=-13.228828 -> V=1.0, theta=0.0
% INFO    : Bus 7543	: V=1.079263, theta=63.417816 -> V=1.0, theta=0.0
% INFO    : Bus 7544	: V=1.031898, theta=-9.317211 -> V=1.0, theta=0.0
% INFO    : Bus 7545	: V=1.023406, theta=33.215649 -> V=1.0, theta=0.0
% INFO    : Bus 7546	: V=0.944594, theta=-10.932082 -> V=1.0, theta=0.0
% INFO    : Bus 7547	: V=1.045375, theta=17.213843 -> V=1.0, theta=0.0
% INFO    : Bus 7548	: V=1.03676, theta=80.007231 -> V=1.0, theta=0.0
% INFO    : Bus 7549	: V=0.973721, theta=-10.511526 -> V=1.0, theta=0.0
% INFO    : Bus 7550	: V=1.033803, theta=2.408169 -> V=1.0, theta=0.0
% INFO    : Bus 7551	: V=1.044493, theta=17.115248 -> V=1.0, theta=0.0
% INFO    : Bus 7552	: V=1.01034, theta=-19.654143 -> V=1.0, theta=0.0
% INFO    : Bus 7553	: V=1.050063, theta=1.790288 -> V=1.0, theta=0.0
% INFO    : Bus 7554	: V=0.966012, theta=-26.182023 -> V=1.0, theta=0.0
% INFO    : Bus 7555	: V=1.03287, theta=9.234842 -> V=1.0, theta=0.0
% INFO    : Bus 7556	: V=0.979015, theta=43.42213 -> V=1.0, theta=0.0
% INFO    : Bus 7557	: V=1.017287, theta=26.369278 -> V=1.0, theta=0.0
% INFO    : Bus 7558	: V=1.017287, theta=26.369278 -> V=1.0, theta=0.0
% INFO    : Bus 7559	: V=1.017287, theta=26.369278 -> V=1.0, theta=0.0
% INFO    : Bus 7560	: V=1.017287, theta=26.369278 -> V=1.0, theta=0.0
% INFO    : Bus 7561	: V=1.050891, theta=3.953704 -> V=1.0, theta=0.0
% INFO    : Bus 7562	: V=1.026207, theta=28.927907 -> V=1.0, theta=0.0
% INFO    : Bus 7563	: V=1.026207, theta=28.927907 -> V=1.0, theta=0.0
% INFO    : Bus 7564	: V=1.048808, theta=20.576441 -> V=1.0, theta=0.0
% INFO    : Bus 7565	: V=1.028074, theta=9.122801 -> V=1.0, theta=0.0
% INFO    : Bus 7566	: V=0.967886, theta=-29.550722 -> V=1.0, theta=0.0
% INFO    : Bus 7567	: V=1.031559, theta=4.308699 -> V=1.0, theta=0.0
% INFO    : Bus 7568	: V=1.000449, theta=37.338871 -> V=1.0, theta=0.0
% INFO    : Bus 7569	: V=0.9959, theta=31.309077 -> V=1.0, theta=0.0
% INFO    : Bus 7570	: V=0.991874, theta=-3.881717 -> V=1.0, theta=0.0
% INFO    : Bus 7571	: V=1.029122, theta=21.17436 -> V=1.0, theta=0.0
% INFO    : Bus 7572	: V=1.017489, theta=3.82958 -> V=1.0, theta=0.0
% INFO    : Bus 7573	: V=1.017516, theta=24.916537 -> V=1.0, theta=0.0
% INFO    : Bus 7574	: V=1.085005, theta=72.392093 -> V=1.0, theta=0.0
% INFO    : Bus 7575	: V=1.037518, theta=8.166974 -> V=1.0, theta=0.0
% INFO    : Bus 7576	: V=1.036632, theta=21.536273 -> V=1.0, theta=0.0
% INFO    : Bus 7577	: V=0.977562, theta=26.05322 -> V=1.0, theta=0.0
% INFO    : Bus 7578	: V=0.966425, theta=19.011458 -> V=1.0, theta=0.0
% INFO    : Bus 7579	: V=0.994266, theta=24.822965 -> V=1.0, theta=0.0
% INFO    : Bus 7580	: V=1.032352, theta=-19.474633 -> V=1.0, theta=0.0
% INFO    : Bus 7581	: V=1.006747, theta=-6.692315 -> V=1.0, theta=0.0
% INFO    : Bus 7582	: V=1.021195, theta=-22.64557 -> V=1.0, theta=0.0
% INFO    : Bus 7583	: V=1.028403, theta=19.42587 -> V=1.0, theta=0.0
% INFO    : Bus 7584	: V=1.020593, theta=8.251081 -> V=1.0, theta=0.0
% INFO    : Bus 7585	: V=0.998951, theta=38.095582 -> V=1.0, theta=0.0
% INFO    : Bus 7586	: V=0.95133, theta=-12.17191 -> V=1.0, theta=0.0
% INFO    : Bus 7587	: V=1.018239, theta=-19.841296 -> V=1.0, theta=0.0
% INFO    : Bus 7588	: V=1.053124, theta=0.544081 -> V=1.0, theta=0.0
% INFO    : Bus 7589	: V=0.962323, theta=-5.059859 -> V=1.0, theta=0.0
% INFO    : Bus 7590	: V=1.00847, theta=2.517223 -> V=1.0, theta=0.0
% INFO    : Bus 7591	: V=1.037428, theta=-2.276022 -> V=1.0, theta=0.0
% INFO    : Bus 7592	: V=1.014219, theta=-26.230001 -> V=1.0, theta=0.0
% INFO    : Bus 7593	: V=0.999494, theta=10.749804 -> V=1.0, theta=0.0
% INFO    : Bus 7594	: V=1.012367, theta=19.105535 -> V=1.0, theta=0.0
% INFO    : Bus 7595	: V=1.029975, theta=-17.836256 -> V=1.0, theta=0.0
% INFO    : Bus 7596	: V=1.030725, theta=8.292435 -> V=1.0, theta=0.0
% INFO    : Bus 7597	: V=0.986301, theta=-14.390471 -> V=1.0, theta=0.0
% INFO    : Bus 7598	: V=1.039863, theta=93.944189 -> V=1.0, theta=0.0
% INFO    : Bus 7599	: V=1.056697, theta=84.200005 -> V=1.0, theta=0.0
% INFO    : Bus 7600	: V=1.034532, theta=19.101591 -> V=1.0, theta=0.0
% INFO    : Bus 7601	: V=0.993956, theta=27.916175 -> V=1.0, theta=0.0
% INFO    : Bus 7602	: V=1.052113, theta=29.000359 -> V=1.0, theta=0.0
% INFO    : Bus 7603	: V=1.017601, theta=-8.578565 -> V=1.0, theta=0.0
% INFO    : Bus 7604	: V=1.033074, theta=20.041137 -> V=1.0, theta=0.0
% INFO    : Bus 7605	: V=1.019087, theta=3.567469 -> V=1.0, theta=0.0
% INFO    : Bus 7606	: V=1.035028, theta=23.912435 -> V=1.0, theta=0.0
% INFO    : Bus 7607	: V=0.973132, theta=-9.209535 -> V=1.0, theta=0.0
% INFO    : Bus 7608	: V=1.02769, theta=0.17135 -> V=1.0, theta=0.0
% INFO    : Bus 7609	: V=1.019595, theta=11.893135 -> V=1.0, theta=0.0
% INFO    : Bus 7610	: V=1.010451, theta=-20.541975 -> V=1.0, theta=0.0
% INFO    : Bus 7611	: V=0.983582, theta=-5.301166 -> V=1.0, theta=0.0
% INFO    : Bus 7612	: V=1.021547, theta=-3.918499 -> V=1.0, theta=0.0
% INFO    : Bus 7613	: V=1.012556, theta=-8.920589 -> V=1.0, theta=0.0
% INFO    : Bus 7614	: V=0.996842, theta=30.308668 -> V=1.0, theta=0.0
% INFO    : Bus 7615	: V=0.900287, theta=-12.257818 -> V=1.0, theta=0.0
% INFO    : Bus 7616	: V=1.007201, theta=17.355456 -> V=1.0, theta=0.0
% INFO    : Bus 7617	: V=1.024793, theta=-7.141759 -> V=1.0, theta=0.0
% INFO    : Bus 7618	: V=0.961786, theta=-4.769176 -> V=1.0, theta=0.0
% INFO    : Bus 7619	: V=1.009246, theta=-1.433025 -> V=1.0, theta=0.0
% INFO    : Bus 7620	: V=0.957345, theta=-9.979812 -> V=1.0, theta=0.0
% INFO    : Bus 7621	: V=1.033359, theta=10.826321 -> V=1.0, theta=0.0
% INFO    : Bus 7622	: V=1.030095, theta=1.211663 -> V=1.0, theta=0.0
% INFO    : Bus 7623	: V=0.967258, theta=-0.3052 -> V=1.0, theta=0.0
% INFO    : Bus 7624	: V=1.032722, theta=23.254549 -> V=1.0, theta=0.0
% INFO    : Bus 7625	: V=1.040138, theta=32.45384 -> V=1.0, theta=0.0
% INFO    : Bus 7626	: V=0.986904, theta=36.297583 -> V=1.0, theta=0.0
% INFO    : Bus 7627	: V=1.026631, theta=0.05062 -> V=1.0, theta=0.0
% INFO    : Bus 7628	: V=1.052257, theta=44.731305 -> V=1.0, theta=0.0
% INFO    : Bus 7629	: V=1.019372, theta=-2.020811 -> V=1.0, theta=0.0
% INFO    : Bus 7630	: V=0.992585, theta=32.412682 -> V=1.0, theta=0.0
% INFO    : Bus 7631	: V=1.032145, theta=20.7029 -> V=1.0, theta=0.0
% INFO    : Bus 7632	: V=1.053421, theta=57.48218 -> V=1.0, theta=0.0
% INFO    : Bus 7633	: V=0.989151, theta=-11.706984 -> V=1.0, theta=0.0
% INFO    : Bus 7634	: V=1.04616, theta=-9.114978 -> V=1.0, theta=0.0
% INFO    : Bus 7635	: V=0.952203, theta=-7.669787 -> V=1.0, theta=0.0
% INFO    : Bus 7636	: V=1.059142, theta=21.764381 -> V=1.0, theta=0.0
% INFO    : Bus 7637	: V=1.059142, theta=21.764381 -> V=1.0, theta=0.0
% INFO    : Bus 7638	: V=1.041676, theta=14.357601 -> V=1.0, theta=0.0
% INFO    : Bus 7639	: V=1.005118, theta=2.132581 -> V=1.0, theta=0.0
% INFO    : Bus 7640	: V=1.020355, theta=-19.386832 -> V=1.0, theta=0.0
% INFO    : Bus 7641	: V=0.98379, theta=29.90696 -> V=1.0, theta=0.0
% INFO    : Bus 7642	: V=1.014614, theta=27.544046 -> V=1.0, theta=0.0
% INFO    : Bus 7643	: V=0.989847, theta=8.461746 -> V=1.0, theta=0.0
% INFO    : Bus 7644	: V=0.964474, theta=34.963089 -> V=1.0, theta=0.0
% INFO    : Bus 7645	: V=1.030879, theta=24.610942 -> V=1.0, theta=0.0
% INFO    : Bus 7646	: V=1.046867, theta=5.19198 -> V=1.0, theta=0.0
% INFO    : Bus 7647	: V=0.964216, theta=32.646923 -> V=1.0, theta=0.0
% INFO    : Bus 7648	: V=1.030879, theta=24.610942 -> V=1.0, theta=0.0
% INFO    : Bus 7649	: V=1.030879, theta=24.610942 -> V=1.0, theta=0.0
% INFO    : Bus 7650	: V=1.004253, theta=18.360619 -> V=1.0, theta=0.0
% INFO    : Bus 7651	: V=0.982403, theta=0.459837 -> V=1.0, theta=0.0
% INFO    : Bus 7652	: V=1.025091, theta=37.934609 -> V=1.0, theta=0.0
% INFO    : Bus 7653	: V=1.021282, theta=26.179888 -> V=1.0, theta=0.0
% INFO    : Bus 7654	: V=1.065374, theta=52.949406 -> V=1.0, theta=0.0
% INFO    : Bus 7655	: V=1.027345, theta=79.006607 -> V=1.0, theta=0.0
% INFO    : Bus 7656	: V=0.980995, theta=-7.049246 -> V=1.0, theta=0.0
% INFO    : Bus 7657	: V=1.0014, theta=-12.664749 -> V=1.0, theta=0.0
% INFO    : Bus 7658	: V=0.985093, theta=44.213476 -> V=1.0, theta=0.0
% INFO    : Bus 7659	: V=0.995622, theta=2.064857 -> V=1.0, theta=0.0
% INFO    : Bus 7660	: V=1.011162, theta=-11.417722 -> V=1.0, theta=0.0
% INFO    : Bus 7661	: V=1.009788, theta=-5.34131 -> V=1.0, theta=0.0
% INFO    : Bus 7662	: V=0.990464, theta=21.09396 -> V=1.0, theta=0.0
% INFO    : Bus 7663	: V=1.021775, theta=34.479028 -> V=1.0, theta=0.0
% INFO    : Bus 7664	: V=1.006123, theta=14.025015 -> V=1.0, theta=0.0
% INFO    : Bus 7665	: V=1.015795, theta=22.756038 -> V=1.0, theta=0.0
% INFO    : Bus 7666	: V=1.066932, theta=53.431939 -> V=1.0, theta=0.0
% INFO    : Bus 7667	: V=1.038747, theta=-8.642337 -> V=1.0, theta=0.0
% INFO    : Bus 7668	: V=1.018739, theta=-6.896129 -> V=1.0, theta=0.0
% INFO    : Bus 7669	: V=1.020153, theta=9.00136 -> V=1.0, theta=0.0
% INFO    : Bus 7670	: V=1.043163, theta=36.844687 -> V=1.0, theta=0.0
% INFO    : Bus 7671	: V=1.043163, theta=36.844687 -> V=1.0, theta=0.0
% INFO    : Bus 7672	: V=1.043163, theta=36.844687 -> V=1.0, theta=0.0
% INFO    : Bus 7673	: V=0.997952, theta=42.31077 -> V=1.0, theta=0.0
% INFO    : Bus 7674	: V=1.039038, theta=39.160421 -> V=1.0, theta=0.0
% INFO    : Bus 7675	: V=1.038621, theta=36.677136 -> V=1.0, theta=0.0
% INFO    : Bus 7676	: V=1.038621, theta=36.677136 -> V=1.0, theta=0.0
% INFO    : Bus 7677	: V=1.012381, theta=36.32396 -> V=1.0, theta=0.0
% INFO    : Bus 7678	: V=1.059011, theta=14.603372 -> V=1.0, theta=0.0
% INFO    : Bus 7679	: V=1.039579, theta=-17.294304 -> V=1.0, theta=0.0
% INFO    : Bus 7680	: V=0.996007, theta=40.621651 -> V=1.0, theta=0.0
% INFO    : Bus 7681	: V=0.948759, theta=58.410077 -> V=1.0, theta=0.0
% INFO    : Bus 7682	: V=0.97384, theta=-5.930731 -> V=1.0, theta=0.0
% INFO    : Bus 7683	: V=1.022827, theta=-6.906314 -> V=1.0, theta=0.0
% INFO    : Bus 7684	: V=1.025682, theta=-7.286792 -> V=1.0, theta=0.0
% INFO    : Bus 7685	: V=1.023538, theta=-11.335143 -> V=1.0, theta=0.0
% INFO    : Bus 7686	: V=0.978047, theta=-5.585121 -> V=1.0, theta=0.0
% INFO    : Bus 7687	: V=1.036304, theta=5.804838 -> V=1.0, theta=0.0
% INFO    : Bus 7688	: V=1.014024, theta=31.07903 -> V=1.0, theta=0.0
% INFO    : Bus 7689	: V=1.030566, theta=-6.658147 -> V=1.0, theta=0.0
% INFO    : Bus 7690	: V=1.026803, theta=33.480301 -> V=1.0, theta=0.0
% INFO    : Bus 7691	: V=1.057106, theta=10.677187 -> V=1.0, theta=0.0
% INFO    : Bus 7692	: V=0.998297, theta=91.50797 -> V=1.0, theta=0.0
% INFO    : Bus 7693	: V=0.978541, theta=-19.945206 -> V=1.0, theta=0.0
% INFO    : Bus 7694	: V=0.974594, theta=-3.800413 -> V=1.0, theta=0.0
% INFO    : Bus 7695	: V=1.014554, theta=-17.012577 -> V=1.0, theta=0.0
% INFO    : Bus 7696	: V=1.003899, theta=29.486608 -> V=1.0, theta=0.0
% INFO    : Bus 7697	: V=1.000697, theta=34.52941 -> V=1.0, theta=0.0
% INFO    : Bus 7698	: V=1.028653, theta=5.929535 -> V=1.0, theta=0.0
% INFO    : Bus 7699	: V=1.005266, theta=46.404335 -> V=1.0, theta=0.0
% INFO    : Bus 7700	: V=1.007844, theta=10.25283 -> V=1.0, theta=0.0
% INFO    : Bus 7701	: V=1.065243, theta=-6.294863 -> V=1.0, theta=0.0
% INFO    : Bus 7702	: V=1.0171, theta=-4.093262 -> V=1.0, theta=0.0
% INFO    : Bus 7703	: V=1.034971, theta=-1.011495 -> V=1.0, theta=0.0
% INFO    : Bus 7704	: V=0.994884, theta=-3.860114 -> V=1.0, theta=0.0
% INFO    : Bus 7705	: V=1.005763, theta=29.922079 -> V=1.0, theta=0.0
% INFO    : Bus 7706	: V=1.025326, theta=5.65858 -> V=1.0, theta=0.0
% INFO    : Bus 7707	: V=0.954584, theta=49.806962 -> V=1.0, theta=0.0
% INFO    : Bus 7708	: V=1.031582, theta=-3.692888 -> V=1.0, theta=0.0
% INFO    : Bus 7709	: V=1.031224, theta=8.621811 -> V=1.0, theta=0.0
% INFO    : Bus 7710	: V=1.01677, theta=27.238345 -> V=1.0, theta=0.0
% INFO    : Bus 7711	: V=0.995217, theta=14.929118 -> V=1.0, theta=0.0
% INFO    : Bus 7712	: V=1.033848, theta=35.240634 -> V=1.0, theta=0.0
% INFO    : Bus 7713	: V=1.023683, theta=-10.396377 -> V=1.0, theta=0.0
% INFO    : Bus 7714	: V=1.011968, theta=-8.193842 -> V=1.0, theta=0.0
% INFO    : Bus 7715	: V=1.025386, theta=8.904631 -> V=1.0, theta=0.0
% INFO    : Bus 7716	: V=1.02806, theta=-6.75496 -> V=1.0, theta=0.0
% INFO    : Bus 7717	: V=1.02806, theta=-6.75496 -> V=1.0, theta=0.0
% INFO    : Bus 7718	: V=0.993956, theta=-21.157564 -> V=1.0, theta=0.0
% INFO    : Bus 7719	: V=1.02806, theta=-6.75496 -> V=1.0, theta=0.0
% INFO    : Bus 7720	: V=0.973567, theta=19.26737 -> V=1.0, theta=0.0
% INFO    : Bus 7721	: V=1.02806, theta=-6.75496 -> V=1.0, theta=0.0
% INFO    : Bus 7722	: V=1.02806, theta=-6.75496 -> V=1.0, theta=0.0
% INFO    : Bus 7723	: V=1.005522, theta=27.151982 -> V=1.0, theta=0.0
% INFO    : Bus 7724	: V=1.038631, theta=53.209448 -> V=1.0, theta=0.0
% INFO    : Bus 7725	: V=1.018206, theta=51.157996 -> V=1.0, theta=0.0
% INFO    : Bus 7726	: V=1.027951, theta=5.82431 -> V=1.0, theta=0.0
% INFO    : Bus 7727	: V=1.000718, theta=32.41785 -> V=1.0, theta=0.0
% INFO    : Bus 7728	: V=1.086195, theta=-3.617645 -> V=1.0, theta=0.0
% INFO    : Bus 7729	: V=1.093017, theta=66.981987 -> V=1.0, theta=0.0
% INFO    : Bus 7730	: V=1.033879, theta=20.32366 -> V=1.0, theta=0.0
% INFO    : Bus 7731	: V=1.015733, theta=2.857525 -> V=1.0, theta=0.0
% INFO    : Bus 7732	: V=1.050328, theta=7.929133 -> V=1.0, theta=0.0
% INFO    : Bus 7733	: V=1.043338, theta=79.315336 -> V=1.0, theta=0.0
% INFO    : Bus 7734	: V=1.04043, theta=49.086444 -> V=1.0, theta=0.0
% INFO    : Bus 7735	: V=1.012081, theta=-5.974014 -> V=1.0, theta=0.0
% INFO    : Bus 7736	: V=1.064843, theta=50.81976 -> V=1.0, theta=0.0
% INFO    : Bus 7737	: V=0.99141, theta=-24.920151 -> V=1.0, theta=0.0
% INFO    : Bus 7738	: V=0.996569, theta=19.168156 -> V=1.0, theta=0.0
% INFO    : Bus 7739	: V=1.039146, theta=-7.96239 -> V=1.0, theta=0.0
% INFO    : Bus 7740	: V=1.045213, theta=9.250128 -> V=1.0, theta=0.0
% INFO    : Bus 7741	: V=1.029393, theta=20.464953 -> V=1.0, theta=0.0
% INFO    : Bus 7742	: V=1.022262, theta=22.386094 -> V=1.0, theta=0.0
% INFO    : Bus 7743	: V=0.993125, theta=29.628125 -> V=1.0, theta=0.0
% INFO    : Bus 7744	: V=0.991606, theta=-5.011662 -> V=1.0, theta=0.0
% INFO    : Bus 7745	: V=1.014605, theta=-26.887876 -> V=1.0, theta=0.0
% INFO    : Bus 7746	: V=1.00234, theta=-7.016126 -> V=1.0, theta=0.0
% INFO    : Bus 7747	: V=1.041754, theta=-0.054874 -> V=1.0, theta=0.0
% INFO    : Bus 7748	: V=1.031224, theta=9.624601 -> V=1.0, theta=0.0
% INFO    : Bus 7749	: V=1.032821, theta=24.353123 -> V=1.0, theta=0.0
% INFO    : Bus 7750	: V=1.008982, theta=42.351688 -> V=1.0, theta=0.0
% INFO    : Bus 7751	: V=1.008348, theta=30.337205 -> V=1.0, theta=0.0
% INFO    : Bus 7752	: V=1.014457, theta=46.592195 -> V=1.0, theta=0.0
% INFO    : Bus 7753	: V=0.990596, theta=-14.119287 -> V=1.0, theta=0.0
% INFO    : Bus 7754	: V=1.032344, theta=9.093698 -> V=1.0, theta=0.0
% INFO    : Bus 7755	: V=1.069965, theta=-1.842784 -> V=1.0, theta=0.0
% INFO    : Bus 7756	: V=1.015916, theta=42.071087 -> V=1.0, theta=0.0
% INFO    : Bus 7757	: V=1.081813, theta=65.890792 -> V=1.0, theta=0.0
% INFO    : Bus 7758	: V=0.987774, theta=6.666713 -> V=1.0, theta=0.0
% INFO    : Bus 7759	: V=0.970708, theta=-10.509264 -> V=1.0, theta=0.0
% INFO    : Bus 7760	: V=1.031909, theta=-3.777508 -> V=1.0, theta=0.0
% INFO    : Bus 7761	: V=1.036191, theta=16.7363 -> V=1.0, theta=0.0
% INFO    : Bus 7762	: V=0.970166, theta=-9.580952 -> V=1.0, theta=0.0
% INFO    : Bus 7763	: V=1.000824, theta=17.437935 -> V=1.0, theta=0.0
% INFO    : Bus 7764	: V=0.947723, theta=4.470254 -> V=1.0, theta=0.0
% INFO    : Bus 7765	: V=1.023288, theta=75.989607 -> V=1.0, theta=0.0
% INFO    : Bus 7766	: V=1.020274, theta=26.013456 -> V=1.0, theta=0.0
% INFO    : Bus 7767	: V=1.015998, theta=31.069444 -> V=1.0, theta=0.0
% INFO    : Bus 7768	: V=1.011648, theta=24.408754 -> V=1.0, theta=0.0
% INFO    : Bus 7769	: V=0.967461, theta=24.197449 -> V=1.0, theta=0.0
% INFO    : Bus 7770	: V=1.037193, theta=-13.548015 -> V=1.0, theta=0.0
% INFO    : Bus 7771	: V=1.063673, theta=-0.208683 -> V=1.0, theta=0.0
% INFO    : Bus 7772	: V=1.016119, theta=-9.542933 -> V=1.0, theta=0.0
% INFO    : Bus 7773	: V=1.018408, theta=19.83996 -> V=1.0, theta=0.0
% INFO    : Bus 7774	: V=1.019517, theta=-6.861741 -> V=1.0, theta=0.0
% INFO    : Bus 7775	: V=0.990546, theta=-8.428479 -> V=1.0, theta=0.0
% INFO    : Bus 7776	: V=1.032321, theta=27.942453 -> V=1.0, theta=0.0
% INFO    : Bus 7777	: V=1.009853, theta=14.713647 -> V=1.0, theta=0.0
% INFO    : Bus 7778	: V=0.991779, theta=-19.695979 -> V=1.0, theta=0.0
% INFO    : Bus 7779	: V=1.026053, theta=18.466754 -> V=1.0, theta=0.0
% INFO    : Bus 7780	: V=1.028263, theta=33.70683 -> V=1.0, theta=0.0
% INFO    : Bus 7781	: V=1.012112, theta=8.292067 -> V=1.0, theta=0.0
% INFO    : Bus 7782	: V=1.016164, theta=-3.688379 -> V=1.0, theta=0.0
% INFO    : Bus 7783	: V=0.984846, theta=37.960461 -> V=1.0, theta=0.0
% INFO    : Bus 7784	: V=1.023144, theta=-9.538309 -> V=1.0, theta=0.0
% INFO    : Bus 7785	: V=0.991494, theta=-4.787477 -> V=1.0, theta=0.0
% INFO    : Bus 7786	: V=0.985348, theta=-3.762933 -> V=1.0, theta=0.0
% INFO    : Bus 7787	: V=1.011021, theta=9.09354 -> V=1.0, theta=0.0
% INFO    : Bus 7788	: V=1.028111, theta=-1.849562 -> V=1.0, theta=0.0
% INFO    : Bus 7789	: V=1.020697, theta=60.764946 -> V=1.0, theta=0.0
% INFO    : Bus 7790	: V=1.004708, theta=-15.20422 -> V=1.0, theta=0.0
% INFO    : Bus 7791	: V=1.00454, theta=36.826069 -> V=1.0, theta=0.0
% INFO    : Bus 7792	: V=1.039218, theta=34.334547 -> V=1.0, theta=0.0
% INFO    : Bus 7793	: V=1.008722, theta=13.375916 -> V=1.0, theta=0.0
% INFO    : Bus 7794	: V=1.018005, theta=31.659728 -> V=1.0, theta=0.0
% INFO    : Bus 7795	: V=0.992301, theta=-5.634869 -> V=1.0, theta=0.0
% INFO    : Bus 7796	: V=1.012958, theta=20.531904 -> V=1.0, theta=0.0
% INFO    : Bus 7797	: V=1.025822, theta=-6.866112 -> V=1.0, theta=0.0
% INFO    : Bus 7798	: V=1.024428, theta=6.959359 -> V=1.0, theta=0.0
% INFO    : Bus 7799	: V=1.014249, theta=27.578122 -> V=1.0, theta=0.0
% INFO    : Bus 7800	: V=0.969691, theta=31.843897 -> V=1.0, theta=0.0
% INFO    : Bus 7801	: V=1.023124, theta=25.472115 -> V=1.0, theta=0.0
% INFO    : Bus 7802	: V=0.944949, theta=-10.831545 -> V=1.0, theta=0.0
% INFO    : Bus 7803	: V=0.912138, theta=-12.07238 -> V=1.0, theta=0.0
% INFO    : Bus 7804	: V=1.029984, theta=17.936173 -> V=1.0, theta=0.0
% INFO    : Bus 7805	: V=1.005544, theta=13.352738 -> V=1.0, theta=0.0
% INFO    : Bus 7806	: V=0.961678, theta=-15.621054 -> V=1.0, theta=0.0
% INFO    : Bus 7807	: V=1.024781, theta=6.070788 -> V=1.0, theta=0.0
% INFO    : Bus 7808	: V=1.031165, theta=22.577641 -> V=1.0, theta=0.0
% INFO    : Bus 7809	: V=1.012421, theta=-10.166509 -> V=1.0, theta=0.0
% INFO    : Bus 7810	: V=1.015703, theta=25.158766 -> V=1.0, theta=0.0
% INFO    : Bus 7811	: V=1.05855, theta=17.887152 -> V=1.0, theta=0.0
% INFO    : Bus 7812	: V=1.026025, theta=16.98036 -> V=1.0, theta=0.0
% INFO    : Bus 7813	: V=1.032564, theta=-19.50784 -> V=1.0, theta=0.0
% INFO    : Bus 7814	: V=1.064355, theta=32.276383 -> V=1.0, theta=0.0
% INFO    : Bus 7815	: V=1.034227, theta=18.922301 -> V=1.0, theta=0.0
% INFO    : Bus 7816	: V=1.040591, theta=20.715061 -> V=1.0, theta=0.0
% INFO    : Bus 7817	: V=1.028099, theta=32.52124 -> V=1.0, theta=0.0
% INFO    : Bus 7818	: V=1.023323, theta=44.777999 -> V=1.0, theta=0.0
% INFO    : Bus 7819	: V=1.027195, theta=-15.651629 -> V=1.0, theta=0.0
% INFO    : Bus 7820	: V=1.027195, theta=-15.651629 -> V=1.0, theta=0.0
% INFO    : Bus 7821	: V=1.027195, theta=-15.651629 -> V=1.0, theta=0.0
% INFO    : Bus 7822	: V=1.027195, theta=-15.651629 -> V=1.0, theta=0.0
% INFO    : Bus 7823	: V=1.076588, theta=-9.350023 -> V=1.0, theta=0.0
% INFO    : Bus 7824	: V=1.005017, theta=-18.861992 -> V=1.0, theta=0.0
% INFO    : Bus 7825	: V=1.027844, theta=-11.185494 -> V=1.0, theta=0.0
% INFO    : Bus 7826	: V=1.047585, theta=-13.395079 -> V=1.0, theta=0.0
% INFO    : Bus 7827	: V=1.002971, theta=29.68317 -> V=1.0, theta=0.0
% INFO    : Bus 7828	: V=0.989515, theta=88.943489 -> V=1.0, theta=0.0
% INFO    : Bus 7829	: V=0.996861, theta=27.639759 -> V=1.0, theta=0.0
% INFO    : Bus 7830	: V=1.010023, theta=-7.96254 -> V=1.0, theta=0.0
% INFO    : Bus 7831	: V=1.028315, theta=92.327608 -> V=1.0, theta=0.0
% INFO    : Bus 7832	: V=0.986743, theta=-17.679196 -> V=1.0, theta=0.0
% INFO    : Bus 7833	: V=1.027461, theta=-17.241264 -> V=1.0, theta=0.0
% INFO    : Bus 7834	: V=1.081314, theta=24.164392 -> V=1.0, theta=0.0
% INFO    : Bus 7835	: V=1.010769, theta=30.193461 -> V=1.0, theta=0.0
% INFO    : Bus 7836	: V=1.022953, theta=-11.439051 -> V=1.0, theta=0.0
% INFO    : Bus 7837	: V=0.993187, theta=-7.06435 -> V=1.0, theta=0.0
% INFO    : Bus 7838	: V=1.036605, theta=5.426006 -> V=1.0, theta=0.0
% INFO    : Bus 7839	: V=1.01143, theta=-10.415049 -> V=1.0, theta=0.0
% INFO    : Bus 7840	: V=1.024756, theta=7.179138 -> V=1.0, theta=0.0
% INFO    : Bus 7841	: V=1.006944, theta=-5.921798 -> V=1.0, theta=0.0
% INFO    : Bus 7842	: V=1.005097, theta=-2.034262 -> V=1.0, theta=0.0
% INFO    : Bus 7843	: V=0.978579, theta=18.445171 -> V=1.0, theta=0.0
% INFO    : Bus 7844	: V=1.048358, theta=31.36576 -> V=1.0, theta=0.0
% INFO    : Bus 7845	: V=1.020755, theta=30.541323 -> V=1.0, theta=0.0
% INFO    : Bus 7846	: V=1.048358, theta=31.36576 -> V=1.0, theta=0.0
% INFO    : Bus 7847	: V=1.006137, theta=-0.690843 -> V=1.0, theta=0.0
% INFO    : Bus 7848	: V=1.005097, theta=-2.034262 -> V=1.0, theta=0.0
% INFO    : Bus 7849	: V=1.041549, theta=2.824814 -> V=1.0, theta=0.0
% INFO    : Bus 7850	: V=0.994055, theta=13.044026 -> V=1.0, theta=0.0
% INFO    : Bus 7851	: V=1.005097, theta=-2.034262 -> V=1.0, theta=0.0
% INFO    : Bus 7852	: V=1.017465, theta=-8.354209 -> V=1.0, theta=0.0
% INFO    : Bus 7853	: V=1.033509, theta=29.0844 -> V=1.0, theta=0.0
% INFO    : Bus 7854	: V=1.027445, theta=-20.926376 -> V=1.0, theta=0.0
% INFO    : Bus 7855	: V=0.967513, theta=-5.643907 -> V=1.0, theta=0.0
% INFO    : Bus 7856	: V=1.017543, theta=13.164281 -> V=1.0, theta=0.0
% INFO    : Bus 7857	: V=1.014368, theta=23.036796 -> V=1.0, theta=0.0
% INFO    : Bus 7858	: V=1.037973, theta=11.471538 -> V=1.0, theta=0.0
% INFO    : Bus 7859	: V=1.022099, theta=17.218586 -> V=1.0, theta=0.0
% INFO    : Bus 7860	: V=1.006175, theta=27.984073 -> V=1.0, theta=0.0
% INFO    : Bus 7861	: V=1.039829, theta=-6.000279 -> V=1.0, theta=0.0
% INFO    : Bus 7862	: V=1.008156, theta=0.533035 -> V=1.0, theta=0.0
% INFO    : Bus 7863	: V=0.989328, theta=-5.037058 -> V=1.0, theta=0.0
% INFO    : Bus 7864	: V=1.024341, theta=-12.447897 -> V=1.0, theta=0.0
% INFO    : Bus 7865	: V=0.986315, theta=45.881122 -> V=1.0, theta=0.0
% INFO    : Bus 7866	: V=1.013108, theta=15.40527 -> V=1.0, theta=0.0
% INFO    : Bus 7867	: V=1.051051, theta=80.227836 -> V=1.0, theta=0.0
% INFO    : Bus 7868	: V=1.027313, theta=23.13711 -> V=1.0, theta=0.0
% INFO    : Bus 7869	: V=1.031202, theta=40.220313 -> V=1.0, theta=0.0
% INFO    : Bus 7870	: V=1.008153, theta=-6.482489 -> V=1.0, theta=0.0
% INFO    : Bus 7871	: V=1.031416, theta=-7.138703 -> V=1.0, theta=0.0
% INFO    : Bus 7872	: V=1.106096, theta=-3.070014 -> V=1.0, theta=0.0
% INFO    : Bus 7873	: V=0.986459, theta=-2.169128 -> V=1.0, theta=0.0
% INFO    : Bus 7874	: V=1.003978, theta=-4.980697 -> V=1.0, theta=0.0
% INFO    : Bus 7875	: V=1.055337, theta=0.681282 -> V=1.0, theta=0.0
% INFO    : Bus 7876	: V=1.011225, theta=-11.321651 -> V=1.0, theta=0.0
% INFO    : Bus 7877	: V=0.996117, theta=32.042491 -> V=1.0, theta=0.0
% INFO    : Bus 7878	: V=1.035434, theta=8.556606 -> V=1.0, theta=0.0
% INFO    : Bus 7879	: V=1.010494, theta=19.277469 -> V=1.0, theta=0.0
% INFO    : Bus 7880	: V=1.073183, theta=36.32563 -> V=1.0, theta=0.0
% INFO    : Bus 7881	: V=1.009545, theta=29.617666 -> V=1.0, theta=0.0
% INFO    : Bus 7882	: V=1.047679, theta=-11.39683 -> V=1.0, theta=0.0
% INFO    : Bus 7883	: V=1.008263, theta=28.002972 -> V=1.0, theta=0.0
% INFO    : Bus 7884	: V=1.040535, theta=35.122896 -> V=1.0, theta=0.0
% INFO    : Bus 7885	: V=0.988474, theta=-3.626576 -> V=1.0, theta=0.0
% INFO    : Bus 7886	: V=1.033255, theta=9.023406 -> V=1.0, theta=0.0
% INFO    : Bus 7887	: V=1.010224, theta=13.928751 -> V=1.0, theta=0.0
% INFO    : Bus 7888	: V=1.008603, theta=6.034417 -> V=1.0, theta=0.0
% INFO    : Bus 7889	: V=0.995215, theta=14.929193 -> V=1.0, theta=0.0
% INFO    : Bus 7890	: V=1.024544, theta=18.974877 -> V=1.0, theta=0.0
% INFO    : Bus 7891	: V=1.018138, theta=42.343965 -> V=1.0, theta=0.0
% INFO    : Bus 7892	: V=1.005547, theta=11.257255 -> V=1.0, theta=0.0
% INFO    : Bus 7893	: V=1.006809, theta=18.334783 -> V=1.0, theta=0.0
% INFO    : Bus 7894	: V=1.026448, theta=-3.53911 -> V=1.0, theta=0.0
% INFO    : Bus 7895	: V=1.076103, theta=-2.193069 -> V=1.0, theta=0.0
% INFO    : Bus 7896	: V=1.063731, theta=-8.12425 -> V=1.0, theta=0.0
% INFO    : Bus 7897	: V=1.016823, theta=7.32684 -> V=1.0, theta=0.0
% INFO    : Bus 7898	: V=1.002692, theta=26.834688 -> V=1.0, theta=0.0
% INFO    : Bus 7899	: V=1.034118, theta=0.51016 -> V=1.0, theta=0.0
% INFO    : Bus 7900	: V=1.025324, theta=1.838916 -> V=1.0, theta=0.0
% INFO    : Bus 7901	: V=1.037128, theta=1.366278 -> V=1.0, theta=0.0
% INFO    : Bus 7902	: V=1.037128, theta=1.366278 -> V=1.0, theta=0.0
% INFO    : Bus 7903	: V=1.016718, theta=-0.774001 -> V=1.0, theta=0.0
% INFO    : Bus 7904	: V=1.016718, theta=-0.774001 -> V=1.0, theta=0.0
% INFO    : Bus 7905	: V=1.042846, theta=0.690036 -> V=1.0, theta=0.0
% INFO    : Bus 7906	: V=1.01006, theta=29.755173 -> V=1.0, theta=0.0
% INFO    : Bus 7907	: V=0.993402, theta=10.337394 -> V=1.0, theta=0.0
% INFO    : Bus 7908	: V=1.016718, theta=-0.774001 -> V=1.0, theta=0.0
% INFO    : Bus 7909	: V=1.079773, theta=-12.967146 -> V=1.0, theta=0.0
% INFO    : Bus 7910	: V=1.011179, theta=13.966873 -> V=1.0, theta=0.0
% INFO    : Bus 7911	: V=1.015261, theta=-19.554209 -> V=1.0, theta=0.0
% INFO    : Bus 7912	: V=0.994456, theta=-2.15907 -> V=1.0, theta=0.0
% INFO    : Bus 7913	: V=1.02601, theta=13.667023 -> V=1.0, theta=0.0
% INFO    : Bus 7914	: V=1.040499, theta=5.769009 -> V=1.0, theta=0.0
% INFO    : Bus 7915	: V=1.034903, theta=75.355671 -> V=1.0, theta=0.0
% INFO    : Bus 7916	: V=1.074984, theta=17.200912 -> V=1.0, theta=0.0
% INFO    : Bus 7917	: V=1.048186, theta=30.077687 -> V=1.0, theta=0.0
% INFO    : Bus 7918	: V=0.994601, theta=31.575691 -> V=1.0, theta=0.0
% INFO    : Bus 7919	: V=1.017657, theta=42.270931 -> V=1.0, theta=0.0
% INFO    : Bus 7920	: V=1.029471, theta=-2.690244 -> V=1.0, theta=0.0
% INFO    : Bus 7921	: V=1.023478, theta=24.695749 -> V=1.0, theta=0.0
% INFO    : Bus 7922	: V=1.005907, theta=26.581496 -> V=1.0, theta=0.0
% INFO    : Bus 7923	: V=0.986867, theta=-7.038889 -> V=1.0, theta=0.0
% INFO    : Bus 7924	: V=0.984641, theta=-5.606786 -> V=1.0, theta=0.0
% INFO    : Bus 7925	: V=1.032265, theta=43.171125 -> V=1.0, theta=0.0
% INFO    : Bus 7926	: V=0.982765, theta=1.187555 -> V=1.0, theta=0.0
% INFO    : Bus 7927	: V=0.955017, theta=-5.135866 -> V=1.0, theta=0.0
% INFO    : Bus 7928	: V=1.009223, theta=1.639395 -> V=1.0, theta=0.0
% INFO    : Bus 7929	: V=1.034412, theta=41.712007 -> V=1.0, theta=0.0
% INFO    : Bus 7930	: V=1.129641, theta=7.22366 -> V=1.0, theta=0.0
% INFO    : Bus 7931	: V=1.026444, theta=23.18548 -> V=1.0, theta=0.0
% INFO    : Bus 7932	: V=1.028453, theta=-12.903077 -> V=1.0, theta=0.0
% INFO    : Bus 7933	: V=0.991806, theta=18.024083 -> V=1.0, theta=0.0
% INFO    : Bus 7934	: V=1.032454, theta=-19.078332 -> V=1.0, theta=0.0
% INFO    : Bus 7935	: V=0.979359, theta=-20.534001 -> V=1.0, theta=0.0
% INFO    : Bus 7936	: V=1.015733, theta=89.969438 -> V=1.0, theta=0.0
% INFO    : Bus 7937	: V=1.024372, theta=-3.025544 -> V=1.0, theta=0.0
% INFO    : Bus 7938	: V=1.029117, theta=21.174398 -> V=1.0, theta=0.0
% INFO    : Bus 7939	: V=1.019144, theta=17.562907 -> V=1.0, theta=0.0
% INFO    : Bus 7940	: V=0.930776, theta=-1.864544 -> V=1.0, theta=0.0
% INFO    : Bus 7941	: V=1.037259, theta=10.990708 -> V=1.0, theta=0.0
% INFO    : Bus 7942	: V=1.033674, theta=9.102988 -> V=1.0, theta=0.0
% INFO    : Bus 7943	: V=1.028453, theta=-12.903077 -> V=1.0, theta=0.0
% INFO    : Bus 7944	: V=0.975641, theta=-22.657708 -> V=1.0, theta=0.0
% INFO    : Bus 7945	: V=1.043815, theta=-4.396276 -> V=1.0, theta=0.0
% INFO    : Bus 7946	: V=1.027132, theta=31.963051 -> V=1.0, theta=0.0
% INFO    : Bus 7947	: V=1.065187, theta=-4.78518 -> V=1.0, theta=0.0
% INFO    : Bus 7948	: V=1.056758, theta=10.699713 -> V=1.0, theta=0.0
% INFO    : Bus 7949	: V=1.02542, theta=12.734487 -> V=1.0, theta=0.0
% INFO    : Bus 7950	: V=1.123995, theta=-0.160436 -> V=1.0, theta=0.0
% INFO    : Bus 7951	: V=0.987171, theta=19.06229 -> V=1.0, theta=0.0
% INFO    : Bus 7952	: V=1.030003, theta=-10.973638 -> V=1.0, theta=0.0
% INFO    : Bus 7953	: V=0.962686, theta=21.941446 -> V=1.0, theta=0.0
% INFO    : Bus 7954	: V=0.998859, theta=-19.342822 -> V=1.0, theta=0.0
% INFO    : Bus 7955	: V=1.034538, theta=4.92857 -> V=1.0, theta=0.0
% INFO    : Bus 7956	: V=1.032639, theta=0.267894 -> V=1.0, theta=0.0
% INFO    : Bus 7957	: V=0.999409, theta=1.749705 -> V=1.0, theta=0.0
% INFO    : Bus 7958	: V=1.025319, theta=-11.644989 -> V=1.0, theta=0.0
% INFO    : Bus 7959	: V=1.02166, theta=-5.451912 -> V=1.0, theta=0.0
% INFO    : Bus 7960	: V=1.012874, theta=43.808504 -> V=1.0, theta=0.0
% INFO    : Bus 7961	: V=1.026149, theta=4.103817 -> V=1.0, theta=0.0
% INFO    : Bus 7962	: V=1.03013, theta=4.624843 -> V=1.0, theta=0.0
% INFO    : Bus 7963	: V=1.048245, theta=57.713043 -> V=1.0, theta=0.0
% INFO    : Bus 7964	: V=0.969247, theta=-5.056037 -> V=1.0, theta=0.0
% INFO    : Bus 7965	: V=1.042865, theta=51.92649 -> V=1.0, theta=0.0
% INFO    : Bus 7966	: V=1.042865, theta=51.92649 -> V=1.0, theta=0.0
% INFO    : Bus 7967	: V=1.043738, theta=-8.975119 -> V=1.0, theta=0.0
% INFO    : Bus 7968	: V=1.015817, theta=-18.078109 -> V=1.0, theta=0.0
% INFO    : Bus 7969	: V=1.024873, theta=3.61754 -> V=1.0, theta=0.0
% INFO    : Bus 7970	: V=1.045647, theta=-10.158279 -> V=1.0, theta=0.0
% INFO    : Bus 7971	: V=1.028847, theta=5.912393 -> V=1.0, theta=0.0
% INFO    : Bus 7972	: V=0.945368, theta=40.225431 -> V=1.0, theta=0.0
% INFO    : Bus 7973	: V=1.009202, theta=-9.329154 -> V=1.0, theta=0.0
% INFO    : Bus 7974	: V=1.062085, theta=2.562194 -> V=1.0, theta=0.0
% INFO    : Bus 7975	: V=1.059168, theta=20.496879 -> V=1.0, theta=0.0
% INFO    : Bus 7976	: V=1.012031, theta=-8.893616 -> V=1.0, theta=0.0
% INFO    : Bus 7977	: V=0.991636, theta=-4.411495 -> V=1.0, theta=0.0
% INFO    : Bus 7978	: V=1.015664, theta=93.242149 -> V=1.0, theta=0.0
% INFO    : Bus 7979	: V=1.035023, theta=-10.739655 -> V=1.0, theta=0.0
% INFO    : Bus 7980	: V=1.102262, theta=-15.183704 -> V=1.0, theta=0.0
% INFO    : Bus 7981	: V=1.035023, theta=-10.739655 -> V=1.0, theta=0.0
% INFO    : Bus 7982	: V=1.013418, theta=23.824726 -> V=1.0, theta=0.0
% INFO    : Bus 7983	: V=1.039291, theta=34.333574 -> V=1.0, theta=0.0
% INFO    : Bus 7984	: V=1.034943, theta=4.996743 -> V=1.0, theta=0.0
% INFO    : Bus 7985	: V=1.037837, theta=-0.48399 -> V=1.0, theta=0.0
% INFO    : Bus 7986	: V=0.979495, theta=5.576426 -> V=1.0, theta=0.0
% INFO    : Bus 7987	: V=1.061678, theta=13.951101 -> V=1.0, theta=0.0
% INFO    : Bus 7988	: V=1.035023, theta=-10.739655 -> V=1.0, theta=0.0
% INFO    : Bus 7989	: V=1.035023, theta=-10.739655 -> V=1.0, theta=0.0
% INFO    : Bus 7990	: V=1.048569, theta=30.055695 -> V=1.0, theta=0.0
% INFO    : Bus 7991	: V=1.014936, theta=-2.091201 -> V=1.0, theta=0.0
% INFO    : Bus 7992	: V=1.041485, theta=29.444117 -> V=1.0, theta=0.0
% INFO    : Bus 7993	: V=1.041485, theta=29.444117 -> V=1.0, theta=0.0
% INFO    : Bus 7994	: V=0.990892, theta=-16.757203 -> V=1.0, theta=0.0
% INFO    : Bus 7995	: V=1.029709, theta=20.473808 -> V=1.0, theta=0.0
% INFO    : Bus 7996	: V=0.999047, theta=-9.556209 -> V=1.0, theta=0.0
% INFO    : Bus 7997	: V=1.099689, theta=80.197228 -> V=1.0, theta=0.0
% INFO    : Bus 7998	: V=0.9865, theta=27.337996 -> V=1.0, theta=0.0
% INFO    : Bus 7999	: V=1.022426, theta=18.257301 -> V=1.0, theta=0.0
% INFO    : Bus 8000	: V=1.029709, theta=20.473808 -> V=1.0, theta=0.0
% INFO    : Bus 8001	: V=1.029709, theta=20.473808 -> V=1.0, theta=0.0
% INFO    : Bus 8002	: V=0.995026, theta=-9.217762 -> V=1.0, theta=0.0
% INFO    : Bus 8003	: V=0.993351, theta=-7.087304 -> V=1.0, theta=0.0
% INFO    : Bus 8004	: V=1.038218, theta=-2.96549 -> V=1.0, theta=0.0
% INFO    : Bus 8005	: V=1.014429, theta=-26.565142 -> V=1.0, theta=0.0
% INFO    : Bus 8006	: V=0.989942, theta=-11.563854 -> V=1.0, theta=0.0
% INFO    : Bus 8007	: V=1.034063, theta=9.790369 -> V=1.0, theta=0.0
% INFO    : Bus 8008	: V=1.058182, theta=13.863396 -> V=1.0, theta=0.0
% INFO    : Bus 8009	: V=1.016709, theta=-11.6258 -> V=1.0, theta=0.0
% INFO    : Bus 8010	: V=0.981441, theta=27.374251 -> V=1.0, theta=0.0
% INFO    : Bus 8011	: V=1.048779, theta=17.891441 -> V=1.0, theta=0.0
% INFO    : Bus 8012	: V=0.964063, theta=-6.217216 -> V=1.0, theta=0.0
% INFO    : Bus 8013	: V=0.987716, theta=-14.359155 -> V=1.0, theta=0.0
% INFO    : Bus 8014	: V=1.017465, theta=-8.354209 -> V=1.0, theta=0.0
% INFO    : Bus 8015	: V=0.995728, theta=-9.194286 -> V=1.0, theta=0.0
% INFO    : Bus 8016	: V=1.005033, theta=-16.192033 -> V=1.0, theta=0.0
% INFO    : Bus 8017	: V=1.052257, theta=44.731305 -> V=1.0, theta=0.0
% INFO    : Bus 8018	: V=1.020785, theta=-32.057931 -> V=1.0, theta=0.0
% INFO    : Bus 8019	: V=1.028516, theta=-14.223496 -> V=1.0, theta=0.0
% INFO    : Bus 8020	: V=1.019656, theta=21.733827 -> V=1.0, theta=0.0
% INFO    : Bus 8021	: V=1.052257, theta=44.731305 -> V=1.0, theta=0.0
% INFO    : Bus 8022	: V=1.052257, theta=44.731305 -> V=1.0, theta=0.0
% INFO    : Bus 8023	: V=0.9595, theta=30.616672 -> V=1.0, theta=0.0
% INFO    : Bus 8024	: V=0.974629, theta=-2.300917 -> V=1.0, theta=0.0
% INFO    : Bus 8025	: V=1.013755, theta=-8.966796 -> V=1.0, theta=0.0
% INFO    : Bus 8026	: V=0.967843, theta=38.675053 -> V=1.0, theta=0.0
% INFO    : Bus 8027	: V=0.968655, theta=-15.322053 -> V=1.0, theta=0.0
% INFO    : Bus 8028	: V=1.012501, theta=-10.498035 -> V=1.0, theta=0.0
% INFO    : Bus 8029	: V=1.022632, theta=4.381728 -> V=1.0, theta=0.0
% INFO    : Bus 8030	: V=1.03685, theta=5.364208 -> V=1.0, theta=0.0
% INFO    : Bus 8031	: V=1.041947, theta=32.905618 -> V=1.0, theta=0.0
% INFO    : Bus 8032	: V=1.073663, theta=4.638114 -> V=1.0, theta=0.0
% INFO    : Bus 8033	: V=1.010732, theta=24.191523 -> V=1.0, theta=0.0
% INFO    : Bus 8034	: V=1.065239, theta=30.419096 -> V=1.0, theta=0.0
% INFO    : Bus 8035	: V=1.02239, theta=28.921949 -> V=1.0, theta=0.0
% INFO    : Bus 8036	: V=1.021827, theta=-0.432854 -> V=1.0, theta=0.0
% INFO    : Bus 8037	: V=1.038408, theta=-1.18914 -> V=1.0, theta=0.0
% INFO    : Bus 8038	: V=1.035923, theta=15.651998 -> V=1.0, theta=0.0
% INFO    : Bus 8039	: V=1.016716, theta=24.455607 -> V=1.0, theta=0.0
% INFO    : Bus 8040	: V=1.032725, theta=8.156247 -> V=1.0, theta=0.0
% INFO    : Bus 8041	: V=1.033791, theta=12.544574 -> V=1.0, theta=0.0
% INFO    : Bus 8042	: V=0.967135, theta=9.358512 -> V=1.0, theta=0.0
% INFO    : Bus 8043	: V=1.048207, theta=30.077507 -> V=1.0, theta=0.0
% INFO    : Bus 8044	: V=1.003644, theta=29.588773 -> V=1.0, theta=0.0
% INFO    : Bus 8045	: V=1.036466, theta=79.982353 -> V=1.0, theta=0.0
% INFO    : Bus 8046	: V=1.007687, theta=16.544078 -> V=1.0, theta=0.0
% INFO    : Bus 8047	: V=1.013027, theta=13.869066 -> V=1.0, theta=0.0
% INFO    : Bus 8048	: V=1.002448, theta=-8.572679 -> V=1.0, theta=0.0
% INFO    : Bus 8049	: V=1.015869, theta=-10.791845 -> V=1.0, theta=0.0
% INFO    : Bus 8050	: V=1.016762, theta=17.505942 -> V=1.0, theta=0.0
% INFO    : Bus 8051	: V=1.064407, theta=-2.034851 -> V=1.0, theta=0.0
% INFO    : Bus 8052	: V=1.017285, theta=27.012865 -> V=1.0, theta=0.0
% INFO    : Bus 8053	: V=1.028453, theta=-12.903077 -> V=1.0, theta=0.0
% INFO    : Bus 8054	: V=0.937011, theta=-2.220462 -> V=1.0, theta=0.0
% INFO    : Bus 8055	: V=1.028453, theta=-12.903077 -> V=1.0, theta=0.0
% INFO    : Bus 8056	: V=1.028453, theta=-12.903077 -> V=1.0, theta=0.0
% INFO    : Bus 8057	: V=0.989447, theta=3.221942 -> V=1.0, theta=0.0
% INFO    : Bus 8058	: V=1.018751, theta=-6.51886 -> V=1.0, theta=0.0
% INFO    : Bus 8059	: V=1.030513, theta=-3.211646 -> V=1.0, theta=0.0
% INFO    : Bus 8060	: V=0.939142, theta=40.851376 -> V=1.0, theta=0.0
% INFO    : Bus 8061	: V=1.009419, theta=14.139585 -> V=1.0, theta=0.0
% INFO    : Bus 8062	: V=0.912043, theta=-12.081031 -> V=1.0, theta=0.0
% INFO    : Bus 8063	: V=1.029166, theta=13.522836 -> V=1.0, theta=0.0
% INFO    : Bus 8064	: V=0.992477, theta=-17.499986 -> V=1.0, theta=0.0
% INFO    : Bus 8065	: V=1.054956, theta=5.244845 -> V=1.0, theta=0.0
% INFO    : Bus 8066	: V=0.979131, theta=-6.584456 -> V=1.0, theta=0.0
% INFO    : Bus 8067	: V=1.021005, theta=21.987746 -> V=1.0, theta=0.0
% INFO    : Bus 8068	: V=1.022252, theta=26.043187 -> V=1.0, theta=0.0
% INFO    : Bus 8069	: V=0.997732, theta=-13.333126 -> V=1.0, theta=0.0
% INFO    : Bus 8070	: V=0.986909, theta=14.960718 -> V=1.0, theta=0.0
% INFO    : Bus 8071	: V=0.997776, theta=-13.235724 -> V=1.0, theta=0.0
% INFO    : Bus 8072	: V=1.017257, theta=-3.442803 -> V=1.0, theta=0.0
% INFO    : Bus 8073	: V=0.978554, theta=-8.141372 -> V=1.0, theta=0.0
% INFO    : Bus 8074	: V=0.973556, theta=-6.561174 -> V=1.0, theta=0.0
% INFO    : Bus 8075	: V=1.032389, theta=35.40681 -> V=1.0, theta=0.0
% INFO    : Bus 8076	: V=1.039236, theta=44.914119 -> V=1.0, theta=0.0
% INFO    : Bus 8077	: V=1.055478, theta=38.52234 -> V=1.0, theta=0.0
% INFO    : Bus 8078	: V=0.928894, theta=-8.400611 -> V=1.0, theta=0.0
% INFO    : Bus 8079	: V=1.035694, theta=16.395031 -> V=1.0, theta=0.0
% INFO    : Bus 8080	: V=1.023776, theta=-5.098586 -> V=1.0, theta=0.0
% INFO    : Bus 8081	: V=1.011802, theta=45.75926 -> V=1.0, theta=0.0
% INFO    : Bus 8082	: V=0.99158, theta=-15.458284 -> V=1.0, theta=0.0
% INFO    : Bus 8083	: V=1.021745, theta=-7.001016 -> V=1.0, theta=0.0
% INFO    : Bus 8084	: V=1.026855, theta=-3.498214 -> V=1.0, theta=0.0
% INFO    : Bus 8085	: V=1.04669, theta=-18.503591 -> V=1.0, theta=0.0
% INFO    : Bus 8086	: V=0.969435, theta=-2.584123 -> V=1.0, theta=0.0
% INFO    : Bus 8087	: V=1.035327, theta=16.80885 -> V=1.0, theta=0.0
% INFO    : Bus 8088	: V=1.055956, theta=46.135912 -> V=1.0, theta=0.0
% INFO    : Bus 8089	: V=1.017878, theta=-10.871595 -> V=1.0, theta=0.0
% INFO    : Bus 8090	: V=1.055956, theta=46.135912 -> V=1.0, theta=0.0
% INFO    : Bus 8091	: V=0.951565, theta=38.529485 -> V=1.0, theta=0.0
% INFO    : Bus 8092	: V=1.027348, theta=16.396901 -> V=1.0, theta=0.0
% INFO    : Bus 8093	: V=1.028437, theta=11.212731 -> V=1.0, theta=0.0
% INFO    : Bus 8094	: V=1.001052, theta=28.442883 -> V=1.0, theta=0.0
% INFO    : Bus 8095	: V=1.00298, theta=10.352439 -> V=1.0, theta=0.0
% INFO    : Bus 8096	: V=1.015954, theta=3.75914 -> V=1.0, theta=0.0
% INFO    : Bus 8097	: V=1.043138, theta=41.982485 -> V=1.0, theta=0.0
% INFO    : Bus 8098	: V=1.036356, theta=36.321766 -> V=1.0, theta=0.0
% INFO    : Bus 8099	: V=1.028604, theta=-12.690591 -> V=1.0, theta=0.0
% INFO    : Bus 8100	: V=1.006677, theta=-15.127499 -> V=1.0, theta=0.0
% INFO    : Bus 8101	: V=0.97105, theta=7.093885 -> V=1.0, theta=0.0
% INFO    : Bus 8102	: V=1.004221, theta=-3.48294 -> V=1.0, theta=0.0
% INFO    : Bus 8103	: V=1.021286, theta=7.910246 -> V=1.0, theta=0.0
% INFO    : Bus 8104	: V=1.017654, theta=25.468999 -> V=1.0, theta=0.0
% INFO    : Bus 8105	: V=1.059015, theta=5.650918 -> V=1.0, theta=0.0
% INFO    : Bus 8106	: V=1.032111, theta=19.618252 -> V=1.0, theta=0.0
% INFO    : Bus 8107	: V=1.025876, theta=-12.172104 -> V=1.0, theta=0.0
% INFO    : Bus 8108	: V=1.017196, theta=5.79313 -> V=1.0, theta=0.0
% INFO    : Bus 8109	: V=1.010466, theta=11.179882 -> V=1.0, theta=0.0
% INFO    : Bus 8110	: V=1.055415, theta=20.933966 -> V=1.0, theta=0.0
% INFO    : Bus 8111	: V=1.049781, theta=32.053958 -> V=1.0, theta=0.0
% INFO    : Bus 8112	: V=1.055415, theta=20.933966 -> V=1.0, theta=0.0
% INFO    : Bus 8113	: V=1.051968, theta=36.354642 -> V=1.0, theta=0.0
% INFO    : Bus 8114	: V=1.049781, theta=32.053958 -> V=1.0, theta=0.0
% INFO    : Bus 8115	: V=0.934933, theta=-8.893156 -> V=1.0, theta=0.0
% INFO    : Bus 8116	: V=1.051968, theta=36.354642 -> V=1.0, theta=0.0
% INFO    : Bus 8117	: V=0.993316, theta=-11.194562 -> V=1.0, theta=0.0
% INFO    : Bus 8118	: V=1.016798, theta=24.876978 -> V=1.0, theta=0.0
% INFO    : Bus 8119	: V=0.99229, theta=29.110566 -> V=1.0, theta=0.0
% INFO    : Bus 8120	: V=0.966664, theta=-9.644625 -> V=1.0, theta=0.0
% INFO    : Bus 8121	: V=0.989111, theta=40.491338 -> V=1.0, theta=0.0
% INFO    : Bus 8122	: V=0.984601, theta=26.113186 -> V=1.0, theta=0.0
% INFO    : Bus 8123	: V=1.031098, theta=31.248826 -> V=1.0, theta=0.0
% INFO    : Bus 8124	: V=1.003398, theta=5.466678 -> V=1.0, theta=0.0
% INFO    : Bus 8125	: V=1.020649, theta=22.846825 -> V=1.0, theta=0.0
% INFO    : Bus 8126	: V=1.031098, theta=31.248826 -> V=1.0, theta=0.0
% INFO    : Bus 8127	: V=1.020649, theta=22.846825 -> V=1.0, theta=0.0
% INFO    : Bus 8128	: V=1.020649, theta=22.846825 -> V=1.0, theta=0.0
% INFO    : Bus 8129	: V=0.971373, theta=-3.469829 -> V=1.0, theta=0.0
% INFO    : Bus 8130	: V=1.046665, theta=36.809947 -> V=1.0, theta=0.0
% INFO    : Bus 8131	: V=1.043422, theta=-6.379294 -> V=1.0, theta=0.0
% INFO    : Bus 8132	: V=1.023685, theta=43.657157 -> V=1.0, theta=0.0
% INFO    : Bus 8133	: V=0.999092, theta=-12.216942 -> V=1.0, theta=0.0
% INFO    : Bus 8134	: V=1.033347, theta=0.325046 -> V=1.0, theta=0.0
% INFO    : Bus 8135	: V=1.0361, theta=25.930527 -> V=1.0, theta=0.0
% INFO    : Bus 8136	: V=0.970328, theta=-8.450182 -> V=1.0, theta=0.0
% INFO    : Bus 8137	: V=0.991126, theta=-1.596968 -> V=1.0, theta=0.0
% INFO    : Bus 8138	: V=1.007204, theta=28.534975 -> V=1.0, theta=0.0
% INFO    : Bus 8139	: V=1.013364, theta=25.066455 -> V=1.0, theta=0.0
% INFO    : Bus 8140	: V=1.013087, theta=29.534987 -> V=1.0, theta=0.0
% INFO    : Bus 8141	: V=1.026372, theta=24.396837 -> V=1.0, theta=0.0
% INFO    : Bus 8142	: V=0.997551, theta=-14.582917 -> V=1.0, theta=0.0
% INFO    : Bus 8143	: V=1.029542, theta=-3.096329 -> V=1.0, theta=0.0
% INFO    : Bus 8144	: V=1.007809, theta=-24.274205 -> V=1.0, theta=0.0
% INFO    : Bus 8145	: V=1.055063, theta=40.300168 -> V=1.0, theta=0.0
% INFO    : Bus 8146	: V=1.053776, theta=40.435567 -> V=1.0, theta=0.0
% INFO    : Bus 8147	: V=1.050978, theta=39.760414 -> V=1.0, theta=0.0
% INFO    : Bus 8148	: V=1.050978, theta=39.760414 -> V=1.0, theta=0.0
% INFO    : Bus 8149	: V=1.053776, theta=40.435567 -> V=1.0, theta=0.0
% INFO    : Bus 8150	: V=1.044994, theta=-2.361946 -> V=1.0, theta=0.0
% INFO    : Bus 8151	: V=1.051219, theta=38.74676 -> V=1.0, theta=0.0
% INFO    : Bus 8152	: V=1.000571, theta=-9.357387 -> V=1.0, theta=0.0
% INFO    : Bus 8153	: V=1.050978, theta=39.760414 -> V=1.0, theta=0.0
% INFO    : Bus 8154	: V=1.051219, theta=38.74676 -> V=1.0, theta=0.0
% INFO    : Bus 8155	: V=1.03518, theta=30.602846 -> V=1.0, theta=0.0
% INFO    : Bus 8156	: V=1.063032, theta=10.867657 -> V=1.0, theta=0.0
% INFO    : Bus 8157	: V=0.996935, theta=21.950327 -> V=1.0, theta=0.0
% INFO    : Bus 8158	: V=1.069519, theta=18.108418 -> V=1.0, theta=0.0
% INFO    : Bus 8159	: V=1.040138, theta=32.45384 -> V=1.0, theta=0.0
% INFO    : Bus 8160	: V=0.996411, theta=16.073394 -> V=1.0, theta=0.0
% INFO    : Bus 8161	: V=0.998943, theta=95.769564 -> V=1.0, theta=0.0
% INFO    : Bus 8162	: V=1.054462, theta=48.756838 -> V=1.0, theta=0.0
% INFO    : Bus 8163	: V=0.992395, theta=35.295433 -> V=1.0, theta=0.0
% INFO    : Bus 8164	: V=1.019889, theta=6.724749 -> V=1.0, theta=0.0
% INFO    : Bus 8165	: V=1.020439, theta=35.495297 -> V=1.0, theta=0.0
% INFO    : Bus 8166	: V=1.02045, theta=25.177237 -> V=1.0, theta=0.0
% INFO    : Bus 8167	: V=1.086148, theta=2.994871 -> V=1.0, theta=0.0
% INFO    : Bus 8168	: V=0.972825, theta=-28.705322 -> V=1.0, theta=0.0
% INFO    : Bus 8169	: V=0.990939, theta=17.193294 -> V=1.0, theta=0.0
% INFO    : Bus 8170	: V=0.994021, theta=-3.834903 -> V=1.0, theta=0.0
% INFO    : Bus 8171	: V=1.036322, theta=-8.15799 -> V=1.0, theta=0.0
% INFO    : Bus 8172	: V=1.040945, theta=-3.367 -> V=1.0, theta=0.0
% INFO    : Bus 8173	: V=1.054462, theta=48.756838 -> V=1.0, theta=0.0
% INFO    : Bus 8174	: V=0.99236, theta=88.032583 -> V=1.0, theta=0.0
% INFO    : Bus 8175	: V=1.054662, theta=30.426567 -> V=1.0, theta=0.0
% INFO    : Bus 8176	: V=1.072959, theta=74.686739 -> V=1.0, theta=0.0
% INFO    : Bus 8177	: V=1.021373, theta=-15.288951 -> V=1.0, theta=0.0
% INFO    : Bus 8178	: V=1.007637, theta=20.568351 -> V=1.0, theta=0.0
% INFO    : Bus 8179	: V=0.997286, theta=47.055099 -> V=1.0, theta=0.0
% INFO    : Bus 8180	: V=0.993632, theta=-5.154689 -> V=1.0, theta=0.0
% INFO    : Bus 8181	: V=1.014524, theta=16.614362 -> V=1.0, theta=0.0
% INFO    : Bus 8182	: V=1.055819, theta=25.808549 -> V=1.0, theta=0.0
% INFO    : Bus 8183	: V=1.044682, theta=-6.242353 -> V=1.0, theta=0.0
% INFO    : Bus 8184	: V=1.028869, theta=-21.802606 -> V=1.0, theta=0.0
% INFO    : Bus 8185	: V=1.013946, theta=-14.578261 -> V=1.0, theta=0.0
% INFO    : Bus 8186	: V=1.037828, theta=-1.327147 -> V=1.0, theta=0.0
% INFO    : Bus 8187	: V=1.044665, theta=38.20133 -> V=1.0, theta=0.0
% INFO    : Bus 8188	: V=0.970886, theta=-7.359378 -> V=1.0, theta=0.0
% INFO    : Bus 8189	: V=1.017415, theta=11.420798 -> V=1.0, theta=0.0
% INFO    : Bus 8190	: V=1.06045, theta=-6.223335 -> V=1.0, theta=0.0
% INFO    : Bus 8191	: V=1.050901, theta=18.201002 -> V=1.0, theta=0.0
% INFO    : Bus 8192	: V=1.022252, theta=-1.200424 -> V=1.0, theta=0.0
% INFO    : Bus 8193	: V=1.013271, theta=19.830863 -> V=1.0, theta=0.0
% INFO    : Bus 8194	: V=1.070002, theta=-2.899764 -> V=1.0, theta=0.0
% INFO    : Bus 8195	: V=1.059478, theta=-5.258058 -> V=1.0, theta=0.0
% INFO    : Bus 8196	: V=0.9786, theta=-5.693268 -> V=1.0, theta=0.0
% INFO    : Bus 8197	: V=1.026084, theta=-2.579099 -> V=1.0, theta=0.0
% INFO    : Bus 8198	: V=0.963234, theta=-6.344118 -> V=1.0, theta=0.0
% INFO    : Bus 8199	: V=1.013946, theta=-14.578261 -> V=1.0, theta=0.0
% INFO    : Bus 8200	: V=1.018239, theta=-19.841296 -> V=1.0, theta=0.0
% INFO    : Bus 8201	: V=0.974036, theta=-11.281582 -> V=1.0, theta=0.0
% INFO    : Bus 8202	: V=0.959478, theta=45.430548 -> V=1.0, theta=0.0
% INFO    : Bus 8203	: V=1.05014, theta=25.794001 -> V=1.0, theta=0.0
% INFO    : Bus 8204	: V=0.986885, theta=-15.737631 -> V=1.0, theta=0.0
% INFO    : Bus 8205	: V=1.042184, theta=0.453797 -> V=1.0, theta=0.0
% INFO    : Bus 8206	: V=1.01282, theta=1.386847 -> V=1.0, theta=0.0
% INFO    : Bus 8207	: V=0.96659, theta=-5.094534 -> V=1.0, theta=0.0
% INFO    : Bus 8208	: V=1.029519, theta=20.554688 -> V=1.0, theta=0.0
% INFO    : Bus 8209	: V=0.958018, theta=-29.201992 -> V=1.0, theta=0.0
% INFO    : Bus 8210	: V=0.947288, theta=-10.924648 -> V=1.0, theta=0.0
% INFO    : Bus 8211	: V=0.987721, theta=33.847662 -> V=1.0, theta=0.0
% INFO    : Bus 8212	: V=1.042943, theta=-7.588989 -> V=1.0, theta=0.0
% INFO    : Bus 8213	: V=1.07209, theta=1.461296 -> V=1.0, theta=0.0
% INFO    : Bus 8214	: V=0.963725, theta=-9.838418 -> V=1.0, theta=0.0
% INFO    : Bus 8215	: V=1.008023, theta=7.053534 -> V=1.0, theta=0.0
% INFO    : Bus 8216	: V=1.015887, theta=34.293408 -> V=1.0, theta=0.0
% INFO    : Bus 8217	: V=1.049377, theta=3.839235 -> V=1.0, theta=0.0
% INFO    : Bus 8218	: V=1.041811, theta=28.30558 -> V=1.0, theta=0.0
% INFO    : Bus 8219	: V=1.041811, theta=28.30558 -> V=1.0, theta=0.0
% INFO    : Bus 8220	: V=1.041811, theta=28.30558 -> V=1.0, theta=0.0
% INFO    : Bus 8221	: V=1.041811, theta=28.30558 -> V=1.0, theta=0.0
% INFO    : Bus 8222	: V=1.041811, theta=28.30558 -> V=1.0, theta=0.0
% INFO    : Bus 8223	: V=1.041811, theta=28.30558 -> V=1.0, theta=0.0
% INFO    : Bus 8224	: V=1.041811, theta=28.30558 -> V=1.0, theta=0.0
% INFO    : Bus 8225	: V=0.990878, theta=-13.512721 -> V=1.0, theta=0.0
% INFO    : Bus 8226	: V=1.047959, theta=30.05409 -> V=1.0, theta=0.0
% INFO    : Bus 8227	: V=0.975802, theta=-29.038137 -> V=1.0, theta=0.0
% INFO    : Bus 8228	: V=0.989489, theta=31.955589 -> V=1.0, theta=0.0
% INFO    : Bus 8229	: V=0.982612, theta=-23.764535 -> V=1.0, theta=0.0
% INFO    : Bus 8230	: V=0.998349, theta=-1.002676 -> V=1.0, theta=0.0
% INFO    : Bus 8231	: V=0.973304, theta=-5.681095 -> V=1.0, theta=0.0
% INFO    : Bus 8232	: V=0.988357, theta=17.315704 -> V=1.0, theta=0.0
% INFO    : Bus 8233	: V=0.983939, theta=28.475593 -> V=1.0, theta=0.0
% INFO    : Bus 8234	: V=1.040974, theta=41.75659 -> V=1.0, theta=0.0
% INFO    : Bus 8235	: V=0.984449, theta=-9.992776 -> V=1.0, theta=0.0
% INFO    : Bus 8236	: V=1.037105, theta=2.47416 -> V=1.0, theta=0.0
% INFO    : Bus 8237	: V=1.020725, theta=23.17778 -> V=1.0, theta=0.0
% INFO    : Bus 8238	: V=0.989115, theta=-13.585363 -> V=1.0, theta=0.0
% INFO    : Bus 8239	: V=0.998394, theta=26.560836 -> V=1.0, theta=0.0
% INFO    : Bus 8240	: V=1.032922, theta=24.930845 -> V=1.0, theta=0.0
% INFO    : Bus 8241	: V=1.049466, theta=-3.512776 -> V=1.0, theta=0.0
% INFO    : Bus 8242	: V=1.028214, theta=5.959625 -> V=1.0, theta=0.0
% INFO    : Bus 8243	: V=0.989854, theta=4.973943 -> V=1.0, theta=0.0
% INFO    : Bus 8244	: V=0.974047, theta=-4.969632 -> V=1.0, theta=0.0
% INFO    : Bus 8245	: V=0.987861, theta=-10.819537 -> V=1.0, theta=0.0
% INFO    : Bus 8246	: V=1.024094, theta=0.934183 -> V=1.0, theta=0.0
% INFO    : Bus 8247	: V=1.001207, theta=-14.751255 -> V=1.0, theta=0.0
% INFO    : Bus 8248	: V=1.041516, theta=-6.856455 -> V=1.0, theta=0.0
% INFO    : Bus 8249	: V=1.066577, theta=30.679964 -> V=1.0, theta=0.0
% INFO    : Bus 8250	: V=1.011444, theta=46.587511 -> V=1.0, theta=0.0
% INFO    : Bus 8251	: V=1.039863, theta=20.752002 -> V=1.0, theta=0.0
% INFO    : Bus 8252	: V=0.993565, theta=42.531711 -> V=1.0, theta=0.0
% INFO    : Bus 8253	: V=1.010291, theta=28.950447 -> V=1.0, theta=0.0
% INFO    : Bus 8254	: V=1.013443, theta=-15.402449 -> V=1.0, theta=0.0
% INFO    : Bus 8255	: V=0.991767, theta=-4.43535 -> V=1.0, theta=0.0
% INFO    : Bus 8256	: V=1.017229, theta=-19.936916 -> V=1.0, theta=0.0
% INFO    : Bus 8257	: V=0.979379, theta=-5.99893 -> V=1.0, theta=0.0
% INFO    : Bus 8258	: V=1.025358, theta=-4.388867 -> V=1.0, theta=0.0
% INFO    : Bus 8259	: V=0.972704, theta=-13.911507 -> V=1.0, theta=0.0
% INFO    : Bus 8260	: V=1.025058, theta=30.614922 -> V=1.0, theta=0.0
% INFO    : Bus 8261	: V=1.024585, theta=32.972112 -> V=1.0, theta=0.0
% INFO    : Bus 8262	: V=1.001838, theta=-13.924947 -> V=1.0, theta=0.0
% INFO    : Bus 8263	: V=1.018306, theta=-3.275258 -> V=1.0, theta=0.0
% INFO    : Bus 8264	: V=1.020098, theta=6.744104 -> V=1.0, theta=0.0
% INFO    : Bus 8265	: V=0.979331, theta=-8.607713 -> V=1.0, theta=0.0
% INFO    : Bus 8266	: V=1.002425, theta=90.543113 -> V=1.0, theta=0.0
% INFO    : Bus 8267	: V=1.062023, theta=13.37906 -> V=1.0, theta=0.0
% INFO    : Bus 8268	: V=1.020179, theta=-26.326218 -> V=1.0, theta=0.0
% INFO    : Bus 8269	: V=1.022265, theta=29.224087 -> V=1.0, theta=0.0
% INFO    : Bus 8270	: V=0.982114, theta=29.866731 -> V=1.0, theta=0.0
% INFO    : Bus 8271	: V=1.08802, theta=1.365864 -> V=1.0, theta=0.0
% INFO    : Bus 8272	: V=1.006525, theta=-15.938718 -> V=1.0, theta=0.0
% INFO    : Bus 8273	: V=0.994009, theta=18.407286 -> V=1.0, theta=0.0
% INFO    : Bus 8274	: V=1.014321, theta=25.016584 -> V=1.0, theta=0.0
% INFO    : Bus 8275	: V=1.014321, theta=25.016584 -> V=1.0, theta=0.0
% INFO    : Bus 8276	: V=1.014321, theta=25.016584 -> V=1.0, theta=0.0
% INFO    : Bus 8277	: V=1.030431, theta=21.089276 -> V=1.0, theta=0.0
% INFO    : Bus 8278	: V=1.016217, theta=20.317809 -> V=1.0, theta=0.0
% INFO    : Bus 8279	: V=1.021606, theta=-18.065799 -> V=1.0, theta=0.0
% INFO    : Bus 8280	: V=0.967096, theta=31.751104 -> V=1.0, theta=0.0
% INFO    : Bus 8281	: V=1.064717, theta=0.810879 -> V=1.0, theta=0.0
% INFO    : Bus 8282	: V=1.023094, theta=-17.062795 -> V=1.0, theta=0.0
% INFO    : Bus 8283	: V=1.031827, theta=1.976857 -> V=1.0, theta=0.0
% INFO    : Bus 8284	: V=1.041322, theta=11.945773 -> V=1.0, theta=0.0
% INFO    : Bus 8285	: V=1.054641, theta=7.773991 -> V=1.0, theta=0.0
% INFO    : Bus 8286	: V=0.989646, theta=-1.533454 -> V=1.0, theta=0.0
% INFO    : Bus 8287	: V=0.988464, theta=12.175779 -> V=1.0, theta=0.0
% INFO    : Bus 8288	: V=1.014387, theta=-20.165566 -> V=1.0, theta=0.0
% INFO    : Bus 8289	: V=0.999876, theta=-0.254373 -> V=1.0, theta=0.0
% INFO    : Bus 8290	: V=1.01208, theta=8.274182 -> V=1.0, theta=0.0
% INFO    : Bus 8291	: V=0.988122, theta=-11.257963 -> V=1.0, theta=0.0
% INFO    : Bus 8292	: V=1.037284, theta=23.086 -> V=1.0, theta=0.0
% INFO    : Bus 8293	: V=0.99154, theta=-14.522454 -> V=1.0, theta=0.0
% INFO    : Bus 8294	: V=0.973884, theta=41.032516 -> V=1.0, theta=0.0
% INFO    : Bus 8295	: V=1.019144, theta=-3.508016 -> V=1.0, theta=0.0
% INFO    : Bus 8296	: V=1.052651, theta=-3.861667 -> V=1.0, theta=0.0
% INFO    : Bus 8297	: V=0.997834, theta=-23.10233 -> V=1.0, theta=0.0
% INFO    : Bus 8298	: V=1.085507, theta=-20.189527 -> V=1.0, theta=0.0
% INFO    : Bus 8299	: V=1.011227, theta=39.453645 -> V=1.0, theta=0.0
% INFO    : Bus 8300	: V=1.042262, theta=-4.737566 -> V=1.0, theta=0.0
% INFO    : Bus 8301	: V=1.029941, theta=-14.211447 -> V=1.0, theta=0.0
% INFO    : Bus 8302	: V=1.007431, theta=-12.204666 -> V=1.0, theta=0.0
% INFO    : Bus 8303	: V=1.001671, theta=17.650724 -> V=1.0, theta=0.0
% INFO    : Bus 8304	: V=0.984603, theta=-7.0462 -> V=1.0, theta=0.0
% INFO    : Bus 8305	: V=1.035746, theta=36.598507 -> V=1.0, theta=0.0
% INFO    : Bus 8306	: V=1.018658, theta=15.730309 -> V=1.0, theta=0.0
% INFO    : Bus 8307	: V=1.036877, theta=21.208834 -> V=1.0, theta=0.0
% INFO    : Bus 8308	: V=1.020649, theta=22.846825 -> V=1.0, theta=0.0
% INFO    : Bus 8309	: V=1.046169, theta=24.949362 -> V=1.0, theta=0.0
% INFO    : Bus 8310	: V=0.999064, theta=-4.33545 -> V=1.0, theta=0.0
% INFO    : Bus 8311	: V=0.996232, theta=-10.906345 -> V=1.0, theta=0.0
% INFO    : Bus 8312	: V=1.006809, theta=89.114721 -> V=1.0, theta=0.0
% INFO    : Bus 8313	: V=1.016279, theta=47.706943 -> V=1.0, theta=0.0
% INFO    : Bus 8314	: V=1.067887, theta=88.947852 -> V=1.0, theta=0.0
% INFO    : Bus 8315	: V=0.974937, theta=-12.82364 -> V=1.0, theta=0.0
% INFO    : Bus 8316	: V=1.033029, theta=76.227372 -> V=1.0, theta=0.0
% INFO    : Bus 8317	: V=1.060899, theta=41.530587 -> V=1.0, theta=0.0
% INFO    : Bus 8318	: V=0.984251, theta=3.036721 -> V=1.0, theta=0.0
% INFO    : Bus 8319	: V=1.060899, theta=41.530587 -> V=1.0, theta=0.0
% INFO    : Bus 8320	: V=1.060899, theta=41.530587 -> V=1.0, theta=0.0
% INFO    : Bus 8321	: V=0.998025, theta=27.572524 -> V=1.0, theta=0.0
% INFO    : Bus 8322	: V=1.035815, theta=19.548683 -> V=1.0, theta=0.0
% INFO    : Bus 8323	: V=1.03284, theta=33.745209 -> V=1.0, theta=0.0
% INFO    : Bus 8324	: V=0.991644, theta=-4.340533 -> V=1.0, theta=0.0
% INFO    : Bus 8325	: V=0.972389, theta=-8.434989 -> V=1.0, theta=0.0
% INFO    : Bus 8326	: V=1.024762, theta=17.972121 -> V=1.0, theta=0.0
% INFO    : Bus 8327	: V=1.018135, theta=-15.006207 -> V=1.0, theta=0.0
% INFO    : Bus 8328	: V=0.963709, theta=-7.73773 -> V=1.0, theta=0.0
% INFO    : Bus 8329	: V=0.990854, theta=-6.458169 -> V=1.0, theta=0.0
% INFO    : Bus 8330	: V=0.964984, theta=-9.807744 -> V=1.0, theta=0.0
% INFO    : Bus 8331	: V=1.04975, theta=-4.156713 -> V=1.0, theta=0.0
% INFO    : Bus 8332	: V=1.025435, theta=0.441157 -> V=1.0, theta=0.0
% INFO    : Bus 8333	: V=1.025297, theta=28.126862 -> V=1.0, theta=0.0
% INFO    : Bus 8334	: V=1.046256, theta=4.635137 -> V=1.0, theta=0.0
% INFO    : Bus 8335	: V=1.03589, theta=-1.009428 -> V=1.0, theta=0.0
% INFO    : Bus 8336	: V=1.072398, theta=2.270159 -> V=1.0, theta=0.0
% INFO    : Bus 8337	: V=1.002439, theta=-3.657013 -> V=1.0, theta=0.0
% INFO    : Bus 8338	: V=1.017961, theta=18.629278 -> V=1.0, theta=0.0
% INFO    : Bus 8339	: V=1.015664, theta=-1.705792 -> V=1.0, theta=0.0
% INFO    : Bus 8340	: V=0.999009, theta=27.91604 -> V=1.0, theta=0.0
% INFO    : Bus 8341	: V=1.002863, theta=-1.281886 -> V=1.0, theta=0.0
% INFO    : Bus 8342	: V=1.043619, theta=-8.436397 -> V=1.0, theta=0.0
% INFO    : Bus 8343	: V=1.028736, theta=-6.917679 -> V=1.0, theta=0.0
% INFO    : Bus 8344	: V=0.970215, theta=-11.106049 -> V=1.0, theta=0.0
% INFO    : Bus 8345	: V=1.039095, theta=5.770455 -> V=1.0, theta=0.0
% INFO    : Bus 8346	: V=0.997426, theta=42.314603 -> V=1.0, theta=0.0
% INFO    : Bus 8347	: V=0.987647, theta=-10.834649 -> V=1.0, theta=0.0
% INFO    : Bus 8348	: V=0.990578, theta=-0.513213 -> V=1.0, theta=0.0
% INFO    : Bus 8349	: V=1.009482, theta=-17.383207 -> V=1.0, theta=0.0
% INFO    : Bus 8350	: V=1.033951, theta=32.215255 -> V=1.0, theta=0.0
% INFO    : Bus 8351	: V=1.018539, theta=22.129856 -> V=1.0, theta=0.0
% INFO    : Bus 8352	: V=1.03161, theta=11.84227 -> V=1.0, theta=0.0
% INFO    : Bus 8353	: V=1.057947, theta=39.34569 -> V=1.0, theta=0.0
% INFO    : Bus 8354	: V=1.028736, theta=-6.917679 -> V=1.0, theta=0.0
% INFO    : Bus 8355	: V=1.010475, theta=-13.381402 -> V=1.0, theta=0.0
% INFO    : Bus 8356	: V=0.964924, theta=32.309672 -> V=1.0, theta=0.0
% INFO    : Bus 8357	: V=1.028736, theta=-6.917679 -> V=1.0, theta=0.0
% INFO    : Bus 8358	: V=1.018305, theta=-6.370445 -> V=1.0, theta=0.0
% INFO    : Bus 8359	: V=1.028038, theta=4.18117 -> V=1.0, theta=0.0
% INFO    : Bus 8360	: V=1.044436, theta=29.692046 -> V=1.0, theta=0.0
% INFO    : Bus 8361	: V=1.034693, theta=37.528372 -> V=1.0, theta=0.0
% INFO    : Bus 8362	: V=1.034369, theta=-8.017111 -> V=1.0, theta=0.0
% INFO    : Bus 8363	: V=0.995774, theta=31.504265 -> V=1.0, theta=0.0
% INFO    : Bus 8364	: V=0.998121, theta=2.826748 -> V=1.0, theta=0.0
% INFO    : Bus 8365	: V=1.007013, theta=-13.166796 -> V=1.0, theta=0.0
% INFO    : Bus 8366	: V=1.080721, theta=8.164837 -> V=1.0, theta=0.0
% INFO    : Bus 8367	: V=1.024544, theta=18.974877 -> V=1.0, theta=0.0
% INFO    : Bus 8368	: V=1.077945, theta=-3.550211 -> V=1.0, theta=0.0
% INFO    : Bus 8369	: V=1.032797, theta=5.614702 -> V=1.0, theta=0.0
% INFO    : Bus 8370	: V=1.040138, theta=32.45384 -> V=1.0, theta=0.0
% INFO    : Bus 8371	: V=1.03379, theta=40.550643 -> V=1.0, theta=0.0
% INFO    : Bus 8372	: V=1.03277, theta=28.800169 -> V=1.0, theta=0.0
% INFO    : Bus 8373	: V=1.034215, theta=9.728222 -> V=1.0, theta=0.0
% INFO    : Bus 8374	: V=1.016256, theta=3.307379 -> V=1.0, theta=0.0
% INFO    : Bus 8375	: V=1.006049, theta=20.814447 -> V=1.0, theta=0.0
% INFO    : Bus 8376	: V=0.974212, theta=6.709329 -> V=1.0, theta=0.0
% INFO    : Bus 8377	: V=1.030205, theta=-20.991033 -> V=1.0, theta=0.0
% INFO    : Bus 8378	: V=1.034215, theta=9.728222 -> V=1.0, theta=0.0
% INFO    : Bus 8379	: V=0.999357, theta=23.53834 -> V=1.0, theta=0.0
% INFO    : Bus 8380	: V=1.032797, theta=5.614702 -> V=1.0, theta=0.0
% INFO    : Bus 8381	: V=1.022856, theta=-10.882134 -> V=1.0, theta=0.0
% INFO    : Bus 8382	: V=1.066458, theta=-4.513735 -> V=1.0, theta=0.0
% INFO    : Bus 8383	: V=1.016769, theta=-19.113768 -> V=1.0, theta=0.0
% INFO    : Bus 8384	: V=0.996109, theta=-3.698386 -> V=1.0, theta=0.0
% INFO    : Bus 8385	: V=1.023034, theta=24.738464 -> V=1.0, theta=0.0
% INFO    : Bus 8386	: V=1.029709, theta=20.473808 -> V=1.0, theta=0.0
% INFO    : Bus 8387	: V=1.00657, theta=25.464337 -> V=1.0, theta=0.0
% INFO    : Bus 8388	: V=0.988817, theta=21.215061 -> V=1.0, theta=0.0
% INFO    : Bus 8389	: V=1.026207, theta=-11.793103 -> V=1.0, theta=0.0
% INFO    : Bus 8390	: V=1.055126, theta=28.025271 -> V=1.0, theta=0.0
% INFO    : Bus 8391	: V=1.025807, theta=48.325393 -> V=1.0, theta=0.0
% INFO    : Bus 8392	: V=0.973403, theta=-6.343919 -> V=1.0, theta=0.0
% INFO    : Bus 8393	: V=1.066894, theta=2.513611 -> V=1.0, theta=0.0
% INFO    : Bus 8394	: V=0.962614, theta=39.578299 -> V=1.0, theta=0.0
% INFO    : Bus 8395	: V=1.037317, theta=25.872032 -> V=1.0, theta=0.0
% INFO    : Bus 8396	: V=1.020502, theta=-7.965953 -> V=1.0, theta=0.0
% INFO    : Bus 8397	: V=1.021376, theta=22.718616 -> V=1.0, theta=0.0
% INFO    : Bus 8398	: V=1.019587, theta=-11.095675 -> V=1.0, theta=0.0
% INFO    : Bus 8399	: V=0.989523, theta=-4.645698 -> V=1.0, theta=0.0
% INFO    : Bus 8400	: V=1.162819, theta=1.018543 -> V=1.0, theta=0.0
% INFO    : Bus 8401	: V=1.016604, theta=-26.138576 -> V=1.0, theta=0.0
% INFO    : Bus 8402	: V=1.021376, theta=22.718616 -> V=1.0, theta=0.0
% INFO    : Bus 8403	: V=1.011027, theta=-12.592409 -> V=1.0, theta=0.0
% INFO    : Bus 8404	: V=1.03806, theta=17.376838 -> V=1.0, theta=0.0
% INFO    : Bus 8405	: V=1.079461, theta=-12.959093 -> V=1.0, theta=0.0
% INFO    : Bus 8406	: V=1.031682, theta=39.188537 -> V=1.0, theta=0.0
% INFO    : Bus 8407	: V=1.027651, theta=79.0077 -> V=1.0, theta=0.0
% INFO    : Bus 8408	: V=1.024365, theta=-1.048273 -> V=1.0, theta=0.0
% INFO    : Bus 8409	: V=1.026822, theta=-0.476726 -> V=1.0, theta=0.0
% INFO    : Bus 8410	: V=1.024407, theta=-16.057704 -> V=1.0, theta=0.0
% INFO    : Bus 8411	: V=1.00377, theta=23.582695 -> V=1.0, theta=0.0
% INFO    : Bus 8412	: V=1.009152, theta=14.501185 -> V=1.0, theta=0.0
% INFO    : Bus 8413	: V=1.00358, theta=37.337153 -> V=1.0, theta=0.0
% INFO    : Bus 8414	: V=1.019924, theta=-8.595055 -> V=1.0, theta=0.0
% INFO    : Bus 8415	: V=1.013179, theta=14.179628 -> V=1.0, theta=0.0
% INFO    : Bus 8416	: V=0.982395, theta=-5.498542 -> V=1.0, theta=0.0
% INFO    : Bus 8417	: V=0.994896, theta=-3.136363 -> V=1.0, theta=0.0
% INFO    : Bus 8418	: V=0.993652, theta=25.056908 -> V=1.0, theta=0.0
% INFO    : Bus 8419	: V=1.012685, theta=-20.115544 -> V=1.0, theta=0.0
% INFO    : Bus 8420	: V=1.004597, theta=91.103926 -> V=1.0, theta=0.0
% INFO    : Bus 8421	: V=1.019405, theta=-14.419189 -> V=1.0, theta=0.0
% INFO    : Bus 8422	: V=1.013128, theta=4.797777 -> V=1.0, theta=0.0
% INFO    : Bus 8423	: V=1.022087, theta=-3.367486 -> V=1.0, theta=0.0
% INFO    : Bus 8424	: V=1.022087, theta=-3.367486 -> V=1.0, theta=0.0
% INFO    : Bus 8425	: V=1.004419, theta=18.615053 -> V=1.0, theta=0.0
% INFO    : Bus 8426	: V=1.039204, theta=27.724089 -> V=1.0, theta=0.0
% INFO    : Bus 8427	: V=1.025816, theta=-8.26672 -> V=1.0, theta=0.0
% INFO    : Bus 8428	: V=1.011997, theta=-3.144432 -> V=1.0, theta=0.0
% INFO    : Bus 8429	: V=1.012148, theta=30.893197 -> V=1.0, theta=0.0
% INFO    : Bus 8430	: V=1.025816, theta=-8.26672 -> V=1.0, theta=0.0
% INFO    : Bus 8431	: V=1.026184, theta=-11.181267 -> V=1.0, theta=0.0
% INFO    : Bus 8432	: V=0.946254, theta=7.550305 -> V=1.0, theta=0.0
% INFO    : Bus 8433	: V=1.022285, theta=8.641504 -> V=1.0, theta=0.0
% INFO    : Bus 8434	: V=1.039004, theta=17.120517 -> V=1.0, theta=0.0
% INFO    : Bus 8435	: V=1.025816, theta=-8.26672 -> V=1.0, theta=0.0
% INFO    : Bus 8436	: V=1.007757, theta=23.409003 -> V=1.0, theta=0.0
% INFO    : Bus 8437	: V=0.975399, theta=-27.696451 -> V=1.0, theta=0.0
% INFO    : Bus 8438	: V=0.973801, theta=-28.252014 -> V=1.0, theta=0.0
% INFO    : Bus 8439	: V=1.045666, theta=52.068402 -> V=1.0, theta=0.0
% INFO    : Bus 8440	: V=1.050455, theta=44.07457 -> V=1.0, theta=0.0
% INFO    : Bus 8441	: V=1.023837, theta=21.039483 -> V=1.0, theta=0.0
% INFO    : Bus 8442	: V=1.013511, theta=22.52849 -> V=1.0, theta=0.0
% INFO    : Bus 8443	: V=1.021734, theta=-10.957359 -> V=1.0, theta=0.0
% INFO    : Bus 8444	: V=1.051219, theta=38.74676 -> V=1.0, theta=0.0
% INFO    : Bus 8445	: V=1.039546, theta=19.356134 -> V=1.0, theta=0.0
% INFO    : Bus 8446	: V=1.039998, theta=0.106626 -> V=1.0, theta=0.0
% INFO    : Bus 8447	: V=1.03758, theta=22.028378 -> V=1.0, theta=0.0
% INFO    : Bus 8448	: V=0.991247, theta=18.669171 -> V=1.0, theta=0.0
% INFO    : Bus 8449	: V=1.007791, theta=36.976632 -> V=1.0, theta=0.0
% INFO    : Bus 8450	: V=1.013902, theta=-2.752831 -> V=1.0, theta=0.0
% INFO    : Bus 8451	: V=0.992069, theta=93.520525 -> V=1.0, theta=0.0
% INFO    : Bus 8452	: V=1.099484, theta=-2.340691 -> V=1.0, theta=0.0
% INFO    : Bus 8453	: V=0.972158, theta=41.061568 -> V=1.0, theta=0.0
% INFO    : Bus 8454	: V=1.044067, theta=35.638952 -> V=1.0, theta=0.0
% INFO    : Bus 8455	: V=0.974207, theta=-7.20883 -> V=1.0, theta=0.0
% INFO    : Bus 8456	: V=1.024324, theta=-10.377063 -> V=1.0, theta=0.0
% INFO    : Bus 8457	: V=1.02611, theta=9.397426 -> V=1.0, theta=0.0
% INFO    : Bus 8458	: V=1.001359, theta=33.84971 -> V=1.0, theta=0.0
% INFO    : Bus 8459	: V=1.02611, theta=9.397426 -> V=1.0, theta=0.0
% INFO    : Bus 8460	: V=1.035351, theta=19.619226 -> V=1.0, theta=0.0
% INFO    : Bus 8461	: V=1.026561, theta=-23.946661 -> V=1.0, theta=0.0
% INFO    : Bus 8462	: V=0.956424, theta=44.925894 -> V=1.0, theta=0.0
% INFO    : Bus 8463	: V=0.990698, theta=-4.186367 -> V=1.0, theta=0.0
% INFO    : Bus 8464	: V=1.031881, theta=17.767373 -> V=1.0, theta=0.0
% INFO    : Bus 8465	: V=1.000535, theta=-9.681265 -> V=1.0, theta=0.0
% INFO    : Bus 8466	: V=1.035784, theta=8.880294 -> V=1.0, theta=0.0
% INFO    : Bus 8467	: V=0.976034, theta=39.492744 -> V=1.0, theta=0.0
% INFO    : Bus 8468	: V=1.040393, theta=84.017948 -> V=1.0, theta=0.0
% INFO    : Bus 8469	: V=1.013769, theta=-16.62541 -> V=1.0, theta=0.0
% INFO    : Bus 8470	: V=1.020956, theta=21.259248 -> V=1.0, theta=0.0
% INFO    : Bus 8471	: V=1.020956, theta=21.259248 -> V=1.0, theta=0.0
% INFO    : Bus 8472	: V=1.057594, theta=44.556346 -> V=1.0, theta=0.0
% INFO    : Bus 8473	: V=1.020956, theta=21.259248 -> V=1.0, theta=0.0
% INFO    : Bus 8474	: V=1.020956, theta=21.259248 -> V=1.0, theta=0.0
% INFO    : Bus 8475	: V=1.058803, theta=-12.07492 -> V=1.0, theta=0.0
% INFO    : Bus 8476	: V=1.000621, theta=19.05802 -> V=1.0, theta=0.0
% INFO    : Bus 8477	: V=1.038248, theta=-7.751154 -> V=1.0, theta=0.0
% INFO    : Bus 8478	: V=1.025548, theta=33.220843 -> V=1.0, theta=0.0
% INFO    : Bus 8479	: V=1.029635, theta=34.5439 -> V=1.0, theta=0.0
% INFO    : Bus 8480	: V=0.986955, theta=-9.508168 -> V=1.0, theta=0.0
% INFO    : Bus 8481	: V=1.023818, theta=16.867894 -> V=1.0, theta=0.0
% INFO    : Bus 8482	: V=1.024954, theta=10.62805 -> V=1.0, theta=0.0
% INFO    : Bus 8483	: V=1.001419, theta=42.731033 -> V=1.0, theta=0.0
% INFO    : Bus 8484	: V=1.022094, theta=-9.15629 -> V=1.0, theta=0.0
% INFO    : Bus 8485	: V=1.017452, theta=31.964092 -> V=1.0, theta=0.0
% INFO    : Bus 8486	: V=0.988967, theta=23.628918 -> V=1.0, theta=0.0
% INFO    : Bus 8487	: V=0.945208, theta=-8.532705 -> V=1.0, theta=0.0
% INFO    : Bus 8488	: V=1.042782, theta=34.930401 -> V=1.0, theta=0.0
% INFO    : Bus 8489	: V=1.013726, theta=-20.719686 -> V=1.0, theta=0.0
% INFO    : Bus 8490	: V=1.015531, theta=4.163384 -> V=1.0, theta=0.0
% INFO    : Bus 8491	: V=0.906068, theta=-11.914453 -> V=1.0, theta=0.0
% INFO    : Bus 8492	: V=1.029156, theta=0.076633 -> V=1.0, theta=0.0
% INFO    : Bus 8493	: V=1.024481, theta=5.581028 -> V=1.0, theta=0.0
% INFO    : Bus 8494	: V=1.033437, theta=0.247819 -> V=1.0, theta=0.0
% INFO    : Bus 8495	: V=1.017873, theta=42.270591 -> V=1.0, theta=0.0
% INFO    : Bus 8496	: V=1.028917, theta=19.248459 -> V=1.0, theta=0.0
% INFO    : Bus 8497	: V=1.008448, theta=20.598984 -> V=1.0, theta=0.0
% INFO    : Bus 8498	: V=0.98794, theta=11.541561 -> V=1.0, theta=0.0
% INFO    : Bus 8499	: V=0.962508, theta=28.579218 -> V=1.0, theta=0.0
% INFO    : Bus 8500	: V=1.008519, theta=-20.573227 -> V=1.0, theta=0.0
% INFO    : Bus 8501	: V=1.041942, theta=0.135841 -> V=1.0, theta=0.0
% INFO    : Bus 8502	: V=1.031135, theta=4.071247 -> V=1.0, theta=0.0
% INFO    : Bus 8503	: V=1.001218, theta=-5.42202 -> V=1.0, theta=0.0
% INFO    : Bus 8504	: V=1.033556, theta=40.640833 -> V=1.0, theta=0.0
% INFO    : Bus 8505	: V=1.040967, theta=10.592542 -> V=1.0, theta=0.0
% INFO    : Bus 8506	: V=1.041842, theta=5.172442 -> V=1.0, theta=0.0
% INFO    : Bus 8507	: V=1.00832, theta=26.187636 -> V=1.0, theta=0.0
% INFO    : Bus 8508	: V=0.985987, theta=19.67774 -> V=1.0, theta=0.0
% INFO    : Bus 8509	: V=1.041506, theta=1.898415 -> V=1.0, theta=0.0
% INFO    : Bus 8510	: V=0.998909, theta=45.144777 -> V=1.0, theta=0.0
% INFO    : Bus 8511	: V=1.001839, theta=15.738688 -> V=1.0, theta=0.0
% INFO    : Bus 8512	: V=0.986787, theta=-3.561117 -> V=1.0, theta=0.0
% INFO    : Bus 8513	: V=0.999015, theta=14.71774 -> V=1.0, theta=0.0
% INFO    : Bus 8514	: V=1.009518, theta=20.920501 -> V=1.0, theta=0.0
% INFO    : Bus 8515	: V=0.992463, theta=89.041689 -> V=1.0, theta=0.0
% INFO    : Bus 8516	: V=0.999015, theta=14.71774 -> V=1.0, theta=0.0
% INFO    : Bus 8517	: V=1.009875, theta=21.502969 -> V=1.0, theta=0.0
% INFO    : Bus 8518	: V=1.007078, theta=-3.740809 -> V=1.0, theta=0.0
% INFO    : Bus 8519	: V=1.026207, theta=-11.793103 -> V=1.0, theta=0.0
% INFO    : Bus 8520	: V=1.058816, theta=18.414025 -> V=1.0, theta=0.0
% INFO    : Bus 8521	: V=1.02718, theta=17.886722 -> V=1.0, theta=0.0
% INFO    : Bus 8522	: V=1.033815, theta=9.21886 -> V=1.0, theta=0.0
% INFO    : Bus 8523	: V=1.023605, theta=-10.708096 -> V=1.0, theta=0.0
% INFO    : Bus 8524	: V=1.035838, theta=-5.172678 -> V=1.0, theta=0.0
% INFO    : Bus 8525	: V=0.998818, theta=-9.928904 -> V=1.0, theta=0.0
% INFO    : Bus 8526	: V=1.088895, theta=-1.018806 -> V=1.0, theta=0.0
% INFO    : Bus 8527	: V=1.033485, theta=-8.016898 -> V=1.0, theta=0.0
% INFO    : Bus 8528	: V=1.004025, theta=-9.891566 -> V=1.0, theta=0.0
% INFO    : Bus 8529	: V=1.057292, theta=76.888885 -> V=1.0, theta=0.0
% INFO    : Bus 8530	: V=1.024655, theta=-11.090856 -> V=1.0, theta=0.0
% INFO    : Bus 8531	: V=1.019474, theta=-15.630869 -> V=1.0, theta=0.0
% INFO    : Bus 8532	: V=1.033485, theta=-8.016898 -> V=1.0, theta=0.0
% INFO    : Bus 8533	: V=1.019474, theta=-15.630869 -> V=1.0, theta=0.0
% INFO    : Bus 8534	: V=1.019474, theta=-15.630869 -> V=1.0, theta=0.0
% INFO    : Bus 8535	: V=1.019474, theta=-15.630869 -> V=1.0, theta=0.0
% INFO    : Bus 8536	: V=1.016639, theta=-11.771752 -> V=1.0, theta=0.0
% INFO    : Bus 8537	: V=1.032132, theta=-3.910762 -> V=1.0, theta=0.0
% INFO    : Bus 8538	: V=1.015227, theta=-3.436884 -> V=1.0, theta=0.0
% INFO    : Bus 8539	: V=1.002179, theta=20.283789 -> V=1.0, theta=0.0
% INFO    : Bus 8540	: V=0.953343, theta=-7.264906 -> V=1.0, theta=0.0
% INFO    : Bus 8541	: V=1.016042, theta=-11.166981 -> V=1.0, theta=0.0
% INFO    : Bus 8542	: V=0.963231, theta=-9.827573 -> V=1.0, theta=0.0
% INFO    : Bus 8543	: V=1.02762, theta=17.221656 -> V=1.0, theta=0.0
% INFO    : Bus 8544	: V=1.012697, theta=95.47097 -> V=1.0, theta=0.0
% INFO    : Bus 8545	: V=1.012641, theta=95.734391 -> V=1.0, theta=0.0
% INFO    : Bus 8546	: V=1.012641, theta=95.734391 -> V=1.0, theta=0.0
% INFO    : Bus 8547	: V=1.028244, theta=96.39747 -> V=1.0, theta=0.0
% INFO    : Bus 8548	: V=1.028244, theta=96.39747 -> V=1.0, theta=0.0
% INFO    : Bus 8549	: V=1.028456, theta=96.447506 -> V=1.0, theta=0.0
% INFO    : Bus 8550	: V=1.028456, theta=96.447506 -> V=1.0, theta=0.0
% INFO    : Bus 8551	: V=1.006366, theta=-15.137227 -> V=1.0, theta=0.0
% INFO    : Bus 8552	: V=1.050589, theta=87.905314 -> V=1.0, theta=0.0
% INFO    : Bus 8553	: V=1.013905, theta=-12.380472 -> V=1.0, theta=0.0
% INFO    : Bus 8554	: V=1.020669, theta=36.645797 -> V=1.0, theta=0.0
% INFO    : Bus 8555	: V=1.000449, theta=37.338871 -> V=1.0, theta=0.0
% INFO    : Bus 8556	: V=1.019976, theta=-17.782538 -> V=1.0, theta=0.0
% INFO    : Bus 8557	: V=1.01659, theta=91.688856 -> V=1.0, theta=0.0
% INFO    : Bus 8558	: V=0.978984, theta=-5.102198 -> V=1.0, theta=0.0
% INFO    : Bus 8559	: V=0.99654, theta=26.163496 -> V=1.0, theta=0.0
% INFO    : Bus 8560	: V=1.061997, theta=16.341333 -> V=1.0, theta=0.0
% INFO    : Bus 8561	: V=0.992794, theta=44.481603 -> V=1.0, theta=0.0
% INFO    : Bus 8562	: V=1.013824, theta=-24.041959 -> V=1.0, theta=0.0
% INFO    : Bus 8563	: V=1.020659, theta=-5.050211 -> V=1.0, theta=0.0
% INFO    : Bus 8564	: V=1.071229, theta=-5.679029 -> V=1.0, theta=0.0
% INFO    : Bus 8565	: V=1.014963, theta=-26.893813 -> V=1.0, theta=0.0
% INFO    : Bus 8566	: V=1.054641, theta=7.773993 -> V=1.0, theta=0.0
% INFO    : Bus 8567	: V=0.962886, theta=-4.988351 -> V=1.0, theta=0.0
% INFO    : Bus 8568	: V=1.009413, theta=-9.559143 -> V=1.0, theta=0.0
% INFO    : Bus 8569	: V=1.043912, theta=38.237051 -> V=1.0, theta=0.0
% INFO    : Bus 8570	: V=1.044271, theta=38.24025 -> V=1.0, theta=0.0
% INFO    : Bus 8571	: V=1.043938, theta=38.255003 -> V=1.0, theta=0.0
% INFO    : Bus 8572	: V=1.03074, theta=18.715448 -> V=1.0, theta=0.0
% INFO    : Bus 8573	: V=1.040642, theta=8.532255 -> V=1.0, theta=0.0
% INFO    : Bus 8574	: V=1.074386, theta=35.546719 -> V=1.0, theta=0.0
% INFO    : Bus 8575	: V=1.17806, theta=3.460132 -> V=1.0, theta=0.0
% INFO    : Bus 8576	: V=1.04434, theta=27.891337 -> V=1.0, theta=0.0
% INFO    : Bus 8577	: V=1.039495, theta=25.225942 -> V=1.0, theta=0.0
% INFO    : Bus 8578	: V=1.039495, theta=25.225942 -> V=1.0, theta=0.0
% INFO    : Bus 8579	: V=1.018943, theta=6.634561 -> V=1.0, theta=0.0
% INFO    : Bus 8580	: V=1.00711, theta=28.112169 -> V=1.0, theta=0.0
% INFO    : Bus 8581	: V=1.053599, theta=21.197213 -> V=1.0, theta=0.0
% INFO    : Bus 8582	: V=1.053599, theta=21.197213 -> V=1.0, theta=0.0
% INFO    : Bus 8583	: V=1.052531, theta=42.677501 -> V=1.0, theta=0.0
% INFO    : Bus 8584	: V=1.022818, theta=35.669345 -> V=1.0, theta=0.0
% INFO    : Bus 8585	: V=1.03042, theta=-18.615687 -> V=1.0, theta=0.0
% INFO    : Bus 8586	: V=1.028806, theta=19.359171 -> V=1.0, theta=0.0
% INFO    : Bus 8587	: V=1.029304, theta=47.335419 -> V=1.0, theta=0.0
% INFO    : Bus 8588	: V=1.033776, theta=23.366887 -> V=1.0, theta=0.0
% INFO    : Bus 8589	: V=1.018061, theta=42.315747 -> V=1.0, theta=0.0
% INFO    : Bus 8590	: V=1.016112, theta=20.652649 -> V=1.0, theta=0.0
% INFO    : Bus 8591	: V=1.002176, theta=-13.481147 -> V=1.0, theta=0.0
% INFO    : Bus 8592	: V=0.996578, theta=38.818651 -> V=1.0, theta=0.0
% INFO    : Bus 8593	: V=1.050151, theta=43.874516 -> V=1.0, theta=0.0
% INFO    : Bus 8594	: V=0.990952, theta=-14.211234 -> V=1.0, theta=0.0
% INFO    : Bus 8595	: V=1.003942, theta=39.409116 -> V=1.0, theta=0.0
% INFO    : Bus 8596	: V=1.022763, theta=-3.774086 -> V=1.0, theta=0.0
% INFO    : Bus 8597	: V=1.005676, theta=-8.882179 -> V=1.0, theta=0.0
% INFO    : Bus 8598	: V=1.031898, theta=-9.317211 -> V=1.0, theta=0.0
% INFO    : Bus 8599	: V=1.037505, theta=-6.683276 -> V=1.0, theta=0.0
% INFO    : Bus 8600	: V=1.007712, theta=17.817524 -> V=1.0, theta=0.0
% INFO    : Bus 8601	: V=1.023757, theta=15.821231 -> V=1.0, theta=0.0
% INFO    : Bus 8602	: V=0.951154, theta=-12.421936 -> V=1.0, theta=0.0
% INFO    : Bus 8603	: V=0.977623, theta=30.982888 -> V=1.0, theta=0.0
% INFO    : Bus 8604	: V=1.052591, theta=40.424368 -> V=1.0, theta=0.0
% INFO    : Bus 8605	: V=1.070477, theta=22.577139 -> V=1.0, theta=0.0
% INFO    : Bus 8606	: V=1.025701, theta=-3.549152 -> V=1.0, theta=0.0
% INFO    : Bus 8607	: V=1.011387, theta=-3.579207 -> V=1.0, theta=0.0
% INFO    : Bus 8608	: V=1.027615, theta=8.124619 -> V=1.0, theta=0.0
% INFO    : Bus 8609	: V=1.052591, theta=40.424368 -> V=1.0, theta=0.0
% INFO    : Bus 8610	: V=1.052591, theta=40.424368 -> V=1.0, theta=0.0
% INFO    : Bus 8611	: V=1.010002, theta=-12.911741 -> V=1.0, theta=0.0
% INFO    : Bus 8612	: V=1.037571, theta=3.363381 -> V=1.0, theta=0.0
% INFO    : Bus 8613	: V=1.03523, theta=7.175845 -> V=1.0, theta=0.0
% INFO    : Bus 8614	: V=1.035503, theta=30.793495 -> V=1.0, theta=0.0
% INFO    : Bus 8615	: V=1.002828, theta=0.450085 -> V=1.0, theta=0.0
% INFO    : Bus 8616	: V=1.042887, theta=29.173811 -> V=1.0, theta=0.0
% INFO    : Bus 8617	: V=1.012367, theta=-8.878211 -> V=1.0, theta=0.0
% INFO    : Bus 8618	: V=1.04551, theta=49.61108 -> V=1.0, theta=0.0
% INFO    : Bus 8619	: V=1.024857, theta=-4.385691 -> V=1.0, theta=0.0
% INFO    : Bus 8620	: V=1.043895, theta=3.24249 -> V=1.0, theta=0.0
% INFO    : Bus 8621	: V=1.019496, theta=22.104164 -> V=1.0, theta=0.0
% INFO    : Bus 8622	: V=1.015499, theta=-22.709466 -> V=1.0, theta=0.0
% INFO    : Bus 8623	: V=1.062888, theta=3.794097 -> V=1.0, theta=0.0
% INFO    : Bus 8624	: V=0.970458, theta=32.668903 -> V=1.0, theta=0.0
% INFO    : Bus 8625	: V=1.016183, theta=-11.264275 -> V=1.0, theta=0.0
% INFO    : Bus 8626	: V=1.014766, theta=-26.891027 -> V=1.0, theta=0.0
% INFO    : Bus 8627	: V=1.003491, theta=-10.282006 -> V=1.0, theta=0.0
% INFO    : Bus 8628	: V=0.980816, theta=-7.972115 -> V=1.0, theta=0.0
% INFO    : Bus 8629	: V=1.026653, theta=-20.337648 -> V=1.0, theta=0.0
% INFO    : Bus 8630	: V=0.983511, theta=-8.815823 -> V=1.0, theta=0.0
% INFO    : Bus 8631	: V=1.020498, theta=-7.004186 -> V=1.0, theta=0.0
% INFO    : Bus 8632	: V=1.128032, theta=6.903218 -> V=1.0, theta=0.0
% INFO    : Bus 8633	: V=1.012585, theta=28.941869 -> V=1.0, theta=0.0
% INFO    : Bus 8634	: V=1.049966, theta=90.439526 -> V=1.0, theta=0.0
% INFO    : Bus 8635	: V=0.968831, theta=49.279117 -> V=1.0, theta=0.0
% INFO    : Bus 8636	: V=0.982346, theta=-5.664036 -> V=1.0, theta=0.0
% INFO    : Bus 8637	: V=1.043665, theta=14.930439 -> V=1.0, theta=0.0
% INFO    : Bus 8638	: V=1.023494, theta=16.826765 -> V=1.0, theta=0.0
% INFO    : Bus 8639	: V=1.026319, theta=-4.093349 -> V=1.0, theta=0.0
% INFO    : Bus 8640	: V=1.011847, theta=-21.235399 -> V=1.0, theta=0.0
% INFO    : Bus 8641	: V=0.965176, theta=19.389202 -> V=1.0, theta=0.0
% INFO    : Bus 8642	: V=1.078046, theta=7.07184 -> V=1.0, theta=0.0
% INFO    : Bus 8643	: V=1.021366, theta=-0.687341 -> V=1.0, theta=0.0
% INFO    : Bus 8644	: V=0.979015, theta=43.42213 -> V=1.0, theta=0.0
% INFO    : Bus 8645	: V=1.059723, theta=-11.874145 -> V=1.0, theta=0.0
% INFO    : Bus 8646	: V=0.999314, theta=44.425993 -> V=1.0, theta=0.0
% INFO    : Bus 8647	: V=1.052654, theta=21.51137 -> V=1.0, theta=0.0
% INFO    : Bus 8648	: V=1.052654, theta=21.51137 -> V=1.0, theta=0.0
% INFO    : Bus 8649	: V=1.051779, theta=-5.83511 -> V=1.0, theta=0.0
% INFO    : Bus 8650	: V=1.080534, theta=-3.780007 -> V=1.0, theta=0.0
% INFO    : Bus 8651	: V=1.024067, theta=20.713541 -> V=1.0, theta=0.0
% INFO    : Bus 8652	: V=1.016464, theta=14.858583 -> V=1.0, theta=0.0
% INFO    : Bus 8653	: V=1.0434, theta=77.613508 -> V=1.0, theta=0.0
% INFO    : Bus 8654	: V=0.984601, theta=26.113187 -> V=1.0, theta=0.0
% INFO    : Bus 8655	: V=1.019231, theta=22.327173 -> V=1.0, theta=0.0
% INFO    : Bus 8656	: V=1.012276, theta=40.254811 -> V=1.0, theta=0.0
% INFO    : Bus 8657	: V=1.013385, theta=-8.195491 -> V=1.0, theta=0.0
% INFO    : Bus 8658	: V=1.061235, theta=43.554839 -> V=1.0, theta=0.0
% INFO    : Bus 8659	: V=1.013817, theta=35.753916 -> V=1.0, theta=0.0
% INFO    : Bus 8660	: V=1.064477, theta=3.338461 -> V=1.0, theta=0.0
% INFO    : Bus 8661	: V=1.026147, theta=-15.127436 -> V=1.0, theta=0.0
% INFO    : Bus 8662	: V=1.058505, theta=-0.088728 -> V=1.0, theta=0.0
% INFO    : Bus 8663	: V=1.029605, theta=-21.145475 -> V=1.0, theta=0.0
% INFO    : Bus 8664	: V=0.997958, theta=26.556133 -> V=1.0, theta=0.0
% INFO    : Bus 8665	: V=1.061235, theta=43.554839 -> V=1.0, theta=0.0
% INFO    : Bus 8666	: V=1.034807, theta=-0.14975 -> V=1.0, theta=0.0
% INFO    : Bus 8667	: V=1.02466, theta=-8.239737 -> V=1.0, theta=0.0
% INFO    : Bus 8668	: V=1.060483, theta=72.601224 -> V=1.0, theta=0.0
% INFO    : Bus 8669	: V=1.030836, theta=31.47751 -> V=1.0, theta=0.0
% INFO    : Bus 8670	: V=1.004627, theta=-12.540227 -> V=1.0, theta=0.0
% INFO    : Bus 8671	: V=1.060483, theta=72.601224 -> V=1.0, theta=0.0
% INFO    : Bus 8672	: V=1.044925, theta=2.499152 -> V=1.0, theta=0.0
% INFO    : Bus 8673	: V=1.01216, theta=7.425482 -> V=1.0, theta=0.0
% INFO    : Bus 8674	: V=1.044074, theta=-6.730644 -> V=1.0, theta=0.0
% INFO    : Bus 8675	: V=1.031719, theta=9.474961 -> V=1.0, theta=0.0
% INFO    : Bus 8676	: V=1.015423, theta=15.004573 -> V=1.0, theta=0.0
% INFO    : Bus 8677	: V=0.985195, theta=5.739458 -> V=1.0, theta=0.0
% INFO    : Bus 8678	: V=0.996665, theta=-7.315796 -> V=1.0, theta=0.0
% INFO    : Bus 8679	: V=1.031719, theta=9.474961 -> V=1.0, theta=0.0
% INFO    : Bus 8680	: V=1.031719, theta=9.474961 -> V=1.0, theta=0.0
% INFO    : Bus 8681	: V=0.99442, theta=-19.142553 -> V=1.0, theta=0.0
% INFO    : Bus 8682	: V=1.03304, theta=-2.188961 -> V=1.0, theta=0.0
% INFO    : Bus 8683	: V=1.073694, theta=71.260391 -> V=1.0, theta=0.0
% INFO    : Bus 8684	: V=0.998764, theta=-1.713308 -> V=1.0, theta=0.0
% INFO    : Bus 8685	: V=0.993084, theta=32.616818 -> V=1.0, theta=0.0
% INFO    : Bus 8686	: V=1.027264, theta=14.46311 -> V=1.0, theta=0.0
% INFO    : Bus 8687	: V=0.992442, theta=9.617717 -> V=1.0, theta=0.0
% INFO    : Bus 8688	: V=1.012567, theta=-5.484707 -> V=1.0, theta=0.0
% INFO    : Bus 8689	: V=1.034054, theta=-4.198425 -> V=1.0, theta=0.0
% INFO    : Bus 8690	: V=1.010868, theta=93.234354 -> V=1.0, theta=0.0
% INFO    : Bus 8691	: V=1.022737, theta=38.788607 -> V=1.0, theta=0.0
% INFO    : Bus 8692	: V=1.010946, theta=-13.506969 -> V=1.0, theta=0.0
% INFO    : Bus 8693	: V=1.0179, theta=3.935052 -> V=1.0, theta=0.0
% INFO    : Bus 8694	: V=1.00949, theta=12.391585 -> V=1.0, theta=0.0
% INFO    : Bus 8695	: V=1.039945, theta=14.048373 -> V=1.0, theta=0.0
% INFO    : Bus 8696	: V=1.023631, theta=36.965167 -> V=1.0, theta=0.0
% INFO    : Bus 8697	: V=1.014343, theta=-8.671556 -> V=1.0, theta=0.0
% INFO    : Bus 8698	: V=1.031641, theta=-4.160427 -> V=1.0, theta=0.0
% INFO    : Bus 8699	: V=1.024166, theta=94.721888 -> V=1.0, theta=0.0
% INFO    : Bus 8700	: V=0.995748, theta=-5.907958 -> V=1.0, theta=0.0
% INFO    : Bus 8701	: V=1.033214, theta=-6.888934 -> V=1.0, theta=0.0
% INFO    : Bus 8702	: V=1.033214, theta=-6.888934 -> V=1.0, theta=0.0
% INFO    : Bus 8703	: V=0.988671, theta=-4.542598 -> V=1.0, theta=0.0
% INFO    : Bus 8704	: V=1.038438, theta=0.065623 -> V=1.0, theta=0.0
% INFO    : Bus 8705	: V=1.000675, theta=17.35251 -> V=1.0, theta=0.0
% INFO    : Bus 8706	: V=1.033214, theta=-6.86015 -> V=1.0, theta=0.0
% INFO    : Bus 8707	: V=1.033214, theta=-6.86015 -> V=1.0, theta=0.0
% INFO    : Bus 8708	: V=1.010994, theta=-1.162397 -> V=1.0, theta=0.0
% INFO    : Bus 8709	: V=0.982549, theta=44.896548 -> V=1.0, theta=0.0
% INFO    : Bus 8710	: V=1.052339, theta=14.454599 -> V=1.0, theta=0.0
% INFO    : Bus 8711	: V=1.044461, theta=26.985271 -> V=1.0, theta=0.0
% INFO    : Bus 8712	: V=1.044461, theta=26.985271 -> V=1.0, theta=0.0
% INFO    : Bus 8713	: V=1.044893, theta=26.926518 -> V=1.0, theta=0.0
% INFO    : Bus 8714	: V=1.044893, theta=26.926518 -> V=1.0, theta=0.0
% INFO    : Bus 8715	: V=1.102004, theta=60.082984 -> V=1.0, theta=0.0
% INFO    : Bus 8716	: V=1.019095, theta=-7.960677 -> V=1.0, theta=0.0
% INFO    : Bus 8717	: V=1.019095, theta=-7.960677 -> V=1.0, theta=0.0
% INFO    : Bus 8718	: V=1.028086, theta=15.549208 -> V=1.0, theta=0.0
% INFO    : Bus 8719	: V=1.022039, theta=16.134374 -> V=1.0, theta=0.0
% INFO    : Bus 8720	: V=1.035548, theta=-4.408789 -> V=1.0, theta=0.0
% INFO    : Bus 8721	: V=1.030956, theta=18.955624 -> V=1.0, theta=0.0
% INFO    : Bus 8722	: V=1.015204, theta=-22.86801 -> V=1.0, theta=0.0
% INFO    : Bus 8723	: V=1.010537, theta=3.784995 -> V=1.0, theta=0.0
% INFO    : Bus 8724	: V=1.033069, theta=20.041193 -> V=1.0, theta=0.0
% INFO    : Bus 8725	: V=1.027819, theta=-9.442028 -> V=1.0, theta=0.0
% INFO    : Bus 8726	: V=1.000784, theta=-5.3448 -> V=1.0, theta=0.0
% INFO    : Bus 8727	: V=0.976129, theta=-6.118497 -> V=1.0, theta=0.0
% INFO    : Bus 8728	: V=1.007795, theta=20.535138 -> V=1.0, theta=0.0
% INFO    : Bus 8729	: V=1.033742, theta=40.550873 -> V=1.0, theta=0.0
% INFO    : Bus 8730	: V=1.02783, theta=19.279135 -> V=1.0, theta=0.0
% INFO    : Bus 8731	: V=1.0598, theta=43.409328 -> V=1.0, theta=0.0
% INFO    : Bus 8732	: V=1.0598, theta=43.409328 -> V=1.0, theta=0.0
% INFO    : Bus 8733	: V=1.0598, theta=43.409328 -> V=1.0, theta=0.0
% INFO    : Bus 8734	: V=1.0598, theta=43.409328 -> V=1.0, theta=0.0
% INFO    : Bus 8735	: V=1.0598, theta=43.409328 -> V=1.0, theta=0.0
% INFO    : Bus 8736	: V=1.042484, theta=-8.329333 -> V=1.0, theta=0.0
% INFO    : Bus 8737	: V=1.077098, theta=41.368237 -> V=1.0, theta=0.0
% INFO    : Bus 8738	: V=0.993908, theta=39.29719 -> V=1.0, theta=0.0
% INFO    : Bus 8739	: V=0.999104, theta=-5.464238 -> V=1.0, theta=0.0
% INFO    : Bus 8740	: V=0.99389, theta=98.19335 -> V=1.0, theta=0.0
% INFO    : Bus 8741	: V=0.988223, theta=95.517768 -> V=1.0, theta=0.0
% INFO    : Bus 8742	: V=0.983111, theta=-11.388547 -> V=1.0, theta=0.0
% INFO    : Bus 8743	: V=1.046536, theta=-20.234575 -> V=1.0, theta=0.0
% INFO    : Bus 8744	: V=1.031165, theta=-7.839877 -> V=1.0, theta=0.0
% INFO    : Bus 8745	: V=1.031165, theta=-7.839877 -> V=1.0, theta=0.0
% INFO    : Bus 8746	: V=1.031165, theta=-7.839877 -> V=1.0, theta=0.0
% INFO    : Bus 8747	: V=1.031165, theta=-7.839877 -> V=1.0, theta=0.0
% INFO    : Bus 8748	: V=1.110806, theta=0.955681 -> V=1.0, theta=0.0
% INFO    : Bus 8749	: V=1.113386, theta=5.807349 -> V=1.0, theta=0.0
% INFO    : Bus 8750	: V=1.057631, theta=18.249732 -> V=1.0, theta=0.0
% INFO    : Bus 8751	: V=0.970261, theta=37.372194 -> V=1.0, theta=0.0
% INFO    : Bus 8752	: V=1.00853, theta=-24.207466 -> V=1.0, theta=0.0
% INFO    : Bus 8753	: V=1.04914, theta=42.65185 -> V=1.0, theta=0.0
% INFO    : Bus 8754	: V=1.068881, theta=5.548581 -> V=1.0, theta=0.0
% INFO    : Bus 8755	: V=1.031165, theta=-7.839877 -> V=1.0, theta=0.0
% INFO    : Bus 8756	: V=1.001498, theta=6.023218 -> V=1.0, theta=0.0
% INFO    : Bus 8757	: V=0.953282, theta=-7.517012 -> V=1.0, theta=0.0
% INFO    : Bus 8758	: V=1.058786, theta=43.17313 -> V=1.0, theta=0.0
% INFO    : Bus 8759	: V=1.032762, theta=-8.550207 -> V=1.0, theta=0.0
% INFO    : Bus 8760	: V=1.041023, theta=3.783242 -> V=1.0, theta=0.0
% INFO    : Bus 8761	: V=1.002114, theta=-15.311194 -> V=1.0, theta=0.0
% INFO    : Bus 8762	: V=1.026254, theta=25.235043 -> V=1.0, theta=0.0
% INFO    : Bus 8763	: V=1.009892, theta=4.868208 -> V=1.0, theta=0.0
% INFO    : Bus 8764	: V=1.030035, theta=1.49544 -> V=1.0, theta=0.0
% INFO    : Bus 8765	: V=1.019803, theta=31.216132 -> V=1.0, theta=0.0
% INFO    : Bus 8766	: V=0.962993, theta=-26.453508 -> V=1.0, theta=0.0
% INFO    : Bus 8767	: V=1.096125, theta=7.622014 -> V=1.0, theta=0.0
% INFO    : Bus 8768	: V=1.019648, theta=37.982078 -> V=1.0, theta=0.0
% INFO    : Bus 8769	: V=1.007899, theta=-8.721694 -> V=1.0, theta=0.0
% INFO    : Bus 8770	: V=1.048632, theta=39.237883 -> V=1.0, theta=0.0
% INFO    : Bus 8771	: V=1.030564, theta=13.40168 -> V=1.0, theta=0.0
% INFO    : Bus 8772	: V=1.023158, theta=23.406873 -> V=1.0, theta=0.0
% INFO    : Bus 8773	: V=1.042956, theta=23.602891 -> V=1.0, theta=0.0
% INFO    : Bus 8774	: V=1.03036, theta=-6.512869 -> V=1.0, theta=0.0
% INFO    : Bus 8775	: V=1.126856, theta=-1.563266 -> V=1.0, theta=0.0
% INFO    : Bus 8776	: V=0.96764, theta=46.597759 -> V=1.0, theta=0.0
% INFO    : Bus 8777	: V=1.010273, theta=7.100671 -> V=1.0, theta=0.0
% INFO    : Bus 8778	: V=0.974291, theta=22.734352 -> V=1.0, theta=0.0
% INFO    : Bus 8779	: V=1.001376, theta=-10.405306 -> V=1.0, theta=0.0
% INFO    : Bus 8780	: V=1.033474, theta=-4.183218 -> V=1.0, theta=0.0
% INFO    : Bus 8781	: V=0.995823, theta=-9.109252 -> V=1.0, theta=0.0
% INFO    : Bus 8782	: V=1.032918, theta=46.113189 -> V=1.0, theta=0.0
% INFO    : Bus 8783	: V=1.051409, theta=-6.429455 -> V=1.0, theta=0.0
% INFO    : Bus 8784	: V=1.026352, theta=44.518276 -> V=1.0, theta=0.0
% INFO    : Bus 8785	: V=1.023876, theta=37.245368 -> V=1.0, theta=0.0
% INFO    : Bus 8786	: V=0.970007, theta=-14.00338 -> V=1.0, theta=0.0
% INFO    : Bus 8787	: V=0.98838, theta=37.047366 -> V=1.0, theta=0.0
% INFO    : Bus 8788	: V=1.027371, theta=13.364096 -> V=1.0, theta=0.0
% INFO    : Bus 8789	: V=0.982997, theta=-8.492112 -> V=1.0, theta=0.0
% INFO    : Bus 8790	: V=1.005639, theta=-1.201359 -> V=1.0, theta=0.0
% INFO    : Bus 8791	: V=1.011737, theta=-19.669579 -> V=1.0, theta=0.0
% INFO    : Bus 8792	: V=1.012784, theta=-1.969846 -> V=1.0, theta=0.0
% INFO    : Bus 8793	: V=1.032132, theta=-0.658602 -> V=1.0, theta=0.0
% INFO    : Bus 8794	: V=1.045009, theta=-6.785844 -> V=1.0, theta=0.0
% INFO    : Bus 8795	: V=1.031735, theta=-7.53735 -> V=1.0, theta=0.0
% INFO    : Bus 8796	: V=1.019317, theta=-6.296032 -> V=1.0, theta=0.0
% INFO    : Bus 8797	: V=1.024762, theta=17.972121 -> V=1.0, theta=0.0
% INFO    : Bus 8798	: V=0.991864, theta=-4.264715 -> V=1.0, theta=0.0
% INFO    : Bus 8799	: V=1.019944, theta=-18.109195 -> V=1.0, theta=0.0
% INFO    : Bus 8800	: V=1.00888, theta=-23.681101 -> V=1.0, theta=0.0
% INFO    : Bus 8801	: V=1.030578, theta=-17.961902 -> V=1.0, theta=0.0
% INFO    : Bus 8802	: V=1.026693, theta=-20.337925 -> V=1.0, theta=0.0
% INFO    : Bus 8803	: V=1.050841, theta=90.684517 -> V=1.0, theta=0.0
% INFO    : Bus 8804	: V=1.021294, theta=52.586969 -> V=1.0, theta=0.0
% INFO    : Bus 8805	: V=0.932912, theta=-10.326204 -> V=1.0, theta=0.0
% INFO    : Bus 8806	: V=1.057091, theta=77.565872 -> V=1.0, theta=0.0
% INFO    : Bus 8807	: V=1.057091, theta=77.565872 -> V=1.0, theta=0.0
% INFO    : Bus 8808	: V=1.015754, theta=19.136214 -> V=1.0, theta=0.0
% INFO    : Bus 8809	: V=1.057091, theta=77.565872 -> V=1.0, theta=0.0
% INFO    : Bus 8810	: V=1.015185, theta=-4.986575 -> V=1.0, theta=0.0
% INFO    : Bus 8811	: V=1.021214, theta=26.174979 -> V=1.0, theta=0.0
% INFO    : Bus 8812	: V=1.005241, theta=4.405336 -> V=1.0, theta=0.0
% INFO    : Bus 8813	: V=1.014813, theta=31.102856 -> V=1.0, theta=0.0
% INFO    : Bus 8814	: V=0.967949, theta=-7.321869 -> V=1.0, theta=0.0
% INFO    : Bus 8815	: V=1.041813, theta=19.321741 -> V=1.0, theta=0.0
% INFO    : Bus 8816	: V=1.036206, theta=7.975321 -> V=1.0, theta=0.0
% INFO    : Bus 8817	: V=0.974981, theta=35.747123 -> V=1.0, theta=0.0
% INFO    : Bus 8818	: V=0.938316, theta=1.779955 -> V=1.0, theta=0.0
% INFO    : Bus 8819	: V=1.032746, theta=44.077076 -> V=1.0, theta=0.0
% INFO    : Bus 8820	: V=1.043492, theta=-15.322718 -> V=1.0, theta=0.0
% INFO    : Bus 8821	: V=1.068183, theta=2.586748 -> V=1.0, theta=0.0
% INFO    : Bus 8822	: V=1.012401, theta=-7.614122 -> V=1.0, theta=0.0
% INFO    : Bus 8823	: V=1.021393, theta=14.872458 -> V=1.0, theta=0.0
% INFO    : Bus 8824	: V=1.027152, theta=23.121261 -> V=1.0, theta=0.0
% INFO    : Bus 8825	: V=1.057455, theta=-6.036434 -> V=1.0, theta=0.0
% INFO    : Bus 8826	: V=1.027024, theta=25.049298 -> V=1.0, theta=0.0
% INFO    : Bus 8827	: V=1.037238, theta=38.50001 -> V=1.0, theta=0.0
% INFO    : Bus 8828	: V=0.993697, theta=-13.728539 -> V=1.0, theta=0.0
% INFO    : Bus 8829	: V=1.025185, theta=37.927142 -> V=1.0, theta=0.0
% INFO    : Bus 8830	: V=0.993492, theta=29.317066 -> V=1.0, theta=0.0
% INFO    : Bus 8831	: V=1.008279, theta=-9.719471 -> V=1.0, theta=0.0
% INFO    : Bus 8832	: V=0.998808, theta=-3.513311 -> V=1.0, theta=0.0
% INFO    : Bus 8833	: V=0.995792, theta=-4.79195 -> V=1.0, theta=0.0
% INFO    : Bus 8834	: V=1.169501, theta=2.546668 -> V=1.0, theta=0.0
% INFO    : Bus 8835	: V=0.975424, theta=-3.142251 -> V=1.0, theta=0.0
% INFO    : Bus 8836	: V=1.013955, theta=15.110149 -> V=1.0, theta=0.0
% INFO    : Bus 8837	: V=0.988686, theta=21.121822 -> V=1.0, theta=0.0
% INFO    : Bus 8838	: V=1.027152, theta=23.121261 -> V=1.0, theta=0.0
% INFO    : Bus 8839	: V=1.055981, theta=85.333831 -> V=1.0, theta=0.0
% INFO    : Bus 8840	: V=1.009626, theta=-16.517753 -> V=1.0, theta=0.0
% INFO    : Bus 8841	: V=1.04706, theta=-6.69158 -> V=1.0, theta=0.0
% INFO    : Bus 8842	: V=1.04706, theta=-6.69158 -> V=1.0, theta=0.0
% INFO    : Bus 8843	: V=1.04706, theta=-6.69158 -> V=1.0, theta=0.0
% INFO    : Bus 8844	: V=1.04706, theta=-6.69158 -> V=1.0, theta=0.0
% INFO    : Bus 8845	: V=1.03174, theta=38.509818 -> V=1.0, theta=0.0
% INFO    : Bus 8846	: V=1.017859, theta=24.98212 -> V=1.0, theta=0.0
% INFO    : Bus 8847	: V=0.967066, theta=-14.754981 -> V=1.0, theta=0.0
% INFO    : Bus 8848	: V=0.976629, theta=28.348694 -> V=1.0, theta=0.0
% INFO    : Bus 8849	: V=1.009499, theta=4.528531 -> V=1.0, theta=0.0
% INFO    : Bus 8850	: V=1.010576, theta=-0.995047 -> V=1.0, theta=0.0
% INFO    : Bus 8851	: V=1.045213, theta=9.250128 -> V=1.0, theta=0.0
% INFO    : Bus 8852	: V=1.024544, theta=18.974877 -> V=1.0, theta=0.0
% INFO    : Bus 8853	: V=1.142288, theta=0.575038 -> V=1.0, theta=0.0
% INFO    : Bus 8854	: V=1.025034, theta=17.055153 -> V=1.0, theta=0.0
% INFO    : Bus 8855	: V=0.989482, theta=-10.614166 -> V=1.0, theta=0.0
% INFO    : Bus 8856	: V=1.026603, theta=13.234905 -> V=1.0, theta=0.0
% INFO    : Bus 8857	: V=1.004314, theta=14.241295 -> V=1.0, theta=0.0
% INFO    : Bus 8858	: V=0.977994, theta=-2.830646 -> V=1.0, theta=0.0
% INFO    : Bus 8859	: V=1.11383, theta=8.533461 -> V=1.0, theta=0.0
% INFO    : Bus 8860	: V=1.045495, theta=-3.944766 -> V=1.0, theta=0.0
% INFO    : Bus 8861	: V=1.045495, theta=-3.944766 -> V=1.0, theta=0.0
% INFO    : Bus 8862	: V=0.985693, theta=-4.971174 -> V=1.0, theta=0.0
% INFO    : Bus 8863	: V=1.021072, theta=-0.687203 -> V=1.0, theta=0.0
% INFO    : Bus 8864	: V=1.052369, theta=0.152148 -> V=1.0, theta=0.0
% INFO    : Bus 8865	: V=1.039352, theta=-14.878706 -> V=1.0, theta=0.0
% INFO    : Bus 8866	: V=1.052369, theta=0.152148 -> V=1.0, theta=0.0
% INFO    : Bus 8867	: V=1.052369, theta=0.152148 -> V=1.0, theta=0.0
% INFO    : Bus 8868	: V=0.988916, theta=-1.928572 -> V=1.0, theta=0.0
% INFO    : Bus 8869	: V=0.983323, theta=-5.042196 -> V=1.0, theta=0.0
% INFO    : Bus 8870	: V=1.034942, theta=38.071181 -> V=1.0, theta=0.0
% INFO    : Bus 8871	: V=1.011795, theta=93.536574 -> V=1.0, theta=0.0
% INFO    : Bus 8872	: V=1.04969, theta=43.665298 -> V=1.0, theta=0.0
% INFO    : Bus 8873	: V=1.028771, theta=2.144472 -> V=1.0, theta=0.0
% INFO    : Bus 8874	: V=0.95615, theta=40.908516 -> V=1.0, theta=0.0
% INFO    : Bus 8875	: V=1.020138, theta=10.175758 -> V=1.0, theta=0.0
% INFO    : Bus 8876	: V=1.007733, theta=27.889509 -> V=1.0, theta=0.0
% INFO    : Bus 8877	: V=0.984173, theta=22.434717 -> V=1.0, theta=0.0
% INFO    : Bus 8878	: V=1.055387, theta=32.270698 -> V=1.0, theta=0.0
% INFO    : Bus 8879	: V=0.998148, theta=-8.920058 -> V=1.0, theta=0.0
% INFO    : Bus 8880	: V=1.034225, theta=-11.583408 -> V=1.0, theta=0.0
% INFO    : Bus 8881	: V=1.008788, theta=8.521149 -> V=1.0, theta=0.0
% INFO    : Bus 8882	: V=1.015119, theta=17.913244 -> V=1.0, theta=0.0
% INFO    : Bus 8883	: V=1.034988, theta=-12.026258 -> V=1.0, theta=0.0
% INFO    : Bus 8884	: V=1.00657, theta=25.464337 -> V=1.0, theta=0.0
% INFO    : Bus 8885	: V=1.037131, theta=84.517509 -> V=1.0, theta=0.0
% INFO    : Bus 8886	: V=1.027925, theta=-7.904402 -> V=1.0, theta=0.0
% INFO    : Bus 8887	: V=1.010141, theta=8.299456 -> V=1.0, theta=0.0
% INFO    : Bus 8888	: V=1.040866, theta=76.768598 -> V=1.0, theta=0.0
% INFO    : Bus 8889	: V=1.041421, theta=-3.450344 -> V=1.0, theta=0.0
% INFO    : Bus 8890	: V=1.015899, theta=42.071153 -> V=1.0, theta=0.0
% INFO    : Bus 8891	: V=1.099261, theta=-0.957248 -> V=1.0, theta=0.0
% INFO    : Bus 8892	: V=0.992276, theta=28.977626 -> V=1.0, theta=0.0
% INFO    : Bus 8893	: V=0.994601, theta=31.575691 -> V=1.0, theta=0.0
% INFO    : Bus 8894	: V=1.018066, theta=-18.544118 -> V=1.0, theta=0.0
% INFO    : Bus 8895	: V=1.021922, theta=25.65862 -> V=1.0, theta=0.0
% INFO    : Bus 8896	: V=0.996866, theta=24.883283 -> V=1.0, theta=0.0
% INFO    : Bus 8897	: V=1.053937, theta=40.267539 -> V=1.0, theta=0.0
% INFO    : Bus 8898	: V=1.039942, theta=37.156863 -> V=1.0, theta=0.0
% INFO    : Bus 8899	: V=1.09911, theta=-4.414302 -> V=1.0, theta=0.0
% INFO    : Bus 8900	: V=1.033776, theta=8.182079 -> V=1.0, theta=0.0
% INFO    : Bus 8901	: V=1.010028, theta=16.739138 -> V=1.0, theta=0.0
% INFO    : Bus 8902	: V=1.010028, theta=16.739138 -> V=1.0, theta=0.0
% INFO    : Bus 8903	: V=1.010028, theta=16.739138 -> V=1.0, theta=0.0
% INFO    : Bus 8904	: V=1.050006, theta=39.688536 -> V=1.0, theta=0.0
% INFO    : Bus 8905	: V=1.050006, theta=39.688536 -> V=1.0, theta=0.0
% INFO    : Bus 8906	: V=1.010028, theta=16.739138 -> V=1.0, theta=0.0
% INFO    : Bus 8907	: V=1.050006, theta=39.688536 -> V=1.0, theta=0.0
% INFO    : Bus 8908	: V=1.053937, theta=40.267539 -> V=1.0, theta=0.0
% INFO    : Bus 8909	: V=1.053937, theta=40.267539 -> V=1.0, theta=0.0
% INFO    : Bus 8910	: V=1.053937, theta=40.267539 -> V=1.0, theta=0.0
% INFO    : Bus 8911	: V=1.033947, theta=-9.228621 -> V=1.0, theta=0.0
% INFO    : Bus 8912	: V=1.019231, theta=22.327173 -> V=1.0, theta=0.0
% INFO    : Bus 8913	: V=1.030967, theta=-6.801792 -> V=1.0, theta=0.0
% INFO    : Bus 8914	: V=1.024089, theta=38.406443 -> V=1.0, theta=0.0
% INFO    : Bus 8915	: V=1.025031, theta=16.970735 -> V=1.0, theta=0.0
% INFO    : Bus 8916	: V=0.984601, theta=26.113186 -> V=1.0, theta=0.0
% INFO    : Bus 8917	: V=1.014698, theta=-2.72048 -> V=1.0, theta=0.0
% INFO    : Bus 8918	: V=0.954917, theta=-5.07993 -> V=1.0, theta=0.0
% INFO    : Bus 8919	: V=1.013094, theta=-14.636462 -> V=1.0, theta=0.0
% INFO    : Bus 8920	: V=0.99609, theta=-7.183362 -> V=1.0, theta=0.0
% INFO    : Bus 8921	: V=1.055881, theta=11.701666 -> V=1.0, theta=0.0
% INFO    : Bus 8922	: V=1.034538, theta=60.163707 -> V=1.0, theta=0.0
% INFO    : Bus 8923	: V=0.982386, theta=15.630758 -> V=1.0, theta=0.0
% INFO    : Bus 8924	: V=1.029315, theta=-6.933752 -> V=1.0, theta=0.0
% INFO    : Bus 8925	: V=1.02373, theta=8.679936 -> V=1.0, theta=0.0
% INFO    : Bus 8926	: V=1.027104, theta=19.850995 -> V=1.0, theta=0.0
% INFO    : Bus 8927	: V=0.966455, theta=-9.685045 -> V=1.0, theta=0.0
% INFO    : Bus 8928	: V=1.013738, theta=-0.854652 -> V=1.0, theta=0.0
% INFO    : Bus 8929	: V=1.031022, theta=26.637798 -> V=1.0, theta=0.0
% INFO    : Bus 8930	: V=1.016312, theta=17.084852 -> V=1.0, theta=0.0
% INFO    : Bus 8931	: V=1.034915, theta=4.996779 -> V=1.0, theta=0.0
% INFO    : Bus 8932	: V=0.977877, theta=-8.635776 -> V=1.0, theta=0.0
% INFO    : Bus 8933	: V=1.011801, theta=13.983947 -> V=1.0, theta=0.0
% INFO    : Bus 8934	: V=1.048895, theta=58.647529 -> V=1.0, theta=0.0
% INFO    : Bus 8935	: V=1.018391, theta=13.251652 -> V=1.0, theta=0.0
% INFO    : Bus 8936	: V=1.052932, theta=42.986036 -> V=1.0, theta=0.0
% INFO    : Bus 8937	: V=1.025724, theta=-14.139236 -> V=1.0, theta=0.0
% INFO    : Bus 8938	: V=1.025724, theta=-14.139236 -> V=1.0, theta=0.0
% INFO    : Bus 8939	: V=1.025724, theta=-14.139236 -> V=1.0, theta=0.0
% INFO    : Bus 8940	: V=1.084411, theta=0.591993 -> V=1.0, theta=0.0
% INFO    : Bus 8941	: V=1.019281, theta=-1.243469 -> V=1.0, theta=0.0
% INFO    : Bus 8942	: V=1.016891, theta=10.696134 -> V=1.0, theta=0.0
% INFO    : Bus 8943	: V=1.019281, theta=-1.243469 -> V=1.0, theta=0.0
% INFO    : Bus 8944	: V=1.019281, theta=-1.243469 -> V=1.0, theta=0.0
% INFO    : Bus 8945	: V=1.017845, theta=-4.792355 -> V=1.0, theta=0.0
% INFO    : Bus 8946	: V=1.063102, theta=1.190758 -> V=1.0, theta=0.0
% INFO    : Bus 8947	: V=0.998, theta=10.001814 -> V=1.0, theta=0.0
% INFO    : Bus 8948	: V=1.028952, theta=55.568264 -> V=1.0, theta=0.0
% INFO    : Bus 8949	: V=0.985807, theta=-5.363422 -> V=1.0, theta=0.0
% INFO    : Bus 8950	: V=1.037844, theta=-1.254072 -> V=1.0, theta=0.0
% INFO    : Bus 8951	: V=1.018463, theta=25.30556 -> V=1.0, theta=0.0
% INFO    : Bus 8952	: V=1.037965, theta=14.047316 -> V=1.0, theta=0.0
% INFO    : Bus 8953	: V=1.037965, theta=14.047316 -> V=1.0, theta=0.0
% INFO    : Bus 8954	: V=1.037965, theta=14.047316 -> V=1.0, theta=0.0
% INFO    : Bus 8955	: V=1.037965, theta=14.047316 -> V=1.0, theta=0.0
% INFO    : Bus 8956	: V=1.062565, theta=2.294369 -> V=1.0, theta=0.0
% INFO    : Bus 8957	: V=1.026453, theta=5.550109 -> V=1.0, theta=0.0
% INFO    : Bus 8958	: V=0.999428, theta=8.526955 -> V=1.0, theta=0.0
% INFO    : Bus 8959	: V=1.013143, theta=25.58747 -> V=1.0, theta=0.0
% INFO    : Bus 8960	: V=1.025141, theta=64.616553 -> V=1.0, theta=0.0
% INFO    : Bus 8961	: V=1.015042, theta=-0.37136 -> V=1.0, theta=0.0
% INFO    : Bus 8962	: V=1.037965, theta=14.047316 -> V=1.0, theta=0.0
% INFO    : Bus 8963	: V=1.038216, theta=15.918534 -> V=1.0, theta=0.0
% INFO    : Bus 8964	: V=1.030057, theta=8.282162 -> V=1.0, theta=0.0
% INFO    : Bus 8965	: V=1.030057, theta=8.282162 -> V=1.0, theta=0.0
% INFO    : Bus 8966	: V=1.030057, theta=8.282162 -> V=1.0, theta=0.0
% INFO    : Bus 8967	: V=1.030057, theta=8.282162 -> V=1.0, theta=0.0
% INFO    : Bus 8968	: V=1.092019, theta=46.227822 -> V=1.0, theta=0.0
% INFO    : Bus 8969	: V=1.030988, theta=2.394145 -> V=1.0, theta=0.0
% INFO    : Bus 8970	: V=1.020105, theta=-23.013394 -> V=1.0, theta=0.0
% INFO    : Bus 8971	: V=1.034786, theta=-3.940241 -> V=1.0, theta=0.0
% INFO    : Bus 8972	: V=1.020798, theta=-25.911872 -> V=1.0, theta=0.0
% INFO    : Bus 8973	: V=0.951938, theta=-28.831094 -> V=1.0, theta=0.0
% INFO    : Bus 8974	: V=1.006345, theta=31.488089 -> V=1.0, theta=0.0
% INFO    : Bus 8975	: V=1.02966, theta=70.488194 -> V=1.0, theta=0.0
% INFO    : Bus 8976	: V=1.011998, theta=0.419036 -> V=1.0, theta=0.0
% INFO    : Bus 8977	: V=1.003375, theta=-10.294034 -> V=1.0, theta=0.0
% INFO    : Bus 8978	: V=1.001585, theta=-16.688433 -> V=1.0, theta=0.0
% INFO    : Bus 8979	: V=1.046682, theta=27.644328 -> V=1.0, theta=0.0
% INFO    : Bus 8980	: V=0.9829, theta=25.033677 -> V=1.0, theta=0.0
% INFO    : Bus 8981	: V=1.015719, theta=-12.837155 -> V=1.0, theta=0.0
% INFO    : Bus 8982	: V=1.015701, theta=-33.369225 -> V=1.0, theta=0.0
% INFO    : Bus 8983	: V=0.998637, theta=27.042734 -> V=1.0, theta=0.0
% INFO    : Bus 8984	: V=1.001162, theta=15.958225 -> V=1.0, theta=0.0
% INFO    : Bus 8985	: V=0.978934, theta=-6.243605 -> V=1.0, theta=0.0
% INFO    : Bus 8986	: V=1.019717, theta=-5.292666 -> V=1.0, theta=0.0
% INFO    : Bus 8987	: V=1.028252, theta=17.788941 -> V=1.0, theta=0.0
% INFO    : Bus 8988	: V=1.023959, theta=-7.603703 -> V=1.0, theta=0.0
% INFO    : Bus 8989	: V=0.965388, theta=-11.747495 -> V=1.0, theta=0.0
% INFO    : Bus 8990	: V=1.017656, theta=42.270911 -> V=1.0, theta=0.0
% INFO    : Bus 8991	: V=1.001041, theta=0.110249 -> V=1.0, theta=0.0
% INFO    : Bus 8992	: V=1.022687, theta=6.310749 -> V=1.0, theta=0.0
% INFO    : Bus 8993	: V=1.026732, theta=81.3069 -> V=1.0, theta=0.0
% INFO    : Bus 8994	: V=1.063361, theta=65.621633 -> V=1.0, theta=0.0
% INFO    : Bus 8995	: V=1.027669, theta=-4.85404 -> V=1.0, theta=0.0
% INFO    : Bus 8996	: V=0.966187, theta=48.309261 -> V=1.0, theta=0.0
% INFO    : Bus 8997	: V=1.026038, theta=-10.378066 -> V=1.0, theta=0.0
% INFO    : Bus 8998	: V=0.994355, theta=-3.968896 -> V=1.0, theta=0.0
% INFO    : Bus 8999	: V=1.020283, theta=-12.097744 -> V=1.0, theta=0.0
% INFO    : Bus 9000	: V=1.016745, theta=6.269013 -> V=1.0, theta=0.0
% INFO    : Bus 9001	: V=1.016622, theta=-0.631522 -> V=1.0, theta=0.0
% INFO    : Bus 9002	: V=0.990777, theta=1.505378 -> V=1.0, theta=0.0
% INFO    : Bus 9003	: V=1.021185, theta=16.043363 -> V=1.0, theta=0.0
% INFO    : Bus 9004	: V=1.031854, theta=8.82489 -> V=1.0, theta=0.0
% INFO    : Bus 9005	: V=1.005176, theta=18.349832 -> V=1.0, theta=0.0
% INFO    : Bus 9006	: V=1.029944, theta=4.331875 -> V=1.0, theta=0.0
% INFO    : Bus 9007	: V=0.992817, theta=-23.197745 -> V=1.0, theta=0.0
% INFO    : Bus 9008	: V=1.01039, theta=-16.760711 -> V=1.0, theta=0.0
% INFO    : Bus 9009	: V=1.028369, theta=21.402713 -> V=1.0, theta=0.0
% INFO    : Bus 9010	: V=1.002482, theta=-9.023078 -> V=1.0, theta=0.0
% INFO    : Bus 9011	: V=1.012722, theta=-8.876216 -> V=1.0, theta=0.0
% INFO    : Bus 9012	: V=1.030954, theta=8.56318 -> V=1.0, theta=0.0
% INFO    : Bus 9013	: V=1.047034, theta=39.205614 -> V=1.0, theta=0.0
% INFO    : Bus 9014	: V=0.989274, theta=-8.954617 -> V=1.0, theta=0.0
% INFO    : Bus 9015	: V=1.028789, theta=19.384691 -> V=1.0, theta=0.0
% INFO    : Bus 9016	: V=0.96764, theta=46.597759 -> V=1.0, theta=0.0
% INFO    : Bus 9017	: V=1.015328, theta=36.145136 -> V=1.0, theta=0.0
% INFO    : Bus 9018	: V=1.013542, theta=14.132282 -> V=1.0, theta=0.0
% INFO    : Bus 9019	: V=1.015247, theta=35.207066 -> V=1.0, theta=0.0
% INFO    : Bus 9020	: V=1.058375, theta=31.68334 -> V=1.0, theta=0.0
% INFO    : Bus 9021	: V=0.96673, theta=-9.641623 -> V=1.0, theta=0.0
% INFO    : Bus 9022	: V=1.029962, theta=8.797799 -> V=1.0, theta=0.0
% INFO    : Bus 9023	: V=1.004322, theta=63.287127 -> V=1.0, theta=0.0
% INFO    : Bus 9024	: V=1.02301, theta=5.762905 -> V=1.0, theta=0.0
% INFO    : Bus 9025	: V=1.010136, theta=-20.682871 -> V=1.0, theta=0.0
% INFO    : Bus 9026	: V=1.023087, theta=15.977582 -> V=1.0, theta=0.0
% INFO    : Bus 9027	: V=0.996095, theta=-11.375796 -> V=1.0, theta=0.0
% INFO    : Bus 9028	: V=1.044704, theta=16.811399 -> V=1.0, theta=0.0
% INFO    : Bus 9029	: V=0.994316, theta=-3.892453 -> V=1.0, theta=0.0
% INFO    : Bus 9030	: V=1.026796, theta=5.578213 -> V=1.0, theta=0.0
% INFO    : Bus 9031	: V=1.046528, theta=-13.149141 -> V=1.0, theta=0.0
% INFO    : Bus 9032	: V=1.032811, theta=40.060195 -> V=1.0, theta=0.0
% INFO    : Bus 9033	: V=1.046254, theta=9.292953 -> V=1.0, theta=0.0
% INFO    : Bus 9034	: V=1.046254, theta=9.292953 -> V=1.0, theta=0.0
% INFO    : Bus 9035	: V=1.01993, theta=9.094543 -> V=1.0, theta=0.0
% INFO    : Bus 9036	: V=0.986493, theta=0.727562 -> V=1.0, theta=0.0
% INFO    : Bus 9037	: V=1.028051, theta=-4.835427 -> V=1.0, theta=0.0
% INFO    : Bus 9038	: V=0.950221, theta=-8.591731 -> V=1.0, theta=0.0
% INFO    : Bus 9039	: V=1.016291, theta=-26.376564 -> V=1.0, theta=0.0
% INFO    : Bus 9040	: V=1.019938, theta=-6.64007 -> V=1.0, theta=0.0
% INFO    : Bus 9041	: V=1.045359, theta=10.101302 -> V=1.0, theta=0.0
% INFO    : Bus 9042	: V=1.015858, theta=-26.579869 -> V=1.0, theta=0.0
% INFO    : Bus 9043	: V=1.044271, theta=-13.760443 -> V=1.0, theta=0.0
% INFO    : Bus 9044	: V=0.965189, theta=-23.699355 -> V=1.0, theta=0.0
% INFO    : Bus 9045	: V=1.060659, theta=20.876838 -> V=1.0, theta=0.0
% INFO    : Bus 9046	: V=0.996141, theta=-3.969869 -> V=1.0, theta=0.0
% INFO    : Bus 9047	: V=1.021906, theta=-21.605261 -> V=1.0, theta=0.0
% INFO    : Bus 9048	: V=0.999464, theta=16.144937 -> V=1.0, theta=0.0
% INFO    : Bus 9049	: V=0.968879, theta=49.23979 -> V=1.0, theta=0.0
% INFO    : Bus 9050	: V=0.997133, theta=-6.657802 -> V=1.0, theta=0.0
% INFO    : Bus 9051	: V=1.065482, theta=13.792426 -> V=1.0, theta=0.0
% INFO    : Bus 9052	: V=1.009249, theta=-1.513395 -> V=1.0, theta=0.0
% INFO    : Bus 9053	: V=0.997675, theta=4.122377 -> V=1.0, theta=0.0
% INFO    : Bus 9054	: V=0.978477, theta=21.737802 -> V=1.0, theta=0.0
% INFO    : Bus 9055	: V=1.029631, theta=2.875298 -> V=1.0, theta=0.0
% INFO    : Bus 9056	: V=1.030388, theta=1.487688 -> V=1.0, theta=0.0
% INFO    : Bus 9057	: V=1.022427, theta=14.359655 -> V=1.0, theta=0.0
% INFO    : Bus 9058	: V=1.034663, theta=-1.23355 -> V=1.0, theta=0.0
% INFO    : Bus 9059	: V=1.044536, theta=18.08141 -> V=1.0, theta=0.0
% INFO    : Bus 9060	: V=1.065482, theta=13.792426 -> V=1.0, theta=0.0
% INFO    : Bus 9061	: V=1.040642, theta=8.532255 -> V=1.0, theta=0.0
% INFO    : Bus 9062	: V=1.017583, theta=13.582942 -> V=1.0, theta=0.0
% INFO    : Bus 9063	: V=1.029324, theta=30.921278 -> V=1.0, theta=0.0
% INFO    : Bus 9064	: V=1.028171, theta=33.067028 -> V=1.0, theta=0.0
% INFO    : Bus 9065	: V=1.039602, theta=2.071227 -> V=1.0, theta=0.0
% INFO    : Bus 9066	: V=1.033897, theta=4.794087 -> V=1.0, theta=0.0
% INFO    : Bus 9067	: V=1.067926, theta=11.58949 -> V=1.0, theta=0.0
% INFO    : Bus 9068	: V=1.010119, theta=29.593937 -> V=1.0, theta=0.0
% INFO    : Bus 9069	: V=1.021099, theta=23.62848 -> V=1.0, theta=0.0
% INFO    : Bus 9070	: V=0.990743, theta=11.266312 -> V=1.0, theta=0.0
% INFO    : Bus 9071	: V=0.982518, theta=14.362004 -> V=1.0, theta=0.0
% INFO    : Bus 9072	: V=1.05886, theta=21.876947 -> V=1.0, theta=0.0
% INFO    : Bus 9073	: V=1.002952, theta=-4.67636 -> V=1.0, theta=0.0
% INFO    : Bus 9074	: V=0.991243, theta=91.841886 -> V=1.0, theta=0.0
% INFO    : Bus 9075	: V=1.044756, theta=52.061269 -> V=1.0, theta=0.0
% INFO    : Bus 9076	: V=0.981999, theta=-11.531273 -> V=1.0, theta=0.0
% INFO    : Bus 9077	: V=1.021447, theta=-10.622729 -> V=1.0, theta=0.0
% INFO    : Bus 9078	: V=0.976712, theta=-11.424113 -> V=1.0, theta=0.0
% INFO    : Bus 9079	: V=1.022048, theta=-13.383541 -> V=1.0, theta=0.0
% INFO    : Bus 9080	: V=1.023597, theta=31.928632 -> V=1.0, theta=0.0
% INFO    : Bus 9081	: V=1.042184, theta=0.453797 -> V=1.0, theta=0.0
% INFO    : Bus 9082	: V=1.02606, theta=18.466684 -> V=1.0, theta=0.0
% INFO    : Bus 9083	: V=1.039067, theta=6.437524 -> V=1.0, theta=0.0
% INFO    : Bus 9084	: V=1.017679, theta=10.590328 -> V=1.0, theta=0.0
% INFO    : Bus 9085	: V=1.099883, theta=80.244023 -> V=1.0, theta=0.0
% INFO    : Bus 9086	: V=0.937547, theta=-11.56742 -> V=1.0, theta=0.0
% INFO    : Bus 9087	: V=1.000613, theta=17.219878 -> V=1.0, theta=0.0
% INFO    : Bus 9088	: V=1.039009, theta=81.664701 -> V=1.0, theta=0.0
% INFO    : Bus 9089	: V=1.02192, theta=11.038401 -> V=1.0, theta=0.0
% INFO    : Bus 9090	: V=1.00818, theta=-8.516263 -> V=1.0, theta=0.0
% INFO    : Bus 9091	: V=1.022581, theta=44.312899 -> V=1.0, theta=0.0
% INFO    : Bus 9092	: V=0.992338, theta=26.531617 -> V=1.0, theta=0.0
% INFO    : Bus 9093	: V=0.993992, theta=-16.264092 -> V=1.0, theta=0.0
% INFO    : Bus 9094	: V=0.978769, theta=-8.124843 -> V=1.0, theta=0.0
% INFO    : Bus 9095	: V=1.004627, theta=-12.540227 -> V=1.0, theta=0.0
% INFO    : Bus 9096	: V=1.030819, theta=21.136828 -> V=1.0, theta=0.0
% INFO    : Bus 9097	: V=1.030531, theta=4.062415 -> V=1.0, theta=0.0
% INFO    : Bus 9098	: V=1.045325, theta=35.806305 -> V=1.0, theta=0.0
% INFO    : Bus 9099	: V=1.023203, theta=9.520695 -> V=1.0, theta=0.0
% INFO    : Bus 9100	: V=1.09631, theta=-4.852232 -> V=1.0, theta=0.0
% INFO    : Bus 9101	: V=0.990956, theta=-4.933793 -> V=1.0, theta=0.0
% INFO    : Bus 9102	: V=1.04328, theta=33.92678 -> V=1.0, theta=0.0
% INFO    : Bus 9103	: V=1.025547, theta=-0.136832 -> V=1.0, theta=0.0
% INFO    : Bus 9104	: V=1.038741, theta=26.945356 -> V=1.0, theta=0.0
% INFO    : Bus 9105	: V=1.036304, theta=-17.70087 -> V=1.0, theta=0.0
% INFO    : Bus 9106	: V=1.04328, theta=33.92678 -> V=1.0, theta=0.0
% INFO    : Bus 9107	: V=1.04328, theta=33.92678 -> V=1.0, theta=0.0
% INFO    : Bus 9108	: V=1.015908, theta=42.071101 -> V=1.0, theta=0.0
% INFO    : Bus 9109	: V=1.03472, theta=7.897462 -> V=1.0, theta=0.0
% INFO    : Bus 9110	: V=0.964368, theta=44.185324 -> V=1.0, theta=0.0
% INFO    : Bus 9111	: V=1.025478, theta=-11.132082 -> V=1.0, theta=0.0
% INFO    : Bus 9112	: V=1.019044, theta=-0.260439 -> V=1.0, theta=0.0
% INFO    : Bus 9113	: V=1.048151, theta=0.703407 -> V=1.0, theta=0.0
% INFO    : Bus 9114	: V=1.028437, theta=-16.535053 -> V=1.0, theta=0.0
% INFO    : Bus 9115	: V=1.028389, theta=-21.95793 -> V=1.0, theta=0.0
% INFO    : Bus 9116	: V=1.082787, theta=9.081419 -> V=1.0, theta=0.0
% INFO    : Bus 9117	: V=0.998796, theta=-9.18697 -> V=1.0, theta=0.0
% INFO    : Bus 9118	: V=0.99123, theta=-4.961218 -> V=1.0, theta=0.0
% INFO    : Bus 9119	: V=1.087273, theta=1.338482 -> V=1.0, theta=0.0
% INFO    : Bus 9120	: V=1.013208, theta=-8.664527 -> V=1.0, theta=0.0
% INFO    : Bus 9121	: V=0.970403, theta=-0.115981 -> V=1.0, theta=0.0
% INFO    : Bus 9122	: V=1.045872, theta=23.94196 -> V=1.0, theta=0.0
% INFO    : Bus 9123	: V=1.032856, theta=3.083067 -> V=1.0, theta=0.0
% INFO    : Bus 9124	: V=1.020008, theta=0.167283 -> V=1.0, theta=0.0
% INFO    : Bus 9125	: V=1.030762, theta=4.104283 -> V=1.0, theta=0.0
% INFO    : Bus 9126	: V=0.977664, theta=-27.479082 -> V=1.0, theta=0.0
% INFO    : Bus 9127	: V=1.103591, theta=-15.033378 -> V=1.0, theta=0.0
% INFO    : Bus 9128	: V=1.082841, theta=3.289791 -> V=1.0, theta=0.0
% INFO    : Bus 9129	: V=1.126202, theta=-1.919233 -> V=1.0, theta=0.0
% INFO    : Bus 9130	: V=0.986673, theta=-1.277013 -> V=1.0, theta=0.0
% INFO    : Bus 9131	: V=0.939246, theta=-6.113394 -> V=1.0, theta=0.0
% INFO    : Bus 9132	: V=0.993879, theta=-6.791088 -> V=1.0, theta=0.0
% INFO    : Bus 9133	: V=0.99674, theta=13.168518 -> V=1.0, theta=0.0
% INFO    : Bus 9134	: V=0.998994, theta=-9.854786 -> V=1.0, theta=0.0
% INFO    : Bus 9135	: V=0.988493, theta=-4.159622 -> V=1.0, theta=0.0
% INFO    : Bus 9136	: V=1.005209, theta=-3.078095 -> V=1.0, theta=0.0
% INFO    : Bus 9137	: V=1.033542, theta=1.716976 -> V=1.0, theta=0.0
% INFO    : Bus 9138	: V=1.001252, theta=-14.682022 -> V=1.0, theta=0.0
% INFO    : Bus 9139	: V=0.99927, theta=-3.461027 -> V=1.0, theta=0.0
% INFO    : Bus 9140	: V=1.073901, theta=24.12996 -> V=1.0, theta=0.0
% INFO    : Bus 9141	: V=1.031723, theta=0.213022 -> V=1.0, theta=0.0
% INFO    : Bus 9142	: V=1.031723, theta=0.213022 -> V=1.0, theta=0.0
% INFO    : Bus 9143	: V=1.027737, theta=5.791688 -> V=1.0, theta=0.0
% INFO    : Bus 9144	: V=1.033534, theta=-10.544863 -> V=1.0, theta=0.0
% INFO    : Bus 9145	: V=1.023214, theta=15.365927 -> V=1.0, theta=0.0
% INFO    : Bus 9146	: V=1.029829, theta=2.299759 -> V=1.0, theta=0.0
% INFO    : Bus 9147	: V=1.045655, theta=3.07576 -> V=1.0, theta=0.0
% INFO    : Bus 9148	: V=1.035363, theta=12.970591 -> V=1.0, theta=0.0
% INFO    : Bus 9149	: V=1.021005, theta=21.987746 -> V=1.0, theta=0.0
% INFO    : Bus 9150	: V=1.034355, theta=10.2688 -> V=1.0, theta=0.0
% INFO    : Bus 9151	: V=0.943602, theta=40.868468 -> V=1.0, theta=0.0
% INFO    : Bus 9152	: V=1.058618, theta=17.704675 -> V=1.0, theta=0.0
% INFO    : Bus 9153	: V=1.042367, theta=64.847481 -> V=1.0, theta=0.0
% INFO    : Bus 9154	: V=0.987632, theta=-15.556879 -> V=1.0, theta=0.0
% INFO    : Bus 9155	: V=1.049805, theta=25.547514 -> V=1.0, theta=0.0
% INFO    : Bus 9156	: V=1.005991, theta=13.874731 -> V=1.0, theta=0.0
% INFO    : Bus 9157	: V=1.019242, theta=21.932927 -> V=1.0, theta=0.0
% INFO    : Bus 9158	: V=0.983962, theta=-5.083708 -> V=1.0, theta=0.0
% INFO    : Bus 9159	: V=1.048472, theta=0.586861 -> V=1.0, theta=0.0
% INFO    : Bus 9160	: V=0.98332, theta=-5.104188 -> V=1.0, theta=0.0
% INFO    : Bus 9161	: V=1.002301, theta=-3.67191 -> V=1.0, theta=0.0
% INFO    : Bus 9162	: V=1.060728, theta=31.642799 -> V=1.0, theta=0.0
% INFO    : Bus 9163	: V=0.997036, theta=26.425104 -> V=1.0, theta=0.0
% INFO    : Bus 9164	: V=0.902549, theta=-12.121472 -> V=1.0, theta=0.0
% INFO    : Bus 9165	: V=1.072384, theta=58.895099 -> V=1.0, theta=0.0
% INFO    : Bus 9166	: V=1.00081, theta=22.506847 -> V=1.0, theta=0.0
% INFO    : Bus 9167	: V=1.041957, theta=41.367634 -> V=1.0, theta=0.0
% INFO    : Bus 9168	: V=1.020547, theta=8.547903 -> V=1.0, theta=0.0
% INFO    : Bus 9169	: V=1.014559, theta=-1.055158 -> V=1.0, theta=0.0
% INFO    : Bus 9170	: V=0.998493, theta=-23.037485 -> V=1.0, theta=0.0
% INFO    : Bus 9171	: V=1.026448, theta=-3.53911 -> V=1.0, theta=0.0
% INFO    : Bus 9172	: V=1.051242, theta=80.128427 -> V=1.0, theta=0.0
% INFO    : Bus 9173	: V=1.020921, theta=-7.474467 -> V=1.0, theta=0.0
% INFO    : Bus 9174	: V=0.98776, theta=-4.689833 -> V=1.0, theta=0.0
% INFO    : Bus 9175	: V=1.013499, theta=-26.262852 -> V=1.0, theta=0.0
% INFO    : Bus 9176	: V=1.0329, theta=65.528598 -> V=1.0, theta=0.0
% INFO    : Bus 9177	: V=1.034423, theta=26.077071 -> V=1.0, theta=0.0
% INFO    : Bus 9178	: V=1.035644, theta=60.585744 -> V=1.0, theta=0.0
% INFO    : Bus 9179	: V=1.033768, theta=14.596978 -> V=1.0, theta=0.0
% INFO    : Bus 9180	: V=0.996606, theta=23.721288 -> V=1.0, theta=0.0
% INFO    : Bus 9181	: V=1.028249, theta=15.997162 -> V=1.0, theta=0.0
% INFO    : Bus 9182	: V=1.016648, theta=20.309778 -> V=1.0, theta=0.0
% INFO    : Bus 9183	: V=1.029866, theta=4.939178 -> V=1.0, theta=0.0
% INFO    : Bus 9184	: V=1.020161, theta=16.222206 -> V=1.0, theta=0.0
% INFO    : Bus 9185	: V=1.02712, theta=-21.419208 -> V=1.0, theta=0.0
% INFO    : Bus 9186	: V=0.986167, theta=31.910384 -> V=1.0, theta=0.0
% INFO    : Bus 9187	: V=0.996851, theta=27.182321 -> V=1.0, theta=0.0
% INFO    : Bus 9188	: V=1.031838, theta=-9.201101 -> V=1.0, theta=0.0
% INFO    : Bus 9189	: V=1.031838, theta=-9.201101 -> V=1.0, theta=0.0
% INFO    : Bus 9190	: V=1.031838, theta=-9.201101 -> V=1.0, theta=0.0
% INFO    : Bus 9191	: V=1.031838, theta=-9.201101 -> V=1.0, theta=0.0
% INFO    : Bus 9192	: V=0.989033, theta=-4.933794 -> V=1.0, theta=0.0
% INFO    : Bus 9193	: V=1.011027, theta=-5.468014 -> V=1.0, theta=0.0
% INFO    : Bus 9194	: V=1.018491, theta=3.932101 -> V=1.0, theta=0.0
% INFO    : Bus 9195	: V=0.980209, theta=32.361809 -> V=1.0, theta=0.0
% INFO    : Bus 9196	: V=1.036884, theta=-20.880107 -> V=1.0, theta=0.0
% INFO    : Bus 9197	: V=1.010484, theta=22.571023 -> V=1.0, theta=0.0
% INFO    : Bus 9198	: V=1.023253, theta=-17.309898 -> V=1.0, theta=0.0
% INFO    : Bus 9199	: V=1.026686, theta=-7.216911 -> V=1.0, theta=0.0
% INFO    : Bus 9200	: V=0.98717, theta=3.88052 -> V=1.0, theta=0.0
% INFO    : Bus 9201	: V=1.053989, theta=-6.618869 -> V=1.0, theta=0.0
% INFO    : Bus 9202	: V=1.02763, theta=-5.734248 -> V=1.0, theta=0.0
% INFO    : Bus 9203	: V=0.98692, theta=-23.433598 -> V=1.0, theta=0.0
% INFO    : Bus 9204	: V=1.056762, theta=11.950776 -> V=1.0, theta=0.0
% INFO    : Bus 9205	: V=1.016688, theta=-3.141725 -> V=1.0, theta=0.0
% INFO    : Bus 9206	: V=1.039006, theta=38.999932 -> V=1.0, theta=0.0
% INFO    : Bus 9207	: V=1.03014, theta=15.494692 -> V=1.0, theta=0.0
% INFO    : Bus 9208	: V=0.919168, theta=-11.232303 -> V=1.0, theta=0.0
% INFO    : Bus 9209	: V=1.055456, theta=5.239412 -> V=1.0, theta=0.0
% INFO    : Bus 9210	: V=0.963667, theta=-7.149819 -> V=1.0, theta=0.0
% INFO    : Bus 9211	: V=1.010289, theta=-0.72505 -> V=1.0, theta=0.0
% INFO    : Bus 9212	: V=1.023343, theta=-11.234733 -> V=1.0, theta=0.0
% INFO    : Bus 9213	: V=1.044317, theta=35.206283 -> V=1.0, theta=0.0
% INFO    : Bus 9214	: V=1.011094, theta=17.983711 -> V=1.0, theta=0.0
% INFO    : Bus 9215	: V=1.05775, theta=16.377573 -> V=1.0, theta=0.0
% INFO    : Bus 9216	: V=1.019482, theta=16.777108 -> V=1.0, theta=0.0
% INFO    : Bus 9217	: V=0.961704, theta=-15.615679 -> V=1.0, theta=0.0
% INFO    : Bus 9218	: V=1.052164, theta=7.333527 -> V=1.0, theta=0.0
% INFO    : Bus 9219	: V=1.043764, theta=37.173377 -> V=1.0, theta=0.0
% INFO    : Bus 9220	: V=1.043764, theta=37.173377 -> V=1.0, theta=0.0
% INFO    : Bus 9221	: V=1.029753, theta=16.35285 -> V=1.0, theta=0.0
% INFO    : Bus 9222	: V=1.044317, theta=35.206283 -> V=1.0, theta=0.0
% INFO    : Bus 9223	: V=1.017385, theta=23.570466 -> V=1.0, theta=0.0
% INFO    : Bus 9224	: V=1.044317, theta=35.206283 -> V=1.0, theta=0.0
% INFO    : Bus 9225	: V=1.048036, theta=22.181451 -> V=1.0, theta=0.0
% INFO    : Bus 9226	: V=0.986945, theta=-15.393544 -> V=1.0, theta=0.0
% INFO    : Bus 9227	: V=0.989111, theta=40.491338 -> V=1.0, theta=0.0
% INFO    : Bus 9228	: V=1.058394, theta=46.810832 -> V=1.0, theta=0.0
% INFO    : Bus 9229	: V=1.058394, theta=46.810832 -> V=1.0, theta=0.0
% INFO    : Bus 9230	: V=1.058394, theta=46.810832 -> V=1.0, theta=0.0
% INFO    : Bus 9231	: V=1.058394, theta=46.810832 -> V=1.0, theta=0.0
% INFO    : Bus 9232	: V=1.058394, theta=46.810832 -> V=1.0, theta=0.0
% INFO    : Bus 9233	: V=1.058394, theta=46.810832 -> V=1.0, theta=0.0
% INFO    : Bus 9234	: V=1.061463, theta=-0.278195 -> V=1.0, theta=0.0
% INFO    : Bus 9235	: V=0.999436, theta=-9.864132 -> V=1.0, theta=0.0
% INFO    : Bus 9236	: V=1.032132, theta=-0.658602 -> V=1.0, theta=0.0
% INFO    : Bus 9237	: V=1.0608, theta=42.720858 -> V=1.0, theta=0.0
% INFO    : Bus 9238	: V=1.057471, theta=5.471328 -> V=1.0, theta=0.0
% INFO    : Bus 9239	: V=1.036493, theta=14.764614 -> V=1.0, theta=0.0
% INFO    : Bus 9240	: V=1.019372, theta=-15.361499 -> V=1.0, theta=0.0
% INFO    : Bus 9241	: V=1.019372, theta=-15.361499 -> V=1.0, theta=0.0
% INFO    : Bus 9242	: V=1.01757, theta=30.154601 -> V=1.0, theta=0.0
% INFO    : Bus 9243	: V=1.019372, theta=-15.361499 -> V=1.0, theta=0.0
% INFO    : Bus 9244	: V=1.019266, theta=-10.730307 -> V=1.0, theta=0.0
% INFO    : Bus 9245	: V=1.005781, theta=34.978072 -> V=1.0, theta=0.0
% INFO    : Bus 9246	: V=1.030174, theta=-14.576007 -> V=1.0, theta=0.0
% INFO    : Bus 9247	: V=1.030174, theta=-14.576007 -> V=1.0, theta=0.0
% INFO    : Bus 9248	: V=0.960595, theta=-9.912117 -> V=1.0, theta=0.0
% INFO    : Bus 9249	: V=0.995268, theta=26.354915 -> V=1.0, theta=0.0
% INFO    : Bus 9250	: V=1.063388, theta=34.050037 -> V=1.0, theta=0.0
% INFO    : Bus 9251	: V=1.036666, theta=0.044572 -> V=1.0, theta=0.0
% INFO    : Bus 9252	: V=0.979058, theta=22.311772 -> V=1.0, theta=0.0
% INFO    : Bus 9253	: V=1.016044, theta=35.103553 -> V=1.0, theta=0.0
% INFO    : Bus 9254	: V=0.971063, theta=-9.097095 -> V=1.0, theta=0.0
% INFO    : Bus 9255	: V=1.014677, theta=-8.666869 -> V=1.0, theta=0.0
% INFO    : Bus 9256	: V=1.030939, theta=24.620583 -> V=1.0, theta=0.0
% INFO    : Bus 9257	: V=1.030939, theta=24.620583 -> V=1.0, theta=0.0
% INFO    : Bus 9258	: V=1.030939, theta=24.620583 -> V=1.0, theta=0.0
% INFO    : Bus 9259	: V=0.981849, theta=-16.787288 -> V=1.0, theta=0.0
% INFO    : Bus 9260	: V=1.030874, theta=24.601888 -> V=1.0, theta=0.0
% INFO    : Bus 9261	: V=1.030874, theta=24.601888 -> V=1.0, theta=0.0
% INFO    : Bus 9262	: V=1.03964, theta=28.678963 -> V=1.0, theta=0.0
% INFO    : Bus 9263	: V=1.059544, theta=18.04116 -> V=1.0, theta=0.0
% INFO    : Bus 9264	: V=1.022708, theta=-13.666083 -> V=1.0, theta=0.0
% INFO    : Bus 9265	: V=1.042062, theta=24.663334 -> V=1.0, theta=0.0
% INFO    : Bus 9266	: V=1.000982, theta=-22.656101 -> V=1.0, theta=0.0
% INFO    : Bus 9267	: V=1.009946, theta=3.890945 -> V=1.0, theta=0.0
% INFO    : Bus 9268	: V=1.003137, theta=32.826235 -> V=1.0, theta=0.0
% INFO    : Bus 9269	: V=1.063275, theta=21.172593 -> V=1.0, theta=0.0
% INFO    : Bus 9270	: V=1.021841, theta=-1.962085 -> V=1.0, theta=0.0
% INFO    : Bus 9271	: V=0.968621, theta=-5.442615 -> V=1.0, theta=0.0
% INFO    : Bus 9272	: V=1.043316, theta=-18.000315 -> V=1.0, theta=0.0
% INFO    : Bus 9273	: V=1.015185, theta=-4.986575 -> V=1.0, theta=0.0
% INFO    : Bus 9274	: V=1.055807, theta=25.808993 -> V=1.0, theta=0.0
% INFO    : Bus 9275	: V=0.940948, theta=-12.203927 -> V=1.0, theta=0.0
% INFO    : Bus 9276	: V=0.99528, theta=-3.853654 -> V=1.0, theta=0.0
% INFO    : Bus 9277	: V=1.042719, theta=49.486952 -> V=1.0, theta=0.0
% INFO    : Bus 9278	: V=1.017398, theta=31.813706 -> V=1.0, theta=0.0
% INFO    : Bus 9279	: V=1.046178, theta=92.710304 -> V=1.0, theta=0.0
% INFO    : Bus 9280	: V=1.044756, theta=52.061269 -> V=1.0, theta=0.0
% INFO    : Bus 9281	: V=1.073284, theta=1.256236 -> V=1.0, theta=0.0
% INFO    : Bus 9282	: V=1.0136, theta=-3.104621 -> V=1.0, theta=0.0
% INFO    : Bus 9283	: V=1.028417, theta=-6.105187 -> V=1.0, theta=0.0
% INFO    : Bus 9284	: V=1.021743, theta=-12.549569 -> V=1.0, theta=0.0
% INFO    : Bus 9285	: V=1.050718, theta=4.154259 -> V=1.0, theta=0.0
% INFO    : Bus 9286	: V=1.009879, theta=-7.120499 -> V=1.0, theta=0.0
% INFO    : Bus 9287	: V=1.026202, theta=-20.972467 -> V=1.0, theta=0.0
% INFO    : Bus 9288	: V=1.012542, theta=1.713537 -> V=1.0, theta=0.0
% INFO    : Bus 9289	: V=1.015096, theta=12.342701 -> V=1.0, theta=0.0
% INFO    : Bus 9290	: V=0.948888, theta=-8.6077 -> V=1.0, theta=0.0
% INFO    : Bus 9291	: V=0.992079, theta=-2.215235 -> V=1.0, theta=0.0
% INFO    : Bus 9292	: V=1.046548, theta=6.871525 -> V=1.0, theta=0.0
% INFO    : Bus 9293	: V=1.065591, theta=-5.496083 -> V=1.0, theta=0.0
% INFO    : Bus 9294	: V=1.061222, theta=57.751527 -> V=1.0, theta=0.0
% INFO    : Bus 9295	: V=1.005322, theta=29.905154 -> V=1.0, theta=0.0
% INFO    : Bus 9296	: V=0.960317, theta=4.257884 -> V=1.0, theta=0.0
% INFO    : Bus 9297	: V=1.027348, theta=16.396901 -> V=1.0, theta=0.0
% INFO    : Bus 9298	: V=0.964189, theta=-8.826746 -> V=1.0, theta=0.0
% INFO    : Bus 9299	: V=1.014641, theta=-26.811678 -> V=1.0, theta=0.0
% INFO    : Bus 9300	: V=1.002311, theta=15.234306 -> V=1.0, theta=0.0
% INFO    : Bus 9301	: V=1.024891, theta=10.992359 -> V=1.0, theta=0.0
% INFO    : Bus 9302	: V=0.980522, theta=-6.641514 -> V=1.0, theta=0.0
% INFO    : Bus 9303	: V=1.053223, theta=-7.960288 -> V=1.0, theta=0.0
% INFO    : Bus 9304	: V=0.971014, theta=7.088734 -> V=1.0, theta=0.0
% INFO    : Bus 9305	: V=0.979908, theta=-26.763384 -> V=1.0, theta=0.0
% INFO    : Bus 9306	: V=1.029753, theta=-4.984284 -> V=1.0, theta=0.0
% INFO    : Bus 9307	: V=1.011289, theta=-24.599894 -> V=1.0, theta=0.0
% INFO    : Bus 9308	: V=0.988705, theta=-8.008281 -> V=1.0, theta=0.0
% INFO    : Bus 9309	: V=1.051067, theta=-0.144768 -> V=1.0, theta=0.0
% INFO    : Bus 9310	: V=1.030924, theta=7.981131 -> V=1.0, theta=0.0
% INFO    : Bus 9311	: V=0.998366, theta=-7.281753 -> V=1.0, theta=0.0
% INFO    : Bus 9312	: V=1.003305, theta=-5.479609 -> V=1.0, theta=0.0
% INFO    : Bus 9313	: V=0.996195, theta=3.691746 -> V=1.0, theta=0.0
% INFO    : Bus 9314	: V=1.012031, theta=-8.893616 -> V=1.0, theta=0.0
% INFO    : Bus 9315	: V=1.027608, theta=28.817016 -> V=1.0, theta=0.0
% INFO    : Bus 9316	: V=1.003585, theta=-15.239367 -> V=1.0, theta=0.0
% INFO    : Bus 9317	: V=1.028283, theta=16.586422 -> V=1.0, theta=0.0
% INFO    : Bus 9318	: V=1.020464, theta=24.448718 -> V=1.0, theta=0.0
% INFO    : Bus 9319	: V=1.083095, theta=86.444403 -> V=1.0, theta=0.0
% INFO    : Bus 9320	: V=1.029358, theta=47.037025 -> V=1.0, theta=0.0
% INFO    : Bus 9321	: V=1.033776, theta=8.182079 -> V=1.0, theta=0.0
% INFO    : Bus 9322	: V=1.021055, theta=-14.38773 -> V=1.0, theta=0.0
% INFO    : Bus 9323	: V=1.021055, theta=-14.38773 -> V=1.0, theta=0.0
% INFO    : Bus 9324	: V=1.027226, theta=29.406206 -> V=1.0, theta=0.0
% INFO    : Bus 9325	: V=0.976527, theta=-15.468409 -> V=1.0, theta=0.0
% INFO    : Bus 9326	: V=0.976265, theta=-11.501599 -> V=1.0, theta=0.0
% INFO    : Bus 9327	: V=1.015617, theta=-6.080033 -> V=1.0, theta=0.0
% INFO    : Bus 9328	: V=1.021862, theta=23.744834 -> V=1.0, theta=0.0
% INFO    : Bus 9329	: V=1.071079, theta=-4.189882 -> V=1.0, theta=0.0
% INFO    : Bus 9330	: V=0.973939, theta=-29.205879 -> V=1.0, theta=0.0
% INFO    : Bus 9331	: V=1.062456, theta=21.477259 -> V=1.0, theta=0.0
% INFO    : Bus 9332	: V=1.051053, theta=1.270275 -> V=1.0, theta=0.0
% INFO    : Bus 9333	: V=1.022666, theta=55.287627 -> V=1.0, theta=0.0
% INFO    : Bus 9334	: V=1.028712, theta=27.886448 -> V=1.0, theta=0.0
% INFO    : Bus 9335	: V=1.035217, theta=25.954532 -> V=1.0, theta=0.0
% INFO    : Bus 9336	: V=1.012806, theta=13.180306 -> V=1.0, theta=0.0
% INFO    : Bus 9337	: V=1.013217, theta=-10.429283 -> V=1.0, theta=0.0
% INFO    : Bus 9338	: V=1.005645, theta=-5.875986 -> V=1.0, theta=0.0
% INFO    : Bus 9339	: V=1.031495, theta=-1.850016 -> V=1.0, theta=0.0
% INFO    : Bus 9340	: V=1.019096, theta=-14.08161 -> V=1.0, theta=0.0
% INFO    : Bus 9341	: V=1.036382, theta=8.668558 -> V=1.0, theta=0.0
% INFO    : Bus 9342	: V=1.024572, theta=-13.995277 -> V=1.0, theta=0.0
% INFO    : Bus 9343	: V=1.029323, theta=-3.215687 -> V=1.0, theta=0.0
% INFO    : Bus 9344	: V=0.998231, theta=-17.176137 -> V=1.0, theta=0.0
% INFO    : Bus 9345	: V=1.028588, theta=4.701247 -> V=1.0, theta=0.0
% INFO    : Bus 9346	: V=1.028588, theta=4.701247 -> V=1.0, theta=0.0
% INFO    : Bus 9347	: V=1.028588, theta=4.701247 -> V=1.0, theta=0.0
% INFO    : Bus 9348	: V=1.028588, theta=4.701247 -> V=1.0, theta=0.0
% INFO    : Bus 9349	: V=1.028588, theta=4.701247 -> V=1.0, theta=0.0
% INFO    : Bus 9350	: V=1.028588, theta=4.701247 -> V=1.0, theta=0.0
% INFO    : Bus 9351	: V=1.028588, theta=4.701247 -> V=1.0, theta=0.0
% INFO    : Bus 9352	: V=1.028588, theta=4.701247 -> V=1.0, theta=0.0
% INFO    : Bus 9353	: V=1.009063, theta=89.858413 -> V=1.0, theta=0.0
% INFO    : Bus 9354	: V=1.028283, theta=16.586422 -> V=1.0, theta=0.0
% INFO    : Bus 9355	: V=1.019668, theta=-2.710611 -> V=1.0, theta=0.0
% INFO    : Bus 9356	: V=1.068482, theta=38.645676 -> V=1.0, theta=0.0
% INFO    : Bus 9357	: V=1.03036, theta=-6.512869 -> V=1.0, theta=0.0
% INFO    : Bus 9358	: V=1.017583, theta=-3.765671 -> V=1.0, theta=0.0
% INFO    : Bus 9359	: V=1.00657, theta=25.464337 -> V=1.0, theta=0.0
% INFO    : Bus 9360	: V=1.015913, theta=33.726089 -> V=1.0, theta=0.0
% INFO    : Bus 9361	: V=0.902529, theta=-12.124125 -> V=1.0, theta=0.0
% INFO    : Bus 9362	: V=1.024298, theta=-14.442769 -> V=1.0, theta=0.0
% INFO    : Bus 9363	: V=1.110446, theta=8.690534 -> V=1.0, theta=0.0
% INFO    : Bus 9364	: V=0.970854, theta=29.381452 -> V=1.0, theta=0.0
% INFO    : Bus 9365	: V=1.027017, theta=25.396175 -> V=1.0, theta=0.0
% INFO    : Bus 9366	: V=1.027114, theta=-8.230884 -> V=1.0, theta=0.0
% INFO    : Bus 9367	: V=0.996384, theta=33.202949 -> V=1.0, theta=0.0
% INFO    : Bus 9368	: V=1.010068, theta=-8.536738 -> V=1.0, theta=0.0
% INFO    : Bus 9369	: V=0.992214, theta=21.028002 -> V=1.0, theta=0.0
% INFO    : Bus 9370	: V=1.073284, theta=1.256236 -> V=1.0, theta=0.0
% INFO    : Bus 9371	: V=0.967068, theta=-14.765518 -> V=1.0, theta=0.0
% INFO    : Bus 9372	: V=0.997458, theta=13.119639 -> V=1.0, theta=0.0
% INFO    : Bus 9373	: V=0.984446, theta=-0.108883 -> V=1.0, theta=0.0
% INFO    : Bus 9374	: V=1.042317, theta=14.274354 -> V=1.0, theta=0.0
% INFO    : Bus 9375	: V=1.024292, theta=-3.924291 -> V=1.0, theta=0.0
% INFO    : Bus 9376	: V=1.022192, theta=20.047374 -> V=1.0, theta=0.0
% INFO    : Bus 9377	: V=1.022192, theta=20.047374 -> V=1.0, theta=0.0
% INFO    : Bus 9378	: V=1.022192, theta=20.047374 -> V=1.0, theta=0.0
% INFO    : Bus 9379	: V=1.022192, theta=20.047374 -> V=1.0, theta=0.0
% INFO    : Bus 9380	: V=1.042328, theta=18.688066 -> V=1.0, theta=0.0
% INFO    : Bus 9381	: V=0.972093, theta=-7.21041 -> V=1.0, theta=0.0
% INFO    : Bus 9382	: V=0.961374, theta=-28.168655 -> V=1.0, theta=0.0
% INFO    : Bus 9383	: V=1.022192, theta=20.047374 -> V=1.0, theta=0.0
% INFO    : Bus 9384	: V=1.022192, theta=20.047374 -> V=1.0, theta=0.0
% INFO    : Bus 9385	: V=0.996081, theta=-14.048563 -> V=1.0, theta=0.0
% INFO    : Bus 9386	: V=1.02934, theta=19.998755 -> V=1.0, theta=0.0
% INFO    : Bus 9387	: V=1.023156, theta=37.450201 -> V=1.0, theta=0.0
% INFO    : Bus 9388	: V=1.047493, theta=-7.198916 -> V=1.0, theta=0.0
% INFO    : Bus 9389	: V=0.985384, theta=-0.999006 -> V=1.0, theta=0.0
% INFO    : Bus 9390	: V=0.977593, theta=-10.732565 -> V=1.0, theta=0.0
% INFO    : Bus 9391	: V=1.034617, theta=20.900749 -> V=1.0, theta=0.0
% INFO    : Bus 9392	: V=1.058231, theta=41.885187 -> V=1.0, theta=0.0
% INFO    : Bus 9393	: V=1.012697, theta=95.47097 -> V=1.0, theta=0.0
% INFO    : Bus 9394	: V=1.017521, theta=32.87514 -> V=1.0, theta=0.0
% INFO    : Bus 9395	: V=1.020595, theta=7.622879 -> V=1.0, theta=0.0
% INFO    : Bus 9396	: V=0.987038, theta=34.043606 -> V=1.0, theta=0.0
% INFO    : Bus 9397	: V=1.067202, theta=42.60671 -> V=1.0, theta=0.0
% INFO    : Bus 9398	: V=0.974625, theta=-8.32398 -> V=1.0, theta=0.0
% INFO    : Bus 9399	: V=0.929197, theta=-11.904661 -> V=1.0, theta=0.0
% INFO    : Bus 9400	: V=0.976688, theta=-4.938655 -> V=1.0, theta=0.0
% INFO    : Bus 9401	: V=1.093949, theta=24.561183 -> V=1.0, theta=0.0
% INFO    : Bus 9402	: V=0.964466, theta=-5.279309 -> V=1.0, theta=0.0
% INFO    : Bus 9403	: V=1.019764, theta=22.127907 -> V=1.0, theta=0.0
% INFO    : Bus 9404	: V=1.050897, theta=44.076116 -> V=1.0, theta=0.0
% INFO    : Bus 9405	: V=1.025041, theta=-11.218198 -> V=1.0, theta=0.0
% INFO    : Bus 9406	: V=0.9926, theta=-22.495997 -> V=1.0, theta=0.0
% INFO    : Bus 9407	: V=1.04016, theta=31.253607 -> V=1.0, theta=0.0
% INFO    : Bus 9408	: V=1.074058, theta=4.909711 -> V=1.0, theta=0.0
% INFO    : Bus 9409	: V=0.99566, theta=17.494551 -> V=1.0, theta=0.0
% INFO    : Bus 9410	: V=1.021734, theta=-10.957359 -> V=1.0, theta=0.0
% INFO    : Bus 9411	: V=1.031195, theta=12.084859 -> V=1.0, theta=0.0
% INFO    : Bus 9412	: V=1.027321, theta=0.48095 -> V=1.0, theta=0.0
% INFO    : Bus 9413	: V=0.984601, theta=26.113187 -> V=1.0, theta=0.0
% INFO    : Bus 9414	: V=1.004293, theta=-8.36677 -> V=1.0, theta=0.0
% INFO    : Bus 9415	: V=1.053522, theta=92.905505 -> V=1.0, theta=0.0
% INFO    : Bus 9416	: V=1.018239, theta=-19.841296 -> V=1.0, theta=0.0
% INFO    : Bus 9417	: V=1.017845, theta=-4.792355 -> V=1.0, theta=0.0
% INFO    : Bus 9418	: V=0.986151, theta=-7.335049 -> V=1.0, theta=0.0
% INFO    : Bus 9419	: V=1.021554, theta=5.304081 -> V=1.0, theta=0.0
% INFO    : Bus 9420	: V=0.98623, theta=-10.553231 -> V=1.0, theta=0.0
% INFO    : Bus 9421	: V=1.030419, theta=1.643213 -> V=1.0, theta=0.0
% INFO    : Bus 9422	: V=1.011998, theta=0.419036 -> V=1.0, theta=0.0
% INFO    : Bus 9423	: V=1.036304, theta=-8.162625 -> V=1.0, theta=0.0
% INFO    : Bus 9424	: V=1.038332, theta=12.07119 -> V=1.0, theta=0.0
% INFO    : Bus 9425	: V=1.026665, theta=32.869784 -> V=1.0, theta=0.0
% INFO    : Bus 9426	: V=1.036268, theta=17.18762 -> V=1.0, theta=0.0
% INFO    : Bus 9427	: V=1.022889, theta=18.879559 -> V=1.0, theta=0.0
% INFO    : Bus 9428	: V=1.00488, theta=20.110868 -> V=1.0, theta=0.0
% INFO    : Bus 9429	: V=1.025297, theta=17.011969 -> V=1.0, theta=0.0
% INFO    : Bus 9430	: V=1.021867, theta=37.577612 -> V=1.0, theta=0.0
% INFO    : Bus 9431	: V=1.016597, theta=-22.538977 -> V=1.0, theta=0.0
% INFO    : Bus 9432	: V=1.032675, theta=4.70045 -> V=1.0, theta=0.0
% INFO    : Bus 9433	: V=1.060742, theta=0.198664 -> V=1.0, theta=0.0
% INFO    : Bus 9434	: V=1.04353, theta=14.87029 -> V=1.0, theta=0.0
% INFO    : Bus 9435	: V=1.016767, theta=-8.269117 -> V=1.0, theta=0.0
% INFO    : Bus 9436	: V=0.958996, theta=-8.031065 -> V=1.0, theta=0.0
% INFO    : Bus 9437	: V=0.993276, theta=18.960031 -> V=1.0, theta=0.0
% INFO    : Bus 9438	: V=1.022995, theta=4.68997 -> V=1.0, theta=0.0
% INFO    : Bus 9439	: V=1.035797, theta=10.227937 -> V=1.0, theta=0.0
% INFO    : Bus 9440	: V=1.022995, theta=4.68997 -> V=1.0, theta=0.0
% INFO    : Bus 9441	: V=1.022995, theta=4.68997 -> V=1.0, theta=0.0
% INFO    : Bus 9442	: V=1.022995, theta=4.68997 -> V=1.0, theta=0.0
% INFO    : Bus 9443	: V=1.022995, theta=4.68997 -> V=1.0, theta=0.0
% INFO    : Bus 9444	: V=1.022579, theta=22.997302 -> V=1.0, theta=0.0
% INFO    : Bus 9445	: V=1.041055, theta=2.513615 -> V=1.0, theta=0.0
% INFO    : Bus 9446	: V=1.014887, theta=-26.770924 -> V=1.0, theta=0.0
% INFO    : Bus 9447	: V=1.031297, theta=8.46293 -> V=1.0, theta=0.0
% INFO    : Bus 9448	: V=1.031816, theta=-19.546233 -> V=1.0, theta=0.0
% INFO    : Bus 9449	: V=1.017607, theta=-2.523511 -> V=1.0, theta=0.0
% INFO    : Bus 9450	: V=1.077878, theta=83.760207 -> V=1.0, theta=0.0
% INFO    : Bus 9451	: V=1.001151, theta=-10.708247 -> V=1.0, theta=0.0
% INFO    : Bus 9452	: V=1.071012, theta=58.767541 -> V=1.0, theta=0.0
% INFO    : Bus 9453	: V=0.998614, theta=-23.017212 -> V=1.0, theta=0.0
% INFO    : Bus 9454	: V=0.980664, theta=5.730494 -> V=1.0, theta=0.0
% INFO    : Bus 9455	: V=1.028904, theta=-3.473096 -> V=1.0, theta=0.0
% INFO    : Bus 9456	: V=1.002908, theta=25.414397 -> V=1.0, theta=0.0
% INFO    : Bus 9457	: V=0.984599, theta=43.311569 -> V=1.0, theta=0.0
% INFO    : Bus 9458	: V=1.018556, theta=8.310178 -> V=1.0, theta=0.0
% INFO    : Bus 9459	: V=0.994575, theta=-7.679701 -> V=1.0, theta=0.0
% INFO    : Bus 9460	: V=1.084998, theta=72.398199 -> V=1.0, theta=0.0
% INFO    : Bus 9461	: V=0.985642, theta=34.609787 -> V=1.0, theta=0.0
% INFO    : Bus 9462	: V=0.983264, theta=22.644761 -> V=1.0, theta=0.0
% INFO    : Bus 9463	: V=1.0159, theta=-12.399971 -> V=1.0, theta=0.0
% INFO    : Bus 9464	: V=1.017638, theta=-6.936102 -> V=1.0, theta=0.0
% INFO    : Bus 9465	: V=1.03099, theta=77.708152 -> V=1.0, theta=0.0
% INFO    : Bus 9466	: V=1.018726, theta=25.16552 -> V=1.0, theta=0.0
% INFO    : Bus 9467	: V=1.05433, theta=78.959661 -> V=1.0, theta=0.0
% INFO    : Bus 9468	: V=1.002557, theta=39.380309 -> V=1.0, theta=0.0
% INFO    : Bus 9469	: V=0.99394, theta=-3.056318 -> V=1.0, theta=0.0
% INFO    : Bus 9470	: V=1.024403, theta=6.31329 -> V=1.0, theta=0.0
% INFO    : Bus 9471	: V=1.027968, theta=24.05088 -> V=1.0, theta=0.0
% INFO    : Bus 9472	: V=1.027968, theta=24.05088 -> V=1.0, theta=0.0
% INFO    : Bus 9473	: V=1.03654, theta=20.486651 -> V=1.0, theta=0.0
% INFO    : Bus 9474	: V=1.03654, theta=20.486651 -> V=1.0, theta=0.0
% INFO    : Bus 9475	: V=1.066367, theta=6.221208 -> V=1.0, theta=0.0
% INFO    : Bus 9476	: V=1.066367, theta=6.221208 -> V=1.0, theta=0.0
% INFO    : Bus 9477	: V=1.042669, theta=14.686826 -> V=1.0, theta=0.0
% INFO    : Bus 9478	: V=1.042101, theta=20.088214 -> V=1.0, theta=0.0
% INFO    : Bus 9479	: V=1.042101, theta=20.088214 -> V=1.0, theta=0.0
% INFO    : Bus 9480	: V=1.042101, theta=20.088214 -> V=1.0, theta=0.0
% INFO    : Bus 9481	: V=1.042101, theta=20.088214 -> V=1.0, theta=0.0
% INFO    : Bus 9482	: V=1.042101, theta=20.088214 -> V=1.0, theta=0.0
% INFO    : Bus 9483	: V=1.038639, theta=53.208541 -> V=1.0, theta=0.0
% INFO    : Bus 9484	: V=1.012004, theta=15.477863 -> V=1.0, theta=0.0
% INFO    : Bus 9485	: V=0.987691, theta=-10.438707 -> V=1.0, theta=0.0
% INFO    : Bus 9486	: V=1.05433, theta=78.959661 -> V=1.0, theta=0.0
% INFO    : Bus 9487	: V=1.024988, theta=40.267048 -> V=1.0, theta=0.0
% INFO    : Bus 9488	: V=1.057403, theta=6.33416 -> V=1.0, theta=0.0
% INFO    : Bus 9489	: V=1.015585, theta=-16.260044 -> V=1.0, theta=0.0
% INFO    : Bus 9490	: V=1.066603, theta=2.162499 -> V=1.0, theta=0.0
% INFO    : Bus 9491	: V=1.020145, theta=-18.154827 -> V=1.0, theta=0.0
% INFO    : Bus 9492	: V=1.010233, theta=18.034291 -> V=1.0, theta=0.0
% INFO    : Bus 9493	: V=1.005977, theta=92.476825 -> V=1.0, theta=0.0
% INFO    : Bus 9494	: V=0.997129, theta=90.192284 -> V=1.0, theta=0.0
% INFO    : Bus 9495	: V=1.023452, theta=23.736503 -> V=1.0, theta=0.0
% INFO    : Bus 9496	: V=1.098589, theta=65.002382 -> V=1.0, theta=0.0
% INFO    : Bus 9497	: V=1.016832, theta=-25.444147 -> V=1.0, theta=0.0
% INFO    : Bus 9498	: V=1.072853, theta=-2.234716 -> V=1.0, theta=0.0
% INFO    : Bus 9499	: V=1.003975, theta=13.514344 -> V=1.0, theta=0.0
% INFO    : Bus 9500	: V=1.001232, theta=93.284203 -> V=1.0, theta=0.0
% INFO    : Bus 9501	: V=0.973768, theta=-8.365086 -> V=1.0, theta=0.0
% INFO    : Bus 9502	: V=1.03958, theta=-14.080105 -> V=1.0, theta=0.0
% INFO    : Bus 9503	: V=1.016166, theta=-7.266251 -> V=1.0, theta=0.0
% INFO    : Bus 9504	: V=0.991989, theta=39.317054 -> V=1.0, theta=0.0
% INFO    : Bus 9505	: V=1.044769, theta=-13.80956 -> V=1.0, theta=0.0
% INFO    : Bus 9506	: V=1.024599, theta=47.939847 -> V=1.0, theta=0.0
% INFO    : Bus 9507	: V=1.005416, theta=32.987634 -> V=1.0, theta=0.0
% INFO    : Bus 9508	: V=1.017078, theta=-0.332817 -> V=1.0, theta=0.0
% INFO    : Bus 9509	: V=1.022066, theta=-17.640449 -> V=1.0, theta=0.0
% INFO    : Bus 9510	: V=1.066218, theta=-0.226637 -> V=1.0, theta=0.0
% INFO    : Bus 9511	: V=1.068565, theta=-12.213472 -> V=1.0, theta=0.0
% INFO    : Bus 9512	: V=1.036065, theta=-16.582357 -> V=1.0, theta=0.0
% INFO    : Bus 9513	: V=1.059317, theta=37.132576 -> V=1.0, theta=0.0
% INFO    : Bus 9514	: V=0.997717, theta=60.875011 -> V=1.0, theta=0.0
% INFO    : Bus 9515	: V=1.055847, theta=34.276348 -> V=1.0, theta=0.0
% INFO    : Bus 9516	: V=1.025395, theta=0.662428 -> V=1.0, theta=0.0
% INFO    : Bus 9517	: V=1.057335, theta=6.795081 -> V=1.0, theta=0.0
% INFO    : Bus 9518	: V=1.055487, theta=33.902432 -> V=1.0, theta=0.0
% INFO    : Bus 9519	: V=0.99636, theta=-17.388796 -> V=1.0, theta=0.0
% INFO    : Bus 9520	: V=1.026025, theta=16.98036 -> V=1.0, theta=0.0
% INFO    : Bus 9521	: V=1.042077, theta=7.956295 -> V=1.0, theta=0.0
% INFO    : Bus 9522	: V=1.059317, theta=37.132576 -> V=1.0, theta=0.0
% INFO    : Bus 9523	: V=1.053646, theta=52.143481 -> V=1.0, theta=0.0
% INFO    : Bus 9524	: V=1.013572, theta=-9.004048 -> V=1.0, theta=0.0
% INFO    : Bus 9525	: V=1.053646, theta=52.143481 -> V=1.0, theta=0.0
% INFO    : Bus 9526	: V=0.99505, theta=88.716582 -> V=1.0, theta=0.0
% INFO    : Bus 9527	: V=1.045516, theta=41.754111 -> V=1.0, theta=0.0
% INFO    : Bus 9528	: V=1.008317, theta=28.003801 -> V=1.0, theta=0.0
% INFO    : Bus 9529	: V=0.999104, theta=17.264377 -> V=1.0, theta=0.0
% INFO    : Bus 9530	: V=1.013601, theta=9.488938 -> V=1.0, theta=0.0
% INFO    : Bus 9531	: V=1.016597, theta=-0.634223 -> V=1.0, theta=0.0
% INFO    : Bus 9532	: V=1.040599, theta=2.681523 -> V=1.0, theta=0.0
% INFO    : Bus 9533	: V=1.018963, theta=-9.214164 -> V=1.0, theta=0.0
% INFO    : Bus 9534	: V=1.04647, theta=-16.339563 -> V=1.0, theta=0.0
% INFO    : Bus 9535	: V=0.959436, theta=4.956416 -> V=1.0, theta=0.0
% INFO    : Bus 9536	: V=1.055662, theta=33.904007 -> V=1.0, theta=0.0
% INFO    : Bus 9537	: V=0.951715, theta=-11.635825 -> V=1.0, theta=0.0
% INFO    : Bus 9538	: V=1.056779, theta=25.791482 -> V=1.0, theta=0.0
% INFO    : Bus 9539	: V=0.997784, theta=-3.020761 -> V=1.0, theta=0.0
% INFO    : Bus 9540	: V=1.052481, theta=55.678412 -> V=1.0, theta=0.0
% INFO    : Bus 9541	: V=1.024164, theta=36.959582 -> V=1.0, theta=0.0
% INFO    : Bus 9542	: V=1.011374, theta=-9.719553 -> V=1.0, theta=0.0
% INFO    : Bus 9543	: V=1.017654, theta=1.64075 -> V=1.0, theta=0.0
% INFO    : Bus 9544	: V=1.050629, theta=24.719094 -> V=1.0, theta=0.0
% INFO    : Bus 9545	: V=0.988917, theta=-2.520979 -> V=1.0, theta=0.0
% INFO    : Bus 9546	: V=1.0229, theta=12.548502 -> V=1.0, theta=0.0
% INFO    : Bus 9547	: V=1.034547, theta=81.296442 -> V=1.0, theta=0.0
% INFO    : Bus 9548	: V=0.99902, theta=13.532872 -> V=1.0, theta=0.0
% INFO    : Bus 9549	: V=1.034547, theta=81.296442 -> V=1.0, theta=0.0
% INFO    : Bus 9550	: V=1.034547, theta=81.296442 -> V=1.0, theta=0.0
% INFO    : Bus 9551	: V=1.034547, theta=81.296442 -> V=1.0, theta=0.0
% INFO    : Bus 9552	: V=1.010522, theta=6.873688 -> V=1.0, theta=0.0
% INFO    : Bus 9553	: V=0.948759, theta=58.410077 -> V=1.0, theta=0.0
% INFO    : Bus 9554	: V=0.962462, theta=44.453484 -> V=1.0, theta=0.0
% INFO    : Bus 9555	: V=1.070982, theta=-4.197914 -> V=1.0, theta=0.0
% INFO    : Bus 9556	: V=1.012871, theta=-6.113908 -> V=1.0, theta=0.0
% INFO    : Bus 9557	: V=1.005257, theta=-1.228322 -> V=1.0, theta=0.0
% INFO    : Bus 9558	: V=0.997177, theta=-10.309572 -> V=1.0, theta=0.0
% INFO    : Bus 9559	: V=1.012641, theta=-13.548608 -> V=1.0, theta=0.0
% INFO    : Bus 9560	: V=1.049458, theta=-11.424885 -> V=1.0, theta=0.0
% INFO    : Bus 9561	: V=1.06763, theta=-2.574176 -> V=1.0, theta=0.0
% INFO    : Bus 9562	: V=1.102248, theta=-15.189017 -> V=1.0, theta=0.0
% INFO    : Bus 9563	: V=1.044427, theta=-4.588031 -> V=1.0, theta=0.0
% INFO    : Bus 9564	: V=0.999619, theta=24.383536 -> V=1.0, theta=0.0
% INFO    : Bus 9565	: V=1.041529, theta=1.66662 -> V=1.0, theta=0.0
% INFO    : Bus 9566	: V=1.013163, theta=-3.278369 -> V=1.0, theta=0.0
% INFO    : Bus 9567	: V=1.058148, theta=83.691686 -> V=1.0, theta=0.0
% INFO    : Bus 9568	: V=0.988028, theta=25.497372 -> V=1.0, theta=0.0
% INFO    : Bus 9569	: V=0.98349, theta=-8.818575 -> V=1.0, theta=0.0
% INFO    : Bus 9570	: V=1.01167, theta=-8.995127 -> V=1.0, theta=0.0
% INFO    : Bus 9571	: V=1.020003, theta=19.679578 -> V=1.0, theta=0.0
% INFO    : Bus 9572	: V=0.934854, theta=-13.687619 -> V=1.0, theta=0.0
% INFO    : Bus 9573	: V=1.022149, theta=-8.624199 -> V=1.0, theta=0.0
% INFO    : Bus 9574	: V=1.022149, theta=-8.624199 -> V=1.0, theta=0.0
% INFO    : Bus 9575	: V=0.953841, theta=-6.772254 -> V=1.0, theta=0.0
% INFO    : Bus 9576	: V=1.038148, theta=1.704093 -> V=1.0, theta=0.0
% INFO    : Bus 9577	: V=1.00474, theta=6.183504 -> V=1.0, theta=0.0
% INFO    : Bus 9578	: V=1.002904, theta=-10.549962 -> V=1.0, theta=0.0
% INFO    : Bus 9579	: V=1.05252, theta=75.282812 -> V=1.0, theta=0.0
% INFO    : Bus 9580	: V=0.955017, theta=-6.204751 -> V=1.0, theta=0.0
% INFO    : Bus 9581	: V=0.900053, theta=-13.491159 -> V=1.0, theta=0.0
% INFO    : Bus 9582	: V=1.113909, theta=0.125762 -> V=1.0, theta=0.0
% INFO    : Bus 9583	: V=1.001356, theta=24.721284 -> V=1.0, theta=0.0
% INFO    : Bus 9584	: V=1.056808, theta=73.571638 -> V=1.0, theta=0.0
% INFO    : Bus 9585	: V=1.056808, theta=73.571638 -> V=1.0, theta=0.0
% INFO    : Bus 9586	: V=1.02748, theta=-20.019397 -> V=1.0, theta=0.0
% INFO    : Bus 9587	: V=1.02748, theta=-20.019397 -> V=1.0, theta=0.0
% INFO    : Bus 9588	: V=1.030361, theta=8.088164 -> V=1.0, theta=0.0
% INFO    : Bus 9589	: V=1.030361, theta=8.088164 -> V=1.0, theta=0.0
% INFO    : Bus 9590	: V=1.030361, theta=8.088164 -> V=1.0, theta=0.0
% INFO    : Bus 9591	: V=1.030361, theta=8.088164 -> V=1.0, theta=0.0
% INFO    : Bus 9592	: V=0.962631, theta=-15.697201 -> V=1.0, theta=0.0
% INFO    : Bus 9593	: V=1.024271, theta=16.34188 -> V=1.0, theta=0.0
% INFO    : Bus 9594	: V=1.042476, theta=-3.280872 -> V=1.0, theta=0.0
% INFO    : Bus 9595	: V=1.015991, theta=31.274209 -> V=1.0, theta=0.0
% INFO    : Bus 9596	: V=1.027355, theta=25.185208 -> V=1.0, theta=0.0
% INFO    : Bus 9597	: V=1.044678, theta=11.395331 -> V=1.0, theta=0.0
% INFO    : Bus 9598	: V=1.007853, theta=-21.50971 -> V=1.0, theta=0.0
% INFO    : Bus 9599	: V=1.066739, theta=16.847814 -> V=1.0, theta=0.0
% INFO    : Bus 9600	: V=0.929893, theta=-10.863302 -> V=1.0, theta=0.0
% INFO    : Bus 9601	: V=1.008448, theta=19.375399 -> V=1.0, theta=0.0
% INFO    : Bus 9602	: V=1.034298, theta=11.483502 -> V=1.0, theta=0.0
% INFO    : Bus 9603	: V=1.041502, theta=-15.945667 -> V=1.0, theta=0.0
% INFO    : Bus 9604	: V=1.03472, theta=7.897462 -> V=1.0, theta=0.0
% INFO    : Bus 9605	: V=1.030227, theta=6.942059 -> V=1.0, theta=0.0
% INFO    : Bus 9606	: V=1.030227, theta=6.942059 -> V=1.0, theta=0.0
% INFO    : Bus 9607	: V=0.990146, theta=-1.905831 -> V=1.0, theta=0.0
% INFO    : Bus 9608	: V=1.002895, theta=0.544676 -> V=1.0, theta=0.0
% INFO    : Bus 9609	: V=1.046846, theta=3.598889 -> V=1.0, theta=0.0
% INFO    : Bus 9610	: V=1.04738, theta=-3.632232 -> V=1.0, theta=0.0
% INFO    : Bus 9611	: V=1.033419, theta=9.504467 -> V=1.0, theta=0.0
% INFO    : Bus 9612	: V=1.001529, theta=-10.388139 -> V=1.0, theta=0.0
% INFO    : Bus 9613	: V=1.00657, theta=25.464337 -> V=1.0, theta=0.0
% INFO    : Bus 9614	: V=1.022099, theta=17.218586 -> V=1.0, theta=0.0
% INFO    : Bus 9615	: V=1.058811, theta=-2.126192 -> V=1.0, theta=0.0
% INFO    : Bus 9616	: V=1.021579, theta=4.43582 -> V=1.0, theta=0.0
% INFO    : Bus 9617	: V=1.023225, theta=-19.634643 -> V=1.0, theta=0.0
% INFO    : Bus 9618	: V=1.023225, theta=-19.634643 -> V=1.0, theta=0.0
% INFO    : Bus 9619	: V=1.025226, theta=0.949671 -> V=1.0, theta=0.0
% INFO    : Bus 9620	: V=1.073765, theta=1.494745 -> V=1.0, theta=0.0
% INFO    : Bus 9621	: V=1.052427, theta=27.707429 -> V=1.0, theta=0.0
% INFO    : Bus 9622	: V=1.025226, theta=0.949671 -> V=1.0, theta=0.0
% INFO    : Bus 9623	: V=1.024756, theta=1.450408 -> V=1.0, theta=0.0
% INFO    : Bus 9624	: V=1.007587, theta=-6.12031 -> V=1.0, theta=0.0
% INFO    : Bus 9625	: V=1.009734, theta=25.198035 -> V=1.0, theta=0.0
% INFO    : Bus 9626	: V=1.017174, theta=-12.280888 -> V=1.0, theta=0.0
% INFO    : Bus 9627	: V=1.055007, theta=43.318634 -> V=1.0, theta=0.0
% INFO    : Bus 9628	: V=1.012126, theta=5.963328 -> V=1.0, theta=0.0
% INFO    : Bus 9629	: V=1.007963, theta=29.122932 -> V=1.0, theta=0.0
% INFO    : Bus 9630	: V=0.988371, theta=-6.145154 -> V=1.0, theta=0.0
% INFO    : Bus 9631	: V=0.999983, theta=-3.374059 -> V=1.0, theta=0.0
% INFO    : Bus 9632	: V=1.043269, theta=8.473763 -> V=1.0, theta=0.0
% INFO    : Bus 9633	: V=1.045599, theta=28.560936 -> V=1.0, theta=0.0
% INFO    : Bus 9634	: V=1.023319, theta=37.705322 -> V=1.0, theta=0.0
% INFO    : Bus 9635	: V=0.986867, theta=-7.038889 -> V=1.0, theta=0.0
% INFO    : Bus 9636	: V=1.05028, theta=78.087019 -> V=1.0, theta=0.0
% INFO    : Bus 9637	: V=1.023003, theta=0.661159 -> V=1.0, theta=0.0
% INFO    : Bus 9638	: V=0.975244, theta=29.57444 -> V=1.0, theta=0.0
% INFO    : Bus 9639	: V=1.012101, theta=27.54054 -> V=1.0, theta=0.0
% INFO    : Bus 9640	: V=0.993752, theta=2.699763 -> V=1.0, theta=0.0
% INFO    : Bus 9641	: V=1.018927, theta=41.487619 -> V=1.0, theta=0.0
% INFO    : Bus 9642	: V=1.012858, theta=-2.152579 -> V=1.0, theta=0.0
% INFO    : Bus 9643	: V=1.035926, theta=25.971708 -> V=1.0, theta=0.0
% INFO    : Bus 9644	: V=0.953241, theta=-5.357245 -> V=1.0, theta=0.0
% INFO    : Bus 9645	: V=0.950398, theta=-10.506843 -> V=1.0, theta=0.0
% INFO    : Bus 9646	: V=1.007774, theta=-19.841296 -> V=1.0, theta=0.0
% INFO    : Bus 9647	: V=1.001437, theta=-8.846246 -> V=1.0, theta=0.0
% INFO    : Bus 9648	: V=0.99941, theta=-27.313147 -> V=1.0, theta=0.0
% INFO    : Bus 9649	: V=1.030691, theta=-20.97126 -> V=1.0, theta=0.0
% INFO    : Bus 9650	: V=0.993064, theta=-8.173443 -> V=1.0, theta=0.0
% INFO    : Bus 9651	: V=0.986558, theta=-10.760497 -> V=1.0, theta=0.0
% INFO    : Bus 9652	: V=1.029936, theta=12.989549 -> V=1.0, theta=0.0
% INFO    : Bus 9653	: V=1.032345, theta=39.964899 -> V=1.0, theta=0.0
% INFO    : Bus 9654	: V=1.038957, theta=41.625628 -> V=1.0, theta=0.0
% INFO    : Bus 9655	: V=1.064074, theta=38.489396 -> V=1.0, theta=0.0
% INFO    : Bus 9656	: V=1.064118, theta=38.498525 -> V=1.0, theta=0.0
% INFO    : Bus 9657	: V=1.003385, theta=-6.85368 -> V=1.0, theta=0.0
% INFO    : Bus 9658	: V=0.994041, theta=8.719222 -> V=1.0, theta=0.0
% INFO    : Bus 9659	: V=1.043178, theta=23.372652 -> V=1.0, theta=0.0
% INFO    : Bus 9660	: V=1.018955, theta=-12.057193 -> V=1.0, theta=0.0
% INFO    : Bus 9661	: V=1.014781, theta=12.155669 -> V=1.0, theta=0.0
% INFO    : Bus 9662	: V=1.043665, theta=14.930439 -> V=1.0, theta=0.0
% INFO    : Bus 9663	: V=1.041265, theta=-14.533241 -> V=1.0, theta=0.0
% INFO    : Bus 9664	: V=0.997685, theta=89.671137 -> V=1.0, theta=0.0
% INFO    : Bus 9665	: V=1.063379, theta=0.197545 -> V=1.0, theta=0.0
% INFO    : Bus 9666	: V=1.036226, theta=-3.103964 -> V=1.0, theta=0.0
% INFO    : Bus 9667	: V=1.06565, theta=86.49366 -> V=1.0, theta=0.0
% INFO    : Bus 9668	: V=0.969807, theta=36.7392 -> V=1.0, theta=0.0
% INFO    : Bus 9669	: V=0.989079, theta=-4.171297 -> V=1.0, theta=0.0
% INFO    : Bus 9670	: V=1.052384, theta=28.271347 -> V=1.0, theta=0.0
% INFO    : Bus 9671	: V=0.988269, theta=3.695187 -> V=1.0, theta=0.0
% INFO    : Bus 9672	: V=1.00409, theta=-9.883933 -> V=1.0, theta=0.0
% INFO    : Bus 9673	: V=1.046806, theta=67.561933 -> V=1.0, theta=0.0
% INFO    : Bus 9674	: V=1.030674, theta=13.215171 -> V=1.0, theta=0.0
% INFO    : Bus 9675	: V=0.989765, theta=14.047486 -> V=1.0, theta=0.0
% INFO    : Bus 9676	: V=1.005126, theta=29.093859 -> V=1.0, theta=0.0
% INFO    : Bus 9677	: V=1.016878, theta=13.461153 -> V=1.0, theta=0.0
% INFO    : Bus 9678	: V=1.025237, theta=-7.644418 -> V=1.0, theta=0.0
% INFO    : Bus 9679	: V=1.023313, theta=25.625812 -> V=1.0, theta=0.0
% INFO    : Bus 9680	: V=1.047106, theta=69.880946 -> V=1.0, theta=0.0
% INFO    : Bus 9681	: V=1.036584, theta=20.620161 -> V=1.0, theta=0.0
% INFO    : Bus 9682	: V=1.036459, theta=20.605907 -> V=1.0, theta=0.0
% INFO    : Bus 9683	: V=0.999988, theta=-7.149899 -> V=1.0, theta=0.0
% INFO    : Bus 9684	: V=1.007, theta=30.406198 -> V=1.0, theta=0.0
% INFO    : Bus 9685	: V=1.038011, theta=34.090519 -> V=1.0, theta=0.0
% INFO    : Bus 9686	: V=1.021223, theta=-29.489741 -> V=1.0, theta=0.0
% INFO    : Bus 9687	: V=1.129641, theta=7.22366 -> V=1.0, theta=0.0
% INFO    : Bus 9688	: V=1.014344, theta=-3.12179 -> V=1.0, theta=0.0
% INFO    : Bus 9689	: V=1.053142, theta=-0.118026 -> V=1.0, theta=0.0
% INFO    : Bus 9690	: V=1.031301, theta=-10.495578 -> V=1.0, theta=0.0
% INFO    : Bus 9691	: V=0.948316, theta=-8.013982 -> V=1.0, theta=0.0
% INFO    : Bus 9692	: V=1.044742, theta=19.902807 -> V=1.0, theta=0.0
% INFO    : Bus 9693	: V=1.003834, theta=31.873789 -> V=1.0, theta=0.0
% INFO    : Bus 9694	: V=1.03953, theta=23.274277 -> V=1.0, theta=0.0
% INFO    : Bus 9695	: V=1.046243, theta=23.151951 -> V=1.0, theta=0.0
% INFO    : Bus 9696	: V=1.046243, theta=23.151951 -> V=1.0, theta=0.0
% INFO    : Bus 9697	: V=1.046243, theta=23.151951 -> V=1.0, theta=0.0
% INFO    : Bus 9698	: V=1.046243, theta=23.151951 -> V=1.0, theta=0.0
% INFO    : Bus 9699	: V=1.030153, theta=24.072406 -> V=1.0, theta=0.0
% INFO    : Bus 9700	: V=1.048966, theta=21.235269 -> V=1.0, theta=0.0
% INFO    : Bus 9701	: V=1.041304, theta=4.262776 -> V=1.0, theta=0.0
% INFO    : Bus 9702	: V=1.030153, theta=24.072406 -> V=1.0, theta=0.0
% INFO    : Bus 9703	: V=1.080545, theta=11.129943 -> V=1.0, theta=0.0
% INFO    : Bus 9704	: V=1.049012, theta=0.593857 -> V=1.0, theta=0.0
% INFO    : Bus 9705	: V=1.039834, theta=43.452094 -> V=1.0, theta=0.0
% INFO    : Bus 9706	: V=1.007614, theta=14.656778 -> V=1.0, theta=0.0
% INFO    : Bus 9707	: V=1.050647, theta=32.165732 -> V=1.0, theta=0.0
% INFO    : Bus 9708	: V=1.069992, theta=-3.402535 -> V=1.0, theta=0.0
% INFO    : Bus 9709	: V=0.999569, theta=14.240658 -> V=1.0, theta=0.0
% INFO    : Bus 9710	: V=1.06271, theta=27.708558 -> V=1.0, theta=0.0
% INFO    : Bus 9711	: V=1.008309, theta=11.773919 -> V=1.0, theta=0.0
% INFO    : Bus 9712	: V=0.996162, theta=-17.299436 -> V=1.0, theta=0.0
% INFO    : Bus 9713	: V=1.017828, theta=-6.986287 -> V=1.0, theta=0.0
% INFO    : Bus 9714	: V=0.989153, theta=3.178231 -> V=1.0, theta=0.0
% INFO    : Bus 9715	: V=0.900287, theta=-12.257818 -> V=1.0, theta=0.0
% INFO    : Bus 9716	: V=1.020928, theta=-8.381911 -> V=1.0, theta=0.0
% INFO    : Bus 9717	: V=0.95811, theta=-5.43376 -> V=1.0, theta=0.0
% INFO    : Bus 9718	: V=1.003301, theta=0.519687 -> V=1.0, theta=0.0
% INFO    : Bus 9719	: V=0.94532, theta=-8.705616 -> V=1.0, theta=0.0
% INFO    : Bus 9720	: V=1.025138, theta=8.534452 -> V=1.0, theta=0.0
% INFO    : Bus 9721	: V=0.986396, theta=-5.096526 -> V=1.0, theta=0.0
% INFO    : Bus 9722	: V=0.988205, theta=29.491637 -> V=1.0, theta=0.0
% INFO    : Bus 9723	: V=0.994631, theta=-3.825994 -> V=1.0, theta=0.0
% INFO    : Bus 9724	: V=1.012631, theta=-8.55661 -> V=1.0, theta=0.0
% INFO    : Bus 9725	: V=0.976121, theta=-3.668858 -> V=1.0, theta=0.0
% INFO    : Bus 9726	: V=1.028943, theta=29.162114 -> V=1.0, theta=0.0
% INFO    : Bus 9727	: V=1.00283, theta=93.080719 -> V=1.0, theta=0.0
% INFO    : Bus 9728	: V=1.02351, theta=0.368636 -> V=1.0, theta=0.0
% INFO    : Bus 9729	: V=1.033874, theta=-19.115405 -> V=1.0, theta=0.0
% INFO    : Bus 9730	: V=1.058833, theta=15.23437 -> V=1.0, theta=0.0
% INFO    : Bus 9731	: V=1.011264, theta=-9.485571 -> V=1.0, theta=0.0
% INFO    : Bus 9732	: V=1.008401, theta=51.637644 -> V=1.0, theta=0.0
% INFO    : Bus 9733	: V=0.959031, theta=-14.016518 -> V=1.0, theta=0.0
% INFO    : Bus 9734	: V=1.012198, theta=-19.054945 -> V=1.0, theta=0.0
% INFO    : Bus 9735	: V=1.017276, theta=20.695588 -> V=1.0, theta=0.0
% INFO    : Bus 9736	: V=0.996013, theta=33.473733 -> V=1.0, theta=0.0
% INFO    : Bus 9737	: V=1.01757, theta=30.154601 -> V=1.0, theta=0.0
% INFO    : Bus 9738	: V=1.039371, theta=7.907608 -> V=1.0, theta=0.0
% INFO    : Bus 9739	: V=1.010151, theta=-20.700361 -> V=1.0, theta=0.0
% INFO    : Bus 9740	: V=1.026065, theta=-18.352217 -> V=1.0, theta=0.0
% INFO    : Bus 9741	: V=1.054135, theta=-0.225548 -> V=1.0, theta=0.0
% INFO    : Bus 9742	: V=1.028604, theta=-12.690591 -> V=1.0, theta=0.0
% INFO    : Bus 9743	: V=1.021205, theta=-3.900416 -> V=1.0, theta=0.0
% INFO    : Bus 9744	: V=1.010863, theta=24.030251 -> V=1.0, theta=0.0
% INFO    : Bus 9745	: V=1.059759, theta=82.219705 -> V=1.0, theta=0.0
% INFO    : Bus 9746	: V=0.994238, theta=-25.837919 -> V=1.0, theta=0.0
% INFO    : Bus 9747	: V=1.014425, theta=3.598052 -> V=1.0, theta=0.0
% INFO    : Bus 9748	: V=0.982004, theta=27.243336 -> V=1.0, theta=0.0
% INFO    : Bus 9749	: V=1.007061, theta=23.578268 -> V=1.0, theta=0.0
% INFO    : Bus 9750	: V=0.960577, theta=-0.88261 -> V=1.0, theta=0.0
% INFO    : Bus 9751	: V=1.057943, theta=47.733865 -> V=1.0, theta=0.0
% INFO    : Bus 9752	: V=1.020153, theta=18.72273 -> V=1.0, theta=0.0
% INFO    : Bus 9753	: V=1.057896, theta=47.783354 -> V=1.0, theta=0.0
% INFO    : Bus 9754	: V=1.057682, theta=40.579523 -> V=1.0, theta=0.0
% INFO    : Bus 9755	: V=0.997177, theta=11.986244 -> V=1.0, theta=0.0
% INFO    : Bus 9756	: V=1.0136, theta=-3.104621 -> V=1.0, theta=0.0
% INFO    : Bus 9757	: V=1.058111, theta=40.947033 -> V=1.0, theta=0.0
% INFO    : Bus 9758	: V=1.058111, theta=40.947033 -> V=1.0, theta=0.0
% INFO    : Bus 9759	: V=1.057682, theta=40.579523 -> V=1.0, theta=0.0
% INFO    : Bus 9760	: V=1.045285, theta=5.023031 -> V=1.0, theta=0.0
% INFO    : Bus 9761	: V=1.058111, theta=40.947033 -> V=1.0, theta=0.0
% INFO    : Bus 9762	: V=1.058111, theta=40.947033 -> V=1.0, theta=0.0
% INFO    : Bus 9763	: V=1.058111, theta=40.947033 -> V=1.0, theta=0.0
% INFO    : Bus 9764	: V=1.058111, theta=40.947033 -> V=1.0, theta=0.0
% INFO    : Bus 9765	: V=0.974853, theta=-5.721699 -> V=1.0, theta=0.0
% INFO    : Bus 9766	: V=1.024995, theta=14.159948 -> V=1.0, theta=0.0
% INFO    : Bus 9767	: V=1.051219, theta=0.292959 -> V=1.0, theta=0.0
% INFO    : Bus 9768	: V=1.040206, theta=-0.472104 -> V=1.0, theta=0.0
% INFO    : Bus 9769	: V=0.975376, theta=18.346988 -> V=1.0, theta=0.0
% INFO    : Bus 9770	: V=0.927968, theta=-7.699274 -> V=1.0, theta=0.0
% INFO    : Bus 9771	: V=1.016944, theta=-15.006207 -> V=1.0, theta=0.0
% INFO    : Bus 9772	: V=1.016944, theta=-15.006207 -> V=1.0, theta=0.0
% INFO    : Bus 9773	: V=1.054652, theta=-13.052855 -> V=1.0, theta=0.0
% INFO    : Bus 9774	: V=1.019397, theta=-6.35206 -> V=1.0, theta=0.0
% INFO    : Bus 9775	: V=1.033768, theta=14.596978 -> V=1.0, theta=0.0
% INFO    : Bus 9776	: V=1.013783, theta=7.123359 -> V=1.0, theta=0.0
% INFO    : Bus 9777	: V=1.013824, theta=-24.041959 -> V=1.0, theta=0.0
% INFO    : Bus 9778	: V=1.00995, theta=-19.451519 -> V=1.0, theta=0.0
% INFO    : Bus 9779	: V=1.005122, theta=2.268732 -> V=1.0, theta=0.0
% INFO    : Bus 9780	: V=1.002327, theta=-2.090017 -> V=1.0, theta=0.0
% INFO    : Bus 9781	: V=1.026025, theta=92.46745 -> V=1.0, theta=0.0
% INFO    : Bus 9782	: V=1.05076, theta=44.070116 -> V=1.0, theta=0.0
% INFO    : Bus 9783	: V=1.073513, theta=-3.322838 -> V=1.0, theta=0.0
% INFO    : Bus 9784	: V=0.958458, theta=-6.733708 -> V=1.0, theta=0.0
% INFO    : Bus 9785	: V=1.037564, theta=83.849724 -> V=1.0, theta=0.0
% INFO    : Bus 9786	: V=1.002609, theta=-15.370282 -> V=1.0, theta=0.0
% INFO    : Bus 9787	: V=1.051011, theta=-4.984581 -> V=1.0, theta=0.0
% INFO    : Bus 9788	: V=1.036442, theta=14.080919 -> V=1.0, theta=0.0
% INFO    : Bus 9789	: V=1.071124, theta=7.551911 -> V=1.0, theta=0.0
% INFO    : Bus 9790	: V=1.001263, theta=-15.294204 -> V=1.0, theta=0.0
% INFO    : Bus 9791	: V=1.040113, theta=-3.422467 -> V=1.0, theta=0.0
% INFO    : Bus 9792	: V=0.983446, theta=-5.444689 -> V=1.0, theta=0.0
% INFO    : Bus 9793	: V=1.028091, theta=-15.249181 -> V=1.0, theta=0.0
% INFO    : Bus 9794	: V=1.020096, theta=5.857127 -> V=1.0, theta=0.0
% INFO    : Bus 9795	: V=1.018303, theta=-8.158586 -> V=1.0, theta=0.0
% INFO    : Bus 9796	: V=1.047026, theta=-3.76473 -> V=1.0, theta=0.0
% INFO    : Bus 9797	: V=1.016107, theta=1.01711 -> V=1.0, theta=0.0
% INFO    : Bus 9798	: V=1.020262, theta=-10.694863 -> V=1.0, theta=0.0
% INFO    : Bus 9799	: V=1.047712, theta=26.451878 -> V=1.0, theta=0.0
% INFO    : Bus 9800	: V=0.996947, theta=24.602605 -> V=1.0, theta=0.0
% INFO    : Bus 9801	: V=1.017241, theta=17.950982 -> V=1.0, theta=0.0
% INFO    : Bus 9802	: V=1.018419, theta=36.677185 -> V=1.0, theta=0.0
% INFO    : Bus 9803	: V=1.005632, theta=18.008822 -> V=1.0, theta=0.0
% INFO    : Bus 9804	: V=0.975244, theta=29.57444 -> V=1.0, theta=0.0
% INFO    : Bus 9805	: V=1.003281, theta=32.058023 -> V=1.0, theta=0.0
% INFO    : Bus 9806	: V=1.052015, theta=-6.377282 -> V=1.0, theta=0.0
% INFO    : Bus 9807	: V=0.971396, theta=7.124961 -> V=1.0, theta=0.0
% INFO    : Bus 9808	: V=1.03058, theta=15.553508 -> V=1.0, theta=0.0
% INFO    : Bus 9809	: V=1.024762, theta=17.972121 -> V=1.0, theta=0.0
% INFO    : Bus 9810	: V=1.021156, theta=36.648632 -> V=1.0, theta=0.0
% INFO    : Bus 9811	: V=1.036478, theta=27.36973 -> V=1.0, theta=0.0
% INFO    : Bus 9812	: V=0.972329, theta=-5.639687 -> V=1.0, theta=0.0
% INFO    : Bus 9813	: V=1.08103, theta=1.353606 -> V=1.0, theta=0.0
% INFO    : Bus 9814	: V=0.958547, theta=-0.989991 -> V=1.0, theta=0.0
% INFO    : Bus 9815	: V=1.022031, theta=39.678638 -> V=1.0, theta=0.0
% INFO    : Bus 9816	: V=0.943794, theta=-6.340562 -> V=1.0, theta=0.0
% INFO    : Bus 9817	: V=1.002609, theta=-15.370282 -> V=1.0, theta=0.0
% INFO    : Bus 9818	: V=1.001006, theta=93.944307 -> V=1.0, theta=0.0
% INFO    : Bus 9819	: V=1.002876, theta=26.824286 -> V=1.0, theta=0.0
% INFO    : Bus 9820	: V=1.022525, theta=77.641197 -> V=1.0, theta=0.0
% INFO    : Bus 9821	: V=0.993408, theta=-9.287355 -> V=1.0, theta=0.0
% INFO    : Bus 9822	: V=1.017364, theta=-18.571503 -> V=1.0, theta=0.0
% INFO    : Bus 9823	: V=1.036569, theta=7.552584 -> V=1.0, theta=0.0
% INFO    : Bus 9824	: V=1.015024, theta=15.20421 -> V=1.0, theta=0.0
% INFO    : Bus 9825	: V=0.985774, theta=-6.101869 -> V=1.0, theta=0.0
% INFO    : Bus 9826	: V=1.024347, theta=-4.066216 -> V=1.0, theta=0.0
% INFO    : Bus 9827	: V=1.001754, theta=-10.577335 -> V=1.0, theta=0.0
% INFO    : Bus 9828	: V=0.997842, theta=-3.148065 -> V=1.0, theta=0.0
% INFO    : Bus 9829	: V=1.006842, theta=-3.990202 -> V=1.0, theta=0.0
% INFO    : Bus 9830	: V=1.030843, theta=4.085708 -> V=1.0, theta=0.0
% INFO    : Bus 9831	: V=1.026675, theta=25.143797 -> V=1.0, theta=0.0
% INFO    : Bus 9832	: V=0.970315, theta=-8.449974 -> V=1.0, theta=0.0
% INFO    : Bus 9833	: V=1.020982, theta=16.877854 -> V=1.0, theta=0.0
% INFO    : Bus 9834	: V=1.078577, theta=3.402619 -> V=1.0, theta=0.0
% INFO    : Bus 9835	: V=1.033802, theta=9.219664 -> V=1.0, theta=0.0
% INFO    : Bus 9836	: V=0.984262, theta=23.826085 -> V=1.0, theta=0.0
% INFO    : Bus 9837	: V=1.012771, theta=-0.442279 -> V=1.0, theta=0.0
% INFO    : Bus 9838	: V=0.988957, theta=-2.562924 -> V=1.0, theta=0.0
% INFO    : Bus 9839	: V=1.023538, theta=3.417449 -> V=1.0, theta=0.0
% INFO    : Bus 9840	: V=1.049156, theta=27.915793 -> V=1.0, theta=0.0
% INFO    : Bus 9841	: V=1.019755, theta=-1.22221 -> V=1.0, theta=0.0
% INFO    : Bus 9842	: V=1.026718, theta=18.644754 -> V=1.0, theta=0.0
% INFO    : Bus 9843	: V=0.992695, theta=4.921387 -> V=1.0, theta=0.0
% INFO    : Bus 9844	: V=1.013429, theta=-19.964795 -> V=1.0, theta=0.0
% INFO    : Bus 9845	: V=1.018435, theta=-0.87376 -> V=1.0, theta=0.0
% INFO    : Bus 9846	: V=1.168959, theta=2.542881 -> V=1.0, theta=0.0
% INFO    : Bus 9847	: V=1.034787, theta=8.45732 -> V=1.0, theta=0.0
% INFO    : Bus 9848	: V=1.084023, theta=4.623015 -> V=1.0, theta=0.0
% INFO    : Bus 9849	: V=1.014311, theta=18.977675 -> V=1.0, theta=0.0
% INFO    : Bus 9850	: V=1.028661, theta=23.341446 -> V=1.0, theta=0.0
% INFO    : Bus 9851	: V=1.023579, theta=33.717002 -> V=1.0, theta=0.0
% INFO    : Bus 9852	: V=1.029637, theta=45.618005 -> V=1.0, theta=0.0
% INFO    : Bus 9853	: V=1.042135, theta=37.953176 -> V=1.0, theta=0.0
% INFO    : Bus 9854	: V=0.983802, theta=37.273795 -> V=1.0, theta=0.0
% INFO    : Bus 9855	: V=1.015406, theta=15.331048 -> V=1.0, theta=0.0
% INFO    : Bus 9856	: V=1.047943, theta=24.026261 -> V=1.0, theta=0.0
% INFO    : Bus 9857	: V=0.989798, theta=-4.249455 -> V=1.0, theta=0.0
% INFO    : Bus 9858	: V=1.017609, theta=-21.781337 -> V=1.0, theta=0.0
% INFO    : Bus 9859	: V=0.999864, theta=-7.119187 -> V=1.0, theta=0.0
% INFO    : Bus 9860	: V=0.998215, theta=12.734047 -> V=1.0, theta=0.0
% INFO    : Bus 9861	: V=1.073302, theta=1.352587 -> V=1.0, theta=0.0
% INFO    : Bus 9862	: V=1.033735, theta=-14.68008 -> V=1.0, theta=0.0
% INFO    : Bus 9863	: V=1.022452, theta=48.259654 -> V=1.0, theta=0.0
% INFO    : Bus 9864	: V=1.045894, theta=10.932839 -> V=1.0, theta=0.0
% INFO    : Bus 9865	: V=0.954852, theta=-8.03732 -> V=1.0, theta=0.0
% INFO    : Bus 9866	: V=1.015482, theta=34.721993 -> V=1.0, theta=0.0
% INFO    : Bus 9867	: V=1.00884, theta=28.509216 -> V=1.0, theta=0.0
% INFO    : Bus 9868	: V=1.018342, theta=-5.238465 -> V=1.0, theta=0.0
% INFO    : Bus 9869	: V=1.035871, theta=12.613244 -> V=1.0, theta=0.0
% INFO    : Bus 9870	: V=1.033735, theta=-14.68008 -> V=1.0, theta=0.0
% INFO    : Bus 9871	: V=1.033788, theta=21.861155 -> V=1.0, theta=0.0
% INFO    : Bus 9872	: V=0.977849, theta=-5.747813 -> V=1.0, theta=0.0
% INFO    : Bus 9873	: V=1.040642, theta=8.532255 -> V=1.0, theta=0.0
% INFO    : Bus 9874	: V=1.014206, theta=-8.158765 -> V=1.0, theta=0.0
% INFO    : Bus 9875	: V=1.058355, theta=41.76159 -> V=1.0, theta=0.0
% INFO    : Bus 9876	: V=0.981799, theta=-5.916291 -> V=1.0, theta=0.0
% INFO    : Bus 9877	: V=1.0363, theta=-8.161166 -> V=1.0, theta=0.0
% INFO    : Bus 9878	: V=1.045756, theta=-16.19126 -> V=1.0, theta=0.0
% INFO    : Bus 9879	: V=1.019351, theta=37.983767 -> V=1.0, theta=0.0
% INFO    : Bus 9880	: V=1.03481, theta=9.302046 -> V=1.0, theta=0.0
% INFO    : Bus 9881	: V=1.026644, theta=-8.343517 -> V=1.0, theta=0.0
% INFO    : Bus 9882	: V=1.000383, theta=15.746042 -> V=1.0, theta=0.0
% INFO    : Bus 9883	: V=1.029959, theta=-17.695067 -> V=1.0, theta=0.0
% INFO    : Bus 9884	: V=1.015531, theta=4.163384 -> V=1.0, theta=0.0
% INFO    : Bus 9885	: V=1.034215, theta=9.728222 -> V=1.0, theta=0.0
% INFO    : Bus 9886	: V=1.020132, theta=-17.027986 -> V=1.0, theta=0.0
% INFO    : Bus 9887	: V=1.034215, theta=9.728222 -> V=1.0, theta=0.0
% INFO    : Bus 9888	: V=0.999681, theta=-3.315766 -> V=1.0, theta=0.0
% INFO    : Bus 9889	: V=0.97134, theta=45.507431 -> V=1.0, theta=0.0
% INFO    : Bus 9890	: V=1.027947, theta=90.287595 -> V=1.0, theta=0.0
% INFO    : Bus 9891	: V=1.040062, theta=-16.220503 -> V=1.0, theta=0.0
% INFO    : Bus 9892	: V=1.024213, theta=6.206273 -> V=1.0, theta=0.0
% INFO    : Bus 9893	: V=1.028581, theta=5.914906 -> V=1.0, theta=0.0
% INFO    : Bus 9894	: V=0.978211, theta=-7.893051 -> V=1.0, theta=0.0
% INFO    : Bus 9895	: V=1.019814, theta=13.132837 -> V=1.0, theta=0.0
% INFO    : Bus 9896	: V=1.035163, theta=2.77244 -> V=1.0, theta=0.0
% INFO    : Bus 9897	: V=1.016633, theta=-9.935635 -> V=1.0, theta=0.0
% INFO    : Bus 9898	: V=1.045649, theta=20.864366 -> V=1.0, theta=0.0
% INFO    : Bus 9899	: V=1.023729, theta=-7.335996 -> V=1.0, theta=0.0
% INFO    : Bus 9900	: V=1.016633, theta=-9.935635 -> V=1.0, theta=0.0
% INFO    : Bus 9901	: V=1.022889, theta=18.879559 -> V=1.0, theta=0.0
% INFO    : Bus 9902	: V=0.951565, theta=38.529485 -> V=1.0, theta=0.0
% INFO    : Bus 9903	: V=1.019587, theta=-11.095675 -> V=1.0, theta=0.0
% INFO    : Bus 9904	: V=1.075446, theta=2.691479 -> V=1.0, theta=0.0
% INFO    : Bus 9905	: V=0.99587, theta=23.917917 -> V=1.0, theta=0.0
% INFO    : Bus 9906	: V=0.991405, theta=49.871472 -> V=1.0, theta=0.0
% INFO    : Bus 9907	: V=1.019315, theta=28.739796 -> V=1.0, theta=0.0
% INFO    : Bus 9908	: V=1.014569, theta=-26.829214 -> V=1.0, theta=0.0
% INFO    : Bus 9909	: V=1.035421, theta=27.235973 -> V=1.0, theta=0.0
% INFO    : Bus 9910	: V=1.054211, theta=-1.099056 -> V=1.0, theta=0.0
% INFO    : Bus 9911	: V=1.035421, theta=27.235973 -> V=1.0, theta=0.0
% INFO    : Bus 9912	: V=1.035421, theta=27.235973 -> V=1.0, theta=0.0
% INFO    : Bus 9913	: V=1.06299, theta=30.147149 -> V=1.0, theta=0.0
% INFO    : Bus 9914	: V=1.052369, theta=0.152148 -> V=1.0, theta=0.0
% INFO    : Bus 9915	: V=1.026231, theta=4.096914 -> V=1.0, theta=0.0
% INFO    : Bus 9916	: V=1.045591, theta=14.974901 -> V=1.0, theta=0.0
% INFO    : Bus 9917	: V=0.998017, theta=-7.448126 -> V=1.0, theta=0.0
% INFO    : Bus 9918	: V=0.965057, theta=-9.801871 -> V=1.0, theta=0.0
% INFO    : Bus 9919	: V=1.072464, theta=0.866855 -> V=1.0, theta=0.0
% INFO    : Bus 9920	: V=1.033741, theta=4.638633 -> V=1.0, theta=0.0
% INFO    : Bus 9921	: V=0.970219, theta=-7.386157 -> V=1.0, theta=0.0
% INFO    : Bus 9922	: V=1.029161, theta=20.548569 -> V=1.0, theta=0.0
% INFO    : Bus 9923	: V=1.01017, theta=15.666854 -> V=1.0, theta=0.0
% INFO    : Bus 9924	: V=1.108643, theta=49.347411 -> V=1.0, theta=0.0
% INFO    : Bus 9925	: V=0.988226, theta=-21.973367 -> V=1.0, theta=0.0
% INFO    : Bus 9926	: V=1.009486, theta=16.888084 -> V=1.0, theta=0.0
% INFO    : Bus 9927	: V=1.019031, theta=36.638239 -> V=1.0, theta=0.0
% INFO    : Bus 9928	: V=1.00569, theta=12.216215 -> V=1.0, theta=0.0
% INFO    : Bus 9929	: V=1.00569, theta=12.216215 -> V=1.0, theta=0.0
% INFO    : Bus 9930	: V=1.00569, theta=12.216215 -> V=1.0, theta=0.0
% INFO    : Bus 9931	: V=0.944702, theta=-10.819415 -> V=1.0, theta=0.0
% INFO    : Bus 9932	: V=1.029382, theta=20.080326 -> V=1.0, theta=0.0
% INFO    : Bus 9933	: V=1.029161, theta=20.548569 -> V=1.0, theta=0.0
% INFO    : Bus 9934	: V=1.001995, theta=2.088521 -> V=1.0, theta=0.0
% INFO    : Bus 9935	: V=0.957824, theta=-5.219353 -> V=1.0, theta=0.0
% INFO    : Bus 9936	: V=0.970769, theta=4.966177 -> V=1.0, theta=0.0
% INFO    : Bus 9937	: V=1.01208, theta=8.274182 -> V=1.0, theta=0.0
% INFO    : Bus 9938	: V=1.029313, theta=26.316753 -> V=1.0, theta=0.0
% INFO    : Bus 9939	: V=1.005022, theta=6.351004 -> V=1.0, theta=0.0
% INFO    : Bus 9940	: V=1.012035, theta=-12.726866 -> V=1.0, theta=0.0
% INFO    : Bus 9941	: V=0.930948, theta=-7.371611 -> V=1.0, theta=0.0
% INFO    : Bus 9942	: V=1.036318, theta=8.669231 -> V=1.0, theta=0.0
% INFO    : Bus 9943	: V=0.966804, theta=-9.648323 -> V=1.0, theta=0.0
% INFO    : Bus 9944	: V=0.96942, theta=29.960607 -> V=1.0, theta=0.0
% INFO    : Bus 9945	: V=0.996771, theta=-3.509392 -> V=1.0, theta=0.0
% INFO    : Bus 9946	: V=1.038225, theta=16.178789 -> V=1.0, theta=0.0
% INFO    : Bus 9947	: V=1.000254, theta=-3.054389 -> V=1.0, theta=0.0
% INFO    : Bus 9948	: V=1.068984, theta=73.067046 -> V=1.0, theta=0.0
% INFO    : Bus 9949	: V=1.020529, theta=-14.481379 -> V=1.0, theta=0.0
% INFO    : Bus 9950	: V=0.98626, theta=29.963187 -> V=1.0, theta=0.0
% INFO    : Bus 9951	: V=1.018021, theta=0.638927 -> V=1.0, theta=0.0
% INFO    : Bus 9952	: V=1.051195, theta=-11.661125 -> V=1.0, theta=0.0
% INFO    : Bus 9953	: V=1.017638, theta=-6.936102 -> V=1.0, theta=0.0
% INFO    : Bus 9954	: V=0.979395, theta=-2.770904 -> V=1.0, theta=0.0
% INFO    : Bus 9955	: V=1.0523, theta=4.801942 -> V=1.0, theta=0.0
% INFO    : Bus 9956	: V=1.028162, theta=4.080023 -> V=1.0, theta=0.0
% INFO    : Bus 9957	: V=1.026081, theta=32.715698 -> V=1.0, theta=0.0
% INFO    : Bus 9958	: V=1.026081, theta=32.715698 -> V=1.0, theta=0.0
% INFO    : Bus 9959	: V=1.026081, theta=32.715698 -> V=1.0, theta=0.0
% INFO    : Bus 9960	: V=1.127948, theta=6.872839 -> V=1.0, theta=0.0
% INFO    : Bus 9961	: V=1.016605, theta=25.542934 -> V=1.0, theta=0.0
% INFO    : Bus 9962	: V=0.978034, theta=-7.906363 -> V=1.0, theta=0.0
% INFO    : Bus 9963	: V=1.016461, theta=26.125945 -> V=1.0, theta=0.0
% INFO    : Bus 9964	: V=1.016605, theta=25.542934 -> V=1.0, theta=0.0
% INFO    : Bus 9965	: V=1.012245, theta=18.343627 -> V=1.0, theta=0.0
% INFO    : Bus 9966	: V=1.026844, theta=15.277514 -> V=1.0, theta=0.0
% INFO    : Bus 9967	: V=1.028796, theta=30.892401 -> V=1.0, theta=0.0
% INFO    : Bus 9968	: V=1.016251, theta=21.980602 -> V=1.0, theta=0.0
% INFO    : Bus 9969	: V=1.039376, theta=5.373829 -> V=1.0, theta=0.0
% INFO    : Bus 9970	: V=1.044895, theta=25.556743 -> V=1.0, theta=0.0
% INFO    : Bus 9971	: V=0.950074, theta=-11.205307 -> V=1.0, theta=0.0
% INFO    : Bus 9972	: V=1.017859, theta=24.98212 -> V=1.0, theta=0.0
% INFO    : Bus 9973	: V=0.992001, theta=57.207789 -> V=1.0, theta=0.0
% INFO    : Bus 9974	: V=1.044939, theta=29.387061 -> V=1.0, theta=0.0
% INFO    : Bus 9975	: V=0.957116, theta=25.356265 -> V=1.0, theta=0.0
% INFO    : Bus 9976	: V=1.029146, theta=3.188044 -> V=1.0, theta=0.0
% INFO    : Bus 9977	: V=0.944686, theta=-10.875693 -> V=1.0, theta=0.0
% INFO    : Bus 9978	: V=0.98221, theta=31.994448 -> V=1.0, theta=0.0
% INFO    : Bus 9979	: V=1.063704, theta=66.981987 -> V=1.0, theta=0.0
% INFO    : Bus 9980	: V=1.098598, theta=65.002423 -> V=1.0, theta=0.0
% INFO    : Bus 9981	: V=0.969283, theta=27.641116 -> V=1.0, theta=0.0
% INFO    : Bus 9982	: V=0.999953, theta=-3.032403 -> V=1.0, theta=0.0
% INFO    : Bus 9983	: V=1.016284, theta=49.478439 -> V=1.0, theta=0.0
% INFO    : Bus 9984	: V=1.026243, theta=6.043442 -> V=1.0, theta=0.0
% INFO    : Bus 9985	: V=1.032237, theta=-8.120404 -> V=1.0, theta=0.0
% INFO    : Bus 9986	: V=1.030293, theta=-20.991696 -> V=1.0, theta=0.0
% INFO    : Bus 9987	: V=1.033881, theta=21.336662 -> V=1.0, theta=0.0
% INFO    : Bus 9988	: V=1.039039, theta=32.352018 -> V=1.0, theta=0.0
% INFO    : Bus 9989	: V=0.993356, theta=89.245985 -> V=1.0, theta=0.0
% INFO    : Bus 9990	: V=1.001746, theta=17.611273 -> V=1.0, theta=0.0
% INFO    : Bus 9991	: V=1.013705, theta=-26.311523 -> V=1.0, theta=0.0
% INFO    : Bus 9992	: V=1.031639, theta=20.734057 -> V=1.0, theta=0.0
% INFO    : Bus 9993	: V=1.009996, theta=-16.605815 -> V=1.0, theta=0.0
% INFO    : Bus 9994	: V=0.99045, theta=-4.367166 -> V=1.0, theta=0.0
% INFO    : Bus 9995	: V=0.993383, theta=32.126146 -> V=1.0, theta=0.0
% INFO    : Bus 9996	: V=0.991988, theta=0.772011 -> V=1.0, theta=0.0
% INFO    : Bus 9997	: V=1.016106, theta=0.556804 -> V=1.0, theta=0.0
% INFO    : Bus 9998	: V=1.024978, theta=18.038243 -> V=1.0, theta=0.0
% INFO    : Bus 9999	: V=1.019717, theta=13.94859 -> V=1.0, theta=0.0
% INFO    : Bus 10000	: V=1.010073, theta=29.952253 -> V=1.0, theta=0.0
% INFO    : Bus 10001	: V=1.024544, theta=18.974877 -> V=1.0, theta=0.0
% INFO    : Bus 10002	: V=0.9864, theta=-4.126615 -> V=1.0, theta=0.0
% INFO    : Bus 10003	: V=1.011474, theta=16.380507 -> V=1.0, theta=0.0
% INFO    : Bus 10004	: V=1.015185, theta=-4.986575 -> V=1.0, theta=0.0
% INFO    : Bus 10005	: V=1.015961, theta=-2.994662 -> V=1.0, theta=0.0
% INFO    : Bus 10006	: V=1.016735, theta=24.349916 -> V=1.0, theta=0.0
% INFO    : Bus 10007	: V=1.043764, theta=37.173377 -> V=1.0, theta=0.0
% INFO    : Bus 10008	: V=0.990736, theta=9.872108 -> V=1.0, theta=0.0
% INFO    : Bus 10009	: V=1.014364, theta=-8.724986 -> V=1.0, theta=0.0
% INFO    : Bus 10010	: V=1.012893, theta=26.368849 -> V=1.0, theta=0.0
% INFO    : Bus 10011	: V=1.045246, theta=19.956837 -> V=1.0, theta=0.0
% INFO    : Bus 10012	: V=1.01515, theta=14.648403 -> V=1.0, theta=0.0
% INFO    : Bus 10013	: V=0.929504, theta=-10.424558 -> V=1.0, theta=0.0
% INFO    : Bus 10014	: V=1.031548, theta=-12.552935 -> V=1.0, theta=0.0
% INFO    : Bus 10015	: V=1.026585, theta=23.218908 -> V=1.0, theta=0.0
% INFO    : Bus 10016	: V=0.964803, theta=-5.53487 -> V=1.0, theta=0.0
% INFO    : Bus 10017	: V=1.017078, theta=-0.332817 -> V=1.0, theta=0.0
% INFO    : Bus 10018	: V=0.961347, theta=34.727912 -> V=1.0, theta=0.0
% INFO    : Bus 10019	: V=0.995355, theta=4.44153 -> V=1.0, theta=0.0
% INFO    : Bus 10020	: V=1.028019, theta=32.505211 -> V=1.0, theta=0.0
% INFO    : Bus 10021	: V=1.035188, theta=16.78973 -> V=1.0, theta=0.0
% INFO    : Bus 10022	: V=1.023287, theta=-16.294788 -> V=1.0, theta=0.0
% INFO    : Bus 10023	: V=1.019357, theta=22.943488 -> V=1.0, theta=0.0
% INFO    : Bus 10024	: V=0.986837, theta=13.352735 -> V=1.0, theta=0.0
% INFO    : Bus 10025	: V=1.00692, theta=0.387233 -> V=1.0, theta=0.0
% INFO    : Bus 10026	: V=1.028324, theta=47.055857 -> V=1.0, theta=0.0
% INFO    : Bus 10027	: V=1.025886, theta=4.522198 -> V=1.0, theta=0.0
% INFO    : Bus 10028	: V=0.991697, theta=-10.534217 -> V=1.0, theta=0.0
% INFO    : Bus 10029	: V=1.070509, theta=1.019613 -> V=1.0, theta=0.0
% INFO    : Bus 10030	: V=1.010526, theta=37.963011 -> V=1.0, theta=0.0
% INFO    : Bus 10031	: V=1.018093, theta=-25.999068 -> V=1.0, theta=0.0
% INFO    : Bus 10032	: V=1.016587, theta=-25.957681 -> V=1.0, theta=0.0
% INFO    : Bus 10033	: V=1.024594, theta=92.45199 -> V=1.0, theta=0.0
% INFO    : Bus 10034	: V=1.006944, theta=-5.921798 -> V=1.0, theta=0.0
% INFO    : Bus 10035	: V=1.013269, theta=7.216318 -> V=1.0, theta=0.0
% INFO    : Bus 10036	: V=1.009755, theta=-7.535974 -> V=1.0, theta=0.0
% INFO    : Bus 10037	: V=1.017464, theta=-4.981811 -> V=1.0, theta=0.0
% INFO    : Bus 10038	: V=0.985548, theta=-7.292905 -> V=1.0, theta=0.0
% INFO    : Bus 10039	: V=0.983619, theta=-6.734185 -> V=1.0, theta=0.0
% INFO    : Bus 10040	: V=1.013012, theta=25.491888 -> V=1.0, theta=0.0
% INFO    : Bus 10041	: V=1.067387, theta=4.878862 -> V=1.0, theta=0.0
% INFO    : Bus 10042	: V=0.996077, theta=-9.142556 -> V=1.0, theta=0.0
% INFO    : Bus 10043	: V=0.985622, theta=-13.402712 -> V=1.0, theta=0.0
% INFO    : Bus 10044	: V=1.051887, theta=-14.484778 -> V=1.0, theta=0.0
% INFO    : Bus 10045	: V=0.99473, theta=33.46147 -> V=1.0, theta=0.0
% INFO    : Bus 10046	: V=0.965162, theta=-7.575228 -> V=1.0, theta=0.0
% INFO    : Bus 10047	: V=1.026388, theta=44.52921 -> V=1.0, theta=0.0
% INFO    : Bus 10048	: V=1.046742, theta=25.054968 -> V=1.0, theta=0.0
% INFO    : Bus 10049	: V=0.922112, theta=-7.609271 -> V=1.0, theta=0.0
% INFO    : Bus 10050	: V=1.02494, theta=28.997481 -> V=1.0, theta=0.0
% INFO    : Bus 10051	: V=1.025335, theta=-26.564951 -> V=1.0, theta=0.0
% INFO    : Bus 10052	: V=1.019503, theta=8.365451 -> V=1.0, theta=0.0
% INFO    : Bus 10053	: V=1.098295, theta=64.988854 -> V=1.0, theta=0.0
% INFO    : Bus 10054	: V=0.974088, theta=-8.221786 -> V=1.0, theta=0.0
% INFO    : Bus 10055	: V=1.001416, theta=34.084126 -> V=1.0, theta=0.0
% INFO    : Bus 10056	: V=1.030573, theta=26.350367 -> V=1.0, theta=0.0
% INFO    : Bus 10057	: V=1.003179, theta=38.552189 -> V=1.0, theta=0.0
% INFO    : Bus 10058	: V=1.012718, theta=13.884467 -> V=1.0, theta=0.0
% INFO    : Bus 10059	: V=1.040992, theta=33.204952 -> V=1.0, theta=0.0
% INFO    : Bus 10060	: V=1.032321, theta=27.942453 -> V=1.0, theta=0.0
% INFO    : Bus 10061	: V=1.014454, theta=20.742832 -> V=1.0, theta=0.0
% INFO    : Bus 10062	: V=1.038246, theta=16.785299 -> V=1.0, theta=0.0
% INFO    : Bus 10063	: V=1.051738, theta=1.280044 -> V=1.0, theta=0.0
% INFO    : Bus 10064	: V=1.033602, theta=30.076827 -> V=1.0, theta=0.0
% INFO    : Bus 10065	: V=1.033601, theta=30.077016 -> V=1.0, theta=0.0
% INFO    : Bus 10066	: V=1.025422, theta=3.194796 -> V=1.0, theta=0.0
% INFO    : Bus 10067	: V=0.947551, theta=51.235294 -> V=1.0, theta=0.0
% INFO    : Bus 10068	: V=1.044317, theta=35.206283 -> V=1.0, theta=0.0
% INFO    : Bus 10069	: V=1.011202, theta=-12.139109 -> V=1.0, theta=0.0
% INFO    : Bus 10070	: V=1.011199, theta=-8.344907 -> V=1.0, theta=0.0
% INFO    : Bus 10071	: V=1.047627, theta=12.568215 -> V=1.0, theta=0.0
% INFO    : Bus 10072	: V=0.975088, theta=-6.482619 -> V=1.0, theta=0.0
% INFO    : Bus 10073	: V=1.028279, theta=-5.259984 -> V=1.0, theta=0.0
% INFO    : Bus 10074	: V=1.028279, theta=-5.260179 -> V=1.0, theta=0.0
% INFO    : Bus 10075	: V=1.027739, theta=-17.648712 -> V=1.0, theta=0.0
% INFO    : Bus 10076	: V=1.027739, theta=-17.648712 -> V=1.0, theta=0.0
% INFO    : Bus 10077	: V=1.027739, theta=-17.648712 -> V=1.0, theta=0.0
% INFO    : Bus 10078	: V=1.027739, theta=-17.648712 -> V=1.0, theta=0.0
% INFO    : Bus 10079	: V=1.001371, theta=-7.617414 -> V=1.0, theta=0.0
% INFO    : Bus 10080	: V=1.027739, theta=-17.648712 -> V=1.0, theta=0.0
% INFO    : Bus 10081	: V=0.964931, theta=-3.531377 -> V=1.0, theta=0.0
% INFO    : Bus 10082	: V=1.026513, theta=30.597405 -> V=1.0, theta=0.0
% INFO    : Bus 10083	: V=0.994374, theta=10.486339 -> V=1.0, theta=0.0
% INFO    : Bus 10084	: V=1.028916, theta=-13.292219 -> V=1.0, theta=0.0
% INFO    : Bus 10085	: V=1.027149, theta=-28.47052 -> V=1.0, theta=0.0
% INFO    : Bus 10086	: V=1.003768, theta=-12.883511 -> V=1.0, theta=0.0
% INFO    : Bus 10087	: V=1.040379, theta=38.521981 -> V=1.0, theta=0.0
% INFO    : Bus 10088	: V=0.94887, theta=-0.107604 -> V=1.0, theta=0.0
% INFO    : Bus 10089	: V=1.012856, theta=14.386679 -> V=1.0, theta=0.0
% INFO    : Bus 10090	: V=1.028895, theta=7.374044 -> V=1.0, theta=0.0
% INFO    : Bus 10091	: V=1.006932, theta=-8.997116 -> V=1.0, theta=0.0
% INFO    : Bus 10092	: V=1.060112, theta=4.394131 -> V=1.0, theta=0.0
% INFO    : Bus 10093	: V=1.018243, theta=34.475442 -> V=1.0, theta=0.0
% INFO    : Bus 10094	: V=0.990464, theta=21.09396 -> V=1.0, theta=0.0
% INFO    : Bus 10095	: V=0.968494, theta=-13.945945 -> V=1.0, theta=0.0
% INFO    : Bus 10096	: V=1.032797, theta=5.614702 -> V=1.0, theta=0.0
% INFO    : Bus 10097	: V=1.009787, theta=-8.141186 -> V=1.0, theta=0.0
% INFO    : Bus 10098	: V=0.979064, theta=-10.93172 -> V=1.0, theta=0.0
% INFO    : Bus 10099	: V=1.091334, theta=82.213028 -> V=1.0, theta=0.0
% INFO    : Bus 10100	: V=1.036949, theta=12.275543 -> V=1.0, theta=0.0
% INFO    : Bus 10101	: V=1.019231, theta=22.327173 -> V=1.0, theta=0.0
% INFO    : Bus 10102	: V=1.034412, theta=41.712007 -> V=1.0, theta=0.0
% INFO    : Bus 10103	: V=1.014977, theta=44.252308 -> V=1.0, theta=0.0
% INFO    : Bus 10104	: V=1.086357, theta=-3.618297 -> V=1.0, theta=0.0
% INFO    : Bus 10105	: V=1.037061, theta=-15.042474 -> V=1.0, theta=0.0
% INFO    : Bus 10106	: V=0.984354, theta=-5.000535 -> V=1.0, theta=0.0
% INFO    : Bus 10107	: V=1.011712, theta=-8.997116 -> V=1.0, theta=0.0
% INFO    : Bus 10108	: V=0.993002, theta=-4.228433 -> V=1.0, theta=0.0
% INFO    : Bus 10109	: V=0.984093, theta=18.898155 -> V=1.0, theta=0.0
% INFO    : Bus 10110	: V=1.012031, theta=-8.893616 -> V=1.0, theta=0.0
% INFO    : Bus 10111	: V=0.880509, theta=-14.642882 -> V=1.0, theta=0.0
% INFO    : Bus 10112	: V=0.996028, theta=20.31987 -> V=1.0, theta=0.0
% INFO    : Bus 10113	: V=1.040357, theta=46.518975 -> V=1.0, theta=0.0
% INFO    : Bus 10114	: V=0.991929, theta=29.398008 -> V=1.0, theta=0.0
% INFO    : Bus 10115	: V=1.041212, theta=-15.377355 -> V=1.0, theta=0.0
% INFO    : Bus 10116	: V=1.041212, theta=-15.377355 -> V=1.0, theta=0.0
% INFO    : Bus 10117	: V=1.041212, theta=-15.377355 -> V=1.0, theta=0.0
% INFO    : Bus 10118	: V=0.996379, theta=-9.059184 -> V=1.0, theta=0.0
% INFO    : Bus 10119	: V=1.031368, theta=-5.222436 -> V=1.0, theta=0.0
% INFO    : Bus 10120	: V=1.033534, theta=-10.544863 -> V=1.0, theta=0.0
% INFO    : Bus 10121	: V=0.981228, theta=25.659354 -> V=1.0, theta=0.0
% INFO    : Bus 10122	: V=1.032084, theta=-6.737315 -> V=1.0, theta=0.0
% INFO    : Bus 10123	: V=1.073678, theta=6.788925 -> V=1.0, theta=0.0
% INFO    : Bus 10124	: V=1.043894, theta=12.654648 -> V=1.0, theta=0.0
% INFO    : Bus 10125	: V=0.999681, theta=15.764613 -> V=1.0, theta=0.0
% INFO    : Bus 10126	: V=1.016633, theta=-26.276997 -> V=1.0, theta=0.0
% INFO    : Bus 10127	: V=1.011334, theta=15.123433 -> V=1.0, theta=0.0
% INFO    : Bus 10128	: V=0.9986, theta=90.164736 -> V=1.0, theta=0.0
% INFO    : Bus 10129	: V=0.981485, theta=0.334141 -> V=1.0, theta=0.0
% INFO    : Bus 10130	: V=1.031372, theta=-11.35432 -> V=1.0, theta=0.0
% INFO    : Bus 10131	: V=1.018079, theta=18.919741 -> V=1.0, theta=0.0
% INFO    : Bus 10132	: V=1.046665, theta=36.809947 -> V=1.0, theta=0.0
% INFO    : Bus 10133	: V=0.966583, theta=-5.616871 -> V=1.0, theta=0.0
% INFO    : Bus 10134	: V=1.046665, theta=36.809947 -> V=1.0, theta=0.0
% INFO    : Bus 10135	: V=1.046665, theta=36.809947 -> V=1.0, theta=0.0
% INFO    : Bus 10136	: V=1.007265, theta=-8.463478 -> V=1.0, theta=0.0
% INFO    : Bus 10137	: V=1.017428, theta=42.294322 -> V=1.0, theta=0.0
% INFO    : Bus 10138	: V=1.046181, theta=1.313814 -> V=1.0, theta=0.0
% INFO    : Bus 10139	: V=1.002858, theta=15.589186 -> V=1.0, theta=0.0
% INFO    : Bus 10140	: V=1.020735, theta=7.8322 -> V=1.0, theta=0.0
% INFO    : Bus 10141	: V=1.014507, theta=26.136069 -> V=1.0, theta=0.0
% INFO    : Bus 10142	: V=1.014507, theta=26.136069 -> V=1.0, theta=0.0
% INFO    : Bus 10143	: V=1.014507, theta=26.136069 -> V=1.0, theta=0.0
% INFO    : Bus 10144	: V=1.047938, theta=-5.803473 -> V=1.0, theta=0.0
% INFO    : Bus 10145	: V=1.030478, theta=-7.645913 -> V=1.0, theta=0.0
% INFO    : Bus 10146	: V=1.002892, theta=-20.493605 -> V=1.0, theta=0.0
% INFO    : Bus 10147	: V=1.031214, theta=76.497249 -> V=1.0, theta=0.0
% INFO    : Bus 10148	: V=1.013214, theta=-9.554079 -> V=1.0, theta=0.0
% INFO    : Bus 10149	: V=1.018017, theta=36.086297 -> V=1.0, theta=0.0
% INFO    : Bus 10150	: V=1.013983, theta=-26.722266 -> V=1.0, theta=0.0
% INFO    : Bus 10151	: V=1.009173, theta=19.132388 -> V=1.0, theta=0.0
% INFO    : Bus 10152	: V=0.942539, theta=-11.042543 -> V=1.0, theta=0.0
% INFO    : Bus 10153	: V=1.01379, theta=35.557931 -> V=1.0, theta=0.0
% INFO    : Bus 10154	: V=0.999957, theta=-4.276216 -> V=1.0, theta=0.0
% INFO    : Bus 10155	: V=1.013445, theta=-14.636462 -> V=1.0, theta=0.0
% INFO    : Bus 10156	: V=0.978477, theta=21.737802 -> V=1.0, theta=0.0
% INFO    : Bus 10157	: V=1.012921, theta=-22.921055 -> V=1.0, theta=0.0
% INFO    : Bus 10158	: V=1.051307, theta=2.565569 -> V=1.0, theta=0.0
% INFO    : Bus 10159	: V=1.025128, theta=10.343603 -> V=1.0, theta=0.0
% INFO    : Bus 10160	: V=1.018665, theta=23.13173 -> V=1.0, theta=0.0
% INFO    : Bus 10161	: V=0.969348, theta=-29.133437 -> V=1.0, theta=0.0
% INFO    : Bus 10162	: V=1.066536, theta=53.399189 -> V=1.0, theta=0.0
% INFO    : Bus 10163	: V=1.099095, theta=-14.350196 -> V=1.0, theta=0.0
% INFO    : Bus 10164	: V=1.009173, theta=19.132388 -> V=1.0, theta=0.0
% INFO    : Bus 10165	: V=1.028579, theta=38.422797 -> V=1.0, theta=0.0
% INFO    : Bus 10166	: V=1.100646, theta=-4.336342 -> V=1.0, theta=0.0
% INFO    : Bus 10167	: V=0.999717, theta=-3.057798 -> V=1.0, theta=0.0
% INFO    : Bus 10168	: V=1.022517, theta=12.676727 -> V=1.0, theta=0.0
% INFO    : Bus 10169	: V=0.978291, theta=-29.075324 -> V=1.0, theta=0.0
% INFO    : Bus 10170	: V=1.02764, theta=29.676461 -> V=1.0, theta=0.0
% INFO    : Bus 10171	: V=1.046641, theta=37.417065 -> V=1.0, theta=0.0
% INFO    : Bus 10172	: V=1.046641, theta=37.417065 -> V=1.0, theta=0.0
% INFO    : Bus 10173	: V=1.046641, theta=37.417065 -> V=1.0, theta=0.0
% INFO    : Bus 10174	: V=1.046641, theta=37.417065 -> V=1.0, theta=0.0
% INFO    : Bus 10175	: V=1.007976, theta=22.201821 -> V=1.0, theta=0.0
% INFO    : Bus 10176	: V=1.013014, theta=-18.282288 -> V=1.0, theta=0.0
% INFO    : Bus 10177	: V=1.011416, theta=44.498643 -> V=1.0, theta=0.0
% INFO    : Bus 10178	: V=1.014865, theta=17.912579 -> V=1.0, theta=0.0
% INFO    : Bus 10179	: V=1.011217, theta=30.729911 -> V=1.0, theta=0.0
% INFO    : Bus 10180	: V=1.055178, theta=-0.20412 -> V=1.0, theta=0.0
% INFO    : Bus 10181	: V=1.015832, theta=3.038481 -> V=1.0, theta=0.0
% INFO    : Bus 10182	: V=1.059753, theta=5.769076 -> V=1.0, theta=0.0
% INFO    : Bus 10183	: V=1.006741, theta=-19.775592 -> V=1.0, theta=0.0
% INFO    : Bus 10184	: V=0.998885, theta=2.232778 -> V=1.0, theta=0.0
% INFO    : Bus 10185	: V=1.045273, theta=-4.513781 -> V=1.0, theta=0.0
% INFO    : Bus 10186	: V=1.031159, theta=7.793526 -> V=1.0, theta=0.0
% INFO    : Bus 10187	: V=1.034934, theta=20.694892 -> V=1.0, theta=0.0
% INFO    : Bus 10188	: V=1.030469, theta=33.297086 -> V=1.0, theta=0.0
% INFO    : Bus 10189	: V=0.981597, theta=1.798554 -> V=1.0, theta=0.0
% INFO    : Bus 10190	: V=0.994035, theta=-3.862533 -> V=1.0, theta=0.0
% INFO    : Bus 10191	: V=0.925713, theta=-12.097092 -> V=1.0, theta=0.0
% INFO    : Bus 10192	: V=1.059619, theta=48.79156 -> V=1.0, theta=0.0
% INFO    : Bus 10193	: V=1.033897, theta=9.294569 -> V=1.0, theta=0.0
% INFO    : Bus 10194	: V=1.048908, theta=44.904436 -> V=1.0, theta=0.0
% INFO    : Bus 10195	: V=1.048908, theta=44.904436 -> V=1.0, theta=0.0
% INFO    : Bus 10196	: V=1.03659, theta=27.548145 -> V=1.0, theta=0.0
% INFO    : Bus 10197	: V=1.052604, theta=52.245403 -> V=1.0, theta=0.0
% INFO    : Bus 10198	: V=1.052604, theta=52.245403 -> V=1.0, theta=0.0
% INFO    : Bus 10199	: V=1.006354, theta=16.054798 -> V=1.0, theta=0.0
% INFO    : Bus 10200	: V=0.996074, theta=40.620445 -> V=1.0, theta=0.0
% INFO    : Bus 10201	: V=1.043753, theta=9.584078 -> V=1.0, theta=0.0
% INFO    : Bus 10202	: V=1.043753, theta=9.584078 -> V=1.0, theta=0.0
% INFO    : Bus 10203	: V=1.000061, theta=30.564736 -> V=1.0, theta=0.0
% INFO    : Bus 10204	: V=1.034597, theta=8.187737 -> V=1.0, theta=0.0
% INFO    : Bus 10205	: V=1.087147, theta=63.648812 -> V=1.0, theta=0.0
% INFO    : Bus 10206	: V=1.004349, theta=-20.93293 -> V=1.0, theta=0.0
% INFO    : Bus 10207	: V=1.014965, theta=-26.867436 -> V=1.0, theta=0.0
% INFO    : Bus 10208	: V=1.027154, theta=79.001432 -> V=1.0, theta=0.0
% INFO    : Bus 10209	: V=1.020951, theta=30.196596 -> V=1.0, theta=0.0
% INFO    : Bus 10210	: V=1.04659, theta=30.049071 -> V=1.0, theta=0.0
% INFO    : Bus 10211	: V=0.979798, theta=33.852101 -> V=1.0, theta=0.0
% INFO    : Bus 10212	: V=0.954713, theta=-7.719623 -> V=1.0, theta=0.0
% INFO    : Bus 10213	: V=0.997519, theta=-11.087305 -> V=1.0, theta=0.0
% INFO    : Bus 10214	: V=1.036388, theta=5.802341 -> V=1.0, theta=0.0
% INFO    : Bus 10215	: V=0.957608, theta=-1.330355 -> V=1.0, theta=0.0
% INFO    : Bus 10216	: V=0.994006, theta=-8.864006 -> V=1.0, theta=0.0
% INFO    : Bus 10217	: V=1.03253, theta=19.967515 -> V=1.0, theta=0.0
% INFO    : Bus 10218	: V=1.042184, theta=0.453797 -> V=1.0, theta=0.0
% INFO    : Bus 10219	: V=1.068014, theta=62.182795 -> V=1.0, theta=0.0
% INFO    : Bus 10220	: V=1.010311, theta=-13.538958 -> V=1.0, theta=0.0
% INFO    : Bus 10221	: V=1.020205, theta=30.212831 -> V=1.0, theta=0.0
% INFO    : Bus 10222	: V=1.008414, theta=-5.891971 -> V=1.0, theta=0.0
% INFO    : Bus 10223	: V=1.011478, theta=-0.639289 -> V=1.0, theta=0.0
% INFO    : Bus 10224	: V=1.049709, theta=35.041807 -> V=1.0, theta=0.0
% INFO    : Bus 10225	: V=0.994316, theta=21.023844 -> V=1.0, theta=0.0
% INFO    : Bus 10226	: V=1.009689, theta=30.943205 -> V=1.0, theta=0.0
% INFO    : Bus 10227	: V=1.063548, theta=7.183251 -> V=1.0, theta=0.0
% INFO    : Bus 10228	: V=0.979022, theta=-3.295551 -> V=1.0, theta=0.0
% INFO    : Bus 10229	: V=0.987981, theta=35.791209 -> V=1.0, theta=0.0
% INFO    : Bus 10230	: V=1.015815, theta=-14.527358 -> V=1.0, theta=0.0
% INFO    : Bus 10231	: V=1.016353, theta=6.24117 -> V=1.0, theta=0.0
% INFO    : Bus 10232	: V=1.059543, theta=4.22325 -> V=1.0, theta=0.0
% INFO    : Bus 10233	: V=0.985117, theta=-3.673542 -> V=1.0, theta=0.0
% INFO    : Bus 10234	: V=1.000945, theta=0.457571 -> V=1.0, theta=0.0
% INFO    : Bus 10235	: V=1.032403, theta=79.8948 -> V=1.0, theta=0.0
% INFO    : Bus 10236	: V=1.00571, theta=1.688469 -> V=1.0, theta=0.0
% INFO    : Bus 10237	: V=1.008736, theta=24.556899 -> V=1.0, theta=0.0
% INFO    : Bus 10238	: V=0.99879, theta=3.61899 -> V=1.0, theta=0.0
% INFO    : Bus 10239	: V=0.989503, theta=7.040273 -> V=1.0, theta=0.0
% INFO    : Bus 10240	: V=1.019574, theta=-2.005894 -> V=1.0, theta=0.0
% INFO    : Bus 10241	: V=1.017394, theta=1.999553 -> V=1.0, theta=0.0
% INFO    : Bus 10242	: V=1.017394, theta=1.999553 -> V=1.0, theta=0.0
% INFO    : Bus 10243	: V=1.009077, theta=33.192465 -> V=1.0, theta=0.0
% INFO    : Bus 10244	: V=0.9962, theta=13.133301 -> V=1.0, theta=0.0
% INFO    : Bus 10245	: V=1.025394, theta=37.285169 -> V=1.0, theta=0.0
% INFO    : Bus 10246	: V=1.024572, theta=-13.995277 -> V=1.0, theta=0.0
% INFO    : Bus 10247	: V=0.990947, theta=88.845295 -> V=1.0, theta=0.0
% INFO    : Bus 10248	: V=1.013093, theta=34.914411 -> V=1.0, theta=0.0
% INFO    : Bus 10249	: V=1.050901, theta=18.201002 -> V=1.0, theta=0.0
% INFO    : Bus 10250	: V=1.050579, theta=35.320834 -> V=1.0, theta=0.0
% INFO    : Bus 10251	: V=1.051255, theta=28.233713 -> V=1.0, theta=0.0
% INFO    : Bus 10252	: V=1.048361, theta=-3.801602 -> V=1.0, theta=0.0
% INFO    : Bus 10253	: V=1.055981, theta=85.333831 -> V=1.0, theta=0.0
% INFO    : Bus 10254	: V=1.055981, theta=85.333831 -> V=1.0, theta=0.0
% INFO    : Bus 10255	: V=0.97789, theta=-11.444181 -> V=1.0, theta=0.0
% INFO    : Bus 10256	: V=1.058657, theta=5.689686 -> V=1.0, theta=0.0
% INFO    : Bus 10257	: V=1.095813, theta=7.157977 -> V=1.0, theta=0.0
% INFO    : Bus 10258	: V=1.030172, theta=4.037839 -> V=1.0, theta=0.0
% INFO    : Bus 10259	: V=0.987249, theta=19.471878 -> V=1.0, theta=0.0
% INFO    : Bus 10260	: V=0.990413, theta=12.1358 -> V=1.0, theta=0.0
% INFO    : Bus 10261	: V=1.024702, theta=-2.505392 -> V=1.0, theta=0.0
% INFO    : Bus 10262	: V=0.963231, theta=-9.827573 -> V=1.0, theta=0.0
% INFO    : Bus 10263	: V=1.022401, theta=-10.668986 -> V=1.0, theta=0.0
% INFO    : Bus 10264	: V=1.028604, theta=-12.690591 -> V=1.0, theta=0.0
% INFO    : Bus 10265	: V=0.995455, theta=35.464296 -> V=1.0, theta=0.0
% INFO    : Bus 10266	: V=0.976287, theta=33.683826 -> V=1.0, theta=0.0
% INFO    : Bus 10267	: V=1.04126, theta=77.085737 -> V=1.0, theta=0.0
% INFO    : Bus 10268	: V=1.04126, theta=77.085737 -> V=1.0, theta=0.0
% INFO    : Bus 10269	: V=1.041091, theta=75.637106 -> V=1.0, theta=0.0
% INFO    : Bus 10270	: V=1.041091, theta=75.637106 -> V=1.0, theta=0.0
% INFO    : Bus 10271	: V=1.019358, theta=40.783179 -> V=1.0, theta=0.0
% INFO    : Bus 10272	: V=1.035344, theta=-9.440561 -> V=1.0, theta=0.0
% INFO    : Bus 10273	: V=1.035769, theta=30.299859 -> V=1.0, theta=0.0
% INFO    : Bus 10274	: V=1.003251, theta=19.398693 -> V=1.0, theta=0.0
% INFO    : Bus 10275	: V=1.006461, theta=-4.530383 -> V=1.0, theta=0.0
% INFO    : Bus 10276	: V=0.943602, theta=40.868468 -> V=1.0, theta=0.0
% INFO    : Bus 10277	: V=1.002743, theta=2.439835 -> V=1.0, theta=0.0
% INFO    : Bus 10278	: V=1.09625, theta=2.009539 -> V=1.0, theta=0.0
% INFO    : Bus 10279	: V=0.993457, theta=-9.311514 -> V=1.0, theta=0.0
% INFO    : Bus 10280	: V=1.008306, theta=49.448109 -> V=1.0, theta=0.0
% INFO    : Bus 10281	: V=1.014364, theta=-5.03166 -> V=1.0, theta=0.0
% INFO    : Bus 10282	: V=1.035329, theta=16.816351 -> V=1.0, theta=0.0
% INFO    : Bus 10283	: V=1.014154, theta=-7.89767 -> V=1.0, theta=0.0
% INFO    : Bus 10284	: V=0.978318, theta=-28.587274 -> V=1.0, theta=0.0
% INFO    : Bus 10285	: V=1.00107, theta=32.866746 -> V=1.0, theta=0.0
% INFO    : Bus 10286	: V=1.003423, theta=-8.957484 -> V=1.0, theta=0.0
% INFO    : Bus 10287	: V=1.010115, theta=96.580077 -> V=1.0, theta=0.0
% INFO    : Bus 10288	: V=1.010918, theta=16.282898 -> V=1.0, theta=0.0
% INFO    : Bus 10289	: V=1.001807, theta=-5.363974 -> V=1.0, theta=0.0
% INFO    : Bus 10290	: V=1.09297, theta=-3.415131 -> V=1.0, theta=0.0
% INFO    : Bus 10291	: V=1.004793, theta=-14.589756 -> V=1.0, theta=0.0
% INFO    : Bus 10292	: V=1.04987, theta=-0.490168 -> V=1.0, theta=0.0
% INFO    : Bus 10293	: V=1.018221, theta=7.924863 -> V=1.0, theta=0.0
% INFO    : Bus 10294	: V=0.969274, theta=14.532451 -> V=1.0, theta=0.0
% INFO    : Bus 10295	: V=1.003014, theta=30.196256 -> V=1.0, theta=0.0
% INFO    : Bus 10296	: V=1.014051, theta=2.972553 -> V=1.0, theta=0.0
% INFO    : Bus 10297	: V=1.09824, theta=-4.476134 -> V=1.0, theta=0.0
% INFO    : Bus 10298	: V=0.935194, theta=31.202294 -> V=1.0, theta=0.0
% INFO    : Bus 10299	: V=1.023849, theta=8.252664 -> V=1.0, theta=0.0
% INFO    : Bus 10300	: V=1.009017, theta=-1.484532 -> V=1.0, theta=0.0
% INFO    : Bus 10301	: V=1.036288, theta=14.771989 -> V=1.0, theta=0.0
% INFO    : Bus 10302	: V=1.016385, theta=22.987603 -> V=1.0, theta=0.0
% INFO    : Bus 10303	: V=1.033317, theta=9.058139 -> V=1.0, theta=0.0
% INFO    : Bus 10304	: V=1.013444, theta=32.585317 -> V=1.0, theta=0.0
% INFO    : Bus 10305	: V=1.009653, theta=27.767279 -> V=1.0, theta=0.0
% INFO    : Bus 10306	: V=1.033281, theta=25.592347 -> V=1.0, theta=0.0
% INFO    : Bus 10307	: V=1.012491, theta=-5.726948 -> V=1.0, theta=0.0
% INFO    : Bus 10308	: V=1.037198, theta=14.833926 -> V=1.0, theta=0.0
% INFO    : Bus 10309	: V=1.001779, theta=27.441266 -> V=1.0, theta=0.0
% INFO    : Bus 10310	: V=1.05522, theta=37.830617 -> V=1.0, theta=0.0
% INFO    : Bus 10311	: V=1.052378, theta=80.413565 -> V=1.0, theta=0.0
% INFO    : Bus 10312	: V=1.05303, theta=-11.87903 -> V=1.0, theta=0.0
% INFO    : Bus 10313	: V=1.011702, theta=30.813924 -> V=1.0, theta=0.0
% INFO    : Bus 10314	: V=0.996509, theta=34.480354 -> V=1.0, theta=0.0
% INFO    : Bus 10315	: V=1.018631, theta=-11.528817 -> V=1.0, theta=0.0
% INFO    : Bus 10316	: V=1.01557, theta=17.067482 -> V=1.0, theta=0.0
% INFO    : Bus 10317	: V=1.019745, theta=-19.936916 -> V=1.0, theta=0.0
% INFO    : Bus 10318	: V=1.01529, theta=6.788901 -> V=1.0, theta=0.0
% INFO    : Bus 10319	: V=1.040656, theta=-3.583822 -> V=1.0, theta=0.0
% INFO    : Bus 10320	: V=1.061637, theta=11.080165 -> V=1.0, theta=0.0
% INFO    : Bus 10321	: V=1.018706, theta=-19.205323 -> V=1.0, theta=0.0
% INFO    : Bus 10322	: V=1.021753, theta=-15.894846 -> V=1.0, theta=0.0
% INFO    : Bus 10323	: V=1.026148, theta=5.975825 -> V=1.0, theta=0.0
% INFO    : Bus 10324	: V=1.058149, theta=41.053759 -> V=1.0, theta=0.0
% INFO    : Bus 10325	: V=1.018895, theta=-9.219198 -> V=1.0, theta=0.0
% INFO    : Bus 10326	: V=0.954248, theta=-5.118194 -> V=1.0, theta=0.0
% INFO    : Bus 10327	: V=1.054552, theta=17.252723 -> V=1.0, theta=0.0
% INFO    : Bus 10328	: V=1.053529, theta=75.167292 -> V=1.0, theta=0.0
% INFO    : Bus 10329	: V=1.058149, theta=41.053759 -> V=1.0, theta=0.0
% INFO    : Bus 10330	: V=1.052406, theta=15.378216 -> V=1.0, theta=0.0
% INFO    : Bus 10331	: V=1.022138, theta=15.571452 -> V=1.0, theta=0.0
% INFO    : Bus 10332	: V=1.048184, theta=29.187518 -> V=1.0, theta=0.0
% INFO    : Bus 10333	: V=0.997862, theta=-7.341464 -> V=1.0, theta=0.0
% INFO    : Bus 10334	: V=0.996879, theta=-10.051669 -> V=1.0, theta=0.0
% INFO    : Bus 10335	: V=1.062527, theta=90.470423 -> V=1.0, theta=0.0
% INFO    : Bus 10336	: V=1.026118, theta=35.20302 -> V=1.0, theta=0.0
% INFO    : Bus 10337	: V=1.019549, theta=96.321283 -> V=1.0, theta=0.0
% INFO    : Bus 10338	: V=1.046953, theta=57.054821 -> V=1.0, theta=0.0
% INFO    : Bus 10339	: V=1.041748, theta=29.3468 -> V=1.0, theta=0.0
% INFO    : Bus 10340	: V=1.019083, theta=-15.334385 -> V=1.0, theta=0.0
% INFO    : Bus 10341	: V=1.024571, theta=19.065775 -> V=1.0, theta=0.0
% INFO    : Bus 10342	: V=1.014006, theta=-4.787416 -> V=1.0, theta=0.0
% INFO    : Bus 10343	: V=1.02039, theta=94.325798 -> V=1.0, theta=0.0
% INFO    : Bus 10344	: V=1.014212, theta=-8.402985 -> V=1.0, theta=0.0
% INFO    : Bus 10345	: V=1.024295, theta=-24.350579 -> V=1.0, theta=0.0
% INFO    : Bus 10346	: V=1.012238, theta=7.437218 -> V=1.0, theta=0.0
% INFO    : Bus 10347	: V=1.046748, theta=-10.254125 -> V=1.0, theta=0.0
% INFO    : Bus 10348	: V=1.006137, theta=-0.690843 -> V=1.0, theta=0.0
% INFO    : Bus 10349	: V=1.014264, theta=20.268969 -> V=1.0, theta=0.0
% INFO    : Bus 10350	: V=0.983108, theta=25.395341 -> V=1.0, theta=0.0
% INFO    : Bus 10351	: V=0.962955, theta=20.095211 -> V=1.0, theta=0.0
% INFO    : Bus 10352	: V=1.035838, theta=-5.172678 -> V=1.0, theta=0.0
% INFO    : Bus 10353	: V=1.03465, theta=-0.98238 -> V=1.0, theta=0.0
% INFO    : Bus 10354	: V=1.052483, theta=35.961266 -> V=1.0, theta=0.0
% INFO    : Bus 10355	: V=1.056125, theta=27.444238 -> V=1.0, theta=0.0
% INFO    : Bus 10356	: V=0.997086, theta=-13.477822 -> V=1.0, theta=0.0
% INFO    : Bus 10357	: V=1.058355, theta=41.76159 -> V=1.0, theta=0.0
% INFO    : Bus 10358	: V=1.033029, theta=15.551902 -> V=1.0, theta=0.0
% INFO    : Bus 10359	: V=0.975691, theta=-10.350743 -> V=1.0, theta=0.0
% INFO    : Bus 10360	: V=1.053457, theta=38.488901 -> V=1.0, theta=0.0
% INFO    : Bus 10361	: V=1.020123, theta=-10.115022 -> V=1.0, theta=0.0
% INFO    : Bus 10362	: V=0.992211, theta=93.728319 -> V=1.0, theta=0.0
% INFO    : Bus 10363	: V=1.006137, theta=-0.690843 -> V=1.0, theta=0.0
% INFO    : Bus 10364	: V=1.020444, theta=-7.003967 -> V=1.0, theta=0.0
% INFO    : Bus 10365	: V=0.996564, theta=21.128006 -> V=1.0, theta=0.0
% INFO    : Bus 10366	: V=1.057947, theta=29.561246 -> V=1.0, theta=0.0
% INFO    : Bus 10367	: V=1.035619, theta=60.598709 -> V=1.0, theta=0.0
% INFO    : Bus 10368	: V=0.992945, theta=23.548377 -> V=1.0, theta=0.0
% INFO    : Bus 10369	: V=0.973171, theta=26.287986 -> V=1.0, theta=0.0
% INFO    : Bus 10370	: V=1.022683, theta=-8.218139 -> V=1.0, theta=0.0
% INFO    : Bus 10371	: V=1.054139, theta=-12.955601 -> V=1.0, theta=0.0
% INFO    : Bus 10372	: V=1.022566, theta=32.312225 -> V=1.0, theta=0.0
% INFO    : Bus 10373	: V=1.029653, theta=5.192863 -> V=1.0, theta=0.0
% INFO    : Bus 10374	: V=1.022804, theta=17.173209 -> V=1.0, theta=0.0
% INFO    : Bus 10375	: V=1.022804, theta=17.173209 -> V=1.0, theta=0.0
% INFO    : Bus 10376	: V=0.927975, theta=33.115277 -> V=1.0, theta=0.0
% INFO    : Bus 10377	: V=1.027231, theta=14.312058 -> V=1.0, theta=0.0
% INFO    : Bus 10378	: V=1.027231, theta=14.312058 -> V=1.0, theta=0.0
% INFO    : Bus 10379	: V=1.014621, theta=63.360606 -> V=1.0, theta=0.0
% INFO    : Bus 10380	: V=0.971722, theta=-11.45905 -> V=1.0, theta=0.0
% INFO    : Bus 10381	: V=1.051356, theta=-0.511838 -> V=1.0, theta=0.0
% INFO    : Bus 10382	: V=1.019966, theta=29.105238 -> V=1.0, theta=0.0
% INFO    : Bus 10383	: V=1.001192, theta=1.338221 -> V=1.0, theta=0.0
% INFO    : Bus 10384	: V=1.045359, theta=10.101302 -> V=1.0, theta=0.0
% INFO    : Bus 10385	: V=0.949279, theta=-0.499054 -> V=1.0, theta=0.0
% INFO    : Bus 10386	: V=1.024669, theta=12.739456 -> V=1.0, theta=0.0
% INFO    : Bus 10387	: V=1.065095, theta=-6.236122 -> V=1.0, theta=0.0
% INFO    : Bus 10388	: V=1.034464, theta=34.885068 -> V=1.0, theta=0.0
% INFO    : Bus 10389	: V=1.08082, theta=-3.765935 -> V=1.0, theta=0.0
% INFO    : Bus 10390	: V=1.058213, theta=27.963025 -> V=1.0, theta=0.0
% INFO    : Bus 10391	: V=1.018502, theta=21.645619 -> V=1.0, theta=0.0
% INFO    : Bus 10392	: V=0.998615, theta=-13.124885 -> V=1.0, theta=0.0
% INFO    : Bus 10393	: V=0.971541, theta=5.051864 -> V=1.0, theta=0.0
% INFO    : Bus 10394	: V=1.020311, theta=-14.530379 -> V=1.0, theta=0.0
% INFO    : Bus 10395	: V=1.011667, theta=-13.100581 -> V=1.0, theta=0.0
% INFO    : Bus 10396	: V=1.045532, theta=-3.335566 -> V=1.0, theta=0.0
% INFO    : Bus 10397	: V=1.030037, theta=17.642709 -> V=1.0, theta=0.0
% INFO    : Bus 10398	: V=1.087045, theta=31.959882 -> V=1.0, theta=0.0
% INFO    : Bus 10399	: V=1.05128, theta=2.217499 -> V=1.0, theta=0.0
% INFO    : Bus 10400	: V=1.008407, theta=28.740661 -> V=1.0, theta=0.0
% INFO    : Bus 10401	: V=1.029941, theta=-14.211447 -> V=1.0, theta=0.0
% INFO    : Bus 10402	: V=1.029941, theta=-14.211447 -> V=1.0, theta=0.0
% INFO    : Bus 10403	: V=0.996631, theta=4.042487 -> V=1.0, theta=0.0
% INFO    : Bus 10404	: V=1.029941, theta=-14.211447 -> V=1.0, theta=0.0
% INFO    : Bus 10405	: V=1.029941, theta=-14.211447 -> V=1.0, theta=0.0
% INFO    : Bus 10406	: V=1.04163, theta=29.614847 -> V=1.0, theta=0.0
% INFO    : Bus 10407	: V=1.056158, theta=27.931459 -> V=1.0, theta=0.0
% INFO    : Bus 10408	: V=1.042166, theta=-4.652525 -> V=1.0, theta=0.0
% INFO    : Bus 10409	: V=1.012872, theta=19.301017 -> V=1.0, theta=0.0
% INFO    : Bus 10410	: V=1.034215, theta=9.728222 -> V=1.0, theta=0.0
% INFO    : Bus 10411	: V=0.996493, theta=12.979776 -> V=1.0, theta=0.0
% INFO    : Bus 10412	: V=0.972849, theta=9.043882 -> V=1.0, theta=0.0
% INFO    : Bus 10413	: V=1.068439, theta=10.944825 -> V=1.0, theta=0.0
% INFO    : Bus 10414	: V=1.063742, theta=1.726953 -> V=1.0, theta=0.0
% INFO    : Bus 10415	: V=1.126602, theta=-0.385846 -> V=1.0, theta=0.0
% INFO    : Bus 10416	: V=1.04632, theta=32.563114 -> V=1.0, theta=0.0
% INFO    : Bus 10417	: V=1.002675, theta=8.668171 -> V=1.0, theta=0.0
% INFO    : Bus 10418	: V=1.0326, theta=4.106738 -> V=1.0, theta=0.0
% INFO    : Bus 10419	: V=0.998209, theta=-5.886993 -> V=1.0, theta=0.0
% INFO    : Bus 10420	: V=1.035607, theta=16.604846 -> V=1.0, theta=0.0
% INFO    : Bus 10421	: V=0.993109, theta=-2.156818 -> V=1.0, theta=0.0
% INFO    : Bus 10422	: V=1.039546, theta=19.356134 -> V=1.0, theta=0.0
% INFO    : Bus 10423	: V=1.020956, theta=21.259248 -> V=1.0, theta=0.0
% INFO    : Bus 10424	: V=1.010169, theta=13.76329 -> V=1.0, theta=0.0
% INFO    : Bus 10425	: V=1.010169, theta=13.76329 -> V=1.0, theta=0.0
% INFO    : Bus 10426	: V=1.015046, theta=18.361995 -> V=1.0, theta=0.0
% INFO    : Bus 10427	: V=1.015046, theta=18.361995 -> V=1.0, theta=0.0
% INFO    : Bus 10428	: V=1.046548, theta=6.871525 -> V=1.0, theta=0.0
% INFO    : Bus 10429	: V=1.010169, theta=13.76329 -> V=1.0, theta=0.0
% INFO    : Bus 10430	: V=1.010169, theta=13.76329 -> V=1.0, theta=0.0
% INFO    : Bus 10431	: V=1.048057, theta=30.057407 -> V=1.0, theta=0.0
% INFO    : Bus 10432	: V=0.998217, theta=13.335097 -> V=1.0, theta=0.0
% INFO    : Bus 10433	: V=0.997543, theta=24.058125 -> V=1.0, theta=0.0
% INFO    : Bus 10434	: V=1.029635, theta=34.5439 -> V=1.0, theta=0.0
% INFO    : Bus 10435	: V=1.029635, theta=34.5439 -> V=1.0, theta=0.0
% INFO    : Bus 10436	: V=0.997985, theta=14.815692 -> V=1.0, theta=0.0
% INFO    : Bus 10437	: V=1.042028, theta=12.694917 -> V=1.0, theta=0.0
% INFO    : Bus 10438	: V=1.042028, theta=12.694917 -> V=1.0, theta=0.0
% INFO    : Bus 10439	: V=0.998217, theta=13.335097 -> V=1.0, theta=0.0
% INFO    : Bus 10440	: V=1.017812, theta=-8.584974 -> V=1.0, theta=0.0
% INFO    : Bus 10441	: V=1.00604, theta=24.82908 -> V=1.0, theta=0.0
% INFO    : Bus 10442	: V=1.041381, theta=77.156696 -> V=1.0, theta=0.0
% INFO    : Bus 10443	: V=1.038225, theta=16.178789 -> V=1.0, theta=0.0
% INFO    : Bus 10444	: V=1.008987, theta=13.241803 -> V=1.0, theta=0.0
% INFO    : Bus 10445	: V=1.014379, theta=-16.62541 -> V=1.0, theta=0.0
% INFO    : Bus 10446	: V=1.011732, theta=16.560007 -> V=1.0, theta=0.0
% INFO    : Bus 10447	: V=1.044747, theta=17.319249 -> V=1.0, theta=0.0
% INFO    : Bus 10448	: V=1.044129, theta=-4.738961 -> V=1.0, theta=0.0
% INFO    : Bus 10449	: V=1.008104, theta=35.763493 -> V=1.0, theta=0.0
% INFO    : Bus 10450	: V=1.013812, theta=-18.422761 -> V=1.0, theta=0.0
% INFO    : Bus 10451	: V=1.020135, theta=22.317919 -> V=1.0, theta=0.0
% INFO    : Bus 10452	: V=1.014607, theta=15.799125 -> V=1.0, theta=0.0
% INFO    : Bus 10453	: V=0.994929, theta=92.815452 -> V=1.0, theta=0.0
% INFO    : Bus 10454	: V=1.049983, theta=5.255239 -> V=1.0, theta=0.0
% INFO    : Bus 10455	: V=1.015763, theta=-26.684165 -> V=1.0, theta=0.0
% INFO    : Bus 10456	: V=1.009038, theta=19.41053 -> V=1.0, theta=0.0
% INFO    : Bus 10457	: V=1.011409, theta=27.376862 -> V=1.0, theta=0.0
% INFO    : Bus 10458	: V=1.031857, theta=-4.668184 -> V=1.0, theta=0.0
% INFO    : Bus 10459	: V=0.989404, theta=-3.967336 -> V=1.0, theta=0.0
% INFO    : Bus 10460	: V=0.974543, theta=-8.287979 -> V=1.0, theta=0.0
% INFO    : Bus 10461	: V=1.035338, theta=-7.144697 -> V=1.0, theta=0.0
% INFO    : Bus 10462	: V=1.035338, theta=-7.144697 -> V=1.0, theta=0.0
% INFO    : Bus 10463	: V=1.021625, theta=18.08826 -> V=1.0, theta=0.0
% INFO    : Bus 10464	: V=1.022503, theta=-30.8059 -> V=1.0, theta=0.0
% INFO    : Bus 10465	: V=1.098505, theta=65.011053 -> V=1.0, theta=0.0
% INFO    : Bus 10466	: V=1.008964, theta=6.659925 -> V=1.0, theta=0.0
% INFO    : Bus 10467	: V=1.023901, theta=2.236436 -> V=1.0, theta=0.0
% INFO    : Bus 10468	: V=1.028121, theta=7.01221 -> V=1.0, theta=0.0
% INFO    : Bus 10469	: V=1.021005, theta=21.987746 -> V=1.0, theta=0.0
% INFO    : Bus 10470	: V=1.044747, theta=17.319249 -> V=1.0, theta=0.0
% INFO    : Bus 10471	: V=1.038898, theta=6.306789 -> V=1.0, theta=0.0
% INFO    : Bus 10472	: V=1.061235, theta=43.554839 -> V=1.0, theta=0.0
% INFO    : Bus 10473	: V=0.962508, theta=28.579218 -> V=1.0, theta=0.0
% INFO    : Bus 10474	: V=1.061235, theta=43.554839 -> V=1.0, theta=0.0
% INFO    : Bus 10475	: V=1.061235, theta=43.554839 -> V=1.0, theta=0.0
% INFO    : Bus 10476	: V=1.061235, theta=43.554839 -> V=1.0, theta=0.0
% INFO    : Bus 10477	: V=1.033645, theta=-10.792881 -> V=1.0, theta=0.0
% INFO    : Bus 10478	: V=1.070343, theta=-2.942936 -> V=1.0, theta=0.0
% INFO    : Bus 10479	: V=1.060605, theta=43.468335 -> V=1.0, theta=0.0
% INFO    : Bus 10480	: V=1.060605, theta=43.468335 -> V=1.0, theta=0.0
% INFO    : Bus 10481	: V=1.033317, theta=28.755712 -> V=1.0, theta=0.0
% INFO    : Bus 10482	: V=0.986425, theta=-8.184485 -> V=1.0, theta=0.0
% INFO    : Bus 10483	: V=1.024181, theta=-13.991173 -> V=1.0, theta=0.0
% INFO    : Bus 10484	: V=1.024181, theta=-13.991173 -> V=1.0, theta=0.0
% INFO    : Bus 10485	: V=1.001889, theta=12.056714 -> V=1.0, theta=0.0
% INFO    : Bus 10486	: V=1.024181, theta=-13.991173 -> V=1.0, theta=0.0
% INFO    : Bus 10487	: V=0.983472, theta=31.050625 -> V=1.0, theta=0.0
% INFO    : Bus 10488	: V=1.031942, theta=-8.549229 -> V=1.0, theta=0.0
% INFO    : Bus 10489	: V=1.031942, theta=-8.549229 -> V=1.0, theta=0.0
% INFO    : Bus 10490	: V=0.962065, theta=32.684828 -> V=1.0, theta=0.0
% INFO    : Bus 10491	: V=1.039235, theta=34.339114 -> V=1.0, theta=0.0
% INFO    : Bus 10492	: V=1.018124, theta=25.300043 -> V=1.0, theta=0.0
% INFO    : Bus 10493	: V=1.0002, theta=34.065331 -> V=1.0, theta=0.0
% INFO    : Bus 10494	: V=1.022296, theta=15.568947 -> V=1.0, theta=0.0
% INFO    : Bus 10495	: V=1.022369, theta=-10.670954 -> V=1.0, theta=0.0
% INFO    : Bus 10496	: V=1.001607, theta=28.753258 -> V=1.0, theta=0.0
% INFO    : Bus 10497	: V=1.043292, theta=-5.133111 -> V=1.0, theta=0.0
% INFO    : Bus 10498	: V=1.000583, theta=-4.148606 -> V=1.0, theta=0.0
% INFO    : Bus 10499	: V=0.987679, theta=-2.410947 -> V=1.0, theta=0.0
% INFO    : Bus 10500	: V=0.943691, theta=-8.960229 -> V=1.0, theta=0.0
% INFO    : Bus 10501	: V=0.993105, theta=34.379244 -> V=1.0, theta=0.0
% INFO    : Bus 10502	: V=1.096229, theta=69.590629 -> V=1.0, theta=0.0
% INFO    : Bus 10503	: V=1.046045, theta=21.235676 -> V=1.0, theta=0.0
% INFO    : Bus 10504	: V=1.023031, theta=8.747727 -> V=1.0, theta=0.0
% INFO    : Bus 10505	: V=1.058114, theta=43.382414 -> V=1.0, theta=0.0
% INFO    : Bus 10506	: V=1.023916, theta=-20.729397 -> V=1.0, theta=0.0
% INFO    : Bus 10507	: V=1.016731, theta=-10.513954 -> V=1.0, theta=0.0
% INFO    : Bus 10508	: V=1.009642, theta=-17.065869 -> V=1.0, theta=0.0
% INFO    : Bus 10509	: V=1.010487, theta=-18.296961 -> V=1.0, theta=0.0
% INFO    : Bus 10510	: V=1.010487, theta=-18.296961 -> V=1.0, theta=0.0
% INFO    : Bus 10511	: V=1.011931, theta=29.719396 -> V=1.0, theta=0.0
% INFO    : Bus 10512	: V=1.017479, theta=-21.662554 -> V=1.0, theta=0.0
% INFO    : Bus 10513	: V=1.015995, theta=27.945435 -> V=1.0, theta=0.0
% INFO    : Bus 10514	: V=1.011219, theta=48.828665 -> V=1.0, theta=0.0
% INFO    : Bus 10515	: V=1.026552, theta=0.558438 -> V=1.0, theta=0.0
% INFO    : Bus 10516	: V=1.023287, theta=-16.294788 -> V=1.0, theta=0.0
% INFO    : Bus 10517	: V=0.996447, theta=-9.896793 -> V=1.0, theta=0.0
% INFO    : Bus 10518	: V=0.999015, theta=14.71774 -> V=1.0, theta=0.0
% INFO    : Bus 10519	: V=0.986622, theta=-5.371359 -> V=1.0, theta=0.0
% INFO    : Bus 10520	: V=1.039787, theta=-14.573329 -> V=1.0, theta=0.0
% INFO    : Bus 10521	: V=1.031898, theta=-9.317211 -> V=1.0, theta=0.0
% INFO    : Bus 10522	: V=1.031898, theta=-9.317211 -> V=1.0, theta=0.0
% INFO    : Bus 10523	: V=0.969715, theta=27.552049 -> V=1.0, theta=0.0
% INFO    : Bus 10524	: V=1.047212, theta=-3.686325 -> V=1.0, theta=0.0
% INFO    : Bus 10525	: V=0.999054, theta=-14.356299 -> V=1.0, theta=0.0
% INFO    : Bus 10526	: V=1.081283, theta=24.107685 -> V=1.0, theta=0.0
% INFO    : Bus 10527	: V=1.029166, theta=13.522836 -> V=1.0, theta=0.0
% INFO    : Bus 10528	: V=1.008758, theta=25.321078 -> V=1.0, theta=0.0
% INFO    : Bus 10529	: V=1.01949, theta=-6.454647 -> V=1.0, theta=0.0
% INFO    : Bus 10530	: V=1.043738, theta=28.126856 -> V=1.0, theta=0.0
% INFO    : Bus 10531	: V=0.996554, theta=-2.148476 -> V=1.0, theta=0.0
% INFO    : Bus 10532	: V=1.044115, theta=-2.191384 -> V=1.0, theta=0.0
% INFO    : Bus 10533	: V=0.990048, theta=-14.661845 -> V=1.0, theta=0.0
% INFO    : Bus 10534	: V=1.01601, theta=-0.145046 -> V=1.0, theta=0.0
% INFO    : Bus 10535	: V=1.126501, theta=-1.915268 -> V=1.0, theta=0.0
% INFO    : Bus 10536	: V=1.031886, theta=-0.395607 -> V=1.0, theta=0.0
% INFO    : Bus 10537	: V=1.019357, theta=22.943488 -> V=1.0, theta=0.0
% INFO    : Bus 10538	: V=1.019357, theta=22.943488 -> V=1.0, theta=0.0
% INFO    : Bus 10539	: V=1.009538, theta=-0.472346 -> V=1.0, theta=0.0
% INFO    : Bus 10540	: V=0.989531, theta=-9.664587 -> V=1.0, theta=0.0
% INFO    : Bus 10541	: V=1.011803, theta=30.349504 -> V=1.0, theta=0.0
% INFO    : Bus 10542	: V=0.995039, theta=-1.015237 -> V=1.0, theta=0.0
% INFO    : Bus 10543	: V=0.982939, theta=-5.438658 -> V=1.0, theta=0.0
% INFO    : Bus 10544	: V=1.014699, theta=-19.147266 -> V=1.0, theta=0.0
% INFO    : Bus 10545	: V=1.015085, theta=78.810625 -> V=1.0, theta=0.0
% INFO    : Bus 10546	: V=0.98902, theta=25.688069 -> V=1.0, theta=0.0
% INFO    : Bus 10547	: V=1.014595, theta=-27.559944 -> V=1.0, theta=0.0
% INFO    : Bus 10548	: V=1.028279, theta=-14.143423 -> V=1.0, theta=0.0
% INFO    : Bus 10549	: V=0.997397, theta=29.197028 -> V=1.0, theta=0.0
% INFO    : Bus 10550	: V=1.040624, theta=1.360588 -> V=1.0, theta=0.0
% INFO    : Bus 10551	: V=0.995284, theta=-3.635619 -> V=1.0, theta=0.0
% INFO    : Bus 10552	: V=0.993841, theta=-4.134498 -> V=1.0, theta=0.0
% INFO    : Bus 10553	: V=1.026938, theta=-11.97068 -> V=1.0, theta=0.0
% INFO    : Bus 10554	: V=1.001419, theta=42.731033 -> V=1.0, theta=0.0
% INFO    : Bus 10555	: V=1.058617, theta=17.70472 -> V=1.0, theta=0.0
% INFO    : Bus 10556	: V=1.058617, theta=17.704764 -> V=1.0, theta=0.0
% INFO    : Bus 10557	: V=0.962211, theta=47.074823 -> V=1.0, theta=0.0
% INFO    : Bus 10558	: V=1.058617, theta=17.704764 -> V=1.0, theta=0.0
% INFO    : Bus 10559	: V=1.057043, theta=-2.110383 -> V=1.0, theta=0.0
% INFO    : Bus 10560	: V=0.991924, theta=-6.64751 -> V=1.0, theta=0.0
% INFO    : Bus 10561	: V=0.970525, theta=38.020423 -> V=1.0, theta=0.0
% INFO    : Bus 10562	: V=1.025974, theta=23.061161 -> V=1.0, theta=0.0
% INFO    : Bus 10563	: V=0.986721, theta=-24.607242 -> V=1.0, theta=0.0
% INFO    : Bus 10564	: V=1.016733, theta=22.521914 -> V=1.0, theta=0.0
% INFO    : Bus 10565	: V=1.003706, theta=0.548715 -> V=1.0, theta=0.0
% INFO    : Bus 10566	: V=0.986044, theta=2.946158 -> V=1.0, theta=0.0
% INFO    : Bus 10567	: V=1.033196, theta=35.634446 -> V=1.0, theta=0.0
% INFO    : Bus 10568	: V=1.005894, theta=17.491888 -> V=1.0, theta=0.0
% INFO    : Bus 10569	: V=1.07312, theta=36.327806 -> V=1.0, theta=0.0
% INFO    : Bus 10570	: V=1.017623, theta=7.990727 -> V=1.0, theta=0.0
% INFO    : Bus 10571	: V=0.936276, theta=-8.848857 -> V=1.0, theta=0.0
% INFO    : Bus 10572	: V=0.993855, theta=48.71734 -> V=1.0, theta=0.0
% INFO    : Bus 10573	: V=1.06341, theta=18.471219 -> V=1.0, theta=0.0
% INFO    : Bus 10574	: V=1.010892, theta=6.188269 -> V=1.0, theta=0.0
% INFO    : Bus 10575	: V=1.058835, theta=5.385711 -> V=1.0, theta=0.0
% INFO    : Bus 10576	: V=1.011815, theta=23.670484 -> V=1.0, theta=0.0
% INFO    : Bus 10577	: V=0.92263, theta=-8.762423 -> V=1.0, theta=0.0
% INFO    : Bus 10578	: V=1.019245, theta=-7.81403 -> V=1.0, theta=0.0
% INFO    : Bus 10579	: V=1.07044, theta=5.391057 -> V=1.0, theta=0.0
% INFO    : Bus 10580	: V=1.003171, theta=37.39829 -> V=1.0, theta=0.0
% INFO    : Bus 10581	: V=1.03472, theta=7.897462 -> V=1.0, theta=0.0
% INFO    : Bus 10582	: V=1.012451, theta=27.828179 -> V=1.0, theta=0.0
% INFO    : Bus 10583	: V=0.997256, theta=-4.698247 -> V=1.0, theta=0.0
% INFO    : Bus 10584	: V=1.037717, theta=-0.24122 -> V=1.0, theta=0.0
% INFO    : Bus 10585	: V=1.017725, theta=15.676084 -> V=1.0, theta=0.0
% INFO    : Bus 10586	: V=0.979511, theta=26.106648 -> V=1.0, theta=0.0
% INFO    : Bus 10587	: V=1.175754, theta=3.227378 -> V=1.0, theta=0.0
% INFO    : Bus 10588	: V=1.000057, theta=26.10357 -> V=1.0, theta=0.0
% INFO    : Bus 10589	: V=1.019231, theta=22.327173 -> V=1.0, theta=0.0
% INFO    : Bus 10590	: V=0.962754, theta=-9.860801 -> V=1.0, theta=0.0
% INFO    : Bus 10591	: V=1.028915, theta=25.353044 -> V=1.0, theta=0.0
% INFO    : Bus 10592	: V=1.021257, theta=36.651298 -> V=1.0, theta=0.0
% INFO    : Bus 10593	: V=1.07537, theta=4.059371 -> V=1.0, theta=0.0
% INFO    : Bus 10594	: V=1.030072, theta=19.446825 -> V=1.0, theta=0.0
% INFO    : Bus 10595	: V=0.986497, theta=-8.940272 -> V=1.0, theta=0.0
% INFO    : Bus 10596	: V=1.035323, theta=-10.516182 -> V=1.0, theta=0.0
% INFO    : Bus 10597	: V=1.000973, theta=-13.484082 -> V=1.0, theta=0.0
% INFO    : Bus 10598	: V=0.996611, theta=21.111934 -> V=1.0, theta=0.0
% INFO    : Bus 10599	: V=0.955736, theta=-16.492467 -> V=1.0, theta=0.0
% INFO    : Bus 10600	: V=0.978181, theta=-9.34911 -> V=1.0, theta=0.0
% INFO    : Bus 10601	: V=1.002352, theta=11.816729 -> V=1.0, theta=0.0
% INFO    : Bus 10602	: V=0.981048, theta=-5.225564 -> V=1.0, theta=0.0
% INFO    : Bus 10603	: V=1.031271, theta=76.497104 -> V=1.0, theta=0.0
% INFO    : Bus 10604	: V=0.995801, theta=-13.455391 -> V=1.0, theta=0.0
% INFO    : Bus 10605	: V=1.035838, theta=-5.172678 -> V=1.0, theta=0.0
% INFO    : Bus 10606	: V=1.020452, theta=-7.005782 -> V=1.0, theta=0.0
% INFO    : Bus 10607	: V=1.012867, theta=-4.992838 -> V=1.0, theta=0.0
% INFO    : Bus 10608	: V=0.965984, theta=-7.512472 -> V=1.0, theta=0.0
% INFO    : Bus 10609	: V=0.976871, theta=21.844087 -> V=1.0, theta=0.0
% INFO    : Bus 10610	: V=0.987043, theta=33.947682 -> V=1.0, theta=0.0
% INFO    : Bus 10611	: V=0.973563, theta=-5.937481 -> V=1.0, theta=0.0
% INFO    : Bus 10612	: V=1.014542, theta=2.91424 -> V=1.0, theta=0.0
% INFO    : Bus 10613	: V=1.018329, theta=1.468316 -> V=1.0, theta=0.0
% INFO    : Bus 10614	: V=0.998681, theta=-5.302422 -> V=1.0, theta=0.0
% INFO    : Bus 10615	: V=1.012277, theta=-17.836874 -> V=1.0, theta=0.0
% INFO    : Bus 10616	: V=1.052535, theta=-6.418371 -> V=1.0, theta=0.0
% INFO    : Bus 10617	: V=1.00657, theta=25.464337 -> V=1.0, theta=0.0
% INFO    : Bus 10618	: V=1.009027, theta=2.688479 -> V=1.0, theta=0.0
% INFO    : Bus 10619	: V=1.031098, theta=31.248826 -> V=1.0, theta=0.0
% INFO    : Bus 10620	: V=1.013068, theta=-14.640825 -> V=1.0, theta=0.0
% INFO    : Bus 10621	: V=1.016891, theta=10.696134 -> V=1.0, theta=0.0
% INFO    : Bus 10622	: V=1.032126, theta=34.816975 -> V=1.0, theta=0.0
% INFO    : Bus 10623	: V=1.002425, theta=-9.120945 -> V=1.0, theta=0.0
% INFO    : Bus 10624	: V=0.954754, theta=-16.903313 -> V=1.0, theta=0.0
% INFO    : Bus 10625	: V=1.016891, theta=10.696134 -> V=1.0, theta=0.0
% INFO    : Bus 10626	: V=1.029312, theta=22.383604 -> V=1.0, theta=0.0
% INFO    : Bus 10627	: V=1.040259, theta=34.3106 -> V=1.0, theta=0.0
% INFO    : Bus 10628	: V=1.020601, theta=-17.036733 -> V=1.0, theta=0.0
% INFO    : Bus 10629	: V=1.038747, theta=-8.642337 -> V=1.0, theta=0.0
% INFO    : Bus 10630	: V=1.012281, theta=-3.154738 -> V=1.0, theta=0.0
% INFO    : Bus 10631	: V=1.026824, theta=34.117804 -> V=1.0, theta=0.0
% INFO    : Bus 10632	: V=1.00775, theta=1.043576 -> V=1.0, theta=0.0
% INFO    : Bus 10633	: V=1.043665, theta=14.930439 -> V=1.0, theta=0.0
% INFO    : Bus 10634	: V=0.995515, theta=4.358377 -> V=1.0, theta=0.0
% INFO    : Bus 10635	: V=1.047752, theta=29.881973 -> V=1.0, theta=0.0
% INFO    : Bus 10636	: V=1.036427, theta=21.464192 -> V=1.0, theta=0.0
% INFO    : Bus 10637	: V=1.019707, theta=44.368784 -> V=1.0, theta=0.0
% INFO    : Bus 10638	: V=1.049538, theta=58.287287 -> V=1.0, theta=0.0
% INFO    : Bus 10639	: V=1.034322, theta=-7.989117 -> V=1.0, theta=0.0
% INFO    : Bus 10640	: V=1.07025, theta=2.362941 -> V=1.0, theta=0.0
% INFO    : Bus 10641	: V=1.027326, theta=1.583262 -> V=1.0, theta=0.0
% INFO    : Bus 10642	: V=1.033422, theta=20.189076 -> V=1.0, theta=0.0
% INFO    : Bus 10643	: V=1.056442, theta=84.300227 -> V=1.0, theta=0.0
% INFO    : Bus 10644	: V=1.018021, theta=3.740756 -> V=1.0, theta=0.0
% INFO    : Bus 10645	: V=1.038413, theta=24.293754 -> V=1.0, theta=0.0
% INFO    : Bus 10646	: V=1.010826, theta=23.125552 -> V=1.0, theta=0.0
% INFO    : Bus 10647	: V=1.045549, theta=56.658865 -> V=1.0, theta=0.0
% INFO    : Bus 10648	: V=1.050191, theta=8.166057 -> V=1.0, theta=0.0
% INFO    : Bus 10649	: V=1.050191, theta=8.166057 -> V=1.0, theta=0.0
% INFO    : Bus 10650	: V=0.958146, theta=44.224727 -> V=1.0, theta=0.0
% INFO    : Bus 10651	: V=1.069459, theta=51.885185 -> V=1.0, theta=0.0
% INFO    : Bus 10652	: V=0.96764, theta=46.597759 -> V=1.0, theta=0.0
% INFO    : Bus 10653	: V=1.035469, theta=23.613483 -> V=1.0, theta=0.0
% INFO    : Bus 10654	: V=1.049993, theta=-2.183536 -> V=1.0, theta=0.0
% INFO    : Bus 10655	: V=1.038751, theta=-2.94006 -> V=1.0, theta=0.0
% INFO    : Bus 10656	: V=1.035773, theta=21.901715 -> V=1.0, theta=0.0
% INFO    : Bus 10657	: V=0.996408, theta=16.94258 -> V=1.0, theta=0.0
% INFO    : Bus 10658	: V=0.996408, theta=16.94258 -> V=1.0, theta=0.0
% INFO    : Bus 10659	: V=0.992675, theta=12.17578 -> V=1.0, theta=0.0
% INFO    : Bus 10660	: V=1.050191, theta=8.166057 -> V=1.0, theta=0.0
% INFO    : Bus 10661	: V=1.031908, theta=31.49392 -> V=1.0, theta=0.0
% INFO    : Bus 10662	: V=1.039231, theta=6.804049 -> V=1.0, theta=0.0
% INFO    : Bus 10663	: V=1.044343, theta=1.455005 -> V=1.0, theta=0.0
% INFO    : Bus 10664	: V=1.063137, theta=8.658596 -> V=1.0, theta=0.0
% INFO    : Bus 10665	: V=0.954782, theta=-5.432343 -> V=1.0, theta=0.0
% INFO    : Bus 10666	: V=0.965625, theta=-5.153597 -> V=1.0, theta=0.0
% INFO    : Bus 10667	: V=1.034195, theta=-0.043883 -> V=1.0, theta=0.0
% INFO    : Bus 10668	: V=1.043771, theta=22.935303 -> V=1.0, theta=0.0
% INFO    : Bus 10669	: V=1.043771, theta=22.935303 -> V=1.0, theta=0.0
% INFO    : Bus 10670	: V=1.009038, theta=19.41053 -> V=1.0, theta=0.0
% INFO    : Bus 10671	: V=1.058434, theta=6.52887 -> V=1.0, theta=0.0
% INFO    : Bus 10672	: V=1.058434, theta=6.52887 -> V=1.0, theta=0.0
% INFO    : Bus 10673	: V=0.959077, theta=36.812848 -> V=1.0, theta=0.0
% INFO    : Bus 10674	: V=1.058434, theta=6.52887 -> V=1.0, theta=0.0
% INFO    : Bus 10675	: V=1.058434, theta=6.52887 -> V=1.0, theta=0.0
% INFO    : Bus 10676	: V=1.058434, theta=6.52887 -> V=1.0, theta=0.0
% INFO    : Bus 10677	: V=1.082511, theta=-4.68964 -> V=1.0, theta=0.0
% INFO    : Bus 10678	: V=1.013602, theta=39.787074 -> V=1.0, theta=0.0
% INFO    : Bus 10679	: V=1.054397, theta=-1.085701 -> V=1.0, theta=0.0
% INFO    : Bus 10680	: V=1.046743, theta=-13.79286 -> V=1.0, theta=0.0
% INFO    : Bus 10681	: V=0.999015, theta=14.71774 -> V=1.0, theta=0.0
% INFO    : Bus 10682	: V=0.976152, theta=2.665581 -> V=1.0, theta=0.0
% INFO    : Bus 10683	: V=1.03011, theta=23.136345 -> V=1.0, theta=0.0
% INFO    : Bus 10684	: V=0.990428, theta=-1.815452 -> V=1.0, theta=0.0
% INFO    : Bus 10685	: V=1.022564, theta=-10.647834 -> V=1.0, theta=0.0
% INFO    : Bus 10686	: V=1.04661, theta=5.291874 -> V=1.0, theta=0.0
% INFO    : Bus 10687	: V=1.015797, theta=19.144387 -> V=1.0, theta=0.0
% INFO    : Bus 10688	: V=0.999929, theta=-8.815144 -> V=1.0, theta=0.0
% INFO    : Bus 10689	: V=1.022926, theta=17.060146 -> V=1.0, theta=0.0
% INFO    : Bus 10690	: V=0.999015, theta=14.71774 -> V=1.0, theta=0.0
% INFO    : Bus 10691	: V=0.989001, theta=-4.438276 -> V=1.0, theta=0.0
% INFO    : Bus 10692	: V=1.02229, theta=13.638837 -> V=1.0, theta=0.0
% INFO    : Bus 10693	: V=1.017738, theta=25.492678 -> V=1.0, theta=0.0
% INFO    : Bus 10694	: V=1.03362, theta=30.239326 -> V=1.0, theta=0.0
% INFO    : Bus 10695	: V=1.009341, theta=3.831939 -> V=1.0, theta=0.0
% INFO    : Bus 10696	: V=1.027264, theta=14.46311 -> V=1.0, theta=0.0
% INFO    : Bus 10697	: V=1.029567, theta=36.282901 -> V=1.0, theta=0.0
% INFO    : Bus 10698	: V=1.072042, theta=-2.027427 -> V=1.0, theta=0.0
% INFO    : Bus 10699	: V=1.025635, theta=80.371453 -> V=1.0, theta=0.0
% INFO    : Bus 10700	: V=0.999015, theta=14.71774 -> V=1.0, theta=0.0
% INFO    : Bus 10701	: V=0.998771, theta=-8.905049 -> V=1.0, theta=0.0
% INFO    : Bus 10702	: V=0.955457, theta=-7.69714 -> V=1.0, theta=0.0
% INFO    : Bus 10703	: V=0.99653, theta=23.710857 -> V=1.0, theta=0.0
% INFO    : Bus 10704	: V=1.013587, theta=-17.471914 -> V=1.0, theta=0.0
% INFO    : Bus 10705	: V=1.004591, theta=-4.12331 -> V=1.0, theta=0.0
% INFO    : Bus 10706	: V=1.028713, theta=30.959458 -> V=1.0, theta=0.0
% INFO    : Bus 10707	: V=0.991507, theta=-2.827643 -> V=1.0, theta=0.0
% INFO    : Bus 10708	: V=0.979788, theta=-12.77143 -> V=1.0, theta=0.0
% INFO    : Bus 10709	: V=1.04422, theta=-9.526922 -> V=1.0, theta=0.0
% INFO    : Bus 10710	: V=1.045246, theta=19.956837 -> V=1.0, theta=0.0
% INFO    : Bus 10711	: V=1.011822, theta=-19.587728 -> V=1.0, theta=0.0
% INFO    : Bus 10712	: V=1.023574, theta=3.735821 -> V=1.0, theta=0.0
% INFO    : Bus 10713	: V=1.041679, theta=-0.382764 -> V=1.0, theta=0.0
% INFO    : Bus 10714	: V=1.006499, theta=-20.670075 -> V=1.0, theta=0.0
% INFO    : Bus 10715	: V=1.043049, theta=13.489159 -> V=1.0, theta=0.0
% INFO    : Bus 10716	: V=0.995755, theta=15.594071 -> V=1.0, theta=0.0
% INFO    : Bus 10717	: V=1.133829, theta=-1.146555 -> V=1.0, theta=0.0
% INFO    : Bus 10718	: V=1.098845, theta=-1.768818 -> V=1.0, theta=0.0
% INFO    : Bus 10719	: V=1.045442, theta=-2.002576 -> V=1.0, theta=0.0
% INFO    : Bus 10720	: V=1.045442, theta=-2.002576 -> V=1.0, theta=0.0
% INFO    : Bus 10721	: V=1.041679, theta=-0.382764 -> V=1.0, theta=0.0
% INFO    : Bus 10722	: V=1.041679, theta=-0.382764 -> V=1.0, theta=0.0
% INFO    : Bus 10723	: V=1.013697, theta=-6.977467 -> V=1.0, theta=0.0
% INFO    : Bus 10724	: V=1.011827, theta=21.695682 -> V=1.0, theta=0.0
% INFO    : Bus 10725	: V=1.044784, theta=-3.156384 -> V=1.0, theta=0.0
% INFO    : Bus 10726	: V=0.982381, theta=33.01246 -> V=1.0, theta=0.0
% INFO    : Bus 10727	: V=1.058551, theta=26.994293 -> V=1.0, theta=0.0
% INFO    : Bus 10728	: V=1.02296, theta=44.620529 -> V=1.0, theta=0.0
% INFO    : Bus 10729	: V=1.017365, theta=-4.056944 -> V=1.0, theta=0.0
% INFO    : Bus 10730	: V=1.001044, theta=-2.929985 -> V=1.0, theta=0.0
% INFO    : Bus 10731	: V=0.994363, theta=17.183871 -> V=1.0, theta=0.0
% INFO    : Bus 10732	: V=0.98617, theta=-9.055253 -> V=1.0, theta=0.0
% INFO    : Bus 10733	: V=0.972246, theta=-5.618279 -> V=1.0, theta=0.0
% INFO    : Bus 10734	: V=1.022678, theta=25.196328 -> V=1.0, theta=0.0
% INFO    : Bus 10735	: V=1.024278, theta=16.341816 -> V=1.0, theta=0.0
% INFO    : Bus 10736	: V=1.030348, theta=-1.015593 -> V=1.0, theta=0.0
% INFO    : Bus 10737	: V=1.029091, theta=11.050068 -> V=1.0, theta=0.0
% INFO    : Bus 10738	: V=1.04914, theta=42.65185 -> V=1.0, theta=0.0
% INFO    : Bus 10739	: V=1.0031, theta=91.66228 -> V=1.0, theta=0.0
% INFO    : Bus 10740	: V=1.021614, theta=-4.069285 -> V=1.0, theta=0.0
% INFO    : Bus 10741	: V=1.031622, theta=-6.333057 -> V=1.0, theta=0.0
% INFO    : Bus 10742	: V=1.052378, theta=80.413565 -> V=1.0, theta=0.0
% INFO    : Bus 10743	: V=1.01964, theta=-10.829105 -> V=1.0, theta=0.0
% INFO    : Bus 10744	: V=1.163482, theta=2.07534 -> V=1.0, theta=0.0
% INFO    : Bus 10745	: V=1.018903, theta=-11.984477 -> V=1.0, theta=0.0
% INFO    : Bus 10746	: V=1.029795, theta=21.603625 -> V=1.0, theta=0.0
% INFO    : Bus 10747	: V=1.053529, theta=75.167292 -> V=1.0, theta=0.0
% INFO    : Bus 10748	: V=1.055981, theta=85.333831 -> V=1.0, theta=0.0
% INFO    : Bus 10749	: V=1.017471, theta=24.91358 -> V=1.0, theta=0.0
% INFO    : Bus 10750	: V=1.019549, theta=96.321283 -> V=1.0, theta=0.0
% INFO    : Bus 10751	: V=0.979584, theta=2.951039 -> V=1.0, theta=0.0
% INFO    : Bus 10752	: V=1.02039, theta=94.325798 -> V=1.0, theta=0.0
% INFO    : Bus 10753	: V=1.060516, theta=63.207291 -> V=1.0, theta=0.0
% INFO    : Bus 10754	: V=1.060516, theta=63.207291 -> V=1.0, theta=0.0
% INFO    : Bus 10755	: V=1.019549, theta=96.321283 -> V=1.0, theta=0.0
% INFO    : Bus 10756	: V=1.019549, theta=96.321283 -> V=1.0, theta=0.0
% INFO    : Bus 10757	: V=1.008788, theta=8.521149 -> V=1.0, theta=0.0
% INFO    : Bus 10758	: V=1.013968, theta=18.460501 -> V=1.0, theta=0.0
% INFO    : Bus 10759	: V=1.02531, theta=14.551431 -> V=1.0, theta=0.0
% INFO    : Bus 10760	: V=1.008795, theta=-8.614735 -> V=1.0, theta=0.0
% INFO    : Bus 10761	: V=1.016881, theta=18.245981 -> V=1.0, theta=0.0
% INFO    : Bus 10762	: V=1.071277, theta=43.713777 -> V=1.0, theta=0.0
% INFO    : Bus 10763	: V=1.071277, theta=43.713777 -> V=1.0, theta=0.0
% INFO    : Bus 10764	: V=1.068762, theta=42.463865 -> V=1.0, theta=0.0
% INFO    : Bus 10765	: V=1.071277, theta=43.713777 -> V=1.0, theta=0.0
% INFO    : Bus 10766	: V=1.047426, theta=-0.530089 -> V=1.0, theta=0.0
% INFO    : Bus 10767	: V=1.054401, theta=30.288494 -> V=1.0, theta=0.0
% INFO    : Bus 10768	: V=1.003424, theta=13.295032 -> V=1.0, theta=0.0
% INFO    : Bus 10769	: V=1.02179, theta=-15.445748 -> V=1.0, theta=0.0
% INFO    : Bus 10770	: V=0.994485, theta=-7.687301 -> V=1.0, theta=0.0
% INFO    : Bus 10771	: V=0.972803, theta=-9.022804 -> V=1.0, theta=0.0
% INFO    : Bus 10772	: V=1.021346, theta=-22.881448 -> V=1.0, theta=0.0
% INFO    : Bus 10773	: V=1.021346, theta=-22.881448 -> V=1.0, theta=0.0
% INFO    : Bus 10774	: V=1.049971, theta=16.509432 -> V=1.0, theta=0.0
% INFO    : Bus 10775	: V=1.034738, theta=85.578957 -> V=1.0, theta=0.0
% INFO    : Bus 10776	: V=1.014379, theta=-16.62541 -> V=1.0, theta=0.0
% INFO    : Bus 10777	: V=1.001185, theta=37.535252 -> V=1.0, theta=0.0
% INFO    : Bus 10778	: V=1.021346, theta=-22.881448 -> V=1.0, theta=0.0
% INFO    : Bus 10779	: V=1.073663, theta=7.212197 -> V=1.0, theta=0.0
% INFO    : Bus 10780	: V=1.012788, theta=-24.277248 -> V=1.0, theta=0.0
% INFO    : Bus 10781	: V=1.018238, theta=31.754693 -> V=1.0, theta=0.0
% INFO    : Bus 10782	: V=1.030283, theta=4.050461 -> V=1.0, theta=0.0
% INFO    : Bus 10783	: V=1.030285, theta=40.859534 -> V=1.0, theta=0.0
% INFO    : Bus 10784	: V=1.010203, theta=8.259748 -> V=1.0, theta=0.0
% INFO    : Bus 10785	: V=1.040138, theta=32.45384 -> V=1.0, theta=0.0
% INFO    : Bus 10786	: V=1.001399, theta=27.844323 -> V=1.0, theta=0.0
% INFO    : Bus 10787	: V=0.972834, theta=6.994576 -> V=1.0, theta=0.0
% INFO    : Bus 10788	: V=1.03058, theta=15.553508 -> V=1.0, theta=0.0
% INFO    : Bus 10789	: V=0.978084, theta=-5.505378 -> V=1.0, theta=0.0
% INFO    : Bus 10790	: V=1.027498, theta=5.66065 -> V=1.0, theta=0.0
% INFO    : Bus 10791	: V=0.973626, theta=-7.095233 -> V=1.0, theta=0.0
% INFO    : Bus 10792	: V=0.982866, theta=-21.140797 -> V=1.0, theta=0.0
% INFO    : Bus 10793	: V=1.031135, theta=4.071247 -> V=1.0, theta=0.0
% INFO    : Bus 10794	: V=0.986382, theta=37.678673 -> V=1.0, theta=0.0
% INFO    : Bus 10795	: V=1.050489, theta=14.314816 -> V=1.0, theta=0.0
% INFO    : Bus 10796	: V=1.043249, theta=28.121526 -> V=1.0, theta=0.0
% INFO    : Bus 10797	: V=1.023736, theta=-1.23217 -> V=1.0, theta=0.0
% INFO    : Bus 10798	: V=1.087269, theta=1.338438 -> V=1.0, theta=0.0
% INFO    : Bus 10799	: V=0.98542, theta=-4.881531 -> V=1.0, theta=0.0
% INFO    : Bus 10800	: V=1.017676, theta=-12.774326 -> V=1.0, theta=0.0
% INFO    : Bus 10801	: V=1.014647, theta=-12.087921 -> V=1.0, theta=0.0
% INFO    : Bus 10802	: V=1.006447, theta=10.354507 -> V=1.0, theta=0.0
% INFO    : Bus 10803	: V=1.047752, theta=29.881973 -> V=1.0, theta=0.0
% INFO    : Bus 10804	: V=1.047752, theta=29.881973 -> V=1.0, theta=0.0
% INFO    : Bus 10805	: V=0.971251, theta=-9.48586 -> V=1.0, theta=0.0
% INFO    : Bus 10806	: V=1.01559, theta=45.608342 -> V=1.0, theta=0.0
% INFO    : Bus 10807	: V=1.02238, theta=33.263905 -> V=1.0, theta=0.0
% INFO    : Bus 10808	: V=1.023144, theta=-9.538309 -> V=1.0, theta=0.0
% INFO    : Bus 10809	: V=1.030656, theta=3.405373 -> V=1.0, theta=0.0
% INFO    : Bus 10810	: V=0.988125, theta=29.987284 -> V=1.0, theta=0.0
% INFO    : Bus 10811	: V=1.048656, theta=21.505608 -> V=1.0, theta=0.0
% INFO    : Bus 10812	: V=1.002307, theta=4.494366 -> V=1.0, theta=0.0
% INFO    : Bus 10813	: V=1.023355, theta=6.426723 -> V=1.0, theta=0.0
% INFO    : Bus 10814	: V=0.976475, theta=43.406918 -> V=1.0, theta=0.0
% INFO    : Bus 10815	: V=1.021355, theta=26.400741 -> V=1.0, theta=0.0
% INFO    : Bus 10816	: V=1.041533, theta=-3.179597 -> V=1.0, theta=0.0
% INFO    : Bus 10817	: V=1.005066, theta=-10.192072 -> V=1.0, theta=0.0
% INFO    : Bus 10818	: V=0.998652, theta=13.237944 -> V=1.0, theta=0.0
% INFO    : Bus 10819	: V=0.958395, theta=15.135397 -> V=1.0, theta=0.0
% INFO    : Bus 10820	: V=1.008397, theta=27.531499 -> V=1.0, theta=0.0
% INFO    : Bus 10821	: V=0.987947, theta=15.904596 -> V=1.0, theta=0.0
% INFO    : Bus 10822	: V=1.003446, theta=-10.066789 -> V=1.0, theta=0.0
% INFO    : Bus 10823	: V=0.953175, theta=-4.97832 -> V=1.0, theta=0.0
% INFO    : Bus 10824	: V=0.983355, theta=-10.131998 -> V=1.0, theta=0.0
% INFO    : Bus 10825	: V=0.988205, theta=29.491637 -> V=1.0, theta=0.0
% INFO    : Bus 10826	: V=1.005475, theta=21.389486 -> V=1.0, theta=0.0
% INFO    : Bus 10827	: V=1.038434, theta=10.255024 -> V=1.0, theta=0.0
% INFO    : Bus 10828	: V=1.005207, theta=32.006799 -> V=1.0, theta=0.0
% INFO    : Bus 10829	: V=1.03064, theta=1.46507 -> V=1.0, theta=0.0
% INFO    : Bus 10830	: V=0.987919, theta=-7.45049 -> V=1.0, theta=0.0
% INFO    : Bus 10831	: V=1.098505, theta=65.011053 -> V=1.0, theta=0.0
% INFO    : Bus 10832	: V=1.022588, theta=-10.912578 -> V=1.0, theta=0.0
% INFO    : Bus 10833	: V=1.020557, theta=9.624602 -> V=1.0, theta=0.0
% INFO    : Bus 10834	: V=1.009718, theta=-10.337767 -> V=1.0, theta=0.0
% INFO    : Bus 10835	: V=0.990208, theta=39.96266 -> V=1.0, theta=0.0
% INFO    : Bus 10836	: V=1.029181, theta=34.311007 -> V=1.0, theta=0.0
% INFO    : Bus 10837	: V=1.02339, theta=-27.351175 -> V=1.0, theta=0.0
% INFO    : Bus 10838	: V=1.022449, theta=29.009397 -> V=1.0, theta=0.0
% INFO    : Bus 10839	: V=1.016054, theta=37.442406 -> V=1.0, theta=0.0
% INFO    : Bus 10840	: V=1.021683, theta=-16.312902 -> V=1.0, theta=0.0
% INFO    : Bus 10841	: V=1.012871, theta=-6.113908 -> V=1.0, theta=0.0
% INFO    : Bus 10842	: V=1.002744, theta=9.696079 -> V=1.0, theta=0.0
% INFO    : Bus 10843	: V=0.980965, theta=-5.333412 -> V=1.0, theta=0.0
% INFO    : Bus 10844	: V=0.996299, theta=-23.298039 -> V=1.0, theta=0.0
% INFO    : Bus 10845	: V=1.050901, theta=18.201002 -> V=1.0, theta=0.0
% INFO    : Bus 10846	: V=1.016226, theta=41.638187 -> V=1.0, theta=0.0
% INFO    : Bus 10847	: V=1.127948, theta=6.872839 -> V=1.0, theta=0.0
% INFO    : Bus 10848	: V=1.017525, theta=-4.63816 -> V=1.0, theta=0.0
% INFO    : Bus 10849	: V=1.045058, theta=31.533985 -> V=1.0, theta=0.0
% INFO    : Bus 10850	: V=1.007631, theta=33.145748 -> V=1.0, theta=0.0
% INFO    : Bus 10851	: V=1.024793, theta=-7.141759 -> V=1.0, theta=0.0
% INFO    : Bus 10852	: V=1.03446, theta=9.76169 -> V=1.0, theta=0.0
% INFO    : Bus 10853	: V=0.993185, theta=-24.339386 -> V=1.0, theta=0.0
% INFO    : Bus 10854	: V=1.024449, theta=39.046761 -> V=1.0, theta=0.0
% INFO    : Bus 10855	: V=1.030884, theta=1.632423 -> V=1.0, theta=0.0
% INFO    : Bus 10856	: V=1.027891, theta=-20.15245 -> V=1.0, theta=0.0
% INFO    : Bus 10857	: V=1.005209, theta=-3.078095 -> V=1.0, theta=0.0
% INFO    : Bus 10858	: V=0.985439, theta=14.751794 -> V=1.0, theta=0.0
% INFO    : Bus 10859	: V=1.046888, theta=-1.764346 -> V=1.0, theta=0.0
% INFO    : Bus 10860	: V=0.875714, theta=-14.918506 -> V=1.0, theta=0.0
% INFO    : Bus 10861	: V=1.024702, theta=5.558519 -> V=1.0, theta=0.0
% INFO    : Bus 10862	: V=1.017582, theta=-1.17871 -> V=1.0, theta=0.0
% INFO    : Bus 10863	: V=0.994421, theta=-11.286237 -> V=1.0, theta=0.0
% INFO    : Bus 10864	: V=1.051216, theta=90.952815 -> V=1.0, theta=0.0
% INFO    : Bus 10865	: V=1.030566, theta=-6.658147 -> V=1.0, theta=0.0
% INFO    : Bus 10866	: V=1.016275, theta=-26.563495 -> V=1.0, theta=0.0
% INFO    : Bus 10867	: V=0.9937, theta=-4.748994 -> V=1.0, theta=0.0
% INFO    : Bus 10868	: V=0.993792, theta=-1.394335 -> V=1.0, theta=0.0
% INFO    : Bus 10869	: V=1.039547, theta=93.884512 -> V=1.0, theta=0.0
% INFO    : Bus 10870	: V=1.014981, theta=-18.306895 -> V=1.0, theta=0.0
% INFO    : Bus 10871	: V=1.078549, theta=2.923312 -> V=1.0, theta=0.0
% INFO    : Bus 10872	: V=0.960372, theta=-0.352042 -> V=1.0, theta=0.0
% INFO    : Bus 10873	: V=1.006471, theta=-4.581022 -> V=1.0, theta=0.0
% INFO    : Bus 10874	: V=1.01123, theta=-2.950698 -> V=1.0, theta=0.0
% INFO    : Bus 10875	: V=1.013565, theta=-8.752258 -> V=1.0, theta=0.0
% INFO    : Bus 10876	: V=1.036364, theta=0.609659 -> V=1.0, theta=0.0
% INFO    : Bus 10877	: V=1.013398, theta=18.391176 -> V=1.0, theta=0.0
% INFO    : Bus 10878	: V=1.015022, theta=-12.727541 -> V=1.0, theta=0.0
% INFO    : Bus 10879	: V=1.004452, theta=15.490712 -> V=1.0, theta=0.0
% INFO    : Bus 10880	: V=0.99896, theta=35.843784 -> V=1.0, theta=0.0
% INFO    : Bus 10881	: V=1.002675, theta=8.668171 -> V=1.0, theta=0.0
% INFO    : Bus 10882	: V=1.013081, theta=3.304943 -> V=1.0, theta=0.0
% INFO    : Bus 10883	: V=1.029528, theta=26.573846 -> V=1.0, theta=0.0
% INFO    : Bus 10884	: V=1.016682, theta=-22.865962 -> V=1.0, theta=0.0
% INFO    : Bus 10885	: V=0.974842, theta=19.011133 -> V=1.0, theta=0.0
% INFO    : Bus 10886	: V=0.983405, theta=-17.874163 -> V=1.0, theta=0.0
% INFO    : Bus 10887	: V=1.050632, theta=28.441322 -> V=1.0, theta=0.0
% INFO    : Bus 10888	: V=1.018307, theta=-5.887967 -> V=1.0, theta=0.0
% INFO    : Bus 10889	: V=1.015268, theta=-1.232652 -> V=1.0, theta=0.0
% INFO    : Bus 10890	: V=0.995518, theta=-13.198494 -> V=1.0, theta=0.0
% INFO    : Bus 10891	: V=1.020801, theta=18.620106 -> V=1.0, theta=0.0
% INFO    : Bus 10892	: V=1.006256, theta=26.531463 -> V=1.0, theta=0.0
% INFO    : Bus 10893	: V=0.990944, theta=-9.604254 -> V=1.0, theta=0.0
% INFO    : Bus 10894	: V=1.014555, theta=-22.095801 -> V=1.0, theta=0.0
% INFO    : Bus 10895	: V=1.018347, theta=4.40155 -> V=1.0, theta=0.0
% INFO    : Bus 10896	: V=1.028201, theta=18.476555 -> V=1.0, theta=0.0
% INFO    : Bus 10897	: V=0.957636, theta=-5.912977 -> V=1.0, theta=0.0
% INFO    : Bus 10898	: V=1.045295, theta=35.245517 -> V=1.0, theta=0.0
% INFO    : Bus 10899	: V=1.017068, theta=57.812163 -> V=1.0, theta=0.0
% INFO    : Bus 10900	: V=1.02095, theta=3.804651 -> V=1.0, theta=0.0
% INFO    : Bus 10901	: V=1.041629, theta=38.466941 -> V=1.0, theta=0.0
% INFO    : Bus 10902	: V=1.017885, theta=42.294482 -> V=1.0, theta=0.0
% INFO    : Bus 10903	: V=1.038112, theta=42.316461 -> V=1.0, theta=0.0
% INFO    : Bus 10904	: V=1.02681, theta=37.543364 -> V=1.0, theta=0.0
% INFO    : Bus 10905	: V=1.031605, theta=79.170309 -> V=1.0, theta=0.0
% INFO    : Bus 10906	: V=1.007106, theta=-18.296961 -> V=1.0, theta=0.0
% INFO    : Bus 10907	: V=1.017638, theta=-6.936102 -> V=1.0, theta=0.0
% INFO    : Bus 10908	: V=1.021858, theta=-2.534901 -> V=1.0, theta=0.0
% INFO    : Bus 10909	: V=1.003916, theta=16.769714 -> V=1.0, theta=0.0
% INFO    : Bus 10910	: V=1.061466, theta=10.803282 -> V=1.0, theta=0.0
% INFO    : Bus 10911	: V=0.982556, theta=88.950654 -> V=1.0, theta=0.0
% INFO    : Bus 10912	: V=1.018445, theta=36.653084 -> V=1.0, theta=0.0
% INFO    : Bus 10913	: V=1.063361, theta=65.621633 -> V=1.0, theta=0.0
% INFO    : Bus 10914	: V=1.000943, theta=33.854292 -> V=1.0, theta=0.0
% INFO    : Bus 10915	: V=1.004033, theta=-14.136758 -> V=1.0, theta=0.0
% INFO    : Bus 10916	: V=1.034574, theta=-1.223747 -> V=1.0, theta=0.0
% INFO    : Bus 10917	: V=1.07271, theta=19.588991 -> V=1.0, theta=0.0
% INFO    : Bus 10918	: V=1.046905, theta=39.305577 -> V=1.0, theta=0.0
% INFO    : Bus 10919	: V=1.089202, theta=7.894075 -> V=1.0, theta=0.0
% INFO    : Bus 10920	: V=1.01303, theta=-0.115586 -> V=1.0, theta=0.0
% INFO    : Bus 10921	: V=1.078292, theta=24.313687 -> V=1.0, theta=0.0
% INFO    : Bus 10922	: V=1.060681, theta=4.426558 -> V=1.0, theta=0.0
% INFO    : Bus 10923	: V=1.021614, theta=6.608806 -> V=1.0, theta=0.0
% INFO    : Bus 10924	: V=1.026724, theta=-18.974379 -> V=1.0, theta=0.0
% INFO    : Bus 10925	: V=0.98864, theta=-1.800447 -> V=1.0, theta=0.0
% INFO    : Bus 10926	: V=1.044116, theta=-1.932699 -> V=1.0, theta=0.0
% INFO    : Bus 10927	: V=1.03324, theta=-5.012105 -> V=1.0, theta=0.0
% INFO    : Bus 10928	: V=1.03324, theta=-5.012105 -> V=1.0, theta=0.0
% INFO    : Bus 10929	: V=1.013059, theta=-26.461759 -> V=1.0, theta=0.0
% INFO    : Bus 10930	: V=1.03324, theta=-5.012105 -> V=1.0, theta=0.0
% INFO    : Bus 10931	: V=0.992578, theta=88.955071 -> V=1.0, theta=0.0
% INFO    : Bus 10932	: V=0.989744, theta=5.658378 -> V=1.0, theta=0.0
% INFO    : Bus 10933	: V=1.013242, theta=-8.26672 -> V=1.0, theta=0.0
% INFO    : Bus 10934	: V=1.015902, theta=4.400211 -> V=1.0, theta=0.0
% INFO    : Bus 10935	: V=1.026025, theta=16.98036 -> V=1.0, theta=0.0
% INFO    : Bus 10936	: V=0.948098, theta=-8.048171 -> V=1.0, theta=0.0
% INFO    : Bus 10937	: V=0.966707, theta=0.298451 -> V=1.0, theta=0.0
% INFO    : Bus 10938	: V=1.034618, theta=3.213705 -> V=1.0, theta=0.0
% INFO    : Bus 10939	: V=1.094178, theta=-13.789895 -> V=1.0, theta=0.0
% INFO    : Bus 10940	: V=0.963524, theta=49.352991 -> V=1.0, theta=0.0
% INFO    : Bus 10941	: V=0.987164, theta=22.924227 -> V=1.0, theta=0.0
% INFO    : Bus 10942	: V=1.044422, theta=11.906623 -> V=1.0, theta=0.0
% INFO    : Bus 10943	: V=1.012774, theta=11.698457 -> V=1.0, theta=0.0
% INFO    : Bus 10944	: V=1.004017, theta=15.367102 -> V=1.0, theta=0.0
% INFO    : Bus 10945	: V=0.987313, theta=21.230551 -> V=1.0, theta=0.0
% INFO    : Bus 10946	: V=1.032433, theta=27.631736 -> V=1.0, theta=0.0
% INFO    : Bus 10947	: V=0.964957, theta=-4.188803 -> V=1.0, theta=0.0
% INFO    : Bus 10948	: V=1.014833, theta=32.681428 -> V=1.0, theta=0.0
% INFO    : Bus 10949	: V=0.975998, theta=-29.032562 -> V=1.0, theta=0.0
% INFO    : Bus 10950	: V=0.950398, theta=-10.506843 -> V=1.0, theta=0.0
% INFO    : Bus 10951	: V=0.979833, theta=25.164622 -> V=1.0, theta=0.0
% INFO    : Bus 10952	: V=1.040375, theta=-20.27869 -> V=1.0, theta=0.0
% INFO    : Bus 10953	: V=1.021504, theta=43.086372 -> V=1.0, theta=0.0
% INFO    : Bus 10954	: V=1.029835, theta=-14.681025 -> V=1.0, theta=0.0
% INFO    : Bus 10955	: V=1.009407, theta=30.297446 -> V=1.0, theta=0.0
% INFO    : Bus 10956	: V=0.966842, theta=-9.620847 -> V=1.0, theta=0.0
% INFO    : Bus 10957	: V=1.042113, theta=78.257418 -> V=1.0, theta=0.0
% INFO    : Bus 10958	: V=1.013008, theta=-2.721836 -> V=1.0, theta=0.0
% INFO    : Bus 10959	: V=1.030177, theta=4.029448 -> V=1.0, theta=0.0
% INFO    : Bus 10960	: V=0.965702, theta=-5.056087 -> V=1.0, theta=0.0
% INFO    : Bus 10961	: V=1.031993, theta=19.778436 -> V=1.0, theta=0.0
% INFO    : Bus 10962	: V=0.996576, theta=38.818644 -> V=1.0, theta=0.0
% INFO    : Bus 10963	: V=1.056762, theta=11.950776 -> V=1.0, theta=0.0
% INFO    : Bus 10964	: V=1.004147, theta=-22.172201 -> V=1.0, theta=0.0
% INFO    : Bus 10965	: V=1.07444, theta=72.668763 -> V=1.0, theta=0.0
% INFO    : Bus 10966	: V=1.012121, theta=9.272005 -> V=1.0, theta=0.0
% INFO    : Bus 10967	: V=1.049435, theta=44.907943 -> V=1.0, theta=0.0
% INFO    : Bus 10968	: V=1.035837, theta=30.303383 -> V=1.0, theta=0.0
% INFO    : Bus 10969	: V=0.996139, theta=-3.970212 -> V=1.0, theta=0.0
% INFO    : Bus 10970	: V=0.995719, theta=11.936633 -> V=1.0, theta=0.0
% INFO    : Bus 10971	: V=0.992395, theta=35.295433 -> V=1.0, theta=0.0
% INFO    : Bus 10972	: V=1.001455, theta=-1.412213 -> V=1.0, theta=0.0
% INFO    : Bus 10973	: V=1.015065, theta=20.651679 -> V=1.0, theta=0.0
% INFO    : Bus 10974	: V=1.000402, theta=-14.170487 -> V=1.0, theta=0.0
% INFO    : Bus 10975	: V=0.965497, theta=21.450186 -> V=1.0, theta=0.0
% INFO    : Bus 10976	: V=0.977661, theta=5.932781 -> V=1.0, theta=0.0
% INFO    : Bus 10977	: V=1.015642, theta=-21.99726 -> V=1.0, theta=0.0
% INFO    : Bus 10978	: V=1.017582, theta=-1.17871 -> V=1.0, theta=0.0
% INFO    : Bus 10979	: V=1.042714, theta=13.161129 -> V=1.0, theta=0.0
% INFO    : Bus 10980	: V=1.056556, theta=-2.749188 -> V=1.0, theta=0.0
% INFO    : Bus 10981	: V=1.057896, theta=29.562711 -> V=1.0, theta=0.0
% INFO    : Bus 10982	: V=0.989913, theta=-15.56772 -> V=1.0, theta=0.0
% INFO    : Bus 10983	: V=1.024499, theta=-3.834468 -> V=1.0, theta=0.0
% INFO    : Bus 10984	: V=1.006745, theta=-15.282702 -> V=1.0, theta=0.0
% INFO    : Bus 10985	: V=1.023338, theta=0.199966 -> V=1.0, theta=0.0
% INFO    : Bus 10986	: V=1.039787, theta=-14.573329 -> V=1.0, theta=0.0
% INFO    : Bus 10987	: V=1.018866, theta=14.228745 -> V=1.0, theta=0.0
% INFO    : Bus 10988	: V=1.021238, theta=18.63529 -> V=1.0, theta=0.0
% INFO    : Bus 10989	: V=1.036108, theta=5.806299 -> V=1.0, theta=0.0
% INFO    : Bus 10990	: V=1.014119, theta=-26.1744 -> V=1.0, theta=0.0
% INFO    : Bus 10991	: V=1.004444, theta=63.292218 -> V=1.0, theta=0.0
% INFO    : Bus 10992	: V=1.033683, theta=-19.351445 -> V=1.0, theta=0.0
% INFO    : Bus 10993	: V=1.035529, theta=26.984517 -> V=1.0, theta=0.0
% INFO    : Bus 10994	: V=0.964368, theta=44.185324 -> V=1.0, theta=0.0
% INFO    : Bus 10995	: V=1.00521, theta=30.518109 -> V=1.0, theta=0.0
% INFO    : Bus 10996	: V=0.992371, theta=15.325908 -> V=1.0, theta=0.0
% INFO    : Bus 10997	: V=1.011697, theta=51.097732 -> V=1.0, theta=0.0
% INFO    : Bus 10998	: V=1.05787, theta=-5.405768 -> V=1.0, theta=0.0
% INFO    : Bus 10999	: V=1.056895, theta=7.793415 -> V=1.0, theta=0.0
% INFO    : Bus 11000	: V=0.965871, theta=1.76722 -> V=1.0, theta=0.0
% INFO    : Bus 11001	: V=1.04564, theta=-1.473285 -> V=1.0, theta=0.0
% INFO    : Bus 11002	: V=0.960912, theta=0.645663 -> V=1.0, theta=0.0
% INFO    : Bus 11003	: V=1.01601, theta=18.41194 -> V=1.0, theta=0.0
% INFO    : Bus 11004	: V=0.981057, theta=20.248958 -> V=1.0, theta=0.0
% INFO    : Bus 11005	: V=1.042317, theta=14.274354 -> V=1.0, theta=0.0
% INFO    : Bus 11006	: V=1.00026, theta=19.167902 -> V=1.0, theta=0.0
% INFO    : Bus 11007	: V=0.985204, theta=-4.275915 -> V=1.0, theta=0.0
% INFO    : Bus 11008	: V=1.034643, theta=-5.112265 -> V=1.0, theta=0.0
% INFO    : Bus 11009	: V=1.023224, theta=9.526501 -> V=1.0, theta=0.0
% INFO    : Bus 11010	: V=1.064335, theta=2.396339 -> V=1.0, theta=0.0
% INFO    : Bus 11011	: V=1.02543, theta=42.897015 -> V=1.0, theta=0.0
% INFO    : Bus 11012	: V=1.016333, theta=31.296283 -> V=1.0, theta=0.0
% INFO    : Bus 11013	: V=0.99812, theta=29.873325 -> V=1.0, theta=0.0
% INFO    : Bus 11014	: V=0.997828, theta=-4.430017 -> V=1.0, theta=0.0
% INFO    : Bus 11015	: V=0.993099, theta=14.527357 -> V=1.0, theta=0.0
% INFO    : Bus 11016	: V=1.018455, theta=3.690325 -> V=1.0, theta=0.0
% INFO    : Bus 11017	: V=1.030905, theta=9.647854 -> V=1.0, theta=0.0
% INFO    : Bus 11018	: V=0.99801, theta=-10.108962 -> V=1.0, theta=0.0
% INFO    : Bus 11019	: V=1.130738, theta=7.126476 -> V=1.0, theta=0.0
% INFO    : Bus 11020	: V=0.991929, theta=29.398008 -> V=1.0, theta=0.0
% INFO    : Bus 11021	: V=1.085458, theta=1.301643 -> V=1.0, theta=0.0
% INFO    : Bus 11022	: V=0.964159, theta=-6.496671 -> V=1.0, theta=0.0
% INFO    : Bus 11023	: V=1.031695, theta=0.0 -> V=1.0, theta=0.0
% INFO    : Bus 11024	: V=0.963863, theta=-9.047548 -> V=1.0, theta=0.0
% INFO    : Bus 11025	: V=1.031695, theta=0.0 -> V=1.0, theta=0.0
% INFO    : Bus 11026	: V=0.982822, theta=15.001687 -> V=1.0, theta=0.0
% INFO    : Bus 11027	: V=0.99836, theta=-22.714373 -> V=1.0, theta=0.0
% INFO    : Bus 11028	: V=1.025977, theta=8.588106 -> V=1.0, theta=0.0
% INFO    : Bus 11029	: V=1.023866, theta=16.659339 -> V=1.0, theta=0.0
% INFO    : Bus 11030	: V=1.021495, theta=11.964278 -> V=1.0, theta=0.0
% INFO    : Bus 11031	: V=1.023514, theta=-27.422646 -> V=1.0, theta=0.0
% INFO    : Bus 11032	: V=1.04071, theta=74.319379 -> V=1.0, theta=0.0
% INFO    : Bus 11033	: V=1.038753, theta=13.420474 -> V=1.0, theta=0.0
% INFO    : Bus 11034	: V=1.071071, theta=-4.191594 -> V=1.0, theta=0.0
% INFO    : Bus 11035	: V=0.989728, theta=-13.568538 -> V=1.0, theta=0.0
% INFO    : Bus 11036	: V=1.013145, theta=93.290213 -> V=1.0, theta=0.0
% INFO    : Bus 11037	: V=1.029671, theta=48.863044 -> V=1.0, theta=0.0
% INFO    : Bus 11038	: V=0.926519, theta=-12.060065 -> V=1.0, theta=0.0
% INFO    : Bus 11039	: V=1.058835, theta=5.385711 -> V=1.0, theta=0.0
% INFO    : Bus 11040	: V=1.014113, theta=-10.382927 -> V=1.0, theta=0.0
% INFO    : Bus 11041	: V=0.99966, theta=4.257778 -> V=1.0, theta=0.0
% INFO    : Bus 11042	: V=1.017096, theta=-26.064396 -> V=1.0, theta=0.0
% INFO    : Bus 11043	: V=1.019788, theta=21.776211 -> V=1.0, theta=0.0
% INFO    : Bus 11044	: V=1.032592, theta=-10.840409 -> V=1.0, theta=0.0
% INFO    : Bus 11045	: V=1.027749, theta=35.91349 -> V=1.0, theta=0.0
% INFO    : Bus 11046	: V=1.022149, theta=51.967191 -> V=1.0, theta=0.0
% INFO    : Bus 11047	: V=0.956299, theta=35.305913 -> V=1.0, theta=0.0
% INFO    : Bus 11048	: V=1.057421, theta=-9.850777 -> V=1.0, theta=0.0
% INFO    : Bus 11049	: V=1.038747, theta=-8.642337 -> V=1.0, theta=0.0
% INFO    : Bus 11050	: V=1.048761, theta=-1.634623 -> V=1.0, theta=0.0
% INFO    : Bus 11051	: V=1.019231, theta=22.327173 -> V=1.0, theta=0.0
% INFO    : Bus 11052	: V=1.000581, theta=2.016131 -> V=1.0, theta=0.0
% INFO    : Bus 11053	: V=0.998763, theta=89.131252 -> V=1.0, theta=0.0
% INFO    : Bus 11054	: V=0.965663, theta=-3.946676 -> V=1.0, theta=0.0
% INFO    : Bus 11055	: V=0.990963, theta=29.255516 -> V=1.0, theta=0.0
% INFO    : Bus 11056	: V=1.041941, theta=12.254953 -> V=1.0, theta=0.0
% INFO    : Bus 11057	: V=1.01539, theta=-4.024409 -> V=1.0, theta=0.0
% INFO    : Bus 11058	: V=1.043702, theta=24.901421 -> V=1.0, theta=0.0
% INFO    : Bus 11059	: V=0.993383, theta=32.126146 -> V=1.0, theta=0.0
% INFO    : Bus 11060	: V=1.03274, theta=40.004966 -> V=1.0, theta=0.0
% INFO    : Bus 11061	: V=1.020343, theta=-11.016395 -> V=1.0, theta=0.0
% INFO    : Bus 11062	: V=1.016593, theta=33.004723 -> V=1.0, theta=0.0
% INFO    : Bus 11063	: V=1.011448, theta=-5.405014 -> V=1.0, theta=0.0
% INFO    : Bus 11064	: V=0.95216, theta=-28.786392 -> V=1.0, theta=0.0
% INFO    : Bus 11065	: V=1.014542, theta=2.91424 -> V=1.0, theta=0.0
% INFO    : Bus 11066	: V=1.041703, theta=17.122885 -> V=1.0, theta=0.0
% INFO    : Bus 11067	: V=1.065465, theta=-5.509476 -> V=1.0, theta=0.0
% INFO    : Bus 11068	: V=1.084957, theta=7.346331 -> V=1.0, theta=0.0
% INFO    : Bus 11069	: V=1.015628, theta=-26.653114 -> V=1.0, theta=0.0
% INFO    : Bus 11070	: V=1.049335, theta=-12.691784 -> V=1.0, theta=0.0
% INFO    : Bus 11071	: V=1.017049, theta=-8.947511 -> V=1.0, theta=0.0
% INFO    : Bus 11072	: V=1.021208, theta=38.056929 -> V=1.0, theta=0.0
% INFO    : Bus 11073	: V=1.028931, theta=19.248313 -> V=1.0, theta=0.0
% INFO    : Bus 11074	: V=1.042079, theta=21.032687 -> V=1.0, theta=0.0
% INFO    : Bus 11075	: V=0.997963, theta=-4.774298 -> V=1.0, theta=0.0
% INFO    : Bus 11076	: V=1.011132, theta=1.192229 -> V=1.0, theta=0.0
% INFO    : Bus 11077	: V=1.025183, theta=2.063528 -> V=1.0, theta=0.0
% INFO    : Bus 11078	: V=1.025593, theta=17.098854 -> V=1.0, theta=0.0
% INFO    : Bus 11079	: V=1.004312, theta=24.594716 -> V=1.0, theta=0.0
% INFO    : Bus 11080	: V=1.032381, theta=14.273943 -> V=1.0, theta=0.0
% INFO    : Bus 11081	: V=1.030478, theta=28.680093 -> V=1.0, theta=0.0
% INFO    : Bus 11082	: V=1.019106, theta=25.890575 -> V=1.0, theta=0.0
% INFO    : Bus 11083	: V=1.021648, theta=-12.117867 -> V=1.0, theta=0.0
% INFO    : Bus 11084	: V=1.023166, theta=4.463602 -> V=1.0, theta=0.0
% INFO    : Bus 11085	: V=1.038916, theta=11.288829 -> V=1.0, theta=0.0
% INFO    : Bus 11086	: V=1.038916, theta=11.288829 -> V=1.0, theta=0.0
% INFO    : Bus 11087	: V=1.038916, theta=11.288829 -> V=1.0, theta=0.0
% INFO    : Bus 11088	: V=1.038916, theta=11.288829 -> V=1.0, theta=0.0
% INFO    : Bus 11089	: V=0.950334, theta=-10.842503 -> V=1.0, theta=0.0
% INFO    : Bus 11090	: V=1.042693, theta=10.439455 -> V=1.0, theta=0.0
% INFO    : Bus 11091	: V=0.986965, theta=-2.623333 -> V=1.0, theta=0.0
% INFO    : Bus 11092	: V=1.031473, theta=33.288433 -> V=1.0, theta=0.0
% INFO    : Bus 11093	: V=0.974554, theta=-6.12814 -> V=1.0, theta=0.0
% INFO    : Bus 11094	: V=1.074857, theta=-3.74166 -> V=1.0, theta=0.0
% INFO    : Bus 11095	: V=1.026425, theta=15.756693 -> V=1.0, theta=0.0
% INFO    : Bus 11096	: V=1.024096, theta=61.613978 -> V=1.0, theta=0.0
% INFO    : Bus 11097	: V=0.99605, theta=-9.027342 -> V=1.0, theta=0.0
% INFO    : Bus 11098	: V=1.042796, theta=26.265727 -> V=1.0, theta=0.0
% INFO    : Bus 11099	: V=1.026957, theta=18.072383 -> V=1.0, theta=0.0
% INFO    : Bus 11100	: V=1.007503, theta=-16.273277 -> V=1.0, theta=0.0
% INFO    : Bus 11101	: V=1.019883, theta=12.179054 -> V=1.0, theta=0.0
% INFO    : Bus 11102	: V=1.035958, theta=27.387404 -> V=1.0, theta=0.0
% INFO    : Bus 11103	: V=0.958617, theta=-8.042541 -> V=1.0, theta=0.0
% INFO    : Bus 11104	: V=1.035958, theta=27.387404 -> V=1.0, theta=0.0
% INFO    : Bus 11105	: V=0.990461, theta=-2.437161 -> V=1.0, theta=0.0
% INFO    : Bus 11106	: V=1.053822, theta=27.723432 -> V=1.0, theta=0.0
% INFO    : Bus 11107	: V=1.035958, theta=27.387404 -> V=1.0, theta=0.0
% INFO    : Bus 11108	: V=1.053822, theta=27.723432 -> V=1.0, theta=0.0
% INFO    : Bus 11109	: V=1.053822, theta=27.723432 -> V=1.0, theta=0.0
% INFO    : Bus 11110	: V=1.01638, theta=20.943598 -> V=1.0, theta=0.0
% INFO    : Bus 11111	: V=1.053822, theta=27.723432 -> V=1.0, theta=0.0
% INFO    : Bus 11112	: V=1.034476, theta=-0.01541 -> V=1.0, theta=0.0
% INFO    : Bus 11113	: V=0.948716, theta=-7.342315 -> V=1.0, theta=0.0
% INFO    : Bus 11114	: V=1.029326, theta=26.316485 -> V=1.0, theta=0.0
% INFO    : Bus 11115	: V=1.019144, theta=17.562907 -> V=1.0, theta=0.0
% INFO    : Bus 11116	: V=1.013758, theta=-18.448945 -> V=1.0, theta=0.0
% INFO    : Bus 11117	: V=1.047639, theta=85.933932 -> V=1.0, theta=0.0
% INFO    : Bus 11118	: V=1.042829, theta=13.668895 -> V=1.0, theta=0.0
% INFO    : Bus 11119	: V=1.042829, theta=13.668895 -> V=1.0, theta=0.0
% INFO    : Bus 11120	: V=1.035471, theta=18.239403 -> V=1.0, theta=0.0
% INFO    : Bus 11121	: V=1.035471, theta=18.239403 -> V=1.0, theta=0.0
% INFO    : Bus 11122	: V=1.055315, theta=14.241147 -> V=1.0, theta=0.0
% INFO    : Bus 11123	: V=1.012226, theta=7.516602 -> V=1.0, theta=0.0
% INFO    : Bus 11124	: V=1.042829, theta=13.668895 -> V=1.0, theta=0.0
% INFO    : Bus 11125	: V=1.042829, theta=13.668895 -> V=1.0, theta=0.0
% INFO    : Bus 11126	: V=0.975009, theta=-15.542069 -> V=1.0, theta=0.0
% INFO    : Bus 11127	: V=0.96051, theta=-7.992356 -> V=1.0, theta=0.0
% INFO    : Bus 11128	: V=1.043665, theta=14.930439 -> V=1.0, theta=0.0
% INFO    : Bus 11129	: V=1.027132, theta=31.963051 -> V=1.0, theta=0.0
% INFO    : Bus 11130	: V=1.035471, theta=18.239403 -> V=1.0, theta=0.0
% INFO    : Bus 11131	: V=1.035771, theta=2.999441 -> V=1.0, theta=0.0
% INFO    : Bus 11132	: V=1.028204, theta=5.666749 -> V=1.0, theta=0.0
% INFO    : Bus 11133	: V=1.028204, theta=5.666749 -> V=1.0, theta=0.0
% INFO    : Bus 11134	: V=1.040116, theta=6.4776 -> V=1.0, theta=0.0
% INFO    : Bus 11135	: V=0.949807, theta=-0.06613 -> V=1.0, theta=0.0
% INFO    : Bus 11136	: V=1.020968, theta=24.881656 -> V=1.0, theta=0.0
% INFO    : Bus 11137	: V=1.028204, theta=5.666749 -> V=1.0, theta=0.0
% INFO    : Bus 11138	: V=1.016735, theta=24.349916 -> V=1.0, theta=0.0
% INFO    : Bus 11139	: V=0.979788, theta=-12.77143 -> V=1.0, theta=0.0
% INFO    : Bus 11140	: V=1.033483, theta=-19.436094 -> V=1.0, theta=0.0
% INFO    : Bus 11141	: V=1.020252, theta=-22.27659 -> V=1.0, theta=0.0
% INFO    : Bus 11142	: V=1.020252, theta=-22.27659 -> V=1.0, theta=0.0
% INFO    : Bus 11143	: V=1.020252, theta=-22.27659 -> V=1.0, theta=0.0
% INFO    : Bus 11144	: V=1.020252, theta=-22.27659 -> V=1.0, theta=0.0
% INFO    : Bus 11145	: V=1.000808, theta=-3.647252 -> V=1.0, theta=0.0
% INFO    : Bus 11146	: V=1.032343, theta=4.317275 -> V=1.0, theta=0.0
% INFO    : Bus 11147	: V=0.920261, theta=-7.851533 -> V=1.0, theta=0.0
% INFO    : Bus 11148	: V=1.006718, theta=31.655284 -> V=1.0, theta=0.0
% INFO    : Bus 11149	: V=0.976309, theta=-26.254285 -> V=1.0, theta=0.0
% INFO    : Bus 11150	: V=0.997555, theta=-9.051308 -> V=1.0, theta=0.0
% INFO    : Bus 11151	: V=1.042487, theta=12.714635 -> V=1.0, theta=0.0
% INFO    : Bus 11152	: V=1.002501, theta=0.438398 -> V=1.0, theta=0.0
% INFO    : Bus 11153	: V=1.023525, theta=-7.363087 -> V=1.0, theta=0.0
% INFO    : Bus 11154	: V=1.07025, theta=2.362941 -> V=1.0, theta=0.0
% INFO    : Bus 11155	: V=1.027264, theta=14.46311 -> V=1.0, theta=0.0
% INFO    : Bus 11156	: V=0.992653, theta=32.856803 -> V=1.0, theta=0.0
% INFO    : Bus 11157	: V=1.01561, theta=-12.050754 -> V=1.0, theta=0.0
% INFO    : Bus 11158	: V=0.991765, theta=36.62363 -> V=1.0, theta=0.0
% INFO    : Bus 11159	: V=1.049883, theta=28.076782 -> V=1.0, theta=0.0
% INFO    : Bus 11160	: V=0.998522, theta=27.102964 -> V=1.0, theta=0.0
% INFO    : Bus 11161	: V=1.0158, theta=9.843152 -> V=1.0, theta=0.0
% INFO    : Bus 11162	: V=1.058677, theta=31.63551 -> V=1.0, theta=0.0
% INFO    : Bus 11163	: V=1.024339, theta=19.049223 -> V=1.0, theta=0.0
% INFO    : Bus 11164	: V=1.000841, theta=-3.260781 -> V=1.0, theta=0.0
% INFO    : Bus 11165	: V=1.070567, theta=30.667523 -> V=1.0, theta=0.0
% INFO    : Bus 11166	: V=1.023141, theta=-27.708185 -> V=1.0, theta=0.0
% INFO    : Bus 11167	: V=1.040259, theta=34.3106 -> V=1.0, theta=0.0
% INFO    : Bus 11168	: V=1.003521, theta=-17.064676 -> V=1.0, theta=0.0
% INFO    : Bus 11169	: V=1.031203, theta=65.423612 -> V=1.0, theta=0.0
% INFO    : Bus 11170	: V=0.962614, theta=39.578299 -> V=1.0, theta=0.0
% INFO    : Bus 11171	: V=1.00831, theta=-2.707293 -> V=1.0, theta=0.0
% INFO    : Bus 11172	: V=1.040259, theta=34.3106 -> V=1.0, theta=0.0
% INFO    : Bus 11173	: V=0.99898, theta=15.395595 -> V=1.0, theta=0.0
% INFO    : Bus 11174	: V=1.040259, theta=34.3106 -> V=1.0, theta=0.0
% INFO    : Bus 11175	: V=1.040259, theta=34.3106 -> V=1.0, theta=0.0
% INFO    : Bus 11176	: V=1.033872, theta=21.357215 -> V=1.0, theta=0.0
% INFO    : Bus 11177	: V=1.01515, theta=14.648403 -> V=1.0, theta=0.0
% INFO    : Bus 11178	: V=1.045197, theta=-4.510954 -> V=1.0, theta=0.0
% INFO    : Bus 11179	: V=1.033898, theta=34.422243 -> V=1.0, theta=0.0
% INFO    : Bus 11180	: V=1.06407, theta=5.836436 -> V=1.0, theta=0.0
% INFO    : Bus 11181	: V=0.998612, theta=-7.023033 -> V=1.0, theta=0.0
% INFO    : Bus 11182	: V=1.015748, theta=23.459867 -> V=1.0, theta=0.0
% INFO    : Bus 11183	: V=1.030771, theta=24.629866 -> V=1.0, theta=0.0
% INFO    : Bus 11184	: V=0.984017, theta=31.265821 -> V=1.0, theta=0.0
% INFO    : Bus 11185	: V=1.09594, theta=-2.304833 -> V=1.0, theta=0.0
% INFO    : Bus 11186	: V=1.039325, theta=61.949237 -> V=1.0, theta=0.0
% INFO    : Bus 11187	: V=1.015857, theta=-18.592394 -> V=1.0, theta=0.0
% INFO    : Bus 11188	: V=1.00546, theta=18.561202 -> V=1.0, theta=0.0
% INFO    : Bus 11189	: V=1.055623, theta=15.228766 -> V=1.0, theta=0.0
% INFO    : Bus 11190	: V=1.040076, theta=10.160103 -> V=1.0, theta=0.0
% INFO    : Bus 11191	: V=1.015029, theta=3.043049 -> V=1.0, theta=0.0
% INFO    : Bus 11192	: V=1.015221, theta=-1.987936 -> V=1.0, theta=0.0
% INFO    : Bus 11193	: V=1.015029, theta=3.043049 -> V=1.0, theta=0.0
% INFO    : Bus 11194	: V=1.015029, theta=3.043049 -> V=1.0, theta=0.0
% INFO    : Bus 11195	: V=1.015029, theta=3.043049 -> V=1.0, theta=0.0
% INFO    : Bus 11196	: V=1.015029, theta=3.043049 -> V=1.0, theta=0.0
% INFO    : Bus 11197	: V=1.015029, theta=3.043049 -> V=1.0, theta=0.0
% INFO    : Bus 11198	: V=1.015029, theta=3.043049 -> V=1.0, theta=0.0
% INFO    : Bus 11199	: V=0.975835, theta=5.335155 -> V=1.0, theta=0.0
% INFO    : Bus 11200	: V=0.964611, theta=-4.941161 -> V=1.0, theta=0.0
% INFO    : Bus 11201	: V=1.020879, theta=-2.731653 -> V=1.0, theta=0.0
% INFO    : Bus 11202	: V=1.09911, theta=-4.414302 -> V=1.0, theta=0.0
% INFO    : Bus 11203	: V=1.05667, theta=-2.722877 -> V=1.0, theta=0.0
% INFO    : Bus 11204	: V=1.020879, theta=-2.731653 -> V=1.0, theta=0.0
% INFO    : Bus 11205	: V=0.976943, theta=30.990047 -> V=1.0, theta=0.0
% INFO    : Bus 11206	: V=1.029596, theta=7.742794 -> V=1.0, theta=0.0
% INFO    : Bus 11207	: V=1.007227, theta=17.02309 -> V=1.0, theta=0.0
% INFO    : Bus 11208	: V=1.028472, theta=33.988037 -> V=1.0, theta=0.0
% INFO    : Bus 11209	: V=0.989842, theta=-9.859665 -> V=1.0, theta=0.0
% INFO    : Bus 11210	: V=1.134218, theta=1.147159 -> V=1.0, theta=0.0
% INFO    : Bus 11211	: V=1.059581, theta=78.307427 -> V=1.0, theta=0.0
% INFO    : Bus 11212	: V=1.049265, theta=79.575419 -> V=1.0, theta=0.0
% INFO    : Bus 11213	: V=1.01937, theta=-12.967405 -> V=1.0, theta=0.0
% INFO    : Bus 11214	: V=1.013527, theta=-7.417807 -> V=1.0, theta=0.0
% INFO    : Bus 11215	: V=1.047231, theta=8.451346 -> V=1.0, theta=0.0
% INFO    : Bus 11216	: V=1.031611, theta=-6.339819 -> V=1.0, theta=0.0
% INFO    : Bus 11217	: V=0.99989, theta=-8.802342 -> V=1.0, theta=0.0
% INFO    : Bus 11218	: V=1.018256, theta=31.685067 -> V=1.0, theta=0.0
% INFO    : Bus 11219	: V=1.047402, theta=52.472138 -> V=1.0, theta=0.0
% INFO    : Bus 11220	: V=1.045943, theta=92.728902 -> V=1.0, theta=0.0
% INFO    : Bus 11221	: V=1.03058, theta=15.553508 -> V=1.0, theta=0.0
% INFO    : Bus 11222	: V=1.033676, theta=19.488235 -> V=1.0, theta=0.0
% INFO    : Bus 11223	: V=1.023924, theta=15.352257 -> V=1.0, theta=0.0
% INFO    : Bus 11224	: V=1.012524, theta=-14.686613 -> V=1.0, theta=0.0
% INFO    : Bus 11225	: V=1.039009, theta=81.664701 -> V=1.0, theta=0.0
% INFO    : Bus 11226	: V=1.028091, theta=-15.249181 -> V=1.0, theta=0.0
% INFO    : Bus 11227	: V=1.044939, theta=29.387061 -> V=1.0, theta=0.0
% INFO    : Bus 11228	: V=1.019273, theta=36.364634 -> V=1.0, theta=0.0
% INFO    : Bus 11229	: V=1.009652, theta=16.297978 -> V=1.0, theta=0.0
% INFO    : Bus 11230	: V=1.045545, theta=9.62853 -> V=1.0, theta=0.0
% INFO    : Bus 11231	: V=1.044939, theta=29.387061 -> V=1.0, theta=0.0
% INFO    : Bus 11232	: V=1.03189, theta=29.322101 -> V=1.0, theta=0.0
% INFO    : Bus 11233	: V=1.041114, theta=89.192565 -> V=1.0, theta=0.0
% INFO    : Bus 11234	: V=1.020254, theta=-23.064206 -> V=1.0, theta=0.0
% INFO    : Bus 11235	: V=1.05622, theta=67.539298 -> V=1.0, theta=0.0
% INFO    : Bus 11236	: V=1.041114, theta=89.192565 -> V=1.0, theta=0.0
% INFO    : Bus 11237	: V=1.015411, theta=-5.476788 -> V=1.0, theta=0.0
% INFO    : Bus 11238	: V=1.05622, theta=67.539298 -> V=1.0, theta=0.0
% INFO    : Bus 11239	: V=1.027155, theta=-13.349627 -> V=1.0, theta=0.0
% INFO    : Bus 11240	: V=1.063297, theta=57.37246 -> V=1.0, theta=0.0
% INFO    : Bus 11241	: V=1.063297, theta=57.37246 -> V=1.0, theta=0.0
% INFO    : Bus 11242	: V=1.063297, theta=57.37246 -> V=1.0, theta=0.0
% INFO    : Bus 11243	: V=1.029481, theta=-21.176174 -> V=1.0, theta=0.0
% INFO    : Bus 11244	: V=1.015411, theta=-5.476788 -> V=1.0, theta=0.0
% INFO    : Bus 11245	: V=1.004639, theta=94.458816 -> V=1.0, theta=0.0
% INFO    : Bus 11246	: V=1.028646, theta=7.51961 -> V=1.0, theta=0.0
% INFO    : Bus 11247	: V=1.030205, theta=22.436567 -> V=1.0, theta=0.0
% INFO    : Bus 11248	: V=1.033234, theta=-15.461113 -> V=1.0, theta=0.0
% INFO    : Bus 11249	: V=1.083816, theta=-4.534997 -> V=1.0, theta=0.0
% INFO    : Bus 11250	: V=1.008948, theta=-4.613451 -> V=1.0, theta=0.0
% INFO    : Bus 11251	: V=1.028648, theta=-14.669346 -> V=1.0, theta=0.0
% INFO    : Bus 11252	: V=1.093657, theta=-0.10105 -> V=1.0, theta=0.0
% INFO    : Bus 11253	: V=0.981547, theta=24.947698 -> V=1.0, theta=0.0
% INFO    : Bus 11254	: V=1.073833, theta=64.707336 -> V=1.0, theta=0.0
% INFO    : Bus 11255	: V=1.025855, theta=17.158047 -> V=1.0, theta=0.0
% INFO    : Bus 11256	: V=1.03657, theta=5.732096 -> V=1.0, theta=0.0
% INFO    : Bus 11257	: V=1.036997, theta=8.018504 -> V=1.0, theta=0.0
% INFO    : Bus 11258	: V=0.963667, theta=-7.149819 -> V=1.0, theta=0.0
% INFO    : Bus 11259	: V=1.03657, theta=5.732096 -> V=1.0, theta=0.0
% INFO    : Bus 11260	: V=1.025173, theta=10.163799 -> V=1.0, theta=0.0
% INFO    : Bus 11261	: V=1.024433, theta=-0.497913 -> V=1.0, theta=0.0
% INFO    : Bus 11262	: V=1.024545, theta=36.252791 -> V=1.0, theta=0.0
% INFO    : Bus 11263	: V=1.047483, theta=87.056246 -> V=1.0, theta=0.0
% INFO    : Bus 11264	: V=1.03058, theta=15.553508 -> V=1.0, theta=0.0
% INFO    : Bus 11265	: V=1.024762, theta=17.972121 -> V=1.0, theta=0.0
% INFO    : Bus 11266	: V=1.091952, theta=-4.839993 -> V=1.0, theta=0.0
% INFO    : Bus 11267	: V=1.029045, theta=-16.851924 -> V=1.0, theta=0.0
% INFO    : Bus 11268	: V=1.04893, theta=0.483335 -> V=1.0, theta=0.0
% INFO    : Bus 11269	: V=1.00751, theta=-6.732268 -> V=1.0, theta=0.0
% INFO    : Bus 11270	: V=1.015548, theta=-22.604629 -> V=1.0, theta=0.0
% INFO    : Bus 11271	: V=1.018385, theta=17.026556 -> V=1.0, theta=0.0
% INFO    : Bus 11272	: V=1.009712, theta=31.100358 -> V=1.0, theta=0.0
% INFO    : Bus 11273	: V=0.96764, theta=46.597759 -> V=1.0, theta=0.0
% INFO    : Bus 11274	: V=1.001049, theta=25.288942 -> V=1.0, theta=0.0
% INFO    : Bus 11275	: V=1.024574, theta=2.187824 -> V=1.0, theta=0.0
% INFO    : Bus 11276	: V=1.027666, theta=10.98452 -> V=1.0, theta=0.0
% INFO    : Bus 11277	: V=1.03616, theta=-10.170176 -> V=1.0, theta=0.0
% INFO    : Bus 11278	: V=1.008907, theta=14.345628 -> V=1.0, theta=0.0
% INFO    : Bus 11279	: V=0.991622, theta=-5.970926 -> V=1.0, theta=0.0
% INFO    : Bus 11280	: V=0.971409, theta=-8.469243 -> V=1.0, theta=0.0
% INFO    : Bus 11281	: V=1.03858, theta=23.545079 -> V=1.0, theta=0.0
% INFO    : Bus 11282	: V=1.022038, theta=27.354939 -> V=1.0, theta=0.0
% INFO    : Bus 11283	: V=1.056779, theta=25.810444 -> V=1.0, theta=0.0
% INFO    : Bus 11284	: V=1.053091, theta=-3.843098 -> V=1.0, theta=0.0
% INFO    : Bus 11285	: V=1.032344, theta=9.093698 -> V=1.0, theta=0.0
% INFO    : Bus 11286	: V=1.033669, theta=33.596335 -> V=1.0, theta=0.0
% INFO    : Bus 11287	: V=1.026297, theta=18.651014 -> V=1.0, theta=0.0
% INFO    : Bus 11288	: V=1.019745, theta=-19.936916 -> V=1.0, theta=0.0
% INFO    : Bus 11289	: V=1.035773, theta=21.901715 -> V=1.0, theta=0.0
% INFO    : Bus 11290	: V=1.001925, theta=28.994671 -> V=1.0, theta=0.0
% INFO    : Bus 11291	: V=0.960396, theta=-8.243085 -> V=1.0, theta=0.0
% INFO    : Bus 11292	: V=1.001636, theta=-3.640685 -> V=1.0, theta=0.0
% INFO    : Bus 11293	: V=1.025682, theta=-7.286792 -> V=1.0, theta=0.0
% INFO    : Bus 11294	: V=1.01249, theta=-3.900476 -> V=1.0, theta=0.0
% INFO    : Bus 11295	: V=1.032164, theta=20.172702 -> V=1.0, theta=0.0
% INFO    : Bus 11296	: V=1.07219, theta=19.888883 -> V=1.0, theta=0.0
% INFO    : Bus 11297	: V=1.019164, theta=45.629261 -> V=1.0, theta=0.0
% INFO    : Bus 11298	: V=1.005342, theta=94.829384 -> V=1.0, theta=0.0
% INFO    : Bus 11299	: V=1.065506, theta=1.014062 -> V=1.0, theta=0.0
% INFO    : Bus 11300	: V=1.006151, theta=-14.005277 -> V=1.0, theta=0.0
% INFO    : Bus 11301	: V=0.995276, theta=-10.528333 -> V=1.0, theta=0.0
% INFO    : Bus 11302	: V=1.09598, theta=24.803662 -> V=1.0, theta=0.0
% INFO    : Bus 11303	: V=0.954084, theta=-7.518624 -> V=1.0, theta=0.0
% INFO    : Bus 11304	: V=0.973019, theta=-2.59664 -> V=1.0, theta=0.0
% INFO    : Bus 11305	: V=1.028153, theta=78.700831 -> V=1.0, theta=0.0
% INFO    : Bus 11306	: V=0.971726, theta=-12.437265 -> V=1.0, theta=0.0
% INFO    : Bus 11307	: V=1.04834, theta=88.719592 -> V=1.0, theta=0.0
% INFO    : Bus 11308	: V=1.03671, theta=88.578657 -> V=1.0, theta=0.0
% INFO    : Bus 11309	: V=1.035773, theta=21.901715 -> V=1.0, theta=0.0
% INFO    : Bus 11310	: V=1.015777, theta=34.284954 -> V=1.0, theta=0.0
% INFO    : Bus 11311	: V=0.982004, theta=27.243336 -> V=1.0, theta=0.0
% INFO    : Bus 11312	: V=1.049674, theta=87.363329 -> V=1.0, theta=0.0
% INFO    : Bus 11313	: V=1.012944, theta=48.511806 -> V=1.0, theta=0.0
% INFO    : Bus 11314	: V=1.045933, theta=36.252184 -> V=1.0, theta=0.0
% INFO    : Bus 11315	: V=1.024544, theta=18.974877 -> V=1.0, theta=0.0
% INFO    : Bus 11316	: V=0.994483, theta=-3.900492 -> V=1.0, theta=0.0
% INFO    : Bus 11317	: V=1.05478, theta=8.215389 -> V=1.0, theta=0.0
% INFO    : Bus 11318	: V=0.880509, theta=-14.642882 -> V=1.0, theta=0.0
% INFO    : Bus 11319	: V=1.040709, theta=-0.335258 -> V=1.0, theta=0.0
% INFO    : Bus 11320	: V=0.979694, theta=-6.226744 -> V=1.0, theta=0.0
% INFO    : Bus 11321	: V=1.019059, theta=-14.535086 -> V=1.0, theta=0.0
% INFO    : Bus 11322	: V=1.002359, theta=-6.963059 -> V=1.0, theta=0.0
% INFO    : Bus 11323	: V=1.000147, theta=1.048084 -> V=1.0, theta=0.0
% INFO    : Bus 11324	: V=1.044735, theta=35.829517 -> V=1.0, theta=0.0
% INFO    : Bus 11325	: V=1.041409, theta=32.91812 -> V=1.0, theta=0.0
% INFO    : Bus 11326	: V=1.003473, theta=-3.77501 -> V=1.0, theta=0.0
% INFO    : Bus 11327	: V=1.024267, theta=0.497112 -> V=1.0, theta=0.0
% INFO    : Bus 11328	: V=1.050901, theta=18.201002 -> V=1.0, theta=0.0
% INFO    : Bus 11329	: V=0.988112, theta=23.208642 -> V=1.0, theta=0.0
% INFO    : Bus 11330	: V=1.049221, theta=26.031718 -> V=1.0, theta=0.0
% INFO    : Bus 11331	: V=1.005689, theta=36.422342 -> V=1.0, theta=0.0
% INFO    : Bus 11332	: V=1.077226, theta=12.556118 -> V=1.0, theta=0.0
% INFO    : Bus 11333	: V=1.077226, theta=12.556118 -> V=1.0, theta=0.0
% INFO    : Bus 11334	: V=1.031939, theta=26.447767 -> V=1.0, theta=0.0
% INFO    : Bus 11335	: V=1.01186, theta=2.974183 -> V=1.0, theta=0.0
% INFO    : Bus 11336	: V=1.023695, theta=-0.879651 -> V=1.0, theta=0.0
% INFO    : Bus 11337	: V=1.02527, theta=-3.478109 -> V=1.0, theta=0.0
% INFO    : Bus 11338	: V=0.929893, theta=-10.863302 -> V=1.0, theta=0.0
% INFO    : Bus 11339	: V=1.022049, theta=-0.726718 -> V=1.0, theta=0.0
% INFO    : Bus 11340	: V=1.019263, theta=25.887486 -> V=1.0, theta=0.0
% INFO    : Bus 11341	: V=1.052147, theta=0.192688 -> V=1.0, theta=0.0
% INFO    : Bus 11342	: V=1.02579, theta=7.134146 -> V=1.0, theta=0.0
% INFO    : Bus 11343	: V=1.0051, theta=-10.459769 -> V=1.0, theta=0.0
% INFO    : Bus 11344	: V=1.052164, theta=7.333527 -> V=1.0, theta=0.0
% INFO    : Bus 11345	: V=1.035102, theta=5.926523 -> V=1.0, theta=0.0
% INFO    : Bus 11346	: V=1.013977, theta=-15.655534 -> V=1.0, theta=0.0
% INFO    : Bus 11347	: V=1.021627, theta=-19.648509 -> V=1.0, theta=0.0
% INFO    : Bus 11348	: V=1.034643, theta=0.304854 -> V=1.0, theta=0.0
% INFO    : Bus 11349	: V=0.997344, theta=13.393742 -> V=1.0, theta=0.0
% INFO    : Bus 11350	: V=1.013977, theta=-15.655534 -> V=1.0, theta=0.0
% INFO    : Bus 11351	: V=1.025019, theta=-12.264635 -> V=1.0, theta=0.0
% INFO    : Bus 11352	: V=1.025019, theta=-12.264635 -> V=1.0, theta=0.0
% INFO    : Bus 11353	: V=1.034643, theta=0.304854 -> V=1.0, theta=0.0
% INFO    : Bus 11354	: V=0.984275, theta=-6.031468 -> V=1.0, theta=0.0
% INFO    : Bus 11355	: V=1.012747, theta=-6.745565 -> V=1.0, theta=0.0
% INFO    : Bus 11356	: V=0.991129, theta=19.563971 -> V=1.0, theta=0.0
% INFO    : Bus 11357	: V=1.005377, theta=4.629549 -> V=1.0, theta=0.0
% INFO    : Bus 11358	: V=1.017916, theta=24.245969 -> V=1.0, theta=0.0
% INFO    : Bus 11359	: V=1.004714, theta=20.616677 -> V=1.0, theta=0.0
% INFO    : Bus 11360	: V=1.086148, theta=2.994871 -> V=1.0, theta=0.0
% INFO    : Bus 11361	: V=1.085902, theta=3.862201 -> V=1.0, theta=0.0
% INFO    : Bus 11362	: V=1.085902, theta=3.862201 -> V=1.0, theta=0.0
% INFO    : Bus 11363	: V=1.02099, theta=1.431006 -> V=1.0, theta=0.0
% INFO    : Bus 11364	: V=1.06019, theta=67.358874 -> V=1.0, theta=0.0
% INFO    : Bus 11365	: V=1.028915, theta=25.353044 -> V=1.0, theta=0.0
% INFO    : Bus 11366	: V=1.051422, theta=54.686199 -> V=1.0, theta=0.0
% INFO    : Bus 11367	: V=1.06019, theta=67.358874 -> V=1.0, theta=0.0
% INFO    : Bus 11368	: V=1.06019, theta=67.358874 -> V=1.0, theta=0.0
% INFO    : Bus 11369	: V=1.06019, theta=67.358874 -> V=1.0, theta=0.0
% INFO    : Bus 11370	: V=1.06019, theta=67.358874 -> V=1.0, theta=0.0
% INFO    : Bus 11371	: V=1.062178, theta=11.667815 -> V=1.0, theta=0.0
% INFO    : Bus 11372	: V=0.994918, theta=-20.94236 -> V=1.0, theta=0.0
% INFO    : Bus 11373	: V=1.012764, theta=18.020749 -> V=1.0, theta=0.0
% INFO    : Bus 11374	: V=0.97735, theta=-26.907108 -> V=1.0, theta=0.0
% INFO    : Bus 11375	: V=1.034951, theta=-6.540792 -> V=1.0, theta=0.0
% INFO    : Bus 11376	: V=1.052654, theta=6.569125 -> V=1.0, theta=0.0
% INFO    : Bus 11377	: V=1.005433, theta=2.576087 -> V=1.0, theta=0.0
% INFO    : Bus 11378	: V=1.059916, theta=14.412289 -> V=1.0, theta=0.0
% INFO    : Bus 11379	: V=1.181, theta=3.660071 -> V=1.0, theta=0.0
% INFO    : Bus 11380	: V=0.980128, theta=0.905508 -> V=1.0, theta=0.0
% INFO    : Bus 11381	: V=1.006263, theta=-13.98211 -> V=1.0, theta=0.0
% INFO    : Bus 11382	: V=1.00314, theta=34.191295 -> V=1.0, theta=0.0
% INFO    : Bus 11383	: V=1.052148, theta=-6.603627 -> V=1.0, theta=0.0
% INFO    : Bus 11384	: V=1.053186, theta=6.507084 -> V=1.0, theta=0.0
% INFO    : Bus 11385	: V=0.96718, theta=-6.283516 -> V=1.0, theta=0.0
% INFO    : Bus 11386	: V=1.025113, theta=18.480146 -> V=1.0, theta=0.0
% INFO    : Bus 11387	: V=1.033489, theta=17.191314 -> V=1.0, theta=0.0
% INFO    : Bus 11388	: V=1.001041, theta=-8.121981 -> V=1.0, theta=0.0
% INFO    : Bus 11389	: V=1.011249, theta=20.694257 -> V=1.0, theta=0.0
% INFO    : Bus 11390	: V=1.03413, theta=-16.318991 -> V=1.0, theta=0.0
% INFO    : Bus 11391	: V=1.073637, theta=71.243837 -> V=1.0, theta=0.0
% INFO    : Bus 11392	: V=1.020228, theta=59.501729 -> V=1.0, theta=0.0
% INFO    : Bus 11393	: V=1.016106, theta=0.556804 -> V=1.0, theta=0.0
% INFO    : Bus 11394	: V=1.015825, theta=42.943198 -> V=1.0, theta=0.0
% INFO    : Bus 11395	: V=1.047997, theta=3.553626 -> V=1.0, theta=0.0
% INFO    : Bus 11396	: V=1.023472, theta=8.50061 -> V=1.0, theta=0.0
% INFO    : Bus 11397	: V=1.042313, theta=-6.262534 -> V=1.0, theta=0.0
% INFO    : Bus 11398	: V=1.015813, theta=3.035457 -> V=1.0, theta=0.0
% INFO    : Bus 11399	: V=1.020219, theta=2.145142 -> V=1.0, theta=0.0
% INFO    : Bus 11400	: V=1.082023, theta=35.200613 -> V=1.0, theta=0.0
% INFO    : Bus 11401	: V=1.050328, theta=7.929133 -> V=1.0, theta=0.0
% INFO    : Bus 11402	: V=1.048807, theta=12.651704 -> V=1.0, theta=0.0
% INFO    : Bus 11403	: V=1.039038, theta=39.160421 -> V=1.0, theta=0.0
% INFO    : Bus 11404	: V=0.959868, theta=-6.582302 -> V=1.0, theta=0.0
% INFO    : Bus 11405	: V=1.015046, theta=16.817691 -> V=1.0, theta=0.0
% INFO    : Bus 11406	: V=1.050841, theta=90.684517 -> V=1.0, theta=0.0
% INFO    : Bus 11407	: V=1.006256, theta=26.531463 -> V=1.0, theta=0.0
% INFO    : Bus 11408	: V=1.013014, theta=63.774723 -> V=1.0, theta=0.0
% INFO    : Bus 11409	: V=1.013014, theta=63.774723 -> V=1.0, theta=0.0
% INFO    : Bus 11410	: V=1.030034, theta=63.293305 -> V=1.0, theta=0.0
% INFO    : Bus 11411	: V=1.035618, theta=-0.462639 -> V=1.0, theta=0.0
% INFO    : Bus 11412	: V=1.035618, theta=-0.462639 -> V=1.0, theta=0.0
% INFO    : Bus 11413	: V=0.998061, theta=-2.568006 -> V=1.0, theta=0.0
% INFO    : Bus 11414	: V=1.035618, theta=-0.462639 -> V=1.0, theta=0.0
% INFO    : Bus 11415	: V=0.972366, theta=-6.443004 -> V=1.0, theta=0.0
% INFO    : Bus 11416	: V=1.035618, theta=-0.462639 -> V=1.0, theta=0.0
% INFO    : Bus 11417	: V=1.042395, theta=5.320062 -> V=1.0, theta=0.0
% INFO    : Bus 11418	: V=1.051278, theta=31.614896 -> V=1.0, theta=0.0
% INFO    : Bus 11419	: V=1.051278, theta=31.614941 -> V=1.0, theta=0.0
% INFO    : Bus 11420	: V=1.002435, theta=-22.866408 -> V=1.0, theta=0.0
% INFO    : Bus 11421	: V=1.009157, theta=2.687917 -> V=1.0, theta=0.0
% INFO    : Bus 11422	: V=0.976924, theta=30.187846 -> V=1.0, theta=0.0
% INFO    : Bus 11423	: V=1.013272, theta=-1.439863 -> V=1.0, theta=0.0
% INFO    : Bus 11424	: V=1.021625, theta=18.108773 -> V=1.0, theta=0.0
% INFO    : Bus 11425	: V=1.002261, theta=-10.056932 -> V=1.0, theta=0.0
% INFO    : Bus 11426	: V=0.961189, theta=-4.928205 -> V=1.0, theta=0.0
% INFO    : Bus 11427	: V=0.997223, theta=15.348082 -> V=1.0, theta=0.0
% INFO    : Bus 11428	: V=0.991226, theta=-23.290634 -> V=1.0, theta=0.0
% INFO    : Bus 11429	: V=1.052317, theta=-2.667381 -> V=1.0, theta=0.0
% INFO    : Bus 11430	: V=0.97744, theta=5.937442 -> V=1.0, theta=0.0
% INFO    : Bus 11431	: V=1.012224, theta=7.433648 -> V=1.0, theta=0.0
% INFO    : Bus 11432	: V=1.010935, theta=29.835678 -> V=1.0, theta=0.0
% INFO    : Bus 11433	: V=0.996251, theta=-7.108586 -> V=1.0, theta=0.0
% INFO    : Bus 11434	: V=1.018338, theta=-8.533019 -> V=1.0, theta=0.0
% INFO    : Bus 11435	: V=1.028279, theta=-3.670442 -> V=1.0, theta=0.0
% INFO    : Bus 11436	: V=1.030579, theta=39.766653 -> V=1.0, theta=0.0
% INFO    : Bus 11437	: V=0.981251, theta=-5.256502 -> V=1.0, theta=0.0
% INFO    : Bus 11438	: V=1.014925, theta=-26.692737 -> V=1.0, theta=0.0
% INFO    : Bus 11439	: V=0.974858, theta=5.221454 -> V=1.0, theta=0.0
% INFO    : Bus 11440	: V=0.984601, theta=26.113188 -> V=1.0, theta=0.0
% INFO    : Bus 11441	: V=1.110503, theta=1.036394 -> V=1.0, theta=0.0
% INFO    : Bus 11442	: V=1.054224, theta=30.71588 -> V=1.0, theta=0.0
% INFO    : Bus 11443	: V=0.988541, theta=17.0878 -> V=1.0, theta=0.0
% INFO    : Bus 11444	: V=0.977862, theta=-8.626469 -> V=1.0, theta=0.0
% INFO    : Bus 11445	: V=1.034682, theta=-22.435771 -> V=1.0, theta=0.0
% INFO    : Bus 11446	: V=1.038413, theta=11.908771 -> V=1.0, theta=0.0
% INFO    : Bus 11447	: V=1.031657, theta=79.191379 -> V=1.0, theta=0.0
% INFO    : Bus 11448	: V=1.056599, theta=16.07956 -> V=1.0, theta=0.0
% INFO    : Bus 11449	: V=1.001069, theta=5.906574 -> V=1.0, theta=0.0
% INFO    : Bus 11450	: V=0.956504, theta=0.050308 -> V=1.0, theta=0.0
% INFO    : Bus 11451	: V=1.027023, theta=17.407089 -> V=1.0, theta=0.0
% INFO    : Bus 11452	: V=1.004233, theta=-6.701569 -> V=1.0, theta=0.0
% INFO    : Bus 11453	: V=1.005946, theta=5.461847 -> V=1.0, theta=0.0
% INFO    : Bus 11454	: V=1.013471, theta=23.648482 -> V=1.0, theta=0.0
% INFO    : Bus 11455	: V=1.013471, theta=23.648482 -> V=1.0, theta=0.0
% INFO    : Bus 11456	: V=1.001613, theta=16.787108 -> V=1.0, theta=0.0
% INFO    : Bus 11457	: V=1.000465, theta=12.056714 -> V=1.0, theta=0.0
% INFO    : Bus 11458	: V=1.000465, theta=12.056714 -> V=1.0, theta=0.0
% INFO    : Bus 11459	: V=1.000465, theta=12.056714 -> V=1.0, theta=0.0
% INFO    : Bus 11460	: V=1.012362, theta=-10.049221 -> V=1.0, theta=0.0
% INFO    : Bus 11461	: V=1.063704, theta=66.981987 -> V=1.0, theta=0.0
% INFO    : Bus 11462	: V=1.018804, theta=38.015302 -> V=1.0, theta=0.0
% INFO    : Bus 11463	: V=1.063704, theta=66.981987 -> V=1.0, theta=0.0
% INFO    : Bus 11464	: V=1.063704, theta=66.981987 -> V=1.0, theta=0.0
% INFO    : Bus 11465	: V=1.007297, theta=16.512842 -> V=1.0, theta=0.0
% INFO    : Bus 11466	: V=1.009763, theta=-12.59241 -> V=1.0, theta=0.0
% INFO    : Bus 11467	: V=1.040642, theta=8.532255 -> V=1.0, theta=0.0
% INFO    : Bus 11468	: V=1.037667, theta=-14.462311 -> V=1.0, theta=0.0
% INFO    : Bus 11469	: V=1.026209, theta=-27.036398 -> V=1.0, theta=0.0
% INFO    : Bus 11470	: V=1.011959, theta=-23.601992 -> V=1.0, theta=0.0
% INFO    : Bus 11471	: V=1.026413, theta=2.766853 -> V=1.0, theta=0.0
% INFO    : Bus 11472	: V=1.035329, theta=26.785392 -> V=1.0, theta=0.0
% INFO    : Bus 11473	: V=1.017601, theta=-9.8258 -> V=1.0, theta=0.0
% INFO    : Bus 11474	: V=1.036049, theta=1.565792 -> V=1.0, theta=0.0
% INFO    : Bus 11475	: V=1.035259, theta=26.774039 -> V=1.0, theta=0.0
% INFO    : Bus 11476	: V=0.834005, theta=-17.59375 -> V=1.0, theta=0.0
% INFO    : Bus 11477	: V=1.035329, theta=26.785392 -> V=1.0, theta=0.0
% INFO    : Bus 11478	: V=1.035259, theta=26.774039 -> V=1.0, theta=0.0
% INFO    : Bus 11479	: V=1.035499, theta=26.862046 -> V=1.0, theta=0.0
% INFO    : Bus 11480	: V=1.035431, theta=26.859737 -> V=1.0, theta=0.0
% INFO    : Bus 11481	: V=1.019623, theta=1.497251 -> V=1.0, theta=0.0
% INFO    : Bus 11482	: V=1.022039, theta=16.134374 -> V=1.0, theta=0.0
% INFO    : Bus 11483	: V=1.063714, theta=6.510197 -> V=1.0, theta=0.0
% INFO    : Bus 11484	: V=1.037469, theta=11.940478 -> V=1.0, theta=0.0
% INFO    : Bus 11485	: V=0.978613, theta=-8.136031 -> V=1.0, theta=0.0
% INFO    : Bus 11486	: V=0.993188, theta=-7.06422 -> V=1.0, theta=0.0
% INFO    : Bus 11487	: V=1.042317, theta=14.274354 -> V=1.0, theta=0.0
% INFO    : Bus 11488	: V=1.043769, theta=-17.010151 -> V=1.0, theta=0.0
% INFO    : Bus 11489	: V=1.051219, theta=0.292959 -> V=1.0, theta=0.0
% INFO    : Bus 11490	: V=1.036739, theta=-15.108104 -> V=1.0, theta=0.0
% INFO    : Bus 11491	: V=1.050366, theta=-6.017105 -> V=1.0, theta=0.0
% INFO    : Bus 11492	: V=0.970854, theta=29.381452 -> V=1.0, theta=0.0
% INFO    : Bus 11493	: V=1.051816, theta=27.634038 -> V=1.0, theta=0.0
% INFO    : Bus 11494	: V=1.069655, theta=-1.580413 -> V=1.0, theta=0.0
% INFO    : Bus 11495	: V=0.994132, theta=-4.107772 -> V=1.0, theta=0.0
% INFO    : Bus 11496	: V=1.062896, theta=-0.392816 -> V=1.0, theta=0.0
% INFO    : Bus 11497	: V=1.029009, theta=32.575777 -> V=1.0, theta=0.0
% INFO    : Bus 11498	: V=1.029009, theta=32.575777 -> V=1.0, theta=0.0
% INFO    : Bus 11499	: V=1.029009, theta=32.575777 -> V=1.0, theta=0.0
% INFO    : Bus 11500	: V=1.029009, theta=32.575777 -> V=1.0, theta=0.0
% INFO    : Bus 11501	: V=1.025734, theta=-19.195718 -> V=1.0, theta=0.0
% INFO    : Bus 11502	: V=1.017349, theta=20.721078 -> V=1.0, theta=0.0
% INFO    : Bus 11503	: V=1.001734, theta=-25.89184 -> V=1.0, theta=0.0
% INFO    : Bus 11504	: V=1.022885, theta=22.331648 -> V=1.0, theta=0.0
% INFO    : Bus 11505	: V=1.024319, theta=-2.010067 -> V=1.0, theta=0.0
% INFO    : Bus 11506	: V=1.062896, theta=-0.392816 -> V=1.0, theta=0.0
% INFO    : Bus 11507	: V=1.062896, theta=-0.392816 -> V=1.0, theta=0.0
% INFO    : Bus 11508	: V=0.988502, theta=2.309053 -> V=1.0, theta=0.0
% INFO    : Bus 11509	: V=1.013195, theta=9.237936 -> V=1.0, theta=0.0
% INFO    : Bus 11510	: V=1.03324, theta=-5.012105 -> V=1.0, theta=0.0
% INFO    : Bus 11511	: V=1.019793, theta=-7.561936 -> V=1.0, theta=0.0
% INFO    : Bus 11512	: V=0.985835, theta=-4.027629 -> V=1.0, theta=0.0
% INFO    : Bus 11513	: V=1.080848, theta=2.641129 -> V=1.0, theta=0.0
% INFO    : Bus 11514	: V=0.973933, theta=-8.952943 -> V=1.0, theta=0.0
% INFO    : Bus 11515	: V=1.056507, theta=27.96286 -> V=1.0, theta=0.0
% INFO    : Bus 11516	: V=0.969418, theta=-8.813263 -> V=1.0, theta=0.0
% INFO    : Bus 11517	: V=0.984712, theta=15.209887 -> V=1.0, theta=0.0
% INFO    : Bus 11518	: V=1.060327, theta=8.879279 -> V=1.0, theta=0.0
% INFO    : Bus 11519	: V=1.036174, theta=36.321501 -> V=1.0, theta=0.0
% INFO    : Bus 11520	: V=1.023361, theta=29.828652 -> V=1.0, theta=0.0
% INFO    : Bus 11521	: V=1.024274, theta=-9.95923 -> V=1.0, theta=0.0
% INFO    : Bus 11522	: V=1.020685, theta=7.63502 -> V=1.0, theta=0.0
% INFO    : Bus 11523	: V=1.031502, theta=0.465782 -> V=1.0, theta=0.0
% INFO    : Bus 11524	: V=1.031502, theta=0.465782 -> V=1.0, theta=0.0
% INFO    : Bus 11525	: V=1.031502, theta=0.465782 -> V=1.0, theta=0.0
% INFO    : Bus 11526	: V=1.031502, theta=0.465782 -> V=1.0, theta=0.0
% INFO    : Bus 11527	: V=1.03122, theta=1.037828 -> V=1.0, theta=0.0
% INFO    : Bus 11528	: V=1.03122, theta=1.037828 -> V=1.0, theta=0.0
% INFO    : Bus 11529	: V=1.007216, theta=-1.420425 -> V=1.0, theta=0.0
% INFO    : Bus 11530	: V=1.03122, theta=1.037828 -> V=1.0, theta=0.0
% INFO    : Bus 11531	: V=1.03616, theta=-10.170176 -> V=1.0, theta=0.0
% INFO    : Bus 11532	: V=1.017123, theta=21.904571 -> V=1.0, theta=0.0
% INFO    : Bus 11533	: V=1.000846, theta=-7.407948 -> V=1.0, theta=0.0
% INFO    : Bus 11534	: V=1.029093, theta=49.644716 -> V=1.0, theta=0.0
% INFO    : Bus 11535	: V=0.970932, theta=21.818127 -> V=1.0, theta=0.0
% INFO    : Bus 11536	: V=1.023361, theta=29.828652 -> V=1.0, theta=0.0
% INFO    : Bus 11537	: V=1.052535, theta=7.6299 -> V=1.0, theta=0.0
% INFO    : Bus 11538	: V=0.990321, theta=23.849769 -> V=1.0, theta=0.0
% INFO    : Bus 11539	: V=1.056762, theta=11.950776 -> V=1.0, theta=0.0
% INFO    : Bus 11540	: V=0.987018, theta=-4.48064 -> V=1.0, theta=0.0
% INFO    : Bus 11541	: V=1.006736, theta=55.801921 -> V=1.0, theta=0.0
% INFO    : Bus 11542	: V=0.996405, theta=-7.172261 -> V=1.0, theta=0.0
% INFO    : Bus 11543	: V=1.050293, theta=43.935202 -> V=1.0, theta=0.0
% INFO    : Bus 11544	: V=1.034667, theta=29.874033 -> V=1.0, theta=0.0
% INFO    : Bus 11545	: V=1.034377, theta=-13.734738 -> V=1.0, theta=0.0
% INFO    : Bus 11546	: V=0.995183, theta=32.889399 -> V=1.0, theta=0.0
% INFO    : Bus 11547	: V=1.048459, theta=-12.77196 -> V=1.0, theta=0.0
% INFO    : Bus 11548	: V=1.036105, theta=-7.389707 -> V=1.0, theta=0.0
% INFO    : Bus 11549	: V=0.995145, theta=31.935435 -> V=1.0, theta=0.0
% INFO    : Bus 11550	: V=0.988946, theta=17.967208 -> V=1.0, theta=0.0
% INFO    : Bus 11551	: V=1.054159, theta=6.298568 -> V=1.0, theta=0.0
% INFO    : Bus 11552	: V=0.964189, theta=-9.676227 -> V=1.0, theta=0.0
% INFO    : Bus 11553	: V=0.988905, theta=-7.944058 -> V=1.0, theta=0.0
% INFO    : Bus 11554	: V=0.970038, theta=-5.739908 -> V=1.0, theta=0.0
% INFO    : Bus 11555	: V=1.011924, theta=12.571042 -> V=1.0, theta=0.0
% INFO    : Bus 11556	: V=1.025664, theta=3.941893 -> V=1.0, theta=0.0
% INFO    : Bus 11557	: V=0.994823, theta=-7.7742 -> V=1.0, theta=0.0
% INFO    : Bus 11558	: V=1.019231, theta=22.327173 -> V=1.0, theta=0.0
% INFO    : Bus 11559	: V=1.022691, theta=-10.833665 -> V=1.0, theta=0.0
% INFO    : Bus 11560	: V=1.021419, theta=-22.29244 -> V=1.0, theta=0.0
% INFO    : Bus 11561	: V=1.05421, theta=6.879607 -> V=1.0, theta=0.0
% INFO    : Bus 11562	: V=0.978211, theta=-7.893051 -> V=1.0, theta=0.0
% INFO    : Bus 11563	: V=1.029712, theta=9.125452 -> V=1.0, theta=0.0
% INFO    : Bus 11564	: V=1.033947, theta=-9.228621 -> V=1.0, theta=0.0
% INFO    : Bus 11565	: V=1.047277, theta=7.939752 -> V=1.0, theta=0.0
% INFO    : Bus 11566	: V=0.985612, theta=-18.102016 -> V=1.0, theta=0.0
% INFO    : Bus 11567	: V=1.019305, theta=44.637887 -> V=1.0, theta=0.0
% INFO    : Bus 11568	: V=1.032238, theta=-4.146012 -> V=1.0, theta=0.0
% INFO    : Bus 11569	: V=1.032238, theta=-4.146012 -> V=1.0, theta=0.0
% INFO    : Bus 11570	: V=1.026319, theta=-4.093349 -> V=1.0, theta=0.0
% INFO    : Bus 11571	: V=1.037776, theta=30.45979 -> V=1.0, theta=0.0
% INFO    : Bus 11572	: V=0.952007, theta=-28.718282 -> V=1.0, theta=0.0
% INFO    : Bus 11573	: V=1.024079, theta=44.848437 -> V=1.0, theta=0.0
% INFO    : Bus 11574	: V=1.052808, theta=14.230733 -> V=1.0, theta=0.0
% INFO    : Bus 11575	: V=1.029478, theta=-2.341076 -> V=1.0, theta=0.0
% INFO    : Bus 11576	: V=1.027086, theta=0.614256 -> V=1.0, theta=0.0
% INFO    : Bus 11577	: V=0.990908, theta=15.83898 -> V=1.0, theta=0.0
% INFO    : Bus 11578	: V=1.016999, theta=60.332496 -> V=1.0, theta=0.0
% INFO    : Bus 11579	: V=1.050987, theta=40.998977 -> V=1.0, theta=0.0
% INFO    : Bus 11580	: V=1.023809, theta=10.838684 -> V=1.0, theta=0.0
% INFO    : Bus 11581	: V=0.995022, theta=23.934845 -> V=1.0, theta=0.0
% INFO    : Bus 11582	: V=1.033386, theta=9.187824 -> V=1.0, theta=0.0
% INFO    : Bus 11583	: V=1.001509, theta=9.954559 -> V=1.0, theta=0.0
% INFO    : Bus 11584	: V=1.00419, theta=31.464758 -> V=1.0, theta=0.0
% INFO    : Bus 11585	: V=1.004923, theta=90.798314 -> V=1.0, theta=0.0
% INFO    : Bus 11586	: V=1.052394, theta=33.692026 -> V=1.0, theta=0.0
% INFO    : Bus 11587	: V=1.030635, theta=2.430468 -> V=1.0, theta=0.0
% INFO    : Bus 11588	: V=1.029344, theta=21.964639 -> V=1.0, theta=0.0
% INFO    : Bus 11589	: V=1.05536, theta=4.225642 -> V=1.0, theta=0.0
% INFO    : Bus 11590	: V=1.022638, theta=24.068742 -> V=1.0, theta=0.0
% INFO    : Bus 11591	: V=1.021461, theta=-8.576014 -> V=1.0, theta=0.0
% INFO    : Bus 11592	: V=1.023532, theta=17.869884 -> V=1.0, theta=0.0
% INFO    : Bus 11593	: V=1.013843, theta=-20.803128 -> V=1.0, theta=0.0
% INFO    : Bus 11594	: V=1.01472, theta=35.673432 -> V=1.0, theta=0.0
% INFO    : Bus 11595	: V=1.039128, theta=10.819615 -> V=1.0, theta=0.0
% INFO    : Bus 11596	: V=1.039377, theta=14.867516 -> V=1.0, theta=0.0
% INFO    : Bus 11597	: V=0.988782, theta=-5.594179 -> V=1.0, theta=0.0
% INFO    : Bus 11598	: V=1.061414, theta=49.736419 -> V=1.0, theta=0.0
% INFO    : Bus 11599	: V=1.045359, theta=9.917398 -> V=1.0, theta=0.0
% INFO    : Bus 11600	: V=1.031054, theta=10.435949 -> V=1.0, theta=0.0
% INFO    : Bus 11601	: V=1.02841, theta=11.034704 -> V=1.0, theta=0.0
% INFO    : Bus 11602	: V=1.045359, theta=9.917398 -> V=1.0, theta=0.0
% INFO    : Bus 11603	: V=1.022352, theta=20.659989 -> V=1.0, theta=0.0
% INFO    : Bus 11604	: V=1.022352, theta=20.659989 -> V=1.0, theta=0.0
% INFO    : Bus 11605	: V=1.031054, theta=10.435949 -> V=1.0, theta=0.0
% INFO    : Bus 11606	: V=1.031054, theta=10.435949 -> V=1.0, theta=0.0
% INFO    : Bus 11607	: V=1.02032, theta=9.008458 -> V=1.0, theta=0.0
% INFO    : Bus 11608	: V=1.031085, theta=-14.460229 -> V=1.0, theta=0.0
% INFO    : Bus 11609	: V=1.015791, theta=22.756082 -> V=1.0, theta=0.0
% INFO    : Bus 11610	: V=1.017753, theta=-8.026498 -> V=1.0, theta=0.0
% INFO    : Bus 11611	: V=1.043059, theta=9.285297 -> V=1.0, theta=0.0
% INFO    : Bus 11612	: V=0.98336, theta=22.995978 -> V=1.0, theta=0.0
% INFO    : Bus 11613	: V=1.052439, theta=-6.564757 -> V=1.0, theta=0.0
% INFO    : Bus 11614	: V=0.975047, theta=41.518085 -> V=1.0, theta=0.0
% INFO    : Bus 11615	: V=1.018322, theta=-0.328638 -> V=1.0, theta=0.0
% INFO    : Bus 11616	: V=1.004155, theta=27.356143 -> V=1.0, theta=0.0
% INFO    : Bus 11617	: V=1.009173, theta=19.132388 -> V=1.0, theta=0.0
% INFO    : Bus 11618	: V=1.102278, theta=-15.190395 -> V=1.0, theta=0.0
% INFO    : Bus 11619	: V=1.041353, theta=7.871779 -> V=1.0, theta=0.0
% INFO    : Bus 11620	: V=0.940462, theta=-11.519394 -> V=1.0, theta=0.0
% INFO    : Bus 11621	: V=0.992991, theta=15.869625 -> V=1.0, theta=0.0
% INFO    : Bus 11622	: V=0.992991, theta=15.869625 -> V=1.0, theta=0.0
% INFO    : Bus 11623	: V=1.009173, theta=19.132388 -> V=1.0, theta=0.0
% INFO    : Bus 11624	: V=1.009173, theta=19.132388 -> V=1.0, theta=0.0
% INFO    : Bus 11625	: V=1.014865, theta=17.912579 -> V=1.0, theta=0.0
% INFO    : Bus 11626	: V=1.014865, theta=17.912579 -> V=1.0, theta=0.0
% INFO    : Bus 11627	: V=1.017817, theta=42.272152 -> V=1.0, theta=0.0
% INFO    : Bus 11628	: V=1.020622, theta=-11.444475 -> V=1.0, theta=0.0
% INFO    : Bus 11629	: V=1.04378, theta=11.735527 -> V=1.0, theta=0.0
% INFO    : Bus 11630	: V=0.991989, theta=39.317054 -> V=1.0, theta=0.0
% INFO    : Bus 11631	: V=1.050944, theta=40.491716 -> V=1.0, theta=0.0
% INFO    : Bus 11632	: V=1.0508, theta=40.476149 -> V=1.0, theta=0.0
% INFO    : Bus 11633	: V=1.04927, theta=45.669864 -> V=1.0, theta=0.0
% INFO    : Bus 11634	: V=1.050944, theta=40.491716 -> V=1.0, theta=0.0
% INFO    : Bus 11635	: V=1.0508, theta=40.476149 -> V=1.0, theta=0.0
% INFO    : Bus 11636	: V=1.00649, theta=19.103021 -> V=1.0, theta=0.0
% INFO    : Bus 11637	: V=1.053823, theta=0.430007 -> V=1.0, theta=0.0
% INFO    : Bus 11638	: V=1.012679, theta=-1.92622 -> V=1.0, theta=0.0
% INFO    : Bus 11639	: V=1.01915, theta=23.7232 -> V=1.0, theta=0.0
% INFO    : Bus 11640	: V=1.031648, theta=8.37821 -> V=1.0, theta=0.0
% INFO    : Bus 11641	: V=1.00746, theta=39.171104 -> V=1.0, theta=0.0
% INFO    : Bus 11642	: V=1.029112, theta=7.476738 -> V=1.0, theta=0.0
% INFO    : Bus 11643	: V=1.035771, theta=2.999441 -> V=1.0, theta=0.0
% INFO    : Bus 11644	: V=1.03531, theta=20.027062 -> V=1.0, theta=0.0
% INFO    : Bus 11645	: V=1.045347, theta=-15.357554 -> V=1.0, theta=0.0
% INFO    : Bus 11646	: V=0.955328, theta=-7.482884 -> V=1.0, theta=0.0
% INFO    : Bus 11647	: V=0.969264, theta=32.129316 -> V=1.0, theta=0.0
% INFO    : Bus 11648	: V=1.029166, theta=13.522836 -> V=1.0, theta=0.0
% INFO    : Bus 11649	: V=1.023418, theta=29.920304 -> V=1.0, theta=0.0
% INFO    : Bus 11650	: V=1.030951, theta=60.569581 -> V=1.0, theta=0.0
% INFO    : Bus 11651	: V=0.987257, theta=-3.558123 -> V=1.0, theta=0.0
% INFO    : Bus 11652	: V=1.015374, theta=8.632692 -> V=1.0, theta=0.0
% INFO    : Bus 11653	: V=1.051675, theta=-1.334511 -> V=1.0, theta=0.0
% INFO    : Bus 11654	: V=1.027264, theta=14.46311 -> V=1.0, theta=0.0
% INFO    : Bus 11655	: V=0.977412, theta=-27.214747 -> V=1.0, theta=0.0
% INFO    : Bus 11656	: V=1.041642, theta=19.877159 -> V=1.0, theta=0.0
% INFO    : Bus 11657	: V=1.020195, theta=-15.690329 -> V=1.0, theta=0.0
% INFO    : Bus 11658	: V=0.992732, theta=2.429388 -> V=1.0, theta=0.0
% INFO    : Bus 11659	: V=1.068375, theta=74.040783 -> V=1.0, theta=0.0
% INFO    : Bus 11660	: V=1.032044, theta=38.537454 -> V=1.0, theta=0.0
% INFO    : Bus 11661	: V=1.007654, theta=15.013591 -> V=1.0, theta=0.0
% INFO    : Bus 11662	: V=1.035273, theta=21.970264 -> V=1.0, theta=0.0
% INFO    : Bus 11663	: V=1.019769, theta=-3.333231 -> V=1.0, theta=0.0
% INFO    : Bus 11664	: V=1.004491, theta=-12.436802 -> V=1.0, theta=0.0
% INFO    : Bus 11665	: V=0.947933, theta=57.203162 -> V=1.0, theta=0.0
% INFO    : Bus 11666	: V=1.032102, theta=-0.219036 -> V=1.0, theta=0.0
% INFO    : Bus 11667	: V=1.032102, theta=-0.219036 -> V=1.0, theta=0.0
% INFO    : Bus 11668	: V=1.032102, theta=-0.219036 -> V=1.0, theta=0.0
% INFO    : Bus 11669	: V=1.032102, theta=-0.219036 -> V=1.0, theta=0.0
% INFO    : Bus 11670	: V=1.032102, theta=-0.219036 -> V=1.0, theta=0.0
% INFO    : Bus 11671	: V=1.021237, theta=23.717974 -> V=1.0, theta=0.0
% INFO    : Bus 11672	: V=1.018847, theta=32.305408 -> V=1.0, theta=0.0
% INFO    : Bus 11673	: V=1.02462, theta=-12.151463 -> V=1.0, theta=0.0
% INFO    : Bus 11674	: V=1.021472, theta=42.962213 -> V=1.0, theta=0.0
% INFO    : Bus 11675	: V=1.033912, theta=12.93783 -> V=1.0, theta=0.0
% INFO    : Bus 11676	: V=1.010939, theta=25.120796 -> V=1.0, theta=0.0
% INFO    : Bus 11677	: V=1.058213, theta=27.963025 -> V=1.0, theta=0.0
% INFO    : Bus 11678	: V=1.036103, theta=23.985216 -> V=1.0, theta=0.0
% INFO    : Bus 11679	: V=1.059879, theta=-2.236576 -> V=1.0, theta=0.0
% INFO    : Bus 11680	: V=1.026027, theta=-7.002651 -> V=1.0, theta=0.0
% INFO    : Bus 11681	: V=1.012673, theta=-2.175699 -> V=1.0, theta=0.0
% INFO    : Bus 11682	: V=1.0437, theta=6.318844 -> V=1.0, theta=0.0
% INFO    : Bus 11683	: V=1.014036, theta=28.98618 -> V=1.0, theta=0.0
% INFO    : Bus 11684	: V=1.027671, theta=29.425746 -> V=1.0, theta=0.0
% INFO    : Bus 11685	: V=0.989283, theta=27.206785 -> V=1.0, theta=0.0
% INFO    : Bus 11686	: V=1.015505, theta=-3.112218 -> V=1.0, theta=0.0
% INFO    : Bus 11687	: V=1.01946, theta=-9.574196 -> V=1.0, theta=0.0
% INFO    : Bus 11688	: V=1.047817, theta=24.207232 -> V=1.0, theta=0.0
% INFO    : Bus 11689	: V=1.005775, theta=-8.537815 -> V=1.0, theta=0.0
% INFO    : Bus 11690	: V=1.005775, theta=-8.537815 -> V=1.0, theta=0.0
% INFO    : Bus 11691	: V=1.005775, theta=-8.537815 -> V=1.0, theta=0.0
% INFO    : Bus 11692	: V=1.005775, theta=-8.537815 -> V=1.0, theta=0.0
% INFO    : Bus 11693	: V=1.005775, theta=-8.537815 -> V=1.0, theta=0.0
% INFO    : Bus 11694	: V=1.015029, theta=3.043049 -> V=1.0, theta=0.0
% INFO    : Bus 11695	: V=1.015029, theta=3.043049 -> V=1.0, theta=0.0
% INFO    : Bus 11696	: V=1.079269, theta=5.904616 -> V=1.0, theta=0.0
% INFO    : Bus 11697	: V=1.018627, theta=-2.342489 -> V=1.0, theta=0.0
% INFO    : Bus 11698	: V=1.02038, theta=17.569195 -> V=1.0, theta=0.0
% INFO    : Bus 11699	: V=1.035838, theta=-5.172678 -> V=1.0, theta=0.0
% INFO    : Bus 11700	: V=1.021285, theta=26.180239 -> V=1.0, theta=0.0
% INFO    : Bus 11701	: V=1.127132, theta=-1.539016 -> V=1.0, theta=0.0
% INFO    : Bus 11702	: V=1.045492, theta=35.801591 -> V=1.0, theta=0.0
% INFO    : Bus 11703	: V=1.059179, theta=30.508917 -> V=1.0, theta=0.0
% INFO    : Bus 11704	: V=1.047549, theta=4.244102 -> V=1.0, theta=0.0
% INFO    : Bus 11705	: V=1.003732, theta=-4.459321 -> V=1.0, theta=0.0
% INFO    : Bus 11706	: V=0.997366, theta=-14.326802 -> V=1.0, theta=0.0
% INFO    : Bus 11707	: V=1.049541, theta=0.642038 -> V=1.0, theta=0.0
% INFO    : Bus 11708	: V=1.015869, theta=-10.791845 -> V=1.0, theta=0.0
% INFO    : Bus 11709	: V=1.014893, theta=-9.156289 -> V=1.0, theta=0.0
% INFO    : Bus 11710	: V=1.001826, theta=2.228946 -> V=1.0, theta=0.0
% INFO    : Bus 11711	: V=1.024531, theta=-10.409141 -> V=1.0, theta=0.0
% INFO    : Bus 11712	: V=0.958243, theta=-7.97843 -> V=1.0, theta=0.0
% INFO    : Bus 11713	: V=1.0182, theta=22.6787 -> V=1.0, theta=0.0
% INFO    : Bus 11714	: V=1.0182, theta=22.6787 -> V=1.0, theta=0.0
% INFO    : Bus 11715	: V=0.967345, theta=5.815652 -> V=1.0, theta=0.0
% INFO    : Bus 11716	: V=1.024861, theta=-2.735628 -> V=1.0, theta=0.0
% INFO    : Bus 11717	: V=1.042492, theta=18.795962 -> V=1.0, theta=0.0
% INFO    : Bus 11718	: V=1.02973, theta=-21.007744 -> V=1.0, theta=0.0
% INFO    : Bus 11719	: V=1.039836, theta=-14.881275 -> V=1.0, theta=0.0
% INFO    : Bus 11720	: V=0.991694, theta=-4.403598 -> V=1.0, theta=0.0
% INFO    : Bus 11721	: V=1.023018, theta=33.158363 -> V=1.0, theta=0.0
% INFO    : Bus 11722	: V=1.01975, theta=9.799079 -> V=1.0, theta=0.0
% INFO    : Bus 11723	: V=1.050494, theta=10.971923 -> V=1.0, theta=0.0
% INFO    : Bus 11724	: V=1.014816, theta=31.102888 -> V=1.0, theta=0.0
% INFO    : Bus 11725	: V=1.013341, theta=-26.927209 -> V=1.0, theta=0.0
% INFO    : Bus 11726	: V=1.025187, theta=10.345307 -> V=1.0, theta=0.0
% INFO    : Bus 11727	: V=0.96359, theta=-0.680295 -> V=1.0, theta=0.0
% INFO    : Bus 11728	: V=0.924746, theta=-12.203993 -> V=1.0, theta=0.0
% INFO    : Bus 11729	: V=1.036966, theta=15.051213 -> V=1.0, theta=0.0
% INFO    : Bus 11730	: V=1.019724, theta=-7.10214 -> V=1.0, theta=0.0
% INFO    : Bus 11731	: V=0.997872, theta=29.769503 -> V=1.0, theta=0.0
% INFO    : Bus 11732	: V=1.012944, theta=32.566079 -> V=1.0, theta=0.0
% INFO    : Bus 11733	: V=0.999881, theta=-2.01284 -> V=1.0, theta=0.0
% INFO    : Bus 11734	: V=1.041776, theta=36.108702 -> V=1.0, theta=0.0
% INFO    : Bus 11735	: V=1.07361, theta=4.31055 -> V=1.0, theta=0.0
% INFO    : Bus 11736	: V=1.046239, theta=4.338704 -> V=1.0, theta=0.0
% INFO    : Bus 11737	: V=1.033684, theta=-16.072132 -> V=1.0, theta=0.0
% INFO    : Bus 11738	: V=1.033098, theta=-19.377215 -> V=1.0, theta=0.0
% INFO    : Bus 11739	: V=1.024838, theta=0.506407 -> V=1.0, theta=0.0
% INFO    : Bus 11740	: V=1.016088, theta=20.739625 -> V=1.0, theta=0.0
% INFO    : Bus 11741	: V=1.036683, theta=47.83205 -> V=1.0, theta=0.0
% INFO    : Bus 11742	: V=0.967445, theta=33.308335 -> V=1.0, theta=0.0
% INFO    : Bus 11743	: V=1.009308, theta=25.594526 -> V=1.0, theta=0.0
% INFO    : Bus 11744	: V=0.997571, theta=-6.64121 -> V=1.0, theta=0.0
% INFO    : Bus 11745	: V=1.039251, theta=-4.888975 -> V=1.0, theta=0.0
% INFO    : Bus 11746	: V=1.056194, theta=25.665777 -> V=1.0, theta=0.0
% INFO    : Bus 11747	: V=0.964803, theta=-5.53487 -> V=1.0, theta=0.0
% INFO    : Bus 11748	: V=1.014672, theta=-3.125729 -> V=1.0, theta=0.0
% INFO    : Bus 11749	: V=1.017828, theta=-6.986287 -> V=1.0, theta=0.0
% INFO    : Bus 11750	: V=1.040527, theta=0.879566 -> V=1.0, theta=0.0
% INFO    : Bus 11751	: V=0.995316, theta=-1.997087 -> V=1.0, theta=0.0
% INFO    : Bus 11752	: V=1.017287, theta=26.369278 -> V=1.0, theta=0.0
% INFO    : Bus 11753	: V=1.014637, theta=14.638791 -> V=1.0, theta=0.0
% INFO    : Bus 11754	: V=0.976898, theta=39.547729 -> V=1.0, theta=0.0
% INFO    : Bus 11755	: V=1.019643, theta=-4.885706 -> V=1.0, theta=0.0
% INFO    : Bus 11756	: V=1.019643, theta=-4.885706 -> V=1.0, theta=0.0
% INFO    : Bus 11757	: V=1.019643, theta=-4.885706 -> V=1.0, theta=0.0
% INFO    : Bus 11758	: V=1.037142, theta=24.334502 -> V=1.0, theta=0.0
% INFO    : Bus 11759	: V=1.037142, theta=24.334502 -> V=1.0, theta=0.0
% INFO    : Bus 11760	: V=1.037142, theta=24.334502 -> V=1.0, theta=0.0
% INFO    : Bus 11761	: V=1.018631, theta=-11.528817 -> V=1.0, theta=0.0
% INFO    : Bus 11762	: V=1.037142, theta=24.334502 -> V=1.0, theta=0.0
% INFO    : Bus 11763	: V=1.037142, theta=24.334502 -> V=1.0, theta=0.0
% INFO    : Bus 11764	: V=1.030705, theta=-20.918416 -> V=1.0, theta=0.0
% INFO    : Bus 11765	: V=1.027351, theta=-0.814842 -> V=1.0, theta=0.0
% INFO    : Bus 11766	: V=0.999629, theta=27.315451 -> V=1.0, theta=0.0
% INFO    : Bus 11767	: V=1.060664, theta=31.154385 -> V=1.0, theta=0.0
% INFO    : Bus 11768	: V=1.023993, theta=4.449412 -> V=1.0, theta=0.0
% INFO    : Bus 11769	: V=1.008615, theta=-8.918557 -> V=1.0, theta=0.0
% INFO    : Bus 11770	: V=1.021249, theta=-4.603249 -> V=1.0, theta=0.0
% INFO    : Bus 11771	: V=0.981726, theta=-7.828011 -> V=1.0, theta=0.0
% INFO    : Bus 11772	: V=0.999599, theta=-7.186284 -> V=1.0, theta=0.0
% INFO    : Bus 11773	: V=1.008948, theta=-4.613451 -> V=1.0, theta=0.0
% INFO    : Bus 11774	: V=1.015224, theta=15.706003 -> V=1.0, theta=0.0
% INFO    : Bus 11775	: V=1.008464, theta=-9.273691 -> V=1.0, theta=0.0
% INFO    : Bus 11776	: V=1.017793, theta=-25.568793 -> V=1.0, theta=0.0
% INFO    : Bus 11777	: V=1.004419, theta=17.422 -> V=1.0, theta=0.0
% INFO    : Bus 11778	: V=0.965388, theta=-11.747495 -> V=1.0, theta=0.0
% INFO    : Bus 11779	: V=0.990025, theta=-5.482919 -> V=1.0, theta=0.0
% INFO    : Bus 11780	: V=0.918259, theta=-12.437657 -> V=1.0, theta=0.0
% INFO    : Bus 11781	: V=1.03053, theta=1.384954 -> V=1.0, theta=0.0
% INFO    : Bus 11782	: V=1.03795, theta=-12.780799 -> V=1.0, theta=0.0
% INFO    : Bus 11783	: V=1.017814, theta=42.27213 -> V=1.0, theta=0.0
% INFO    : Bus 11784	: V=0.953672, theta=-7.51553 -> V=1.0, theta=0.0
% INFO    : Bus 11785	: V=0.992936, theta=-4.042052 -> V=1.0, theta=0.0
% INFO    : Bus 11786	: V=1.058114, theta=43.382414 -> V=1.0, theta=0.0
% INFO    : Bus 11787	: V=0.979531, theta=-5.995895 -> V=1.0, theta=0.0
% INFO    : Bus 11788	: V=1.031335, theta=18.168562 -> V=1.0, theta=0.0
% INFO    : Bus 11789	: V=0.996117, theta=32.042491 -> V=1.0, theta=0.0
% INFO    : Bus 11790	: V=1.02416, theta=36.959559 -> V=1.0, theta=0.0
% INFO    : Bus 11791	: V=0.980914, theta=1.532206 -> V=1.0, theta=0.0
% INFO    : Bus 11792	: V=1.01769, theta=-5.855082 -> V=1.0, theta=0.0
% INFO    : Bus 11793	: V=0.967603, theta=48.289835 -> V=1.0, theta=0.0
% INFO    : Bus 11794	: V=0.984643, theta=-1.523613 -> V=1.0, theta=0.0
% INFO    : Bus 11795	: V=0.990096, theta=-3.188831 -> V=1.0, theta=0.0
% INFO    : Bus 11796	: V=1.015006, theta=-6.446837 -> V=1.0, theta=0.0
% INFO    : Bus 11797	: V=1.027461, theta=-17.241264 -> V=1.0, theta=0.0
% INFO    : Bus 11798	: V=1.095454, theta=-13.630803 -> V=1.0, theta=0.0
% INFO    : Bus 11799	: V=0.997412, theta=-7.185192 -> V=1.0, theta=0.0
% INFO    : Bus 11800	: V=0.986973, theta=-7.976535 -> V=1.0, theta=0.0
% INFO    : Bus 11801	: V=1.040262, theta=2.637511 -> V=1.0, theta=0.0
% INFO    : Bus 11802	: V=1.020557, theta=9.624602 -> V=1.0, theta=0.0
% INFO    : Bus 11803	: V=1.060489, theta=63.22043 -> V=1.0, theta=0.0
% INFO    : Bus 11804	: V=1.005867, theta=26.566969 -> V=1.0, theta=0.0
% INFO    : Bus 11805	: V=1.030832, theta=-9.752509 -> V=1.0, theta=0.0
% INFO    : Bus 11806	: V=0.990977, theta=91.853031 -> V=1.0, theta=0.0
% INFO    : Bus 11807	: V=1.004043, theta=-7.27619 -> V=1.0, theta=0.0
% INFO    : Bus 11808	: V=1.024183, theta=12.272913 -> V=1.0, theta=0.0
% INFO    : Bus 11809	: V=1.025276, theta=-26.834417 -> V=1.0, theta=0.0
% INFO    : Bus 11810	: V=1.023397, theta=-17.3231 -> V=1.0, theta=0.0
% INFO    : Bus 11811	: V=1.026579, theta=1.653291 -> V=1.0, theta=0.0
% INFO    : Bus 11812	: V=1.000643, theta=27.976596 -> V=1.0, theta=0.0
% INFO    : Bus 11813	: V=1.024687, theta=-5.034434 -> V=1.0, theta=0.0
% INFO    : Bus 11814	: V=1.024687, theta=-5.034434 -> V=1.0, theta=0.0
% INFO    : Bus 11815	: V=1.026579, theta=1.653291 -> V=1.0, theta=0.0
% INFO    : Bus 11816	: V=1.026579, theta=1.653291 -> V=1.0, theta=0.0
% INFO    : Bus 11817	: V=1.029323, theta=-3.215687 -> V=1.0, theta=0.0
% INFO    : Bus 11818	: V=1.029323, theta=-3.215687 -> V=1.0, theta=0.0
% INFO    : Bus 11819	: V=1.024687, theta=-5.034434 -> V=1.0, theta=0.0
% INFO    : Bus 11820	: V=1.024687, theta=-5.034434 -> V=1.0, theta=0.0
% INFO    : Bus 11821	: V=0.986648, theta=-14.509154 -> V=1.0, theta=0.0
% INFO    : Bus 11822	: V=1.050901, theta=18.201002 -> V=1.0, theta=0.0
% INFO    : Bus 11823	: V=1.041349, theta=33.378779 -> V=1.0, theta=0.0
% INFO    : Bus 11824	: V=1.031653, theta=60.53182 -> V=1.0, theta=0.0
% INFO    : Bus 11825	: V=1.024059, theta=-1.195476 -> V=1.0, theta=0.0
% INFO    : Bus 11826	: V=1.034698, theta=-10.504371 -> V=1.0, theta=0.0
% INFO    : Bus 11827	: V=1.050857, theta=44.08115 -> V=1.0, theta=0.0
% INFO    : Bus 11828	: V=1.013971, theta=-22.771884 -> V=1.0, theta=0.0
% INFO    : Bus 11829	: V=1.039817, theta=13.277797 -> V=1.0, theta=0.0
% INFO    : Bus 11830	: V=1.023783, theta=-20.67892 -> V=1.0, theta=0.0
% INFO    : Bus 11831	: V=1.022983, theta=34.764528 -> V=1.0, theta=0.0
% INFO    : Bus 11832	: V=0.924454, theta=-8.009866 -> V=1.0, theta=0.0
% INFO    : Bus 11833	: V=0.994977, theta=26.39214 -> V=1.0, theta=0.0
% INFO    : Bus 11834	: V=0.986767, theta=-2.140551 -> V=1.0, theta=0.0
% INFO    : Bus 11835	: V=1.065242, theta=11.327355 -> V=1.0, theta=0.0
% INFO    : Bus 11836	: V=0.971979, theta=7.130049 -> V=1.0, theta=0.0
% INFO    : Bus 11837	: V=1.026312, theta=17.731987 -> V=1.0, theta=0.0
% INFO    : Bus 11838	: V=1.01282, theta=-20.654825 -> V=1.0, theta=0.0
% INFO    : Bus 11839	: V=1.023827, theta=61.091818 -> V=1.0, theta=0.0
% INFO    : Bus 11840	: V=1.040515, theta=28.323211 -> V=1.0, theta=0.0
% INFO    : Bus 11841	: V=0.985038, theta=-14.340693 -> V=1.0, theta=0.0
% INFO    : Bus 11842	: V=1.010591, theta=16.730632 -> V=1.0, theta=0.0
% INFO    : Bus 11843	: V=1.013919, theta=18.923306 -> V=1.0, theta=0.0
% INFO    : Bus 11844	: V=0.97384, theta=-5.930731 -> V=1.0, theta=0.0
% INFO    : Bus 11845	: V=1.041528, theta=18.789335 -> V=1.0, theta=0.0
% INFO    : Bus 11846	: V=0.980712, theta=-2.997082 -> V=1.0, theta=0.0
% INFO    : Bus 11847	: V=0.994501, theta=-3.334975 -> V=1.0, theta=0.0
% INFO    : Bus 11848	: V=1.031466, theta=4.488829 -> V=1.0, theta=0.0
% INFO    : Bus 11849	: V=1.040009, theta=86.062395 -> V=1.0, theta=0.0
% INFO    : Bus 11850	: V=0.955439, theta=48.700819 -> V=1.0, theta=0.0
% INFO    : Bus 11851	: V=1.056682, theta=5.170602 -> V=1.0, theta=0.0
% INFO    : Bus 11852	: V=1.004296, theta=17.471584 -> V=1.0, theta=0.0
% INFO    : Bus 11853	: V=1.057062, theta=4.322623 -> V=1.0, theta=0.0
% INFO    : Bus 11854	: V=1.056682, theta=5.170602 -> V=1.0, theta=0.0
% INFO    : Bus 11855	: V=0.997329, theta=-9.773309 -> V=1.0, theta=0.0
% INFO    : Bus 11856	: V=1.021695, theta=19.217324 -> V=1.0, theta=0.0
% INFO    : Bus 11857	: V=0.99325, theta=-13.883981 -> V=1.0, theta=0.0
% INFO    : Bus 11858	: V=1.069542, theta=22.417993 -> V=1.0, theta=0.0
% INFO    : Bus 11859	: V=1.009821, theta=29.021748 -> V=1.0, theta=0.0
% INFO    : Bus 11860	: V=0.97939, theta=6.577418 -> V=1.0, theta=0.0
% INFO    : Bus 11861	: V=1.022284, theta=15.569104 -> V=1.0, theta=0.0
% INFO    : Bus 11862	: V=0.98112, theta=0.528152 -> V=1.0, theta=0.0
% INFO    : Bus 11863	: V=1.060995, theta=0.247818 -> V=1.0, theta=0.0
% INFO    : Bus 11864	: V=1.002496, theta=19.130689 -> V=1.0, theta=0.0
% INFO    : Bus 11865	: V=0.971128, theta=-15.83459 -> V=1.0, theta=0.0
% INFO    : Bus 11866	: V=1.028521, theta=7.435606 -> V=1.0, theta=0.0
% INFO    : Bus 11867	: V=1.013456, theta=26.007542 -> V=1.0, theta=0.0
% INFO    : Bus 11868	: V=1.016223, theta=-26.428264 -> V=1.0, theta=0.0
% INFO    : Bus 11869	: V=1.039579, theta=-17.294301 -> V=1.0, theta=0.0
% INFO    : Bus 11870	: V=1.009571, theta=-19.616145 -> V=1.0, theta=0.0
% INFO    : Bus 11871	: V=0.995342, theta=-4.221904 -> V=1.0, theta=0.0
% INFO    : Bus 11872	: V=0.98329, theta=1.387261 -> V=1.0, theta=0.0
% INFO    : Bus 11873	: V=1.006753, theta=32.438243 -> V=1.0, theta=0.0
% INFO    : Bus 11874	: V=1.032056, theta=23.237993 -> V=1.0, theta=0.0
% INFO    : Bus 11875	: V=1.016616, theta=-4.658699 -> V=1.0, theta=0.0
% INFO    : Bus 11876	: V=0.98849, theta=14.04829 -> V=1.0, theta=0.0
% INFO    : Bus 11877	: V=0.987181, theta=-4.824838 -> V=1.0, theta=0.0
% INFO    : Bus 11878	: V=1.010274, theta=-12.645316 -> V=1.0, theta=0.0
% INFO    : Bus 11879	: V=1.023918, theta=1.897357 -> V=1.0, theta=0.0
% INFO    : Bus 11880	: V=1.010466, theta=11.179882 -> V=1.0, theta=0.0
% INFO    : Bus 11881	: V=1.025497, theta=53.824202 -> V=1.0, theta=0.0
% INFO    : Bus 11882	: V=1.041516, theta=-6.856455 -> V=1.0, theta=0.0
% INFO    : Bus 11883	: V=1.099209, theta=-14.353653 -> V=1.0, theta=0.0
% INFO    : Bus 11884	: V=1.012574, theta=31.34297 -> V=1.0, theta=0.0
% INFO    : Bus 11885	: V=1.000041, theta=-13.895043 -> V=1.0, theta=0.0
% INFO    : Bus 11886	: V=1.013429, theta=96.570197 -> V=1.0, theta=0.0
% INFO    : Bus 11887	: V=1.008279, theta=-10.478046 -> V=1.0, theta=0.0
% INFO    : Bus 11888	: V=1.081636, theta=33.907239 -> V=1.0, theta=0.0
% INFO    : Bus 11889	: V=1.061603, theta=44.385823 -> V=1.0, theta=0.0
% INFO    : Bus 11890	: V=0.981663, theta=21.412796 -> V=1.0, theta=0.0
% INFO    : Bus 11891	: V=1.038438, theta=0.065623 -> V=1.0, theta=0.0
% INFO    : Bus 11892	: V=1.017287, theta=26.369278 -> V=1.0, theta=0.0
% INFO    : Bus 11893	: V=1.034739, theta=39.279987 -> V=1.0, theta=0.0
% INFO    : Bus 11894	: V=1.023338, theta=0.199966 -> V=1.0, theta=0.0
% INFO    : Bus 11895	: V=1.010998, theta=1.300317 -> V=1.0, theta=0.0
% INFO    : Bus 11896	: V=0.985586, theta=4.453073 -> V=1.0, theta=0.0
% INFO    : Bus 11897	: V=1.061603, theta=44.385823 -> V=1.0, theta=0.0
% INFO    : Bus 11898	: V=1.062536, theta=46.73809 -> V=1.0, theta=0.0
% INFO    : Bus 11899	: V=0.993049, theta=0.964393 -> V=1.0, theta=0.0
% INFO    : Bus 11900	: V=0.964368, theta=44.185324 -> V=1.0, theta=0.0
% INFO    : Bus 11901	: V=1.031288, theta=1.850677 -> V=1.0, theta=0.0
% INFO    : Bus 11902	: V=1.074011, theta=71.405171 -> V=1.0, theta=0.0
% INFO    : Bus 11903	: V=1.03013, theta=4.624843 -> V=1.0, theta=0.0
% INFO    : Bus 11904	: V=1.028716, theta=93.98767 -> V=1.0, theta=0.0
% INFO    : Bus 11905	: V=1.024817, theta=27.384645 -> V=1.0, theta=0.0
% INFO    : Bus 11906	: V=1.053308, theta=-2.057219 -> V=1.0, theta=0.0
% INFO    : Bus 11907	: V=0.954989, theta=-16.611965 -> V=1.0, theta=0.0
% INFO    : Bus 11908	: V=1.026883, theta=14.232028 -> V=1.0, theta=0.0
% INFO    : Bus 11909	: V=1.028568, theta=11.503252 -> V=1.0, theta=0.0
% INFO    : Bus 11910	: V=1.001011, theta=-3.053282 -> V=1.0, theta=0.0
% INFO    : Bus 11911	: V=1.000373, theta=27.679835 -> V=1.0, theta=0.0
% INFO    : Bus 11912	: V=1.032162, theta=11.548429 -> V=1.0, theta=0.0
% INFO    : Bus 11913	: V=1.033359, theta=20.594354 -> V=1.0, theta=0.0
% INFO    : Bus 11914	: V=1.033359, theta=20.594354 -> V=1.0, theta=0.0
% INFO    : Bus 11915	: V=1.004773, theta=-7.512043 -> V=1.0, theta=0.0
% INFO    : Bus 11916	: V=1.026957, theta=18.072383 -> V=1.0, theta=0.0
% INFO    : Bus 11917	: V=1.031923, theta=19.780218 -> V=1.0, theta=0.0
% INFO    : Bus 11918	: V=1.027586, theta=-0.028263 -> V=1.0, theta=0.0
% INFO    : Bus 11919	: V=1.026957, theta=18.072383 -> V=1.0, theta=0.0
% INFO    : Bus 11920	: V=0.998951, theta=38.095582 -> V=1.0, theta=0.0
% INFO    : Bus 11921	: V=1.023854, theta=16.871011 -> V=1.0, theta=0.0
% INFO    : Bus 11922	: V=1.029382, theta=20.080326 -> V=1.0, theta=0.0
% INFO    : Bus 11923	: V=1.027524, theta=7.135692 -> V=1.0, theta=0.0
% INFO    : Bus 11924	: V=1.0608, theta=42.720858 -> V=1.0, theta=0.0
% INFO    : Bus 11925	: V=1.059073, theta=29.479384 -> V=1.0, theta=0.0
% INFO    : Bus 11926	: V=1.022428, theta=-2.963232 -> V=1.0, theta=0.0
% INFO    : Bus 11927	: V=1.058046, theta=7.877809 -> V=1.0, theta=0.0
% INFO    : Bus 11928	: V=0.976931, theta=30.182064 -> V=1.0, theta=0.0
% INFO    : Bus 11929	: V=1.02281, theta=-10.941228 -> V=1.0, theta=0.0
% INFO    : Bus 11930	: V=1.042018, theta=29.370588 -> V=1.0, theta=0.0
% INFO    : Bus 11931	: V=1.032947, theta=12.673591 -> V=1.0, theta=0.0
% INFO    : Bus 11932	: V=1.002928, theta=17.35183 -> V=1.0, theta=0.0
% INFO    : Bus 11933	: V=1.024842, theta=6.070005 -> V=1.0, theta=0.0
% INFO    : Bus 11934	: V=1.010399, theta=38.6722 -> V=1.0, theta=0.0
% INFO    : Bus 11935	: V=0.994234, theta=37.670381 -> V=1.0, theta=0.0
% INFO    : Bus 11936	: V=0.970991, theta=4.942762 -> V=1.0, theta=0.0
% INFO    : Bus 11937	: V=1.024614, theta=2.680146 -> V=1.0, theta=0.0
% INFO    : Bus 11938	: V=1.021685, theta=-10.456797 -> V=1.0, theta=0.0
% INFO    : Bus 11939	: V=1.012907, theta=2.260233 -> V=1.0, theta=0.0
% INFO    : Bus 11940	: V=0.978898, theta=-6.597551 -> V=1.0, theta=0.0
% INFO    : Bus 11941	: V=1.07251, theta=0.28715 -> V=1.0, theta=0.0
% INFO    : Bus 11942	: V=1.009609, theta=-16.526291 -> V=1.0, theta=0.0
% INFO    : Bus 11943	: V=1.00842, theta=28.258293 -> V=1.0, theta=0.0
% INFO    : Bus 11944	: V=1.036963, theta=-1.571198 -> V=1.0, theta=0.0
% INFO    : Bus 11945	: V=1.012893, theta=26.368849 -> V=1.0, theta=0.0
% INFO    : Bus 11946	: V=1.033214, theta=-6.888934 -> V=1.0, theta=0.0
% INFO    : Bus 11947	: V=1.071016, theta=58.767652 -> V=1.0, theta=0.0
% INFO    : Bus 11948	: V=1.019544, theta=-32.956369 -> V=1.0, theta=0.0
% INFO    : Bus 11949	: V=1.033686, theta=13.392829 -> V=1.0, theta=0.0
% INFO    : Bus 11950	: V=1.04459, theta=35.949142 -> V=1.0, theta=0.0
% INFO    : Bus 11951	: V=1.054686, theta=-2.922157 -> V=1.0, theta=0.0
% INFO    : Bus 11952	: V=1.040569, theta=13.793762 -> V=1.0, theta=0.0
% INFO    : Bus 11953	: V=0.951565, theta=38.529485 -> V=1.0, theta=0.0
% INFO    : Bus 11954	: V=0.959267, theta=-6.51368 -> V=1.0, theta=0.0
% INFO    : Bus 11955	: V=1.063275, theta=21.172664 -> V=1.0, theta=0.0
% INFO    : Bus 11956	: V=0.984374, theta=88.942692 -> V=1.0, theta=0.0
% INFO    : Bus 11957	: V=0.90264, theta=-12.097367 -> V=1.0, theta=0.0
% INFO    : Bus 11958	: V=1.007569, theta=-12.183288 -> V=1.0, theta=0.0
% INFO    : Bus 11959	: V=1.033214, theta=-6.86015 -> V=1.0, theta=0.0
% INFO    : Bus 11960	: V=0.989121, theta=29.435974 -> V=1.0, theta=0.0
% INFO    : Bus 11961	: V=1.025491, theta=37.337345 -> V=1.0, theta=0.0
% INFO    : Bus 11962	: V=1.033214, theta=-6.86015 -> V=1.0, theta=0.0
% INFO    : Bus 11963	: V=1.00389, theta=18.263979 -> V=1.0, theta=0.0
% INFO    : Bus 11964	: V=0.991781, theta=14.889742 -> V=1.0, theta=0.0
% INFO    : Bus 11965	: V=1.033623, theta=30.239446 -> V=1.0, theta=0.0
% INFO    : Bus 11966	: V=1.011867, theta=1.688451 -> V=1.0, theta=0.0
% INFO    : Bus 11967	: V=1.019503, theta=8.365451 -> V=1.0, theta=0.0
% INFO    : Bus 11968	: V=1.023144, theta=-9.538309 -> V=1.0, theta=0.0
% INFO    : Bus 11969	: V=1.034068, theta=30.209322 -> V=1.0, theta=0.0
% INFO    : Bus 11970	: V=0.988112, theta=23.208642 -> V=1.0, theta=0.0
% INFO    : Bus 11971	: V=0.983835, theta=1.517642 -> V=1.0, theta=0.0
% INFO    : Bus 11972	: V=1.00288, theta=28.368105 -> V=1.0, theta=0.0
% INFO    : Bus 11973	: V=0.999369, theta=-13.617092 -> V=1.0, theta=0.0
% INFO    : Bus 11974	: V=0.966317, theta=0.966505 -> V=1.0, theta=0.0
% INFO    : Bus 11975	: V=1.015227, theta=-3.436884 -> V=1.0, theta=0.0
% INFO    : Bus 11976	: V=1.04826, theta=-8.707987 -> V=1.0, theta=0.0
% INFO    : Bus 11977	: V=1.02486, theta=-11.460772 -> V=1.0, theta=0.0
% INFO    : Bus 11978	: V=1.054388, theta=47.373035 -> V=1.0, theta=0.0
% INFO    : Bus 11979	: V=1.054388, theta=47.373035 -> V=1.0, theta=0.0
% INFO    : Bus 11980	: V=1.054388, theta=47.373035 -> V=1.0, theta=0.0
% INFO    : Bus 11981	: V=1.020921, theta=-7.474467 -> V=1.0, theta=0.0
% INFO    : Bus 11982	: V=1.04876, theta=45.73683 -> V=1.0, theta=0.0
% INFO    : Bus 11983	: V=1.026753, theta=-20.195844 -> V=1.0, theta=0.0
% INFO    : Bus 11984	: V=1.009654, theta=2.894147 -> V=1.0, theta=0.0
% INFO    : Bus 11985	: V=1.000468, theta=-9.336623 -> V=1.0, theta=0.0
% INFO    : Bus 11986	: V=1.01601, theta=-0.145046 -> V=1.0, theta=0.0
% INFO    : Bus 11987	: V=0.971901, theta=45.235162 -> V=1.0, theta=0.0
% INFO    : Bus 11988	: V=1.037973, theta=11.471538 -> V=1.0, theta=0.0
% INFO    : Bus 11989	: V=0.989988, theta=-18.685834 -> V=1.0, theta=0.0
% INFO    : Bus 11990	: V=1.002465, theta=24.966083 -> V=1.0, theta=0.0
% INFO    : Bus 11991	: V=1.003002, theta=18.950589 -> V=1.0, theta=0.0
% INFO    : Bus 11992	: V=0.966158, theta=-9.712391 -> V=1.0, theta=0.0
% INFO    : Bus 11993	: V=0.978141, theta=-14.535595 -> V=1.0, theta=0.0
% INFO    : Bus 11994	: V=1.01023, theta=-1.501018 -> V=1.0, theta=0.0
% INFO    : Bus 11995	: V=1.053059, theta=-2.989742 -> V=1.0, theta=0.0
% INFO    : Bus 11996	: V=1.032132, theta=-0.658602 -> V=1.0, theta=0.0
% INFO    : Bus 11997	: V=1.024048, theta=34.917994 -> V=1.0, theta=0.0
% INFO    : Bus 11998	: V=1.072837, theta=36.250253 -> V=1.0, theta=0.0
% INFO    : Bus 11999	: V=1.012583, theta=31.342815 -> V=1.0, theta=0.0
% INFO    : Bus 12000	: V=1.051128, theta=37.961676 -> V=1.0, theta=0.0
% INFO    : Bus 12001	: V=1.016606, theta=10.005767 -> V=1.0, theta=0.0
% INFO    : Bus 12002	: V=1.031386, theta=-10.502639 -> V=1.0, theta=0.0
% INFO    : Bus 12003	: V=1.040737, theta=28.962102 -> V=1.0, theta=0.0
% INFO    : Bus 12004	: V=1.045892, theta=-13.188115 -> V=1.0, theta=0.0
% INFO    : Bus 12005	: V=1.016233, theta=-10.469824 -> V=1.0, theta=0.0
% INFO    : Bus 12006	: V=1.021912, theta=-13.38294 -> V=1.0, theta=0.0
% INFO    : Bus 12007	: V=0.994863, theta=-7.726774 -> V=1.0, theta=0.0
% INFO    : Bus 12008	: V=1.014403, theta=-26.633426 -> V=1.0, theta=0.0
% INFO    : Bus 12009	: V=1.017509, theta=4.48626 -> V=1.0, theta=0.0
% INFO    : Bus 12010	: V=1.017509, theta=4.48626 -> V=1.0, theta=0.0
% INFO    : Bus 12011	: V=1.017509, theta=4.48626 -> V=1.0, theta=0.0
% INFO    : Bus 12012	: V=1.074409, theta=0.241246 -> V=1.0, theta=0.0
% INFO    : Bus 12013	: V=1.008914, theta=18.33376 -> V=1.0, theta=0.0
% INFO    : Bus 12014	: V=1.023938, theta=3.432435 -> V=1.0, theta=0.0
% INFO    : Bus 12015	: V=1.056086, theta=-3.056772 -> V=1.0, theta=0.0
% INFO    : Bus 12016	: V=1.065343, theta=53.072846 -> V=1.0, theta=0.0
% INFO    : Bus 12017	: V=0.999005, theta=27.908744 -> V=1.0, theta=0.0
% INFO    : Bus 12018	: V=1.010498, theta=-17.064676 -> V=1.0, theta=0.0
% INFO    : Bus 12019	: V=1.032873, theta=-19.373029 -> V=1.0, theta=0.0
% INFO    : Bus 12020	: V=1.015252, theta=-6.735079 -> V=1.0, theta=0.0
% INFO    : Bus 12021	: V=1.018676, theta=-12.462271 -> V=1.0, theta=0.0
% INFO    : Bus 12022	: V=0.998709, theta=-8.901449 -> V=1.0, theta=0.0
% INFO    : Bus 12023	: V=1.041308, theta=-1.973007 -> V=1.0, theta=0.0
% INFO    : Bus 12024	: V=1.034048, theta=-9.733404 -> V=1.0, theta=0.0
% INFO    : Bus 12025	: V=1.030499, theta=6.658168 -> V=1.0, theta=0.0
% INFO    : Bus 12026	: V=1.033858, theta=-10.849314 -> V=1.0, theta=0.0
% INFO    : Bus 12027	: V=1.042665, theta=-9.557361 -> V=1.0, theta=0.0
% INFO    : Bus 12028	: V=1.123219, theta=-0.417507 -> V=1.0, theta=0.0
% INFO    : Bus 12029	: V=1.024385, theta=-8.261011 -> V=1.0, theta=0.0
% INFO    : Bus 12030	: V=1.014648, theta=-4.044158 -> V=1.0, theta=0.0
% INFO    : Bus 12031	: V=1.055555, theta=-3.757386 -> V=1.0, theta=0.0
% INFO    : Bus 12032	: V=1.017145, theta=17.949482 -> V=1.0, theta=0.0
% INFO    : Bus 12033	: V=0.987995, theta=-14.036111 -> V=1.0, theta=0.0
% INFO    : Bus 12034	: V=1.006456, theta=-4.02582 -> V=1.0, theta=0.0
% INFO    : Bus 12035	: V=1.035838, theta=-5.172678 -> V=1.0, theta=0.0
% INFO    : Bus 12036	: V=1.002452, theta=16.388576 -> V=1.0, theta=0.0
% INFO    : Bus 12037	: V=1.002937, theta=-4.683269 -> V=1.0, theta=0.0
% INFO    : Bus 12038	: V=0.992378, theta=34.134663 -> V=1.0, theta=0.0
% INFO    : Bus 12039	: V=1.049848, theta=19.032506 -> V=1.0, theta=0.0
% INFO    : Bus 12040	: V=1.02822, theta=-20.958707 -> V=1.0, theta=0.0
% INFO    : Bus 12041	: V=0.994127, theta=33.837786 -> V=1.0, theta=0.0
% INFO    : Bus 12042	: V=1.014428, theta=-7.519045 -> V=1.0, theta=0.0
% INFO    : Bus 12043	: V=1.036533, theta=7.566778 -> V=1.0, theta=0.0
% INFO    : Bus 12044	: V=1.046552, theta=-20.234692 -> V=1.0, theta=0.0
% INFO    : Bus 12045	: V=1.013722, theta=-11.978977 -> V=1.0, theta=0.0
% INFO    : Bus 12046	: V=1.023058, theta=-10.869221 -> V=1.0, theta=0.0
% INFO    : Bus 12047	: V=1.006941, theta=-8.995126 -> V=1.0, theta=0.0
% INFO    : Bus 12048	: V=1.015467, theta=-26.709784 -> V=1.0, theta=0.0
% INFO    : Bus 12049	: V=1.073911, theta=4.277217 -> V=1.0, theta=0.0
% INFO    : Bus 12050	: V=1.008348, theta=30.337205 -> V=1.0, theta=0.0
% INFO    : Bus 12051	: V=1.011292, theta=29.334797 -> V=1.0, theta=0.0
% INFO    : Bus 12052	: V=1.008412, theta=69.340675 -> V=1.0, theta=0.0
% INFO    : Bus 12053	: V=1.025116, theta=22.799171 -> V=1.0, theta=0.0
% INFO    : Bus 12054	: V=1.036891, theta=21.208732 -> V=1.0, theta=0.0
% INFO    : Bus 12055	: V=1.018472, theta=13.591184 -> V=1.0, theta=0.0
% INFO    : Bus 12056	: V=0.956568, theta=-7.820575 -> V=1.0, theta=0.0
% INFO    : Bus 12057	: V=1.027437, theta=79.001946 -> V=1.0, theta=0.0
% INFO    : Bus 12058	: V=1.048954, theta=68.758885 -> V=1.0, theta=0.0
% INFO    : Bus 12059	: V=1.021269, theta=36.651421 -> V=1.0, theta=0.0
% INFO    : Bus 12060	: V=0.996411, theta=28.78407 -> V=1.0, theta=0.0
% INFO    : Bus 12061	: V=1.000158, theta=26.820337 -> V=1.0, theta=0.0
% INFO    : Bus 12062	: V=0.998503, theta=-10.411516 -> V=1.0, theta=0.0
% INFO    : Bus 12063	: V=1.016437, theta=51.339973 -> V=1.0, theta=0.0
% INFO    : Bus 12064	: V=1.005625, theta=13.356599 -> V=1.0, theta=0.0
% INFO    : Bus 12065	: V=1.031165, theta=22.577641 -> V=1.0, theta=0.0
% INFO    : Bus 12066	: V=0.993675, theta=90.655341 -> V=1.0, theta=0.0
% INFO    : Bus 12067	: V=1.015757, theta=31.653843 -> V=1.0, theta=0.0
% INFO    : Bus 12068	: V=1.016555, theta=19.710237 -> V=1.0, theta=0.0
% INFO    : Bus 12069	: V=1.035406, theta=21.74444 -> V=1.0, theta=0.0
% INFO    : Bus 12070	: V=1.035406, theta=21.74444 -> V=1.0, theta=0.0
% INFO    : Bus 12071	: V=1.035406, theta=21.74444 -> V=1.0, theta=0.0
% INFO    : Bus 12072	: V=1.051326, theta=28.77397 -> V=1.0, theta=0.0
% INFO    : Bus 12073	: V=1.035406, theta=21.74444 -> V=1.0, theta=0.0
% INFO    : Bus 12074	: V=1.035406, theta=21.74444 -> V=1.0, theta=0.0
% INFO    : Bus 12075	: V=1.035406, theta=21.74444 -> V=1.0, theta=0.0
% INFO    : Bus 12076	: V=1.035406, theta=21.74444 -> V=1.0, theta=0.0
% INFO    : Bus 12077	: V=0.950409, theta=-5.384362 -> V=1.0, theta=0.0
% INFO    : Bus 12078	: V=1.024668, theta=10.263437 -> V=1.0, theta=0.0
% INFO    : Bus 12079	: V=1.017661, theta=-10.180091 -> V=1.0, theta=0.0
% INFO    : Bus 12080	: V=1.021811, theta=49.289996 -> V=1.0, theta=0.0
% INFO    : Bus 12081	: V=1.018208, theta=-5.092604 -> V=1.0, theta=0.0
% INFO    : Bus 12082	: V=1.014547, theta=-18.70804 -> V=1.0, theta=0.0
% INFO    : Bus 12083	: V=0.987102, theta=3.009904 -> V=1.0, theta=0.0
% INFO    : Bus 12084	: V=1.012034, theta=5.351331 -> V=1.0, theta=0.0
% INFO    : Bus 12085	: V=1.012034, theta=5.351331 -> V=1.0, theta=0.0
% INFO    : Bus 12086	: V=1.033277, theta=23.511773 -> V=1.0, theta=0.0
% INFO    : Bus 12087	: V=0.970315, theta=-8.449974 -> V=1.0, theta=0.0
% INFO    : Bus 12088	: V=1.014269, theta=27.689496 -> V=1.0, theta=0.0
% INFO    : Bus 12089	: V=1.044104, theta=2.133328 -> V=1.0, theta=0.0
% INFO    : Bus 12090	: V=0.969719, theta=-6.483101 -> V=1.0, theta=0.0
% INFO    : Bus 12091	: V=1.005112, theta=-1.198328 -> V=1.0, theta=0.0
% INFO    : Bus 12092	: V=1.049093, theta=7.513515 -> V=1.0, theta=0.0
% INFO    : Bus 12093	: V=1.056125, theta=27.444238 -> V=1.0, theta=0.0
% INFO    : Bus 12094	: V=0.969713, theta=18.803207 -> V=1.0, theta=0.0
% INFO    : Bus 12095	: V=1.024647, theta=-2.171451 -> V=1.0, theta=0.0
% INFO    : Bus 12096	: V=0.976458, theta=41.660917 -> V=1.0, theta=0.0
% INFO    : Bus 12097	: V=1.026207, theta=-11.793103 -> V=1.0, theta=0.0
% INFO    : Bus 12098	: V=1.00499, theta=31.934591 -> V=1.0, theta=0.0
% INFO    : Bus 12099	: V=1.030988, theta=2.394145 -> V=1.0, theta=0.0
% INFO    : Bus 12100	: V=1.04154, theta=-14.32672 -> V=1.0, theta=0.0
% INFO    : Bus 12101	: V=1.029639, theta=17.04104 -> V=1.0, theta=0.0
% INFO    : Bus 12102	: V=1.023818, theta=-10.471889 -> V=1.0, theta=0.0
% INFO    : Bus 12103	: V=1.005395, theta=30.514439 -> V=1.0, theta=0.0
% INFO    : Bus 12104	: V=1.006974, theta=2.951136 -> V=1.0, theta=0.0
% INFO    : Bus 12105	: V=0.987737, theta=46.492873 -> V=1.0, theta=0.0
% INFO    : Bus 12106	: V=1.024267, theta=0.497112 -> V=1.0, theta=0.0
% INFO    : Bus 12107	: V=1.002453, theta=-9.411953 -> V=1.0, theta=0.0
% INFO    : Bus 12108	: V=1.037317, theta=25.872032 -> V=1.0, theta=0.0
% INFO    : Bus 12109	: V=1.042633, theta=20.102708 -> V=1.0, theta=0.0
% INFO    : Bus 12110	: V=0.978701, theta=25.524635 -> V=1.0, theta=0.0
% INFO    : Bus 12111	: V=0.982065, theta=-7.80271 -> V=1.0, theta=0.0
% INFO    : Bus 12112	: V=1.014425, theta=-9.789718 -> V=1.0, theta=0.0
% INFO    : Bus 12113	: V=1.012055, theta=-4.801845 -> V=1.0, theta=0.0
% INFO    : Bus 12114	: V=0.978251, theta=10.243079 -> V=1.0, theta=0.0
% INFO    : Bus 12115	: V=1.040444, theta=6.867695 -> V=1.0, theta=0.0
% INFO    : Bus 12116	: V=1.031695, theta=0.0 -> V=1.0, theta=0.0
% INFO    : Bus 12117	: V=1.029233, theta=-10.064406 -> V=1.0, theta=0.0
% INFO    : Bus 12118	: V=1.012268, theta=-26.760459 -> V=1.0, theta=0.0
% INFO    : Bus 12119	: V=1.013515, theta=-9.02175 -> V=1.0, theta=0.0
% INFO    : Bus 12120	: V=1.053349, theta=-2.98314 -> V=1.0, theta=0.0
% INFO    : Bus 12121	: V=1.049756, theta=20.130595 -> V=1.0, theta=0.0
% INFO    : Bus 12122	: V=1.025009, theta=18.463948 -> V=1.0, theta=0.0
% INFO    : Bus 12123	: V=1.003288, theta=23.155407 -> V=1.0, theta=0.0
% INFO    : Bus 12124	: V=1.025271, theta=20.88058 -> V=1.0, theta=0.0
% INFO    : Bus 12125	: V=1.044881, theta=6.491094 -> V=1.0, theta=0.0
% INFO    : Bus 12126	: V=1.025372, theta=28.364246 -> V=1.0, theta=0.0
% INFO    : Bus 12127	: V=1.025372, theta=28.364246 -> V=1.0, theta=0.0
% INFO    : Bus 12128	: V=1.001622, theta=-9.968038 -> V=1.0, theta=0.0
% INFO    : Bus 12129	: V=1.007399, theta=27.999318 -> V=1.0, theta=0.0
% INFO    : Bus 12130	: V=1.002279, theta=-13.779687 -> V=1.0, theta=0.0
% INFO    : Bus 12131	: V=1.039883, theta=-8.632286 -> V=1.0, theta=0.0
% INFO    : Bus 12132	: V=1.039883, theta=-8.632286 -> V=1.0, theta=0.0
% INFO    : Bus 12133	: V=1.033722, theta=29.674924 -> V=1.0, theta=0.0
% INFO    : Bus 12134	: V=1.033722, theta=29.674924 -> V=1.0, theta=0.0
% INFO    : Bus 12135	: V=1.033722, theta=29.674924 -> V=1.0, theta=0.0
% INFO    : Bus 12136	: V=1.033722, theta=29.674924 -> V=1.0, theta=0.0
% INFO    : Bus 12137	: V=1.033736, theta=29.645181 -> V=1.0, theta=0.0
% INFO    : Bus 12138	: V=1.033736, theta=29.645181 -> V=1.0, theta=0.0
% INFO    : Bus 12139	: V=1.033736, theta=29.645181 -> V=1.0, theta=0.0
% INFO    : Bus 12140	: V=1.033736, theta=29.645181 -> V=1.0, theta=0.0
% INFO    : Bus 12141	: V=1.05459, theta=7.846898 -> V=1.0, theta=0.0
% INFO    : Bus 12142	: V=1.026998, theta=21.381155 -> V=1.0, theta=0.0
% INFO    : Bus 12143	: V=1.037456, theta=-12.983195 -> V=1.0, theta=0.0
% INFO    : Bus 12144	: V=0.972666, theta=20.278257 -> V=1.0, theta=0.0
% INFO    : Bus 12145	: V=1.021211, theta=26.174949 -> V=1.0, theta=0.0
% INFO    : Bus 12146	: V=0.978549, theta=1.896927 -> V=1.0, theta=0.0
% INFO    : Bus 12147	: V=0.976996, theta=-5.755046 -> V=1.0, theta=0.0
% INFO    : Bus 12148	: V=1.012529, theta=-13.185268 -> V=1.0, theta=0.0
% INFO    : Bus 12149	: V=1.008452, theta=19.375763 -> V=1.0, theta=0.0
% INFO    : Bus 12150	: V=1.010382, theta=15.656999 -> V=1.0, theta=0.0
% INFO    : Bus 12151	: V=1.05433, theta=45.681206 -> V=1.0, theta=0.0
% INFO    : Bus 12152	: V=1.030656, theta=3.405373 -> V=1.0, theta=0.0
% INFO    : Bus 12153	: V=1.137373, theta=-1.114463 -> V=1.0, theta=0.0
% INFO    : Bus 12154	: V=1.011305, theta=28.622228 -> V=1.0, theta=0.0
% INFO    : Bus 12155	: V=1.017379, theta=-22.651908 -> V=1.0, theta=0.0
% INFO    : Bus 12156	: V=0.994871, theta=-3.848423 -> V=1.0, theta=0.0
% INFO    : Bus 12157	: V=0.975069, theta=16.05223 -> V=1.0, theta=0.0
% INFO    : Bus 12158	: V=1.020063, theta=-14.094216 -> V=1.0, theta=0.0
% INFO    : Bus 12159	: V=1.038979, theta=-13.937788 -> V=1.0, theta=0.0
% INFO    : Bus 12160	: V=1.021838, theta=49.280767 -> V=1.0, theta=0.0
% INFO    : Bus 12161	: V=1.047022, theta=28.781319 -> V=1.0, theta=0.0
% INFO    : Bus 12162	: V=0.999462, theta=-21.242915 -> V=1.0, theta=0.0
% INFO    : Bus 12163	: V=1.05667, theta=-2.722877 -> V=1.0, theta=0.0
% INFO    : Bus 12164	: V=1.05667, theta=-2.722877 -> V=1.0, theta=0.0
% INFO    : Bus 12165	: V=1.10093, theta=-2.183793 -> V=1.0, theta=0.0
% INFO    : Bus 12166	: V=1.030179, theta=32.417925 -> V=1.0, theta=0.0
% INFO    : Bus 12167	: V=1.030179, theta=32.417925 -> V=1.0, theta=0.0
% INFO    : Bus 12168	: V=1.030179, theta=32.417925 -> V=1.0, theta=0.0
% INFO    : Bus 12169	: V=1.030179, theta=32.417925 -> V=1.0, theta=0.0
% INFO    : Bus 12170	: V=1.05667, theta=-2.722877 -> V=1.0, theta=0.0
% INFO    : Bus 12171	: V=1.05667, theta=-2.722877 -> V=1.0, theta=0.0
% INFO    : Bus 12172	: V=1.030179, theta=32.417925 -> V=1.0, theta=0.0
% INFO    : Bus 12173	: V=1.04071, theta=74.319379 -> V=1.0, theta=0.0
% INFO    : Bus 12174	: V=0.952652, theta=-11.963627 -> V=1.0, theta=0.0
% INFO    : Bus 12175	: V=1.035888, theta=21.491029 -> V=1.0, theta=0.0
% INFO    : Bus 12176	: V=1.005453, theta=-5.630958 -> V=1.0, theta=0.0
% INFO    : Bus 12177	: V=1.00191, theta=-5.355721 -> V=1.0, theta=0.0
% INFO    : Bus 12178	: V=1.014358, theta=8.671133 -> V=1.0, theta=0.0
% INFO    : Bus 12179	: V=1.017635, theta=-3.080045 -> V=1.0, theta=0.0
% INFO    : Bus 12180	: V=1.006681, theta=30.125372 -> V=1.0, theta=0.0
% INFO    : Bus 12181	: V=0.998766, theta=-23.003981 -> V=1.0, theta=0.0
% INFO    : Bus 12182	: V=0.979669, theta=-3.90823 -> V=1.0, theta=0.0
% INFO    : Bus 12183	: V=0.988243, theta=13.342353 -> V=1.0, theta=0.0
% INFO    : Bus 12184	: V=1.025229, theta=54.199763 -> V=1.0, theta=0.0
% INFO    : Bus 12185	: V=1.000192, theta=-4.465417 -> V=1.0, theta=0.0
% INFO    : Bus 12186	: V=1.057634, theta=18.249721 -> V=1.0, theta=0.0
% INFO    : Bus 12187	: V=1.019178, theta=34.651774 -> V=1.0, theta=0.0
% INFO    : Bus 12188	: V=0.95809, theta=-16.391366 -> V=1.0, theta=0.0
% INFO    : Bus 12189	: V=1.007227, theta=24.551226 -> V=1.0, theta=0.0
% INFO    : Bus 12190	: V=1.023431, theta=-10.714615 -> V=1.0, theta=0.0
% INFO    : Bus 12191	: V=1.013974, theta=-8.858315 -> V=1.0, theta=0.0
% INFO    : Bus 12192	: V=1.013974, theta=-8.858315 -> V=1.0, theta=0.0
% INFO    : Bus 12193	: V=1.015043, theta=-15.09113 -> V=1.0, theta=0.0
% INFO    : Bus 12194	: V=1.015043, theta=-15.09113 -> V=1.0, theta=0.0
% INFO    : Bus 12195	: V=1.048748, theta=7.516157 -> V=1.0, theta=0.0
% INFO    : Bus 12196	: V=1.087414, theta=8.898313 -> V=1.0, theta=0.0
% INFO    : Bus 12197	: V=1.040006, theta=41.084857 -> V=1.0, theta=0.0
% INFO    : Bus 12198	: V=1.098531, theta=65.002694 -> V=1.0, theta=0.0
% INFO    : Bus 12199	: V=0.991398, theta=31.360075 -> V=1.0, theta=0.0
% INFO    : Bus 12200	: V=1.031553, theta=24.597119 -> V=1.0, theta=0.0
% INFO    : Bus 12201	: V=0.995093, theta=5.914505 -> V=1.0, theta=0.0
% INFO    : Bus 12202	: V=1.023421, theta=5.136164 -> V=1.0, theta=0.0
% INFO    : Bus 12203	: V=1.024504, theta=38.533334 -> V=1.0, theta=0.0
% INFO    : Bus 12204	: V=0.975834, theta=33.412223 -> V=1.0, theta=0.0
% INFO    : Bus 12205	: V=1.039675, theta=26.268321 -> V=1.0, theta=0.0
% INFO    : Bus 12206	: V=0.994875, theta=-4.178758 -> V=1.0, theta=0.0
% INFO    : Bus 12207	: V=1.032194, theta=21.496822 -> V=1.0, theta=0.0
% INFO    : Bus 12208	: V=1.043874, theta=15.587474 -> V=1.0, theta=0.0
% INFO    : Bus 12209	: V=1.033818, theta=27.836778 -> V=1.0, theta=0.0
% INFO    : Bus 12210	: V=1.036271, theta=5.075112 -> V=1.0, theta=0.0
% INFO    : Bus 12211	: V=1.026027, theta=-7.002651 -> V=1.0, theta=0.0
% INFO    : Bus 12212	: V=1.024841, theta=18.337972 -> V=1.0, theta=0.0
% INFO    : Bus 12213	: V=1.038536, theta=1.12257 -> V=1.0, theta=0.0
% INFO    : Bus 12214	: V=1.006583, theta=-15.130947 -> V=1.0, theta=0.0
% INFO    : Bus 12215	: V=0.996897, theta=23.818152 -> V=1.0, theta=0.0
% INFO    : Bus 12216	: V=1.021005, theta=21.987746 -> V=1.0, theta=0.0
% INFO    : Bus 12217	: V=1.036966, theta=15.051213 -> V=1.0, theta=0.0
% INFO    : Bus 12218	: V=1.098453, theta=64.998015 -> V=1.0, theta=0.0
% INFO    : Bus 12219	: V=1.043942, theta=17.353218 -> V=1.0, theta=0.0
% INFO    : Bus 12220	: V=0.973261, theta=-9.531782 -> V=1.0, theta=0.0
% INFO    : Bus 12221	: V=1.029545, theta=3.003491 -> V=1.0, theta=0.0
% INFO    : Bus 12222	: V=1.02494, theta=28.997481 -> V=1.0, theta=0.0
% INFO    : Bus 12223	: V=1.08404, theta=51.888439 -> V=1.0, theta=0.0
% INFO    : Bus 12224	: V=1.095691, theta=-4.631591 -> V=1.0, theta=0.0
% INFO    : Bus 12225	: V=1.019604, theta=-24.436994 -> V=1.0, theta=0.0
% INFO    : Bus 12226	: V=1.000971, theta=-4.328082 -> V=1.0, theta=0.0
% INFO    : Bus 12227	: V=1.043087, theta=11.638661 -> V=1.0, theta=0.0
% INFO    : Bus 12228	: V=1.01227, theta=-2.402886 -> V=1.0, theta=0.0
% INFO    : Bus 12229	: V=1.021096, theta=23.640191 -> V=1.0, theta=0.0
% INFO    : Bus 12230	: V=0.970372, theta=27.607329 -> V=1.0, theta=0.0
% INFO    : Bus 12231	: V=0.998346, theta=-4.38145 -> V=1.0, theta=0.0
% INFO    : Bus 12232	: V=1.037993, theta=28.716517 -> V=1.0, theta=0.0
% INFO    : Bus 12233	: V=1.050133, theta=-3.105156 -> V=1.0, theta=0.0
% INFO    : Bus 12234	: V=1.050186, theta=25.602515 -> V=1.0, theta=0.0
% INFO    : Bus 12235	: V=0.990868, theta=-2.50336 -> V=1.0, theta=0.0
% INFO    : Bus 12236	: V=0.996281, theta=12.615694 -> V=1.0, theta=0.0
% INFO    : Bus 12237	: V=0.970208, theta=5.158798 -> V=1.0, theta=0.0
% INFO    : Bus 12238	: V=1.01, theta=12.196035 -> V=1.0, theta=0.0
% INFO    : Bus 12239	: V=1.012035, theta=-12.726866 -> V=1.0, theta=0.0
% INFO    : Bus 12240	: V=1.022424, theta=-10.029386 -> V=1.0, theta=0.0
% INFO    : Bus 12241	: V=1.065676, theta=17.770112 -> V=1.0, theta=0.0
% INFO    : Bus 12242	: V=0.989904, theta=-7.663746 -> V=1.0, theta=0.0
% INFO    : Bus 12243	: V=0.965855, theta=-6.047065 -> V=1.0, theta=0.0
% INFO    : Bus 12244	: V=1.029293, theta=-6.89657 -> V=1.0, theta=0.0
% INFO    : Bus 12245	: V=1.037281, theta=-8.202796 -> V=1.0, theta=0.0
% INFO    : Bus 12246	: V=1.034774, theta=-11.388611 -> V=1.0, theta=0.0
% INFO    : Bus 12247	: V=0.97655, theta=2.339227 -> V=1.0, theta=0.0
% INFO    : Bus 12248	: V=0.988817, theta=21.215061 -> V=1.0, theta=0.0
% INFO    : Bus 12249	: V=1.004014, theta=-3.506061 -> V=1.0, theta=0.0
% INFO    : Bus 12250	: V=1.026831, theta=21.377342 -> V=1.0, theta=0.0
% INFO    : Bus 12251	: V=0.97451, theta=22.850553 -> V=1.0, theta=0.0
% INFO    : Bus 12252	: V=1.063358, theta=20.842529 -> V=1.0, theta=0.0
% INFO    : Bus 12253	: V=1.050524, theta=44.07973 -> V=1.0, theta=0.0
% INFO    : Bus 12254	: V=1.075269, theta=1.500112 -> V=1.0, theta=0.0
% INFO    : Bus 12255	: V=1.062762, theta=29.233304 -> V=1.0, theta=0.0
% INFO    : Bus 12256	: V=0.98827, theta=-24.136428 -> V=1.0, theta=0.0
% INFO    : Bus 12257	: V=0.996144, theta=-14.280798 -> V=1.0, theta=0.0
% INFO    : Bus 12258	: V=1.095609, theta=8.932766 -> V=1.0, theta=0.0
% INFO    : Bus 12259	: V=1.06345, theta=20.85668 -> V=1.0, theta=0.0
% INFO    : Bus 12260	: V=1.025901, theta=4.522465 -> V=1.0, theta=0.0
% INFO    : Bus 12261	: V=1.00971, theta=-11.697978 -> V=1.0, theta=0.0
% INFO    : Bus 12262	: V=1.000845, theta=34.550179 -> V=1.0, theta=0.0
% INFO    : Bus 12263	: V=1.009381, theta=-12.831934 -> V=1.0, theta=0.0
% INFO    : Bus 12264	: V=1.027923, theta=5.769471 -> V=1.0, theta=0.0
% INFO    : Bus 12265	: V=1.041994, theta=0.526847 -> V=1.0, theta=0.0
% INFO    : Bus 12266	: V=1.034282, theta=8.113127 -> V=1.0, theta=0.0
% INFO    : Bus 12267	: V=1.02525, theta=28.139664 -> V=1.0, theta=0.0
% INFO    : Bus 12268	: V=1.045266, theta=6.578998 -> V=1.0, theta=0.0
% INFO    : Bus 12269	: V=1.062465, theta=80.362016 -> V=1.0, theta=0.0
% INFO    : Bus 12270	: V=1.013884, theta=6.141471 -> V=1.0, theta=0.0
% INFO    : Bus 12271	: V=1.057978, theta=83.728387 -> V=1.0, theta=0.0
% INFO    : Bus 12272	: V=1.026362, theta=14.401429 -> V=1.0, theta=0.0
% INFO    : Bus 12273	: V=1.004873, theta=26.961875 -> V=1.0, theta=0.0
% INFO    : Bus 12274	: V=1.006483, theta=26.909077 -> V=1.0, theta=0.0
% INFO    : Bus 12275	: V=1.042396, theta=85.13469 -> V=1.0, theta=0.0
% INFO    : Bus 12276	: V=1.042396, theta=85.13469 -> V=1.0, theta=0.0
% INFO    : Bus 12277	: V=1.00107, theta=32.866746 -> V=1.0, theta=0.0
% INFO    : Bus 12278	: V=1.047117, theta=89.983578 -> V=1.0, theta=0.0
% INFO    : Bus 12279	: V=1.047117, theta=89.983578 -> V=1.0, theta=0.0
% INFO    : Bus 12280	: V=1.042396, theta=85.13469 -> V=1.0, theta=0.0
% INFO    : Bus 12281	: V=1.047117, theta=89.983578 -> V=1.0, theta=0.0
% INFO    : Bus 12282	: V=1.028283, theta=16.586422 -> V=1.0, theta=0.0
% INFO    : Bus 12283	: V=1.013768, theta=-6.885216 -> V=1.0, theta=0.0
% INFO    : Bus 12284	: V=1.034072, theta=-10.492546 -> V=1.0, theta=0.0
% INFO    : Bus 12285	: V=0.991765, theta=36.62363 -> V=1.0, theta=0.0
% INFO    : Bus 12286	: V=0.959658, theta=41.263569 -> V=1.0, theta=0.0
% INFO    : Bus 12287	: V=0.993125, theta=29.628125 -> V=1.0, theta=0.0
% INFO    : Bus 12288	: V=1.002315, theta=11.835726 -> V=1.0, theta=0.0
% INFO    : Bus 12289	: V=1.022965, theta=37.031937 -> V=1.0, theta=0.0
% INFO    : Bus 12290	: V=0.947278, theta=-8.004469 -> V=1.0, theta=0.0
% INFO    : Bus 12291	: V=0.990464, theta=21.09396 -> V=1.0, theta=0.0
% INFO    : Bus 12292	: V=1.024657, theta=15.946191 -> V=1.0, theta=0.0
% INFO    : Bus 12293	: V=1.115485, theta=1.405788 -> V=1.0, theta=0.0
% INFO    : Bus 12294	: V=1.016064, theta=32.747434 -> V=1.0, theta=0.0
% INFO    : Bus 12295	: V=1.050283, theta=28.393059 -> V=1.0, theta=0.0
% INFO    : Bus 12296	: V=1.012516, theta=20.730823 -> V=1.0, theta=0.0
% INFO    : Bus 12297	: V=0.988782, theta=-2.439471 -> V=1.0, theta=0.0
% INFO    : Bus 12298	: V=0.980116, theta=-4.823997 -> V=1.0, theta=0.0
% INFO    : Bus 12299	: V=1.037269, theta=23.086136 -> V=1.0, theta=0.0
% INFO    : Bus 12300	: V=1.001772, theta=-12.11369 -> V=1.0, theta=0.0
% INFO    : Bus 12301	: V=1.014152, theta=3.583716 -> V=1.0, theta=0.0
% INFO    : Bus 12302	: V=1.028425, theta=-14.940962 -> V=1.0, theta=0.0
% INFO    : Bus 12303	: V=1.028425, theta=-14.940962 -> V=1.0, theta=0.0
% INFO    : Bus 12304	: V=1.028425, theta=-14.940962 -> V=1.0, theta=0.0
% INFO    : Bus 12305	: V=1.025731, theta=-28.633876 -> V=1.0, theta=0.0
% INFO    : Bus 12306	: V=1.026363, theta=2.051273 -> V=1.0, theta=0.0
% INFO    : Bus 12307	: V=1.028425, theta=-14.940962 -> V=1.0, theta=0.0
% INFO    : Bus 12308	: V=1.018396, theta=3.799696 -> V=1.0, theta=0.0
% INFO    : Bus 12309	: V=1.011255, theta=29.949849 -> V=1.0, theta=0.0
% INFO    : Bus 12310	: V=1.054937, theta=4.624127 -> V=1.0, theta=0.0
% INFO    : Bus 12311	: V=0.991283, theta=25.812593 -> V=1.0, theta=0.0
% INFO    : Bus 12312	: V=1.00568, theta=-6.75619 -> V=1.0, theta=0.0
% INFO    : Bus 12313	: V=1.070945, theta=1.199007 -> V=1.0, theta=0.0
% INFO    : Bus 12314	: V=1.022969, theta=-2.790609 -> V=1.0, theta=0.0
% INFO    : Bus 12315	: V=1.008747, theta=26.26701 -> V=1.0, theta=0.0
% INFO    : Bus 12316	: V=0.998315, theta=-1.39854 -> V=1.0, theta=0.0
% INFO    : Bus 12317	: V=1.019678, theta=-23.024367 -> V=1.0, theta=0.0
% INFO    : Bus 12318	: V=1.052137, theta=7.420861 -> V=1.0, theta=0.0
% INFO    : Bus 12319	: V=1.021414, theta=-20.989235 -> V=1.0, theta=0.0
% INFO    : Bus 12320	: V=1.022961, theta=3.336952 -> V=1.0, theta=0.0
% INFO    : Bus 12321	: V=1.050901, theta=18.201002 -> V=1.0, theta=0.0
% INFO    : Bus 12322	: V=1.027056, theta=17.711863 -> V=1.0, theta=0.0
% INFO    : Bus 12323	: V=1.021419, theta=-22.29244 -> V=1.0, theta=0.0
% INFO    : Bus 12324	: V=0.986522, theta=-4.034109 -> V=1.0, theta=0.0
% INFO    : Bus 12325	: V=1.021414, theta=-20.989235 -> V=1.0, theta=0.0
% INFO    : Bus 12326	: V=0.935752, theta=-10.35524 -> V=1.0, theta=0.0
% INFO    : Bus 12327	: V=1.006613, theta=17.383224 -> V=1.0, theta=0.0
% INFO    : Bus 12328	: V=1.016692, theta=13.997892 -> V=1.0, theta=0.0
% INFO    : Bus 12329	: V=1.025747, theta=22.553164 -> V=1.0, theta=0.0
% INFO    : Bus 12330	: V=1.030356, theta=27.865848 -> V=1.0, theta=0.0
% INFO    : Bus 12331	: V=1.001642, theta=19.795922 -> V=1.0, theta=0.0
% INFO    : Bus 12332	: V=1.030356, theta=27.865848 -> V=1.0, theta=0.0
% INFO    : Bus 12333	: V=1.030356, theta=27.865848 -> V=1.0, theta=0.0
% INFO    : Bus 12334	: V=1.030356, theta=27.865848 -> V=1.0, theta=0.0
% INFO    : Bus 12335	: V=1.057014, theta=60.122944 -> V=1.0, theta=0.0
% INFO    : Bus 12336	: V=1.102395, theta=0.903089 -> V=1.0, theta=0.0
% INFO    : Bus 12337	: V=1.030375, theta=28.469876 -> V=1.0, theta=0.0
% INFO    : Bus 12338	: V=1.030375, theta=28.469876 -> V=1.0, theta=0.0
% INFO    : Bus 12339	: V=1.078678, theta=-4.744253 -> V=1.0, theta=0.0
% INFO    : Bus 12340	: V=1.003295, theta=-3.652509 -> V=1.0, theta=0.0
% INFO    : Bus 12341	: V=1.034048, theta=-9.733404 -> V=1.0, theta=0.0
% INFO    : Bus 12342	: V=1.012736, theta=-19.855402 -> V=1.0, theta=0.0
% INFO    : Bus 12343	: V=1.026073, theta=-20.572924 -> V=1.0, theta=0.0
% INFO    : Bus 12344	: V=1.023729, theta=-5.215442 -> V=1.0, theta=0.0
% INFO    : Bus 12345	: V=1.008569, theta=-7.665426 -> V=1.0, theta=0.0
% INFO    : Bus 12346	: V=1.059619, theta=6.357453 -> V=1.0, theta=0.0
% INFO    : Bus 12347	: V=1.066503, theta=7.436668 -> V=1.0, theta=0.0
% INFO    : Bus 12348	: V=1.057338, theta=4.561597 -> V=1.0, theta=0.0
% INFO    : Bus 12349	: V=1.005646, theta=-3.164565 -> V=1.0, theta=0.0
% INFO    : Bus 12350	: V=1.010129, theta=-10.716048 -> V=1.0, theta=0.0
% INFO    : Bus 12351	: V=0.958855, theta=-9.877767 -> V=1.0, theta=0.0
% INFO    : Bus 12352	: V=1.018483, theta=51.345355 -> V=1.0, theta=0.0
% INFO    : Bus 12353	: V=1.04731, theta=-17.410105 -> V=1.0, theta=0.0
% INFO    : Bus 12354	: V=0.986477, theta=-4.89785 -> V=1.0, theta=0.0
% INFO    : Bus 12355	: V=0.989862, theta=18.147647 -> V=1.0, theta=0.0
% INFO    : Bus 12356	: V=0.99277, theta=18.046203 -> V=1.0, theta=0.0
% INFO    : Bus 12357	: V=1.047215, theta=2.332733 -> V=1.0, theta=0.0
% INFO    : Bus 12358	: V=1.016383, theta=11.964626 -> V=1.0, theta=0.0
% INFO    : Bus 12359	: V=1.00107, theta=32.866746 -> V=1.0, theta=0.0
% INFO    : Bus 12360	: V=1.007927, theta=11.058227 -> V=1.0, theta=0.0
% INFO    : Bus 12361	: V=1.015736, theta=34.286404 -> V=1.0, theta=0.0
% INFO    : Bus 12362	: V=0.999618, theta=53.047091 -> V=1.0, theta=0.0
% INFO    : Bus 12363	: V=0.994361, theta=45.601994 -> V=1.0, theta=0.0
% INFO    : Bus 12364	: V=1.025692, theta=38.011993 -> V=1.0, theta=0.0
% INFO    : Bus 12365	: V=0.995947, theta=2.30069 -> V=1.0, theta=0.0
% INFO    : Bus 12366	: V=1.006419, theta=29.654203 -> V=1.0, theta=0.0
% INFO    : Bus 12367	: V=0.981513, theta=33.636923 -> V=1.0, theta=0.0
% INFO    : Bus 12368	: V=1.023184, theta=33.690697 -> V=1.0, theta=0.0
% INFO    : Bus 12369	: V=1.013904, theta=44.840594 -> V=1.0, theta=0.0
% INFO    : Bus 12370	: V=1.002425, theta=-9.120945 -> V=1.0, theta=0.0
% INFO    : Bus 12371	: V=1.004982, theta=5.145557 -> V=1.0, theta=0.0
% INFO    : Bus 12372	: V=1.023157, theta=55.244731 -> V=1.0, theta=0.0
% INFO    : Bus 12373	: V=1.035914, theta=35.115322 -> V=1.0, theta=0.0
% INFO    : Bus 12374	: V=0.989849, theta=-10.807776 -> V=1.0, theta=0.0
% INFO    : Bus 12375	: V=1.007198, theta=24.820792 -> V=1.0, theta=0.0
% INFO    : Bus 12376	: V=1.035137, theta=3.669478 -> V=1.0, theta=0.0
% INFO    : Bus 12377	: V=1.018693, theta=-8.555675 -> V=1.0, theta=0.0
% INFO    : Bus 12378	: V=1.027094, theta=-8.230817 -> V=1.0, theta=0.0
% INFO    : Bus 12379	: V=1.044824, theta=-6.793188 -> V=1.0, theta=0.0
% INFO    : Bus 12380	: V=0.986027, theta=-2.287209 -> V=1.0, theta=0.0
% INFO    : Bus 12381	: V=1.021475, theta=28.018024 -> V=1.0, theta=0.0
% INFO    : Bus 12382	: V=0.994581, theta=-7.684207 -> V=1.0, theta=0.0
% INFO    : Bus 12383	: V=1.017202, theta=25.964665 -> V=1.0, theta=0.0
% INFO    : Bus 12384	: V=1.033833, theta=-19.153366 -> V=1.0, theta=0.0
% INFO    : Bus 12385	: V=1.027912, theta=18.761456 -> V=1.0, theta=0.0
% INFO    : Bus 12386	: V=1.038916, theta=4.735605 -> V=1.0, theta=0.0
% INFO    : Bus 12387	: V=1.031726, theta=-2.251951 -> V=1.0, theta=0.0
% INFO    : Bus 12388	: V=1.017464, theta=-4.981811 -> V=1.0, theta=0.0
% INFO    : Bus 12389	: V=0.985038, theta=-5.07072 -> V=1.0, theta=0.0
% INFO    : Bus 12390	: V=1.039621, theta=10.691121 -> V=1.0, theta=0.0
% INFO    : Bus 12391	: V=1.060227, theta=-11.884948 -> V=1.0, theta=0.0
% INFO    : Bus 12392	: V=1.014056, theta=-1.175376 -> V=1.0, theta=0.0
% INFO    : Bus 12393	: V=1.090507, theta=11.169589 -> V=1.0, theta=0.0
% INFO    : Bus 12394	: V=1.004203, theta=-9.712444 -> V=1.0, theta=0.0
% INFO    : Bus 12395	: V=1.026656, theta=-6.600104 -> V=1.0, theta=0.0
% INFO    : Bus 12396	: V=1.137371, theta=48.602264 -> V=1.0, theta=0.0
% INFO    : Bus 12397	: V=1.033675, theta=9.664326 -> V=1.0, theta=0.0
% INFO    : Bus 12398	: V=0.988831, theta=38.418014 -> V=1.0, theta=0.0
% INFO    : Bus 12399	: V=1.020782, theta=-1.666242 -> V=1.0, theta=0.0
% INFO    : Bus 12400	: V=1.024479, theta=-0.687261 -> V=1.0, theta=0.0
% INFO    : Bus 12401	: V=1.019049, theta=8.433799 -> V=1.0, theta=0.0
% INFO    : Bus 12402	: V=0.997819, theta=-4.854372 -> V=1.0, theta=0.0
% INFO    : Bus 12403	: V=1.000872, theta=-5.558833 -> V=1.0, theta=0.0
% INFO    : Bus 12404	: V=0.995006, theta=-14.28861 -> V=1.0, theta=0.0
% INFO    : Bus 12405	: V=1.051918, theta=5.627699 -> V=1.0, theta=0.0
% INFO    : Bus 12406	: V=1.068044, theta=88.930216 -> V=1.0, theta=0.0
% INFO    : Bus 12407	: V=1.057605, theta=8.235054 -> V=1.0, theta=0.0
% INFO    : Bus 12408	: V=0.976355, theta=30.641085 -> V=1.0, theta=0.0
% INFO    : Bus 12409	: V=0.994272, theta=-4.708058 -> V=1.0, theta=0.0
% INFO    : Bus 12410	: V=0.958773, theta=0.244074 -> V=1.0, theta=0.0
% INFO    : Bus 12411	: V=1.035207, theta=-6.870994 -> V=1.0, theta=0.0
% INFO    : Bus 12412	: V=1.040313, theta=28.796962 -> V=1.0, theta=0.0
% INFO    : Bus 12413	: V=1.053914, theta=4.841595 -> V=1.0, theta=0.0
% INFO    : Bus 12414	: V=0.988935, theta=-26.085217 -> V=1.0, theta=0.0
% INFO    : Bus 12415	: V=1.028414, theta=-6.287287 -> V=1.0, theta=0.0
% INFO    : Bus 12416	: V=1.029697, theta=16.341634 -> V=1.0, theta=0.0
% INFO    : Bus 12417	: V=0.984319, theta=14.271938 -> V=1.0, theta=0.0
% INFO    : Bus 12418	: V=0.961184, theta=-6.931245 -> V=1.0, theta=0.0
% INFO    : Bus 12419	: V=1.013208, theta=-8.664527 -> V=1.0, theta=0.0
% INFO    : Bus 12420	: V=1.044939, theta=2.648844 -> V=1.0, theta=0.0
% INFO    : Bus 12421	: V=0.981334, theta=37.783033 -> V=1.0, theta=0.0
% INFO    : Bus 12422	: V=1.020663, theta=37.928025 -> V=1.0, theta=0.0
% INFO    : Bus 12423	: V=1.053522, theta=-4.967752 -> V=1.0, theta=0.0
% INFO    : Bus 12424	: V=1.001285, theta=17.521015 -> V=1.0, theta=0.0
% INFO    : Bus 12425	: V=1.001641, theta=-9.981403 -> V=1.0, theta=0.0
% INFO    : Bus 12426	: V=1.012396, theta=-9.882591 -> V=1.0, theta=0.0
% INFO    : Bus 12427	: V=0.951436, theta=-8.337769 -> V=1.0, theta=0.0
% INFO    : Bus 12428	: V=1.027725, theta=-17.372828 -> V=1.0, theta=0.0
% INFO    : Bus 12429	: V=1.027725, theta=-17.372828 -> V=1.0, theta=0.0
% INFO    : Bus 12430	: V=1.027725, theta=-17.372828 -> V=1.0, theta=0.0
% INFO    : Bus 12431	: V=1.027725, theta=-17.372828 -> V=1.0, theta=0.0
% INFO    : Bus 12432	: V=1.063824, theta=4.899786 -> V=1.0, theta=0.0
% INFO    : Bus 12433	: V=1.027725, theta=-17.372828 -> V=1.0, theta=0.0
% INFO    : Bus 12434	: V=1.013219, theta=-5.540854 -> V=1.0, theta=0.0
% INFO    : Bus 12435	: V=1.033007, theta=6.963586 -> V=1.0, theta=0.0
% INFO    : Bus 12436	: V=1.022086, theta=26.499257 -> V=1.0, theta=0.0
% INFO    : Bus 12437	: V=1.019936, theta=14.700597 -> V=1.0, theta=0.0
% INFO    : Bus 12438	: V=1.008454, theta=28.268379 -> V=1.0, theta=0.0
% INFO    : Bus 12439	: V=1.033316, theta=30.22478 -> V=1.0, theta=0.0
% INFO    : Bus 12440	: V=1.043738, theta=-8.975119 -> V=1.0, theta=0.0
% INFO    : Bus 12441	: V=1.004719, theta=2.040837 -> V=1.0, theta=0.0
% INFO    : Bus 12442	: V=0.98672, theta=-22.441078 -> V=1.0, theta=0.0
% INFO    : Bus 12443	: V=0.967037, theta=-8.252401 -> V=1.0, theta=0.0
% INFO    : Bus 12444	: V=1.00773, theta=0.837784 -> V=1.0, theta=0.0
% INFO    : Bus 12445	: V=1.058596, theta=0.438284 -> V=1.0, theta=0.0
% INFO    : Bus 12446	: V=1.041946, theta=-1.815076 -> V=1.0, theta=0.0
% INFO    : Bus 12447	: V=1.028667, theta=-4.741858 -> V=1.0, theta=0.0
% INFO    : Bus 12448	: V=1.036966, theta=15.051213 -> V=1.0, theta=0.0
% INFO    : Bus 12449	: V=1.017949, theta=10.152132 -> V=1.0, theta=0.0
% INFO    : Bus 12450	: V=1.025585, theta=34.455378 -> V=1.0, theta=0.0
% INFO    : Bus 12451	: V=1.024669, theta=12.739456 -> V=1.0, theta=0.0
% INFO    : Bus 12452	: V=1.035311, theta=42.433038 -> V=1.0, theta=0.0
% INFO    : Bus 12453	: V=1.035255, theta=42.395082 -> V=1.0, theta=0.0
% INFO    : Bus 12454	: V=1.016573, theta=45.994905 -> V=1.0, theta=0.0
% INFO    : Bus 12455	: V=1.028667, theta=-4.741858 -> V=1.0, theta=0.0
% INFO    : Bus 12456	: V=1.058626, theta=17.900462 -> V=1.0, theta=0.0
% INFO    : Bus 12457	: V=1.014358, theta=41.933926 -> V=1.0, theta=0.0
% INFO    : Bus 12458	: V=1.01073, theta=-8.580613 -> V=1.0, theta=0.0
% INFO    : Bus 12459	: V=1.04826, theta=-8.707987 -> V=1.0, theta=0.0
% INFO    : Bus 12460	: V=1.062485, theta=0.136857 -> V=1.0, theta=0.0
% INFO    : Bus 12461	: V=1.057713, theta=44.127182 -> V=1.0, theta=0.0
% INFO    : Bus 12462	: V=1.057713, theta=44.127182 -> V=1.0, theta=0.0
% INFO    : Bus 12463	: V=0.971587, theta=5.047365 -> V=1.0, theta=0.0
% INFO    : Bus 12464	: V=1.057713, theta=44.127182 -> V=1.0, theta=0.0
% INFO    : Bus 12465	: V=1.05445, theta=48.75455 -> V=1.0, theta=0.0
% INFO    : Bus 12466	: V=1.057713, theta=44.127182 -> V=1.0, theta=0.0
% INFO    : Bus 12467	: V=1.057713, theta=44.127182 -> V=1.0, theta=0.0
% INFO    : Bus 12468	: V=0.991937, theta=88.98538 -> V=1.0, theta=0.0
% INFO    : Bus 12469	: V=1.05445, theta=48.75455 -> V=1.0, theta=0.0
% INFO    : Bus 12470	: V=1.05445, theta=48.75455 -> V=1.0, theta=0.0
% INFO    : Bus 12471	: V=1.033422, theta=-6.60149 -> V=1.0, theta=0.0
% INFO    : Bus 12472	: V=1.040643, theta=19.952471 -> V=1.0, theta=0.0
% INFO    : Bus 12473	: V=1.039652, theta=-6.424256 -> V=1.0, theta=0.0
% INFO    : Bus 12474	: V=1.000416, theta=28.059075 -> V=1.0, theta=0.0
% INFO    : Bus 12475	: V=1.009859, theta=39.894462 -> V=1.0, theta=0.0
% INFO    : Bus 12476	: V=1.01083, theta=28.808468 -> V=1.0, theta=0.0
% INFO    : Bus 12477	: V=1.037214, theta=32.974337 -> V=1.0, theta=0.0
% INFO    : Bus 12478	: V=1.012634, theta=-19.834858 -> V=1.0, theta=0.0
% INFO    : Bus 12479	: V=0.983018, theta=-8.488121 -> V=1.0, theta=0.0
% INFO    : Bus 12480	: V=1.015791, theta=-1.704574 -> V=1.0, theta=0.0
% INFO    : Bus 12481	: V=1.014445, theta=32.429678 -> V=1.0, theta=0.0
% INFO    : Bus 12482	: V=1.077814, theta=0.7293 -> V=1.0, theta=0.0
% INFO    : Bus 12483	: V=1.056191, theta=25.665794 -> V=1.0, theta=0.0
% INFO    : Bus 12484	: V=1.046801, theta=25.041884 -> V=1.0, theta=0.0
% INFO    : Bus 12485	: V=0.983182, theta=7.024133 -> V=1.0, theta=0.0
% INFO    : Bus 12486	: V=0.994915, theta=24.02232 -> V=1.0, theta=0.0
% INFO    : Bus 12487	: V=1.024241, theta=-6.779685 -> V=1.0, theta=0.0
% INFO    : Bus 12488	: V=1.12345, theta=-0.14804 -> V=1.0, theta=0.0
% INFO    : Bus 12489	: V=0.992433, theta=-3.280361 -> V=1.0, theta=0.0
% INFO    : Bus 12490	: V=1.023616, theta=-1.513773 -> V=1.0, theta=0.0
% INFO    : Bus 12491	: V=1.033243, theta=1.205486 -> V=1.0, theta=0.0
% INFO    : Bus 12492	: V=1.028436, theta=20.306678 -> V=1.0, theta=0.0
% INFO    : Bus 12493	: V=1.079318, theta=2.779714 -> V=1.0, theta=0.0
% INFO    : Bus 12494	: V=1.01993, theta=9.094543 -> V=1.0, theta=0.0
% INFO    : Bus 12495	: V=1.0268, theta=-20.255767 -> V=1.0, theta=0.0
% INFO    : Bus 12496	: V=0.972421, theta=7.134096 -> V=1.0, theta=0.0
% INFO    : Bus 12497	: V=1.030865, theta=18.670476 -> V=1.0, theta=0.0
% INFO    : Bus 12498	: V=1.071574, theta=22.564331 -> V=1.0, theta=0.0
% INFO    : Bus 12499	: V=1.040719, theta=26.306193 -> V=1.0, theta=0.0
% INFO    : Bus 12500	: V=1.050684, theta=91.443424 -> V=1.0, theta=0.0
% INFO    : Bus 12501	: V=1.032889, theta=46.113563 -> V=1.0, theta=0.0
% INFO    : Bus 12502	: V=1.004154, theta=-3.879517 -> V=1.0, theta=0.0
% INFO    : Bus 12503	: V=0.985206, theta=1.958171 -> V=1.0, theta=0.0
% INFO    : Bus 12504	: V=1.050851, theta=44.081079 -> V=1.0, theta=0.0
% INFO    : Bus 12505	: V=1.029991, theta=3.188016 -> V=1.0, theta=0.0
% INFO    : Bus 12506	: V=1.029991, theta=3.188016 -> V=1.0, theta=0.0
% INFO    : Bus 12507	: V=1.015733, theta=2.857525 -> V=1.0, theta=0.0
% INFO    : Bus 12508	: V=1.001199, theta=-2.907812 -> V=1.0, theta=0.0
% INFO    : Bus 12509	: V=1.060659, theta=20.876727 -> V=1.0, theta=0.0
% INFO    : Bus 12510	: V=1.043805, theta=-6.740275 -> V=1.0, theta=0.0
% INFO    : Bus 12511	: V=1.032077, theta=9.94197 -> V=1.0, theta=0.0
% INFO    : Bus 12512	: V=1.003067, theta=26.71029 -> V=1.0, theta=0.0
% INFO    : Bus 12513	: V=1.049549, theta=58.720219 -> V=1.0, theta=0.0
% INFO    : Bus 12514	: V=1.033467, theta=32.233232 -> V=1.0, theta=0.0
% INFO    : Bus 12515	: V=1.05922, theta=-11.863331 -> V=1.0, theta=0.0
% INFO    : Bus 12516	: V=1.02408, theta=7.904971 -> V=1.0, theta=0.0
% INFO    : Bus 12517	: V=1.024254, theta=10.943171 -> V=1.0, theta=0.0
% INFO    : Bus 12518	: V=1.028417, theta=-6.105187 -> V=1.0, theta=0.0
% INFO    : Bus 12519	: V=1.057091, theta=77.565872 -> V=1.0, theta=0.0
% INFO    : Bus 12520	: V=1.021469, theta=26.422336 -> V=1.0, theta=0.0
% INFO    : Bus 12521	: V=1.022689, theta=-16.891323 -> V=1.0, theta=0.0
% INFO    : Bus 12522	: V=1.022689, theta=-16.891323 -> V=1.0, theta=0.0
% INFO    : Bus 12523	: V=1.022689, theta=-16.891323 -> V=1.0, theta=0.0
% INFO    : Bus 12524	: V=0.983198, theta=-2.811042 -> V=1.0, theta=0.0
% INFO    : Bus 12525	: V=1.034235, theta=2.214597 -> V=1.0, theta=0.0
% INFO    : Bus 12526	: V=1.034235, theta=2.214597 -> V=1.0, theta=0.0
% INFO    : Bus 12527	: V=1.024706, theta=22.682557 -> V=1.0, theta=0.0
% INFO    : Bus 12528	: V=1.040642, theta=8.532255 -> V=1.0, theta=0.0
% INFO    : Bus 12529	: V=1.024151, theta=24.403529 -> V=1.0, theta=0.0
% INFO    : Bus 12530	: V=0.963945, theta=-9.066656 -> V=1.0, theta=0.0
% INFO    : Bus 12531	: V=1.062163, theta=20.979236 -> V=1.0, theta=0.0
% INFO    : Bus 12532	: V=0.947189, theta=-8.737106 -> V=1.0, theta=0.0
% INFO    : Bus 12533	: V=1.044117, theta=0.887619 -> V=1.0, theta=0.0
% INFO    : Bus 12534	: V=1.042522, theta=-4.869386 -> V=1.0, theta=0.0
% INFO    : Bus 12535	: V=1.040037, theta=14.871755 -> V=1.0, theta=0.0
% INFO    : Bus 12536	: V=1.04179, theta=74.863317 -> V=1.0, theta=0.0
% INFO    : Bus 12537	: V=1.035364, theta=12.970449 -> V=1.0, theta=0.0
% INFO    : Bus 12538	: V=0.992161, theta=2.241109 -> V=1.0, theta=0.0
% INFO    : Bus 12539	: V=1.006626, theta=-6.636873 -> V=1.0, theta=0.0
% INFO    : Bus 12540	: V=0.942721, theta=-7.656569 -> V=1.0, theta=0.0
% INFO    : Bus 12541	: V=1.02993, theta=1.561794 -> V=1.0, theta=0.0
% INFO    : Bus 12542	: V=1.028438, theta=-19.446471 -> V=1.0, theta=0.0
% INFO    : Bus 12543	: V=1.012068, theta=24.123921 -> V=1.0, theta=0.0
% INFO    : Bus 12544	: V=1.051432, theta=-10.828911 -> V=1.0, theta=0.0
% INFO    : Bus 12545	: V=0.964406, theta=-4.211993 -> V=1.0, theta=0.0
% INFO    : Bus 12546	: V=0.985531, theta=-4.991115 -> V=1.0, theta=0.0
% INFO    : Bus 12547	: V=1.023772, theta=3.420383 -> V=1.0, theta=0.0
% INFO    : Bus 12548	: V=1.033735, theta=42.729299 -> V=1.0, theta=0.0
% INFO    : Bus 12549	: V=1.015104, theta=-0.273623 -> V=1.0, theta=0.0
% INFO    : Bus 12550	: V=1.019828, theta=44.646555 -> V=1.0, theta=0.0
% INFO    : Bus 12551	: V=1.034631, theta=4.683321 -> V=1.0, theta=0.0
% INFO    : Bus 12552	: V=1.027627, theta=5.677018 -> V=1.0, theta=0.0
% INFO    : Bus 12553	: V=1.012708, theta=-19.712251 -> V=1.0, theta=0.0
% INFO    : Bus 12554	: V=1.020861, theta=-3.956799 -> V=1.0, theta=0.0
% INFO    : Bus 12555	: V=1.003834, theta=31.873789 -> V=1.0, theta=0.0
% INFO    : Bus 12556	: V=1.029835, theta=-14.681025 -> V=1.0, theta=0.0
% INFO    : Bus 12557	: V=0.992801, theta=39.577248 -> V=1.0, theta=0.0
% INFO    : Bus 12558	: V=0.971908, theta=40.431219 -> V=1.0, theta=0.0
% INFO    : Bus 12559	: V=1.04358, theta=17.126486 -> V=1.0, theta=0.0
% INFO    : Bus 12560	: V=1.032136, theta=33.351366 -> V=1.0, theta=0.0
% INFO    : Bus 12561	: V=1.02606, theta=16.511466 -> V=1.0, theta=0.0
% INFO    : Bus 12562	: V=1.017664, theta=-15.016249 -> V=1.0, theta=0.0
% INFO    : Bus 12563	: V=1.020396, theta=12.801356 -> V=1.0, theta=0.0
% INFO    : Bus 12564	: V=1.001293, theta=17.356053 -> V=1.0, theta=0.0
% INFO    : Bus 12565	: V=1.057526, theta=-6.024854 -> V=1.0, theta=0.0
% INFO    : Bus 12566	: V=1.030112, theta=17.57744 -> V=1.0, theta=0.0
% INFO    : Bus 12567	: V=1.032903, theta=-3.018826 -> V=1.0, theta=0.0
% INFO    : Bus 12568	: V=0.990229, theta=11.73922 -> V=1.0, theta=0.0
% INFO    : Bus 12569	: V=1.011983, theta=20.514966 -> V=1.0, theta=0.0
% INFO    : Bus 12570	: V=1.022447, theta=17.861755 -> V=1.0, theta=0.0
% INFO    : Bus 12571	: V=1.021812, theta=59.451188 -> V=1.0, theta=0.0
% INFO    : Bus 12572	: V=0.989707, theta=35.937223 -> V=1.0, theta=0.0
% INFO    : Bus 12573	: V=1.060539, theta=4.452559 -> V=1.0, theta=0.0
% INFO    : Bus 12574	: V=0.976396, theta=-27.177556 -> V=1.0, theta=0.0
% INFO    : Bus 12575	: V=1.04035, theta=8.357264 -> V=1.0, theta=0.0
% INFO    : Bus 12576	: V=1.04035, theta=8.357264 -> V=1.0, theta=0.0
% INFO    : Bus 12577	: V=1.017564, theta=-19.177951 -> V=1.0, theta=0.0
% INFO    : Bus 12578	: V=1.04035, theta=8.357264 -> V=1.0, theta=0.0
% INFO    : Bus 12579	: V=0.960771, theta=44.51306 -> V=1.0, theta=0.0
% INFO    : Bus 12580	: V=1.04035, theta=8.357264 -> V=1.0, theta=0.0
% INFO    : Bus 12581	: V=1.04035, theta=8.357264 -> V=1.0, theta=0.0
% INFO    : Bus 12582	: V=1.049495, theta=12.649819 -> V=1.0, theta=0.0
% INFO    : Bus 12583	: V=1.049495, theta=12.649819 -> V=1.0, theta=0.0
% INFO    : Bus 12584	: V=1.025973, theta=5.996733 -> V=1.0, theta=0.0
% INFO    : Bus 12585	: V=1.04035, theta=8.357264 -> V=1.0, theta=0.0
% INFO    : Bus 12586	: V=1.058287, theta=5.521142 -> V=1.0, theta=0.0
% INFO    : Bus 12587	: V=1.016947, theta=23.125552 -> V=1.0, theta=0.0
% INFO    : Bus 12588	: V=0.980901, theta=1.580971 -> V=1.0, theta=0.0
% INFO    : Bus 12589	: V=1.058287, theta=5.521142 -> V=1.0, theta=0.0
% INFO    : Bus 12590	: V=1.058287, theta=5.521142 -> V=1.0, theta=0.0
% INFO    : Bus 12591	: V=1.058287, theta=5.521142 -> V=1.0, theta=0.0
% INFO    : Bus 12592	: V=1.058287, theta=5.521142 -> V=1.0, theta=0.0
% INFO    : Bus 12593	: V=0.991603, theta=-12.182028 -> V=1.0, theta=0.0
% INFO    : Bus 12594	: V=1.029513, theta=3.924035 -> V=1.0, theta=0.0
% INFO    : Bus 12595	: V=1.031042, theta=8.597105 -> V=1.0, theta=0.0
% INFO    : Bus 12596	: V=0.975425, theta=9.544549 -> V=1.0, theta=0.0
% INFO    : Bus 12597	: V=1.03197, theta=34.05665 -> V=1.0, theta=0.0
% INFO    : Bus 12598	: V=0.99025, theta=-4.371984 -> V=1.0, theta=0.0
% INFO    : Bus 12599	: V=1.033945, theta=-7.536483 -> V=1.0, theta=0.0
% INFO    : Bus 12600	: V=1.033945, theta=-7.536483 -> V=1.0, theta=0.0
% INFO    : Bus 12601	: V=1.033945, theta=-7.536483 -> V=1.0, theta=0.0
% INFO    : Bus 12602	: V=1.012421, theta=-10.166509 -> V=1.0, theta=0.0
% INFO    : Bus 12603	: V=0.947933, theta=57.203162 -> V=1.0, theta=0.0
% INFO    : Bus 12604	: V=0.944619, theta=-7.941005 -> V=1.0, theta=0.0
% INFO    : Bus 12605	: V=1.02557, theta=17.194572 -> V=1.0, theta=0.0
% INFO    : Bus 12606	: V=1.020332, theta=23.152992 -> V=1.0, theta=0.0
% INFO    : Bus 12607	: V=1.026221, theta=1.816827 -> V=1.0, theta=0.0
% INFO    : Bus 12608	: V=1.011671, theta=23.560034 -> V=1.0, theta=0.0
% INFO    : Bus 12609	: V=1.003783, theta=14.429739 -> V=1.0, theta=0.0
% INFO    : Bus 12610	: V=1.026221, theta=1.816827 -> V=1.0, theta=0.0
% INFO    : Bus 12611	: V=1.026964, theta=17.858001 -> V=1.0, theta=0.0
% INFO    : Bus 12612	: V=1.030988, theta=2.394145 -> V=1.0, theta=0.0
% INFO    : Bus 12613	: V=0.99345, theta=-24.884337 -> V=1.0, theta=0.0
% INFO    : Bus 12614	: V=1.045898, theta=82.995161 -> V=1.0, theta=0.0
% INFO    : Bus 12615	: V=0.993712, theta=-1.750779 -> V=1.0, theta=0.0
% INFO    : Bus 12616	: V=0.996117, theta=32.042491 -> V=1.0, theta=0.0
% INFO    : Bus 12617	: V=0.979247, theta=-8.554353 -> V=1.0, theta=0.0
% INFO    : Bus 12618	: V=0.96442, theta=-0.202797 -> V=1.0, theta=0.0
% INFO    : Bus 12619	: V=0.996198, theta=-5.152317 -> V=1.0, theta=0.0
% INFO    : Bus 12620	: V=1.010475, theta=30.420994 -> V=1.0, theta=0.0
% INFO    : Bus 12621	: V=1.006881, theta=26.429157 -> V=1.0, theta=0.0
% INFO    : Bus 12622	: V=1.074567, theta=88.264357 -> V=1.0, theta=0.0
% INFO    : Bus 12623	: V=1.001746, theta=17.611273 -> V=1.0, theta=0.0
% INFO    : Bus 12624	: V=1.018821, theta=-14.589104 -> V=1.0, theta=0.0
% INFO    : Bus 12625	: V=0.948759, theta=58.410078 -> V=1.0, theta=0.0
% INFO    : Bus 12626	: V=1.042524, theta=1.0069 -> V=1.0, theta=0.0
% INFO    : Bus 12627	: V=1.003651, theta=31.884957 -> V=1.0, theta=0.0
% INFO    : Bus 12628	: V=0.964149, theta=-15.086645 -> V=1.0, theta=0.0
% INFO    : Bus 12629	: V=1.024655, theta=7.233326 -> V=1.0, theta=0.0
% INFO    : Bus 12630	: V=1.055954, theta=27.990261 -> V=1.0, theta=0.0
% INFO    : Bus 12631	: V=1.048783, theta=-15.463026 -> V=1.0, theta=0.0
% INFO    : Bus 12632	: V=1.079049, theta=-0.263696 -> V=1.0, theta=0.0
% INFO    : Bus 12633	: V=1.014079, theta=18.851636 -> V=1.0, theta=0.0
% INFO    : Bus 12634	: V=1.036563, theta=-1.739082 -> V=1.0, theta=0.0
% INFO    : Bus 12635	: V=1.012593, theta=3.023648 -> V=1.0, theta=0.0
% INFO    : Bus 12636	: V=1.007821, theta=10.245998 -> V=1.0, theta=0.0
% INFO    : Bus 12637	: V=0.998377, theta=6.098094 -> V=1.0, theta=0.0
% INFO    : Bus 12638	: V=0.995589, theta=-3.184629 -> V=1.0, theta=0.0
% INFO    : Bus 12639	: V=0.991849, theta=-13.731605 -> V=1.0, theta=0.0
% INFO    : Bus 12640	: V=1.014372, theta=-1.282515 -> V=1.0, theta=0.0
% INFO    : Bus 12641	: V=0.995435, theta=4.377334 -> V=1.0, theta=0.0
% INFO    : Bus 12642	: V=1.022369, theta=22.437418 -> V=1.0, theta=0.0
% INFO    : Bus 12643	: V=1.023722, theta=-7.333653 -> V=1.0, theta=0.0
% INFO    : Bus 12644	: V=0.962725, theta=-7.715632 -> V=1.0, theta=0.0
% INFO    : Bus 12645	: V=1.026651, theta=-27.256651 -> V=1.0, theta=0.0
% INFO    : Bus 12646	: V=1.042693, theta=10.439455 -> V=1.0, theta=0.0
% INFO    : Bus 12647	: V=1.029333, theta=-7.499675 -> V=1.0, theta=0.0
% INFO    : Bus 12648	: V=1.029333, theta=-7.499675 -> V=1.0, theta=0.0
% INFO    : Bus 12649	: V=0.990644, theta=-1.876429 -> V=1.0, theta=0.0
% INFO    : Bus 12650	: V=1.029333, theta=-7.499675 -> V=1.0, theta=0.0
% INFO    : Bus 12651	: V=1.029323, theta=-7.468239 -> V=1.0, theta=0.0
% INFO    : Bus 12652	: V=1.029323, theta=-7.468239 -> V=1.0, theta=0.0
% INFO    : Bus 12653	: V=1.029333, theta=-7.499675 -> V=1.0, theta=0.0
% INFO    : Bus 12654	: V=1.029323, theta=-7.468239 -> V=1.0, theta=0.0
% INFO    : Bus 12655	: V=1.004761, theta=-16.59957 -> V=1.0, theta=0.0
% INFO    : Bus 12656	: V=1.04659, theta=30.049071 -> V=1.0, theta=0.0
% INFO    : Bus 12657	: V=1.017738, theta=25.492678 -> V=1.0, theta=0.0
% INFO    : Bus 12658	: V=0.956073, theta=24.685075 -> V=1.0, theta=0.0
% INFO    : Bus 12659	: V=1.040793, theta=26.940223 -> V=1.0, theta=0.0
% INFO    : Bus 12660	: V=1.016117, theta=19.693513 -> V=1.0, theta=0.0
% INFO    : Bus 12661	: V=0.993913, theta=-7.711171 -> V=1.0, theta=0.0
% INFO    : Bus 12662	: V=1.031338, theta=-16.305128 -> V=1.0, theta=0.0
% INFO    : Bus 12663	: V=0.997924, theta=-10.001384 -> V=1.0, theta=0.0
% INFO    : Bus 12664	: V=1.037469, theta=11.940478 -> V=1.0, theta=0.0
% INFO    : Bus 12665	: V=1.038308, theta=18.388307 -> V=1.0, theta=0.0
% INFO    : Bus 12666	: V=1.075158, theta=0.186 -> V=1.0, theta=0.0
% INFO    : Bus 12667	: V=0.978996, theta=-5.170122 -> V=1.0, theta=0.0
% INFO    : Bus 12668	: V=1.017623, theta=-24.44662 -> V=1.0, theta=0.0
% INFO    : Bus 12669	: V=1.067807, theta=11.076245 -> V=1.0, theta=0.0
% INFO    : Bus 12670	: V=1.016854, theta=15.686717 -> V=1.0, theta=0.0
% INFO    : Bus 12671	: V=1.027688, theta=40.037008 -> V=1.0, theta=0.0
% INFO    : Bus 12672	: V=1.003775, theta=-1.133771 -> V=1.0, theta=0.0
% INFO    : Bus 12673	: V=1.040793, theta=26.940223 -> V=1.0, theta=0.0
% INFO    : Bus 12674	: V=1.029478, theta=-2.341076 -> V=1.0, theta=0.0
% INFO    : Bus 12675	: V=1.004938, theta=-21.014507 -> V=1.0, theta=0.0
% INFO    : Bus 12676	: V=0.974521, theta=-8.282724 -> V=1.0, theta=0.0
% INFO    : Bus 12677	: V=1.041687, theta=-2.946438 -> V=1.0, theta=0.0
% INFO    : Bus 12678	: V=1.090507, theta=11.169589 -> V=1.0, theta=0.0
% INFO    : Bus 12679	: V=1.020254, theta=-23.064206 -> V=1.0, theta=0.0
% INFO    : Bus 12680	: V=1.069511, theta=1.473714 -> V=1.0, theta=0.0
% INFO    : Bus 12681	: V=1.014635, theta=-0.980319 -> V=1.0, theta=0.0
% INFO    : Bus 12682	: V=1.024518, theta=-10.41164 -> V=1.0, theta=0.0
% INFO    : Bus 12683	: V=1.054144, theta=25.676299 -> V=1.0, theta=0.0
% INFO    : Bus 12684	: V=1.072691, theta=72.716931 -> V=1.0, theta=0.0
% INFO    : Bus 12685	: V=0.954262, theta=-5.140695 -> V=1.0, theta=0.0
% INFO    : Bus 12686	: V=0.996188, theta=29.118836 -> V=1.0, theta=0.0
% INFO    : Bus 12687	: V=1.01812, theta=15.465461 -> V=1.0, theta=0.0
% INFO    : Bus 12688	: V=1.001419, theta=42.731033 -> V=1.0, theta=0.0
% INFO    : Bus 12689	: V=1.025956, theta=7.450641 -> V=1.0, theta=0.0
% INFO    : Bus 12690	: V=1.040793, theta=26.940223 -> V=1.0, theta=0.0
% INFO    : Bus 12691	: V=0.989794, theta=-3.305032 -> V=1.0, theta=0.0
% INFO    : Bus 12692	: V=1.015529, theta=-18.474164 -> V=1.0, theta=0.0
% INFO    : Bus 12693	: V=0.963088, theta=-5.788161 -> V=1.0, theta=0.0
% INFO    : Bus 12694	: V=1.015506, theta=-2.151015 -> V=1.0, theta=0.0
% INFO    : Bus 12695	: V=1.024295, theta=-24.350547 -> V=1.0, theta=0.0
% INFO    : Bus 12696	: V=1.038067, theta=5.796634 -> V=1.0, theta=0.0
% INFO    : Bus 12697	: V=1.027132, theta=31.963051 -> V=1.0, theta=0.0
% INFO    : Bus 12698	: V=0.987855, theta=34.356338 -> V=1.0, theta=0.0
% INFO    : Bus 12699	: V=1.027132, theta=31.963051 -> V=1.0, theta=0.0
% INFO    : Bus 12700	: V=1.024885, theta=0.182742 -> V=1.0, theta=0.0
% INFO    : Bus 12701	: V=1.041939, theta=17.231675 -> V=1.0, theta=0.0
% INFO    : Bus 12702	: V=1.027132, theta=31.963051 -> V=1.0, theta=0.0
% INFO    : Bus 12703	: V=1.01143, theta=-19.86799 -> V=1.0, theta=0.0
% INFO    : Bus 12704	: V=1.041939, theta=17.231675 -> V=1.0, theta=0.0
% INFO    : Bus 12705	: V=1.03975, theta=24.63487 -> V=1.0, theta=0.0
% INFO    : Bus 12706	: V=1.03975, theta=24.63487 -> V=1.0, theta=0.0
% INFO    : Bus 12707	: V=1.02861, theta=33.499831 -> V=1.0, theta=0.0
% INFO    : Bus 12708	: V=1.017238, theta=-14.795645 -> V=1.0, theta=0.0
% INFO    : Bus 12709	: V=1.011489, theta=10.204543 -> V=1.0, theta=0.0
% INFO    : Bus 12710	: V=1.00238, theta=-9.035194 -> V=1.0, theta=0.0
% INFO    : Bus 12711	: V=1.007801, theta=-12.641343 -> V=1.0, theta=0.0
% INFO    : Bus 12712	: V=0.997405, theta=-17.375683 -> V=1.0, theta=0.0
% INFO    : Bus 12713	: V=1.009886, theta=-8.195055 -> V=1.0, theta=0.0
% INFO    : Bus 12714	: V=1.017238, theta=-14.795645 -> V=1.0, theta=0.0
% INFO    : Bus 12715	: V=1.020382, theta=-2.841001 -> V=1.0, theta=0.0
% INFO    : Bus 12716	: V=1.030243, theta=11.953288 -> V=1.0, theta=0.0
% INFO    : Bus 12717	: V=1.043087, theta=11.638661 -> V=1.0, theta=0.0
% INFO    : Bus 12718	: V=1.01571, theta=22.558348 -> V=1.0, theta=0.0
% INFO    : Bus 12719	: V=0.992973, theta=90.962411 -> V=1.0, theta=0.0
% INFO    : Bus 12720	: V=1.088271, theta=29.372504 -> V=1.0, theta=0.0
% INFO    : Bus 12721	: V=0.993038, theta=-9.265022 -> V=1.0, theta=0.0
% INFO    : Bus 12722	: V=1.000556, theta=26.386651 -> V=1.0, theta=0.0
% INFO    : Bus 12723	: V=1.015411, theta=-5.476788 -> V=1.0, theta=0.0
% INFO    : Bus 12724	: V=1.028402, theta=2.843072 -> V=1.0, theta=0.0
% INFO    : Bus 12725	: V=1.042121, theta=-1.28407 -> V=1.0, theta=0.0
% INFO    : Bus 12726	: V=1.035338, theta=-7.144697 -> V=1.0, theta=0.0
% INFO    : Bus 12727	: V=1.029542, theta=-3.096329 -> V=1.0, theta=0.0
% INFO    : Bus 12728	: V=1.03058, theta=15.553508 -> V=1.0, theta=0.0
% INFO    : Bus 12729	: V=0.953443, theta=-7.581698 -> V=1.0, theta=0.0
% INFO    : Bus 12730	: V=1.017293, theta=7.59717 -> V=1.0, theta=0.0
% INFO    : Bus 12731	: V=0.996162, theta=-2.611738 -> V=1.0, theta=0.0
% INFO    : Bus 12732	: V=1.013494, theta=12.768835 -> V=1.0, theta=0.0
% INFO    : Bus 12733	: V=1.029781, theta=18.149388 -> V=1.0, theta=0.0
% INFO    : Bus 12734	: V=1.021614, theta=43.10077 -> V=1.0, theta=0.0
% INFO    : Bus 12735	: V=1.008169, theta=-10.617063 -> V=1.0, theta=0.0
% INFO    : Bus 12736	: V=0.957116, theta=25.356265 -> V=1.0, theta=0.0
% INFO    : Bus 12737	: V=1.016051, theta=5.508506 -> V=1.0, theta=0.0
% INFO    : Bus 12738	: V=1.027968, theta=24.05088 -> V=1.0, theta=0.0
% INFO    : Bus 12739	: V=1.034435, theta=9.724651 -> V=1.0, theta=0.0
% INFO    : Bus 12740	: V=0.983226, theta=-12.964461 -> V=1.0, theta=0.0
% INFO    : Bus 12741	: V=1.020254, theta=-23.064206 -> V=1.0, theta=0.0
% INFO    : Bus 12742	: V=1.035958, theta=27.387404 -> V=1.0, theta=0.0
% INFO    : Bus 12743	: V=1.04543, theta=-13.937788 -> V=1.0, theta=0.0
% INFO    : Bus 12744	: V=1.049407, theta=3.6767 -> V=1.0, theta=0.0
% INFO    : Bus 12745	: V=0.998919, theta=12.925679 -> V=1.0, theta=0.0
% INFO    : Bus 12746	: V=0.990115, theta=-3.684995 -> V=1.0, theta=0.0
% INFO    : Bus 12747	: V=1.035958, theta=27.387404 -> V=1.0, theta=0.0
% INFO    : Bus 12748	: V=0.9846, theta=26.113194 -> V=1.0, theta=0.0
% INFO    : Bus 12749	: V=1.020995, theta=3.543798 -> V=1.0, theta=0.0
% INFO    : Bus 12750	: V=1.031586, theta=6.722493 -> V=1.0, theta=0.0
% INFO    : Bus 12751	: V=0.961075, theta=-15.738133 -> V=1.0, theta=0.0
% INFO    : Bus 12752	: V=1.046972, theta=-19.838782 -> V=1.0, theta=0.0
% INFO    : Bus 12753	: V=0.927015, theta=-12.042266 -> V=1.0, theta=0.0
% INFO    : Bus 12754	: V=1.015754, theta=-20.966355 -> V=1.0, theta=0.0
% INFO    : Bus 12755	: V=1.053726, theta=-3.038855 -> V=1.0, theta=0.0
% INFO    : Bus 12756	: V=1.026235, theta=6.371926 -> V=1.0, theta=0.0
% INFO    : Bus 12757	: V=1.001945, theta=0.575302 -> V=1.0, theta=0.0
% INFO    : Bus 12758	: V=1.0608, theta=42.720858 -> V=1.0, theta=0.0
% INFO    : Bus 12759	: V=0.991622, theta=29.430959 -> V=1.0, theta=0.0
% INFO    : Bus 12760	: V=1.028736, theta=-6.917679 -> V=1.0, theta=0.0
% INFO    : Bus 12761	: V=1.028736, theta=-6.917679 -> V=1.0, theta=0.0
% INFO    : Bus 12762	: V=0.996936, theta=-19.146593 -> V=1.0, theta=0.0
% INFO    : Bus 12763	: V=1.028736, theta=-6.917679 -> V=1.0, theta=0.0
% INFO    : Bus 12764	: V=1.051947, theta=4.007575 -> V=1.0, theta=0.0
% INFO    : Bus 12765	: V=1.051947, theta=4.007575 -> V=1.0, theta=0.0
% INFO    : Bus 12766	: V=1.011954, theta=-10.391865 -> V=1.0, theta=0.0
% INFO    : Bus 12767	: V=0.965766, theta=-9.555001 -> V=1.0, theta=0.0
% INFO    : Bus 12768	: V=1.015423, theta=34.258867 -> V=1.0, theta=0.0
% INFO    : Bus 12769	: V=1.016798, theta=24.877895 -> V=1.0, theta=0.0
% INFO    : Bus 12770	: V=1.177153, theta=3.211364 -> V=1.0, theta=0.0
% INFO    : Bus 12771	: V=1.083886, theta=-4.648509 -> V=1.0, theta=0.0
% INFO    : Bus 12772	: V=1.04706, theta=-6.69158 -> V=1.0, theta=0.0
% INFO    : Bus 12773	: V=1.0196, theta=34.038724 -> V=1.0, theta=0.0
% INFO    : Bus 12774	: V=0.98453, theta=-5.62162 -> V=1.0, theta=0.0
% INFO    : Bus 12775	: V=0.968879, theta=49.23979 -> V=1.0, theta=0.0
% INFO    : Bus 12776	: V=0.973294, theta=0.169843 -> V=1.0, theta=0.0
% INFO    : Bus 12777	: V=1.010323, theta=-7.916943 -> V=1.0, theta=0.0
% INFO    : Bus 12778	: V=1.038504, theta=-13.052855 -> V=1.0, theta=0.0
% INFO    : Bus 12779	: V=1.038504, theta=-13.052855 -> V=1.0, theta=0.0
% INFO    : Bus 12780	: V=1.038504, theta=-13.052855 -> V=1.0, theta=0.0
% INFO    : Bus 12781	: V=1.038504, theta=-13.052855 -> V=1.0, theta=0.0
% INFO    : Bus 12782	: V=1.033617, theta=-8.646596 -> V=1.0, theta=0.0
% INFO    : Bus 12783	: V=1.005883, theta=16.469663 -> V=1.0, theta=0.0
% INFO    : Bus 12784	: V=1.048201, theta=32.736039 -> V=1.0, theta=0.0
% INFO    : Bus 12785	: V=1.043675, theta=20.973559 -> V=1.0, theta=0.0
% INFO    : Bus 12786	: V=1.03036, theta=-6.512869 -> V=1.0, theta=0.0
% INFO    : Bus 12787	: V=1.040854, theta=1.201737 -> V=1.0, theta=0.0
% INFO    : Bus 12788	: V=1.045385, theta=33.348896 -> V=1.0, theta=0.0
% INFO    : Bus 12789	: V=1.045385, theta=33.348896 -> V=1.0, theta=0.0
% INFO    : Bus 12790	: V=1.045385, theta=33.348896 -> V=1.0, theta=0.0
% INFO    : Bus 12791	: V=1.045385, theta=33.348896 -> V=1.0, theta=0.0
% INFO    : Bus 12792	: V=0.95061, theta=-5.613582 -> V=1.0, theta=0.0
% INFO    : Bus 12793	: V=1.091249, theta=-4.873838 -> V=1.0, theta=0.0
% INFO    : Bus 12794	: V=1.041485, theta=26.637585 -> V=1.0, theta=0.0
% INFO    : Bus 12795	: V=1.020907, theta=12.759721 -> V=1.0, theta=0.0
% INFO    : Bus 12796	: V=1.016079, theta=-14.335683 -> V=1.0, theta=0.0
% INFO    : Bus 12797	: V=1.001956, theta=10.351303 -> V=1.0, theta=0.0
% INFO    : Bus 12798	: V=1.036256, theta=30.880029 -> V=1.0, theta=0.0
% INFO    : Bus 12799	: V=1.028648, theta=-14.669346 -> V=1.0, theta=0.0
% INFO    : Bus 12800	: V=1.027731, theta=13.470944 -> V=1.0, theta=0.0
% INFO    : Bus 12801	: V=1.013388, theta=13.908401 -> V=1.0, theta=0.0
% INFO    : Bus 12802	: V=1.027025, theta=78.256658 -> V=1.0, theta=0.0
% INFO    : Bus 12803	: V=1.056333, theta=76.025167 -> V=1.0, theta=0.0
% INFO    : Bus 12804	: V=1.035658, theta=-8.418453 -> V=1.0, theta=0.0
% INFO    : Bus 12805	: V=1.035412, theta=27.217512 -> V=1.0, theta=0.0
% INFO    : Bus 12806	: V=1.053741, theta=76.235894 -> V=1.0, theta=0.0
% INFO    : Bus 12807	: V=1.053741, theta=76.235894 -> V=1.0, theta=0.0
% INFO    : Bus 12808	: V=1.053741, theta=76.235894 -> V=1.0, theta=0.0
% INFO    : Bus 12809	: V=0.975659, theta=17.56195 -> V=1.0, theta=0.0
% INFO    : Bus 12810	: V=1.017062, theta=-22.849854 -> V=1.0, theta=0.0
% INFO    : Bus 12811	: V=1.026645, theta=1.873835 -> V=1.0, theta=0.0
% INFO    : Bus 12812	: V=1.040039, theta=-14.484778 -> V=1.0, theta=0.0
% INFO    : Bus 12813	: V=1.003585, theta=-15.239367 -> V=1.0, theta=0.0
% INFO    : Bus 12814	: V=1.051326, theta=28.77397 -> V=1.0, theta=0.0
% INFO    : Bus 12815	: V=1.046995, theta=7.343111 -> V=1.0, theta=0.0
% INFO    : Bus 12816	: V=1.003342, theta=23.89027 -> V=1.0, theta=0.0
% INFO    : Bus 12817	: V=1.062539, theta=23.499848 -> V=1.0, theta=0.0
% INFO    : Bus 12818	: V=1.062539, theta=23.499848 -> V=1.0, theta=0.0
% INFO    : Bus 12819	: V=1.022889, theta=18.879559 -> V=1.0, theta=0.0
% INFO    : Bus 12820	: V=1.030274, theta=-20.752051 -> V=1.0, theta=0.0
% INFO    : Bus 12821	: V=1.098911, theta=64.999347 -> V=1.0, theta=0.0
% INFO    : Bus 12822	: V=1.045359, theta=10.101302 -> V=1.0, theta=0.0
% INFO    : Bus 12823	: V=1.01789, theta=21.771841 -> V=1.0, theta=0.0
% INFO    : Bus 12824	: V=1.031793, theta=-18.98361 -> V=1.0, theta=0.0
% INFO    : Bus 12825	: V=1.055315, theta=14.241147 -> V=1.0, theta=0.0
% INFO    : Bus 12826	: V=0.953427, theta=-6.513376 -> V=1.0, theta=0.0
% INFO    : Bus 12827	: V=0.971607, theta=2.277859 -> V=1.0, theta=0.0
% INFO    : Bus 12828	: V=0.981384, theta=-14.232345 -> V=1.0, theta=0.0
% INFO    : Bus 12829	: V=0.935194, theta=31.202294 -> V=1.0, theta=0.0
% INFO    : Bus 12830	: V=1.063125, theta=3.494752 -> V=1.0, theta=0.0
% INFO    : Bus 12831	: V=1.018065, theta=44.19048 -> V=1.0, theta=0.0
% INFO    : Bus 12832	: V=1.091105, theta=1.871396 -> V=1.0, theta=0.0
% INFO    : Bus 12833	: V=1.073133, theta=28.039751 -> V=1.0, theta=0.0
% INFO    : Bus 12834	: V=1.014279, theta=-23.738766 -> V=1.0, theta=0.0
% INFO    : Bus 12835	: V=1.021754, theta=8.163576 -> V=1.0, theta=0.0
% INFO    : Bus 12836	: V=0.988099, theta=-12.498604 -> V=1.0, theta=0.0
% INFO    : Bus 12837	: V=1.046789, theta=3.602815 -> V=1.0, theta=0.0
% INFO    : Bus 12838	: V=1.020484, theta=4.216846 -> V=1.0, theta=0.0
% INFO    : Bus 12839	: V=0.989721, theta=7.405739 -> V=1.0, theta=0.0
% INFO    : Bus 12840	: V=1.052369, theta=0.152148 -> V=1.0, theta=0.0
% INFO    : Bus 12841	: V=1.017459, theta=18.918066 -> V=1.0, theta=0.0
% INFO    : Bus 12842	: V=0.993879, theta=-6.791088 -> V=1.0, theta=0.0
% INFO    : Bus 12843	: V=1.052369, theta=0.152148 -> V=1.0, theta=0.0
% INFO    : Bus 12844	: V=0.964216, theta=32.646923 -> V=1.0, theta=0.0
% INFO    : Bus 12845	: V=0.967312, theta=16.29545 -> V=1.0, theta=0.0
% INFO    : Bus 12846	: V=0.965204, theta=-27.491586 -> V=1.0, theta=0.0
% INFO    : Bus 12847	: V=1.023718, theta=-17.827354 -> V=1.0, theta=0.0
% INFO    : Bus 12848	: V=0.997919, theta=15.815205 -> V=1.0, theta=0.0
% INFO    : Bus 12849	: V=1.028575, theta=5.914981 -> V=1.0, theta=0.0
% INFO    : Bus 12850	: V=1.004372, theta=14.523885 -> V=1.0, theta=0.0
% INFO    : Bus 12851	: V=1.017441, theta=-2.682822 -> V=1.0, theta=0.0
% INFO    : Bus 12852	: V=0.989531, theta=22.273953 -> V=1.0, theta=0.0
% INFO    : Bus 12853	: V=1.034362, theta=-10.828436 -> V=1.0, theta=0.0
% INFO    : Bus 12854	: V=1.016881, theta=46.122544 -> V=1.0, theta=0.0
% INFO    : Bus 12855	: V=1.057579, theta=34.734619 -> V=1.0, theta=0.0
% INFO    : Bus 12856	: V=1.052369, theta=0.152148 -> V=1.0, theta=0.0
% INFO    : Bus 12857	: V=1.031795, theta=9.603746 -> V=1.0, theta=0.0
% INFO    : Bus 12858	: V=1.003512, theta=-19.342822 -> V=1.0, theta=0.0
% INFO    : Bus 12859	: V=1.055881, theta=11.701666 -> V=1.0, theta=0.0
% INFO    : Bus 12860	: V=1.093729, theta=21.721068 -> V=1.0, theta=0.0
% INFO    : Bus 12861	: V=1.03889, theta=12.478006 -> V=1.0, theta=0.0
% INFO    : Bus 12862	: V=1.022406, theta=14.490154 -> V=1.0, theta=0.0
% INFO    : Bus 12863	: V=1.017634, theta=-12.373197 -> V=1.0, theta=0.0
% INFO    : Bus 12864	: V=0.999314, theta=-14.571261 -> V=1.0, theta=0.0
% INFO    : Bus 12865	: V=1.029957, theta=9.250663 -> V=1.0, theta=0.0
% INFO    : Bus 12866	: V=1.070357, theta=88.048615 -> V=1.0, theta=0.0
% INFO    : Bus 12867	: V=1.021041, theta=-10.966008 -> V=1.0, theta=0.0
% INFO    : Bus 12868	: V=1.013846, theta=22.363012 -> V=1.0, theta=0.0
% INFO    : Bus 12869	: V=1.028204, theta=5.666749 -> V=1.0, theta=0.0
% INFO    : Bus 12870	: V=1.060308, theta=15.402866 -> V=1.0, theta=0.0
% INFO    : Bus 12871	: V=1.00034, theta=8.32903 -> V=1.0, theta=0.0
% INFO    : Bus 12872	: V=0.98683, theta=33.936217 -> V=1.0, theta=0.0
% INFO    : Bus 12873	: V=1.014795, theta=23.808394 -> V=1.0, theta=0.0
% INFO    : Bus 12874	: V=1.042461, theta=6.951342 -> V=1.0, theta=0.0
% INFO    : Bus 12875	: V=1.011483, theta=33.497968 -> V=1.0, theta=0.0
% INFO    : Bus 12876	: V=1.025536, theta=-11.129474 -> V=1.0, theta=0.0
% INFO    : Bus 12877	: V=1.005955, theta=-16.299988 -> V=1.0, theta=0.0
% INFO    : Bus 12878	: V=1.060659, theta=20.876838 -> V=1.0, theta=0.0
% INFO    : Bus 12879	: V=1.00235, theta=0.684638 -> V=1.0, theta=0.0
% INFO    : Bus 12880	: V=1.065482, theta=13.792426 -> V=1.0, theta=0.0
% INFO    : Bus 12881	: V=1.018533, theta=-11.038857 -> V=1.0, theta=0.0
% INFO    : Bus 12882	: V=1.065482, theta=13.792426 -> V=1.0, theta=0.0
% INFO    : Bus 12883	: V=1.065482, theta=13.792426 -> V=1.0, theta=0.0
% INFO    : Bus 12884	: V=1.065482, theta=13.792426 -> V=1.0, theta=0.0
% INFO    : Bus 12885	: V=0.982559, theta=0.477885 -> V=1.0, theta=0.0
% INFO    : Bus 12886	: V=0.993337, theta=-4.053104 -> V=1.0, theta=0.0
% INFO    : Bus 12887	: V=1.019063, theta=-9.896101 -> V=1.0, theta=0.0
% INFO    : Bus 12888	: V=1.019803, theta=31.688356 -> V=1.0, theta=0.0
% INFO    : Bus 12889	: V=1.024414, theta=-19.55614 -> V=1.0, theta=0.0
% INFO    : Bus 12890	: V=1.010994, theta=-1.162395 -> V=1.0, theta=0.0
% INFO    : Bus 12891	: V=1.014972, theta=-1.093742 -> V=1.0, theta=0.0
% INFO    : Bus 12892	: V=1.025891, theta=-20.35324 -> V=1.0, theta=0.0
% INFO    : Bus 12893	: V=1.029487, theta=19.232681 -> V=1.0, theta=0.0
% INFO    : Bus 12894	: V=1.050831, theta=28.477811 -> V=1.0, theta=0.0
% INFO    : Bus 12895	: V=0.944702, theta=-10.819415 -> V=1.0, theta=0.0
% INFO    : Bus 12896	: V=0.995077, theta=34.268512 -> V=1.0, theta=0.0
% INFO    : Bus 12897	: V=0.980806, theta=17.58249 -> V=1.0, theta=0.0
% INFO    : Bus 12898	: V=1.043059, theta=-1.392239 -> V=1.0, theta=0.0
% INFO    : Bus 12899	: V=1.050082, theta=4.029033 -> V=1.0, theta=0.0
% INFO    : Bus 12900	: V=1.007268, theta=1.91796 -> V=1.0, theta=0.0
% INFO    : Bus 12901	: V=1.031096, theta=27.214607 -> V=1.0, theta=0.0
% INFO    : Bus 12902	: V=1.030509, theta=2.528611 -> V=1.0, theta=0.0
% INFO    : Bus 12903	: V=1.010415, theta=-0.925141 -> V=1.0, theta=0.0
% INFO    : Bus 12904	: V=1.019094, theta=-5.889827 -> V=1.0, theta=0.0
% INFO    : Bus 12905	: V=1.008763, theta=-9.147175 -> V=1.0, theta=0.0
% INFO    : Bus 12906	: V=1.020161, theta=16.222206 -> V=1.0, theta=0.0
% INFO    : Bus 12907	: V=1.020161, theta=16.222206 -> V=1.0, theta=0.0
% INFO    : Bus 12908	: V=1.020161, theta=16.222206 -> V=1.0, theta=0.0
% INFO    : Bus 12909	: V=0.964867, theta=-6.136956 -> V=1.0, theta=0.0
% INFO    : Bus 12910	: V=1.020161, theta=16.222206 -> V=1.0, theta=0.0
% INFO    : Bus 12911	: V=1.045359, theta=10.101302 -> V=1.0, theta=0.0
% INFO    : Bus 12912	: V=1.020161, theta=16.222206 -> V=1.0, theta=0.0
% INFO    : Bus 12913	: V=1.022559, theta=4.844849 -> V=1.0, theta=0.0
% INFO    : Bus 12914	: V=1.021452, theta=28.019771 -> V=1.0, theta=0.0
% INFO    : Bus 12915	: V=1.033735, theta=-14.68008 -> V=1.0, theta=0.0
% INFO    : Bus 12916	: V=1.020161, theta=16.222206 -> V=1.0, theta=0.0
% INFO    : Bus 12917	: V=1.020161, theta=16.222206 -> V=1.0, theta=0.0
% INFO    : Bus 12918	: V=1.024162, theta=34.668761 -> V=1.0, theta=0.0
% INFO    : Bus 12919	: V=1.007061, theta=3.290321 -> V=1.0, theta=0.0
% INFO    : Bus 12920	: V=1.038461, theta=24.211106 -> V=1.0, theta=0.0
% INFO    : Bus 12921	: V=1.038461, theta=24.211106 -> V=1.0, theta=0.0
% INFO    : Bus 12922	: V=1.025069, theta=-10.520076 -> V=1.0, theta=0.0
% INFO    : Bus 12923	: V=1.011292, theta=-10.569275 -> V=1.0, theta=0.0
% INFO    : Bus 12924	: V=1.049763, theta=-5.507334 -> V=1.0, theta=0.0
% INFO    : Bus 12925	: V=1.038461, theta=24.211153 -> V=1.0, theta=0.0
% INFO    : Bus 12926	: V=1.033586, theta=9.148129 -> V=1.0, theta=0.0
% INFO    : Bus 12927	: V=0.998271, theta=35.539323 -> V=1.0, theta=0.0
% INFO    : Bus 12928	: V=0.992257, theta=-3.145402 -> V=1.0, theta=0.0
% INFO    : Bus 12929	: V=1.037296, theta=-1.6783 -> V=1.0, theta=0.0
% INFO    : Bus 12930	: V=1.041198, theta=4.140848 -> V=1.0, theta=0.0
% INFO    : Bus 12931	: V=0.969086, theta=-9.139692 -> V=1.0, theta=0.0
% INFO    : Bus 12932	: V=0.997706, theta=-9.08371 -> V=1.0, theta=0.0
% INFO    : Bus 12933	: V=1.059268, theta=-3.944719 -> V=1.0, theta=0.0
% INFO    : Bus 12934	: V=1.035207, theta=-6.870994 -> V=1.0, theta=0.0
% INFO    : Bus 12935	: V=1.009492, theta=30.233366 -> V=1.0, theta=0.0
% INFO    : Bus 12936	: V=0.974052, theta=-15.620125 -> V=1.0, theta=0.0
% INFO    : Bus 12937	: V=1.038461, theta=24.211153 -> V=1.0, theta=0.0
% INFO    : Bus 12938	: V=1.027116, theta=-8.230896 -> V=1.0, theta=0.0
% INFO    : Bus 12939	: V=1.038957, theta=23.917076 -> V=1.0, theta=0.0
% INFO    : Bus 12940	: V=1.013165, theta=-25.196592 -> V=1.0, theta=0.0
% INFO    : Bus 12941	: V=0.971452, theta=-14.646159 -> V=1.0, theta=0.0
% INFO    : Bus 12942	: V=1.016071, theta=-5.447511 -> V=1.0, theta=0.0
% INFO    : Bus 12943	: V=0.964592, theta=-4.465921 -> V=1.0, theta=0.0
% INFO    : Bus 12944	: V=1.050586, theta=-3.068048 -> V=1.0, theta=0.0
% INFO    : Bus 12945	: V=1.021335, theta=-22.198903 -> V=1.0, theta=0.0
% INFO    : Bus 12946	: V=0.998951, theta=38.095582 -> V=1.0, theta=0.0
% INFO    : Bus 12947	: V=0.99781, theta=-5.781696 -> V=1.0, theta=0.0
% INFO    : Bus 12948	: V=1.017569, theta=-13.372717 -> V=1.0, theta=0.0
% INFO    : Bus 12949	: V=1.002664, theta=30.778713 -> V=1.0, theta=0.0
% INFO    : Bus 12950	: V=0.994612, theta=-8.532772 -> V=1.0, theta=0.0
% INFO    : Bus 12951	: V=1.022459, theta=64.220655 -> V=1.0, theta=0.0
% INFO    : Bus 12952	: V=1.002492, theta=-3.462358 -> V=1.0, theta=0.0
% INFO    : Bus 12953	: V=0.926522, theta=-7.872363 -> V=1.0, theta=0.0
% INFO    : Bus 12954	: V=1.019249, theta=-32.394295 -> V=1.0, theta=0.0
% INFO    : Bus 12955	: V=0.997165, theta=-9.074411 -> V=1.0, theta=0.0
% INFO    : Bus 12956	: V=1.053349, theta=-2.98314 -> V=1.0, theta=0.0
% INFO    : Bus 12957	: V=1.00654, theta=29.808981 -> V=1.0, theta=0.0
% INFO    : Bus 12958	: V=0.998386, theta=26.560735 -> V=1.0, theta=0.0
% INFO    : Bus 12959	: V=1.059079, theta=9.801529 -> V=1.0, theta=0.0
% INFO    : Bus 12960	: V=0.988154, theta=-1.80095 -> V=1.0, theta=0.0
% INFO    : Bus 12961	: V=1.033542, theta=73.267064 -> V=1.0, theta=0.0
% INFO    : Bus 12962	: V=1.129641, theta=7.22366 -> V=1.0, theta=0.0
% INFO    : Bus 12963	: V=1.027061, theta=22.856557 -> V=1.0, theta=0.0
% INFO    : Bus 12964	: V=1.020343, theta=-11.016395 -> V=1.0, theta=0.0
% INFO    : Bus 12965	: V=1.043227, theta=47.072253 -> V=1.0, theta=0.0
% INFO    : Bus 12966	: V=0.977562, theta=26.05322 -> V=1.0, theta=0.0
% INFO    : Bus 12967	: V=1.008283, theta=18.258946 -> V=1.0, theta=0.0
% INFO    : Bus 12968	: V=1.053159, theta=33.930358 -> V=1.0, theta=0.0
% INFO    : Bus 12969	: V=1.053581, theta=52.246384 -> V=1.0, theta=0.0
% INFO    : Bus 12970	: V=1.053581, theta=52.246384 -> V=1.0, theta=0.0
% INFO    : Bus 12971	: V=1.014823, theta=-3.066083 -> V=1.0, theta=0.0
% INFO    : Bus 12972	: V=1.053823, theta=0.430007 -> V=1.0, theta=0.0
% INFO    : Bus 12973	: V=1.024018, theta=19.935265 -> V=1.0, theta=0.0
% INFO    : Bus 12974	: V=1.025296, theta=-0.17102 -> V=1.0, theta=0.0
% INFO    : Bus 12975	: V=0.970638, theta=21.202444 -> V=1.0, theta=0.0
% INFO    : Bus 12976	: V=1.002278, theta=-10.054248 -> V=1.0, theta=0.0
% INFO    : Bus 12977	: V=1.010415, theta=38.669 -> V=1.0, theta=0.0
% INFO    : Bus 12978	: V=0.992128, theta=10.128688 -> V=1.0, theta=0.0
% INFO    : Bus 12979	: V=1.009289, theta=-3.506967 -> V=1.0, theta=0.0
% INFO    : Bus 12980	: V=1.004575, theta=30.879385 -> V=1.0, theta=0.0
% INFO    : Bus 12981	: V=0.991872, theta=-1.713117 -> V=1.0, theta=0.0
% INFO    : Bus 12982	: V=0.985512, theta=-3.634382 -> V=1.0, theta=0.0
% INFO    : Bus 12983	: V=0.989744, theta=5.658378 -> V=1.0, theta=0.0
% INFO    : Bus 12984	: V=1.046953, theta=2.429703 -> V=1.0, theta=0.0
% INFO    : Bus 12985	: V=0.992255, theta=-19.517601 -> V=1.0, theta=0.0
% INFO    : Bus 12986	: V=1.046953, theta=2.429703 -> V=1.0, theta=0.0
% INFO    : Bus 12987	: V=1.045673, theta=42.716267 -> V=1.0, theta=0.0
% INFO    : Bus 12988	: V=0.992757, theta=3.56089 -> V=1.0, theta=0.0
% INFO    : Bus 12989	: V=1.021989, theta=24.453866 -> V=1.0, theta=0.0
% INFO    : Bus 12990	: V=0.987219, theta=-14.841108 -> V=1.0, theta=0.0
% INFO    : Bus 12991	: V=1.046517, theta=-0.884756 -> V=1.0, theta=0.0
% INFO    : Bus 12992	: V=0.962534, theta=-6.995462 -> V=1.0, theta=0.0
% INFO    : Bus 12993	: V=1.036433, theta=-0.581009 -> V=1.0, theta=0.0
% INFO    : Bus 12994	: V=1.036433, theta=-0.581009 -> V=1.0, theta=0.0
% INFO    : Bus 12995	: V=1.05204, theta=28.126902 -> V=1.0, theta=0.0
% INFO    : Bus 12996	: V=0.968256, theta=9.335661 -> V=1.0, theta=0.0
% INFO    : Bus 12997	: V=1.049159, theta=13.512116 -> V=1.0, theta=0.0
% INFO    : Bus 12998	: V=0.990019, theta=19.974179 -> V=1.0, theta=0.0
% INFO    : Bus 12999	: V=0.976439, theta=-19.028349 -> V=1.0, theta=0.0
% INFO    : Bus 13000	: V=1.032761, theta=8.736741 -> V=1.0, theta=0.0
% INFO    : Bus 13001	: V=1.041792, theta=7.031154 -> V=1.0, theta=0.0
% INFO    : Bus 13002	: V=0.960023, theta=9.298617 -> V=1.0, theta=0.0
% INFO    : Bus 13003	: V=1.028106, theta=19.439072 -> V=1.0, theta=0.0
% INFO    : Bus 13004	: V=0.993886, theta=57.027969 -> V=1.0, theta=0.0
% INFO    : Bus 13005	: V=0.996732, theta=2.354009 -> V=1.0, theta=0.0
% INFO    : Bus 13006	: V=1.016378, theta=6.321351 -> V=1.0, theta=0.0
% INFO    : Bus 13007	: V=1.041919, theta=21.315953 -> V=1.0, theta=0.0
% INFO    : Bus 13008	: V=1.041919, theta=21.315953 -> V=1.0, theta=0.0
% INFO    : Bus 13009	: V=1.041919, theta=21.315953 -> V=1.0, theta=0.0
% INFO    : Bus 13010	: V=1.090507, theta=11.169589 -> V=1.0, theta=0.0
% INFO    : Bus 13011	: V=1.042906, theta=29.386549 -> V=1.0, theta=0.0
% INFO    : Bus 13012	: V=1.033471, theta=35.764202 -> V=1.0, theta=0.0
% INFO    : Bus 13013	: V=0.996231, theta=-13.15907 -> V=1.0, theta=0.0
% INFO    : Bus 13014	: V=0.984345, theta=-2.661671 -> V=1.0, theta=0.0
% INFO    : Bus 13015	: V=0.986078, theta=-4.509414 -> V=1.0, theta=0.0
% INFO    : Bus 13016	: V=1.021103, theta=22.611795 -> V=1.0, theta=0.0
% INFO    : Bus 13017	: V=1.04338, theta=41.777724 -> V=1.0, theta=0.0
% INFO    : Bus 13018	: V=1.008126, theta=-14.668138 -> V=1.0, theta=0.0
% INFO    : Bus 13019	: V=1.046382, theta=6.543925 -> V=1.0, theta=0.0
% INFO    : Bus 13020	: V=1.050334, theta=93.202502 -> V=1.0, theta=0.0
% INFO    : Bus 13021	: V=1.048113, theta=-0.97616 -> V=1.0, theta=0.0
% INFO    : Bus 13022	: V=1.03864, theta=21.497055 -> V=1.0, theta=0.0
% INFO    : Bus 13023	: V=0.987771, theta=-2.171556 -> V=1.0, theta=0.0
% INFO    : Bus 13024	: V=1.018329, theta=-16.147917 -> V=1.0, theta=0.0
% INFO    : Bus 13025	: V=1.023493, theta=8.422588 -> V=1.0, theta=0.0
% INFO    : Bus 13026	: V=1.007971, theta=-15.20422 -> V=1.0, theta=0.0
% INFO    : Bus 13027	: V=1.024979, theta=-15.140439 -> V=1.0, theta=0.0
% INFO    : Bus 13028	: V=1.050184, theta=25.602523 -> V=1.0, theta=0.0
% INFO    : Bus 13029	: V=1.0018, theta=-10.471434 -> V=1.0, theta=0.0
% INFO    : Bus 13030	: V=1.007971, theta=-15.20422 -> V=1.0, theta=0.0
% INFO    : Bus 13031	: V=1.065203, theta=3.392771 -> V=1.0, theta=0.0
% INFO    : Bus 13032	: V=1.011811, theta=-11.502098 -> V=1.0, theta=0.0
% INFO    : Bus 13033	: V=0.988838, theta=9.016669 -> V=1.0, theta=0.0
% INFO    : Bus 13034	: V=1.026116, theta=-2.752551 -> V=1.0, theta=0.0
% INFO    : Bus 13035	: V=1.037066, theta=30.465618 -> V=1.0, theta=0.0
% INFO    : Bus 13036	: V=1.068833, theta=-3.112735 -> V=1.0, theta=0.0
% INFO    : Bus 13037	: V=1.067719, theta=1.976449 -> V=1.0, theta=0.0
% INFO    : Bus 13038	: V=0.957912, theta=-9.968502 -> V=1.0, theta=0.0
% INFO    : Bus 13039	: V=1.010465, theta=27.854841 -> V=1.0, theta=0.0
% INFO    : Bus 13040	: V=0.966671, theta=-6.553134 -> V=1.0, theta=0.0
% INFO    : Bus 13041	: V=1.040642, theta=8.532255 -> V=1.0, theta=0.0
% INFO    : Bus 13042	: V=1.015517, theta=32.752016 -> V=1.0, theta=0.0
% INFO    : Bus 13043	: V=1.010028, theta=16.739138 -> V=1.0, theta=0.0
% INFO    : Bus 13044	: V=1.03659, theta=21.196154 -> V=1.0, theta=0.0
% INFO    : Bus 13045	: V=1.03216, theta=30.377663 -> V=1.0, theta=0.0
% INFO    : Bus 13046	: V=1.010028, theta=16.739138 -> V=1.0, theta=0.0
% INFO    : Bus 13047	: V=1.007128, theta=-2.88458 -> V=1.0, theta=0.0
% INFO    : Bus 13048	: V=1.007128, theta=-2.88458 -> V=1.0, theta=0.0
% INFO    : Bus 13049	: V=1.007128, theta=-2.88458 -> V=1.0, theta=0.0
% INFO    : Bus 13050	: V=1.01602, theta=34.837954 -> V=1.0, theta=0.0
% INFO    : Bus 13051	: V=1.060215, theta=0.364906 -> V=1.0, theta=0.0
% INFO    : Bus 13052	: V=1.007128, theta=-2.88458 -> V=1.0, theta=0.0
% INFO    : Bus 13053	: V=1.007128, theta=-2.88458 -> V=1.0, theta=0.0
% INFO    : Bus 13054	: V=1.007128, theta=-2.88458 -> V=1.0, theta=0.0
% INFO    : Bus 13055	: V=1.010028, theta=16.739138 -> V=1.0, theta=0.0
% INFO    : Bus 13056	: V=1.063704, theta=66.981987 -> V=1.0, theta=0.0
% INFO    : Bus 13057	: V=1.007679, theta=-4.961668 -> V=1.0, theta=0.0
% INFO    : Bus 13058	: V=1.007679, theta=-4.961668 -> V=1.0, theta=0.0
% INFO    : Bus 13059	: V=1.010028, theta=16.739138 -> V=1.0, theta=0.0
% INFO    : Bus 13060	: V=1.010028, theta=16.739138 -> V=1.0, theta=0.0
% INFO    : Bus 13061	: V=1.052488, theta=29.654092 -> V=1.0, theta=0.0
% INFO    : Bus 13062	: V=1.040259, theta=34.3106 -> V=1.0, theta=0.0
% INFO    : Bus 13063	: V=0.980954, theta=-7.906638 -> V=1.0, theta=0.0
% INFO    : Bus 13064	: V=1.010028, theta=16.739138 -> V=1.0, theta=0.0
% INFO    : Bus 13065	: V=1.005379, theta=17.277761 -> V=1.0, theta=0.0
% INFO    : Bus 13066	: V=1.040259, theta=34.3106 -> V=1.0, theta=0.0
% INFO    : Bus 13067	: V=1.0058, theta=30.296047 -> V=1.0, theta=0.0
% INFO    : Bus 13068	: V=1.036027, theta=-4.088525 -> V=1.0, theta=0.0
% INFO    : Bus 13069	: V=1.023818, theta=-10.471889 -> V=1.0, theta=0.0
% INFO    : Bus 13070	: V=1.001957, theta=29.002971 -> V=1.0, theta=0.0
% INFO    : Bus 13071	: V=1.025033, theta=7.696957 -> V=1.0, theta=0.0
% INFO    : Bus 13072	: V=1.058962, theta=-2.160344 -> V=1.0, theta=0.0
% INFO    : Bus 13073	: V=0.923946, theta=-8.905161 -> V=1.0, theta=0.0
% INFO    : Bus 13074	: V=1.020714, theta=26.358811 -> V=1.0, theta=0.0
% INFO    : Bus 13075	: V=1.021202, theta=7.512555 -> V=1.0, theta=0.0
% INFO    : Bus 13076	: V=1.003152, theta=-15.344503 -> V=1.0, theta=0.0
% INFO    : Bus 13077	: V=1.00346, theta=8.210209 -> V=1.0, theta=0.0
% INFO    : Bus 13078	: V=1.029571, theta=7.597342 -> V=1.0, theta=0.0
% INFO    : Bus 13079	: V=1.065314, theta=53.15385 -> V=1.0, theta=0.0
% INFO    : Bus 13080	: V=1.034597, theta=19.022639 -> V=1.0, theta=0.0
% INFO    : Bus 13081	: V=1.024595, theta=25.456155 -> V=1.0, theta=0.0
% INFO    : Bus 13082	: V=1.003807, theta=31.8753 -> V=1.0, theta=0.0
% INFO    : Bus 13083	: V=1.025108, theta=6.300939 -> V=1.0, theta=0.0
% INFO    : Bus 13084	: V=0.966992, theta=-14.766387 -> V=1.0, theta=0.0
% INFO    : Bus 13085	: V=1.013872, theta=19.392415 -> V=1.0, theta=0.0
% INFO    : Bus 13086	: V=0.991806, theta=18.024083 -> V=1.0, theta=0.0
% INFO    : Bus 13087	: V=0.975077, theta=24.924484 -> V=1.0, theta=0.0
% INFO    : Bus 13088	: V=0.983289, theta=-8.188197 -> V=1.0, theta=0.0
% INFO    : Bus 13089	: V=1.003783, theta=-4.176779 -> V=1.0, theta=0.0
% INFO    : Bus 13090	: V=0.970854, theta=29.381452 -> V=1.0, theta=0.0
% INFO    : Bus 13091	: V=1.022149, theta=-8.624199 -> V=1.0, theta=0.0
% INFO    : Bus 13092	: V=1.035406, theta=9.681664 -> V=1.0, theta=0.0
% INFO    : Bus 13093	: V=1.023603, theta=23.127902 -> V=1.0, theta=0.0
% INFO    : Bus 13094	: V=0.952203, theta=-7.669787 -> V=1.0, theta=0.0
% INFO    : Bus 13095	: V=1.034376, theta=-4.403708 -> V=1.0, theta=0.0
% INFO    : Bus 13096	: V=0.9595, theta=30.616672 -> V=1.0, theta=0.0
% INFO    : Bus 13097	: V=1.024594, theta=18.007302 -> V=1.0, theta=0.0
% INFO    : Bus 13098	: V=0.954239, theta=-5.131616 -> V=1.0, theta=0.0
% INFO    : Bus 13099	: V=1.063704, theta=66.981987 -> V=1.0, theta=0.0
% INFO    : Bus 13100	: V=0.995233, theta=38.646991 -> V=1.0, theta=0.0
% INFO    : Bus 13101	: V=1.034597, theta=19.022639 -> V=1.0, theta=0.0
% INFO    : Bus 13102	: V=0.966688, theta=-9.645178 -> V=1.0, theta=0.0
% INFO    : Bus 13103	: V=1.012712, theta=32.305565 -> V=1.0, theta=0.0
% INFO    : Bus 13104	: V=0.914844, theta=-11.630868 -> V=1.0, theta=0.0
% INFO    : Bus 13105	: V=1.040629, theta=-6.467869 -> V=1.0, theta=0.0
% INFO    : Bus 13106	: V=1.015439, theta=-7.646483 -> V=1.0, theta=0.0
% INFO    : Bus 13107	: V=1.018571, theta=4.743217 -> V=1.0, theta=0.0
% INFO    : Bus 13108	: V=1.034532, theta=19.101591 -> V=1.0, theta=0.0
% INFO    : Bus 13109	: V=1.026591, theta=0.238487 -> V=1.0, theta=0.0
% INFO    : Bus 13110	: V=1.024898, theta=-7.521787 -> V=1.0, theta=0.0
% INFO    : Bus 13111	: V=1.030429, theta=-16.387658 -> V=1.0, theta=0.0
% INFO    : Bus 13112	: V=0.994692, theta=24.255635 -> V=1.0, theta=0.0
% INFO    : Bus 13113	: V=0.978245, theta=-5.718324 -> V=1.0, theta=0.0
% INFO    : Bus 13114	: V=1.052152, theta=-6.603595 -> V=1.0, theta=0.0
% INFO    : Bus 13115	: V=1.017687, theta=-20.359003 -> V=1.0, theta=0.0
% INFO    : Bus 13116	: V=0.98896, theta=-8.641435 -> V=1.0, theta=0.0
% INFO    : Bus 13117	: V=1.021606, theta=-15.901143 -> V=1.0, theta=0.0
% INFO    : Bus 13118	: V=1.02049, theta=-0.396649 -> V=1.0, theta=0.0
% INFO    : Bus 13119	: V=1.108354, theta=0.984062 -> V=1.0, theta=0.0
% INFO    : Bus 13120	: V=0.977424, theta=-27.223914 -> V=1.0, theta=0.0
% INFO    : Bus 13121	: V=1.017519, theta=44.942025 -> V=1.0, theta=0.0
% INFO    : Bus 13122	: V=1.035838, theta=-5.172678 -> V=1.0, theta=0.0
% INFO    : Bus 13123	: V=1.034935, theta=24.924619 -> V=1.0, theta=0.0
% INFO    : Bus 13124	: V=1.063704, theta=66.981987 -> V=1.0, theta=0.0
% INFO    : Bus 13125	: V=0.989365, theta=-4.13673 -> V=1.0, theta=0.0
% INFO    : Bus 13126	: V=0.961079, theta=-6.675736 -> V=1.0, theta=0.0
% INFO    : Bus 13127	: V=1.069676, theta=18.143892 -> V=1.0, theta=0.0
% INFO    : Bus 13128	: V=1.02407, theta=-1.128997 -> V=1.0, theta=0.0
% INFO    : Bus 13129	: V=1.029526, theta=-21.179796 -> V=1.0, theta=0.0
% INFO    : Bus 13130	: V=1.019598, theta=6.987203 -> V=1.0, theta=0.0
% INFO    : Bus 13131	: V=1.015521, theta=7.836059 -> V=1.0, theta=0.0
% INFO    : Bus 13132	: V=1.028169, theta=-8.006973 -> V=1.0, theta=0.0
% INFO    : Bus 13133	: V=1.015531, theta=4.163384 -> V=1.0, theta=0.0
% INFO    : Bus 13134	: V=1.029418, theta=-21.61392 -> V=1.0, theta=0.0
% INFO    : Bus 13135	: V=1.019336, theta=-25.362726 -> V=1.0, theta=0.0
% INFO    : Bus 13136	: V=1.056468, theta=13.149601 -> V=1.0, theta=0.0
% INFO    : Bus 13137	: V=1.058231, theta=41.885187 -> V=1.0, theta=0.0
% INFO    : Bus 13138	: V=1.04054, theta=2.144138 -> V=1.0, theta=0.0
% INFO    : Bus 13139	: V=1.058848, theta=6.682119 -> V=1.0, theta=0.0
% INFO    : Bus 13140	: V=1.062954, theta=40.091654 -> V=1.0, theta=0.0
% INFO    : Bus 13141	: V=0.960402, theta=-0.350918 -> V=1.0, theta=0.0
% INFO    : Bus 13142	: V=1.035139, theta=9.656078 -> V=1.0, theta=0.0
% INFO    : Bus 13143	: V=1.016606, theta=10.005767 -> V=1.0, theta=0.0
% INFO    : Bus 13144	: V=1.020976, theta=7.632703 -> V=1.0, theta=0.0
% INFO    : Bus 13145	: V=1.029219, theta=47.514576 -> V=1.0, theta=0.0
% INFO    : Bus 13146	: V=1.036832, theta=1.60787 -> V=1.0, theta=0.0
% INFO    : Bus 13147	: V=1.034688, theta=8.184132 -> V=1.0, theta=0.0
% INFO    : Bus 13148	: V=1.02447, theta=39.046287 -> V=1.0, theta=0.0
% INFO    : Bus 13149	: V=1.053388, theta=-5.242446 -> V=1.0, theta=0.0
% INFO    : Bus 13150	: V=0.924064, theta=-8.114251 -> V=1.0, theta=0.0
% INFO    : Bus 13151	: V=1.08983, theta=7.912429 -> V=1.0, theta=0.0
% INFO    : Bus 13152	: V=0.983713, theta=25.689119 -> V=1.0, theta=0.0
% INFO    : Bus 13153	: V=1.038118, theta=-21.317066 -> V=1.0, theta=0.0
% INFO    : Bus 13154	: V=0.991214, theta=-14.218835 -> V=1.0, theta=0.0
% INFO    : Bus 13155	: V=1.002707, theta=2.493238 -> V=1.0, theta=0.0
% INFO    : Bus 13156	: V=0.975452, theta=-4.937173 -> V=1.0, theta=0.0
% INFO    : Bus 13157	: V=1.041751, theta=1.738367 -> V=1.0, theta=0.0
% INFO    : Bus 13158	: V=1.036955, theta=14.906904 -> V=1.0, theta=0.0
% INFO    : Bus 13159	: V=0.974729, theta=26.313842 -> V=1.0, theta=0.0
% INFO    : Bus 13160	: V=1.015029, theta=3.043049 -> V=1.0, theta=0.0
% INFO    : Bus 13161	: V=1.01713, theta=-4.112133 -> V=1.0, theta=0.0
% INFO    : Bus 13162	: V=1.017956, theta=13.697984 -> V=1.0, theta=0.0
% INFO    : Bus 13163	: V=1.026957, theta=18.072383 -> V=1.0, theta=0.0
% INFO    : Bus 13164	: V=1.068363, theta=-3.573969 -> V=1.0, theta=0.0
% INFO    : Bus 13165	: V=1.031159, theta=7.793526 -> V=1.0, theta=0.0
% INFO    : Bus 13166	: V=1.018573, theta=25.306793 -> V=1.0, theta=0.0
% INFO    : Bus 13167	: V=1.032754, theta=9.236724 -> V=1.0, theta=0.0
% INFO    : Bus 13168	: V=1.015159, theta=31.900987 -> V=1.0, theta=0.0
% INFO    : Bus 13169	: V=1.044224, theta=13.79089 -> V=1.0, theta=0.0
% INFO    : Bus 13170	: V=1.050488, theta=44.077076 -> V=1.0, theta=0.0
% INFO    : Bus 13171	: V=1.043123, theta=11.567567 -> V=1.0, theta=0.0
% INFO    : Bus 13172	: V=1.024989, theta=6.612752 -> V=1.0, theta=0.0
% INFO    : Bus 13173	: V=1.013455, theta=-8.739663 -> V=1.0, theta=0.0
% INFO    : Bus 13174	: V=1.043087, theta=11.638661 -> V=1.0, theta=0.0
% INFO    : Bus 13175	: V=1.010986, theta=27.852289 -> V=1.0, theta=0.0
% INFO    : Bus 13176	: V=0.99653, theta=-9.692613 -> V=1.0, theta=0.0
% INFO    : Bus 13177	: V=0.975181, theta=15.869625 -> V=1.0, theta=0.0
% INFO    : Bus 13178	: V=1.000925, theta=34.567738 -> V=1.0, theta=0.0
% INFO    : Bus 13179	: V=1.025843, theta=35.252312 -> V=1.0, theta=0.0
% INFO    : Bus 13180	: V=1.024306, theta=14.515875 -> V=1.0, theta=0.0
% INFO    : Bus 13181	: V=1.028706, theta=7.443704 -> V=1.0, theta=0.0
% INFO    : Bus 13182	: V=0.975956, theta=41.478844 -> V=1.0, theta=0.0
% INFO    : Bus 13183	: V=1.066454, theta=-4.703726 -> V=1.0, theta=0.0
% INFO    : Bus 13184	: V=1.006143, theta=20.873808 -> V=1.0, theta=0.0
% INFO    : Bus 13185	: V=1.025093, theta=13.584701 -> V=1.0, theta=0.0
% INFO    : Bus 13186	: V=1.004296, theta=17.471585 -> V=1.0, theta=0.0
% INFO    : Bus 13187	: V=1.026643, theta=-1.232792 -> V=1.0, theta=0.0
% INFO    : Bus 13188	: V=1.051387, theta=32.912535 -> V=1.0, theta=0.0
% INFO    : Bus 13189	: V=1.051387, theta=32.912535 -> V=1.0, theta=0.0
% INFO    : Bus 13190	: V=1.051387, theta=32.912535 -> V=1.0, theta=0.0
% INFO    : Bus 13191	: V=1.020032, theta=8.963657 -> V=1.0, theta=0.0
% INFO    : Bus 13192	: V=1.038082, theta=40.430696 -> V=1.0, theta=0.0
% INFO    : Bus 13193	: V=1.003171, theta=37.39829 -> V=1.0, theta=0.0
% INFO    : Bus 13194	: V=1.018948, theta=-8.90721 -> V=1.0, theta=0.0
% INFO    : Bus 13195	: V=0.98379, theta=29.90696 -> V=1.0, theta=0.0
% INFO    : Bus 13196	: V=1.03765, theta=17.609515 -> V=1.0, theta=0.0
% INFO    : Bus 13197	: V=0.995164, theta=34.73145 -> V=1.0, theta=0.0
% INFO    : Bus 13198	: V=1.083585, theta=35.443136 -> V=1.0, theta=0.0
% INFO    : Bus 13199	: V=0.975439, theta=-10.224225 -> V=1.0, theta=0.0
% INFO    : Bus 13200	: V=0.99654, theta=26.163496 -> V=1.0, theta=0.0
% INFO    : Bus 13201	: V=1.010954, theta=89.347655 -> V=1.0, theta=0.0
% INFO    : Bus 13202	: V=0.995533, theta=-14.126603 -> V=1.0, theta=0.0
% INFO    : Bus 13203	: V=1.025445, theta=7.76184 -> V=1.0, theta=0.0
% INFO    : Bus 13204	: V=0.985641, theta=2.113381 -> V=1.0, theta=0.0
% INFO    : Bus 13205	: V=1.042369, theta=0.793884 -> V=1.0, theta=0.0
% INFO    : Bus 13206	: V=1.028784, theta=19.379012 -> V=1.0, theta=0.0
% INFO    : Bus 13207	: V=1.023166, theta=4.463602 -> V=1.0, theta=0.0
% INFO    : Bus 13208	: V=0.942791, theta=-9.095892 -> V=1.0, theta=0.0
% INFO    : Bus 13209	: V=1.029835, theta=-14.681025 -> V=1.0, theta=0.0
% INFO    : Bus 13210	: V=1.005238, theta=-7.194433 -> V=1.0, theta=0.0
% INFO    : Bus 13211	: V=1.025167, theta=2.023484 -> V=1.0, theta=0.0
% INFO    : Bus 13212	: V=1.00107, theta=32.866746 -> V=1.0, theta=0.0
% INFO    : Bus 13213	: V=1.071669, theta=23.992312 -> V=1.0, theta=0.0
% INFO    : Bus 13214	: V=1.018996, theta=14.242218 -> V=1.0, theta=0.0
% INFO    : Bus 13215	: V=1.0629, theta=21.173824 -> V=1.0, theta=0.0
% INFO    : Bus 13216	: V=1.018896, theta=-8.431592 -> V=1.0, theta=0.0
% INFO    : Bus 13217	: V=0.988894, theta=-26.08969 -> V=1.0, theta=0.0
% INFO    : Bus 13218	: V=1.008348, theta=30.337205 -> V=1.0, theta=0.0
% INFO    : Bus 13219	: V=1.040094, theta=-20.271382 -> V=1.0, theta=0.0
% INFO    : Bus 13220	: V=1.040914, theta=13.793 -> V=1.0, theta=0.0
% INFO    : Bus 13221	: V=1.066121, theta=2.762902 -> V=1.0, theta=0.0
% INFO    : Bus 13222	: V=0.943436, theta=50.691637 -> V=1.0, theta=0.0
% INFO    : Bus 13223	: V=1.021005, theta=21.987746 -> V=1.0, theta=0.0
% INFO    : Bus 13224	: V=1.024598, theta=-28.939594 -> V=1.0, theta=0.0
% INFO    : Bus 13225	: V=0.998123, theta=-23.060675 -> V=1.0, theta=0.0
% INFO    : Bus 13226	: V=1.00746, theta=39.171104 -> V=1.0, theta=0.0
% INFO    : Bus 13227	: V=1.013676, theta=-8.338005 -> V=1.0, theta=0.0
% INFO    : Bus 13228	: V=0.975711, theta=-8.687888 -> V=1.0, theta=0.0
% INFO    : Bus 13229	: V=0.979466, theta=-1.074571 -> V=1.0, theta=0.0
% INFO    : Bus 13230	: V=1.076036, theta=84.574972 -> V=1.0, theta=0.0
% INFO    : Bus 13231	: V=0.977566, theta=23.48751 -> V=1.0, theta=0.0
% INFO    : Bus 13232	: V=1.010998, theta=1.300317 -> V=1.0, theta=0.0
% INFO    : Bus 13233	: V=1.03133, theta=-13.963675 -> V=1.0, theta=0.0
% INFO    : Bus 13234	: V=1.030067, theta=19.445758 -> V=1.0, theta=0.0
% INFO    : Bus 13235	: V=1.058114, theta=43.382414 -> V=1.0, theta=0.0
% INFO    : Bus 13236	: V=0.996666, theta=-4.723793 -> V=1.0, theta=0.0
% INFO    : Bus 13237	: V=1.025943, theta=5.865231 -> V=1.0, theta=0.0
% INFO    : Bus 13238	: V=0.9646, theta=54.13357 -> V=1.0, theta=0.0
% INFO    : Bus 13239	: V=0.98836, theta=-4.6058 -> V=1.0, theta=0.0
% INFO    : Bus 13240	: V=1.007537, theta=-12.433936 -> V=1.0, theta=0.0
% INFO    : Bus 13241	: V=1.024332, theta=-4.383178 -> V=1.0, theta=0.0
% INFO    : Bus 13242	: V=1.014468, theta=46.591225 -> V=1.0, theta=0.0
% INFO    : Bus 13243	: V=0.982731, theta=29.96695 -> V=1.0, theta=0.0
% INFO    : Bus 13244	: V=1.066937, theta=48.44975 -> V=1.0, theta=0.0
% INFO    : Bus 13245	: V=0.977843, theta=-27.152454 -> V=1.0, theta=0.0
% INFO    : Bus 13246	: V=0.970166, theta=-9.580952 -> V=1.0, theta=0.0
% INFO    : Bus 13247	: V=1.046477, theta=-20.234317 -> V=1.0, theta=0.0
% INFO    : Bus 13248	: V=1.022708, theta=-7.370065 -> V=1.0, theta=0.0
% INFO    : Bus 13249	: V=1.022649, theta=44.459971 -> V=1.0, theta=0.0
% INFO    : Bus 13250	: V=1.00925, theta=13.329705 -> V=1.0, theta=0.0
% INFO    : Bus 13251	: V=0.992728, theta=-23.206002 -> V=1.0, theta=0.0
% INFO    : Bus 13252	: V=1.041896, theta=26.213331 -> V=1.0, theta=0.0
% INFO    : Bus 13253	: V=1.006717, theta=-12.883457 -> V=1.0, theta=0.0
% INFO    : Bus 13254	: V=1.023428, theta=21.664024 -> V=1.0, theta=0.0
% INFO    : Bus 13255	: V=1.03042, theta=-8.082898 -> V=1.0, theta=0.0
% INFO    : Bus 13256	: V=1.096387, theta=69.583402 -> V=1.0, theta=0.0
% INFO    : Bus 13257	: V=1.056069, theta=-2.371819 -> V=1.0, theta=0.0
% INFO    : Bus 13258	: V=0.96993, theta=17.803297 -> V=1.0, theta=0.0
% INFO    : Bus 13259	: V=1.019183, theta=16.868099 -> V=1.0, theta=0.0
% INFO    : Bus 13260	: V=0.991102, theta=-5.123003 -> V=1.0, theta=0.0
% INFO    : Bus 13261	: V=1.015642, theta=-21.99726 -> V=1.0, theta=0.0
% INFO    : Bus 13262	: V=1.011422, theta=-0.473281 -> V=1.0, theta=0.0
% INFO    : Bus 13263	: V=1.032574, theta=26.636821 -> V=1.0, theta=0.0
% INFO    : Bus 13264	: V=1.003373, theta=-19.517601 -> V=1.0, theta=0.0
% INFO    : Bus 13265	: V=1.000157, theta=-14.767921 -> V=1.0, theta=0.0
% INFO    : Bus 13266	: V=1.003373, theta=-19.517601 -> V=1.0, theta=0.0
% INFO    : Bus 13267	: V=1.014637, theta=-8.280321 -> V=1.0, theta=0.0
% INFO    : Bus 13268	: V=1.016188, theta=-15.391233 -> V=1.0, theta=0.0
% INFO    : Bus 13269	: V=1.019745, theta=-19.936916 -> V=1.0, theta=0.0
% INFO    : Bus 13270	: V=0.981334, theta=37.783033 -> V=1.0, theta=0.0
% INFO    : Bus 13271	: V=1.03295, theta=-8.426784 -> V=1.0, theta=0.0
% INFO    : Bus 13272	: V=1.052781, theta=-9.309841 -> V=1.0, theta=0.0
% INFO    : Bus 13273	: V=0.981474, theta=-5.943609 -> V=1.0, theta=0.0
% INFO    : Bus 13274	: V=1.034196, theta=12.040102 -> V=1.0, theta=0.0
% INFO    : Bus 13275	: V=0.987786, theta=25.477106 -> V=1.0, theta=0.0
% INFO    : Bus 13276	: V=1.032979, theta=13.492326 -> V=1.0, theta=0.0
% INFO    : Bus 13277	: V=0.980943, theta=-7.908747 -> V=1.0, theta=0.0
% INFO    : Bus 13278	: V=0.994083, theta=-17.375682 -> V=1.0, theta=0.0
% INFO    : Bus 13279	: V=1.016914, theta=-15.630869 -> V=1.0, theta=0.0
% INFO    : Bus 13280	: V=1.025593, theta=37.336465 -> V=1.0, theta=0.0
% INFO    : Bus 13281	: V=1.015635, theta=-1.587105 -> V=1.0, theta=0.0
% INFO    : Bus 13282	: V=1.02421, theta=52.49799 -> V=1.0, theta=0.0
% INFO    : Bus 13283	: V=0.961964, theta=-9.865409 -> V=1.0, theta=0.0
% INFO    : Bus 13284	: V=0.965766, theta=-9.555001 -> V=1.0, theta=0.0
% INFO    : Bus 13285	: V=1.019281, theta=-1.243469 -> V=1.0, theta=0.0
% INFO    : Bus 13286	: V=1.016314, theta=7.334762 -> V=1.0, theta=0.0
% INFO    : Bus 13287	: V=1.021338, theta=-13.991173 -> V=1.0, theta=0.0
% INFO    : Bus 13288	: V=1.027732, theta=2.440628 -> V=1.0, theta=0.0
% INFO    : Bus 13289	: V=1.031349, theta=4.288277 -> V=1.0, theta=0.0
% INFO    : Bus 13290	: V=1.025409, theta=-3.188199 -> V=1.0, theta=0.0
% INFO    : Bus 13291	: V=0.998718, theta=26.916364 -> V=1.0, theta=0.0
% INFO    : Bus 13292	: V=1.042317, theta=14.274354 -> V=1.0, theta=0.0
% INFO    : Bus 13293	: V=0.995043, theta=-3.754412 -> V=1.0, theta=0.0
% INFO    : Bus 13294	: V=1.051966, theta=25.688886 -> V=1.0, theta=0.0
% INFO    : Bus 13295	: V=1.009613, theta=-10.15781 -> V=1.0, theta=0.0
% INFO    : Bus 13296	: V=1.014222, theta=32.604509 -> V=1.0, theta=0.0
% INFO    : Bus 13297	: V=1.011334, theta=21.793145 -> V=1.0, theta=0.0
% INFO    : Bus 13298	: V=1.019411, theta=-14.420581 -> V=1.0, theta=0.0
% INFO    : Bus 13299	: V=0.997725, theta=19.123501 -> V=1.0, theta=0.0
% INFO    : Bus 13300	: V=0.984318, theta=15.137295 -> V=1.0, theta=0.0
% INFO    : Bus 13301	: V=0.961087, theta=-15.659318 -> V=1.0, theta=0.0
% INFO    : Bus 13302	: V=1.034077, theta=8.370153 -> V=1.0, theta=0.0
% INFO    : Bus 13303	: V=1.045359, theta=10.101302 -> V=1.0, theta=0.0
% INFO    : Bus 13304	: V=1.029838, theta=-11.418316 -> V=1.0, theta=0.0
% INFO    : Bus 13305	: V=1.010396, theta=89.157471 -> V=1.0, theta=0.0
% INFO    : Bus 13306	: V=1.054559, theta=75.762051 -> V=1.0, theta=0.0
% INFO    : Bus 13307	: V=1.033156, theta=-14.381315 -> V=1.0, theta=0.0
% INFO    : Bus 13308	: V=1.026587, theta=18.649448 -> V=1.0, theta=0.0
% INFO    : Bus 13309	: V=1.021082, theta=63.452163 -> V=1.0, theta=0.0
% INFO    : Bus 13310	: V=1.025649, theta=-20.066719 -> V=1.0, theta=0.0
% INFO    : Bus 13311	: V=1.055904, theta=-17.760173 -> V=1.0, theta=0.0
% INFO    : Bus 13312	: V=0.995346, theta=36.752154 -> V=1.0, theta=0.0
% INFO    : Bus 13313	: V=1.023809, theta=10.838684 -> V=1.0, theta=0.0
% INFO    : Bus 13314	: V=1.023188, theta=2.537974 -> V=1.0, theta=0.0
% INFO    : Bus 13315	: V=1.056296, theta=-0.708052 -> V=1.0, theta=0.0
% INFO    : Bus 13316	: V=1.034532, theta=19.101591 -> V=1.0, theta=0.0
% INFO    : Bus 13317	: V=0.993556, theta=25.389197 -> V=1.0, theta=0.0
% INFO    : Bus 13318	: V=1.032532, theta=-0.066659 -> V=1.0, theta=0.0
% INFO    : Bus 13319	: V=1.014647, theta=-12.087921 -> V=1.0, theta=0.0
% INFO    : Bus 13320	: V=1.010963, theta=-0.712232 -> V=1.0, theta=0.0
% INFO    : Bus 13321	: V=1.078833, theta=1.728689 -> V=1.0, theta=0.0
% INFO    : Bus 13322	: V=1.043049, theta=13.489159 -> V=1.0, theta=0.0
% INFO    : Bus 13323	: V=1.021346, theta=-22.881448 -> V=1.0, theta=0.0
% INFO    : Bus 13324	: V=1.023892, theta=8.254887 -> V=1.0, theta=0.0
% INFO    : Bus 13325	: V=1.021789, theta=-19.844351 -> V=1.0, theta=0.0
% INFO    : Bus 13326	: V=1.026967, theta=22.605928 -> V=1.0, theta=0.0
% INFO    : Bus 13327	: V=1.117446, theta=4.922187 -> V=1.0, theta=0.0
% INFO    : Bus 13328	: V=0.98627, theta=-4.659541 -> V=1.0, theta=0.0
% INFO    : Bus 13329	: V=1.059724, theta=-0.446506 -> V=1.0, theta=0.0
% INFO    : Bus 13330	: V=1.011478, theta=-0.639289 -> V=1.0, theta=0.0
% INFO    : Bus 13331	: V=0.972672, theta=16.077471 -> V=1.0, theta=0.0
% INFO    : Bus 13332	: V=1.027321, theta=5.578339 -> V=1.0, theta=0.0
% INFO    : Bus 13333	: V=1.065343, theta=53.072846 -> V=1.0, theta=0.0
% INFO    : Bus 13334	: V=1.026971, theta=5.501097 -> V=1.0, theta=0.0
% INFO    : Bus 13335	: V=0.971843, theta=-7.304062 -> V=1.0, theta=0.0
% INFO    : Bus 13336	: V=1.037306, theta=27.360815 -> V=1.0, theta=0.0
% INFO    : Bus 13337	: V=0.975965, theta=28.510882 -> V=1.0, theta=0.0
% INFO    : Bus 13338	: V=1.000057, theta=26.10357 -> V=1.0, theta=0.0
% INFO    : Bus 13339	: V=0.984937, theta=7.581128 -> V=1.0, theta=0.0
% INFO    : Bus 13340	: V=0.973224, theta=-4.991666 -> V=1.0, theta=0.0
% INFO    : Bus 13341	: V=0.995041, theta=33.268248 -> V=1.0, theta=0.0
% INFO    : Bus 13342	: V=1.063145, theta=-2.590835 -> V=1.0, theta=0.0
% INFO    : Bus 13343	: V=0.993675, theta=90.655341 -> V=1.0, theta=0.0
% INFO    : Bus 13344	: V=0.972809, theta=-28.706724 -> V=1.0, theta=0.0
% INFO    : Bus 13345	: V=1.025019, theta=-12.264635 -> V=1.0, theta=0.0
% INFO    : Bus 13346	: V=1.041768, theta=12.293615 -> V=1.0, theta=0.0
% INFO    : Bus 13347	: V=1.024854, theta=17.026834 -> V=1.0, theta=0.0
% INFO    : Bus 13348	: V=1.046536, theta=-20.234594 -> V=1.0, theta=0.0
% INFO    : Bus 13349	: V=1.037314, theta=-19.889053 -> V=1.0, theta=0.0
% INFO    : Bus 13350	: V=1.012731, theta=25.47515 -> V=1.0, theta=0.0
% INFO    : Bus 13351	: V=1.017233, theta=-16.531897 -> V=1.0, theta=0.0
% INFO    : Bus 13352	: V=1.048814, theta=28.18734 -> V=1.0, theta=0.0
% INFO    : Bus 13353	: V=1.024685, theta=-1.981769 -> V=1.0, theta=0.0
% INFO    : Bus 13354	: V=1.107706, theta=75.952864 -> V=1.0, theta=0.0
% INFO    : Bus 13355	: V=1.066282, theta=1.23233 -> V=1.0, theta=0.0
% INFO    : Bus 13356	: V=1.068417, theta=1.099548 -> V=1.0, theta=0.0
% INFO    : Bus 13357	: V=1.016026, theta=27.942514 -> V=1.0, theta=0.0
% INFO    : Bus 13358	: V=1.009595, theta=-9.543523 -> V=1.0, theta=0.0
% INFO    : Bus 13359	: V=1.01437, theta=6.320018 -> V=1.0, theta=0.0
% INFO    : Bus 13360	: V=1.06669, theta=-4.514841 -> V=1.0, theta=0.0
% INFO    : Bus 13361	: V=1.029371, theta=9.370477 -> V=1.0, theta=0.0
% INFO    : Bus 13362	: V=1.000539, theta=-7.914068 -> V=1.0, theta=0.0
% INFO    : Bus 13363	: V=1.062565, theta=2.294369 -> V=1.0, theta=0.0
% INFO    : Bus 13364	: V=1.019724, theta=-7.10214 -> V=1.0, theta=0.0
% INFO    : Bus 13365	: V=0.995583, theta=89.682428 -> V=1.0, theta=0.0
% INFO    : Bus 13366	: V=0.973767, theta=-22.709919 -> V=1.0, theta=0.0
% INFO    : Bus 13367	: V=1.00814, theta=-12.831745 -> V=1.0, theta=0.0
% INFO    : Bus 13368	: V=0.88398, theta=-14.103043 -> V=1.0, theta=0.0
% INFO    : Bus 13369	: V=1.030892, theta=1.639451 -> V=1.0, theta=0.0
% INFO    : Bus 13370	: V=1.024788, theta=-12.464012 -> V=1.0, theta=0.0
% INFO    : Bus 13371	: V=1.027307, theta=-18.397327 -> V=1.0, theta=0.0
% INFO    : Bus 13372	: V=1.050644, theta=32.165751 -> V=1.0, theta=0.0
% INFO    : Bus 13373	: V=1.019313, theta=14.657917 -> V=1.0, theta=0.0
% INFO    : Bus 13374	: V=1.020254, theta=-23.064206 -> V=1.0, theta=0.0
% INFO    : Bus 13375	: V=1.029418, theta=77.694305 -> V=1.0, theta=0.0
% INFO    : Bus 13376	: V=1.089497, theta=1.416675 -> V=1.0, theta=0.0
% INFO    : Bus 13377	: V=1.028646, theta=7.51961 -> V=1.0, theta=0.0
% INFO    : Bus 13378	: V=1.009925, theta=-3.074401 -> V=1.0, theta=0.0
% INFO    : Bus 13379	: V=1.052254, theta=11.947216 -> V=1.0, theta=0.0
% INFO    : Bus 13380	: V=1.039079, theta=-1.89058 -> V=1.0, theta=0.0
% INFO    : Bus 13381	: V=0.99558, theta=90.692442 -> V=1.0, theta=0.0
% INFO    : Bus 13382	: V=1.04189, theta=2.242319 -> V=1.0, theta=0.0
% INFO    : Bus 13383	: V=1.063297, theta=57.37246 -> V=1.0, theta=0.0
% INFO    : Bus 13384	: V=1.037466, theta=28.004671 -> V=1.0, theta=0.0
% INFO    : Bus 13385	: V=1.030828, theta=-0.367949 -> V=1.0, theta=0.0
% INFO    : Bus 13386	: V=1.030828, theta=-0.367949 -> V=1.0, theta=0.0
% INFO    : Bus 13387	: V=1.030828, theta=-0.367949 -> V=1.0, theta=0.0
% INFO    : Bus 13388	: V=1.055605, theta=26.96637 -> V=1.0, theta=0.0
% INFO    : Bus 13389	: V=1.055605, theta=26.96637 -> V=1.0, theta=0.0
% INFO    : Bus 13390	: V=1.016891, theta=10.696134 -> V=1.0, theta=0.0
% INFO    : Bus 13391	: V=1.016891, theta=10.696134 -> V=1.0, theta=0.0
% INFO    : Bus 13392	: V=1.043178, theta=23.372652 -> V=1.0, theta=0.0
% INFO    : Bus 13393	: V=1.016891, theta=10.696134 -> V=1.0, theta=0.0
% INFO    : Bus 13394	: V=1.016891, theta=10.696134 -> V=1.0, theta=0.0
% INFO    : Bus 13395	: V=1.016891, theta=10.696134 -> V=1.0, theta=0.0
% INFO    : Bus 13396	: V=1.005221, theta=16.315529 -> V=1.0, theta=0.0
% INFO    : Bus 13397	: V=1.055605, theta=26.96637 -> V=1.0, theta=0.0
% INFO    : Bus 13398	: V=1.055605, theta=26.96637 -> V=1.0, theta=0.0
% INFO    : Bus 13399	: V=1.055605, theta=26.96637 -> V=1.0, theta=0.0
% INFO    : Bus 13400	: V=0.99704, theta=-13.288962 -> V=1.0, theta=0.0
% INFO    : Bus 13401	: V=1.019406, theta=37.270568 -> V=1.0, theta=0.0
% INFO    : Bus 13402	: V=0.999512, theta=33.001947 -> V=1.0, theta=0.0
% INFO    : Bus 13403	: V=1.040995, theta=33.204925 -> V=1.0, theta=0.0
% INFO    : Bus 13404	: V=0.99762, theta=-4.347464 -> V=1.0, theta=0.0
% INFO    : Bus 13405	: V=1.054724, theta=33.113517 -> V=1.0, theta=0.0
% INFO    : Bus 13406	: V=1.004024, theta=-18.321279 -> V=1.0, theta=0.0
% INFO    : Bus 13407	: V=0.965886, theta=44.832426 -> V=1.0, theta=0.0
% INFO    : Bus 13408	: V=1.040657, theta=19.42178 -> V=1.0, theta=0.0
% INFO    : Bus 13409	: V=1.015954, theta=3.75914 -> V=1.0, theta=0.0
% INFO    : Bus 13410	: V=1.013727, theta=36.461333 -> V=1.0, theta=0.0
% INFO    : Bus 13411	: V=1.043619, theta=-8.436397 -> V=1.0, theta=0.0
% INFO    : Bus 13412	: V=1.027264, theta=14.46311 -> V=1.0, theta=0.0
% INFO    : Bus 13413	: V=1.016594, theta=19.314094 -> V=1.0, theta=0.0
% INFO    : Bus 13414	: V=1.048204, theta=32.7209 -> V=1.0, theta=0.0
% INFO    : Bus 13415	: V=0.983779, theta=-12.14246 -> V=1.0, theta=0.0
% INFO    : Bus 13416	: V=0.975073, theta=40.56328 -> V=1.0, theta=0.0
% INFO    : Bus 13417	: V=1.012371, theta=-11.441989 -> V=1.0, theta=0.0
% INFO    : Bus 13418	: V=0.944968, theta=-10.854722 -> V=1.0, theta=0.0
% INFO    : Bus 13419	: V=1.043942, theta=17.353218 -> V=1.0, theta=0.0
% INFO    : Bus 13420	: V=0.963614, theta=-4.868439 -> V=1.0, theta=0.0
% INFO    : Bus 13421	: V=1.02494, theta=28.997481 -> V=1.0, theta=0.0
% INFO    : Bus 13422	: V=0.98586, theta=-4.164195 -> V=1.0, theta=0.0
% INFO    : Bus 13423	: V=1.02494, theta=28.997481 -> V=1.0, theta=0.0
% INFO    : Bus 13424	: V=1.02494, theta=28.997481 -> V=1.0, theta=0.0
% INFO    : Bus 13425	: V=1.025625, theta=-16.674993 -> V=1.0, theta=0.0
% INFO    : Bus 13426	: V=1.03448, theta=21.013586 -> V=1.0, theta=0.0
% INFO    : Bus 13427	: V=1.027866, theta=16.538428 -> V=1.0, theta=0.0
% INFO    : Bus 13428	: V=1.00143, theta=-6.748273 -> V=1.0, theta=0.0
% INFO    : Bus 13429	: V=1.053805, theta=0.42706 -> V=1.0, theta=0.0
% INFO    : Bus 13430	: V=0.998645, theta=10.064174 -> V=1.0, theta=0.0
% INFO    : Bus 13431	: V=1.029674, theta=25.846398 -> V=1.0, theta=0.0
% INFO    : Bus 13432	: V=1.027952, theta=46.673663 -> V=1.0, theta=0.0
% INFO    : Bus 13433	: V=1.021414, theta=-20.989235 -> V=1.0, theta=0.0
% INFO    : Bus 13434	: V=1.019678, theta=-23.024367 -> V=1.0, theta=0.0
% INFO    : Bus 13435	: V=0.929129, theta=-11.916099 -> V=1.0, theta=0.0
% INFO    : Bus 13436	: V=1.03722, theta=14.842216 -> V=1.0, theta=0.0
% INFO    : Bus 13437	: V=1.021414, theta=-20.989235 -> V=1.0, theta=0.0
% INFO    : Bus 13438	: V=1.003202, theta=27.868067 -> V=1.0, theta=0.0
% INFO    : Bus 13439	: V=1.021414, theta=-20.989235 -> V=1.0, theta=0.0
% INFO    : Bus 13440	: V=1.014614, theta=-15.196146 -> V=1.0, theta=0.0
% INFO    : Bus 13441	: V=1.021508, theta=58.607652 -> V=1.0, theta=0.0
% INFO    : Bus 13442	: V=0.989357, theta=45.563421 -> V=1.0, theta=0.0
% INFO    : Bus 13443	: V=1.017775, theta=79.055094 -> V=1.0, theta=0.0
% INFO    : Bus 13444	: V=1.023486, theta=19.424707 -> V=1.0, theta=0.0
% INFO    : Bus 13445	: V=1.053846, theta=-6.619406 -> V=1.0, theta=0.0
% INFO    : Bus 13446	: V=1.009746, theta=8.102362 -> V=1.0, theta=0.0
% INFO    : Bus 13447	: V=1.011745, theta=17.062335 -> V=1.0, theta=0.0
% INFO    : Bus 13448	: V=1.016787, theta=21.906986 -> V=1.0, theta=0.0
% INFO    : Bus 13449	: V=0.992617, theta=33.294937 -> V=1.0, theta=0.0
% INFO    : Bus 13450	: V=1.01278, theta=22.188029 -> V=1.0, theta=0.0
% INFO    : Bus 13451	: V=1.025682, theta=-6.023946 -> V=1.0, theta=0.0
% INFO    : Bus 13452	: V=1.0037, theta=-10.261267 -> V=1.0, theta=0.0
% INFO    : Bus 13453	: V=1.025028, theta=7.263324 -> V=1.0, theta=0.0
% INFO    : Bus 13454	: V=1.008844, theta=51.084468 -> V=1.0, theta=0.0
% INFO    : Bus 13455	: V=1.043627, theta=7.79121 -> V=1.0, theta=0.0
% INFO    : Bus 13456	: V=1.005915, theta=0.12691 -> V=1.0, theta=0.0
% INFO    : Bus 13457	: V=0.991364, theta=18.825266 -> V=1.0, theta=0.0
% INFO    : Bus 13458	: V=1.019071, theta=7.96358 -> V=1.0, theta=0.0
% INFO    : Bus 13459	: V=1.025237, theta=-7.644418 -> V=1.0, theta=0.0
% INFO    : Bus 13460	: V=1.042565, theta=24.855063 -> V=1.0, theta=0.0
% INFO    : Bus 13461	: V=1.077884, theta=7.357907 -> V=1.0, theta=0.0
% INFO    : Bus 13462	: V=1.00691, theta=-22.518312 -> V=1.0, theta=0.0
% INFO    : Bus 13463	: V=1.046177, theta=8.247773 -> V=1.0, theta=0.0
% INFO    : Bus 13464	: V=0.958925, theta=-16.006713 -> V=1.0, theta=0.0
% INFO    : Bus 13465	: V=1.050646, theta=32.165732 -> V=1.0, theta=0.0
% INFO    : Bus 13466	: V=1.062896, theta=-0.392816 -> V=1.0, theta=0.0
% INFO    : Bus 13467	: V=0.989708, theta=1.882164 -> V=1.0, theta=0.0
% INFO    : Bus 13468	: V=1.024375, theta=-1.976838 -> V=1.0, theta=0.0
% INFO    : Bus 13469	: V=1.04035, theta=8.357264 -> V=1.0, theta=0.0
% INFO    : Bus 13470	: V=0.972308, theta=-2.718329 -> V=1.0, theta=0.0
% INFO    : Bus 13471	: V=1.033064, theta=16.599356 -> V=1.0, theta=0.0
% INFO    : Bus 13472	: V=1.000964, theta=-2.993742 -> V=1.0, theta=0.0
% INFO    : Bus 13473	: V=0.97666, theta=29.263732 -> V=1.0, theta=0.0
% INFO    : Bus 13474	: V=1.014746, theta=17.839526 -> V=1.0, theta=0.0
% INFO    : Bus 13475	: V=0.998052, theta=-0.623483 -> V=1.0, theta=0.0
% INFO    : Bus 13476	: V=1.005595, theta=14.268483 -> V=1.0, theta=0.0
% INFO    : Bus 13477	: V=1.036114, theta=25.111328 -> V=1.0, theta=0.0
% INFO    : Bus 13478	: V=1.00787, theta=-25.080034 -> V=1.0, theta=0.0
% INFO    : Bus 13479	: V=1.019038, theta=-1.856624 -> V=1.0, theta=0.0
% INFO    : Bus 13480	: V=0.998235, theta=2.780849 -> V=1.0, theta=0.0
% INFO    : Bus 13481	: V=1.03499, theta=9.763907 -> V=1.0, theta=0.0
% INFO    : Bus 13482	: V=1.062896, theta=-0.392816 -> V=1.0, theta=0.0
% INFO    : Bus 13483	: V=1.001346, theta=26.686522 -> V=1.0, theta=0.0
% INFO    : Bus 13484	: V=1.013127, theta=27.002676 -> V=1.0, theta=0.0
% INFO    : Bus 13485	: V=1.051699, theta=-5.861304 -> V=1.0, theta=0.0
% INFO    : Bus 13486	: V=1.062896, theta=-0.392816 -> V=1.0, theta=0.0
% INFO    : Bus 13487	: V=1.03143, theta=0.621932 -> V=1.0, theta=0.0
% INFO    : Bus 13488	: V=0.990162, theta=46.115411 -> V=1.0, theta=0.0
% INFO    : Bus 13489	: V=1.061099, theta=-1.375053 -> V=1.0, theta=0.0
% INFO    : Bus 13490	: V=1.055526, theta=12.967489 -> V=1.0, theta=0.0
% INFO    : Bus 13491	: V=1.026081, theta=32.715698 -> V=1.0, theta=0.0
% INFO    : Bus 13492	: V=1.033125, theta=23.713599 -> V=1.0, theta=0.0
% INFO    : Bus 13493	: V=0.97953, theta=39.88697 -> V=1.0, theta=0.0
% INFO    : Bus 13494	: V=0.997884, theta=-4.981739 -> V=1.0, theta=0.0
% INFO    : Bus 13495	: V=1.023284, theta=53.641998 -> V=1.0, theta=0.0
% INFO    : Bus 13496	: V=1.044924, theta=29.406092 -> V=1.0, theta=0.0
% INFO    : Bus 13497	: V=1.044924, theta=29.406092 -> V=1.0, theta=0.0
% INFO    : Bus 13498	: V=1.050728, theta=28.162224 -> V=1.0, theta=0.0
% INFO    : Bus 13499	: V=1.037216, theta=-1.577146 -> V=1.0, theta=0.0
% INFO    : Bus 13500	: V=1.044939, theta=29.387061 -> V=1.0, theta=0.0
% INFO    : Bus 13501	: V=1.029091, theta=2.944245 -> V=1.0, theta=0.0
% INFO    : Bus 13502	: V=1.044939, theta=29.387061 -> V=1.0, theta=0.0
% INFO    : Bus 13503	: V=1.037295, theta=5.560158 -> V=1.0, theta=0.0
% INFO    : Bus 13504	: V=1.015643, theta=-12.653637 -> V=1.0, theta=0.0
% INFO    : Bus 13505	: V=1.044924, theta=29.406092 -> V=1.0, theta=0.0
% INFO    : Bus 13506	: V=1.044924, theta=29.406092 -> V=1.0, theta=0.0
% INFO    : Bus 13507	: V=1.044924, theta=29.406092 -> V=1.0, theta=0.0
% INFO    : Bus 13508	: V=1.002327, theta=-2.090017 -> V=1.0, theta=0.0
% INFO    : Bus 13509	: V=0.979714, theta=-25.778478 -> V=1.0, theta=0.0
% INFO    : Bus 13510	: V=1.016107, theta=1.117381 -> V=1.0, theta=0.0
% INFO    : Bus 13511	: V=1.043446, theta=0.547925 -> V=1.0, theta=0.0
% INFO    : Bus 13512	: V=1.030407, theta=32.510933 -> V=1.0, theta=0.0
% INFO    : Bus 13513	: V=0.979705, theta=-26.824454 -> V=1.0, theta=0.0
% INFO    : Bus 13514	: V=1.000449, theta=37.338871 -> V=1.0, theta=0.0
% INFO    : Bus 13515	: V=0.99786, theta=15.372787 -> V=1.0, theta=0.0
% INFO    : Bus 13516	: V=1.004347, theta=-20.932921 -> V=1.0, theta=0.0
% INFO    : Bus 13517	: V=1.042521, theta=24.431977 -> V=1.0, theta=0.0
% INFO    : Bus 13518	: V=0.989728, theta=-13.568538 -> V=1.0, theta=0.0
% INFO    : Bus 13519	: V=1.01361, theta=-2.270783 -> V=1.0, theta=0.0
% INFO    : Bus 13520	: V=1.061099, theta=-1.375053 -> V=1.0, theta=0.0
% INFO    : Bus 13521	: V=1.044479, theta=35.825794 -> V=1.0, theta=0.0
% INFO    : Bus 13522	: V=0.94985, theta=0.99867 -> V=1.0, theta=0.0
% INFO    : Bus 13523	: V=1.053911, theta=0.255931 -> V=1.0, theta=0.0
% INFO    : Bus 13524	: V=1.01268, theta=36.766084 -> V=1.0, theta=0.0
% INFO    : Bus 13525	: V=1.025333, theta=3.180104 -> V=1.0, theta=0.0
% INFO    : Bus 13526	: V=1.062073, theta=84.08696 -> V=1.0, theta=0.0
% INFO    : Bus 13527	: V=1.068425, theta=7.142111 -> V=1.0, theta=0.0
% INFO    : Bus 13528	: V=1.009202, theta=-9.329154 -> V=1.0, theta=0.0
% INFO    : Bus 13529	: V=1.03256, theta=16.651965 -> V=1.0, theta=0.0
% INFO    : Bus 13530	: V=1.042446, theta=6.957021 -> V=1.0, theta=0.0
% INFO    : Bus 13531	: V=1.028513, theta=-22.307748 -> V=1.0, theta=0.0
% INFO    : Bus 13532	: V=1.003512, theta=-19.342822 -> V=1.0, theta=0.0
% INFO    : Bus 13533	: V=1.003512, theta=-19.342822 -> V=1.0, theta=0.0
% INFO    : Bus 13534	: V=1.015051, theta=32.251738 -> V=1.0, theta=0.0
% INFO    : Bus 13535	: V=1.003512, theta=-19.342822 -> V=1.0, theta=0.0
% INFO    : Bus 13536	: V=1.040042, theta=41.08762 -> V=1.0, theta=0.0
% INFO    : Bus 13537	: V=1.015472, theta=-11.700252 -> V=1.0, theta=0.0
% INFO    : Bus 13538	: V=1.008279, theta=-10.478046 -> V=1.0, theta=0.0
% INFO    : Bus 13539	: V=1.023383, theta=42.683688 -> V=1.0, theta=0.0
% INFO    : Bus 13540	: V=0.983404, theta=1.560689 -> V=1.0, theta=0.0
% INFO    : Bus 13541	: V=1.025518, theta=6.138633 -> V=1.0, theta=0.0
% INFO    : Bus 13542	: V=1.01555, theta=-10.855307 -> V=1.0, theta=0.0
% INFO    : Bus 13543	: V=0.983074, theta=-8.186805 -> V=1.0, theta=0.0
% INFO    : Bus 13544	: V=1.033426, theta=15.128762 -> V=1.0, theta=0.0
% INFO    : Bus 13545	: V=1.026198, theta=-16.155637 -> V=1.0, theta=0.0
% INFO    : Bus 13546	: V=1.025258, theta=-3.745037 -> V=1.0, theta=0.0
% INFO    : Bus 13547	: V=1.040263, theta=28.661705 -> V=1.0, theta=0.0
% INFO    : Bus 13548	: V=1.021257, theta=7.312963 -> V=1.0, theta=0.0
% INFO    : Bus 13549	: V=0.996935, theta=21.950327 -> V=1.0, theta=0.0
% INFO    : Bus 13550	: V=1.016735, theta=24.349916 -> V=1.0, theta=0.0
% INFO    : Bus 13551	: V=0.984601, theta=26.113188 -> V=1.0, theta=0.0
% INFO    : Bus 13552	: V=1.018662, theta=-33.087457 -> V=1.0, theta=0.0
% INFO    : Bus 13553	: V=0.982498, theta=-8.529449 -> V=1.0, theta=0.0
% INFO    : Bus 13554	: V=0.993427, theta=-9.324273 -> V=1.0, theta=0.0
% INFO    : Bus 13555	: V=1.007864, theta=11.047273 -> V=1.0, theta=0.0
% INFO    : Bus 13556	: V=0.994601, theta=31.575691 -> V=1.0, theta=0.0
% INFO    : Bus 13557	: V=1.008244, theta=-3.184184 -> V=1.0, theta=0.0
% INFO    : Bus 13558	: V=1.021067, theta=36.65418 -> V=1.0, theta=0.0
% INFO    : Bus 13559	: V=1.051912, theta=5.608241 -> V=1.0, theta=0.0
% INFO    : Bus 13560	: V=1.033239, theta=35.570464 -> V=1.0, theta=0.0
% INFO    : Bus 13561	: V=1.000535, theta=-9.681265 -> V=1.0, theta=0.0
% INFO    : Bus 13562	: V=1.039357, theta=-2.051947 -> V=1.0, theta=0.0
% INFO    : Bus 13563	: V=1.022641, theta=24.05693 -> V=1.0, theta=0.0
% INFO    : Bus 13564	: V=1.005815, theta=-2.908572 -> V=1.0, theta=0.0
% INFO    : Bus 13565	: V=1.024082, theta=10.196492 -> V=1.0, theta=0.0
% INFO    : Bus 13566	: V=0.992072, theta=-4.62442 -> V=1.0, theta=0.0
% INFO    : Bus 13567	: V=0.996488, theta=-8.999786 -> V=1.0, theta=0.0
% INFO    : Bus 13568	: V=1.033292, theta=16.596766 -> V=1.0, theta=0.0
% INFO    : Bus 13569	: V=1.036065, theta=-16.582357 -> V=1.0, theta=0.0
% INFO    : Bus 13570	: V=1.013683, theta=-0.730425 -> V=1.0, theta=0.0
% INFO    : Bus 13571	: V=0.997383, theta=-14.35601 -> V=1.0, theta=0.0
% INFO    : Bus 13572	: V=1.030297, theta=20.234769 -> V=1.0, theta=0.0
% INFO    : Bus 13573	: V=0.995147, theta=19.31397 -> V=1.0, theta=0.0
% INFO    : Bus 13574	: V=1.025659, theta=22.029811 -> V=1.0, theta=0.0
% INFO    : Bus 13575	: V=1.059983, theta=-1.662639 -> V=1.0, theta=0.0
% INFO    : Bus 13576	: V=1.036622, theta=7.110319 -> V=1.0, theta=0.0
% INFO    : Bus 13577	: V=1.034597, theta=19.022639 -> V=1.0, theta=0.0
% INFO    : Bus 13578	: V=1.001456, theta=-8.619342 -> V=1.0, theta=0.0
% INFO    : Bus 13579	: V=1.071454, theta=1.370559 -> V=1.0, theta=0.0
% INFO    : Bus 13580	: V=1.043178, theta=23.372652 -> V=1.0, theta=0.0
% INFO    : Bus 13581	: V=1.034873, theta=4.848207 -> V=1.0, theta=0.0
% INFO    : Bus 13582	: V=1.043178, theta=23.372652 -> V=1.0, theta=0.0
% INFO    : Bus 13583	: V=0.996638, theta=13.542185 -> V=1.0, theta=0.0
% INFO    : Bus 13584	: V=1.030744, theta=-0.382174 -> V=1.0, theta=0.0
% INFO    : Bus 13585	: V=1.04545, theta=17.664921 -> V=1.0, theta=0.0
% INFO    : Bus 13586	: V=1.032358, theta=23.741403 -> V=1.0, theta=0.0
% INFO    : Bus 13587	: V=1.006208, theta=20.83367 -> V=1.0, theta=0.0
% INFO    : Bus 13588	: V=1.032503, theta=-3.384672 -> V=1.0, theta=0.0
% INFO    : Bus 13589	: V=1.04545, theta=17.664921 -> V=1.0, theta=0.0
% INFO    : Bus 13590	: V=0.962614, theta=39.578299 -> V=1.0, theta=0.0
% INFO    : Bus 13591	: V=1.000661, theta=-5.473621 -> V=1.0, theta=0.0
% INFO    : Bus 13592	: V=1.051118, theta=25.29251 -> V=1.0, theta=0.0
% INFO    : Bus 13593	: V=1.023635, theta=0.441918 -> V=1.0, theta=0.0
% INFO    : Bus 13594	: V=1.045375, theta=17.213843 -> V=1.0, theta=0.0
% INFO    : Bus 13595	: V=1.005996, theta=-15.154422 -> V=1.0, theta=0.0
% INFO    : Bus 13596	: V=1.01508, theta=-20.654825 -> V=1.0, theta=0.0
% INFO    : Bus 13597	: V=1.045375, theta=17.213843 -> V=1.0, theta=0.0
% INFO    : Bus 13598	: V=0.995589, theta=33.909349 -> V=1.0, theta=0.0
% INFO    : Bus 13599	: V=0.91947, theta=-10.968821 -> V=1.0, theta=0.0
% INFO    : Bus 13600	: V=1.029652, theta=34.356781 -> V=1.0, theta=0.0
% INFO    : Bus 13601	: V=1.050175, theta=5.20925 -> V=1.0, theta=0.0
% INFO    : Bus 13602	: V=1.004626, theta=-15.516883 -> V=1.0, theta=0.0
% INFO    : Bus 13603	: V=0.996849, theta=-12.475537 -> V=1.0, theta=0.0
% INFO    : Bus 13604	: V=1.04545, theta=17.664921 -> V=1.0, theta=0.0
% INFO    : Bus 13605	: V=0.990055, theta=14.71774 -> V=1.0, theta=0.0
% INFO    : Bus 13606	: V=0.988767, theta=-1.899151 -> V=1.0, theta=0.0
% INFO    : Bus 13607	: V=1.020265, theta=-12.139526 -> V=1.0, theta=0.0
% INFO    : Bus 13608	: V=1.01076, theta=44.146078 -> V=1.0, theta=0.0
% INFO    : Bus 13609	: V=1.030852, theta=14.833561 -> V=1.0, theta=0.0
% INFO    : Bus 13610	: V=1.018465, theta=-5.640469 -> V=1.0, theta=0.0
% INFO    : Bus 13611	: V=1.016297, theta=30.173068 -> V=1.0, theta=0.0
% INFO    : Bus 13612	: V=0.98248, theta=33.260777 -> V=1.0, theta=0.0
% INFO    : Bus 13613	: V=1.015753, theta=16.87996 -> V=1.0, theta=0.0
% INFO    : Bus 13614	: V=1.037073, theta=30.465607 -> V=1.0, theta=0.0
% INFO    : Bus 13615	: V=0.989728, theta=-4.296953 -> V=1.0, theta=0.0
% INFO    : Bus 13616	: V=0.937702, theta=-1.59787 -> V=1.0, theta=0.0
% INFO    : Bus 13617	: V=0.991929, theta=29.398008 -> V=1.0, theta=0.0
% INFO    : Bus 13618	: V=1.06601, theta=-5.428594 -> V=1.0, theta=0.0
% INFO    : Bus 13619	: V=1.066104, theta=33.9921 -> V=1.0, theta=0.0
% INFO    : Bus 13620	: V=1.034935, theta=24.924619 -> V=1.0, theta=0.0
% INFO    : Bus 13621	: V=0.994725, theta=24.542662 -> V=1.0, theta=0.0
% INFO    : Bus 13622	: V=1.003125, theta=-3.610696 -> V=1.0, theta=0.0
% INFO    : Bus 13623	: V=0.946151, theta=-7.796967 -> V=1.0, theta=0.0
% INFO    : Bus 13624	: V=1.016603, theta=17.55807 -> V=1.0, theta=0.0
% INFO    : Bus 13625	: V=1.030275, theta=-20.984998 -> V=1.0, theta=0.0
% INFO    : Bus 13626	: V=1.013634, theta=32.140775 -> V=1.0, theta=0.0
% INFO    : Bus 13627	: V=1.051765, theta=-1.298833 -> V=1.0, theta=0.0
% INFO    : Bus 13628	: V=0.948174, theta=-7.95012 -> V=1.0, theta=0.0
% INFO    : Bus 13629	: V=1.056217, theta=14.209439 -> V=1.0, theta=0.0
% INFO    : Bus 13630	: V=1.030233, theta=17.606169 -> V=1.0, theta=0.0
% INFO    : Bus 13631	: V=1.035312, theta=38.187653 -> V=1.0, theta=0.0
% INFO    : Bus 13632	: V=1.00299, theta=1.259242 -> V=1.0, theta=0.0
% INFO    : Bus 13633	: V=1.03143, theta=0.621932 -> V=1.0, theta=0.0
% INFO    : Bus 13634	: V=1.034538, theta=19.040969 -> V=1.0, theta=0.0
% INFO    : Bus 13635	: V=1.020998, theta=22.939343 -> V=1.0, theta=0.0
% INFO    : Bus 13636	: V=0.958613, theta=-0.321963 -> V=1.0, theta=0.0
% INFO    : Bus 13637	: V=1.049406, theta=-5.456139 -> V=1.0, theta=0.0
% INFO    : Bus 13638	: V=1.033627, theta=4.718668 -> V=1.0, theta=0.0
% INFO    : Bus 13639	: V=0.980011, theta=18.705058 -> V=1.0, theta=0.0
% INFO    : Bus 13640	: V=1.001397, theta=93.26676 -> V=1.0, theta=0.0
% INFO    : Bus 13641	: V=1.012393, theta=-8.865545 -> V=1.0, theta=0.0
% INFO    : Bus 13642	: V=1.007442, theta=-12.200575 -> V=1.0, theta=0.0
% INFO    : Bus 13643	: V=0.995077, theta=34.268512 -> V=1.0, theta=0.0
% INFO    : Bus 13644	: V=0.979074, theta=-10.789922 -> V=1.0, theta=0.0
% INFO    : Bus 13645	: V=1.002037, theta=0.742162 -> V=1.0, theta=0.0
% INFO    : Bus 13646	: V=1.101093, theta=10.056103 -> V=1.0, theta=0.0
% INFO    : Bus 13647	: V=1.048531, theta=28.220134 -> V=1.0, theta=0.0
% INFO    : Bus 13648	: V=1.03143, theta=0.621932 -> V=1.0, theta=0.0
% INFO    : Bus 13649	: V=0.993195, theta=-1.493042 -> V=1.0, theta=0.0
% INFO    : Bus 13650	: V=1.038563, theta=26.451559 -> V=1.0, theta=0.0
% INFO    : Bus 13651	: V=1.042166, theta=-4.652525 -> V=1.0, theta=0.0
% INFO    : Bus 13652	: V=1.01608, theta=-6.699546 -> V=1.0, theta=0.0
% INFO    : Bus 13653	: V=1.02042, theta=-1.807734 -> V=1.0, theta=0.0
% INFO    : Bus 13654	: V=1.079579, theta=42.660061 -> V=1.0, theta=0.0
% INFO    : Bus 13655	: V=0.992821, theta=91.559603 -> V=1.0, theta=0.0
% INFO    : Bus 13656	: V=1.045517, theta=35.805985 -> V=1.0, theta=0.0
% INFO    : Bus 13657	: V=0.962266, theta=-9.928975 -> V=1.0, theta=0.0
% INFO    : Bus 13658	: V=1.038011, theta=31.920163 -> V=1.0, theta=0.0
% INFO    : Bus 13659	: V=1.038656, theta=21.496915 -> V=1.0, theta=0.0
% INFO    : 
% INFO    : === Generator Setpoint Replacement Notes ===
% INFO    : Gen at bus 1	: Pg=42.33, Qg=15.72 -> Pg=64.11, Qg=15.0
% INFO    : Gen at bus 1	: Vg=1.031695 -> Vg=1.0
% INFO    : Gen at bus 12	: Pg=238.58, Qg=-4.09 -> Pg=300.0, Qg=80.0
% INFO    : Gen at bus 12	: Vg=1.004054 -> Vg=1.0
% INFO    : Gen at bus 18	: Pg=38.02, Qg=11.21 -> Pg=62.675, Qg=10.0
% INFO    : Gen at bus 18	: Vg=1.043087 -> Vg=1.0
% INFO    : Gen at bus 29	: Pg=34.78, Qg=14.67 -> Pg=61.595, Qg=10.0
% INFO    : Gen at bus 29	: Vg=1.033319 -> Vg=1.0
% INFO    : Gen at bus 33	: Pg=25.35, Qg=8.5 -> Pg=58.45, Qg=15.0
% INFO    : Gen at bus 33	: Vg=1.018631 -> Vg=1.0
% INFO    : Gen at bus 39	: Pg=214.6, Qg=55.92 -> Pg=300.0, Qg=80.0
% INFO    : Gen at bus 39	: Vg=1.073284 -> Vg=1.0
% INFO    : Gen at bus 42	: Pg=16.1, Qg=-4.12 -> Pg=55.365, Qg=0.0
% INFO    : Gen at bus 42	: Vg=0.985213 -> Vg=1.0
% INFO    : Gen at bus 45	: Pg=192.55, Qg=1.87 -> Pg=250.0, Qg=60.0
% INFO    : Gen at bus 45	: Vg=1.012099 -> Vg=1.0
% INFO    : Gen at bus 51	: Pg=161.0, Qg=0.83 -> Pg=250.0, Qg=0.0
% INFO    : Gen at bus 51	: Vg=1.011416 -> Vg=1.0
% INFO    : Gen at bus 54	: Pg=37.08, Qg=5.51 -> Pg=62.36, Qg=10.0
% INFO    : Gen at bus 54	: Vg=1.021005 -> Vg=1.0
% INFO    : Gen at bus 62	: Pg=617.7, Qg=178.65 -> Pg=850.0, Qg=200.0
% INFO    : Gen at bus 62	: Vg=1.058268 -> Vg=1.0
% INFO    : Gen at bus 63	: Pg=617.7, Qg=178.65 -> Pg=850.0, Qg=200.0
% INFO    : Gen at bus 63	: Vg=1.058268 -> Vg=1.0
% INFO    : Gen at bus 66	: Pg=179.12, Qg=14.03 -> Pg=250.0, Qg=60.0
% INFO    : Gen at bus 66	: Vg=1.034768 -> Vg=1.0
% INFO    : Gen at bus 68	: Pg=53.72, Qg=11.91 -> Pg=117.905, Qg=15.0
% INFO    : Gen at bus 68	: Vg=1.035023 -> Vg=1.0
% INFO    : Gen at bus 69	: Pg=53.72, Qg=11.91 -> Pg=117.905, Qg=15.0
% INFO    : Gen at bus 69	: Vg=1.035023 -> Vg=1.0
% INFO    : Gen at bus 77	: Pg=24.65, Qg=6.97 -> Pg=58.215, Qg=10.0
% INFO    : Gen at bus 77	: Vg=1.038344 -> Vg=1.0
% INFO    : Gen at bus 78	: Pg=54.48, Qg=10.37 -> Pg=118.16, Qg=10.0
% INFO    : Gen at bus 78	: Vg=1.027383 -> Vg=1.0
% INFO    : Gen at bus 79	: Pg=18.13, Qg=3.85 -> Pg=56.045, Qg=10.0
% INFO    : Gen at bus 79	: Vg=1.016716 -> Vg=1.0
% INFO    : Gen at bus 86	: Pg=152.7, Qg=32.92 -> Pg=250.0, Qg=30.0
% INFO    : Gen at bus 86	: Vg=1.023881 -> Vg=1.0
% INFO    : Gen at bus 94	: Pg=17.64, Qg=3.05 -> Pg=55.88, Qg=5.0
% INFO    : Gen at bus 94	: Vg=1.022611 -> Vg=1.0
% INFO    : Gen at bus 96	: Pg=49.42, Qg=5.32 -> Pg=66.475, Qg=15.0
% INFO    : Gen at bus 96	: Vg=1.043225 -> Vg=1.0
% INFO    : Gen at bus 97	: Pg=49.42, Qg=5.32 -> Pg=66.475, Qg=15.0
% INFO    : Gen at bus 97	: Vg=1.043225 -> Vg=1.0
% INFO    : Gen at bus 98	: Pg=49.42, Qg=5.32 -> Pg=66.475, Qg=15.0
% INFO    : Gen at bus 98	: Vg=1.043225 -> Vg=1.0
% INFO    : Gen at bus 99	: Pg=23.85, Qg=6.18 -> Pg=57.95, Qg=15.0
% INFO    : Gen at bus 99	: Vg=1.031885 -> Vg=1.0
% INFO    : Gen at bus 100	: Pg=23.85, Qg=6.18 -> Pg=57.95, Qg=15.0
% INFO    : Gen at bus 100	: Vg=1.031885 -> Vg=1.0
% INFO    : Gen at bus 101	: Pg=49.42, Qg=5.32 -> Pg=66.475, Qg=15.0
% INFO    : Gen at bus 101	: Vg=1.043225 -> Vg=1.0
% INFO    : Gen at bus 102	: Pg=49.42, Qg=5.32 -> Pg=66.475, Qg=15.0
% INFO    : Gen at bus 102	: Vg=1.043225 -> Vg=1.0
% INFO    : Gen at bus 104	: Pg=87.95, Qg=47.73 -> Pg=129.315, Qg=20.0
% INFO    : Gen at bus 104	: Vg=1.052257 -> Vg=1.0
% INFO    : Gen at bus 107	: Pg=68.26, Qg=9.75 -> Pg=122.755, Qg=20.0
% INFO    : Gen at bus 107	: Vg=1.028153 -> Vg=1.0
% INFO    : Gen at bus 110	: Pg=91.47, Qg=10.42 -> Pg=130.49, Qg=20.0
% INFO    : Gen at bus 110	: Vg=1.051233 -> Vg=1.0
% INFO    : Gen at bus 114	: Pg=42.35, Qg=6.03 -> Pg=64.115, Qg=15.0
% INFO    : Gen at bus 114	: Vg=1.030832 -> Vg=1.0
% INFO    : Gen at bus 115	: Pg=22.35, Qg=5.33 -> Pg=57.45, Qg=10.0
% INFO    : Gen at bus 115	: Vg=1.019 -> Vg=1.0
% INFO    : Gen at bus 121	: Pg=36.03, Qg=16.08 -> Pg=62.01, Qg=10.0
% INFO    : Gen at bus 121	: Vg=1.045359 -> Vg=1.0
% INFO    : Gen at bus 132	: Pg=6.52, Qg=0.05 -> Pg=52.175, Qg=0.0
% INFO    : Gen at bus 132	: Vg=0.996117 -> Vg=1.0
% INFO    : Gen at bus 133	: Pg=36.77, Qg=13.93 -> Pg=62.255, Qg=10.0
% INFO    : Gen at bus 133	: Vg=1.042317 -> Vg=1.0
% INFO    : Gen at bus 134	: Pg=45.54, Qg=5.69 -> Pg=65.18, Qg=15.0
% INFO    : Gen at bus 134	: Vg=1.044129 -> Vg=1.0
% INFO    : Gen at bus 135	: Pg=42.35, Qg=6.03 -> Pg=64.115, Qg=15.0
% INFO    : Gen at bus 135	: Vg=1.030832 -> Vg=1.0
% INFO    : Gen at bus 136	: Pg=50.83, Qg=3.96 -> Pg=116.945, Qg=20.0
% INFO    : Gen at bus 136	: Vg=1.049674 -> Vg=1.0
% INFO    : Gen at bus 144	: Pg=17.8, Qg=10.21 -> Pg=55.935, Qg=10.0
% INFO    : Gen at bus 144	: Vg=1.034631 -> Vg=1.0
% INFO    : Gen at bus 145	: Pg=612.01, Qg=227.35 -> Pg=850.0, Qg=200.0
% INFO    : Gen at bus 145	: Vg=1.040587 -> Vg=1.0
% INFO    : Gen at bus 146	: Pg=612.04, Qg=259.97 -> Pg=850.0, Qg=200.0
% INFO    : Gen at bus 146	: Vg=1.044313 -> Vg=1.0
% INFO    : Gen at bus 147	: Pg=612.04, Qg=259.97 -> Pg=850.0, Qg=200.0
% INFO    : Gen at bus 147	: Vg=1.044313 -> Vg=1.0
% INFO    : Gen at bus 151	: Pg=204.0, Qg=30.47 -> Pg=300.0, Qg=45.0
% INFO    : Gen at bus 151	: Vg=1.023215 -> Vg=1.0
% INFO    : Gen at bus 153	: Pg=36.13, Qg=4.17 -> Pg=62.045, Qg=10.0
% INFO    : Gen at bus 153	: Vg=1.027348 -> Vg=1.0
% INFO    : Gen at bus 154	: Pg=766.83, Qg=2.68 -> Pg=1050.0, Qg=200.0
% INFO    : Gen at bus 154	: Vg=1.05252 -> Vg=1.0
% INFO    : Gen at bus 156	: Pg=49.34, Qg=9.15 -> Pg=66.445, Qg=15.0
% INFO    : Gen at bus 156	: Vg=1.034597 -> Vg=1.0
% INFO    : Gen at bus 161	: Pg=49.34, Qg=9.15 -> Pg=66.445, Qg=15.0
% INFO    : Gen at bus 161	: Vg=1.034597 -> Vg=1.0
% INFO    : Gen at bus 162	: Pg=49.34, Qg=9.15 -> Pg=66.445, Qg=15.0
% INFO    : Gen at bus 162	: Vg=1.034597 -> Vg=1.0
% INFO    : Gen at bus 165	: Pg=42.35, Qg=6.03 -> Pg=64.115, Qg=15.0
% INFO    : Gen at bus 165	: Vg=1.030832 -> Vg=1.0
% INFO    : Gen at bus 179	: Pg=95.02, Qg=8.09 -> Pg=131.675, Qg=20.0
% INFO    : Gen at bus 179	: Vg=1.023144 -> Vg=1.0
% INFO    : Gen at bus 182	: Pg=34.96, Qg=12.97 -> Pg=61.655, Qg=10.0
% INFO    : Gen at bus 182	: Vg=1.054937 -> Vg=1.0
% INFO    : Gen at bus 196	: Pg=81.07, Qg=20.71 -> Pg=127.025, Qg=20.0
% INFO    : Gen at bus 196	: Vg=1.021915 -> Vg=1.0
% INFO    : Gen at bus 197	: Pg=245.73, Qg=1.48 -> Pg=300.0, Qg=60.0
% INFO    : Gen at bus 197	: Vg=1.005341 -> Vg=1.0
% INFO    : Gen at bus 207	: Pg=27.95, Qg=4.02 -> Pg=59.315, Qg=10.0
% INFO    : Gen at bus 207	: Vg=1.016461 -> Vg=1.0
% INFO    : Gen at bus 220	: Pg=97.72, Qg=38.87 -> Pg=132.575, Qg=20.0
% INFO    : Gen at bus 220	: Vg=1.055654 -> Vg=1.0
% INFO    : Gen at bus 221	: Pg=97.72, Qg=38.87 -> Pg=132.575, Qg=20.0
% INFO    : Gen at bus 221	: Vg=1.055654 -> Vg=1.0
% INFO    : Gen at bus 222	: Pg=97.66, Qg=41.74 -> Pg=132.555, Qg=20.0
% INFO    : Gen at bus 222	: Vg=1.051105 -> Vg=1.0
% INFO    : Gen at bus 223	: Pg=97.72, Qg=38.87 -> Pg=132.575, Qg=20.0
% INFO    : Gen at bus 223	: Vg=1.055654 -> Vg=1.0
% INFO    : Gen at bus 224	: Pg=97.66, Qg=41.74 -> Pg=132.555, Qg=20.0
% INFO    : Gen at bus 224	: Vg=1.051105 -> Vg=1.0
% INFO    : Gen at bus 225	: Pg=97.66, Qg=41.74 -> Pg=132.555, Qg=20.0
% INFO    : Gen at bus 225	: Vg=1.051105 -> Vg=1.0
% INFO    : Gen at bus 229	: Pg=21.03, Qg=9.77 -> Pg=57.01, Qg=10.0
% INFO    : Gen at bus 229	: Vg=1.034441 -> Vg=1.0
% INFO    : Gen at bus 241	: Pg=601.87, Qg=179.7 -> Pg=850.0, Qg=200.0
% INFO    : Gen at bus 241	: Vg=1.037622 -> Vg=1.0
% INFO    : Gen at bus 243	: Pg=32.43, Qg=17.87 -> Pg=60.81, Qg=10.0
% INFO    : Gen at bus 243	: Vg=1.053647 -> Vg=1.0
% INFO    : Gen at bus 248	: Pg=26.38, Qg=8.7 -> Pg=58.795, Qg=10.0
% INFO    : Gen at bus 248	: Vg=1.026279 -> Vg=1.0
% INFO    : Gen at bus 250	: Pg=192.55, Qg=1.87 -> Pg=250.0, Qg=60.0
% INFO    : Gen at bus 250	: Vg=1.012099 -> Vg=1.0
% INFO    : Gen at bus 258	: Pg=8.2, Qg=-2.56 -> Pg=52.735, Qg=0.0
% INFO    : Gen at bus 258	: Vg=0.955439 -> Vg=1.0
% INFO    : Gen at bus 259	: Pg=38.51, Qg=8.85 -> Pg=62.835, Qg=10.0
% INFO    : Gen at bus 259	: Vg=1.03425 -> Vg=1.0
% INFO    : Gen at bus 266	: Pg=28.48, Qg=6.95 -> Pg=59.495, Qg=10.0
% INFO    : Gen at bus 266	: Vg=1.005915 -> Vg=1.0
% INFO    : Gen at bus 270	: Pg=18.4, Qg=-1.01 -> Pg=56.135, Qg=0.0
% INFO    : Gen at bus 270	: Vg=1.003342 -> Vg=1.0
% INFO    : Gen at bus 271	: Pg=626.63, Qg=195.6 -> Pg=850.0, Qg=200.0
% INFO    : Gen at bus 271	: Vg=1.053159 -> Vg=1.0
% INFO    : Gen at bus 273	: Pg=626.63, Qg=190.1 -> Pg=850.0, Qg=200.0
% INFO    : Gen at bus 273	: Vg=1.051456 -> Vg=1.0
% INFO    : Gen at bus 274	: Pg=626.64, Qg=188.59 -> Pg=850.0, Qg=200.0
% INFO    : Gen at bus 274	: Vg=1.051088 -> Vg=1.0
% INFO    : Gen at bus 275	: Pg=626.64, Qg=188.59 -> Pg=850.0, Qg=200.0
% INFO    : Gen at bus 275	: Vg=1.051088 -> Vg=1.0
% INFO    : Gen at bus 276	: Pg=626.64, Qg=187.14 -> Pg=850.0, Qg=200.0
% INFO    : Gen at bus 276	: Vg=1.050379 -> Vg=1.0
% INFO    : Gen at bus 278	: Pg=627.0, Qg=28.92 -> Pg=850.0, Qg=65.0
% INFO    : Gen at bus 278	: Vg=0.960771 -> Vg=1.0
% INFO    : Gen at bus 283	: Pg=8.0, Qg=0.73 -> Pg=52.665, Qg=0.0
% INFO    : Gen at bus 283	: Vg=1.000621 -> Vg=1.0
% INFO    : Gen at bus 289	: Pg=36.9, Qg=11.76 -> Pg=62.3, Qg=10.0
% INFO    : Gen at bus 289	: Vg=1.040289 -> Vg=1.0
% INFO    : Gen at bus 294	: Pg=92.8, Qg=3.25 -> Pg=130.935, Qg=0.0
% INFO    : Gen at bus 294	: Vg=0.999187 -> Vg=1.0
% INFO    : Gen at bus 296	: Pg=21.0, Qg=0.7 -> Pg=57.0, Qg=0.0
% INFO    : Gen at bus 296	: Vg=0.989117 -> Vg=1.0
% INFO    : Gen at bus 299	: Pg=158.9, Qg=35.36 -> Pg=250.0, Qg=35.0
% INFO    : Gen at bus 299	: Vg=0.993468 -> Vg=1.0
% INFO    : Gen at bus 304	: Pg=39.98, Qg=8.7 -> Pg=63.325, Qg=10.0
% INFO    : Gen at bus 304	: Vg=1.037997 -> Vg=1.0
% INFO    : Gen at bus 305	: Pg=27.73, Qg=2.0 -> Pg=59.245, Qg=10.0
% INFO    : Gen at bus 305	: Vg=1.030407 -> Vg=1.0
% INFO    : Gen at bus 306	: Pg=27.73, Qg=2.0 -> Pg=59.245, Qg=10.0
% INFO    : Gen at bus 306	: Vg=1.030407 -> Vg=1.0
% INFO    : Gen at bus 307	: Pg=17.66, Qg=6.95 -> Pg=55.885, Qg=10.0
% INFO    : Gen at bus 307	: Vg=1.049321 -> Vg=1.0
% INFO    : Gen at bus 308	: Pg=17.66, Qg=6.95 -> Pg=55.885, Qg=10.0
% INFO    : Gen at bus 308	: Vg=1.049321 -> Vg=1.0
% INFO    : Gen at bus 309	: Pg=32.08, Qg=3.64 -> Pg=60.695, Qg=10.0
% INFO    : Gen at bus 309	: Vg=1.05655 -> Vg=1.0
% INFO    : Gen at bus 310	: Pg=32.08, Qg=3.64 -> Pg=60.695, Qg=10.0
% INFO    : Gen at bus 310	: Vg=1.05655 -> Vg=1.0
% INFO    : Gen at bus 311	: Pg=32.08, Qg=3.64 -> Pg=60.695, Qg=10.0
% INFO    : Gen at bus 311	: Vg=1.05655 -> Vg=1.0
% INFO    : Gen at bus 312	: Pg=32.08, Qg=3.64 -> Pg=60.695, Qg=10.0
% INFO    : Gen at bus 312	: Vg=1.05655 -> Vg=1.0
% INFO    : Gen at bus 315	: Pg=2.06, Qg=0.62 -> Pg=50.685, Qg=0.0
% INFO    : Gen at bus 315	: Vg=1.021202 -> Vg=1.0
% INFO    : Gen at bus 323	: Pg=419.13, Qg=110.83 -> Pg=550.0, Qg=200.0
% INFO    : Gen at bus 323	: Vg=1.016993 -> Vg=1.0
% INFO    : Gen at bus 324	: Pg=5.0, Qg=1.91 -> Pg=51.665, Qg=0.0
% INFO    : Gen at bus 324	: Vg=1.024179 -> Vg=1.0
% INFO    : Gen at bus 325	: Pg=4.8, Qg=-0.12 -> Pg=51.6, Qg=0.0
% INFO    : Gen at bus 325	: Vg=0.996355 -> Vg=1.0
% INFO    : Gen at bus 328	: Pg=54.54, Qg=27.56 -> Pg=118.18, Qg=15.0
% INFO    : Gen at bus 328	: Vg=1.023168 -> Vg=1.0
% INFO    : Gen at bus 331	: Pg=27.62, Qg=3.89 -> Pg=59.205, Qg=5.0
% INFO    : Gen at bus 331	: Vg=1.006233 -> Vg=1.0
% INFO    : Gen at bus 332	: Pg=2.0, Qg=-0.0 -> Pg=50.665, Qg=0.0
% INFO    : Gen at bus 332	: Vg=0.996766 -> Vg=1.0
% INFO    : Gen at bus 336	: Pg=16.08, Qg=0.01 -> Pg=55.36, Qg=0.0
% INFO    : Gen at bus 336	: Vg=1.010862 -> Vg=1.0
% INFO    : Gen at bus 338	: Pg=16.08, Qg=-0.17 -> Pg=55.36, Qg=0.0
% INFO    : Gen at bus 338	: Vg=1.00038 -> Vg=1.0
% INFO    : Gen at bus 345	: Pg=333.1, Qg=57.13 -> Pg=450.0, Qg=80.0
% INFO    : Gen at bus 345	: Vg=1.030395 -> Vg=1.0
% INFO    : Gen at bus 346	: Pg=333.1, Qg=57.13 -> Pg=450.0, Qg=80.0
% INFO    : Gen at bus 346	: Vg=1.030395 -> Vg=1.0
% INFO    : Gen at bus 351	: Pg=167.59, Qg=39.08 -> Pg=250.0, Qg=80.0
% INFO    : Gen at bus 351	: Vg=1.024484 -> Vg=1.0
% INFO    : Gen at bus 354	: Pg=36.42, Qg=7.96 -> Pg=62.14, Qg=10.0
% INFO    : Gen at bus 354	: Vg=1.029166 -> Vg=1.0
% INFO    : Gen at bus 358	: Pg=165.24, Qg=104.62 -> Pg=250.0, Qg=80.0
% INFO    : Gen at bus 358	: Vg=1.050725 -> Vg=1.0
% INFO    : Gen at bus 360	: Pg=84.12, Qg=16.88 -> Pg=128.04, Qg=20.0
% INFO    : Gen at bus 360	: Vg=1.028641 -> Vg=1.0
% INFO    : Gen at bus 361	: Pg=84.12, Qg=16.88 -> Pg=128.04, Qg=20.0
% INFO    : Gen at bus 361	: Vg=1.028641 -> Vg=1.0
% INFO    : Gen at bus 362	: Pg=84.12, Qg=16.88 -> Pg=128.04, Qg=20.0
% INFO    : Gen at bus 362	: Vg=1.028641 -> Vg=1.0
% INFO    : Gen at bus 363	: Pg=84.12, Qg=16.88 -> Pg=128.04, Qg=20.0
% INFO    : Gen at bus 363	: Vg=1.028641 -> Vg=1.0
% INFO    : Gen at bus 364	: Pg=5.25, Qg=0.21 -> Pg=51.75, Qg=0.0
% INFO    : Gen at bus 364	: Vg=1.00564 -> Vg=1.0
% INFO    : Gen at bus 365	: Pg=95.2, Qg=36.17 -> Pg=131.735, Qg=40.0
% INFO    : Gen at bus 365	: Vg=0.997585 -> Vg=1.0
% INFO    : Gen at bus 368	: Pg=84.12, Qg=16.88 -> Pg=128.04, Qg=20.0
% INFO    : Gen at bus 368	: Vg=1.028641 -> Vg=1.0
% INFO    : Gen at bus 369	: Pg=84.12, Qg=16.88 -> Pg=128.04, Qg=20.0
% INFO    : Gen at bus 369	: Vg=1.028641 -> Vg=1.0
% INFO    : Gen at bus 382	: Pg=102.03, Qg=10.64 -> Pg=184.01, Qg=20.0
% INFO    : Gen at bus 382	: Vg=0.990596 -> Vg=1.0
% INFO    : Gen at bus 383	: Pg=102.24, Qg=30.32 -> Pg=184.08, Qg=20.0
% INFO    : Gen at bus 383	: Vg=1.012482 -> Vg=1.0
% INFO    : Gen at bus 392	: Pg=1.03, Qg=0.09 -> Pg=50.345, Qg=0.0
% INFO    : Gen at bus 392	: Vg=1.030636 -> Vg=1.0
% INFO    : Gen at bus 394	: Pg=37.9, Qg=13.47 -> Pg=62.635, Qg=10.0
% INFO    : Gen at bus 394	: Vg=1.0326 -> Vg=1.0
% INFO    : Gen at bus 395	: Pg=37.23, Qg=4.01 -> Pg=62.41, Qg=10.0
% INFO    : Gen at bus 395	: Vg=1.028283 -> Vg=1.0
% INFO    : Gen at bus 396	: Pg=85.28, Qg=21.31 -> Pg=128.425, Qg=20.0
% INFO    : Gen at bus 396	: Vg=1.029542 -> Vg=1.0
% INFO    : Gen at bus 400	: Pg=94.5, Qg=8.92 -> Pg=131.5, Qg=5.0
% INFO    : Gen at bus 400	: Vg=0.979015 -> Vg=1.0
% INFO    : Gen at bus 405	: Pg=33.64, Qg=6.9 -> Pg=61.215, Qg=10.0
% INFO    : Gen at bus 405	: Vg=1.00773 -> Vg=1.0
% INFO    : Gen at bus 406	: Pg=33.64, Qg=6.9 -> Pg=61.215, Qg=10.0
% INFO    : Gen at bus 406	: Vg=1.00773 -> Vg=1.0
% INFO    : Gen at bus 408	: Pg=34.92, Qg=9.74 -> Pg=61.64, Qg=10.0
% INFO    : Gen at bus 408	: Vg=1.043492 -> Vg=1.0
% INFO    : Gen at bus 423	: Pg=0.99, Qg=-0.05 -> Pg=50.33, Qg=0.0
% INFO    : Gen at bus 423	: Vg=1.015919 -> Vg=1.0
% INFO    : Gen at bus 432	: Pg=4.5, Qg=0.47 -> Pg=51.5, Qg=0.0
% INFO    : Gen at bus 432	: Vg=1.016602 -> Vg=1.0
% INFO    : Gen at bus 433	: Pg=30.04, Qg=7.71 -> Pg=60.015, Qg=10.0
% INFO    : Gen at bus 433	: Vg=1.011489 -> Vg=1.0
% INFO    : Gen at bus 438	: Pg=18.13, Qg=3.85 -> Pg=56.045, Qg=10.0
% INFO    : Gen at bus 438	: Vg=1.016716 -> Vg=1.0
% INFO    : Gen at bus 442	: Pg=31.35, Qg=11.33 -> Pg=60.45, Qg=10.0
% INFO    : Gen at bus 442	: Vg=1.043357 -> Vg=1.0
% INFO    : Gen at bus 448	: Pg=25.22, Qg=6.35 -> Pg=58.405, Qg=5.0
% INFO    : Gen at bus 448	: Vg=1.038795 -> Vg=1.0
% INFO    : Gen at bus 454	: Pg=8.35, Qg=-1.53 -> Pg=52.785, Qg=0.0
% INFO    : Gen at bus 454	: Vg=0.973833 -> Vg=1.0
% INFO    : Gen at bus 458	: Pg=31.28, Qg=-0.92 -> Pg=60.425, Qg=10.0
% INFO    : Gen at bus 458	: Vg=1.009892 -> Vg=1.0
% INFO    : Gen at bus 463	: Pg=-19.98, Qg=270.34 -> Pg=36.68, Qg=0.0
% INFO    : Gen at bus 463	: Vg=1.126642 -> Vg=1.0
% INFO    : Gen at bus 470	: Pg=74.8, Qg=42.23 -> Pg=124.935, Qg=20.0
% INFO    : Gen at bus 470	: Vg=1.046905 -> Vg=1.0
% INFO    : Gen at bus 476	: Pg=214.05, Qg=76.67 -> Pg=300.0, Qg=80.0
% INFO    : Gen at bus 476	: Vg=1.029484 -> Vg=1.0
% INFO    : Gen at bus 477	: Pg=38.02, Qg=11.21 -> Pg=62.675, Qg=10.0
% INFO    : Gen at bus 477	: Vg=1.043087 -> Vg=1.0
% INFO    : Gen at bus 480	: Pg=89.2, Qg=18.25 -> Pg=129.735, Qg=20.0
% INFO    : Gen at bus 480	: Vg=1.033425 -> Vg=1.0
% INFO    : Gen at bus 481	: Pg=89.2, Qg=18.25 -> Pg=129.735, Qg=20.0
% INFO    : Gen at bus 481	: Vg=1.033425 -> Vg=1.0
% INFO    : Gen at bus 482	: Pg=89.2, Qg=18.25 -> Pg=129.735, Qg=20.0
% INFO    : Gen at bus 482	: Vg=1.033425 -> Vg=1.0
% INFO    : Gen at bus 483	: Pg=89.2, Qg=18.25 -> Pg=129.735, Qg=20.0
% INFO    : Gen at bus 483	: Vg=1.033425 -> Vg=1.0
% INFO    : Gen at bus 485	: Pg=325.03, Qg=139.06 -> Pg=450.0, Qg=80.0
% INFO    : Gen at bus 485	: Vg=1.059619 -> Vg=1.0
% INFO    : Gen at bus 492	: Pg=273.28, Qg=112.89 -> Pg=350.0, Qg=80.0
% INFO    : Gen at bus 492	: Vg=1.041985 -> Vg=1.0
% INFO    : Gen at bus 496	: Pg=64.28, Qg=29.97 -> Pg=121.425, Qg=20.0
% INFO    : Gen at bus 496	: Vg=1.00876 -> Vg=1.0
% INFO    : Gen at bus 508	: Pg=857.64, Qg=276.43 -> Pg=1150.0, Qg=200.0
% INFO    : Gen at bus 508	: Vg=1.044776 -> Vg=1.0
% INFO    : Gen at bus 509	: Pg=857.69, Qg=282.91 -> Pg=1150.0, Qg=200.0
% INFO    : Gen at bus 509	: Vg=1.044388 -> Vg=1.0
% INFO    : Gen at bus 510	: Pg=857.66, Qg=271.49 -> Pg=1150.0, Qg=200.0
% INFO    : Gen at bus 510	: Vg=1.044096 -> Vg=1.0
% INFO    : Gen at bus 514	: Pg=857.64, Qg=273.87 -> Pg=1150.0, Qg=200.0
% INFO    : Gen at bus 514	: Vg=1.044511 -> Vg=1.0
% INFO    : Gen at bus 516	: Pg=32.57, Qg=7.29 -> Pg=60.855, Qg=10.0
% INFO    : Gen at bus 516	: Vg=1.041748 -> Vg=1.0
% INFO    : Gen at bus 528	: Pg=23.66, Qg=2.76 -> Pg=57.885, Qg=10.0
% INFO    : Gen at bus 528	: Vg=1.020703 -> Vg=1.0
% INFO    : Gen at bus 531	: Pg=38.79, Qg=7.11 -> Pg=62.93, Qg=10.0
% INFO    : Gen at bus 531	: Vg=1.035838 -> Vg=1.0
% INFO    : Gen at bus 532	: Pg=258.95, Qg=65.97 -> Pg=350.0, Qg=80.0
% INFO    : Gen at bus 532	: Vg=1.036699 -> Vg=1.0
% INFO    : Gen at bus 533	: Pg=164.92, Qg=6.68 -> Pg=250.0, Qg=60.0
% INFO    : Gen at bus 533	: Vg=1.016377 -> Vg=1.0
% INFO    : Gen at bus 539	: Pg=152.0, Qg=33.4 -> Pg=250.0, Qg=25.0
% INFO    : Gen at bus 539	: Vg=0.993492 -> Vg=1.0
% INFO    : Gen at bus 552	: Pg=30.6, Qg=-1.46 -> Pg=60.2, Qg=0.0
% INFO    : Gen at bus 552	: Vg=0.99834 -> Vg=1.0
% INFO    : Gen at bus 559	: Pg=51.5, Qg=-7.54 -> Pg=117.165, Qg=0.0
% INFO    : Gen at bus 559	: Vg=0.954584 -> Vg=1.0
% INFO    : Gen at bus 564	: Pg=21.77, Qg=6.35 -> Pg=57.255, Qg=10.0
% INFO    : Gen at bus 564	: Vg=1.024499 -> Vg=1.0
% INFO    : Gen at bus 572	: Pg=7.0, Qg=0.9 -> Pg=52.335, Qg=0.0
% INFO    : Gen at bus 572	: Vg=1.004314 -> Vg=1.0
% INFO    : Gen at bus 575	: Pg=18.09, Qg=1.85 -> Pg=56.03, Qg=10.0
% INFO    : Gen at bus 575	: Vg=1.016739 -> Vg=1.0
% INFO    : Gen at bus 576	: Pg=18.09, Qg=1.85 -> Pg=56.03, Qg=10.0
% INFO    : Gen at bus 576	: Vg=1.016739 -> Vg=1.0
% INFO    : Gen at bus 577	: Pg=18.09, Qg=1.85 -> Pg=56.03, Qg=10.0
% INFO    : Gen at bus 577	: Vg=1.016739 -> Vg=1.0
% INFO    : Gen at bus 581	: Pg=18.09, Qg=1.85 -> Pg=56.03, Qg=10.0
% INFO    : Gen at bus 581	: Vg=1.016739 -> Vg=1.0
% INFO    : Gen at bus 585	: Pg=72.61, Qg=29.56 -> Pg=124.205, Qg=20.0
% INFO    : Gen at bus 585	: Vg=1.041629 -> Vg=1.0
% INFO    : Gen at bus 589	: Pg=13.38, Qg=0.68 -> Pg=54.46, Qg=0.0
% INFO    : Gen at bus 589	: Vg=1.00755 -> Vg=1.0
% INFO    : Gen at bus 610	: Pg=31.95, Qg=15.26 -> Pg=60.65, Qg=10.0
% INFO    : Gen at bus 610	: Vg=1.019723 -> Vg=1.0
% INFO    : Gen at bus 614	: Pg=34.81, Qg=16.31 -> Pg=61.605, Qg=15.0
% INFO    : Gen at bus 614	: Vg=1.031902 -> Vg=1.0
% INFO    : Gen at bus 615	: Pg=34.81, Qg=16.31 -> Pg=61.605, Qg=15.0
% INFO    : Gen at bus 615	: Vg=1.031902 -> Vg=1.0
% INFO    : Gen at bus 619	: Pg=42.5, Qg=5.74 -> Pg=64.165, Qg=15.0
% INFO    : Gen at bus 619	: Vg=1.031502 -> Vg=1.0
% INFO    : Gen at bus 621	: Pg=5.8, Qg=-0.78 -> Pg=51.935, Qg=0.0
% INFO    : Gen at bus 621	: Vg=1.003942 -> Vg=1.0
% INFO    : Gen at bus 623	: Pg=36.03, Qg=16.08 -> Pg=62.01, Qg=10.0
% INFO    : Gen at bus 623	: Vg=1.045359 -> Vg=1.0
% INFO    : Gen at bus 626	: Pg=43.29, Qg=23.54 -> Pg=64.43, Qg=20.0
% INFO    : Gen at bus 626	: Vg=1.035771 -> Vg=1.0
% INFO    : Gen at bus 635	: Pg=0.13, Qg=-0.1 -> Pg=50.045, Qg=0.0
% INFO    : Gen at bus 635	: Vg=1.023511 -> Vg=1.0
% INFO    : Gen at bus 637	: Pg=25.22, Qg=5.17 -> Pg=58.405, Qg=10.0
% INFO    : Gen at bus 637	: Vg=1.04616 -> Vg=1.0
% INFO    : Gen at bus 646	: Pg=333.1, Qg=57.13 -> Pg=450.0, Qg=80.0
% INFO    : Gen at bus 646	: Vg=1.030395 -> Vg=1.0
% INFO    : Gen at bus 648	: Pg=322.05, Qg=10.4 -> Pg=450.0, Qg=80.0
% INFO    : Gen at bus 648	: Vg=1.007781 -> Vg=1.0
% INFO    : Gen at bus 649	: Pg=333.1, Qg=57.13 -> Pg=450.0, Qg=80.0
% INFO    : Gen at bus 649	: Vg=1.030395 -> Vg=1.0
% INFO    : Gen at bus 651	: Pg=188.27, Qg=-7.75 -> Pg=250.0, Qg=80.0
% INFO    : Gen at bus 651	: Vg=1.028351 -> Vg=1.0
% INFO    : Gen at bus 652	: Pg=188.27, Qg=-7.75 -> Pg=250.0, Qg=80.0
% INFO    : Gen at bus 652	: Vg=1.028351 -> Vg=1.0
% INFO    : Gen at bus 654	: Pg=92.4, Qg=2.72 -> Pg=130.8, Qg=20.0
% INFO    : Gen at bus 654	: Vg=1.014507 -> Vg=1.0
% INFO    : Gen at bus 660	: Pg=33.21, Qg=5.47 -> Pg=61.07, Qg=10.0
% INFO    : Gen at bus 660	: Vg=1.022689 -> Vg=1.0
% INFO    : Gen at bus 666	: Pg=31.3, Qg=-0.77 -> Pg=60.435, Qg=10.0
% INFO    : Gen at bus 666	: Vg=1.018739 -> Vg=1.0
% INFO    : Gen at bus 671	: Pg=25.2, Qg=-0.32 -> Pg=58.4, Qg=5.0
% INFO    : Gen at bus 671	: Vg=0.999061 -> Vg=1.0
% INFO    : Gen at bus 676	: Pg=274.65, Qg=30.64 -> Pg=350.0, Qg=60.0
% INFO    : Gen at bus 676	: Vg=1.018066 -> Vg=1.0
% INFO    : Gen at bus 681	: Pg=84.68, Qg=7.94 -> Pg=128.225, Qg=20.0
% INFO    : Gen at bus 681	: Vg=1.00657 -> Vg=1.0
% INFO    : Gen at bus 684	: Pg=68.89, Qg=19.23 -> Pg=122.965, Qg=20.0
% INFO    : Gen at bus 684	: Vg=1.035618 -> Vg=1.0
% INFO    : Gen at bus 693	: Pg=209.96, Qg=80.03 -> Pg=300.0, Qg=60.0
% INFO    : Gen at bus 693	: Vg=1.038999 -> Vg=1.0
% INFO    : Gen at bus 695	: Pg=8.4, Qg=-0.84 -> Pg=52.8, Qg=0.0
% INFO    : Gen at bus 695	: Vg=1.010516 -> Vg=1.0
% INFO    : Gen at bus 698	: Pg=26.72, Qg=4.41 -> Pg=58.905, Qg=5.0
% INFO    : Gen at bus 698	: Vg=1.018527 -> Vg=1.0
% INFO    : Gen at bus 709	: Pg=626.68, Qg=236.63 -> Pg=850.0, Qg=200.0
% INFO    : Gen at bus 709	: Vg=1.051727 -> Vg=1.0
% INFO    : Gen at bus 715	: Pg=23.9, Qg=3.61 -> Pg=57.965, Qg=10.0
% INFO    : Gen at bus 715	: Vg=1.007844 -> Vg=1.0
% INFO    : Gen at bus 717	: Pg=23.12, Qg=5.58 -> Pg=57.705, Qg=5.0
% INFO    : Gen at bus 717	: Vg=1.027572 -> Vg=1.0
% INFO    : Gen at bus 721	: Pg=74.35, Qg=10.28 -> Pg=124.785, Qg=20.0
% INFO    : Gen at bus 721	: Vg=0.992442 -> Vg=1.0
% INFO    : Gen at bus 724	: Pg=35.5, Qg=10.89 -> Pg=61.835, Qg=10.0
% INFO    : Gen at bus 724	: Vg=1.045213 -> Vg=1.0
% INFO    : Gen at bus 730	: Pg=98.46, Qg=12.34 -> Pg=132.82, Qg=20.0
% INFO    : Gen at bus 730	: Vg=1.01458 -> Vg=1.0
% INFO    : Gen at bus 731	: Pg=98.46, Qg=12.34 -> Pg=132.82, Qg=20.0
% INFO    : Gen at bus 731	: Vg=1.01458 -> Vg=1.0
% INFO    : Gen at bus 732	: Pg=98.46, Qg=12.34 -> Pg=132.82, Qg=20.0
% INFO    : Gen at bus 732	: Vg=1.01458 -> Vg=1.0
% INFO    : Gen at bus 734	: Pg=98.46, Qg=12.34 -> Pg=132.82, Qg=20.0
% INFO    : Gen at bus 734	: Vg=1.01458 -> Vg=1.0
% INFO    : Gen at bus 746	: Pg=16.0, Qg=0.19 -> Pg=55.335, Qg=0.0
% INFO    : Gen at bus 746	: Vg=0.994194 -> Vg=1.0
% INFO    : Gen at bus 749	: Pg=22.58, Qg=9.34 -> Pg=57.525, Qg=10.0
% INFO    : Gen at bus 749	: Vg=1.009791 -> Vg=1.0
% INFO    : Gen at bus 750	: Pg=22.58, Qg=9.34 -> Pg=57.525, Qg=10.0
% INFO    : Gen at bus 750	: Vg=1.009791 -> Vg=1.0
% INFO    : Gen at bus 751	: Pg=22.58, Qg=9.34 -> Pg=57.525, Qg=10.0
% INFO    : Gen at bus 751	: Vg=1.009791 -> Vg=1.0
% INFO    : Gen at bus 753	: Pg=20.64, Qg=7.21 -> Pg=56.88, Qg=10.0
% INFO    : Gen at bus 753	: Vg=1.018866 -> Vg=1.0
% INFO    : Gen at bus 754	: Pg=64.65, Qg=13.16 -> Pg=121.55, Qg=20.0
% INFO    : Gen at bus 754	: Vg=1.009683 -> Vg=1.0
% INFO    : Gen at bus 765	: Pg=78.37, Qg=30.34 -> Pg=126.125, Qg=20.0
% INFO    : Gen at bus 765	: Vg=1.032985 -> Vg=1.0
% INFO    : Gen at bus 768	: Pg=46.74, Qg=7.22 -> Pg=65.58, Qg=10.0
% INFO    : Gen at bus 768	: Vg=1.044527 -> Vg=1.0
% INFO    : Gen at bus 769	: Pg=46.74, Qg=7.22 -> Pg=65.58, Qg=10.0
% INFO    : Gen at bus 769	: Vg=1.044527 -> Vg=1.0
% INFO    : Gen at bus 773	: Pg=30.13, Qg=8.92 -> Pg=60.045, Qg=10.0
% INFO    : Gen at bus 773	: Vg=1.016081 -> Vg=1.0
% INFO    : Gen at bus 775	: Pg=26.34, Qg=0.75 -> Pg=58.78, Qg=5.0
% INFO    : Gen at bus 775	: Vg=1.003456 -> Vg=1.0
% INFO    : Gen at bus 778	: Pg=18.74, Qg=6.56 -> Pg=56.245, Qg=10.0
% INFO    : Gen at bus 778	: Vg=1.02868 -> Vg=1.0
% INFO    : Gen at bus 779	: Pg=21.6, Qg=0.33 -> Pg=57.2, Qg=0.0
% INFO    : Gen at bus 779	: Vg=0.9829 -> Vg=1.0
% INFO    : Gen at bus 783	: Pg=16.28, Qg=8.5 -> Pg=55.425, Qg=10.0
% INFO    : Gen at bus 783	: Vg=1.027518 -> Vg=1.0
% INFO    : Gen at bus 786	: Pg=31.29, Qg=-0.48 -> Pg=60.43, Qg=0.0
% INFO    : Gen at bus 786	: Vg=1.013792 -> Vg=1.0
% INFO    : Gen at bus 798	: Pg=30.9, Qg=1.92 -> Pg=60.3, Qg=10.0
% INFO    : Gen at bus 798	: Vg=1.015954 -> Vg=1.0
% INFO    : Gen at bus 800	: Pg=612.01, Qg=227.35 -> Pg=850.0, Qg=200.0
% INFO    : Gen at bus 800	: Vg=1.040587 -> Vg=1.0
% INFO    : Gen at bus 809	: Pg=31.3, Qg=3.8 -> Pg=60.435, Qg=5.0
% INFO    : Gen at bus 809	: Vg=1.023128 -> Vg=1.0
% INFO    : Gen at bus 811	: Pg=31.72, Qg=4.48 -> Pg=60.575, Qg=10.0
% INFO    : Gen at bus 811	: Vg=1.022192 -> Vg=1.0
% INFO    : Gen at bus 814	: Pg=951.82, Qg=32.74 -> Pg=1300.0, Qg=200.0
% INFO    : Gen at bus 814	: Vg=1.01249 -> Vg=1.0
% INFO    : Gen at bus 815	: Pg=92.69, Qg=14.48 -> Pg=130.895, Qg=20.0
% INFO    : Gen at bus 815	: Vg=1.026207 -> Vg=1.0
% INFO    : Gen at bus 819	: Pg=219.68, Qg=138.48 -> Pg=300.0, Qg=60.0
% INFO    : Gen at bus 819	: Vg=1.048632 -> Vg=1.0
% INFO    : Gen at bus 824	: Pg=31.3, Qg=-0.77 -> Pg=60.435, Qg=10.0
% INFO    : Gen at bus 824	: Vg=1.018739 -> Vg=1.0
% INFO    : Gen at bus 828	: Pg=224.42, Qg=24.73 -> Pg=300.0, Qg=80.0
% INFO    : Gen at bus 828	: Vg=1.01121 -> Vg=1.0
% INFO    : Gen at bus 836	: Pg=19.15, Qg=4.15 -> Pg=56.385, Qg=5.0
% INFO    : Gen at bus 836	: Vg=1.015461 -> Vg=1.0
% INFO    : Gen at bus 839	: Pg=7.54, Qg=0.74 -> Pg=52.515, Qg=0.0
% INFO    : Gen at bus 839	: Vg=1.0079 -> Vg=1.0
% INFO    : Gen at bus 841	: Pg=96.03, Qg=17.22 -> Pg=132.01, Qg=20.0
% INFO    : Gen at bus 841	: Vg=1.036065 -> Vg=1.0
% INFO    : Gen at bus 844	: Pg=59.02, Qg=10.61 -> Pg=119.675, Qg=15.0
% INFO    : Gen at bus 844	: Vg=1.059427 -> Vg=1.0
% INFO    : Gen at bus 845	: Pg=59.02, Qg=10.61 -> Pg=119.675, Qg=15.0
% INFO    : Gen at bus 845	: Vg=1.059427 -> Vg=1.0
% INFO    : Gen at bus 846	: Pg=59.02, Qg=10.61 -> Pg=119.675, Qg=15.0
% INFO    : Gen at bus 846	: Vg=1.059427 -> Vg=1.0
% INFO    : Gen at bus 849	: Pg=68.26, Qg=9.75 -> Pg=122.755, Qg=20.0
% INFO    : Gen at bus 849	: Vg=1.028153 -> Vg=1.0
% INFO    : Gen at bus 855	: Pg=39.67, Qg=13.3 -> Pg=63.225, Qg=10.0
% INFO    : Gen at bus 855	: Vg=1.046298 -> Vg=1.0
% INFO    : Gen at bus 858	: Pg=257.94, Qg=36.73 -> Pg=350.0, Qg=60.0
% INFO    : Gen at bus 858	: Vg=1.021858 -> Vg=1.0
% INFO    : Gen at bus 859	: Pg=36.91, Qg=13.33 -> Pg=62.305, Qg=10.0
% INFO    : Gen at bus 859	: Vg=1.037973 -> Vg=1.0
% INFO    : Gen at bus 861	: Pg=30.28, Qg=3.51 -> Pg=60.095, Qg=10.0
% INFO    : Gen at bus 861	: Vg=1.018125 -> Vg=1.0
% INFO    : Gen at bus 862	: Pg=30.28, Qg=3.51 -> Pg=60.095, Qg=10.0
% INFO    : Gen at bus 862	: Vg=1.018125 -> Vg=1.0
% INFO    : Gen at bus 864	: Pg=30.28, Qg=3.51 -> Pg=60.095, Qg=10.0
% INFO    : Gen at bus 864	: Vg=1.018125 -> Vg=1.0
% INFO    : Gen at bus 865	: Pg=30.28, Qg=3.51 -> Pg=60.095, Qg=10.0
% INFO    : Gen at bus 865	: Vg=1.018125 -> Vg=1.0
% INFO    : Gen at bus 869	: Pg=37.9, Qg=13.47 -> Pg=62.635, Qg=10.0
% INFO    : Gen at bus 869	: Vg=1.0326 -> Vg=1.0
% INFO    : Gen at bus 873	: Pg=37.97, Qg=8.2 -> Pg=62.655, Qg=15.0
% INFO    : Gen at bus 873	: Vg=0.994173 -> Vg=1.0
% INFO    : Gen at bus 874	: Pg=40.23, Qg=5.24 -> Pg=63.41, Qg=10.0
% INFO    : Gen at bus 874	: Vg=1.006137 -> Vg=1.0
% INFO    : Gen at bus 888	: Pg=38.16, Qg=4.12 -> Pg=62.72, Qg=10.0
% INFO    : Gen at bus 888	: Vg=1.055337 -> Vg=1.0
% INFO    : Gen at bus 898	: Pg=35.97, Qg=5.34 -> Pg=61.99, Qg=10.0
% INFO    : Gen at bus 898	: Vg=1.058434 -> Vg=1.0
% INFO    : Gen at bus 901	: Pg=84.68, Qg=7.94 -> Pg=128.225, Qg=20.0
% INFO    : Gen at bus 901	: Vg=1.00657 -> Vg=1.0
% INFO    : Gen at bus 904	: Pg=32.52, Qg=9.41 -> Pg=60.84, Qg=10.0
% INFO    : Gen at bus 904	: Vg=1.028707 -> Vg=1.0
% INFO    : Gen at bus 907	: Pg=32.52, Qg=9.41 -> Pg=60.84, Qg=10.0
% INFO    : Gen at bus 907	: Vg=1.028707 -> Vg=1.0
% INFO    : Gen at bus 910	: Pg=88.32, Qg=56.36 -> Pg=129.44, Qg=20.0
% INFO    : Gen at bus 910	: Vg=1.127961 -> Vg=1.0
% INFO    : Gen at bus 912	: Pg=43.17, Qg=6.95 -> Pg=64.39, Qg=10.0
% INFO    : Gen at bus 912	: Vg=1.015029 -> Vg=1.0
% INFO    : Gen at bus 916	: Pg=159.8, Qg=-8.66 -> Pg=250.0, Qg=30.0
% INFO    : Gen at bus 916	: Vg=0.957523 -> Vg=1.0
% INFO    : Gen at bus 920	: Pg=43.17, Qg=6.95 -> Pg=64.39, Qg=10.0
% INFO    : Gen at bus 920	: Vg=1.015029 -> Vg=1.0
% INFO    : Gen at bus 921	: Pg=274.65, Qg=30.64 -> Pg=350.0, Qg=60.0
% INFO    : Gen at bus 921	: Vg=1.018066 -> Vg=1.0
% INFO    : Gen at bus 925	: Pg=266.84, Qg=38.78 -> Pg=350.0, Qg=80.0
% INFO    : Gen at bus 925	: Vg=1.032265 -> Vg=1.0
% INFO    : Gen at bus 926	: Pg=245.73, Qg=1.48 -> Pg=300.0, Qg=60.0
% INFO    : Gen at bus 926	: Vg=1.005341 -> Vg=1.0
% INFO    : Gen at bus 927	: Pg=43.5, Qg=1.21 -> Pg=64.5, Qg=0.0
% INFO    : Gen at bus 927	: Vg=1.007757 -> Vg=1.0
% INFO    : Gen at bus 930	: Pg=43.17, Qg=6.95 -> Pg=64.39, Qg=10.0
% INFO    : Gen at bus 930	: Vg=1.015029 -> Vg=1.0
% INFO    : Gen at bus 932	: Pg=19.57, Qg=7.03 -> Pg=56.525, Qg=10.0
% INFO    : Gen at bus 932	: Vg=1.023156 -> Vg=1.0
% INFO    : Gen at bus 937	: Pg=24.63, Qg=12.17 -> Pg=58.21, Qg=10.0
% INFO    : Gen at bus 937	: Vg=1.026822 -> Vg=1.0
% INFO    : Gen at bus 938	: Pg=28.83, Qg=4.62 -> Pg=59.61, Qg=10.0
% INFO    : Gen at bus 938	: Vg=1.019144 -> Vg=1.0
% INFO    : Gen at bus 954	: Pg=60.3, Qg=-12.67 -> Pg=120.1, Qg=0.0
% INFO    : Gen at bus 954	: Vg=0.961175 -> Vg=1.0
% INFO    : Gen at bus 956	: Pg=20.94, Qg=5.59 -> Pg=56.98, Qg=10.0
% INFO    : Gen at bus 956	: Vg=1.044097 -> Vg=1.0
% INFO    : Gen at bus 958	: Pg=31.5, Qg=1.72 -> Pg=60.5, Qg=5.0
% INFO    : Gen at bus 958	: Vg=1.016735 -> Vg=1.0
% INFO    : Gen at bus 975	: Pg=16.74, Qg=3.04 -> Pg=55.58, Qg=10.0
% INFO    : Gen at bus 975	: Vg=1.042545 -> Vg=1.0
% INFO    : Gen at bus 976	: Pg=16.62, Qg=7.24 -> Pg=55.54, Qg=10.0
% INFO    : Gen at bus 976	: Vg=1.070058 -> Vg=1.0
% INFO    : Gen at bus 977	: Pg=16.62, Qg=7.24 -> Pg=55.54, Qg=10.0
% INFO    : Gen at bus 977	: Vg=1.070058 -> Vg=1.0
% INFO    : Gen at bus 978	: Pg=16.62, Qg=7.24 -> Pg=55.54, Qg=10.0
% INFO    : Gen at bus 978	: Vg=1.070058 -> Vg=1.0
% INFO    : Gen at bus 980	: Pg=30.87, Qg=9.69 -> Pg=60.29, Qg=10.0
% INFO    : Gen at bus 980	: Vg=1.023796 -> Vg=1.0
% INFO    : Gen at bus 981	: Pg=38.33, Qg=9.23 -> Pg=62.775, Qg=10.0
% INFO    : Gen at bus 981	: Vg=1.018701 -> Vg=1.0
% INFO    : Gen at bus 982	: Pg=38.33, Qg=9.23 -> Pg=62.775, Qg=10.0
% INFO    : Gen at bus 982	: Vg=1.018701 -> Vg=1.0
% INFO    : Gen at bus 983	: Pg=38.33, Qg=9.23 -> Pg=62.775, Qg=10.0
% INFO    : Gen at bus 983	: Vg=1.018701 -> Vg=1.0
% INFO    : Gen at bus 984	: Pg=19.0, Qg=4.14 -> Pg=56.335, Qg=10.0
% INFO    : Gen at bus 984	: Vg=1.050192 -> Vg=1.0
% INFO    : Gen at bus 985	: Pg=19.0, Qg=4.14 -> Pg=56.335, Qg=10.0
% INFO    : Gen at bus 985	: Vg=1.050192 -> Vg=1.0
% INFO    : Gen at bus 986	: Pg=19.0, Qg=4.14 -> Pg=56.335, Qg=10.0
% INFO    : Gen at bus 986	: Vg=1.050192 -> Vg=1.0
% INFO    : Gen at bus 987	: Pg=19.0, Qg=4.14 -> Pg=56.335, Qg=10.0
% INFO    : Gen at bus 987	: Vg=1.050192 -> Vg=1.0
% INFO    : Gen at bus 995	: Pg=37.23, Qg=4.01 -> Pg=62.41, Qg=10.0
% INFO    : Gen at bus 995	: Vg=1.028283 -> Vg=1.0
% INFO    : Gen at bus 1002	: Pg=223.3, Qg=11.76 -> Pg=300.0, Qg=60.0
% INFO    : Gen at bus 1002	: Vg=1.026117 -> Vg=1.0
% INFO    : Gen at bus 1004	: Pg=4.2, Qg=1.44 -> Pg=51.4, Qg=0.0
% INFO    : Gen at bus 1004	: Vg=1.020732 -> Vg=1.0
% INFO    : Gen at bus 1007	: Pg=15.0, Qg=2.18 -> Pg=55.0, Qg=0.0
% INFO    : Gen at bus 1007	: Vg=1.009902 -> Vg=1.0
% INFO    : Gen at bus 1010	: Pg=86.25, Qg=-3.04 -> Pg=128.75, Qg=-10.0
% INFO    : Gen at bus 1010	: Vg=0.962614 -> Vg=1.0
% INFO    : Gen at bus 1013	: Pg=35.97, Qg=9.16 -> Pg=61.99, Qg=10.0
% INFO    : Gen at bus 1013	: Vg=1.001252 -> Vg=1.0
% INFO    : Gen at bus 1031	: Pg=89.66, Qg=46.76 -> Pg=129.885, Qg=20.0
% INFO    : Gen at bus 1031	: Vg=1.050891 -> Vg=1.0
% INFO    : Gen at bus 1043	: Pg=50.92, Qg=11.1 -> Pg=116.975, Qg=15.0
% INFO    : Gen at bus 1043	: Vg=1.010998 -> Vg=1.0
% INFO    : Gen at bus 1044	: Pg=5.25, Qg=0.74 -> Pg=51.75, Qg=0.0
% INFO    : Gen at bus 1044	: Vg=1.019396 -> Vg=1.0
% INFO    : Gen at bus 1046	: Pg=8.54, Qg=0.6 -> Pg=52.845, Qg=0.0
% INFO    : Gen at bus 1046	: Vg=1.014635 -> Vg=1.0
% INFO    : Gen at bus 1048	: Pg=0.34, Qg=-0.09 -> Pg=50.115, Qg=0.0
% INFO    : Gen at bus 1048	: Vg=1.024095 -> Vg=1.0
% INFO    : Gen at bus 1050	: Pg=348.55, Qg=140.56 -> Pg=450.0, Qg=80.0
% INFO    : Gen at bus 1050	: Vg=1.048227 -> Vg=1.0
% INFO    : Gen at bus 1055	: Pg=34.92, Qg=9.74 -> Pg=61.64, Qg=10.0
% INFO    : Gen at bus 1055	: Vg=1.043492 -> Vg=1.0
% INFO    : Gen at bus 1057	: Pg=52.81, Qg=50.16 -> Pg=117.605, Qg=20.0
% INFO    : Gen at bus 1057	: Vg=1.055479 -> Vg=1.0
% INFO    : Gen at bus 1059	: Pg=36.8, Qg=-2.54 -> Pg=62.265, Qg=0.0
% INFO    : Gen at bus 1059	: Vg=0.98379 -> Vg=1.0
% INFO    : Gen at bus 1070	: Pg=23.01, Qg=6.63 -> Pg=57.67, Qg=10.0
% INFO    : Gen at bus 1070	: Vg=1.01964 -> Vg=1.0
% INFO    : Gen at bus 1071	: Pg=23.6, Qg=10.13 -> Pg=57.865, Qg=10.0
% INFO    : Gen at bus 1071	: Vg=1.031397 -> Vg=1.0
% INFO    : Gen at bus 1072	: Pg=89.91, Qg=48.94 -> Pg=129.97, Qg=20.0
% INFO    : Gen at bus 1072	: Vg=1.065506 -> Vg=1.0
% INFO    : Gen at bus 1073	: Pg=39.81, Qg=14.61 -> Pg=63.27, Qg=10.0
% INFO    : Gen at bus 1073	: Vg=1.037189 -> Vg=1.0
% INFO    : Gen at bus 1074	: Pg=80.74, Qg=25.03 -> Pg=126.915, Qg=20.0
% INFO    : Gen at bus 1074	: Vg=1.061099 -> Vg=1.0
% INFO    : Gen at bus 1077	: Pg=23.3, Qg=5.11 -> Pg=57.765, Qg=10.0
% INFO    : Gen at bus 1077	: Vg=1.015556 -> Vg=1.0
% INFO    : Gen at bus 1079	: Pg=36.7, Qg=9.55 -> Pg=62.235, Qg=10.0
% INFO    : Gen at bus 1079	: Vg=1.037501 -> Vg=1.0
% INFO    : Gen at bus 1083	: Pg=206.32, Qg=45.91 -> Pg=300.0, Qg=60.0
% INFO    : Gen at bus 1083	: Vg=1.035499 -> Vg=1.0
% INFO    : Gen at bus 1085	: Pg=261.4, Qg=61.69 -> Pg=350.0, Qg=35.0
% INFO    : Gen at bus 1085	: Vg=0.98883 -> Vg=1.0
% INFO    : Gen at bus 1088	: Pg=0.07, Qg=-0.16 -> Pg=50.025, Qg=0.0
% INFO    : Gen at bus 1088	: Vg=1.015045 -> Vg=1.0
% INFO    : Gen at bus 1089	: Pg=26.24, Qg=8.12 -> Pg=58.745, Qg=10.0
% INFO    : Gen at bus 1089	: Vg=1.039754 -> Vg=1.0
% INFO    : Gen at bus 1090	: Pg=19.85, Qg=-1.9 -> Pg=56.615, Qg=10.0
% INFO    : Gen at bus 1090	: Vg=1.026413 -> Vg=1.0
% INFO    : Gen at bus 1092	: Pg=26.24, Qg=8.12 -> Pg=58.745, Qg=10.0
% INFO    : Gen at bus 1092	: Vg=1.039754 -> Vg=1.0
% INFO    : Gen at bus 1093	: Pg=26.24, Qg=8.12 -> Pg=58.745, Qg=10.0
% INFO    : Gen at bus 1093	: Vg=1.039754 -> Vg=1.0
% INFO    : Gen at bus 1096	: Pg=37.29, Qg=8.19 -> Pg=62.43, Qg=10.0
% INFO    : Gen at bus 1096	: Vg=1.030566 -> Vg=1.0
% INFO    : Gen at bus 1104	: Pg=34.92, Qg=9.74 -> Pg=61.64, Qg=10.0
% INFO    : Gen at bus 1104	: Vg=1.043492 -> Vg=1.0
% INFO    : Gen at bus 1123	: Pg=100.41, Qg=11.92 -> Pg=183.47, Qg=20.0
% INFO    : Gen at bus 1123	: Vg=1.038747 -> Vg=1.0
% INFO    : Gen at bus 1125	: Pg=31.3, Qg=-0.77 -> Pg=60.435, Qg=10.0
% INFO    : Gen at bus 1125	: Vg=1.018739 -> Vg=1.0
% INFO    : Gen at bus 1138	: Pg=290.0, Qg=-23.36 -> Pg=350.0, Qg=0.0
% INFO    : Gen at bus 1138	: Vg=0.971901 -> Vg=1.0
% INFO    : Gen at bus 1148	: Pg=9.0, Qg=0.72 -> Pg=53.0, Qg=0.0
% INFO    : Gen at bus 1148	: Vg=1.020087 -> Vg=1.0
% INFO    : Gen at bus 1150	: Pg=240.6, Qg=37.13 -> Pg=300.0, Qg=35.0
% INFO    : Gen at bus 1150	: Vg=0.970854 -> Vg=1.0
% INFO    : Gen at bus 1180	: Pg=25.2, Qg=-0.32 -> Pg=58.4, Qg=5.0
% INFO    : Gen at bus 1180	: Vg=0.999061 -> Vg=1.0
% INFO    : Gen at bus 1182	: Pg=23.37, Qg=7.44 -> Pg=57.79, Qg=10.0
% INFO    : Gen at bus 1182	: Vg=1.056688 -> Vg=1.0
% INFO    : Gen at bus 1183	: Pg=23.37, Qg=7.44 -> Pg=57.79, Qg=10.0
% INFO    : Gen at bus 1183	: Vg=1.056688 -> Vg=1.0
% INFO    : Gen at bus 1189	: Pg=27.96, Qg=5.11 -> Pg=59.32, Qg=10.0
% INFO    : Gen at bus 1189	: Vg=1.029009 -> Vg=1.0
% INFO    : Gen at bus 1192	: Pg=38.79, Qg=7.11 -> Pg=62.93, Qg=10.0
% INFO    : Gen at bus 1192	: Vg=1.035838 -> Vg=1.0
% INFO    : Gen at bus 1202	: Pg=35.5, Qg=10.89 -> Pg=61.835, Qg=10.0
% INFO    : Gen at bus 1202	: Vg=1.045213 -> Vg=1.0
% INFO    : Gen at bus 1208	: Pg=20.0, Qg=-2.63 -> Pg=56.665, Qg=10.0
% INFO    : Gen at bus 1208	: Vg=1.010291 -> Vg=1.0
% INFO    : Gen at bus 1218	: Pg=181.73, Qg=12.69 -> Pg=250.0, Qg=60.0
% INFO    : Gen at bus 1218	: Vg=0.989939 -> Vg=1.0
% INFO    : Gen at bus 1238	: Pg=6.55, Qg=-0.21 -> Pg=52.185, Qg=0.0
% INFO    : Gen at bus 1238	: Vg=1.003807 -> Vg=1.0
% INFO    : Gen at bus 1245	: Pg=17.6, Qg=0.07 -> Pg=55.865, Qg=0.0
% INFO    : Gen at bus 1245	: Vg=0.977562 -> Vg=1.0
% INFO    : Gen at bus 1257	: Pg=56.25, Qg=11.12 -> Pg=118.75, Qg=15.0
% INFO    : Gen at bus 1257	: Vg=1.03036 -> Vg=1.0
% INFO    : Gen at bus 1262	: Pg=219.68, Qg=138.48 -> Pg=300.0, Qg=60.0
% INFO    : Gen at bus 1262	: Vg=1.048632 -> Vg=1.0
% INFO    : Gen at bus 1263	: Pg=241.27, Qg=5.04 -> Pg=300.0, Qg=60.0
% INFO    : Gen at bus 1263	: Vg=1.017546 -> Vg=1.0
% INFO    : Gen at bus 1264	: Pg=270.0, Qg=-15.65 -> Pg=350.0, Qg=0.0
% INFO    : Gen at bus 1264	: Vg=1.002671 -> Vg=1.0
% INFO    : Gen at bus 1273	: Pg=17.95, Qg=10.38 -> Pg=55.985, Qg=10.0
% INFO    : Gen at bus 1273	: Vg=1.044317 -> Vg=1.0
% INFO    : Gen at bus 1274	: Pg=96.03, Qg=17.22 -> Pg=132.01, Qg=20.0
% INFO    : Gen at bus 1274	: Vg=1.036065 -> Vg=1.0
% INFO    : Gen at bus 1278	: Pg=38.16, Qg=4.12 -> Pg=62.72, Qg=10.0
% INFO    : Gen at bus 1278	: Vg=1.055337 -> Vg=1.0
% INFO    : Gen at bus 1287	: Pg=27.88, Qg=10.37 -> Pg=59.295, Qg=10.0
% INFO    : Gen at bus 1287	: Vg=1.052164 -> Vg=1.0
% INFO    : Gen at bus 1288	: Pg=27.2, Qg=3.82 -> Pg=59.065, Qg=10.0
% INFO    : Gen at bus 1288	: Vg=1.024762 -> Vg=1.0
% INFO    : Gen at bus 1290	: Pg=20.55, Qg=5.71 -> Pg=56.85, Qg=10.0
% INFO    : Gen at bus 1290	: Vg=1.019482 -> Vg=1.0
% INFO    : Gen at bus 1298	: Pg=27.88, Qg=10.37 -> Pg=59.295, Qg=10.0
% INFO    : Gen at bus 1298	: Vg=1.052164 -> Vg=1.0
% INFO    : Gen at bus 1304	: Pg=36.91, Qg=13.33 -> Pg=62.305, Qg=10.0
% INFO    : Gen at bus 1304	: Vg=1.037973 -> Vg=1.0
% INFO    : Gen at bus 1305	: Pg=24.84, Qg=4.52 -> Pg=58.28, Qg=10.0
% INFO    : Gen at bus 1305	: Vg=1.022099 -> Vg=1.0
% INFO    : Gen at bus 1306	: Pg=95.02, Qg=8.09 -> Pg=131.675, Qg=20.0
% INFO    : Gen at bus 1306	: Vg=1.023144 -> Vg=1.0
% INFO    : Gen at bus 1308	: Pg=264.57, Qg=207.6 -> Pg=350.0, Qg=80.0
% INFO    : Gen at bus 1308	: Vg=1.127182 -> Vg=1.0
% INFO    : Gen at bus 1310	: Pg=81.31, Qg=8.06 -> Pg=127.105, Qg=20.0
% INFO    : Gen at bus 1310	: Vg=1.043619 -> Vg=1.0
% INFO    : Gen at bus 1323	: Pg=353.02, Qg=203.37 -> Pg=500.0, Qg=80.0
% INFO    : Gen at bus 1323	: Vg=1.128032 -> Vg=1.0
% INFO    : Gen at bus 1324	: Pg=38.16, Qg=4.12 -> Pg=62.72, Qg=10.0
% INFO    : Gen at bus 1324	: Vg=1.055337 -> Vg=1.0
% INFO    : Gen at bus 1329	: Pg=5.0, Qg=2.04 -> Pg=51.665, Qg=0.0
% INFO    : Gen at bus 1329	: Vg=1.009821 -> Vg=1.0
% INFO    : Gen at bus 1330	: Pg=36.11, Qg=3.87 -> Pg=62.035, Qg=10.0
% INFO    : Gen at bus 1330	: Vg=1.024544 -> Vg=1.0
% INFO    : Gen at bus 1335	: Pg=95.51, Qg=37.64 -> Pg=131.835, Qg=20.0
% INFO    : Gen at bus 1335	: Vg=1.0608 -> Vg=1.0
% INFO    : Gen at bus 1338	: Pg=25.65, Qg=3.95 -> Pg=58.55, Qg=10.0
% INFO    : Gen at bus 1338	: Vg=1.02611 -> Vg=1.0
% INFO    : Gen at bus 1339	: Pg=25.65, Qg=3.95 -> Pg=58.55, Qg=10.0
% INFO    : Gen at bus 1339	: Vg=1.02611 -> Vg=1.0
% INFO    : Gen at bus 1342	: Pg=25.65, Qg=3.95 -> Pg=58.55, Qg=10.0
% INFO    : Gen at bus 1342	: Vg=1.02611 -> Vg=1.0
% INFO    : Gen at bus 1343	: Pg=25.65, Qg=3.95 -> Pg=58.55, Qg=10.0
% INFO    : Gen at bus 1343	: Vg=1.02611 -> Vg=1.0
% INFO    : Gen at bus 1344	: Pg=84.68, Qg=7.94 -> Pg=128.225, Qg=20.0
% INFO    : Gen at bus 1344	: Vg=1.00657 -> Vg=1.0
% INFO    : Gen at bus 1348	: Pg=25.65, Qg=3.95 -> Pg=58.55, Qg=10.0
% INFO    : Gen at bus 1348	: Vg=1.02611 -> Vg=1.0
% INFO    : Gen at bus 1349	: Pg=32.01, Qg=22.27 -> Pg=60.67, Qg=10.0
% INFO    : Gen at bus 1349	: Vg=1.031144 -> Vg=1.0
% INFO    : Gen at bus 1359	: Pg=31.57, Qg=7.72 -> Pg=60.525, Qg=10.0
% INFO    : Gen at bus 1359	: Vg=1.008948 -> Vg=1.0
% INFO    : Gen at bus 1367	: Pg=48.33, Qg=15.81 -> Pg=66.11, Qg=15.0
% INFO    : Gen at bus 1367	: Vg=1.031502 -> Vg=1.0
% INFO    : Gen at bus 1369	: Pg=266.84, Qg=38.78 -> Pg=350.0, Qg=80.0
% INFO    : Gen at bus 1369	: Vg=1.032265 -> Vg=1.0
% INFO    : Gen at bus 1372	: Pg=274.65, Qg=30.64 -> Pg=350.0, Qg=60.0
% INFO    : Gen at bus 1372	: Vg=1.018066 -> Vg=1.0
% INFO    : Gen at bus 1376	: Pg=24.65, Qg=14.16 -> Pg=58.215, Qg=10.0
% INFO    : Gen at bus 1376	: Vg=1.027131 -> Vg=1.0
% INFO    : Gen at bus 1381	: Pg=55.46, Qg=13.9 -> Pg=118.485, Qg=15.0
% INFO    : Gen at bus 1381	: Vg=1.030174 -> Vg=1.0
% INFO    : Gen at bus 1382	: Pg=21.45, Qg=5.94 -> Pg=57.15, Qg=10.0
% INFO    : Gen at bus 1382	: Vg=1.013179 -> Vg=1.0
% INFO    : Gen at bus 1389	: Pg=220.02, Qg=99.9 -> Pg=300.0, Qg=80.0
% INFO    : Gen at bus 1389	: Vg=1.03558 -> Vg=1.0
% INFO    : Gen at bus 1390	: Pg=220.02, Qg=99.9 -> Pg=300.0, Qg=80.0
% INFO    : Gen at bus 1390	: Vg=1.03558 -> Vg=1.0
% INFO    : Gen at bus 1391	: Pg=220.02, Qg=99.9 -> Pg=300.0, Qg=80.0
% INFO    : Gen at bus 1391	: Vg=1.03558 -> Vg=1.0
% INFO    : Gen at bus 1394	: Pg=255.53, Qg=96.98 -> Pg=350.0, Qg=80.0
% INFO    : Gen at bus 1394	: Vg=1.03858 -> Vg=1.0
% INFO    : Gen at bus 1401	: Pg=262.4, Qg=19.68 -> Pg=350.0, Qg=60.0
% INFO    : Gen at bus 1401	: Vg=1.015161 -> Vg=1.0
% INFO    : Gen at bus 1407	: Pg=87.88, Qg=32.08 -> Pg=129.295, Qg=20.0
% INFO    : Gen at bus 1407	: Vg=1.042865 -> Vg=1.0
% INFO    : Gen at bus 1408	: Pg=87.88, Qg=32.08 -> Pg=129.295, Qg=20.0
% INFO    : Gen at bus 1408	: Vg=1.042865 -> Vg=1.0
% INFO    : Gen at bus 1410	: Pg=91.17, Qg=37.8 -> Pg=130.39, Qg=20.0
% INFO    : Gen at bus 1410	: Vg=1.045666 -> Vg=1.0
% INFO    : Gen at bus 1411	: Pg=91.17, Qg=37.8 -> Pg=130.39, Qg=20.0
% INFO    : Gen at bus 1411	: Vg=1.045666 -> Vg=1.0
% INFO    : Gen at bus 1412	: Pg=91.17, Qg=37.8 -> Pg=130.39, Qg=20.0
% INFO    : Gen at bus 1412	: Vg=1.045666 -> Vg=1.0
% INFO    : Gen at bus 1413	: Pg=91.17, Qg=37.8 -> Pg=130.39, Qg=20.0
% INFO    : Gen at bus 1413	: Vg=1.045666 -> Vg=1.0
% INFO    : Gen at bus 1414	: Pg=87.88, Qg=32.08 -> Pg=129.295, Qg=20.0
% INFO    : Gen at bus 1414	: Vg=1.042865 -> Vg=1.0
% INFO    : Gen at bus 1415	: Pg=87.88, Qg=32.08 -> Pg=129.295, Qg=20.0
% INFO    : Gen at bus 1415	: Vg=1.042865 -> Vg=1.0
% INFO    : Gen at bus 1416	: Pg=91.17, Qg=37.8 -> Pg=130.39, Qg=20.0
% INFO    : Gen at bus 1416	: Vg=1.045666 -> Vg=1.0
% INFO    : Gen at bus 1417	: Pg=87.88, Qg=32.08 -> Pg=129.295, Qg=20.0
% INFO    : Gen at bus 1417	: Vg=1.042865 -> Vg=1.0
% INFO    : Gen at bus 1419	: Pg=22.22, Qg=6.81 -> Pg=57.405, Qg=10.0
% INFO    : Gen at bus 1419	: Vg=1.03758 -> Vg=1.0
% INFO    : Gen at bus 1421	: Pg=2.0, Qg=-0.0 -> Pg=50.665, Qg=0.0
% INFO    : Gen at bus 1421	: Vg=0.996766 -> Vg=1.0
% INFO    : Gen at bus 1423	: Pg=83.78, Qg=15.02 -> Pg=127.925, Qg=20.0
% INFO    : Gen at bus 1423	: Vg=1.033534 -> Vg=1.0
% INFO    : Gen at bus 1427	: Pg=91.88, Qg=4.87 -> Pg=130.625, Qg=20.0
% INFO    : Gen at bus 1427	: Vg=1.046359 -> Vg=1.0
% INFO    : Gen at bus 1433	: Pg=18.76, Qg=6.31 -> Pg=56.255, Qg=10.0
% INFO    : Gen at bus 1433	: Vg=1.033648 -> Vg=1.0
% INFO    : Gen at bus 1434	: Pg=18.76, Qg=6.31 -> Pg=56.255, Qg=10.0
% INFO    : Gen at bus 1434	: Vg=1.033648 -> Vg=1.0
% INFO    : Gen at bus 1435	: Pg=32.35, Qg=4.05 -> Pg=60.785, Qg=10.0
% INFO    : Gen at bus 1435	: Vg=1.048683 -> Vg=1.0
% INFO    : Gen at bus 1436	: Pg=32.35, Qg=4.05 -> Pg=60.785, Qg=10.0
% INFO    : Gen at bus 1436	: Vg=1.048683 -> Vg=1.0
% INFO    : Gen at bus 1437	: Pg=18.76, Qg=6.31 -> Pg=56.255, Qg=10.0
% INFO    : Gen at bus 1437	: Vg=1.033648 -> Vg=1.0
% INFO    : Gen at bus 1438	: Pg=18.76, Qg=6.31 -> Pg=56.255, Qg=10.0
% INFO    : Gen at bus 1438	: Vg=1.033648 -> Vg=1.0
% INFO    : Gen at bus 1440	: Pg=44.64, Qg=3.39 -> Pg=64.88, Qg=10.0
% INFO    : Gen at bus 1440	: Vg=1.04081 -> Vg=1.0
% INFO    : Gen at bus 1441	: Pg=32.35, Qg=4.05 -> Pg=60.785, Qg=10.0
% INFO    : Gen at bus 1441	: Vg=1.048683 -> Vg=1.0
% INFO    : Gen at bus 1447	: Pg=55.46, Qg=13.9 -> Pg=118.485, Qg=15.0
% INFO    : Gen at bus 1447	: Vg=1.030174 -> Vg=1.0
% INFO    : Gen at bus 1448	: Pg=55.46, Qg=13.9 -> Pg=118.485, Qg=15.0
% INFO    : Gen at bus 1448	: Vg=1.030174 -> Vg=1.0
% INFO    : Gen at bus 1449	: Pg=55.46, Qg=13.9 -> Pg=118.485, Qg=15.0
% INFO    : Gen at bus 1449	: Vg=1.030174 -> Vg=1.0
% INFO    : Gen at bus 1450	: Pg=55.46, Qg=13.9 -> Pg=118.485, Qg=15.0
% INFO    : Gen at bus 1450	: Vg=1.030174 -> Vg=1.0
% INFO    : Gen at bus 1451	: Pg=48.3, Qg=8.12 -> Pg=66.1, Qg=15.0
% INFO    : Gen at bus 1451	: Vg=1.021906 -> Vg=1.0
% INFO    : Gen at bus 1453	: Pg=48.3, Qg=8.12 -> Pg=66.1, Qg=15.0
% INFO    : Gen at bus 1453	: Vg=1.021906 -> Vg=1.0
% INFO    : Gen at bus 1454	: Pg=48.3, Qg=8.12 -> Pg=66.1, Qg=15.0
% INFO    : Gen at bus 1454	: Vg=1.021906 -> Vg=1.0
% INFO    : Gen at bus 1455	: Pg=31.28, Qg=-0.92 -> Pg=60.425, Qg=10.0
% INFO    : Gen at bus 1455	: Vg=1.009892 -> Vg=1.0
% INFO    : Gen at bus 1458	: Pg=91.88, Qg=4.87 -> Pg=130.625, Qg=20.0
% INFO    : Gen at bus 1458	: Vg=1.046359 -> Vg=1.0
% INFO    : Gen at bus 1462	: Pg=96.03, Qg=17.22 -> Pg=132.01, Qg=20.0
% INFO    : Gen at bus 1462	: Vg=1.036065 -> Vg=1.0
% INFO    : Gen at bus 1469	: Pg=7.0, Qg=0.35 -> Pg=52.335, Qg=0.0
% INFO    : Gen at bus 1469	: Vg=1.01541 -> Vg=1.0
% INFO    : Gen at bus 1470	: Pg=90.1, Qg=33.82 -> Pg=130.035, Qg=20.0
% INFO    : Gen at bus 1470	: Vg=1.06527 -> Vg=1.0
% INFO    : Gen at bus 1471	: Pg=90.1, Qg=33.82 -> Pg=130.035, Qg=20.0
% INFO    : Gen at bus 1471	: Vg=1.06527 -> Vg=1.0
% INFO    : Gen at bus 1473	: Pg=90.1, Qg=33.82 -> Pg=130.035, Qg=20.0
% INFO    : Gen at bus 1473	: Vg=1.06527 -> Vg=1.0
% INFO    : Gen at bus 1474	: Pg=90.1, Qg=33.82 -> Pg=130.035, Qg=20.0
% INFO    : Gen at bus 1474	: Vg=1.06527 -> Vg=1.0
% INFO    : Gen at bus 1475	: Pg=90.1, Qg=33.82 -> Pg=130.035, Qg=20.0
% INFO    : Gen at bus 1475	: Vg=1.06527 -> Vg=1.0
% INFO    : Gen at bus 1476	: Pg=90.1, Qg=33.82 -> Pg=130.035, Qg=20.0
% INFO    : Gen at bus 1476	: Vg=1.06527 -> Vg=1.0
% INFO    : Gen at bus 1477	: Pg=18.08, Qg=8.32 -> Pg=56.025, Qg=10.0
% INFO    : Gen at bus 1477	: Vg=1.063432 -> Vg=1.0
% INFO    : Gen at bus 1478	: Pg=18.08, Qg=8.32 -> Pg=56.025, Qg=10.0
% INFO    : Gen at bus 1478	: Vg=1.063432 -> Vg=1.0
% INFO    : Gen at bus 1479	: Pg=18.08, Qg=8.32 -> Pg=56.025, Qg=10.0
% INFO    : Gen at bus 1479	: Vg=1.063432 -> Vg=1.0
% INFO    : Gen at bus 1484	: Pg=30.8, Qg=11.3 -> Pg=60.265, Qg=10.0
% INFO    : Gen at bus 1484	: Vg=1.060798 -> Vg=1.0
% INFO    : Gen at bus 1485	: Pg=30.8, Qg=11.3 -> Pg=60.265, Qg=10.0
% INFO    : Gen at bus 1485	: Vg=1.060798 -> Vg=1.0
% INFO    : Gen at bus 1486	: Pg=30.8, Qg=11.3 -> Pg=60.265, Qg=10.0
% INFO    : Gen at bus 1486	: Vg=1.060798 -> Vg=1.0
% INFO    : Gen at bus 1488	: Pg=1.2, Qg=0.03 -> Pg=50.4, Qg=0.0
% INFO    : Gen at bus 1488	: Vg=1.003171 -> Vg=1.0
% INFO    : Gen at bus 1505	: Pg=21.35, Qg=3.74 -> Pg=57.115, Qg=5.0
% INFO    : Gen at bus 1505	: Vg=1.025426 -> Vg=1.0
% INFO    : Gen at bus 1514	: Pg=36.42, Qg=7.96 -> Pg=62.14, Qg=10.0
% INFO    : Gen at bus 1514	: Vg=1.029166 -> Vg=1.0
% INFO    : Gen at bus 1516	: Pg=38.79, Qg=7.11 -> Pg=62.93, Qg=10.0
% INFO    : Gen at bus 1516	: Vg=1.035838 -> Vg=1.0
% INFO    : Gen at bus 1517	: Pg=51.4, Qg=10.71 -> Pg=117.135, Qg=20.0
% INFO    : Gen at bus 1517	: Vg=1.033944 -> Vg=1.0
% INFO    : Gen at bus 1518	: Pg=51.4, Qg=10.71 -> Pg=117.135, Qg=20.0
% INFO    : Gen at bus 1518	: Vg=1.033944 -> Vg=1.0
% INFO    : Gen at bus 1519	: Pg=50.15, Qg=10.7 -> Pg=116.715, Qg=20.0
% INFO    : Gen at bus 1519	: Vg=1.033944 -> Vg=1.0
% INFO    : Gen at bus 1520	: Pg=50.15, Qg=10.7 -> Pg=116.715, Qg=20.0
% INFO    : Gen at bus 1520	: Vg=1.033944 -> Vg=1.0
% INFO    : Gen at bus 1521	: Pg=73.5, Qg=31.87 -> Pg=124.5, Qg=20.0
% INFO    : Gen at bus 1521	: Vg=1.055774 -> Vg=1.0
% INFO    : Gen at bus 1526	: Pg=22.0, Qg=10.36 -> Pg=57.335, Qg=10.0
% INFO    : Gen at bus 1526	: Vg=1.014332 -> Vg=1.0
% INFO    : Gen at bus 1532	: Pg=20.21, Qg=8.41 -> Pg=56.735, Qg=10.0
% INFO    : Gen at bus 1532	: Vg=1.012556 -> Vg=1.0
% INFO    : Gen at bus 1534	: Pg=97.52, Qg=42.26 -> Pg=132.505, Qg=20.0
% INFO    : Gen at bus 1534	: Vg=1.053776 -> Vg=1.0
% INFO    : Gen at bus 1546	: Pg=152.79, Qg=-6.51 -> Pg=250.0, Qg=30.0
% INFO    : Gen at bus 1546	: Vg=1.051916 -> Vg=1.0
% INFO    : Gen at bus 1552	: Pg=369.99, Qg=86.96 -> Pg=500.0, Qg=80.0
% INFO    : Gen at bus 1552	: Vg=1.043138 -> Vg=1.0
% INFO    : Gen at bus 1553	: Pg=36.13, Qg=4.17 -> Pg=62.045, Qg=10.0
% INFO    : Gen at bus 1553	: Vg=1.027348 -> Vg=1.0
% INFO    : Gen at bus 1556	: Pg=31.58, Qg=5.23 -> Pg=60.525, Qg=10.0
% INFO    : Gen at bus 1556	: Vg=1.069569 -> Vg=1.0
% INFO    : Gen at bus 1557	: Pg=31.58, Qg=5.23 -> Pg=60.525, Qg=10.0
% INFO    : Gen at bus 1557	: Vg=1.069569 -> Vg=1.0
% INFO    : Gen at bus 1558	: Pg=31.58, Qg=5.23 -> Pg=60.525, Qg=10.0
% INFO    : Gen at bus 1558	: Vg=1.069569 -> Vg=1.0
% INFO    : Gen at bus 1559	: Pg=400.01, Qg=197.96 -> Pg=550.0, Qg=80.0
% INFO    : Gen at bus 1559	: Vg=1.113563 -> Vg=1.0
% INFO    : Gen at bus 1560	: Pg=32.57, Qg=6.62 -> Pg=60.855, Qg=10.0
% INFO    : Gen at bus 1560	: Vg=1.059142 -> Vg=1.0
% INFO    : Gen at bus 1561	: Pg=204.89, Qg=166.08 -> Pg=300.0, Qg=80.0
% INFO    : Gen at bus 1561	: Vg=1.066067 -> Vg=1.0
% INFO    : Gen at bus 1562	: Pg=3.5, Qg=-0.25 -> Pg=51.165, Qg=0.0
% INFO    : Gen at bus 1562	: Vg=0.995346 -> Vg=1.0
% INFO    : Gen at bus 1577	: Pg=37.45, Qg=15.75 -> Pg=62.485, Qg=15.0
% INFO    : Gen at bus 1577	: Vg=1.026206 -> Vg=1.0
% INFO    : Gen at bus 1586	: Pg=97.82, Qg=33.17 -> Pg=132.605, Qg=20.0
% INFO    : Gen at bus 1586	: Vg=1.055063 -> Vg=1.0
% INFO    : Gen at bus 1587	: Pg=97.82, Qg=33.17 -> Pg=132.605, Qg=20.0
% INFO    : Gen at bus 1587	: Vg=1.055063 -> Vg=1.0
% INFO    : Gen at bus 1594	: Pg=44.8, Qg=-1.18 -> Pg=64.935, Qg=5.0
% INFO    : Gen at bus 1594	: Vg=1.004901 -> Vg=1.0
% INFO    : Gen at bus 1599	: Pg=3.84, Qg=0.45 -> Pg=51.28, Qg=0.0
% INFO    : Gen at bus 1599	: Vg=1.030843 -> Vg=1.0
% INFO    : Gen at bus 1606	: Pg=82.46, Qg=55.28 -> Pg=127.485, Qg=20.0
% INFO    : Gen at bus 1606	: Vg=1.127948 -> Vg=1.0
% INFO    : Gen at bus 1627	: Pg=219.46, Qg=64.31 -> Pg=300.0, Qg=80.0
% INFO    : Gen at bus 1627	: Vg=1.050142 -> Vg=1.0
% INFO    : Gen at bus 1629	: Pg=26.28, Qg=8.7 -> Pg=58.76, Qg=10.0
% INFO    : Gen at bus 1629	: Vg=1.026298 -> Vg=1.0
% INFO    : Gen at bus 1631	: Pg=276.46, Qg=124.36 -> Pg=350.0, Qg=60.0
% INFO    : Gen at bus 1631	: Vg=1.052654 -> Vg=1.0
% INFO    : Gen at bus 1636	: Pg=20.79, Qg=7.32 -> Pg=56.93, Qg=10.0
% INFO    : Gen at bus 1636	: Vg=1.033848 -> Vg=1.0
% INFO    : Gen at bus 1640	: Pg=10.5, Qg=-0.35 -> Pg=53.5, Qg=0.0
% INFO    : Gen at bus 1640	: Vg=0.994858 -> Vg=1.0
% INFO    : Gen at bus 1641	: Pg=26.33, Qg=10.66 -> Pg=58.775, Qg=10.0
% INFO    : Gen at bus 1641	: Vg=1.01282 -> Vg=1.0
% INFO    : Gen at bus 1642	: Pg=12.15, Qg=4.2 -> Pg=54.05, Qg=5.0
% INFO    : Gen at bus 1642	: Vg=1.012131 -> Vg=1.0
% INFO    : Gen at bus 1644	: Pg=13.95, Qg=4.91 -> Pg=54.65, Qg=5.0
% INFO    : Gen at bus 1644	: Vg=1.042135 -> Vg=1.0
% INFO    : Gen at bus 1656	: Pg=685.9, Qg=149.42 -> Pg=900.0, Qg=200.0
% INFO    : Gen at bus 1656	: Vg=1.062519 -> Vg=1.0
% INFO    : Gen at bus 1661	: Pg=626.63, Qg=190.1 -> Pg=850.0, Qg=200.0
% INFO    : Gen at bus 1661	: Vg=1.051456 -> Vg=1.0
% INFO    : Gen at bus 1662	: Pg=26.06, Qg=3.99 -> Pg=58.685, Qg=5.0
% INFO    : Gen at bus 1662	: Vg=1.027716 -> Vg=1.0
% INFO    : Gen at bus 1675	: Pg=626.64, Qg=187.14 -> Pg=850.0, Qg=200.0
% INFO    : Gen at bus 1675	: Vg=1.050379 -> Vg=1.0
% INFO    : Gen at bus 1685	: Pg=20.0, Qg=-2.63 -> Pg=56.665, Qg=10.0
% INFO    : Gen at bus 1685	: Vg=1.010291 -> Vg=1.0
% INFO    : Gen at bus 1689	: Pg=754.17, Qg=238.65 -> Pg=1050.0, Qg=200.0
% INFO    : Gen at bus 1689	: Vg=1.043738 -> Vg=1.0
% INFO    : Gen at bus 1701	: Pg=40.49, Qg=8.06 -> Pg=63.495, Qg=10.0
% INFO    : Gen at bus 1701	: Vg=1.036966 -> Vg=1.0
% INFO    : Gen at bus 1726	: Pg=617.75, Qg=183.04 -> Pg=850.0, Qg=200.0
% INFO    : Gen at bus 1726	: Vg=1.058676 -> Vg=1.0
% INFO    : Gen at bus 1731	: Pg=41.8, Qg=9.39 -> Pg=63.935, Qg=15.0
% INFO    : Gen at bus 1731	: Vg=1.028604 -> Vg=1.0
% INFO    : Gen at bus 1732	: Pg=56.25, Qg=11.12 -> Pg=118.75, Qg=15.0
% INFO    : Gen at bus 1732	: Vg=1.03036 -> Vg=1.0
% INFO    : Gen at bus 1734	: Pg=156.87, Qg=105.55 -> Pg=250.0, Qg=60.0
% INFO    : Gen at bus 1734	: Vg=1.068377 -> Vg=1.0
% INFO    : Gen at bus 1735	: Pg=156.87, Qg=105.55 -> Pg=250.0, Qg=60.0
% INFO    : Gen at bus 1735	: Vg=1.068377 -> Vg=1.0
% INFO    : Gen at bus 1749	: Pg=31.28, Qg=-0.92 -> Pg=60.425, Qg=10.0
% INFO    : Gen at bus 1749	: Vg=1.009892 -> Vg=1.0
% INFO    : Gen at bus 1750	: Pg=336.9, Qg=100.14 -> Pg=450.0, Qg=80.0
% INFO    : Gen at bus 1750	: Vg=1.061222 -> Vg=1.0
% INFO    : Gen at bus 1751	: Pg=336.9, Qg=100.14 -> Pg=450.0, Qg=80.0
% INFO    : Gen at bus 1751	: Vg=1.061222 -> Vg=1.0
% INFO    : Gen at bus 1757	: Pg=27.2, Qg=3.82 -> Pg=59.065, Qg=10.0
% INFO    : Gen at bus 1757	: Vg=1.024762 -> Vg=1.0
% INFO    : Gen at bus 1763	: Pg=24.84, Qg=4.52 -> Pg=58.28, Qg=10.0
% INFO    : Gen at bus 1763	: Vg=1.022099 -> Vg=1.0
% INFO    : Gen at bus 1764	: Pg=18.67, Qg=5.94 -> Pg=56.225, Qg=10.0
% INFO    : Gen at bus 1764	: Vg=1.015505 -> Vg=1.0
% INFO    : Gen at bus 1770	: Pg=97.12, Qg=8.38 -> Pg=132.375, Qg=20.0
% INFO    : Gen at bus 1770	: Vg=1.040009 -> Vg=1.0
% INFO    : Gen at bus 1772	: Pg=97.12, Qg=8.38 -> Pg=132.375, Qg=20.0
% INFO    : Gen at bus 1772	: Vg=1.040009 -> Vg=1.0
% INFO    : Gen at bus 1774	: Pg=81.31, Qg=8.06 -> Pg=127.105, Qg=20.0
% INFO    : Gen at bus 1774	: Vg=1.043619 -> Vg=1.0
% INFO    : Gen at bus 1791	: Pg=30.13, Qg=8.92 -> Pg=60.045, Qg=10.0
% INFO    : Gen at bus 1791	: Vg=1.016081 -> Vg=1.0
% INFO    : Gen at bus 1794	: Pg=36.11, Qg=3.87 -> Pg=62.035, Qg=10.0
% INFO    : Gen at bus 1794	: Vg=1.024544 -> Vg=1.0
% INFO    : Gen at bus 1796	: Pg=234.71, Qg=26.51 -> Pg=300.0, Qg=60.0
% INFO    : Gen at bus 1796	: Vg=1.008485 -> Vg=1.0
% INFO    : Gen at bus 1801	: Pg=98.05, Qg=38.32 -> Pg=132.685, Qg=20.0
% INFO    : Gen at bus 1801	: Vg=1.058149 -> Vg=1.0
% INFO    : Gen at bus 1803	: Pg=27.65, Qg=14.97 -> Pg=59.215, Qg=10.0
% INFO    : Gen at bus 1803	: Vg=1.018554 -> Vg=1.0
% INFO    : Gen at bus 1805	: Pg=30.02, Qg=16.69 -> Pg=60.005, Qg=10.0
% INFO    : Gen at bus 1805	: Vg=1.023695 -> Vg=1.0
% INFO    : Gen at bus 1807	: Pg=30.02, Qg=16.69 -> Pg=60.005, Qg=10.0
% INFO    : Gen at bus 1807	: Vg=1.023695 -> Vg=1.0
% INFO    : Gen at bus 1808	: Pg=27.65, Qg=14.97 -> Pg=59.215, Qg=10.0
% INFO    : Gen at bus 1808	: Vg=1.018554 -> Vg=1.0
% INFO    : Gen at bus 1812	: Pg=81.88, Qg=21.37 -> Pg=127.295, Qg=20.0
% INFO    : Gen at bus 1812	: Vg=1.031971 -> Vg=1.0
% INFO    : Gen at bus 1813	: Pg=37.23, Qg=9.09 -> Pg=62.41, Qg=10.0
% INFO    : Gen at bus 1813	: Vg=1.012457 -> Vg=1.0
% INFO    : Gen at bus 1815	: Pg=23.96, Qg=4.79 -> Pg=57.985, Qg=10.0
% INFO    : Gen at bus 1815	: Vg=1.007614 -> Vg=1.0
% INFO    : Gen at bus 1816	: Pg=24.94, Qg=11.53 -> Pg=58.315, Qg=10.0
% INFO    : Gen at bus 1816	: Vg=1.042445 -> Vg=1.0
% INFO    : Gen at bus 1821	: Pg=161.0, Qg=0.83 -> Pg=250.0, Qg=0.0
% INFO    : Gen at bus 1821	: Vg=1.011416 -> Vg=1.0
% INFO    : Gen at bus 1822	: Pg=204.0, Qg=41.74 -> Pg=300.0, Qg=45.0
% INFO    : Gen at bus 1822	: Vg=1.035162 -> Vg=1.0
% INFO    : Gen at bus 1831	: Pg=28.97, Qg=5.47 -> Pg=59.655, Qg=10.0
% INFO    : Gen at bus 1831	: Vg=1.043059 -> Vg=1.0
% INFO    : Gen at bus 1834	: Pg=14.99, Qg=2.45 -> Pg=54.995, Qg=0.0
% INFO    : Gen at bus 1834	: Vg=0.998251 -> Vg=1.0
% INFO    : Gen at bus 1836	: Pg=3.58, Qg=0.38 -> Pg=51.195, Qg=0.0
% INFO    : Gen at bus 1836	: Vg=1.006718 -> Vg=1.0
% INFO    : Gen at bus 1839	: Pg=72.47, Qg=11.44 -> Pg=124.155, Qg=20.0
% INFO    : Gen at bus 1839	: Vg=1.019231 -> Vg=1.0
% INFO    : Gen at bus 1840	: Pg=321.41, Qg=105.18 -> Pg=450.0, Qg=80.0
% INFO    : Gen at bus 1840	: Vg=1.033947 -> Vg=1.0
% INFO    : Gen at bus 1845	: Pg=86.25, Qg=-3.04 -> Pg=128.75, Qg=-10.0
% INFO    : Gen at bus 1845	: Vg=0.962614 -> Vg=1.0
% INFO    : Gen at bus 1851	: Pg=322.34, Qg=84.39 -> Pg=450.0, Qg=80.0
% INFO    : Gen at bus 1851	: Vg=1.058231 -> Vg=1.0
% INFO    : Gen at bus 1853	: Pg=37.8, Qg=19.78 -> Pg=62.6, Qg=10.0
% INFO    : Gen at bus 1853	: Vg=1.031737 -> Vg=1.0
% INFO    : Gen at bus 1868	: Pg=114.0, Qg=6.43 -> Pg=188.0, Qg=10.0
% INFO    : Gen at bus 1868	: Vg=0.989649 -> Vg=1.0
% INFO    : Gen at bus 1869	: Pg=57.12, Qg=17.95 -> Pg=119.04, Qg=15.0
% INFO    : Gen at bus 1869	: Vg=1.017464 -> Vg=1.0
% INFO    : Gen at bus 1876	: Pg=55.55, Qg=12.64 -> Pg=118.515, Qg=15.0
% INFO    : Gen at bus 1876	: Vg=1.024324 -> Vg=1.0
% INFO    : Gen at bus 1877	: Pg=55.55, Qg=12.64 -> Pg=118.515, Qg=15.0
% INFO    : Gen at bus 1877	: Vg=1.024324 -> Vg=1.0
% INFO    : Gen at bus 1878	: Pg=55.55, Qg=12.64 -> Pg=118.515, Qg=15.0
% INFO    : Gen at bus 1878	: Vg=1.024324 -> Vg=1.0
% INFO    : Gen at bus 1879	: Pg=55.55, Qg=12.64 -> Pg=118.515, Qg=15.0
% INFO    : Gen at bus 1879	: Vg=1.024324 -> Vg=1.0
% INFO    : Gen at bus 1880	: Pg=55.55, Qg=12.64 -> Pg=118.515, Qg=15.0
% INFO    : Gen at bus 1880	: Vg=1.024324 -> Vg=1.0
% INFO    : Gen at bus 1881	: Pg=55.55, Qg=12.64 -> Pg=118.515, Qg=15.0
% INFO    : Gen at bus 1881	: Vg=1.024324 -> Vg=1.0
% INFO    : Gen at bus 1882	: Pg=46.26, Qg=7.53 -> Pg=65.42, Qg=15.0
% INFO    : Gen at bus 1882	: Vg=1.015006 -> Vg=1.0
% INFO    : Gen at bus 1883	: Pg=46.26, Qg=7.53 -> Pg=65.42, Qg=15.0
% INFO    : Gen at bus 1883	: Vg=1.015006 -> Vg=1.0
% INFO    : Gen at bus 1884	: Pg=46.26, Qg=7.53 -> Pg=65.42, Qg=15.0
% INFO    : Gen at bus 1884	: Vg=1.015006 -> Vg=1.0
% INFO    : Gen at bus 1889	: Pg=33.97, Qg=5.68 -> Pg=61.325, Qg=10.0
% INFO    : Gen at bus 1889	: Vg=1.022889 -> Vg=1.0
% INFO    : Gen at bus 1895	: Pg=23.5, Qg=5.12 -> Pg=57.835, Qg=10.0
% INFO    : Gen at bus 1895	: Vg=1.029146 -> Vg=1.0
% INFO    : Gen at bus 1896	: Pg=39.93, Qg=11.77 -> Pg=63.31, Qg=10.0
% INFO    : Gen at bus 1896	: Vg=1.012991 -> Vg=1.0
% INFO    : Gen at bus 1903	: Pg=5.2, Qg=0.53 -> Pg=51.735, Qg=0.0
% INFO    : Gen at bus 1903	: Vg=1.031159 -> Vg=1.0
% INFO    : Gen at bus 1906	: Pg=25.01, Qg=5.98 -> Pg=58.335, Qg=10.0
% INFO    : Gen at bus 1906	: Vg=0.999838 -> Vg=1.0
% INFO    : Gen at bus 1907	: Pg=18.1, Qg=0.8 -> Pg=56.035, Qg=0.0
% INFO    : Gen at bus 1907	: Vg=1.007227 -> Vg=1.0
% INFO    : Gen at bus 1913	: Pg=81.62, Qg=16.81 -> Pg=127.205, Qg=20.0
% INFO    : Gen at bus 1913	: Vg=1.042096 -> Vg=1.0
% INFO    : Gen at bus 1914	: Pg=81.62, Qg=16.81 -> Pg=127.205, Qg=20.0
% INFO    : Gen at bus 1914	: Vg=1.042096 -> Vg=1.0
% INFO    : Gen at bus 1928	: Pg=16.54, Qg=-1.5 -> Pg=55.515, Qg=0.0
% INFO    : Gen at bus 1928	: Vg=0.999593 -> Vg=1.0
% INFO    : Gen at bus 1932	: Pg=419.12, Qg=110.83 -> Pg=550.0, Qg=200.0
% INFO    : Gen at bus 1932	: Vg=1.016993 -> Vg=1.0
% INFO    : Gen at bus 1935	: Pg=17.96, Qg=1.67 -> Pg=55.985, Qg=10.0
% INFO    : Gen at bus 1935	: Vg=1.048808 -> Vg=1.0
% INFO    : Gen at bus 1936	: Pg=17.96, Qg=1.67 -> Pg=55.985, Qg=10.0
% INFO    : Gen at bus 1936	: Vg=1.048808 -> Vg=1.0
% INFO    : Gen at bus 1940	: Pg=206.37, Qg=113.42 -> Pg=300.0, Qg=60.0
% INFO    : Gen at bus 1940	: Vg=1.061603 -> Vg=1.0
% INFO    : Gen at bus 1949	: Pg=-30.21, Qg=0.29 -> Pg=29.86, Qg=0.0
% INFO    : Gen at bus 1949	: Vg=1.00597 -> Vg=1.0
% INFO    : Gen at bus 1955	: Pg=65.21, Qg=12.85 -> Pg=121.735, Qg=20.0
% INFO    : Gen at bus 1955	: Vg=1.026243 -> Vg=1.0
% INFO    : Gen at bus 1957	: Pg=12.81, Qg=0.42 -> Pg=54.27, Qg=0.0
% INFO    : Gen at bus 1957	: Vg=1.019066 -> Vg=1.0
% INFO    : Gen at bus 1959	: Pg=10.75, Qg=0.78 -> Pg=53.585, Qg=0.0
% INFO    : Gen at bus 1959	: Vg=1.023372 -> Vg=1.0
% INFO    : Gen at bus 1960	: Pg=22.35, Qg=5.33 -> Pg=57.45, Qg=10.0
% INFO    : Gen at bus 1960	: Vg=1.019 -> Vg=1.0
% INFO    : Gen at bus 1961	: Pg=17.5, Qg=-0.6 -> Pg=55.835, Qg=0.0
% INFO    : Gen at bus 1961	: Vg=0.996564 -> Vg=1.0
% INFO    : Gen at bus 1963	: Pg=68.3, Qg=12.27 -> Pg=122.765, Qg=20.0
% INFO    : Gen at bus 1963	: Vg=1.015227 -> Vg=1.0
% INFO    : Gen at bus 1966	: Pg=50.34, Qg=11.93 -> Pg=116.78, Qg=20.0
% INFO    : Gen at bus 1966	: Vg=1.051329 -> Vg=1.0
% INFO    : Gen at bus 1967	: Pg=50.34, Qg=11.93 -> Pg=116.78, Qg=20.0
% INFO    : Gen at bus 1967	: Vg=1.051329 -> Vg=1.0
% INFO    : Gen at bus 1969	: Pg=66.65, Qg=5.48 -> Pg=122.215, Qg=20.0
% INFO    : Gen at bus 1969	: Vg=1.01993 -> Vg=1.0
% INFO    : Gen at bus 1972	: Pg=36.42, Qg=7.96 -> Pg=62.14, Qg=10.0
% INFO    : Gen at bus 1972	: Vg=1.029166 -> Vg=1.0
% INFO    : Gen at bus 1985	: Pg=60.3, Qg=-12.73 -> Pg=120.1, Qg=0.0
% INFO    : Gen at bus 1985	: Vg=0.961956 -> Vg=1.0
% INFO    : Gen at bus 1988	: Pg=25.73, Qg=6.33 -> Pg=58.575, Qg=10.0
% INFO    : Gen at bus 1988	: Vg=1.027807 -> Vg=1.0
% INFO    : Gen at bus 1995	: Pg=305.54, Qg=12.74 -> Pg=450.0, Qg=80.0
% INFO    : Gen at bus 1995	: Vg=0.989323 -> Vg=1.0
% INFO    : Gen at bus 1997	: Pg=863.34, Qg=248.84 -> Pg=1150.0, Qg=200.0
% INFO    : Gen at bus 1997	: Vg=1.044265 -> Vg=1.0
% INFO    : Gen at bus 1999	: Pg=35.65, Qg=6.01 -> Pg=61.885, Qg=10.0
% INFO    : Gen at bus 1999	: Vg=1.058091 -> Vg=1.0
% INFO    : Gen at bus 2000	: Pg=35.65, Qg=6.01 -> Pg=61.885, Qg=10.0
% INFO    : Gen at bus 2000	: Vg=1.058091 -> Vg=1.0
% INFO    : Gen at bus 2001	: Pg=39.12, Qg=14.36 -> Pg=63.04, Qg=10.0
% INFO    : Gen at bus 2001	: Vg=1.038561 -> Vg=1.0
% INFO    : Gen at bus 2003	: Pg=30.7, Qg=16.74 -> Pg=60.235, Qg=10.0
% INFO    : Gen at bus 2003	: Vg=1.0385 -> Vg=1.0
% INFO    : Gen at bus 2004	: Pg=30.7, Qg=16.74 -> Pg=60.235, Qg=10.0
% INFO    : Gen at bus 2004	: Vg=1.0385 -> Vg=1.0
% INFO    : Gen at bus 2005	: Pg=30.7, Qg=16.74 -> Pg=60.235, Qg=10.0
% INFO    : Gen at bus 2005	: Vg=1.0385 -> Vg=1.0
% INFO    : Gen at bus 2006	: Pg=29.05, Qg=10.97 -> Pg=59.685, Qg=10.0
% INFO    : Gen at bus 2006	: Vg=1.053599 -> Vg=1.0
% INFO    : Gen at bus 2011	: Pg=35.65, Qg=6.01 -> Pg=61.885, Qg=10.0
% INFO    : Gen at bus 2011	: Vg=1.058091 -> Vg=1.0
% INFO    : Gen at bus 2012	: Pg=54.32, Qg=19.31 -> Pg=118.105, Qg=15.0
% INFO    : Gen at bus 2012	: Vg=1.040793 -> Vg=1.0
% INFO    : Gen at bus 2013	: Pg=54.32, Qg=19.31 -> Pg=118.105, Qg=15.0
% INFO    : Gen at bus 2013	: Vg=1.040793 -> Vg=1.0
% INFO    : Gen at bus 2014	: Pg=54.32, Qg=19.31 -> Pg=118.105, Qg=15.0
% INFO    : Gen at bus 2014	: Vg=1.040793 -> Vg=1.0
% INFO    : Gen at bus 2020	: Pg=54.32, Qg=19.31 -> Pg=118.105, Qg=15.0
% INFO    : Gen at bus 2020	: Vg=1.040793 -> Vg=1.0
% INFO    : Gen at bus 2042	: Pg=-143.08, Qg=-12.98 -> Pg=-45.385, Qg=-10.0
% INFO    : Gen at bus 2042	: Vg=1.027071 -> Vg=1.0
% INFO    : Gen at bus 2047	: Pg=279.23, Qg=123.34 -> Pg=350.0, Qg=60.0
% INFO    : Gen at bus 2047	: Vg=1.05948 -> Vg=1.0
% INFO    : Gen at bus 2048	: Pg=22.0, Qg=2.53 -> Pg=57.335, Qg=5.0
% INFO    : Gen at bus 2048	: Vg=1.047307 -> Vg=1.0
% INFO    : Gen at bus 2053	: Pg=293.92, Qg=111.78 -> Pg=350.0, Qg=80.0
% INFO    : Gen at bus 2053	: Vg=1.039038 -> Vg=1.0
% INFO    : Gen at bus 2063	: Pg=25.89, Qg=9.83 -> Pg=58.63, Qg=15.0
% INFO    : Gen at bus 2063	: Vg=1.013208 -> Vg=1.0
% INFO    : Gen at bus 2066	: Pg=59.5, Qg=9.44 -> Pg=119.835, Qg=20.0
% INFO    : Gen at bus 2066	: Vg=1.032856 -> Vg=1.0
% INFO    : Gen at bus 2067	: Pg=-599.99, Qg=1981.94 -> Pg=-349.995, Qg=0.0
% INFO    : Gen at bus 2067	: Vg=1.099592 -> Vg=1.0
% INFO    : Gen at bus 2069	: Pg=172.2, Qg=40.07 -> Pg=250.0, Qg=35.0
% INFO    : Gen at bus 2069	: Vg=1.019153 -> Vg=1.0
% INFO    : Gen at bus 2071	: Pg=92.8, Qg=3.25 -> Pg=130.935, Qg=0.0
% INFO    : Gen at bus 2071	: Vg=0.999187 -> Vg=1.0
% INFO    : Gen at bus 2080	: Pg=90.48, Qg=33.58 -> Pg=130.16, Qg=20.0
% INFO    : Gen at bus 2080	: Vg=1.043665 -> Vg=1.0
% INFO    : Gen at bus 2082	: Pg=58.57, Qg=21.97 -> Pg=119.525, Qg=15.0
% INFO    : Gen at bus 2082	: Vg=1.034376 -> Vg=1.0
% INFO    : Gen at bus 2084	: Pg=312.49, Qg=55.02 -> Pg=450.0, Qg=80.0
% INFO    : Gen at bus 2084	: Vg=1.033042 -> Vg=1.0
% INFO    : Gen at bus 2085	: Pg=58.57, Qg=21.99 -> Pg=119.525, Qg=15.0
% INFO    : Gen at bus 2085	: Vg=1.03432 -> Vg=1.0
% INFO    : Gen at bus 2086	: Pg=58.57, Qg=21.99 -> Pg=119.525, Qg=15.0
% INFO    : Gen at bus 2086	: Vg=1.03432 -> Vg=1.0
% INFO    : Gen at bus 2090	: Pg=279.76, Qg=45.2 -> Pg=350.0, Qg=60.0
% INFO    : Gen at bus 2090	: Vg=1.030138 -> Vg=1.0
% INFO    : Gen at bus 2091	: Pg=279.76, Qg=45.2 -> Pg=350.0, Qg=60.0
% INFO    : Gen at bus 2091	: Vg=1.030138 -> Vg=1.0
% INFO    : Gen at bus 2093	: Pg=279.76, Qg=45.2 -> Pg=350.0, Qg=60.0
% INFO    : Gen at bus 2093	: Vg=1.030138 -> Vg=1.0
% INFO    : Gen at bus 2097	: Pg=167.59, Qg=39.08 -> Pg=250.0, Qg=80.0
% INFO    : Gen at bus 2097	: Vg=1.024484 -> Vg=1.0
% INFO    : Gen at bus 2102	: Pg=20.38, Qg=9.61 -> Pg=56.795, Qg=10.0
% INFO    : Gen at bus 2102	: Vg=1.012679 -> Vg=1.0
% INFO    : Gen at bus 2106	: Pg=165.0, Qg=33.72 -> Pg=250.0, Qg=40.0
% INFO    : Gen at bus 2106	: Vg=0.962508 -> Vg=1.0
% INFO    : Gen at bus 2107	: Pg=19.1, Qg=2.95 -> Pg=56.365, Qg=5.0
% INFO    : Gen at bus 2107	: Vg=1.022583 -> Vg=1.0
% INFO    : Gen at bus 2119	: Pg=616.37, Qg=99.15 -> Pg=850.0, Qg=200.0
% INFO    : Gen at bus 2119	: Vg=1.048702 -> Vg=1.0
% INFO    : Gen at bus 2122	: Pg=25.2, Qg=-3.93 -> Pg=58.4, Qg=0.0
% INFO    : Gen at bus 2122	: Vg=0.993105 -> Vg=1.0
% INFO    : Gen at bus 2131	: Pg=44.1, Qg=5.46 -> Pg=64.7, Qg=15.0
% INFO    : Gen at bus 2131	: Vg=0.988831 -> Vg=1.0
% INFO    : Gen at bus 2135	: Pg=629.75, Qg=200.05 -> Pg=850.0, Qg=200.0
% INFO    : Gen at bus 2135	: Vg=1.035502 -> Vg=1.0
% INFO    : Gen at bus 2136	: Pg=629.77, Qg=200.05 -> Pg=850.0, Qg=200.0
% INFO    : Gen at bus 2136	: Vg=1.035502 -> Vg=1.0
% INFO    : Gen at bus 2137	: Pg=629.77, Qg=200.05 -> Pg=850.0, Qg=200.0
% INFO    : Gen at bus 2137	: Vg=1.035502 -> Vg=1.0
% INFO    : Gen at bus 2138	: Pg=629.75, Qg=200.05 -> Pg=850.0, Qg=200.0
% INFO    : Gen at bus 2138	: Vg=1.035502 -> Vg=1.0
% INFO    : Gen at bus 2139	: Pg=57.0, Qg=2.92 -> Pg=119.0, Qg=0.0
% INFO    : Gen at bus 2139	: Vg=1.003313 -> Vg=1.0
% INFO    : Gen at bus 2143	: Pg=241.27, Qg=5.04 -> Pg=300.0, Qg=60.0
% INFO    : Gen at bus 2143	: Vg=1.017546 -> Vg=1.0
% INFO    : Gen at bus 2144	: Pg=241.27, Qg=5.04 -> Pg=300.0, Qg=60.0
% INFO    : Gen at bus 2144	: Vg=1.017546 -> Vg=1.0
% INFO    : Gen at bus 2146	: Pg=241.27, Qg=5.04 -> Pg=300.0, Qg=60.0
% INFO    : Gen at bus 2146	: Vg=1.017546 -> Vg=1.0
% INFO    : Gen at bus 2147	: Pg=259.51, Qg=14.89 -> Pg=350.0, Qg=60.0
% INFO    : Gen at bus 2147	: Vg=1.019095 -> Vg=1.0
% INFO    : Gen at bus 2148	: Pg=33.94, Qg=6.74 -> Pg=61.315, Qg=10.0
% INFO    : Gen at bus 2148	: Vg=1.046243 -> Vg=1.0
% INFO    : Gen at bus 2149	: Pg=33.94, Qg=6.74 -> Pg=61.315, Qg=10.0
% INFO    : Gen at bus 2149	: Vg=1.046243 -> Vg=1.0
% INFO    : Gen at bus 2153	: Pg=29.22, Qg=4.97 -> Pg=59.74, Qg=10.0
% INFO    : Gen at bus 2153	: Vg=1.01017 -> Vg=1.0
% INFO    : Gen at bus 2154	: Pg=22.27, Qg=8.99 -> Pg=57.425, Qg=10.0
% INFO    : Gen at bus 2154	: Vg=1.04545 -> Vg=1.0
% INFO    : Gen at bus 2155	: Pg=24.48, Qg=2.37 -> Pg=58.16, Qg=10.0
% INFO    : Gen at bus 2155	: Vg=1.030117 -> Vg=1.0
% INFO    : Gen at bus 2156	: Pg=31.3, Qg=11.67 -> Pg=60.435, Qg=10.0
% INFO    : Gen at bus 2156	: Vg=1.049836 -> Vg=1.0
% INFO    : Gen at bus 2157	: Pg=22.0, Qg=9.29 -> Pg=57.335, Qg=10.0
% INFO    : Gen at bus 2157	: Vg=1.030852 -> Vg=1.0
% INFO    : Gen at bus 2158	: Pg=24.48, Qg=2.37 -> Pg=58.16, Qg=10.0
% INFO    : Gen at bus 2158	: Vg=1.030117 -> Vg=1.0
% INFO    : Gen at bus 2166	: Pg=21.45, Qg=2.81 -> Pg=57.15, Qg=5.0
% INFO    : Gen at bus 2166	: Vg=1.02436 -> Vg=1.0
% INFO    : Gen at bus 2167	: Pg=31.72, Qg=4.48 -> Pg=60.575, Qg=10.0
% INFO    : Gen at bus 2167	: Vg=1.022192 -> Vg=1.0
% INFO    : Gen at bus 2172	: Pg=74.78, Qg=41.98 -> Pg=124.925, Qg=20.0
% INFO    : Gen at bus 2172	: Vg=1.04914 -> Vg=1.0
% INFO    : Gen at bus 2176	: Pg=82.46, Qg=49.93 -> Pg=127.485, Qg=20.0
% INFO    : Gen at bus 2176	: Vg=1.054354 -> Vg=1.0
% INFO    : Gen at bus 2177	: Pg=82.46, Qg=49.93 -> Pg=127.485, Qg=20.0
% INFO    : Gen at bus 2177	: Vg=1.054354 -> Vg=1.0
% INFO    : Gen at bus 2178	: Pg=82.46, Qg=49.93 -> Pg=127.485, Qg=20.0
% INFO    : Gen at bus 2178	: Vg=1.054354 -> Vg=1.0
% INFO    : Gen at bus 2179	: Pg=82.46, Qg=49.93 -> Pg=127.485, Qg=20.0
% INFO    : Gen at bus 2179	: Vg=1.054354 -> Vg=1.0
% INFO    : Gen at bus 2180	: Pg=132.3, Qg=-12.95 -> Pg=194.1, Qg=0.0
% INFO    : Gen at bus 2180	: Vg=0.985554 -> Vg=1.0
% INFO    : Gen at bus 2183	: Pg=35.95, Qg=6.39 -> Pg=61.985, Qg=15.0
% INFO    : Gen at bus 2183	: Vg=1.015185 -> Vg=1.0
% INFO    : Gen at bus 2186	: Pg=189.36, Qg=46.97 -> Pg=250.0, Qg=60.0
% INFO    : Gen at bus 2186	: Vg=1.05594 -> Vg=1.0
% INFO    : Gen at bus 2190	: Pg=43.55, Qg=17.11 -> Pg=64.515, Qg=15.0
% INFO    : Gen at bus 2190	: Vg=1.033542 -> Vg=1.0
% INFO    : Gen at bus 2192	: Pg=0.99, Qg=-0.05 -> Pg=50.33, Qg=0.0
% INFO    : Gen at bus 2192	: Vg=1.015919 -> Vg=1.0
% INFO    : Gen at bus 2197	: Pg=200.04, Qg=44.85 -> Pg=300.0, Qg=80.0
% INFO    : Gen at bus 2197	: Vg=1.024678 -> Vg=1.0
% INFO    : Gen at bus 2198	: Pg=96.9, Qg=14.27 -> Pg=132.3, Qg=20.0
% INFO    : Gen at bus 2198	: Vg=1.033735 -> Vg=1.0
% INFO    : Gen at bus 2205	: Pg=7.94, Qg=0.62 -> Pg=52.645, Qg=0.0
% INFO    : Gen at bus 2205	: Vg=1.010845 -> Vg=1.0
% INFO    : Gen at bus 2210	: Pg=27.2, Qg=3.82 -> Pg=59.065, Qg=10.0
% INFO    : Gen at bus 2210	: Vg=1.024762 -> Vg=1.0
% INFO    : Gen at bus 2215	: Pg=27.37, Qg=3.79 -> Pg=59.125, Qg=5.0
% INFO    : Gen at bus 2215	: Vg=1.003014 -> Vg=1.0
% INFO    : Gen at bus 2222	: Pg=25.41, Qg=10.96 -> Pg=58.47, Qg=10.0
% INFO    : Gen at bus 2222	: Vg=1.019405 -> Vg=1.0
% INFO    : Gen at bus 2223	: Pg=23.04, Qg=1.33 -> Pg=57.68, Qg=0.0
% INFO    : Gen at bus 2223	: Vg=0.996935 -> Vg=1.0
% INFO    : Gen at bus 2236	: Pg=53.99, Qg=18.23 -> Pg=117.995, Qg=15.0
% INFO    : Gen at bus 2236	: Vg=1.062896 -> Vg=1.0
% INFO    : Gen at bus 2237	: Pg=44.8, Qg=3.17 -> Pg=64.935, Qg=10.0
% INFO    : Gen at bus 2237	: Vg=0.991989 -> Vg=1.0
% INFO    : Gen at bus 2242	: Pg=36.11, Qg=3.87 -> Pg=62.035, Qg=10.0
% INFO    : Gen at bus 2242	: Vg=1.024544 -> Vg=1.0
% INFO    : Gen at bus 2246	: Pg=24.03, Qg=8.37 -> Pg=58.01, Qg=10.0
% INFO    : Gen at bus 2246	: Vg=1.005775 -> Vg=1.0
% INFO    : Gen at bus 2247	: Pg=31.95, Qg=15.26 -> Pg=60.65, Qg=10.0
% INFO    : Gen at bus 2247	: Vg=1.019723 -> Vg=1.0
% INFO    : Gen at bus 2248	: Pg=31.95, Qg=15.26 -> Pg=60.65, Qg=10.0
% INFO    : Gen at bus 2248	: Vg=1.019723 -> Vg=1.0
% INFO    : Gen at bus 2249	: Pg=31.95, Qg=15.26 -> Pg=60.65, Qg=10.0
% INFO    : Gen at bus 2249	: Vg=1.019723 -> Vg=1.0
% INFO    : Gen at bus 2252	: Pg=31.95, Qg=15.26 -> Pg=60.65, Qg=10.0
% INFO    : Gen at bus 2252	: Vg=1.019723 -> Vg=1.0
% INFO    : Gen at bus 2253	: Pg=30.01, Qg=15.35 -> Pg=60.005, Qg=10.0
% INFO    : Gen at bus 2253	: Vg=1.052369 -> Vg=1.0
% INFO    : Gen at bus 2260	: Pg=136.0, Qg=40.17 -> Pg=195.335, Qg=40.0
% INFO    : Gen at bus 2260	: Vg=1.001531 -> Vg=1.0
% INFO    : Gen at bus 2266	: Pg=-31.54, Qg=-6.13 -> Pg=28.975, Qg=-5.0
% INFO    : Gen at bus 2266	: Vg=1.006784 -> Vg=1.0
% INFO    : Gen at bus 2268	: Pg=15.0, Qg=5.29 -> Pg=55.0, Qg=5.0
% INFO    : Gen at bus 2268	: Vg=1.037301 -> Vg=1.0
% INFO    : Gen at bus 2270	: Pg=14.0, Qg=-0.92 -> Pg=54.665, Qg=0.0
% INFO    : Gen at bus 2270	: Vg=0.99902 -> Vg=1.0
% INFO    : Gen at bus 2278	: Pg=5.2, Qg=0.52 -> Pg=51.735, Qg=0.0
% INFO    : Gen at bus 2278	: Vg=1.018046 -> Vg=1.0
% INFO    : Gen at bus 2282	: Pg=31.72, Qg=4.48 -> Pg=60.575, Qg=10.0
% INFO    : Gen at bus 2282	: Vg=1.022192 -> Vg=1.0
% INFO    : Gen at bus 2283	: Pg=31.72, Qg=4.48 -> Pg=60.575, Qg=10.0
% INFO    : Gen at bus 2283	: Vg=1.022192 -> Vg=1.0
% INFO    : Gen at bus 2284	: Pg=31.72, Qg=4.48 -> Pg=60.575, Qg=10.0
% INFO    : Gen at bus 2284	: Vg=1.022192 -> Vg=1.0
% INFO    : Gen at bus 2285	: Pg=31.72, Qg=4.48 -> Pg=60.575, Qg=10.0
% INFO    : Gen at bus 2285	: Vg=1.022192 -> Vg=1.0
% INFO    : Gen at bus 2286	: Pg=170.85, Qg=16.98 -> Pg=250.0, Qg=60.0
% INFO    : Gen at bus 2286	: Vg=1.000084 -> Vg=1.0
% INFO    : Gen at bus 2287	: Pg=170.85, Qg=16.98 -> Pg=250.0, Qg=60.0
% INFO    : Gen at bus 2287	: Vg=1.000084 -> Vg=1.0
% INFO    : Gen at bus 2292	: Pg=22.73, Qg=8.07 -> Pg=57.575, Qg=10.0
% INFO    : Gen at bus 2292	: Vg=1.024089 -> Vg=1.0
% INFO    : Gen at bus 2301	: Pg=219.03, Qg=73.16 -> Pg=300.0, Qg=80.0
% INFO    : Gen at bus 2301	: Vg=1.033551 -> Vg=1.0
% INFO    : Gen at bus 2302	: Pg=322.34, Qg=84.39 -> Pg=450.0, Qg=80.0
% INFO    : Gen at bus 2302	: Vg=1.058231 -> Vg=1.0
% INFO    : Gen at bus 2303	: Pg=131.51, Qg=26.68 -> Pg=193.835, Qg=25.0
% INFO    : Gen at bus 2303	: Vg=1.005693 -> Vg=1.0
% INFO    : Gen at bus 2307	: Pg=24.45, Qg=4.95 -> Pg=58.15, Qg=10.0
% INFO    : Gen at bus 2307	: Vg=0.994621 -> Vg=1.0
% INFO    : Gen at bus 2308	: Pg=290.0, Qg=-14.76 -> Pg=350.0, Qg=0.0
% INFO    : Gen at bus 2308	: Vg=1.001855 -> Vg=1.0
% INFO    : Gen at bus 2318	: Pg=56.84, Qg=10.43 -> Pg=118.945, Qg=15.0
% INFO    : Gen at bus 2318	: Vg=1.025724 -> Vg=1.0
% INFO    : Gen at bus 2321	: Pg=56.84, Qg=10.43 -> Pg=118.945, Qg=15.0
% INFO    : Gen at bus 2321	: Vg=1.025724 -> Vg=1.0
% INFO    : Gen at bus 2322	: Pg=56.84, Qg=10.43 -> Pg=118.945, Qg=15.0
% INFO    : Gen at bus 2322	: Vg=1.025724 -> Vg=1.0
% INFO    : Gen at bus 2324	: Pg=23.3, Qg=5.11 -> Pg=57.765, Qg=10.0
% INFO    : Gen at bus 2324	: Vg=1.015556 -> Vg=1.0
% INFO    : Gen at bus 2325	: Pg=23.3, Qg=5.11 -> Pg=57.765, Qg=10.0
% INFO    : Gen at bus 2325	: Vg=1.015556 -> Vg=1.0
% INFO    : Gen at bus 2328	: Pg=34.3, Qg=7.71 -> Pg=61.435, Qg=10.0
% INFO    : Gen at bus 2328	: Vg=1.038216 -> Vg=1.0
% INFO    : Gen at bus 2329	: Pg=34.3, Qg=7.71 -> Pg=61.435, Qg=10.0
% INFO    : Gen at bus 2329	: Vg=1.038216 -> Vg=1.0
% INFO    : Gen at bus 2330	: Pg=34.3, Qg=7.71 -> Pg=61.435, Qg=10.0
% INFO    : Gen at bus 2330	: Vg=1.038216 -> Vg=1.0
% INFO    : Gen at bus 2331	: Pg=34.3, Qg=7.71 -> Pg=61.435, Qg=10.0
% INFO    : Gen at bus 2331	: Vg=1.038216 -> Vg=1.0
% INFO    : Gen at bus 2332	: Pg=33.97, Qg=5.68 -> Pg=61.325, Qg=10.0
% INFO    : Gen at bus 2332	: Vg=1.022889 -> Vg=1.0
% INFO    : Gen at bus 2333	: Pg=23.3, Qg=5.11 -> Pg=57.765, Qg=10.0
% INFO    : Gen at bus 2333	: Vg=1.015556 -> Vg=1.0
% INFO    : Gen at bus 2341	: Pg=2.5, Qg=0.07 -> Pg=50.835, Qg=0.0
% INFO    : Gen at bus 2341	: Vg=0.9846 -> Vg=1.0
% INFO    : Gen at bus 2345	: Pg=300.01, Qg=75.79 -> Pg=450.0, Qg=60.0
% INFO    : Gen at bus 2345	: Vg=1.035781 -> Vg=1.0
% INFO    : Gen at bus 2347	: Pg=81.31, Qg=8.06 -> Pg=127.105, Qg=20.0
% INFO    : Gen at bus 2347	: Vg=1.043619 -> Vg=1.0
% INFO    : Gen at bus 2351	: Pg=9.98, Qg=3.74 -> Pg=53.325, Qg=0.0
% INFO    : Gen at bus 2351	: Vg=1.015932 -> Vg=1.0
% INFO    : Gen at bus 2357	: Pg=6.38, Qg=-2.2 -> Pg=52.125, Qg=0.0
% INFO    : Gen at bus 2357	: Vg=0.958146 -> Vg=1.0
% INFO    : Gen at bus 2368	: Pg=74.8, Qg=42.23 -> Pg=124.935, Qg=20.0
% INFO    : Gen at bus 2368	: Vg=1.046905 -> Vg=1.0
% INFO    : Gen at bus 2369	: Pg=32.57, Qg=6.88 -> Pg=60.855, Qg=10.0
% INFO    : Gen at bus 2369	: Vg=1.03654 -> Vg=1.0
% INFO    : Gen at bus 2370	: Pg=32.57, Qg=6.88 -> Pg=60.855, Qg=10.0
% INFO    : Gen at bus 2370	: Vg=1.03654 -> Vg=1.0
% INFO    : Gen at bus 2371	: Pg=32.57, Qg=6.88 -> Pg=60.855, Qg=10.0
% INFO    : Gen at bus 2371	: Vg=1.03654 -> Vg=1.0
% INFO    : Gen at bus 2372	: Pg=84.3, Qg=7.63 -> Pg=128.1, Qg=20.0
% INFO    : Gen at bus 2372	: Vg=1.05433 -> Vg=1.0
% INFO    : Gen at bus 2373	: Pg=84.3, Qg=7.63 -> Pg=128.1, Qg=20.0
% INFO    : Gen at bus 2373	: Vg=1.05433 -> Vg=1.0
% INFO    : Gen at bus 2377	: Pg=84.3, Qg=7.63 -> Pg=128.1, Qg=20.0
% INFO    : Gen at bus 2377	: Vg=1.05433 -> Vg=1.0
% INFO    : Gen at bus 2389	: Pg=33.64, Qg=6.9 -> Pg=61.215, Qg=10.0
% INFO    : Gen at bus 2389	: Vg=1.00773 -> Vg=1.0
% INFO    : Gen at bus 2397	: Pg=7.0, Qg=0.35 -> Pg=52.335, Qg=0.0
% INFO    : Gen at bus 2397	: Vg=1.01541 -> Vg=1.0
% INFO    : Gen at bus 2408	: Pg=96.03, Qg=17.22 -> Pg=132.01, Qg=20.0
% INFO    : Gen at bus 2408	: Vg=1.036065 -> Vg=1.0
% INFO    : Gen at bus 2410	: Pg=16.07, Qg=9.31 -> Pg=55.355, Qg=10.0
% INFO    : Gen at bus 2410	: Vg=1.034871 -> Vg=1.0
% INFO    : Gen at bus 2411	: Pg=17.21, Qg=5.28 -> Pg=55.735, Qg=10.0
% INFO    : Gen at bus 2411	: Vg=1.020161 -> Vg=1.0
% INFO    : Gen at bus 2422	: Pg=3.37, Qg=0.4 -> Pg=51.125, Qg=0.0
% INFO    : Gen at bus 2422	: Vg=1.03091 -> Vg=1.0
% INFO    : Gen at bus 2428	: Pg=55.25, Qg=2.21 -> Pg=118.415, Qg=0.0
% INFO    : Gen at bus 2428	: Vg=0.994234 -> Vg=1.0
% INFO    : Gen at bus 2429	: Pg=26.62, Qg=13.25 -> Pg=58.875, Qg=10.0
% INFO    : Gen at bus 2429	: Vg=1.040642 -> Vg=1.0
% INFO    : Gen at bus 2430	: Pg=159.8, Qg=20.91 -> Pg=250.0, Qg=30.0
% INFO    : Gen at bus 2430	: Vg=1.008982 -> Vg=1.0
% INFO    : Gen at bus 2434	: Pg=206.32, Qg=45.73 -> Pg=300.0, Qg=60.0
% INFO    : Gen at bus 2434	: Vg=1.035431 -> Vg=1.0
% INFO    : Gen at bus 2435	: Pg=85.21, Qg=4.77 -> Pg=128.405, Qg=20.0
% INFO    : Gen at bus 2435	: Vg=1.052787 -> Vg=1.0
% INFO    : Gen at bus 2436	: Pg=85.21, Qg=4.77 -> Pg=128.405, Qg=20.0
% INFO    : Gen at bus 2436	: Vg=1.052787 -> Vg=1.0
% INFO    : Gen at bus 2437	: Pg=85.21, Qg=4.77 -> Pg=128.405, Qg=20.0
% INFO    : Gen at bus 2437	: Vg=1.052787 -> Vg=1.0
% INFO    : Gen at bus 2438	: Pg=85.21, Qg=4.77 -> Pg=128.405, Qg=20.0
% INFO    : Gen at bus 2438	: Vg=1.052787 -> Vg=1.0
% INFO    : Gen at bus 2439	: Pg=85.21, Qg=4.77 -> Pg=128.405, Qg=20.0
% INFO    : Gen at bus 2439	: Vg=1.052787 -> Vg=1.0
% INFO    : Gen at bus 2440	: Pg=25.32, Qg=7.7 -> Pg=58.44, Qg=10.0
% INFO    : Gen at bus 2440	: Vg=1.059619 -> Vg=1.0
% INFO    : Gen at bus 2446	: Pg=81.88, Qg=21.37 -> Pg=127.295, Qg=20.0
% INFO    : Gen at bus 2446	: Vg=1.031971 -> Vg=1.0
% INFO    : Gen at bus 2447	: Pg=81.88, Qg=21.37 -> Pg=127.295, Qg=20.0
% INFO    : Gen at bus 2447	: Vg=1.031971 -> Vg=1.0
% INFO    : Gen at bus 2448	: Pg=81.88, Qg=21.37 -> Pg=127.295, Qg=20.0
% INFO    : Gen at bus 2448	: Vg=1.031971 -> Vg=1.0
% INFO    : Gen at bus 2458	: Pg=18.62, Qg=7.28 -> Pg=56.205, Qg=10.0
% INFO    : Gen at bus 2458	: Vg=1.020659 -> Vg=1.0
% INFO    : Gen at bus 2459	: Pg=36.91, Qg=13.33 -> Pg=62.305, Qg=10.0
% INFO    : Gen at bus 2459	: Vg=1.037973 -> Vg=1.0
% INFO    : Gen at bus 2460	: Pg=21.1, Qg=5.27 -> Pg=57.035, Qg=5.0
% INFO    : Gen at bus 2460	: Vg=1.011637 -> Vg=1.0
% INFO    : Gen at bus 2462	: Pg=312.49, Qg=55.02 -> Pg=450.0, Qg=80.0
% INFO    : Gen at bus 2462	: Vg=1.033042 -> Vg=1.0
% INFO    : Gen at bus 2464	: Pg=5.26, Qg=0.06 -> Pg=51.755, Qg=0.0
% INFO    : Gen at bus 2464	: Vg=1.011692 -> Vg=1.0
% INFO    : Gen at bus 2473	: Pg=38.79, Qg=7.11 -> Pg=62.93, Qg=10.0
% INFO    : Gen at bus 2473	: Vg=1.035838 -> Vg=1.0
% INFO    : Gen at bus 2480	: Pg=851.1, Qg=450.38 -> Pg=1150.0, Qg=200.0
% INFO    : Gen at bus 2480	: Vg=1.078638 -> Vg=1.0
% INFO    : Gen at bus 2481	: Pg=851.1, Qg=450.38 -> Pg=1150.0, Qg=200.0
% INFO    : Gen at bus 2481	: Vg=1.078638 -> Vg=1.0
% INFO    : Gen at bus 2482	: Pg=76.7, Qg=4.41 -> Pg=125.565, Qg=20.0
% INFO    : Gen at bus 2482	: Vg=1.02424 -> Vg=1.0
% INFO    : Gen at bus 2485	: Pg=34.31, Qg=1.99 -> Pg=61.435, Qg=10.0
% INFO    : Gen at bus 2485	: Vg=1.015531 -> Vg=1.0
% INFO    : Gen at bus 2486	: Pg=31.12, Qg=9.56 -> Pg=60.375, Qg=10.0
% INFO    : Gen at bus 2486	: Vg=1.04434 -> Vg=1.0
% INFO    : Gen at bus 2487	: Pg=31.12, Qg=9.56 -> Pg=60.375, Qg=10.0
% INFO    : Gen at bus 2487	: Vg=1.04434 -> Vg=1.0
% INFO    : Gen at bus 2488	: Pg=20.97, Qg=7.8 -> Pg=56.99, Qg=10.0
% INFO    : Gen at bus 2488	: Vg=1.055727 -> Vg=1.0
% INFO    : Gen at bus 2489	: Pg=20.97, Qg=7.8 -> Pg=56.99, Qg=10.0
% INFO    : Gen at bus 2489	: Vg=1.055727 -> Vg=1.0
% INFO    : Gen at bus 2490	: Pg=31.12, Qg=9.56 -> Pg=60.375, Qg=10.0
% INFO    : Gen at bus 2490	: Vg=1.04434 -> Vg=1.0
% INFO    : Gen at bus 2506	: Pg=47.25, Qg=-1.74 -> Pg=65.75, Qg=0.0
% INFO    : Gen at bus 2506	: Vg=0.990208 -> Vg=1.0
% INFO    : Gen at bus 2510	: Pg=92.69, Qg=14.48 -> Pg=130.895, Qg=20.0
% INFO    : Gen at bus 2510	: Vg=1.026207 -> Vg=1.0
% INFO    : Gen at bus 2513	: Pg=43.55, Qg=17.11 -> Pg=64.515, Qg=15.0
% INFO    : Gen at bus 2513	: Vg=1.033542 -> Vg=1.0
% INFO    : Gen at bus 2514	: Pg=43.55, Qg=17.08 -> Pg=64.515, Qg=15.0
% INFO    : Gen at bus 2514	: Vg=1.033552 -> Vg=1.0
% INFO    : Gen at bus 2515	: Pg=43.55, Qg=17.08 -> Pg=64.515, Qg=15.0
% INFO    : Gen at bus 2515	: Vg=1.033552 -> Vg=1.0
% INFO    : Gen at bus 2516	: Pg=43.55, Qg=17.08 -> Pg=64.515, Qg=15.0
% INFO    : Gen at bus 2516	: Vg=1.033552 -> Vg=1.0
% INFO    : Gen at bus 2518	: Pg=53.01, Qg=8.19 -> Pg=117.67, Qg=15.0
% INFO    : Gen at bus 2518	: Vg=1.026319 -> Vg=1.0
% INFO    : Gen at bus 2526	: Pg=0.91, Qg=-0.06 -> Pg=50.3, Qg=0.0
% INFO    : Gen at bus 2526	: Vg=1.01592 -> Vg=1.0
% INFO    : Gen at bus 2533	: Pg=94.74, Qg=2.75 -> Pg=131.58, Qg=20.0
% INFO    : Gen at bus 2533	: Vg=1.014104 -> Vg=1.0
% INFO    : Gen at bus 2534	: Pg=90.45, Qg=21.15 -> Pg=130.15, Qg=20.0
% INFO    : Gen at bus 2534	: Vg=1.046641 -> Vg=1.0
% INFO    : Gen at bus 2539	: Pg=595.0, Qg=-374.87 -> Pg=750.0, Qg=0.0
% INFO    : Gen at bus 2539	: Vg=1.000445 -> Vg=1.0
% INFO    : Gen at bus 2540	: Pg=90.45, Qg=21.15 -> Pg=130.15, Qg=20.0
% INFO    : Gen at bus 2540	: Vg=1.046641 -> Vg=1.0
% INFO    : Gen at bus 2543	: Pg=90.45, Qg=21.15 -> Pg=130.15, Qg=20.0
% INFO    : Gen at bus 2543	: Vg=1.046641 -> Vg=1.0
% INFO    : Gen at bus 2559	: Pg=23.61, Qg=14.88 -> Pg=57.87, Qg=10.0
% INFO    : Gen at bus 2559	: Vg=1.029344 -> Vg=1.0
% INFO    : Gen at bus 2561	: Pg=23.81, Qg=8.18 -> Pg=57.935, Qg=10.0
% INFO    : Gen at bus 2561	: Vg=1.024067 -> Vg=1.0
% INFO    : Gen at bus 2566	: Pg=48.5, Qg=-4.15 -> Pg=66.165, Qg=0.0
% INFO    : Gen at bus 2566	: Vg=1.002755 -> Vg=1.0
% INFO    : Gen at bus 2569	: Pg=159.17, Qg=-15.32 -> Pg=250.0, Qg=60.0
% INFO    : Gen at bus 2569	: Vg=1.030434 -> Vg=1.0
% INFO    : Gen at bus 2571	: Pg=90.45, Qg=21.15 -> Pg=130.15, Qg=20.0
% INFO    : Gen at bus 2571	: Vg=1.046641 -> Vg=1.0
% INFO    : Gen at bus 2572	: Pg=94.74, Qg=2.75 -> Pg=131.58, Qg=20.0
% INFO    : Gen at bus 2572	: Vg=1.014104 -> Vg=1.0
% INFO    : Gen at bus 2573	: Pg=94.74, Qg=2.75 -> Pg=131.58, Qg=20.0
% INFO    : Gen at bus 2573	: Vg=1.014104 -> Vg=1.0
% INFO    : Gen at bus 2577	: Pg=90.45, Qg=21.15 -> Pg=130.15, Qg=20.0
% INFO    : Gen at bus 2577	: Vg=1.046641 -> Vg=1.0
% INFO    : Gen at bus 2584	: Pg=198.91, Qg=5.92 -> Pg=250.0, Qg=80.0
% INFO    : Gen at bus 2584	: Vg=1.031301 -> Vg=1.0
% INFO    : Gen at bus 2592	: Pg=200.67, Qg=-1.54 -> Pg=300.0, Qg=60.0
% INFO    : Gen at bus 2592	: Vg=1.014299 -> Vg=1.0
% INFO    : Gen at bus 2603	: Pg=44.8, Qg=-1.18 -> Pg=64.935, Qg=5.0
% INFO    : Gen at bus 2603	: Vg=1.004901 -> Vg=1.0
% INFO    : Gen at bus 2606	: Pg=338.05, Qg=109.11 -> Pg=450.0, Qg=80.0
% INFO    : Gen at bus 2606	: Vg=1.033036 -> Vg=1.0
% INFO    : Gen at bus 2607	: Pg=338.05, Qg=109.11 -> Pg=450.0, Qg=80.0
% INFO    : Gen at bus 2607	: Vg=1.033036 -> Vg=1.0
% INFO    : Gen at bus 2610	: Pg=55.22, Qg=8.96 -> Pg=118.405, Qg=15.0
% INFO    : Gen at bus 2610	: Vg=1.017828 -> Vg=1.0
% INFO    : Gen at bus 2624	: Pg=285.75, Qg=2.4 -> Pg=350.0, Qg=80.0
% INFO    : Gen at bus 2624	: Vg=1.045696 -> Vg=1.0
% INFO    : Gen at bus 2625	: Pg=209.96, Qg=80.01 -> Pg=300.0, Qg=60.0
% INFO    : Gen at bus 2625	: Vg=1.039006 -> Vg=1.0
% INFO    : Gen at bus 2627	: Pg=261.96, Qg=25.03 -> Pg=350.0, Qg=80.0
% INFO    : Gen at bus 2627	: Vg=1.042062 -> Vg=1.0
% INFO    : Gen at bus 2635	: Pg=41.8, Qg=9.39 -> Pg=63.935, Qg=15.0
% INFO    : Gen at bus 2635	: Vg=1.028604 -> Vg=1.0
% INFO    : Gen at bus 2642	: Pg=55.81, Qg=12.44 -> Pg=118.605, Qg=15.0
% INFO    : Gen at bus 2642	: Vg=1.030658 -> Vg=1.0
% INFO    : Gen at bus 2645	: Pg=36.72, Qg=5.04 -> Pg=62.24, Qg=5.0
% INFO    : Gen at bus 2645	: Vg=1.013484 -> Vg=1.0
% INFO    : Gen at bus 2646	: Pg=50.33, Qg=11.56 -> Pg=116.775, Qg=15.0
% INFO    : Gen at bus 2646	: Vg=1.037142 -> Vg=1.0
% INFO    : Gen at bus 2647	: Pg=50.94, Qg=19.18 -> Pg=116.98, Qg=15.0
% INFO    : Gen at bus 2647	: Vg=1.0136 -> Vg=1.0
% INFO    : Gen at bus 2650	: Pg=95.51, Qg=37.64 -> Pg=131.835, Qg=20.0
% INFO    : Gen at bus 2650	: Vg=1.0608 -> Vg=1.0
% INFO    : Gen at bus 2651	: Pg=95.51, Qg=37.64 -> Pg=131.835, Qg=20.0
% INFO    : Gen at bus 2651	: Vg=1.0608 -> Vg=1.0
% INFO    : Gen at bus 2652	: Pg=97.9, Qg=33.0 -> Pg=132.635, Qg=20.0
% INFO    : Gen at bus 2652	: Vg=1.058549 -> Vg=1.0
% INFO    : Gen at bus 2653	: Pg=97.9, Qg=33.0 -> Pg=132.635, Qg=20.0
% INFO    : Gen at bus 2653	: Vg=1.058549 -> Vg=1.0
% INFO    : Gen at bus 2654	: Pg=97.9, Qg=33.0 -> Pg=132.635, Qg=20.0
% INFO    : Gen at bus 2654	: Vg=1.058549 -> Vg=1.0
% INFO    : Gen at bus 2655	: Pg=97.9, Qg=33.0 -> Pg=132.635, Qg=20.0
% INFO    : Gen at bus 2655	: Vg=1.058549 -> Vg=1.0
% INFO    : Gen at bus 2656	: Pg=97.9, Qg=33.0 -> Pg=132.635, Qg=20.0
% INFO    : Gen at bus 2656	: Vg=1.058549 -> Vg=1.0
% INFO    : Gen at bus 2657	: Pg=97.9, Qg=33.0 -> Pg=132.635, Qg=20.0
% INFO    : Gen at bus 2657	: Vg=1.058549 -> Vg=1.0
% INFO    : Gen at bus 2662	: Pg=38.16, Qg=4.12 -> Pg=62.72, Qg=10.0
% INFO    : Gen at bus 2662	: Vg=1.055337 -> Vg=1.0
% INFO    : Gen at bus 2666	: Pg=25.73, Qg=6.33 -> Pg=58.575, Qg=10.0
% INFO    : Gen at bus 2666	: Vg=1.027807 -> Vg=1.0
% INFO    : Gen at bus 2667	: Pg=25.73, Qg=6.33 -> Pg=58.575, Qg=10.0
% INFO    : Gen at bus 2667	: Vg=1.027807 -> Vg=1.0
% INFO    : Gen at bus 2669	: Pg=25.73, Qg=6.33 -> Pg=58.575, Qg=10.0
% INFO    : Gen at bus 2669	: Vg=1.027807 -> Vg=1.0
% INFO    : Gen at bus 2670	: Pg=79.79, Qg=-1.82 -> Pg=126.595, Qg=20.0
% INFO    : Gen at bus 2670	: Vg=1.024891 -> Vg=1.0
% INFO    : Gen at bus 2676	: Pg=34.14, Qg=3.85 -> Pg=61.38, Qg=10.0
% INFO    : Gen at bus 2676	: Vg=1.012735 -> Vg=1.0
% INFO    : Gen at bus 2681	: Pg=90.48, Qg=33.58 -> Pg=130.16, Qg=20.0
% INFO    : Gen at bus 2681	: Vg=1.043665 -> Vg=1.0
% INFO    : Gen at bus 2687	: Pg=37.32, Qg=7.31 -> Pg=62.44, Qg=10.0
% INFO    : Gen at bus 2687	: Vg=1.034314 -> Vg=1.0
% INFO    : Gen at bus 2688	: Pg=40.16, Qg=4.54 -> Pg=63.385, Qg=10.0
% INFO    : Gen at bus 2688	: Vg=1.021208 -> Vg=1.0
% INFO    : Gen at bus 2690	: Pg=37.32, Qg=7.31 -> Pg=62.44, Qg=10.0
% INFO    : Gen at bus 2690	: Vg=1.034314 -> Vg=1.0
% INFO    : Gen at bus 2691	: Pg=5.26, Qg=0.5 -> Pg=51.755, Qg=0.0
% INFO    : Gen at bus 2691	: Vg=1.01939 -> Vg=1.0
% INFO    : Gen at bus 2693	: Pg=19.91, Qg=7.13 -> Pg=56.635, Qg=10.0
% INFO    : Gen at bus 2693	: Vg=1.021055 -> Vg=1.0
% INFO    : Gen at bus 2694	: Pg=19.91, Qg=7.13 -> Pg=56.635, Qg=10.0
% INFO    : Gen at bus 2694	: Vg=1.021055 -> Vg=1.0
% INFO    : Gen at bus 2695	: Pg=46.2, Qg=9.44 -> Pg=65.4, Qg=10.0
% INFO    : Gen at bus 2695	: Vg=1.030241 -> Vg=1.0
% INFO    : Gen at bus 2698	: Pg=36.8, Qg=6.62 -> Pg=62.265, Qg=10.0
% INFO    : Gen at bus 2698	: Vg=1.03058 -> Vg=1.0
% INFO    : Gen at bus 2700	: Pg=27.2, Qg=3.82 -> Pg=59.065, Qg=10.0
% INFO    : Gen at bus 2700	: Vg=1.024762 -> Vg=1.0
% INFO    : Gen at bus 2702	: Pg=16.67, Qg=4.68 -> Pg=55.555, Qg=10.0
% INFO    : Gen at bus 2702	: Vg=1.013686 -> Vg=1.0
% INFO    : Gen at bus 2703	: Pg=31.08, Qg=5.31 -> Pg=60.36, Qg=10.0
% INFO    : Gen at bus 2703	: Vg=1.031603 -> Vg=1.0
% INFO    : Gen at bus 2705	: Pg=31.08, Qg=5.31 -> Pg=60.36, Qg=10.0
% INFO    : Gen at bus 2705	: Vg=1.031603 -> Vg=1.0
% INFO    : Gen at bus 2708	: Pg=26.98, Qg=3.71 -> Pg=58.995, Qg=10.0
% INFO    : Gen at bus 2708	: Vg=1.066367 -> Vg=1.0
% INFO    : Gen at bus 2711	: Pg=27.51, Qg=11.78 -> Pg=59.17, Qg=10.0
% INFO    : Gen at bus 2711	: Vg=1.042669 -> Vg=1.0
% INFO    : Gen at bus 2712	: Pg=49.1, Qg=1.57 -> Pg=66.365, Qg=5.0
% INFO    : Gen at bus 2712	: Vg=1.016984 -> Vg=1.0
% INFO    : Gen at bus 2717	: Pg=107.01, Qg=-5.63 -> Pg=185.67, Qg=0.0
% INFO    : Gen at bus 2717	: Vg=0.996677 -> Vg=1.0
% INFO    : Gen at bus 2721	: Pg=12.6, Qg=5.12 -> Pg=54.2, Qg=5.0
% INFO    : Gen at bus 2721	: Vg=1.029248 -> Vg=1.0
% INFO    : Gen at bus 2734	: Pg=78.21, Qg=5.29 -> Pg=126.07, Qg=20.0
% INFO    : Gen at bus 2734	: Vg=1.025803 -> Vg=1.0
% INFO    : Gen at bus 2756	: Pg=22.5, Qg=7.8 -> Pg=57.5, Qg=10.0
% INFO    : Gen at bus 2756	: Vg=0.998215 -> Vg=1.0
% INFO    : Gen at bus 2759	: Pg=240.6, Qg=61.33 -> Pg=300.0, Qg=35.0
% INFO    : Gen at bus 2759	: Vg=0.990464 -> Vg=1.0
% INFO    : Gen at bus 2760	: Pg=311.23, Qg=83.72 -> Pg=450.0, Qg=80.0
% INFO    : Gen at bus 2760	: Vg=1.058355 -> Vg=1.0
% INFO    : Gen at bus 2767	: Pg=36.22, Qg=11.19 -> Pg=62.075, Qg=10.0
% INFO    : Gen at bus 2767	: Vg=1.003847 -> Vg=1.0
% INFO    : Gen at bus 2777	: Pg=31.28, Qg=-0.92 -> Pg=60.425, Qg=10.0
% INFO    : Gen at bus 2777	: Vg=1.009892 -> Vg=1.0
% INFO    : Gen at bus 2783	: Pg=54.32, Qg=19.31 -> Pg=118.105, Qg=15.0
% INFO    : Gen at bus 2783	: Vg=1.040793 -> Vg=1.0
% INFO    : Gen at bus 2784	: Pg=4.2, Qg=1.57 -> Pg=51.4, Qg=0.0
% INFO    : Gen at bus 2784	: Vg=1.019419 -> Vg=1.0
% INFO    : Gen at bus 2785	: Pg=36.22, Qg=11.19 -> Pg=62.075, Qg=10.0
% INFO    : Gen at bus 2785	: Vg=1.003847 -> Vg=1.0
% INFO    : Gen at bus 2786	: Pg=38.79, Qg=7.11 -> Pg=62.93, Qg=10.0
% INFO    : Gen at bus 2786	: Vg=1.035838 -> Vg=1.0
% INFO    : Gen at bus 2787	: Pg=57.27, Qg=17.52 -> Pg=119.09, Qg=15.0
% INFO    : Gen at bus 2787	: Vg=1.017845 -> Vg=1.0
% INFO    : Gen at bus 2789	: Pg=74.86, Qg=19.42 -> Pg=124.955, Qg=20.0
% INFO    : Gen at bus 2789	: Vg=1.011998 -> Vg=1.0
% INFO    : Gen at bus 2790	: Pg=24.98, Qg=14.2 -> Pg=58.325, Qg=10.0
% INFO    : Gen at bus 2790	: Vg=1.031726 -> Vg=1.0
% INFO    : Gen at bus 2796	: Pg=33.97, Qg=5.68 -> Pg=61.325, Qg=10.0
% INFO    : Gen at bus 2796	: Vg=1.022889 -> Vg=1.0
% INFO    : Gen at bus 2799	: Pg=54.32, Qg=19.31 -> Pg=118.105, Qg=15.0
% INFO    : Gen at bus 2799	: Vg=1.040793 -> Vg=1.0
% INFO    : Gen at bus 2803	: Pg=27.38, Qg=10.62 -> Pg=59.125, Qg=10.0
% INFO    : Gen at bus 2803	: Vg=1.015042 -> Vg=1.0
% INFO    : Gen at bus 2810	: Pg=54.32, Qg=19.31 -> Pg=118.105, Qg=15.0
% INFO    : Gen at bus 2810	: Vg=1.040793 -> Vg=1.0
% INFO    : Gen at bus 2811	: Pg=257.89, Qg=39.7 -> Pg=350.0, Qg=80.0
% INFO    : Gen at bus 2811	: Vg=1.022087 -> Vg=1.0
% INFO    : Gen at bus 2816	: Pg=15.0, Qg=-0.86 -> Pg=55.0, Qg=0.0
% INFO    : Gen at bus 2816	: Vg=0.992395 -> Vg=1.0
% INFO    : Gen at bus 2819	: Pg=26.19, Qg=8.11 -> Pg=58.73, Qg=10.0
% INFO    : Gen at bus 2819	: Vg=1.031736 -> Vg=1.0
% INFO    : Gen at bus 2828	: Pg=93.04, Qg=14.9 -> Pg=131.015, Qg=20.0
% INFO    : Gen at bus 2828	: Vg=1.017638 -> Vg=1.0
% INFO    : Gen at bus 2831	: Pg=23.0, Qg=-6.2 -> Pg=57.665, Qg=0.0
% INFO    : Gen at bus 2831	: Vg=0.989469 -> Vg=1.0
% INFO    : Gen at bus 2836	: Pg=18.58, Qg=13.67 -> Pg=56.195, Qg=10.0
% INFO    : Gen at bus 2836	: Vg=1.061581 -> Vg=1.0
% INFO    : Gen at bus 2838	: Pg=21.72, Qg=6.98 -> Pg=57.24, Qg=10.0
% INFO    : Gen at bus 2838	: Vg=1.064384 -> Vg=1.0
% INFO    : Gen at bus 2840	: Pg=32.97, Qg=4.46 -> Pg=60.99, Qg=10.0
% INFO    : Gen at bus 2840	: Vg=1.027968 -> Vg=1.0
% INFO    : Gen at bus 2841	: Pg=32.97, Qg=4.46 -> Pg=60.99, Qg=10.0
% INFO    : Gen at bus 2841	: Vg=1.027968 -> Vg=1.0
% INFO    : Gen at bus 2842	: Pg=18.58, Qg=13.67 -> Pg=56.195, Qg=10.0
% INFO    : Gen at bus 2842	: Vg=1.061581 -> Vg=1.0
% INFO    : Gen at bus 2844	: Pg=21.05, Qg=5.06 -> Pg=57.015, Qg=10.0
% INFO    : Gen at bus 2844	: Vg=1.070991 -> Vg=1.0
% INFO    : Gen at bus 2845	: Pg=21.72, Qg=6.98 -> Pg=57.24, Qg=10.0
% INFO    : Gen at bus 2845	: Vg=1.064384 -> Vg=1.0
% INFO    : Gen at bus 2852	: Pg=30.0, Qg=-0.55 -> Pg=60.0, Qg=0.0
% INFO    : Gen at bus 2852	: Vg=1.013948 -> Vg=1.0
% INFO    : Gen at bus 2858	: Pg=32.64, Qg=6.68 -> Pg=60.88, Qg=10.0
% INFO    : Gen at bus 2858	: Vg=1.044939 -> Vg=1.0
% INFO    : Gen at bus 2870	: Pg=42.35, Qg=6.03 -> Pg=64.115, Qg=15.0
% INFO    : Gen at bus 2870	: Vg=1.030832 -> Vg=1.0
% INFO    : Gen at bus 2871	: Pg=32.64, Qg=6.67 -> Pg=60.88, Qg=10.0
% INFO    : Gen at bus 2871	: Vg=1.044924 -> Vg=1.0
% INFO    : Gen at bus 2877	: Pg=36.42, Qg=7.96 -> Pg=62.14, Qg=10.0
% INFO    : Gen at bus 2877	: Vg=1.029166 -> Vg=1.0
% INFO    : Gen at bus 2880	: Pg=286.96, Qg=43.74 -> Pg=350.0, Qg=60.0
% INFO    : Gen at bus 2880	: Vg=1.028088 -> Vg=1.0
% INFO    : Gen at bus 2881	: Pg=286.96, Qg=43.74 -> Pg=350.0, Qg=60.0
% INFO    : Gen at bus 2881	: Vg=1.028088 -> Vg=1.0
% INFO    : Gen at bus 2894	: Pg=370.08, Qg=97.24 -> Pg=500.0, Qg=80.0
% INFO    : Gen at bus 2894	: Vg=1.045516 -> Vg=1.0
% INFO    : Gen at bus 2895	: Pg=209.49, Qg=209.89 -> Pg=300.0, Qg=80.0
% INFO    : Gen at bus 2895	: Vg=1.126501 -> Vg=1.0
% INFO    : Gen at bus 2901	: Pg=328.17, Qg=108.89 -> Pg=450.0, Qg=80.0
% INFO    : Gen at bus 2901	: Vg=1.039232 -> Vg=1.0
% INFO    : Gen at bus 2902	: Pg=328.17, Qg=108.89 -> Pg=450.0, Qg=80.0
% INFO    : Gen at bus 2902	: Vg=1.039232 -> Vg=1.0
% INFO    : Gen at bus 2906	: Pg=9.1, Qg=0.73 -> Pg=53.035, Qg=0.0
% INFO    : Gen at bus 2906	: Vg=1.026436 -> Vg=1.0
% INFO    : Gen at bus 2912	: Pg=19.55, Qg=6.06 -> Pg=56.515, Qg=10.0
% INFO    : Gen at bus 2912	: Vg=1.020176 -> Vg=1.0
% INFO    : Gen at bus 2933	: Pg=3.78, Qg=0.53 -> Pg=51.26, Qg=0.0
% INFO    : Gen at bus 2933	: Vg=0.989831 -> Vg=1.0
% INFO    : Gen at bus 2934	: Pg=225.92, Qg=112.91 -> Pg=300.0, Qg=80.0
% INFO    : Gen at bus 2934	: Vg=1.033975 -> Vg=1.0
% INFO    : Gen at bus 2950	: Pg=-142.46, Qg=-0.39 -> Pg=-44.975, Qg=0.0
% INFO    : Gen at bus 2950	: Vg=1.006699 -> Vg=1.0
% INFO    : Gen at bus 2955	: Pg=32.06, Qg=6.83 -> Pg=60.685, Qg=10.0
% INFO    : Gen at bus 2955	: Vg=1.054489 -> Vg=1.0
% INFO    : Gen at bus 2963	: Pg=34.37, Qg=6.67 -> Pg=61.455, Qg=10.0
% INFO    : Gen at bus 2963	: Vg=1.035406 -> Vg=1.0
% INFO    : Gen at bus 2964	: Pg=35.56, Qg=3.76 -> Pg=61.855, Qg=5.0
% INFO    : Gen at bus 2964	: Vg=1.036949 -> Vg=1.0
% INFO    : Gen at bus 2968	: Pg=36.0, Qg=6.82 -> Pg=62.0, Qg=10.0
% INFO    : Gen at bus 2968	: Vg=1.03481 -> Vg=1.0
% INFO    : Gen at bus 2969	: Pg=36.0, Qg=6.82 -> Pg=62.0, Qg=10.0
% INFO    : Gen at bus 2969	: Vg=1.03481 -> Vg=1.0
% INFO    : Gen at bus 2970	: Pg=16.71, Qg=0.01 -> Pg=55.57, Qg=10.0
% INFO    : Gen at bus 2970	: Vg=1.030988 -> Vg=1.0
% INFO    : Gen at bus 2973	: Pg=36.0, Qg=6.82 -> Pg=62.0, Qg=10.0
% INFO    : Gen at bus 2973	: Vg=1.03481 -> Vg=1.0
% INFO    : Gen at bus 2974	: Pg=36.0, Qg=6.82 -> Pg=62.0, Qg=10.0
% INFO    : Gen at bus 2974	: Vg=1.03481 -> Vg=1.0
% INFO    : Gen at bus 2976	: Pg=84.68, Qg=7.94 -> Pg=128.225, Qg=20.0
% INFO    : Gen at bus 2976	: Vg=1.00657 -> Vg=1.0
% INFO    : Gen at bus 2978	: Pg=35.84, Qg=15.66 -> Pg=61.945, Qg=15.0
% INFO    : Gen at bus 2978	: Vg=1.027523 -> Vg=1.0
% INFO    : Gen at bus 2979	: Pg=35.84, Qg=15.66 -> Pg=61.945, Qg=15.0
% INFO    : Gen at bus 2979	: Vg=1.027523 -> Vg=1.0
% INFO    : Gen at bus 2980	: Pg=35.84, Qg=15.66 -> Pg=61.945, Qg=15.0
% INFO    : Gen at bus 2980	: Vg=1.027523 -> Vg=1.0
% INFO    : Gen at bus 2981	: Pg=44.71, Qg=9.09 -> Pg=64.905, Qg=15.0
% INFO    : Gen at bus 2981	: Vg=1.024756 -> Vg=1.0
% INFO    : Gen at bus 2982	: Pg=44.71, Qg=9.09 -> Pg=64.905, Qg=15.0
% INFO    : Gen at bus 2982	: Vg=1.024756 -> Vg=1.0
% INFO    : Gen at bus 2984	: Pg=31.25, Qg=10.3 -> Pg=60.415, Qg=15.0
% INFO    : Gen at bus 2984	: Vg=1.024833 -> Vg=1.0
% INFO    : Gen at bus 2990	: Pg=159.8, Qg=8.06 -> Pg=250.0, Qg=25.0
% INFO    : Gen at bus 2990	: Vg=1.016588 -> Vg=1.0
% INFO    : Gen at bus 2991	: Pg=74.36, Qg=21.23 -> Pg=124.785, Qg=20.0
% INFO    : Gen at bus 2991	: Vg=1.032132 -> Vg=1.0
% INFO    : Gen at bus 2994	: Pg=50.0, Qg=-1.48 -> Pg=116.665, Qg=5.0
% INFO    : Gen at bus 2994	: Vg=0.985642 -> Vg=1.0
% INFO    : Gen at bus 3012	: Pg=200.42, Qg=8.27 -> Pg=300.0, Qg=60.0
% INFO    : Gen at bus 3012	: Vg=1.024412 -> Vg=1.0
% INFO    : Gen at bus 3013	: Pg=299.46, Qg=57.87 -> Pg=350.0, Qg=60.0
% INFO    : Gen at bus 3013	: Vg=1.041662 -> Vg=1.0
% INFO    : Gen at bus 3015	: Pg=199.83, Qg=54.25 -> Pg=250.0, Qg=60.0
% INFO    : Gen at bus 3015	: Vg=1.033334 -> Vg=1.0
% INFO    : Gen at bus 3017	: Pg=94.74, Qg=2.75 -> Pg=131.58, Qg=20.0
% INFO    : Gen at bus 3017	: Vg=1.014104 -> Vg=1.0
% INFO    : Gen at bus 3021	: Pg=94.74, Qg=2.75 -> Pg=131.58, Qg=20.0
% INFO    : Gen at bus 3021	: Vg=1.014104 -> Vg=1.0
% INFO    : Gen at bus 3022	: Pg=94.74, Qg=2.75 -> Pg=131.58, Qg=20.0
% INFO    : Gen at bus 3022	: Vg=1.014104 -> Vg=1.0
% INFO    : Gen at bus 3029	: Pg=90.48, Qg=33.58 -> Pg=130.16, Qg=20.0
% INFO    : Gen at bus 3029	: Vg=1.043665 -> Vg=1.0
% INFO    : Gen at bus 3031	: Pg=37.21, Qg=7.27 -> Pg=62.405, Qg=10.0
% INFO    : Gen at bus 3031	: Vg=1.018242 -> Vg=1.0
% INFO    : Gen at bus 3050	: Pg=87.35, Qg=17.85 -> Pg=129.115, Qg=20.0
% INFO    : Gen at bus 3050	: Vg=1.033768 -> Vg=1.0
% INFO    : Gen at bus 3058	: Pg=46.56, Qg=9.04 -> Pg=65.52, Qg=10.0
% INFO    : Gen at bus 3058	: Vg=1.021353 -> Vg=1.0
% INFO    : Gen at bus 3061	: Pg=27.88, Qg=21.29 -> Pg=59.295, Qg=10.0
% INFO    : Gen at bus 3061	: Vg=1.041842 -> Vg=1.0
% INFO    : Gen at bus 3062	: Pg=27.88, Qg=21.29 -> Pg=59.295, Qg=10.0
% INFO    : Gen at bus 3062	: Vg=1.041842 -> Vg=1.0
% INFO    : Gen at bus 3063	: Pg=29.35, Qg=12.59 -> Pg=59.785, Qg=10.0
% INFO    : Gen at bus 3063	: Vg=1.05544 -> Vg=1.0
% INFO    : Gen at bus 3065	: Pg=279.13, Qg=130.91 -> Pg=350.0, Qg=80.0
% INFO    : Gen at bus 3065	: Vg=1.048637 -> Vg=1.0
% INFO    : Gen at bus 3068	: Pg=857.74, Qg=280.43 -> Pg=1150.0, Qg=200.0
% INFO    : Gen at bus 3068	: Vg=1.043939 -> Vg=1.0
% INFO    : Gen at bus 3072	: Pg=328.39, Qg=49.41 -> Pg=450.0, Qg=80.0
% INFO    : Gen at bus 3072	: Vg=1.023058 -> Vg=1.0
% INFO    : Gen at bus 3074	: Pg=328.39, Qg=49.41 -> Pg=450.0, Qg=80.0
% INFO    : Gen at bus 3074	: Vg=1.023058 -> Vg=1.0
% INFO    : Gen at bus 3082	: Pg=55.25, Qg=0.75 -> Pg=118.415, Qg=0.0
% INFO    : Gen at bus 3082	: Vg=0.959658 -> Vg=1.0
% INFO    : Gen at bus 3093	: Pg=200.87, Qg=149.12 -> Pg=300.0, Qg=80.0
% INFO    : Gen at bus 3093	: Vg=1.062094 -> Vg=1.0
% INFO    : Gen at bus 3094	: Pg=194.99, Qg=63.31 -> Pg=250.0, Qg=80.0
% INFO    : Gen at bus 3094	: Vg=1.048559 -> Vg=1.0
% INFO    : Gen at bus 3095	: Pg=366.07, Qg=56.62 -> Pg=500.0, Qg=80.0
% INFO    : Gen at bus 3095	: Vg=1.050106 -> Vg=1.0
% INFO    : Gen at bus 3096	: Pg=194.99, Qg=63.31 -> Pg=250.0, Qg=80.0
% INFO    : Gen at bus 3096	: Vg=1.048559 -> Vg=1.0
% INFO    : Gen at bus 3097	: Pg=366.07, Qg=56.62 -> Pg=500.0, Qg=80.0
% INFO    : Gen at bus 3097	: Vg=1.050106 -> Vg=1.0
% INFO    : Gen at bus 3098	: Pg=366.07, Qg=56.62 -> Pg=500.0, Qg=80.0
% INFO    : Gen at bus 3098	: Vg=1.050106 -> Vg=1.0
% INFO    : Gen at bus 3100	: Pg=200.87, Qg=149.13 -> Pg=300.0, Qg=80.0
% INFO    : Gen at bus 3100	: Vg=1.062073 -> Vg=1.0
% INFO    : Gen at bus 3101	: Pg=200.87, Qg=149.12 -> Pg=300.0, Qg=80.0
% INFO    : Gen at bus 3101	: Vg=1.062094 -> Vg=1.0
% INFO    : Gen at bus 3103	: Pg=84.19, Qg=8.48 -> Pg=128.065, Qg=20.0
% INFO    : Gen at bus 3103	: Vg=1.040259 -> Vg=1.0
% INFO    : Gen at bus 3104	: Pg=84.19, Qg=8.48 -> Pg=128.065, Qg=20.0
% INFO    : Gen at bus 3104	: Vg=1.040259 -> Vg=1.0
% INFO    : Gen at bus 3107	: Pg=33.38, Qg=14.38 -> Pg=61.125, Qg=10.0
% INFO    : Gen at bus 3107	: Vg=1.023574 -> Vg=1.0
% INFO    : Gen at bus 3108	: Pg=33.38, Qg=14.38 -> Pg=61.125, Qg=10.0
% INFO    : Gen at bus 3108	: Vg=1.023574 -> Vg=1.0
% INFO    : Gen at bus 3109	: Pg=33.37, Qg=14.47 -> Pg=61.125, Qg=10.0
% INFO    : Gen at bus 3109	: Vg=1.0234 -> Vg=1.0
% INFO    : Gen at bus 3111	: Pg=33.37, Qg=14.47 -> Pg=61.125, Qg=10.0
% INFO    : Gen at bus 3111	: Vg=1.0234 -> Vg=1.0
% INFO    : Gen at bus 3112	: Pg=25.03, Qg=21.04 -> Pg=58.345, Qg=10.0
% INFO    : Gen at bus 3112	: Vg=1.030367 -> Vg=1.0
% INFO    : Gen at bus 3113	: Pg=30.07, Qg=11.9 -> Pg=60.025, Qg=10.0
% INFO    : Gen at bus 3113	: Vg=1.030443 -> Vg=1.0
% INFO    : Gen at bus 3114	: Pg=24.37, Qg=4.5 -> Pg=58.125, Qg=10.0
% INFO    : Gen at bus 3114	: Vg=1.00571 -> Vg=1.0
% INFO    : Gen at bus 3121	: Pg=95.62, Qg=39.51 -> Pg=131.875, Qg=20.0
% INFO    : Gen at bus 3121	: Vg=1.057682 -> Vg=1.0
% INFO    : Gen at bus 3122	: Pg=95.62, Qg=39.51 -> Pg=131.875, Qg=20.0
% INFO    : Gen at bus 3122	: Vg=1.057682 -> Vg=1.0
% INFO    : Gen at bus 3123	: Pg=382.46, Qg=57.23 -> Pg=500.0, Qg=80.0
% INFO    : Gen at bus 3123	: Vg=1.050841 -> Vg=1.0
% INFO    : Gen at bus 3124	: Pg=382.46, Qg=57.23 -> Pg=500.0, Qg=80.0
% INFO    : Gen at bus 3124	: Vg=1.050841 -> Vg=1.0
% INFO    : Gen at bus 3127	: Pg=163.94, Qg=189.92 -> Pg=250.0, Qg=80.0
% INFO    : Gen at bus 3127	: Vg=1.050579 -> Vg=1.0
% INFO    : Gen at bus 3128	: Pg=383.05, Qg=40.91 -> Pg=500.0, Qg=80.0
% INFO    : Gen at bus 3128	: Vg=1.045612 -> Vg=1.0
% INFO    : Gen at bus 3130	: Pg=383.05, Qg=40.91 -> Pg=500.0, Qg=80.0
% INFO    : Gen at bus 3130	: Vg=1.045612 -> Vg=1.0
% INFO    : Gen at bus 3134	: Pg=82.3, Qg=25.62 -> Pg=127.435, Qg=20.0
% INFO    : Gen at bus 3134	: Vg=1.055592 -> Vg=1.0
% INFO    : Gen at bus 3135	: Pg=82.3, Qg=25.62 -> Pg=127.435, Qg=20.0
% INFO    : Gen at bus 3135	: Vg=1.055592 -> Vg=1.0
% INFO    : Gen at bus 3136	: Pg=82.3, Qg=25.62 -> Pg=127.435, Qg=20.0
% INFO    : Gen at bus 3136	: Vg=1.055592 -> Vg=1.0
% INFO    : Gen at bus 3137	: Pg=82.3, Qg=25.62 -> Pg=127.435, Qg=20.0
% INFO    : Gen at bus 3137	: Vg=1.055592 -> Vg=1.0
% INFO    : Gen at bus 3139	: Pg=87.35, Qg=17.85 -> Pg=129.115, Qg=20.0
% INFO    : Gen at bus 3139	: Vg=1.033768 -> Vg=1.0
% INFO    : Gen at bus 3141	: Pg=20.56, Qg=10.34 -> Pg=56.855, Qg=10.0
% INFO    : Gen at bus 3141	: Vg=1.03603 -> Vg=1.0
% INFO    : Gen at bus 3142	: Pg=20.56, Qg=10.34 -> Pg=56.855, Qg=10.0
% INFO    : Gen at bus 3142	: Vg=1.03603 -> Vg=1.0
% INFO    : Gen at bus 3143	: Pg=32.85, Qg=10.54 -> Pg=60.95, Qg=10.0
% INFO    : Gen at bus 3143	: Vg=1.034933 -> Vg=1.0
% INFO    : Gen at bus 3145	: Pg=90.32, Qg=6.14 -> Pg=130.105, Qg=20.0
% INFO    : Gen at bus 3145	: Vg=1.034547 -> Vg=1.0
% INFO    : Gen at bus 3146	: Pg=41.8, Qg=9.39 -> Pg=63.935, Qg=15.0
% INFO    : Gen at bus 3146	: Vg=1.028604 -> Vg=1.0
% INFO    : Gen at bus 3148	: Pg=7.36, Qg=0.9 -> Pg=52.455, Qg=0.0
% INFO    : Gen at bus 3148	: Vg=1.017868 -> Vg=1.0
% INFO    : Gen at bus 3152	: Pg=335.08, Qg=109.13 -> Pg=450.0, Qg=80.0
% INFO    : Gen at bus 3152	: Vg=1.05813 -> Vg=1.0
% INFO    : Gen at bus 3154	: Pg=89.73, Qg=17.85 -> Pg=129.91, Qg=20.0
% INFO    : Gen at bus 3154	: Vg=1.041223 -> Vg=1.0
% INFO    : Gen at bus 3164	: Pg=5.26, Qg=-0.96 -> Pg=51.755, Qg=0.0
% INFO    : Gen at bus 3164	: Vg=1.01814 -> Vg=1.0
% INFO    : Gen at bus 3165	: Pg=219.49, Qg=53.36 -> Pg=300.0, Qg=80.0
% INFO    : Gen at bus 3165	: Vg=1.029459 -> Vg=1.0
% INFO    : Gen at bus 3166	: Pg=20.91, Qg=7.74 -> Pg=56.97, Qg=10.0
% INFO    : Gen at bus 3166	: Vg=1.014154 -> Vg=1.0
% INFO    : Gen at bus 3167	: Pg=202.63, Qg=63.88 -> Pg=300.0, Qg=60.0
% INFO    : Gen at bus 3167	: Vg=1.022861 -> Vg=1.0
% INFO    : Gen at bus 3168	: Pg=202.63, Qg=63.88 -> Pg=300.0, Qg=60.0
% INFO    : Gen at bus 3168	: Vg=1.022861 -> Vg=1.0
% INFO    : Gen at bus 3169	: Pg=202.63, Qg=63.88 -> Pg=300.0, Qg=60.0
% INFO    : Gen at bus 3169	: Vg=1.022861 -> Vg=1.0
% INFO    : Gen at bus 3176	: Pg=36.8, Qg=6.62 -> Pg=62.265, Qg=10.0
% INFO    : Gen at bus 3176	: Vg=1.03058 -> Vg=1.0
% INFO    : Gen at bus 3178	: Pg=165.0, Qg=33.72 -> Pg=250.0, Qg=40.0
% INFO    : Gen at bus 3178	: Vg=0.962508 -> Vg=1.0
% INFO    : Gen at bus 3179	: Pg=261.4, Qg=37.15 -> Pg=350.0, Qg=35.0
% INFO    : Gen at bus 3179	: Vg=0.969605 -> Vg=1.0
% INFO    : Gen at bus 3184	: Pg=25.2, Qg=-3.93 -> Pg=58.4, Qg=0.0
% INFO    : Gen at bus 3184	: Vg=0.993105 -> Vg=1.0
% INFO    : Gen at bus 3186	: Pg=94.28, Qg=43.72 -> Pg=131.425, Qg=20.0
% INFO    : Gen at bus 3186	: Vg=1.048808 -> Vg=1.0
% INFO    : Gen at bus 3201	: Pg=155.5, Qg=12.42 -> Pg=250.0, Qg=15.0
% INFO    : Gen at bus 3201	: Vg=1.034282 -> Vg=1.0
% INFO    : Gen at bus 3206	: Pg=25.35, Qg=8.5 -> Pg=58.45, Qg=15.0
% INFO    : Gen at bus 3206	: Vg=1.018631 -> Vg=1.0
% INFO    : Gen at bus 3210	: Pg=60.07, Qg=-4.22 -> Pg=120.025, Qg=20.0
% INFO    : Gen at bus 3210	: Vg=1.016876 -> Vg=1.0
% INFO    : Gen at bus 3213	: Pg=60.07, Qg=-4.22 -> Pg=120.025, Qg=20.0
% INFO    : Gen at bus 3213	: Vg=1.016868 -> Vg=1.0
% INFO    : Gen at bus 3214	: Pg=60.07, Qg=-4.22 -> Pg=120.025, Qg=20.0
% INFO    : Gen at bus 3214	: Vg=1.016876 -> Vg=1.0
% INFO    : Gen at bus 3215	: Pg=60.07, Qg=-4.22 -> Pg=120.025, Qg=20.0
% INFO    : Gen at bus 3215	: Vg=1.016876 -> Vg=1.0
% INFO    : Gen at bus 3216	: Pg=60.07, Qg=-4.22 -> Pg=120.025, Qg=20.0
% INFO    : Gen at bus 3216	: Vg=1.016876 -> Vg=1.0
% INFO    : Gen at bus 3217	: Pg=83.51, Qg=27.65 -> Pg=127.835, Qg=20.0
% INFO    : Gen at bus 3217	: Vg=1.063297 -> Vg=1.0
% INFO    : Gen at bus 3219	: Pg=60.07, Qg=-4.22 -> Pg=120.025, Qg=20.0
% INFO    : Gen at bus 3219	: Vg=1.016868 -> Vg=1.0
% INFO    : Gen at bus 3220	: Pg=60.07, Qg=-4.22 -> Pg=120.025, Qg=20.0
% INFO    : Gen at bus 3220	: Vg=1.016868 -> Vg=1.0
% INFO    : Gen at bus 3224	: Pg=233.96, Qg=-20.31 -> Pg=300.0, Qg=80.0
% INFO    : Gen at bus 3224	: Vg=1.034075 -> Vg=1.0
% INFO    : Gen at bus 3225	: Pg=37.32, Qg=7.31 -> Pg=62.44, Qg=10.0
% INFO    : Gen at bus 3225	: Vg=1.034314 -> Vg=1.0
% INFO    : Gen at bus 3228	: Pg=16.28, Qg=8.5 -> Pg=55.425, Qg=10.0
% INFO    : Gen at bus 3228	: Vg=1.027518 -> Vg=1.0
% INFO    : Gen at bus 3233	: Pg=37.32, Qg=7.31 -> Pg=62.44, Qg=10.0
% INFO    : Gen at bus 3233	: Vg=1.034314 -> Vg=1.0
% INFO    : Gen at bus 3234	: Pg=22.36, Qg=9.77 -> Pg=57.455, Qg=10.0
% INFO    : Gen at bus 3234	: Vg=1.014559 -> Vg=1.0
% INFO    : Gen at bus 3236	: Pg=31.0, Qg=0.14 -> Pg=60.335, Qg=0.0
% INFO    : Gen at bus 3236	: Vg=1.000449 -> Vg=1.0
% INFO    : Gen at bus 3248	: Pg=36.91, Qg=13.33 -> Pg=62.305, Qg=10.0
% INFO    : Gen at bus 3248	: Vg=1.037973 -> Vg=1.0
% INFO    : Gen at bus 3255	: Pg=311.23, Qg=83.72 -> Pg=450.0, Qg=80.0
% INFO    : Gen at bus 3255	: Vg=1.058355 -> Vg=1.0
% INFO    : Gen at bus 3265	: Pg=994.84, Qg=302.65 -> Pg=1300.0, Qg=200.0
% INFO    : Gen at bus 3265	: Vg=1.05787 -> Vg=1.0
% INFO    : Gen at bus 3270	: Pg=9.94, Qg=1.23 -> Pg=53.315, Qg=0.0
% INFO    : Gen at bus 3270	: Vg=0.98472 -> Vg=1.0
% INFO    : Gen at bus 3280	: Pg=237.72, Qg=5.93 -> Pg=300.0, Qg=60.0
% INFO    : Gen at bus 3280	: Vg=1.041353 -> Vg=1.0
% INFO    : Gen at bus 3282	: Pg=86.61, Qg=21.7 -> Pg=128.87, Qg=20.0
% INFO    : Gen at bus 3282	: Vg=1.039025 -> Vg=1.0
% INFO    : Gen at bus 3283	: Pg=86.61, Qg=21.7 -> Pg=128.87, Qg=20.0
% INFO    : Gen at bus 3283	: Vg=1.039025 -> Vg=1.0
% INFO    : Gen at bus 3284	: Pg=86.61, Qg=21.7 -> Pg=128.87, Qg=20.0
% INFO    : Gen at bus 3284	: Vg=1.039025 -> Vg=1.0
% INFO    : Gen at bus 3292	: Pg=43.29, Qg=23.54 -> Pg=64.43, Qg=20.0
% INFO    : Gen at bus 3292	: Vg=1.035771 -> Vg=1.0
% INFO    : Gen at bus 3294	: Pg=228.6, Qg=9.57 -> Pg=300.0, Qg=45.0
% INFO    : Gen at bus 3294	: Vg=0.974759 -> Vg=1.0
% INFO    : Gen at bus 3296	: Pg=72.61, Qg=29.56 -> Pg=124.205, Qg=20.0
% INFO    : Gen at bus 3296	: Vg=1.041629 -> Vg=1.0
% INFO    : Gen at bus 3297	: Pg=46.38, Qg=17.23 -> Pg=65.46, Qg=15.0
% INFO    : Gen at bus 3297	: Vg=1.048358 -> Vg=1.0
% INFO    : Gen at bus 3298	: Pg=46.38, Qg=17.23 -> Pg=65.46, Qg=15.0
% INFO    : Gen at bus 3298	: Vg=1.048358 -> Vg=1.0
% INFO    : Gen at bus 3299	: Pg=46.38, Qg=17.23 -> Pg=65.46, Qg=15.0
% INFO    : Gen at bus 3299	: Vg=1.048358 -> Vg=1.0
% INFO    : Gen at bus 3306	: Pg=46.38, Qg=17.23 -> Pg=65.46, Qg=15.0
% INFO    : Gen at bus 3306	: Vg=1.048358 -> Vg=1.0
% INFO    : Gen at bus 3307	: Pg=46.38, Qg=17.23 -> Pg=65.46, Qg=15.0
% INFO    : Gen at bus 3307	: Vg=1.048358 -> Vg=1.0
% INFO    : Gen at bus 3308	: Pg=38.42, Qg=21.93 -> Pg=62.805, Qg=10.0
% INFO    : Gen at bus 3308	: Vg=1.054031 -> Vg=1.0
% INFO    : Gen at bus 3309	: Pg=38.42, Qg=21.93 -> Pg=62.805, Qg=10.0
% INFO    : Gen at bus 3309	: Vg=1.054031 -> Vg=1.0
% INFO    : Gen at bus 3323	: Pg=28.83, Qg=4.62 -> Pg=59.61, Qg=10.0
% INFO    : Gen at bus 3323	: Vg=1.019144 -> Vg=1.0
% INFO    : Gen at bus 3325	: Pg=24.72, Qg=4.34 -> Pg=58.24, Qg=10.0
% INFO    : Gen at bus 3325	: Vg=1.03955 -> Vg=1.0
% INFO    : Gen at bus 3326	: Pg=24.72, Qg=4.34 -> Pg=58.24, Qg=10.0
% INFO    : Gen at bus 3326	: Vg=1.03955 -> Vg=1.0
% INFO    : Gen at bus 3327	: Pg=26.71, Qg=4.35 -> Pg=58.905, Qg=10.0
% INFO    : Gen at bus 3327	: Vg=1.039449 -> Vg=1.0
% INFO    : Gen at bus 3328	: Pg=26.71, Qg=4.35 -> Pg=58.905, Qg=10.0
% INFO    : Gen at bus 3328	: Vg=1.039449 -> Vg=1.0
% INFO    : Gen at bus 3329	: Pg=93.04, Qg=14.9 -> Pg=131.015, Qg=20.0
% INFO    : Gen at bus 3329	: Vg=1.017638 -> Vg=1.0
% INFO    : Gen at bus 3330	: Pg=21.12, Qg=7.89 -> Pg=57.04, Qg=5.0
% INFO    : Gen at bus 3330	: Vg=1.062419 -> Vg=1.0
% INFO    : Gen at bus 3334	: Pg=22.13, Qg=5.02 -> Pg=57.375, Qg=10.0
% INFO    : Gen at bus 3334	: Vg=1.031677 -> Vg=1.0
% INFO    : Gen at bus 3335	: Pg=22.13, Qg=5.02 -> Pg=57.375, Qg=10.0
% INFO    : Gen at bus 3335	: Vg=1.031677 -> Vg=1.0
% INFO    : Gen at bus 3336	: Pg=22.13, Qg=5.02 -> Pg=57.375, Qg=10.0
% INFO    : Gen at bus 3336	: Vg=1.031677 -> Vg=1.0
% INFO    : Gen at bus 3337	: Pg=22.13, Qg=5.02 -> Pg=57.375, Qg=10.0
% INFO    : Gen at bus 3337	: Vg=1.031677 -> Vg=1.0
% INFO    : Gen at bus 3338	: Pg=24.86, Qg=5.7 -> Pg=58.285, Qg=10.0
% INFO    : Gen at bus 3338	: Vg=0.997985 -> Vg=1.0
% INFO    : Gen at bus 3339	: Pg=22.13, Qg=5.02 -> Pg=57.375, Qg=10.0
% INFO    : Gen at bus 3339	: Vg=1.031677 -> Vg=1.0
% INFO    : Gen at bus 3343	: Pg=45.54, Qg=5.69 -> Pg=65.18, Qg=15.0
% INFO    : Gen at bus 3343	: Vg=1.044129 -> Vg=1.0
% INFO    : Gen at bus 3344	: Pg=172.98, Qg=103.13 -> Pg=250.0, Qg=60.0
% INFO    : Gen at bus 3344	: Vg=1.062747 -> Vg=1.0
% INFO    : Gen at bus 3348	: Pg=5.21, Qg=0.17 -> Pg=51.735, Qg=0.0
% INFO    : Gen at bus 3348	: Vg=1.02922 -> Vg=1.0
% INFO    : Gen at bus 3351	: Pg=19.26, Qg=2.33 -> Pg=56.42, Qg=10.0
% INFO    : Gen at bus 3351	: Vg=1.049756 -> Vg=1.0
% INFO    : Gen at bus 3352	: Pg=81.02, Qg=15.21 -> Pg=127.005, Qg=20.0
% INFO    : Gen at bus 3352	: Vg=1.035421 -> Vg=1.0
% INFO    : Gen at bus 3360	: Pg=0.43, Qg=-0.09 -> Pg=50.145, Qg=0.0
% INFO    : Gen at bus 3360	: Vg=1.024095 -> Vg=1.0
% INFO    : Gen at bus 3361	: Pg=25.75, Qg=4.04 -> Pg=58.585, Qg=10.0
% INFO    : Gen at bus 3361	: Vg=1.026025 -> Vg=1.0
% INFO    : Gen at bus 3365	: Pg=95.45, Qg=36.47 -> Pg=131.815, Qg=20.0
% INFO    : Gen at bus 3365	: Vg=1.060605 -> Vg=1.0
% INFO    : Gen at bus 3366	: Pg=95.45, Qg=36.47 -> Pg=131.815, Qg=20.0
% INFO    : Gen at bus 3366	: Vg=1.060605 -> Vg=1.0
% INFO    : Gen at bus 3367	: Pg=95.45, Qg=36.47 -> Pg=131.815, Qg=20.0
% INFO    : Gen at bus 3367	: Vg=1.060605 -> Vg=1.0
% INFO    : Gen at bus 3368	: Pg=95.45, Qg=36.47 -> Pg=131.815, Qg=20.0
% INFO    : Gen at bus 3368	: Vg=1.060605 -> Vg=1.0
% INFO    : Gen at bus 3369	: Pg=158.9, Qg=55.92 -> Pg=250.0, Qg=35.0
% INFO    : Gen at bus 3369	: Vg=1.000957 -> Vg=1.0
% INFO    : Gen at bus 3371	: Pg=19.75, Qg=-0.1 -> Pg=56.585, Qg=0.0
% INFO    : Gen at bus 3371	: Vg=1.002465 -> Vg=1.0
% INFO    : Gen at bus 3384	: Pg=35.95, Qg=6.39 -> Pg=61.985, Qg=15.0
% INFO    : Gen at bus 3384	: Vg=1.015185 -> Vg=1.0
% INFO    : Gen at bus 3385	: Pg=8.75, Qg=-0.1 -> Pg=52.915, Qg=0.0
% INFO    : Gen at bus 3385	: Vg=0.988654 -> Vg=1.0
% INFO    : Gen at bus 3396	: Pg=35.69, Qg=7.89 -> Pg=61.895, Qg=10.0
% INFO    : Gen at bus 3396	: Vg=1.017601 -> Vg=1.0
% INFO    : Gen at bus 3403	: Pg=67.68, Qg=4.49 -> Pg=122.56, Qg=20.0
% INFO    : Gen at bus 3403	: Vg=1.017078 -> Vg=1.0
% INFO    : Gen at bus 3404	: Pg=36.11, Qg=3.87 -> Pg=62.035, Qg=10.0
% INFO    : Gen at bus 3404	: Vg=1.024544 -> Vg=1.0
% INFO    : Gen at bus 3409	: Pg=15.52, Qg=0.02 -> Pg=55.175, Qg=0.0
% INFO    : Gen at bus 3409	: Vg=1.016693 -> Vg=1.0
% INFO    : Gen at bus 3410	: Pg=29.92, Qg=13.61 -> Pg=59.975, Qg=10.0
% INFO    : Gen at bus 3410	: Vg=1.031553 -> Vg=1.0
% INFO    : Gen at bus 3412	: Pg=86.41, Qg=23.5 -> Pg=128.805, Qg=20.0
% INFO    : Gen at bus 3412	: Vg=1.031898 -> Vg=1.0
% INFO    : Gen at bus 3414	: Pg=86.41, Qg=23.5 -> Pg=128.805, Qg=20.0
% INFO    : Gen at bus 3414	: Vg=1.031898 -> Vg=1.0
% INFO    : Gen at bus 3415	: Pg=86.41, Qg=23.5 -> Pg=128.805, Qg=20.0
% INFO    : Gen at bus 3415	: Vg=1.031898 -> Vg=1.0
% INFO    : Gen at bus 3416	: Pg=86.41, Qg=23.5 -> Pg=128.805, Qg=20.0
% INFO    : Gen at bus 3416	: Vg=1.031898 -> Vg=1.0
% INFO    : Gen at bus 3418	: Pg=87.19, Qg=27.18 -> Pg=129.065, Qg=20.0
% INFO    : Gen at bus 3418	: Vg=1.023338 -> Vg=1.0
% INFO    : Gen at bus 3419	: Pg=87.19, Qg=27.18 -> Pg=129.065, Qg=20.0
% INFO    : Gen at bus 3419	: Vg=1.023338 -> Vg=1.0
% INFO    : Gen at bus 3432	: Pg=29.4, Qg=8.8 -> Pg=59.8, Qg=5.0
% INFO    : Gen at bus 3432	: Vg=1.01809 -> Vg=1.0
% INFO    : Gen at bus 3451	: Pg=617.46, Qg=92.14 -> Pg=850.0, Qg=200.0
% INFO    : Gen at bus 3451	: Vg=1.032321 -> Vg=1.0
% INFO    : Gen at bus 3456	: Pg=32.69, Qg=0.72 -> Pg=60.895, Qg=15.0
% INFO    : Gen at bus 3456	: Vg=1.022332 -> Vg=1.0
% INFO    : Gen at bus 3463	: Pg=221.97, Qg=103.8 -> Pg=300.0, Qg=80.0
% INFO    : Gen at bus 3463	: Vg=1.063388 -> Vg=1.0
% INFO    : Gen at bus 3468	: Pg=37.23, Qg=4.01 -> Pg=62.41, Qg=10.0
% INFO    : Gen at bus 3468	: Vg=1.028283 -> Vg=1.0
% INFO    : Gen at bus 3469	: Pg=73.92, Qg=33.18 -> Pg=124.64, Qg=80.0
% INFO    : Gen at bus 3469	: Vg=1.034629 -> Vg=1.0
% INFO    : Gen at bus 3471	: Pg=37.66, Qg=9.24 -> Pg=62.555, Qg=10.0
% INFO    : Gen at bus 3471	: Vg=1.060112 -> Vg=1.0
% INFO    : Gen at bus 3481	: Pg=35.74, Qg=6.84 -> Pg=61.915, Qg=10.0
% INFO    : Gen at bus 3481	: Vg=1.040138 -> Vg=1.0
% INFO    : Gen at bus 3482	: Pg=84.68, Qg=7.94 -> Pg=128.225, Qg=20.0
% INFO    : Gen at bus 3482	: Vg=1.00657 -> Vg=1.0
% INFO    : Gen at bus 3485	: Pg=47.94, Qg=3.29 -> Pg=65.98, Qg=15.0
% INFO    : Gen at bus 3485	: Vg=1.023602 -> Vg=1.0
% INFO    : Gen at bus 3487	: Pg=47.94, Qg=3.29 -> Pg=65.98, Qg=15.0
% INFO    : Gen at bus 3487	: Vg=1.023603 -> Vg=1.0
% INFO    : Gen at bus 3488	: Pg=15.73, Qg=-3.4 -> Pg=55.245, Qg=-5.0
% INFO    : Gen at bus 3488	: Vg=0.975077 -> Vg=1.0
% INFO    : Gen at bus 3489	: Pg=47.94, Qg=3.29 -> Pg=65.98, Qg=15.0
% INFO    : Gen at bus 3489	: Vg=1.023602 -> Vg=1.0
% INFO    : Gen at bus 3490	: Pg=47.94, Qg=3.29 -> Pg=65.98, Qg=15.0
% INFO    : Gen at bus 3490	: Vg=1.023602 -> Vg=1.0
% INFO    : Gen at bus 3491	: Pg=38.05, Qg=10.9 -> Pg=62.685, Qg=10.0
% INFO    : Gen at bus 3491	: Vg=1.037557 -> Vg=1.0
% INFO    : Gen at bus 3494	: Pg=391.23, Qg=71.04 -> Pg=500.0, Qg=80.0
% INFO    : Gen at bus 3494	: Vg=1.036517 -> Vg=1.0
% INFO    : Gen at bus 3495	: Pg=391.23, Qg=71.04 -> Pg=500.0, Qg=80.0
% INFO    : Gen at bus 3495	: Vg=1.036517 -> Vg=1.0
% INFO    : Gen at bus 3496	: Pg=391.23, Qg=71.04 -> Pg=500.0, Qg=80.0
% INFO    : Gen at bus 3496	: Vg=1.036517 -> Vg=1.0
% INFO    : Gen at bus 3499	: Pg=31.3, Qg=-0.89 -> Pg=60.435, Qg=0.0
% INFO    : Gen at bus 3499	: Vg=0.998951 -> Vg=1.0
% INFO    : Gen at bus 3508	: Pg=24.86, Qg=7.42 -> Pg=58.285, Qg=10.0
% INFO    : Gen at bus 3508	: Vg=1.01212 -> Vg=1.0
% INFO    : Gen at bus 3515	: Pg=80.4, Qg=12.89 -> Pg=126.8, Qg=20.0
% INFO    : Gen at bus 3515	: Vg=1.045647 -> Vg=1.0
% INFO    : Gen at bus 3517	: Pg=31.79, Qg=7.29 -> Pg=60.595, Qg=10.0
% INFO    : Gen at bus 3517	: Vg=1.005112 -> Vg=1.0
% INFO    : Gen at bus 3520	: Pg=33.68, Qg=6.27 -> Pg=61.225, Qg=10.0
% INFO    : Gen at bus 3520	: Vg=1.046665 -> Vg=1.0
% INFO    : Gen at bus 3521	: Pg=33.68, Qg=6.27 -> Pg=61.225, Qg=10.0
% INFO    : Gen at bus 3521	: Vg=1.046665 -> Vg=1.0
% INFO    : Gen at bus 3523	: Pg=33.68, Qg=6.27 -> Pg=61.225, Qg=10.0
% INFO    : Gen at bus 3523	: Vg=1.046665 -> Vg=1.0
% INFO    : Gen at bus 3524	: Pg=33.68, Qg=6.27 -> Pg=61.225, Qg=10.0
% INFO    : Gen at bus 3524	: Vg=1.046665 -> Vg=1.0
% INFO    : Gen at bus 3525	: Pg=33.68, Qg=6.27 -> Pg=61.225, Qg=10.0
% INFO    : Gen at bus 3525	: Vg=1.046665 -> Vg=1.0
% INFO    : Gen at bus 3526	: Pg=33.68, Qg=6.27 -> Pg=61.225, Qg=10.0
% INFO    : Gen at bus 3526	: Vg=1.046665 -> Vg=1.0
% INFO    : Gen at bus 3528	: Pg=81.96, Qg=34.23 -> Pg=127.32, Qg=20.0
% INFO    : Gen at bus 3528	: Vg=1.031098 -> Vg=1.0
% INFO    : Gen at bus 3529	: Pg=81.96, Qg=34.23 -> Pg=127.32, Qg=20.0
% INFO    : Gen at bus 3529	: Vg=1.031098 -> Vg=1.0
% INFO    : Gen at bus 3530	: Pg=81.96, Qg=34.23 -> Pg=127.32, Qg=20.0
% INFO    : Gen at bus 3530	: Vg=1.031098 -> Vg=1.0
% INFO    : Gen at bus 3535	: Pg=90.48, Qg=33.58 -> Pg=130.16, Qg=20.0
% INFO    : Gen at bus 3535	: Vg=1.043665 -> Vg=1.0
% INFO    : Gen at bus 3543	: Pg=29.65, Qg=15.88 -> Pg=59.885, Qg=10.0
% INFO    : Gen at bus 3543	: Vg=1.051307 -> Vg=1.0
% INFO    : Gen at bus 3551	: Pg=209.93, Qg=1.9 -> Pg=300.0, Qg=80.0
% INFO    : Gen at bus 3551	: Vg=1.045549 -> Vg=1.0
% INFO    : Gen at bus 3553	: Pg=219.68, Qg=138.48 -> Pg=300.0, Qg=60.0
% INFO    : Gen at bus 3553	: Vg=1.048632 -> Vg=1.0
% INFO    : Gen at bus 3557	: Pg=863.42, Qg=301.07 -> Pg=1150.0, Qg=200.0
% INFO    : Gen at bus 3557	: Vg=1.066429 -> Vg=1.0
% INFO    : Gen at bus 3558	: Pg=863.4, Qg=229.87 -> Pg=1150.0, Qg=200.0
% INFO    : Gen at bus 3558	: Vg=1.06254 -> Vg=1.0
% INFO    : Gen at bus 3567	: Pg=50.0, Qg=-0.52 -> Pg=116.665, Qg=5.0
% INFO    : Gen at bus 3567	: Vg=0.992476 -> Vg=1.0
% INFO    : Gen at bus 3569	: Pg=38.22, Qg=19.69 -> Pg=62.74, Qg=10.0
% INFO    : Gen at bus 3569	: Vg=1.056202 -> Vg=1.0
% INFO    : Gen at bus 3571	: Pg=31.45, Qg=10.87 -> Pg=60.485, Qg=10.0
% INFO    : Gen at bus 3571	: Vg=1.043771 -> Vg=1.0
% INFO    : Gen at bus 3577	: Pg=38.79, Qg=7.11 -> Pg=62.93, Qg=10.0
% INFO    : Gen at bus 3577	: Vg=1.035838 -> Vg=1.0
% INFO    : Gen at bus 3580	: Pg=23.53, Qg=19.57 -> Pg=57.845, Qg=10.0
% INFO    : Gen at bus 3580	: Vg=1.054138 -> Vg=1.0
% INFO    : Gen at bus 3582	: Pg=23.53, Qg=19.57 -> Pg=57.845, Qg=10.0
% INFO    : Gen at bus 3582	: Vg=1.054138 -> Vg=1.0
% INFO    : Gen at bus 3585	: Pg=257.98, Qg=85.38 -> Pg=350.0, Qg=80.0
% INFO    : Gen at bus 3585	: Vg=1.037254 -> Vg=1.0
% INFO    : Gen at bus 3586	: Pg=257.98, Qg=85.38 -> Pg=350.0, Qg=80.0
% INFO    : Gen at bus 3586	: Vg=1.037254 -> Vg=1.0
% INFO    : Gen at bus 3587	: Pg=225.92, Qg=112.91 -> Pg=300.0, Qg=80.0
% INFO    : Gen at bus 3587	: Vg=1.033975 -> Vg=1.0
% INFO    : Gen at bus 3588	: Pg=225.92, Qg=112.91 -> Pg=300.0, Qg=80.0
% INFO    : Gen at bus 3588	: Vg=1.033975 -> Vg=1.0
% INFO    : Gen at bus 3593	: Pg=43.18, Qg=13.4 -> Pg=64.395, Qg=10.0
% INFO    : Gen at bus 3593	: Vg=1.017275 -> Vg=1.0
% INFO    : Gen at bus 3607	: Pg=200.19, Qg=-0.55 -> Pg=300.0, Qg=60.0
% INFO    : Gen at bus 3607	: Vg=1.039371 -> Vg=1.0
% INFO    : Gen at bus 3608	: Pg=19.98, Qg=0.98 -> Pg=56.66, Qg=10.0
% INFO    : Gen at bus 3608	: Vg=1.029635 -> Vg=1.0
% INFO    : Gen at bus 3610	: Pg=332.36, Qg=180.64 -> Pg=450.0, Qg=80.0
% INFO    : Gen at bus 3610	: Vg=1.068762 -> Vg=1.0
% INFO    : Gen at bus 3611	: Pg=332.36, Qg=180.64 -> Pg=450.0, Qg=80.0
% INFO    : Gen at bus 3611	: Vg=1.068762 -> Vg=1.0
% INFO    : Gen at bus 3617	: Pg=21.77, Qg=6.35 -> Pg=57.255, Qg=10.0
% INFO    : Gen at bus 3617	: Vg=1.024499 -> Vg=1.0
% INFO    : Gen at bus 3619	: Pg=30.04, Qg=7.07 -> Pg=60.015, Qg=10.0
% INFO    : Gen at bus 3619	: Vg=1.043657 -> Vg=1.0
% INFO    : Gen at bus 3620	: Pg=30.04, Qg=7.07 -> Pg=60.015, Qg=10.0
% INFO    : Gen at bus 3620	: Vg=1.043657 -> Vg=1.0
% INFO    : Gen at bus 3621	: Pg=29.76, Qg=14.06 -> Pg=59.92, Qg=5.0
% INFO    : Gen at bus 3621	: Vg=1.030254 -> Vg=1.0
% INFO    : Gen at bus 3625	: Pg=29.84, Qg=3.47 -> Pg=59.945, Qg=10.0
% INFO    : Gen at bus 3625	: Vg=1.022039 -> Vg=1.0
% INFO    : Gen at bus 3631	: Pg=79.99, Qg=47.72 -> Pg=126.665, Qg=20.0
% INFO    : Gen at bus 3631	: Vg=1.050006 -> Vg=1.0
% INFO    : Gen at bus 3633	: Pg=26.75, Qg=6.78 -> Pg=58.915, Qg=15.0
% INFO    : Gen at bus 3633	: Vg=1.024572 -> Vg=1.0
% INFO    : Gen at bus 3641	: Pg=17.27, Qg=6.34 -> Pg=55.755, Qg=10.0
% INFO    : Gen at bus 3641	: Vg=1.03809 -> Vg=1.0
% INFO    : Gen at bus 3642	: Pg=17.27, Qg=6.34 -> Pg=55.755, Qg=10.0
% INFO    : Gen at bus 3642	: Vg=1.03809 -> Vg=1.0
% INFO    : Gen at bus 3644	: Pg=87.35, Qg=17.85 -> Pg=129.115, Qg=20.0
% INFO    : Gen at bus 3644	: Vg=1.033768 -> Vg=1.0
% INFO    : Gen at bus 3646	: Pg=23.01, Qg=6.63 -> Pg=57.67, Qg=10.0
% INFO    : Gen at bus 3646	: Vg=1.01964 -> Vg=1.0
% INFO    : Gen at bus 3647	: Pg=81.35, Qg=28.89 -> Pg=127.115, Qg=20.0
% INFO    : Gen at bus 3647	: Vg=1.055981 -> Vg=1.0
% INFO    : Gen at bus 3651	: Pg=96.29, Qg=19.0 -> Pg=132.095, Qg=20.0
% INFO    : Gen at bus 3651	: Vg=1.037131 -> Vg=1.0
% INFO    : Gen at bus 3655	: Pg=94.28, Qg=43.72 -> Pg=131.425, Qg=20.0
% INFO    : Gen at bus 3655	: Vg=1.048808 -> Vg=1.0
% INFO    : Gen at bus 3656	: Pg=96.29, Qg=19.0 -> Pg=132.095, Qg=20.0
% INFO    : Gen at bus 3656	: Vg=1.037131 -> Vg=1.0
% INFO    : Gen at bus 3663	: Pg=99.7, Qg=4.57 -> Pg=133.235, Qg=20.0
% INFO    : Gen at bus 3663	: Vg=1.028091 -> Vg=1.0
% INFO    : Gen at bus 3671	: Pg=93.11, Qg=0.33 -> Pg=131.035, Qg=20.0
% INFO    : Gen at bus 3671	: Vg=1.038581 -> Vg=1.0
% INFO    : Gen at bus 3672	: Pg=93.11, Qg=0.33 -> Pg=131.035, Qg=20.0
% INFO    : Gen at bus 3672	: Vg=1.038581 -> Vg=1.0
% INFO    : Gen at bus 3674	: Pg=4.27, Qg=0.56 -> Pg=51.425, Qg=0.0
% INFO    : Gen at bus 3674	: Vg=1.021115 -> Vg=1.0
% INFO    : Gen at bus 3675	: Pg=5.27, Qg=0.07 -> Pg=51.755, Qg=0.0
% INFO    : Gen at bus 3675	: Vg=1.025842 -> Vg=1.0
% INFO    : Gen at bus 3680	: Pg=20.91, Qg=7.74 -> Pg=56.97, Qg=10.0
% INFO    : Gen at bus 3680	: Vg=1.014154 -> Vg=1.0
% INFO    : Gen at bus 3682	: Pg=17.0, Qg=6.28 -> Pg=55.665, Qg=5.0
% INFO    : Gen at bus 3682	: Vg=1.023493 -> Vg=1.0
% INFO    : Gen at bus 3683	: Pg=36.8, Qg=6.62 -> Pg=62.265, Qg=10.0
% INFO    : Gen at bus 3683	: Vg=1.03058 -> Vg=1.0
% INFO    : Gen at bus 3686	: Pg=53.13, Qg=-3.75 -> Pg=117.71, Qg=0.0
% INFO    : Gen at bus 3686	: Vg=1.003179 -> Vg=1.0
% INFO    : Gen at bus 3695	: Pg=54.83, Qg=12.78 -> Pg=118.275, Qg=15.0
% INFO    : Gen at bus 3695	: Vg=1.047752 -> Vg=1.0
% INFO    : Gen at bus 3696	: Pg=54.83, Qg=12.78 -> Pg=118.275, Qg=15.0
% INFO    : Gen at bus 3696	: Vg=1.047752 -> Vg=1.0
% INFO    : Gen at bus 3697	: Pg=54.83, Qg=12.78 -> Pg=118.275, Qg=15.0
% INFO    : Gen at bus 3697	: Vg=1.047752 -> Vg=1.0
% INFO    : Gen at bus 3698	: Pg=54.83, Qg=12.78 -> Pg=118.275, Qg=15.0
% INFO    : Gen at bus 3698	: Vg=1.047752 -> Vg=1.0
% INFO    : Gen at bus 3699	: Pg=54.83, Qg=12.78 -> Pg=118.275, Qg=15.0
% INFO    : Gen at bus 3699	: Vg=1.047752 -> Vg=1.0
% INFO    : Gen at bus 3700	: Pg=54.83, Qg=12.78 -> Pg=118.275, Qg=15.0
% INFO    : Gen at bus 3700	: Vg=1.047752 -> Vg=1.0
% INFO    : Gen at bus 3701	: Pg=54.83, Qg=12.78 -> Pg=118.275, Qg=15.0
% INFO    : Gen at bus 3701	: Vg=1.047752 -> Vg=1.0
% INFO    : Gen at bus 3710	: Pg=95.02, Qg=8.09 -> Pg=131.675, Qg=20.0
% INFO    : Gen at bus 3710	: Vg=1.023144 -> Vg=1.0
% INFO    : Gen at bus 3712	: Pg=36.6, Qg=6.27 -> Pg=62.2, Qg=10.0
% INFO    : Gen at bus 3712	: Vg=1.027328 -> Vg=1.0
% INFO    : Gen at bus 3714	: Pg=36.6, Qg=6.27 -> Pg=62.2, Qg=10.0
% INFO    : Gen at bus 3714	: Vg=1.027328 -> Vg=1.0
% INFO    : Gen at bus 3717	: Pg=91.41, Qg=18.38 -> Pg=130.47, Qg=20.0
% INFO    : Gen at bus 3717	: Vg=1.020566 -> Vg=1.0
% INFO    : Gen at bus 3718	: Pg=91.41, Qg=18.38 -> Pg=130.47, Qg=20.0
% INFO    : Gen at bus 3718	: Vg=1.020566 -> Vg=1.0
% INFO    : Gen at bus 3720	: Pg=91.41, Qg=18.38 -> Pg=130.47, Qg=20.0
% INFO    : Gen at bus 3720	: Vg=1.020566 -> Vg=1.0
% INFO    : Gen at bus 3724	: Pg=586.88, Qg=407.04 -> Pg=750.0, Qg=200.0
% INFO    : Gen at bus 3724	: Vg=1.052406 -> Vg=1.0
% INFO    : Gen at bus 3728	: Pg=74.79, Qg=37.77 -> Pg=124.93, Qg=20.0
% INFO    : Gen at bus 3728	: Vg=1.041161 -> Vg=1.0
% INFO    : Gen at bus 3729	: Pg=74.79, Qg=37.77 -> Pg=124.93, Qg=20.0
% INFO    : Gen at bus 3729	: Vg=1.041161 -> Vg=1.0
% INFO    : Gen at bus 3738	: Pg=25.0, Qg=6.1 -> Pg=58.335, Qg=5.0
% INFO    : Gen at bus 3738	: Vg=1.024613 -> Vg=1.0
% INFO    : Gen at bus 3754	: Pg=285.52, Qg=89.66 -> Pg=350.0, Qg=80.0
% INFO    : Gen at bus 3754	: Vg=1.04459 -> Vg=1.0
% INFO    : Gen at bus 3757	: Pg=285.52, Qg=89.66 -> Pg=350.0, Qg=80.0
% INFO    : Gen at bus 3757	: Vg=1.04459 -> Vg=1.0
% INFO    : Gen at bus 3763	: Pg=46.38, Qg=17.23 -> Pg=65.46, Qg=15.0
% INFO    : Gen at bus 3763	: Vg=1.048358 -> Vg=1.0
% INFO    : Gen at bus 3771	: Pg=26.56, Qg=10.95 -> Pg=58.855, Qg=10.0
% INFO    : Gen at bus 3771	: Vg=1.002675 -> Vg=1.0
% INFO    : Gen at bus 3781	: Pg=80.4, Qg=12.89 -> Pg=126.8, Qg=20.0
% INFO    : Gen at bus 3781	: Vg=1.045647 -> Vg=1.0
% INFO    : Gen at bus 3782	: Pg=80.4, Qg=12.89 -> Pg=126.8, Qg=20.0
% INFO    : Gen at bus 3782	: Vg=1.045647 -> Vg=1.0
% INFO    : Gen at bus 3787	: Pg=80.4, Qg=12.89 -> Pg=126.8, Qg=20.0
% INFO    : Gen at bus 3787	: Vg=1.045647 -> Vg=1.0
% INFO    : Gen at bus 3792	: Pg=72.61, Qg=29.56 -> Pg=124.205, Qg=20.0
% INFO    : Gen at bus 3792	: Vg=1.041629 -> Vg=1.0
% INFO    : Gen at bus 3797	: Pg=344.6, Qg=7.8 -> Pg=450.0, Qg=20.0
% INFO    : Gen at bus 3797	: Vg=0.97953 -> Vg=1.0
% INFO    : Gen at bus 3800	: Pg=69.42, Qg=1.26 -> Pg=123.14, Qg=20.0
% INFO    : Gen at bus 3800	: Vg=1.034738 -> Vg=1.0
% INFO    : Gen at bus 3810	: Pg=22.28, Qg=12.48 -> Pg=57.425, Qg=10.0
% INFO    : Gen at bus 3810	: Vg=1.043637 -> Vg=1.0
% INFO    : Gen at bus 3811	: Pg=38.05, Qg=10.9 -> Pg=62.685, Qg=10.0
% INFO    : Gen at bus 3811	: Vg=1.037557 -> Vg=1.0
% INFO    : Gen at bus 3812	: Pg=38.05, Qg=10.9 -> Pg=62.685, Qg=10.0
% INFO    : Gen at bus 3812	: Vg=1.037557 -> Vg=1.0
% INFO    : Gen at bus 3814	: Pg=7.28, Qg=-1.45 -> Pg=52.425, Qg=0.0
% INFO    : Gen at bus 3814	: Vg=0.990319 -> Vg=1.0
% INFO    : Gen at bus 3815	: Pg=26.31, Qg=9.5 -> Pg=58.77, Qg=10.0
% INFO    : Gen at bus 3815	: Vg=1.038225 -> Vg=1.0
% INFO    : Gen at bus 3816	: Pg=26.31, Qg=9.5 -> Pg=58.77, Qg=10.0
% INFO    : Gen at bus 3816	: Vg=1.038225 -> Vg=1.0
% INFO    : Gen at bus 3820	: Pg=22.28, Qg=12.48 -> Pg=57.425, Qg=10.0
% INFO    : Gen at bus 3820	: Vg=1.043637 -> Vg=1.0
% INFO    : Gen at bus 3823	: Pg=74.8, Qg=42.23 -> Pg=124.935, Qg=20.0
% INFO    : Gen at bus 3823	: Vg=1.046905 -> Vg=1.0
% INFO    : Gen at bus 3838	: Pg=26.29, Qg=7.55 -> Pg=58.765, Qg=10.0
% INFO    : Gen at bus 3838	: Vg=1.004212 -> Vg=1.0
% INFO    : Gen at bus 3842	: Pg=3.2, Qg=1.16 -> Pg=51.065, Qg=0.0
% INFO    : Gen at bus 3842	: Vg=0.991765 -> Vg=1.0
% INFO    : Gen at bus 3845	: Pg=37.08, Qg=5.51 -> Pg=62.36, Qg=10.0
% INFO    : Gen at bus 3845	: Vg=1.021005 -> Vg=1.0
% INFO    : Gen at bus 3848	: Pg=9.0, Qg=-0.95 -> Pg=53.0, Qg=0.0
% INFO    : Gen at bus 3848	: Vg=0.943602 -> Vg=1.0
% INFO    : Gen at bus 3853	: Pg=33.75, Qg=8.82 -> Pg=61.25, Qg=15.0
% INFO    : Gen at bus 3853	: Vg=0.999522 -> Vg=1.0
% INFO    : Gen at bus 3854	: Pg=30.9, Qg=1.92 -> Pg=60.3, Qg=10.0
% INFO    : Gen at bus 3854	: Vg=1.015954 -> Vg=1.0
% INFO    : Gen at bus 3857	: Pg=46.26, Qg=7.53 -> Pg=65.42, Qg=15.0
% INFO    : Gen at bus 3857	: Vg=1.015006 -> Vg=1.0
% INFO    : Gen at bus 3866	: Pg=239.85, Qg=38.05 -> Pg=300.0, Qg=60.0
% INFO    : Gen at bus 3866	: Vg=1.032762 -> Vg=1.0
% INFO    : Gen at bus 3867	: Pg=239.85, Qg=38.05 -> Pg=300.0, Qg=60.0
% INFO    : Gen at bus 3867	: Vg=1.032762 -> Vg=1.0
% INFO    : Gen at bus 3872	: Pg=6.0, Qg=1.0 -> Pg=52.0, Qg=0.0
% INFO    : Gen at bus 3872	: Vg=0.972026 -> Vg=1.0
% INFO    : Gen at bus 3877	: Pg=35.95, Qg=6.39 -> Pg=61.985, Qg=15.0
% INFO    : Gen at bus 3877	: Vg=1.015185 -> Vg=1.0
% INFO    : Gen at bus 3878	: Pg=27.67, Qg=4.45 -> Pg=59.225, Qg=10.0
% INFO    : Gen at bus 3878	: Vg=1.027132 -> Vg=1.0
% INFO    : Gen at bus 3880	: Pg=18.1, Qg=0.8 -> Pg=56.035, Qg=0.0
% INFO    : Gen at bus 3880	: Vg=1.007227 -> Vg=1.0
% INFO    : Gen at bus 3893	: Pg=16.08, Qg=-1.58 -> Pg=55.36, Qg=0.0
% INFO    : Gen at bus 3893	: Vg=1.025595 -> Vg=1.0
% INFO    : Gen at bus 3894	: Pg=3.84, Qg=0.45 -> Pg=51.28, Qg=0.0
% INFO    : Gen at bus 3894	: Vg=1.030843 -> Vg=1.0
% INFO    : Gen at bus 3899	: Pg=36.42, Qg=7.96 -> Pg=62.14, Qg=10.0
% INFO    : Gen at bus 3899	: Vg=1.029166 -> Vg=1.0
% INFO    : Gen at bus 3903	: Pg=49.08, Qg=7.63 -> Pg=66.36, Qg=20.0
% INFO    : Gen at bus 3903	: Vg=0.988537 -> Vg=1.0
% INFO    : Gen at bus 3904	: Pg=93.77, Qg=48.62 -> Pg=131.255, Qg=20.0
% INFO    : Gen at bus 3904	: Vg=1.054388 -> Vg=1.0
% INFO    : Gen at bus 3906	: Pg=28.92, Qg=12.55 -> Pg=59.64, Qg=15.0
% INFO    : Gen at bus 3906	: Vg=1.019357 -> Vg=1.0
% INFO    : Gen at bus 3907	: Pg=28.92, Qg=12.55 -> Pg=59.64, Qg=15.0
% INFO    : Gen at bus 3907	: Vg=1.019357 -> Vg=1.0
% INFO    : Gen at bus 3908	: Pg=28.92, Qg=12.55 -> Pg=59.64, Qg=15.0
% INFO    : Gen at bus 3908	: Vg=1.019357 -> Vg=1.0
% INFO    : Gen at bus 3909	: Pg=28.92, Qg=12.55 -> Pg=59.64, Qg=15.0
% INFO    : Gen at bus 3909	: Vg=1.019357 -> Vg=1.0
% INFO    : Gen at bus 3910	: Pg=28.92, Qg=12.55 -> Pg=59.64, Qg=15.0
% INFO    : Gen at bus 3910	: Vg=1.019357 -> Vg=1.0
% INFO    : Gen at bus 3911	: Pg=28.92, Qg=12.55 -> Pg=59.64, Qg=15.0
% INFO    : Gen at bus 3911	: Vg=1.019357 -> Vg=1.0
% INFO    : Gen at bus 3912	: Pg=49.34, Qg=9.15 -> Pg=66.445, Qg=15.0
% INFO    : Gen at bus 3912	: Vg=1.034597 -> Vg=1.0
% INFO    : Gen at bus 3913	: Pg=52.7, Qg=8.59 -> Pg=117.565, Qg=20.0
% INFO    : Gen at bus 3913	: Vg=1.008149 -> Vg=1.0
% INFO    : Gen at bus 3914	: Pg=93.77, Qg=48.62 -> Pg=131.255, Qg=20.0
% INFO    : Gen at bus 3914	: Vg=1.054388 -> Vg=1.0
% INFO    : Gen at bus 3915	: Pg=36.77, Qg=13.93 -> Pg=62.255, Qg=10.0
% INFO    : Gen at bus 3915	: Vg=1.042317 -> Vg=1.0
% INFO    : Gen at bus 3916	: Pg=28.12, Qg=1.08 -> Pg=59.375, Qg=10.0
% INFO    : Gen at bus 3916	: Vg=1.028994 -> Vg=1.0
% INFO    : Gen at bus 3922	: Pg=100.29, Qg=29.56 -> Pg=183.43, Qg=20.0
% INFO    : Gen at bus 3922	: Vg=1.064335 -> Vg=1.0
% INFO    : Gen at bus 3926	: Pg=230.0, Qg=25.76 -> Pg=300.0, Qg=45.0
% INFO    : Gen at bus 3926	: Vg=0.984593 -> Vg=1.0
% INFO    : Gen at bus 3929	: Pg=18.32, Qg=-0.94 -> Pg=56.105, Qg=0.0
% INFO    : Gen at bus 3929	: Vg=0.995077 -> Vg=1.0
% INFO    : Gen at bus 3934	: Pg=30.46, Qg=6.53 -> Pg=60.155, Qg=5.0
% INFO    : Gen at bus 3934	: Vg=0.997643 -> Vg=1.0
% INFO    : Gen at bus 3939	: Pg=210.0, Qg=15.07 -> Pg=300.0, Qg=35.0
% INFO    : Gen at bus 3939	: Vg=0.980209 -> Vg=1.0
% INFO    : Gen at bus 3943	: Pg=174.02, Qg=89.48 -> Pg=250.0, Qg=80.0
% INFO    : Gen at bus 3943	: Vg=1.046877 -> Vg=1.0
% INFO    : Gen at bus 3947	: Pg=30.07, Qg=6.48 -> Pg=60.025, Qg=10.0
% INFO    : Gen at bus 3947	: Vg=1.058835 -> Vg=1.0
% INFO    : Gen at bus 3948	: Pg=58.8, Qg=-10.54 -> Pg=119.6, Qg=0.0
% INFO    : Gen at bus 3948	: Vg=0.9646 -> Vg=1.0
% INFO    : Gen at bus 3962	: Pg=88.32, Qg=56.36 -> Pg=129.44, Qg=20.0
% INFO    : Gen at bus 3962	: Vg=1.127961 -> Vg=1.0
% INFO    : Gen at bus 3968	: Pg=44.1, Qg=5.46 -> Pg=64.7, Qg=15.0
% INFO    : Gen at bus 3968	: Vg=0.988831 -> Vg=1.0
% INFO    : Gen at bus 3971	: Pg=72.47, Qg=11.44 -> Pg=124.155, Qg=20.0
% INFO    : Gen at bus 3971	: Vg=1.019231 -> Vg=1.0
% INFO    : Gen at bus 3984	: Pg=227.37, Qg=10.01 -> Pg=300.0, Qg=60.0
% INFO    : Gen at bus 3984	: Vg=1.028414 -> Vg=1.0
% INFO    : Gen at bus 3990	: Pg=27.19, Qg=6.05 -> Pg=59.065, Qg=10.0
% INFO    : Gen at bus 3990	: Vg=1.014542 -> Vg=1.0
% INFO    : Gen at bus 3997	: Pg=96.9, Qg=14.27 -> Pg=132.3, Qg=20.0
% INFO    : Gen at bus 3997	: Vg=1.033735 -> Vg=1.0
% INFO    : Gen at bus 4000	: Pg=100.41, Qg=11.92 -> Pg=183.47, Qg=20.0
% INFO    : Gen at bus 4000	: Vg=1.038747 -> Vg=1.0
% INFO    : Gen at bus 4004	: Pg=90.48, Qg=33.58 -> Pg=130.16, Qg=20.0
% INFO    : Gen at bus 4004	: Vg=1.043665 -> Vg=1.0
% INFO    : Gen at bus 4009	: Pg=0.08, Qg=-0.15 -> Pg=50.025, Qg=0.0
% INFO    : Gen at bus 4009	: Vg=1.016106 -> Vg=1.0
% INFO    : Gen at bus 4011	: Pg=25.24, Qg=9.06 -> Pg=58.415, Qg=10.0
% INFO    : Gen at bus 4011	: Vg=1.045295 -> Vg=1.0
% INFO    : Gen at bus 4013	: Pg=200.33, Qg=74.16 -> Pg=300.0, Qg=80.0
% INFO    : Gen at bus 4013	: Vg=1.024096 -> Vg=1.0
% INFO    : Gen at bus 4020	: Pg=28.05, Qg=6.93 -> Pg=59.35, Qg=10.0
% INFO    : Gen at bus 4020	: Vg=1.035469 -> Vg=1.0
% INFO    : Gen at bus 4021	: Pg=28.05, Qg=6.93 -> Pg=59.35, Qg=10.0
% INFO    : Gen at bus 4021	: Vg=1.035469 -> Vg=1.0
% INFO    : Gen at bus 4022	: Pg=38.97, Qg=3.58 -> Pg=62.99, Qg=10.0
% INFO    : Gen at bus 4022	: Vg=1.048029 -> Vg=1.0
% INFO    : Gen at bus 4024	: Pg=27.42, Qg=7.69 -> Pg=59.14, Qg=10.0
% INFO    : Gen at bus 4024	: Vg=1.049669 -> Vg=1.0
% INFO    : Gen at bus 4025	: Pg=27.42, Qg=7.69 -> Pg=59.14, Qg=10.0
% INFO    : Gen at bus 4025	: Vg=1.049669 -> Vg=1.0
% INFO    : Gen at bus 4026	: Pg=23.99, Qg=10.2 -> Pg=57.995, Qg=10.0
% INFO    : Gen at bus 4026	: Vg=1.045658 -> Vg=1.0
% INFO    : Gen at bus 4027	: Pg=23.99, Qg=10.2 -> Pg=57.995, Qg=10.0
% INFO    : Gen at bus 4027	: Vg=1.045658 -> Vg=1.0
% INFO    : Gen at bus 4039	: Pg=30.91, Qg=13.15 -> Pg=60.305, Qg=10.0
% INFO    : Gen at bus 4039	: Vg=1.040404 -> Vg=1.0
% INFO    : Gen at bus 4040	: Pg=30.91, Qg=13.15 -> Pg=60.305, Qg=10.0
% INFO    : Gen at bus 4040	: Vg=1.040404 -> Vg=1.0
% INFO    : Gen at bus 4041	: Pg=17.82, Qg=3.95 -> Pg=55.94, Qg=10.0
% INFO    : Gen at bus 4041	: Vg=1.066829 -> Vg=1.0
% INFO    : Gen at bus 4042	: Pg=30.91, Qg=13.15 -> Pg=60.305, Qg=10.0
% INFO    : Gen at bus 4042	: Vg=1.040404 -> Vg=1.0
% INFO    : Gen at bus 4043	: Pg=28.62, Qg=19.42 -> Pg=59.54, Qg=10.0
% INFO    : Gen at bus 4043	: Vg=1.048055 -> Vg=1.0
% INFO    : Gen at bus 4044	: Pg=28.62, Qg=19.42 -> Pg=59.54, Qg=10.0
% INFO    : Gen at bus 4044	: Vg=1.048055 -> Vg=1.0
% INFO    : Gen at bus 4045	: Pg=39.58, Qg=7.79 -> Pg=63.195, Qg=10.0
% INFO    : Gen at bus 4045	: Vg=1.022502 -> Vg=1.0
% INFO    : Gen at bus 4047	: Pg=36.43, Qg=14.37 -> Pg=62.145, Qg=10.0
% INFO    : Gen at bus 4047	: Vg=1.048211 -> Vg=1.0
% INFO    : Gen at bus 4048	: Pg=26.97, Qg=7.32 -> Pg=58.99, Qg=10.0
% INFO    : Gen at bus 4048	: Vg=1.049221 -> Vg=1.0
% INFO    : Gen at bus 4049	: Pg=29.57, Qg=20.51 -> Pg=59.855, Qg=10.0
% INFO    : Gen at bus 4049	: Vg=1.041409 -> Vg=1.0
% INFO    : Gen at bus 4052	: Pg=42.63, Qg=9.46 -> Pg=64.21, Qg=10.0
% INFO    : Gen at bus 4052	: Vg=1.001216 -> Vg=1.0
% INFO    : Gen at bus 4053	: Pg=90.32, Qg=31.5 -> Pg=130.105, Qg=20.0
% INFO    : Gen at bus 4053	: Vg=1.035102 -> Vg=1.0
% INFO    : Gen at bus 4054	: Pg=90.32, Qg=31.5 -> Pg=130.105, Qg=20.0
% INFO    : Gen at bus 4054	: Vg=1.035102 -> Vg=1.0
% INFO    : Gen at bus 4056	: Pg=90.32, Qg=31.5 -> Pg=130.105, Qg=20.0
% INFO    : Gen at bus 4056	: Vg=1.035102 -> Vg=1.0
% INFO    : Gen at bus 4057	: Pg=86.85, Qg=27.93 -> Pg=128.95, Qg=20.0
% INFO    : Gen at bus 4057	: Vg=1.028397 -> Vg=1.0
% INFO    : Gen at bus 4058	: Pg=86.85, Qg=27.93 -> Pg=128.95, Qg=20.0
% INFO    : Gen at bus 4058	: Vg=1.028397 -> Vg=1.0
% INFO    : Gen at bus 4059	: Pg=86.85, Qg=27.93 -> Pg=128.95, Qg=20.0
% INFO    : Gen at bus 4059	: Vg=1.028397 -> Vg=1.0
% INFO    : Gen at bus 4060	: Pg=86.85, Qg=27.93 -> Pg=128.95, Qg=20.0
% INFO    : Gen at bus 4060	: Vg=1.028397 -> Vg=1.0
% INFO    : Gen at bus 4061	: Pg=86.85, Qg=27.93 -> Pg=128.95, Qg=20.0
% INFO    : Gen at bus 4061	: Vg=1.028397 -> Vg=1.0
% INFO    : Gen at bus 4062	: Pg=86.85, Qg=27.93 -> Pg=128.95, Qg=20.0
% INFO    : Gen at bus 4062	: Vg=1.028397 -> Vg=1.0
% INFO    : Gen at bus 4063	: Pg=43.29, Qg=23.54 -> Pg=64.43, Qg=20.0
% INFO    : Gen at bus 4063	: Vg=1.035771 -> Vg=1.0
% INFO    : Gen at bus 4066	: Pg=49.88, Qg=7.11 -> Pg=66.625, Qg=15.0
% INFO    : Gen at bus 4066	: Vg=1.013219 -> Vg=1.0
% INFO    : Gen at bus 4067	: Pg=49.88, Qg=7.11 -> Pg=66.625, Qg=15.0
% INFO    : Gen at bus 4067	: Vg=1.013219 -> Vg=1.0
% INFO    : Gen at bus 4068	: Pg=49.88, Qg=7.11 -> Pg=66.625, Qg=15.0
% INFO    : Gen at bus 4068	: Vg=1.013219 -> Vg=1.0
% INFO    : Gen at bus 4069	: Pg=49.88, Qg=7.11 -> Pg=66.625, Qg=15.0
% INFO    : Gen at bus 4069	: Vg=1.013219 -> Vg=1.0
% INFO    : Gen at bus 4074	: Pg=31.92, Qg=6.07 -> Pg=60.64, Qg=10.0
% INFO    : Gen at bus 4074	: Vg=1.027264 -> Vg=1.0
% INFO    : Gen at bus 4083	: Pg=277.24, Qg=62.37 -> Pg=350.0, Qg=60.0
% INFO    : Gen at bus 4083	: Vg=1.023361 -> Vg=1.0
% INFO    : Gen at bus 4084	: Pg=277.21, Qg=61.8 -> Pg=350.0, Qg=60.0
% INFO    : Gen at bus 4084	: Vg=1.023418 -> Vg=1.0
% INFO    : Gen at bus 4085	: Pg=5.0, Qg=2.04 -> Pg=51.665, Qg=0.0
% INFO    : Gen at bus 4085	: Vg=1.009821 -> Vg=1.0
% INFO    : Gen at bus 4087	: Pg=277.21, Qg=61.8 -> Pg=350.0, Qg=60.0
% INFO    : Gen at bus 4087	: Vg=1.023418 -> Vg=1.0
% INFO    : Gen at bus 4102	: Pg=319.18, Qg=33.68 -> Pg=450.0, Qg=80.0
% INFO    : Gen at bus 4102	: Vg=1.026027 -> Vg=1.0
% INFO    : Gen at bus 4116	: Pg=-143.87, Qg=-1.92 -> Pg=-45.915, Qg=0.0
% INFO    : Gen at bus 4116	: Vg=0.96498 -> Vg=1.0
% INFO    : Gen at bus 4120	: Pg=74.78, Qg=41.98 -> Pg=124.925, Qg=20.0
% INFO    : Gen at bus 4120	: Vg=1.04914 -> Vg=1.0
% INFO    : Gen at bus 4126	: Pg=34.43, Qg=7.93 -> Pg=61.475, Qg=10.0
% INFO    : Gen at bus 4126	: Vg=1.013384 -> Vg=1.0
% INFO    : Gen at bus 4130	: Pg=223.9, Qg=28.79 -> Pg=300.0, Qg=60.0
% INFO    : Gen at bus 4130	: Vg=0.992143 -> Vg=1.0
% INFO    : Gen at bus 4133	: Pg=36.8, Qg=6.62 -> Pg=62.265, Qg=10.0
% INFO    : Gen at bus 4133	: Vg=1.03058 -> Vg=1.0
% INFO    : Gen at bus 4135	: Pg=40.49, Qg=8.06 -> Pg=63.495, Qg=10.0
% INFO    : Gen at bus 4135	: Vg=1.036966 -> Vg=1.0
% INFO    : Gen at bus 4136	: Pg=59.71, Qg=48.45 -> Pg=119.905, Qg=20.0
% INFO    : Gen at bus 4136	: Vg=1.060489 -> Vg=1.0
% INFO    : Gen at bus 4137	: Pg=78.19, Qg=5.27 -> Pg=126.065, Qg=20.0
% INFO    : Gen at bus 4137	: Vg=1.025746 -> Vg=1.0
% INFO    : Gen at bus 4138	: Pg=78.19, Qg=5.27 -> Pg=126.065, Qg=20.0
% INFO    : Gen at bus 4138	: Vg=1.025746 -> Vg=1.0
% INFO    : Gen at bus 4139	: Pg=78.19, Qg=5.27 -> Pg=126.065, Qg=20.0
% INFO    : Gen at bus 4139	: Vg=1.025746 -> Vg=1.0
% INFO    : Gen at bus 4140	: Pg=78.21, Qg=5.29 -> Pg=126.07, Qg=20.0
% INFO    : Gen at bus 4140	: Vg=1.025803 -> Vg=1.0
% INFO    : Gen at bus 4141	: Pg=78.21, Qg=5.29 -> Pg=126.07, Qg=20.0
% INFO    : Gen at bus 4141	: Vg=1.025803 -> Vg=1.0
% INFO    : Gen at bus 4143	: Pg=78.21, Qg=5.29 -> Pg=126.07, Qg=20.0
% INFO    : Gen at bus 4143	: Vg=1.025803 -> Vg=1.0
% INFO    : Gen at bus 4144	: Pg=76.33, Qg=5.57 -> Pg=125.445, Qg=20.0
% INFO    : Gen at bus 4144	: Vg=1.027882 -> Vg=1.0
% INFO    : Gen at bus 4145	: Pg=95.62, Qg=39.51 -> Pg=131.875, Qg=20.0
% INFO    : Gen at bus 4145	: Vg=1.057682 -> Vg=1.0
% INFO    : Gen at bus 4151	: Pg=29.25, Qg=3.13 -> Pg=59.75, Qg=15.0
% INFO    : Gen at bus 4151	: Vg=1.008035 -> Vg=1.0
% INFO    : Gen at bus 4152	: Pg=32.29, Qg=8.39 -> Pg=60.765, Qg=15.0
% INFO    : Gen at bus 4152	: Vg=1.015318 -> Vg=1.0
% INFO    : Gen at bus 4154	: Pg=32.72, Qg=7.26 -> Pg=60.905, Qg=10.0
% INFO    : Gen at bus 4154	: Vg=1.016616 -> Vg=1.0
% INFO    : Gen at bus 4155	: Pg=76.7, Qg=4.41 -> Pg=125.565, Qg=20.0
% INFO    : Gen at bus 4155	: Vg=1.02424 -> Vg=1.0
% INFO    : Gen at bus 4156	: Pg=76.7, Qg=4.41 -> Pg=125.565, Qg=20.0
% INFO    : Gen at bus 4156	: Vg=1.02424 -> Vg=1.0
% INFO    : Gen at bus 4157	: Pg=97.15, Qg=3.14 -> Pg=132.385, Qg=20.0
% INFO    : Gen at bus 4157	: Vg=1.026566 -> Vg=1.0
% INFO    : Gen at bus 4158	: Pg=97.15, Qg=3.14 -> Pg=132.385, Qg=20.0
% INFO    : Gen at bus 4158	: Vg=1.026566 -> Vg=1.0
% INFO    : Gen at bus 4159	: Pg=69.46, Qg=4.37 -> Pg=123.155, Qg=20.0
% INFO    : Gen at bus 4159	: Vg=1.041381 -> Vg=1.0
% INFO    : Gen at bus 4160	: Pg=97.15, Qg=3.14 -> Pg=132.385, Qg=20.0
% INFO    : Gen at bus 4160	: Vg=1.026566 -> Vg=1.0
% INFO    : Gen at bus 4161	: Pg=69.46, Qg=4.37 -> Pg=123.155, Qg=20.0
% INFO    : Gen at bus 4161	: Vg=1.041381 -> Vg=1.0
% INFO    : Gen at bus 4162	: Pg=31.64, Qg=8.73 -> Pg=60.545, Qg=15.0
% INFO    : Gen at bus 4162	: Vg=0.997106 -> Vg=1.0
% INFO    : Gen at bus 4163	: Pg=73.94, Qg=10.77 -> Pg=124.645, Qg=20.0
% INFO    : Gen at bus 4163	: Vg=1.027512 -> Vg=1.0
% INFO    : Gen at bus 4164	: Pg=73.94, Qg=10.77 -> Pg=124.645, Qg=20.0
% INFO    : Gen at bus 4164	: Vg=1.027512 -> Vg=1.0
% INFO    : Gen at bus 4166	: Pg=18.58, Qg=13.67 -> Pg=56.195, Qg=10.0
% INFO    : Gen at bus 4166	: Vg=1.061581 -> Vg=1.0
% INFO    : Gen at bus 4167	: Pg=31.57, Qg=7.72 -> Pg=60.525, Qg=10.0
% INFO    : Gen at bus 4167	: Vg=1.008948 -> Vg=1.0
% INFO    : Gen at bus 4171	: Pg=27.95, Qg=4.02 -> Pg=59.315, Qg=10.0
% INFO    : Gen at bus 4171	: Vg=1.016461 -> Vg=1.0
% INFO    : Gen at bus 4181	: Pg=39.44, Qg=10.06 -> Pg=63.145, Qg=15.0
% INFO    : Gen at bus 4181	: Vg=1.021987 -> Vg=1.0
% INFO    : Gen at bus 4182	: Pg=80.74, Qg=25.03 -> Pg=126.915, Qg=20.0
% INFO    : Gen at bus 4182	: Vg=1.061099 -> Vg=1.0
% INFO    : Gen at bus 4183	: Pg=80.74, Qg=25.03 -> Pg=126.915, Qg=20.0
% INFO    : Gen at bus 4183	: Vg=1.061099 -> Vg=1.0
% INFO    : Gen at bus 4185	: Pg=80.74, Qg=25.03 -> Pg=126.915, Qg=20.0
% INFO    : Gen at bus 4185	: Vg=1.061099 -> Vg=1.0
% INFO    : Gen at bus 4187	: Pg=80.74, Qg=25.03 -> Pg=126.915, Qg=20.0
% INFO    : Gen at bus 4187	: Vg=1.061099 -> Vg=1.0
% INFO    : Gen at bus 4190	: Pg=50.0, Qg=-1.48 -> Pg=116.665, Qg=5.0
% INFO    : Gen at bus 4190	: Vg=0.985642 -> Vg=1.0
% INFO    : Gen at bus 4191	: Pg=36.8, Qg=6.62 -> Pg=62.265, Qg=10.0
% INFO    : Gen at bus 4191	: Vg=1.03058 -> Vg=1.0
% INFO    : Gen at bus 4193	: Pg=38.51, Qg=8.85 -> Pg=62.835, Qg=10.0
% INFO    : Gen at bus 4193	: Vg=1.03425 -> Vg=1.0
% INFO    : Gen at bus 4195	: Pg=300.49, Qg=77.66 -> Pg=450.0, Qg=80.0
% INFO    : Gen at bus 4195	: Vg=1.049436 -> Vg=1.0
% INFO    : Gen at bus 4196	: Pg=5.0, Qg=0.52 -> Pg=51.665, Qg=0.0
% INFO    : Gen at bus 4196	: Vg=1.019692 -> Vg=1.0
% INFO    : Gen at bus 4197	: Pg=360.13, Qg=84.68 -> Pg=500.0, Qg=80.0
% INFO    : Gen at bus 4197	: Vg=1.005717 -> Vg=1.0
% INFO    : Gen at bus 4200	: Pg=21.05, Qg=5.06 -> Pg=57.015, Qg=10.0
% INFO    : Gen at bus 4200	: Vg=1.070991 -> Vg=1.0
% INFO    : Gen at bus 4202	: Pg=300.0, Qg=-14.29 -> Pg=450.0, Qg=0.0
% INFO    : Gen at bus 4202	: Vg=1.001419 -> Vg=1.0
% INFO    : Gen at bus 4203	: Pg=74.8, Qg=42.23 -> Pg=124.935, Qg=20.0
% INFO    : Gen at bus 4203	: Vg=1.046905 -> Vg=1.0
% INFO    : Gen at bus 4206	: Pg=50.29, Qg=10.48 -> Pg=116.765, Qg=15.0
% INFO    : Gen at bus 4206	: Vg=1.031165 -> Vg=1.0
% INFO    : Gen at bus 4207	: Pg=91.34, Qg=21.91 -> Pg=130.445, Qg=20.0
% INFO    : Gen at bus 4207	: Vg=1.030656 -> Vg=1.0
% INFO    : Gen at bus 4208	: Pg=151.81, Qg=0.39 -> Pg=250.0, Qg=25.0
% INFO    : Gen at bus 4208	: Vg=1.017341 -> Vg=1.0
% INFO    : Gen at bus 4209	: Pg=95.02, Qg=8.09 -> Pg=131.675, Qg=20.0
% INFO    : Gen at bus 4209	: Vg=1.023144 -> Vg=1.0
% INFO    : Gen at bus 4214	: Pg=91.34, Qg=21.91 -> Pg=130.445, Qg=20.0
% INFO    : Gen at bus 4214	: Vg=1.030656 -> Vg=1.0
% INFO    : Gen at bus 4217	: Pg=25.35, Qg=8.5 -> Pg=58.45, Qg=15.0
% INFO    : Gen at bus 4217	: Vg=1.018631 -> Vg=1.0
% INFO    : Gen at bus 4226	: Pg=262.9, Qg=48.53 -> Pg=350.0, Qg=60.0
% INFO    : Gen at bus 4226	: Vg=1.027461 -> Vg=1.0
% INFO    : Gen at bus 4234	: Pg=45.38, Qg=12.31 -> Pg=65.125, Qg=20.0
% INFO    : Gen at bus 4234	: Vg=0.990977 -> Vg=1.0
% INFO    : Gen at bus 4235	: Pg=12.3, Qg=0.28 -> Pg=54.1, Qg=0.0
% INFO    : Gen at bus 4235	: Vg=1.011745 -> Vg=1.0
% INFO    : Gen at bus 4237	: Pg=6.52, Qg=-0.06 -> Pg=52.175, Qg=0.0
% INFO    : Gen at bus 4237	: Vg=0.994601 -> Vg=1.0
% INFO    : Gen at bus 4240	: Pg=67.0, Qg=8.72 -> Pg=122.335, Qg=15.0
% INFO    : Gen at bus 4240	: Vg=0.992643 -> Vg=1.0
% INFO    : Gen at bus 4242	: Pg=72.17, Qg=16.24 -> Pg=124.055, Qg=20.0
% INFO    : Gen at bus 4242	: Vg=1.022616 -> Vg=1.0
% INFO    : Gen at bus 4245	: Pg=227.21, Qg=72.31 -> Pg=300.0, Qg=80.0
% INFO    : Gen at bus 4245	: Vg=1.063358 -> Vg=1.0
% INFO    : Gen at bus 4252	: Pg=34.86, Qg=4.81 -> Pg=61.62, Qg=10.0
% INFO    : Gen at bus 4252	: Vg=1.050901 -> Vg=1.0
% INFO    : Gen at bus 4253	: Pg=165.7, Qg=155.15 -> Pg=250.0, Qg=60.0
% INFO    : Gen at bus 4253	: Vg=1.077217 -> Vg=1.0
% INFO    : Gen at bus 4254	: Pg=165.7, Qg=155.15 -> Pg=250.0, Qg=60.0
% INFO    : Gen at bus 4254	: Vg=1.077217 -> Vg=1.0
% INFO    : Gen at bus 4256	: Pg=22.38, Qg=13.57 -> Pg=57.46, Qg=10.0
% INFO    : Gen at bus 4256	: Vg=1.011374 -> Vg=1.0
% INFO    : Gen at bus 4259	: Pg=8.4, Qg=-0.84 -> Pg=52.8, Qg=0.0
% INFO    : Gen at bus 4259	: Vg=1.010516 -> Vg=1.0
% INFO    : Gen at bus 4261	: Pg=158.9, Qg=35.36 -> Pg=250.0, Qg=35.0
% INFO    : Gen at bus 4261	: Vg=0.993468 -> Vg=1.0
% INFO    : Gen at bus 4264	: Pg=36.42, Qg=7.96 -> Pg=62.14, Qg=10.0
% INFO    : Gen at bus 4264	: Vg=1.029166 -> Vg=1.0
% INFO    : Gen at bus 4267	: Pg=36.8, Qg=-2.54 -> Pg=62.265, Qg=0.0
% INFO    : Gen at bus 4267	: Vg=0.98379 -> Vg=1.0
% INFO    : Gen at bus 4274	: Pg=227.2, Qg=72.57 -> Pg=300.0, Qg=80.0
% INFO    : Gen at bus 4274	: Vg=1.063453 -> Vg=1.0
% INFO    : Gen at bus 4282	: Pg=36.22, Qg=11.19 -> Pg=62.075, Qg=10.0
% INFO    : Gen at bus 4282	: Vg=1.003847 -> Vg=1.0
% INFO    : Gen at bus 4284	: Pg=95.25, Qg=8.91 -> Pg=131.75, Qg=20.0
% INFO    : Gen at bus 4284	: Vg=1.058465 -> Vg=1.0
% INFO    : Gen at bus 4285	: Pg=95.25, Qg=8.91 -> Pg=131.75, Qg=20.0
% INFO    : Gen at bus 4285	: Vg=1.058465 -> Vg=1.0
% INFO    : Gen at bus 4286	: Pg=95.25, Qg=8.91 -> Pg=131.75, Qg=20.0
% INFO    : Gen at bus 4286	: Vg=1.058465 -> Vg=1.0
% INFO    : Gen at bus 4287	: Pg=95.25, Qg=8.91 -> Pg=131.75, Qg=20.0
% INFO    : Gen at bus 4287	: Vg=1.058465 -> Vg=1.0
% INFO    : Gen at bus 4288	: Pg=95.25, Qg=8.91 -> Pg=131.75, Qg=20.0
% INFO    : Gen at bus 4288	: Vg=1.058465 -> Vg=1.0
% INFO    : Gen at bus 4290	: Pg=95.25, Qg=8.91 -> Pg=131.75, Qg=20.0
% INFO    : Gen at bus 4290	: Vg=1.058465 -> Vg=1.0
% INFO    : Gen at bus 4298	: Pg=38.79, Qg=7.11 -> Pg=62.93, Qg=10.0
% INFO    : Gen at bus 4298	: Vg=1.035838 -> Vg=1.0
% INFO    : Gen at bus 4301	: Pg=93.04, Qg=14.9 -> Pg=131.015, Qg=20.0
% INFO    : Gen at bus 4301	: Vg=1.017638 -> Vg=1.0
% INFO    : Gen at bus 4309	: Pg=72.61, Qg=29.56 -> Pg=124.205, Qg=20.0
% INFO    : Gen at bus 4309	: Vg=1.041629 -> Vg=1.0
% INFO    : Gen at bus 4310	: Pg=380.17, Qg=55.84 -> Pg=500.0, Qg=80.0
% INFO    : Gen at bus 4310	: Vg=1.059635 -> Vg=1.0
% INFO    : Gen at bus 4314	: Pg=48.81, Qg=10.42 -> Pg=66.27, Qg=15.0
% INFO    : Gen at bus 4314	: Vg=1.017273 -> Vg=1.0
% INFO    : Gen at bus 4324	: Pg=27.81, Qg=13.1 -> Pg=59.27, Qg=10.0
% INFO    : Gen at bus 4324	: Vg=1.016415 -> Vg=1.0
% INFO    : Gen at bus 4326	: Pg=29.43, Qg=7.09 -> Pg=59.81, Qg=10.0
% INFO    : Gen at bus 4326	: Vg=1.028438 -> Vg=1.0
% INFO    : Gen at bus 4331	: Pg=50.0, Qg=-0.52 -> Pg=116.665, Qg=5.0
% INFO    : Gen at bus 4331	: Vg=0.992476 -> Vg=1.0
% INFO    : Gen at bus 4337	: Pg=20.16, Qg=7.15 -> Pg=56.72, Qg=5.0
% INFO    : Gen at bus 4337	: Vg=1.020298 -> Vg=1.0
% INFO    : Gen at bus 4339	: Pg=37.67, Qg=5.32 -> Pg=62.56, Qg=5.0
% INFO    : Gen at bus 4339	: Vg=1.027032 -> Vg=1.0
% INFO    : Gen at bus 4343	: Pg=48.81, Qg=10.42 -> Pg=66.27, Qg=15.0
% INFO    : Gen at bus 4343	: Vg=1.017273 -> Vg=1.0
% INFO    : Gen at bus 4344	: Pg=18.74, Qg=6.56 -> Pg=56.245, Qg=10.0
% INFO    : Gen at bus 4344	: Vg=1.02868 -> Vg=1.0
% INFO    : Gen at bus 4345	: Pg=48.81, Qg=10.42 -> Pg=66.27, Qg=15.0
% INFO    : Gen at bus 4345	: Vg=1.017273 -> Vg=1.0
% INFO    : Gen at bus 4347	: Pg=83.78, Qg=15.02 -> Pg=127.925, Qg=20.0
% INFO    : Gen at bus 4347	: Vg=1.033534 -> Vg=1.0
% INFO    : Gen at bus 4353	: Pg=50.6, Qg=9.87 -> Pg=116.865, Qg=5.0
% INFO    : Gen at bus 4353	: Vg=1.012422 -> Vg=1.0
% INFO    : Gen at bus 4354	: Pg=37.08, Qg=5.51 -> Pg=62.36, Qg=10.0
% INFO    : Gen at bus 4354	: Vg=1.021005 -> Vg=1.0
% INFO    : Gen at bus 4366	: Pg=25.01, Qg=5.98 -> Pg=58.335, Qg=10.0
% INFO    : Gen at bus 4366	: Vg=0.999838 -> Vg=1.0
% INFO    : Gen at bus 4367	: Pg=350.88, Qg=-13.06 -> Pg=500.0, Qg=80.0
% INFO    : Gen at bus 4367	: Vg=1.037481 -> Vg=1.0
% INFO    : Gen at bus 4371	: Pg=305.43, Qg=40.11 -> Pg=450.0, Qg=80.0
% INFO    : Gen at bus 4371	: Vg=1.031705 -> Vg=1.0
% INFO    : Gen at bus 4376	: Pg=328.01, Qg=53.95 -> Pg=450.0, Qg=80.0
% INFO    : Gen at bus 4376	: Vg=1.05097 -> Vg=1.0
% INFO    : Gen at bus 4378	: Pg=328.01, Qg=53.95 -> Pg=450.0, Qg=80.0
% INFO    : Gen at bus 4378	: Vg=1.05097 -> Vg=1.0
% INFO    : Gen at bus 4379	: Pg=328.01, Qg=53.95 -> Pg=450.0, Qg=80.0
% INFO    : Gen at bus 4379	: Vg=1.05097 -> Vg=1.0
% INFO    : Gen at bus 4380	: Pg=328.01, Qg=53.95 -> Pg=450.0, Qg=80.0
% INFO    : Gen at bus 4380	: Vg=1.05097 -> Vg=1.0
% INFO    : Gen at bus 4384	: Pg=38.02, Qg=11.21 -> Pg=62.675, Qg=10.0
% INFO    : Gen at bus 4384	: Vg=1.043087 -> Vg=1.0
% INFO    : Gen at bus 4385	: Pg=18.92, Qg=10.7 -> Pg=56.305, Qg=10.0
% INFO    : Gen at bus 4385	: Vg=1.056129 -> Vg=1.0
% INFO    : Gen at bus 4386	: Pg=18.92, Qg=10.7 -> Pg=56.305, Qg=10.0
% INFO    : Gen at bus 4386	: Vg=1.056129 -> Vg=1.0
% INFO    : Gen at bus 4387	: Pg=18.92, Qg=10.7 -> Pg=56.305, Qg=10.0
% INFO    : Gen at bus 4387	: Vg=1.056129 -> Vg=1.0
% INFO    : Gen at bus 4392	: Pg=29.4, Qg=6.58 -> Pg=59.8, Qg=10.0
% INFO    : Gen at bus 4392	: Vg=1.034872 -> Vg=1.0
% INFO    : Gen at bus 4393	: Pg=62.61, Qg=24.83 -> Pg=120.87, Qg=20.0
% INFO    : Gen at bus 4393	: Vg=1.034646 -> Vg=1.0
% INFO    : Gen at bus 4400	: Pg=277.26, Qg=31.82 -> Pg=350.0, Qg=80.0
% INFO    : Gen at bus 4400	: Vg=1.04876 -> Vg=1.0
% INFO    : Gen at bus 4403	: Pg=57.51, Qg=17.72 -> Pg=119.17, Qg=15.0
% INFO    : Gen at bus 4403	: Vg=1.029323 -> Vg=1.0
% INFO    : Gen at bus 4405	: Pg=24.65, Qg=6.97 -> Pg=58.215, Qg=10.0
% INFO    : Gen at bus 4405	: Vg=1.038344 -> Vg=1.0
% INFO    : Gen at bus 4411	: Pg=39.43, Qg=5.93 -> Pg=63.145, Qg=10.0
% INFO    : Gen at bus 4411	: Vg=1.017582 -> Vg=1.0
% INFO    : Gen at bus 4422	: Pg=53.99, Qg=18.23 -> Pg=117.995, Qg=15.0
% INFO    : Gen at bus 4422	: Vg=1.062896 -> Vg=1.0
% INFO    : Gen at bus 4423	: Pg=2.5, Qg=0.07 -> Pg=50.835, Qg=0.0
% INFO    : Gen at bus 4423	: Vg=0.984601 -> Vg=1.0
% INFO    : Gen at bus 4424	: Pg=53.99, Qg=18.23 -> Pg=117.995, Qg=15.0
% INFO    : Gen at bus 4424	: Vg=1.062896 -> Vg=1.0
% INFO    : Gen at bus 4425	: Pg=53.99, Qg=18.23 -> Pg=117.995, Qg=15.0
% INFO    : Gen at bus 4425	: Vg=1.062896 -> Vg=1.0
% INFO    : Gen at bus 4426	: Pg=27.96, Qg=5.11 -> Pg=59.32, Qg=10.0
% INFO    : Gen at bus 4426	: Vg=1.029009 -> Vg=1.0
% INFO    : Gen at bus 4427	: Pg=27.96, Qg=5.11 -> Pg=59.32, Qg=10.0
% INFO    : Gen at bus 4427	: Vg=1.029009 -> Vg=1.0
% INFO    : Gen at bus 4430	: Pg=17.09, Qg=6.06 -> Pg=55.695, Qg=10.0
% INFO    : Gen at bus 4430	: Vg=1.033479 -> Vg=1.0
% INFO    : Gen at bus 4432	: Pg=27.73, Qg=2.0 -> Pg=59.245, Qg=10.0
% INFO    : Gen at bus 4432	: Vg=1.030407 -> Vg=1.0
% INFO    : Gen at bus 4433	: Pg=27.73, Qg=2.0 -> Pg=59.245, Qg=10.0
% INFO    : Gen at bus 4433	: Vg=1.030407 -> Vg=1.0
% INFO    : Gen at bus 4434	: Pg=27.73, Qg=2.0 -> Pg=59.245, Qg=10.0
% INFO    : Gen at bus 4434	: Vg=1.030407 -> Vg=1.0
% INFO    : Gen at bus 4440	: Pg=36.77, Qg=13.93 -> Pg=62.255, Qg=10.0
% INFO    : Gen at bus 4440	: Vg=1.042317 -> Vg=1.0
% INFO    : Gen at bus 4443	: Pg=353.02, Qg=203.37 -> Pg=500.0, Qg=80.0
% INFO    : Gen at bus 4443	: Vg=1.128032 -> Vg=1.0
% INFO    : Gen at bus 4448	: Pg=264.57, Qg=207.6 -> Pg=350.0, Qg=80.0
% INFO    : Gen at bus 4448	: Vg=1.127182 -> Vg=1.0
% INFO    : Gen at bus 4449	: Pg=34.37, Qg=6.67 -> Pg=61.455, Qg=10.0
% INFO    : Gen at bus 4449	: Vg=1.035406 -> Vg=1.0
% INFO    : Gen at bus 4451	: Pg=47.36, Qg=7.24 -> Pg=65.785, Qg=15.0
% INFO    : Gen at bus 4451	: Vg=1.026147 -> Vg=1.0
% INFO    : Gen at bus 4452	: Pg=200.58, Qg=41.06 -> Pg=300.0, Qg=80.0
% INFO    : Gen at bus 4452	: Vg=1.044746 -> Vg=1.0
% INFO    : Gen at bus 4453	: Pg=47.36, Qg=7.24 -> Pg=65.785, Qg=15.0
% INFO    : Gen at bus 4453	: Vg=1.026147 -> Vg=1.0
% INFO    : Gen at bus 4454	: Pg=39.82, Qg=7.25 -> Pg=63.275, Qg=15.0
% INFO    : Gen at bus 4454	: Vg=1.026722 -> Vg=1.0
% INFO    : Gen at bus 4455	: Pg=58.52, Qg=7.84 -> Pg=119.505, Qg=15.0
% INFO    : Gen at bus 4455	: Vg=1.025977 -> Vg=1.0
% INFO    : Gen at bus 4456	: Pg=39.82, Qg=7.25 -> Pg=63.275, Qg=15.0
% INFO    : Gen at bus 4456	: Vg=1.026722 -> Vg=1.0
% INFO    : Gen at bus 4457	: Pg=39.82, Qg=7.25 -> Pg=63.275, Qg=15.0
% INFO    : Gen at bus 4457	: Vg=1.026722 -> Vg=1.0
% INFO    : Gen at bus 4458	: Pg=42.33, Qg=15.72 -> Pg=64.11, Qg=15.0
% INFO    : Gen at bus 4458	: Vg=1.031695 -> Vg=1.0
% INFO    : Gen at bus 4460	: Pg=52.53, Qg=15.88 -> Pg=117.51, Qg=15.0
% INFO    : Gen at bus 4460	: Vg=1.02748 -> Vg=1.0
% INFO    : Gen at bus 4461	: Pg=47.36, Qg=7.24 -> Pg=65.785, Qg=15.0
% INFO    : Gen at bus 4461	: Vg=1.026147 -> Vg=1.0
% INFO    : Gen at bus 4470	: Pg=95.62, Qg=39.51 -> Pg=131.875, Qg=20.0
% INFO    : Gen at bus 4470	: Vg=1.057682 -> Vg=1.0
% INFO    : Gen at bus 4473	: Pg=188.54, Qg=108.59 -> Pg=250.0, Qg=80.0
% INFO    : Gen at bus 4473	: Vg=1.037029 -> Vg=1.0
% INFO    : Gen at bus 4480	: Pg=17.64, Qg=4.13 -> Pg=55.88, Qg=10.0
% INFO    : Gen at bus 4480	: Vg=1.031189 -> Vg=1.0
% INFO    : Gen at bus 4481	: Pg=33.27, Qg=9.43 -> Pg=61.09, Qg=15.0
% INFO    : Gen at bus 4481	: Vg=1.025116 -> Vg=1.0
% INFO    : Gen at bus 4483	: Pg=32.98, Qg=7.31 -> Pg=60.995, Qg=10.0
% INFO    : Gen at bus 4483	: Vg=1.054159 -> Vg=1.0
% INFO    : Gen at bus 4484	: Pg=33.28, Qg=7.19 -> Pg=61.095, Qg=15.0
% INFO    : Gen at bus 4484	: Vg=1.022819 -> Vg=1.0
% INFO    : Gen at bus 4488	: Pg=3.65, Qg=0.04 -> Pg=51.215, Qg=0.0
% INFO    : Gen at bus 4488	: Vg=0.982004 -> Vg=1.0
% INFO    : Gen at bus 4495	: Pg=100.41, Qg=11.92 -> Pg=183.47, Qg=20.0
% INFO    : Gen at bus 4495	: Vg=1.038747 -> Vg=1.0
% INFO    : Gen at bus 4499	: Pg=72.47, Qg=11.44 -> Pg=124.155, Qg=20.0
% INFO    : Gen at bus 4499	: Vg=1.019231 -> Vg=1.0
% INFO    : Gen at bus 4501	: Pg=32.52, Qg=9.41 -> Pg=60.84, Qg=10.0
% INFO    : Gen at bus 4501	: Vg=1.028707 -> Vg=1.0
% INFO    : Gen at bus 4505	: Pg=227.37, Qg=10.01 -> Pg=300.0, Qg=60.0
% INFO    : Gen at bus 4505	: Vg=1.028414 -> Vg=1.0
% INFO    : Gen at bus 4509	: Pg=550.03, Qg=481.13 -> Pg=750.0, Qg=200.0
% INFO    : Gen at bus 4509	: Vg=1.061212 -> Vg=1.0
% INFO    : Gen at bus 4512	: Pg=32.52, Qg=9.41 -> Pg=60.84, Qg=10.0
% INFO    : Gen at bus 4512	: Vg=1.028707 -> Vg=1.0
% INFO    : Gen at bus 4513	: Pg=20.33, Qg=6.46 -> Pg=56.775, Qg=10.0
% INFO    : Gen at bus 4513	: Vg=0.990908 -> Vg=1.0
% INFO    : Gen at bus 4517	: Pg=290.0, Qg=-23.36 -> Pg=350.0, Qg=0.0
% INFO    : Gen at bus 4517	: Vg=0.971901 -> Vg=1.0
% INFO    : Gen at bus 4526	: Pg=85.0, Qg=-13.61 -> Pg=128.335, Qg=0.0
% INFO    : Gen at bus 4526	: Vg=0.969146 -> Vg=1.0
% INFO    : Gen at bus 4534	: Pg=30.04, Qg=7.71 -> Pg=60.015, Qg=10.0
% INFO    : Gen at bus 4534	: Vg=1.011489 -> Vg=1.0
% INFO    : Gen at bus 4535	: Pg=30.04, Qg=7.71 -> Pg=60.015, Qg=10.0
% INFO    : Gen at bus 4535	: Vg=1.011489 -> Vg=1.0
% INFO    : Gen at bus 4537	: Pg=30.04, Qg=7.71 -> Pg=60.015, Qg=10.0
% INFO    : Gen at bus 4537	: Vg=1.011489 -> Vg=1.0
% INFO    : Gen at bus 4539	: Pg=31.35, Qg=11.33 -> Pg=60.45, Qg=10.0
% INFO    : Gen at bus 4539	: Vg=1.043357 -> Vg=1.0
% INFO    : Gen at bus 4540	: Pg=22.02, Qg=10.78 -> Pg=57.34, Qg=10.0
% INFO    : Gen at bus 4540	: Vg=1.026425 -> Vg=1.0
% INFO    : Gen at bus 4547	: Pg=33.09, Qg=8.73 -> Pg=61.03, Qg=10.0
% INFO    : Gen at bus 4547	: Vg=1.040215 -> Vg=1.0
% INFO    : Gen at bus 4548	: Pg=33.09, Qg=8.73 -> Pg=61.03, Qg=10.0
% INFO    : Gen at bus 4548	: Vg=1.040215 -> Vg=1.0
% INFO    : Gen at bus 4549	: Pg=33.09, Qg=8.73 -> Pg=61.03, Qg=10.0
% INFO    : Gen at bus 4549	: Vg=1.040215 -> Vg=1.0
% INFO    : Gen at bus 4550	: Pg=33.09, Qg=8.73 -> Pg=61.03, Qg=10.0
% INFO    : Gen at bus 4550	: Vg=1.040215 -> Vg=1.0
% INFO    : Gen at bus 4551	: Pg=33.09, Qg=8.73 -> Pg=61.03, Qg=10.0
% INFO    : Gen at bus 4551	: Vg=1.040215 -> Vg=1.0
% INFO    : Gen at bus 4552	: Pg=33.09, Qg=8.73 -> Pg=61.03, Qg=10.0
% INFO    : Gen at bus 4552	: Vg=1.040215 -> Vg=1.0
% INFO    : Gen at bus 4553	: Pg=28.95, Qg=9.55 -> Pg=59.65, Qg=10.0
% INFO    : Gen at bus 4553	: Vg=1.01638 -> Vg=1.0
% INFO    : Gen at bus 4554	: Pg=33.09, Qg=8.73 -> Pg=61.03, Qg=10.0
% INFO    : Gen at bus 4554	: Vg=1.040215 -> Vg=1.0
% INFO    : Gen at bus 4563	: Pg=28.83, Qg=4.62 -> Pg=59.61, Qg=10.0
% INFO    : Gen at bus 4563	: Vg=1.019144 -> Vg=1.0
% INFO    : Gen at bus 4572	: Pg=32.46, Qg=19.3 -> Pg=60.82, Qg=10.0
% INFO    : Gen at bus 4572	: Vg=1.04927 -> Vg=1.0
% INFO    : Gen at bus 4573	: Pg=90.48, Qg=33.58 -> Pg=130.16, Qg=20.0
% INFO    : Gen at bus 4573	: Vg=1.043665 -> Vg=1.0
% INFO    : Gen at bus 4576	: Pg=82.6, Qg=2.11 -> Pg=127.535, Qg=20.0
% INFO    : Gen at bus 4576	: Vg=1.02421 -> Vg=1.0
% INFO    : Gen at bus 4577	: Pg=82.6, Qg=2.11 -> Pg=127.535, Qg=20.0
% INFO    : Gen at bus 4577	: Vg=1.02421 -> Vg=1.0
% INFO    : Gen at bus 4578	: Pg=82.6, Qg=2.11 -> Pg=127.535, Qg=20.0
% INFO    : Gen at bus 4578	: Vg=1.02421 -> Vg=1.0
% INFO    : Gen at bus 4580	: Pg=82.6, Qg=2.11 -> Pg=127.535, Qg=20.0
% INFO    : Gen at bus 4580	: Vg=1.02421 -> Vg=1.0
% INFO    : Gen at bus 4585	: Pg=92.4, Qg=2.72 -> Pg=130.8, Qg=20.0
% INFO    : Gen at bus 4585	: Vg=1.014507 -> Vg=1.0
% INFO    : Gen at bus 4590	: Pg=28.8, Qg=6.92 -> Pg=59.6, Qg=10.0
% INFO    : Gen at bus 4590	: Vg=1.000808 -> Vg=1.0
% INFO    : Gen at bus 4594	: Pg=31.92, Qg=6.07 -> Pg=60.64, Qg=10.0
% INFO    : Gen at bus 4594	: Vg=1.027264 -> Vg=1.0
% INFO    : Gen at bus 4598	: Pg=78.37, Qg=30.34 -> Pg=126.125, Qg=20.0
% INFO    : Gen at bus 4598	: Vg=1.032985 -> Vg=1.0
% INFO    : Gen at bus 4602	: Pg=78.37, Qg=30.34 -> Pg=126.125, Qg=20.0
% INFO    : Gen at bus 4602	: Vg=1.032985 -> Vg=1.0
% INFO    : Gen at bus 4603	: Pg=78.37, Qg=30.34 -> Pg=126.125, Qg=20.0
% INFO    : Gen at bus 4603	: Vg=1.032985 -> Vg=1.0
% INFO    : Gen at bus 4604	: Pg=78.37, Qg=30.34 -> Pg=126.125, Qg=20.0
% INFO    : Gen at bus 4604	: Vg=1.032985 -> Vg=1.0
% INFO    : Gen at bus 4607	: Pg=23.07, Qg=4.45 -> Pg=57.69, Qg=10.0
% INFO    : Gen at bus 4607	: Vg=1.026025 -> Vg=1.0
% INFO    : Gen at bus 4611	: Pg=0.99, Qg=-0.05 -> Pg=50.33, Qg=0.0
% INFO    : Gen at bus 4611	: Vg=1.015919 -> Vg=1.0
% INFO    : Gen at bus 4612	: Pg=290.07, Qg=141.78 -> Pg=350.0, Qg=80.0
% INFO    : Gen at bus 4612	: Vg=1.033649 -> Vg=1.0
% INFO    : Gen at bus 4614	: Pg=22.5, Qg=5.53 -> Pg=57.5, Qg=5.0
% INFO    : Gen at bus 4614	: Vg=1.039055 -> Vg=1.0
% INFO    : Gen at bus 4616	: Pg=319.18, Qg=33.68 -> Pg=450.0, Qg=80.0
% INFO    : Gen at bus 4616	: Vg=1.026027 -> Vg=1.0
% INFO    : Gen at bus 4617	: Pg=39.78, Qg=18.08 -> Pg=63.26, Qg=10.0
% INFO    : Gen at bus 4617	: Vg=1.041665 -> Vg=1.0
% INFO    : Gen at bus 4618	: Pg=20.0, Qg=3.75 -> Pg=56.665, Qg=10.0
% INFO    : Gen at bus 4618	: Vg=1.024278 -> Vg=1.0
% INFO    : Gen at bus 4619	: Pg=20.0, Qg=3.75 -> Pg=56.665, Qg=10.0
% INFO    : Gen at bus 4619	: Vg=1.024278 -> Vg=1.0
% INFO    : Gen at bus 4622	: Pg=162.61, Qg=110.24 -> Pg=250.0, Qg=80.0
% INFO    : Gen at bus 4622	: Vg=1.054046 -> Vg=1.0
% INFO    : Gen at bus 4626	: Pg=43.17, Qg=6.95 -> Pg=64.39, Qg=10.0
% INFO    : Gen at bus 4626	: Vg=1.015029 -> Vg=1.0
% INFO    : Gen at bus 4627	: Pg=43.17, Qg=6.95 -> Pg=64.39, Qg=10.0
% INFO    : Gen at bus 4627	: Vg=1.015029 -> Vg=1.0
% INFO    : Gen at bus 4630	: Pg=43.17, Qg=6.95 -> Pg=64.39, Qg=10.0
% INFO    : Gen at bus 4630	: Vg=1.015029 -> Vg=1.0
% INFO    : Gen at bus 4631	: Pg=43.17, Qg=6.95 -> Pg=64.39, Qg=10.0
% INFO    : Gen at bus 4631	: Vg=1.015029 -> Vg=1.0
% INFO    : Gen at bus 4633	: Pg=43.17, Qg=6.95 -> Pg=64.39, Qg=10.0
% INFO    : Gen at bus 4633	: Vg=1.015029 -> Vg=1.0
% INFO    : Gen at bus 4634	: Pg=43.17, Qg=6.95 -> Pg=64.39, Qg=10.0
% INFO    : Gen at bus 4634	: Vg=1.015029 -> Vg=1.0
% INFO    : Gen at bus 4635	: Pg=43.17, Qg=6.95 -> Pg=64.39, Qg=10.0
% INFO    : Gen at bus 4635	: Vg=1.015029 -> Vg=1.0
% INFO    : Gen at bus 4643	: Pg=10.36, Qg=0.68 -> Pg=53.455, Qg=0.0
% INFO    : Gen at bus 4643	: Vg=1.012893 -> Vg=1.0
% INFO    : Gen at bus 4644	: Pg=14.76, Qg=0.22 -> Pg=54.92, Qg=0.0
% INFO    : Gen at bus 4644	: Vg=1.011577 -> Vg=1.0
% INFO    : Gen at bus 4648	: Pg=21.3, Qg=1.07 -> Pg=57.1, Qg=5.0
% INFO    : Gen at bus 4648	: Vg=1.032267 -> Vg=1.0
% INFO    : Gen at bus 4652	: Pg=83.69, Qg=18.55 -> Pg=127.895, Qg=20.0
% INFO    : Gen at bus 4652	: Vg=1.037564 -> Vg=1.0
% INFO    : Gen at bus 4655	: Pg=223.02, Qg=66.59 -> Pg=300.0, Qg=60.0
% INFO    : Gen at bus 4655	: Vg=1.042492 -> Vg=1.0
% INFO    : Gen at bus 4656	: Pg=223.02, Qg=66.59 -> Pg=300.0, Qg=60.0
% INFO    : Gen at bus 4656	: Vg=1.042492 -> Vg=1.0
% INFO    : Gen at bus 4657	: Pg=223.3, Qg=11.76 -> Pg=300.0, Qg=60.0
% INFO    : Gen at bus 4657	: Vg=1.026117 -> Vg=1.0
% INFO    : Gen at bus 4658	: Pg=223.3, Qg=11.76 -> Pg=300.0, Qg=60.0
% INFO    : Gen at bus 4658	: Vg=1.026117 -> Vg=1.0
% INFO    : Gen at bus 4662	: Pg=47.08, Qg=25.26 -> Pg=65.695, Qg=20.0
% INFO    : Gen at bus 4662	: Vg=1.055425 -> Vg=1.0
% INFO    : Gen at bus 4663	: Pg=47.08, Qg=25.26 -> Pg=65.695, Qg=20.0
% INFO    : Gen at bus 4663	: Vg=1.055425 -> Vg=1.0
% INFO    : Gen at bus 4664	: Pg=85.34, Qg=16.39 -> Pg=128.445, Qg=20.0
% INFO    : Gen at bus 4664	: Vg=1.053529 -> Vg=1.0
% INFO    : Gen at bus 4665	: Pg=85.34, Qg=16.39 -> Pg=128.445, Qg=20.0
% INFO    : Gen at bus 4665	: Vg=1.053529 -> Vg=1.0
% INFO    : Gen at bus 4666	: Pg=52.81, Qg=50.16 -> Pg=117.605, Qg=20.0
% INFO    : Gen at bus 4666	: Vg=1.055479 -> Vg=1.0
% INFO    : Gen at bus 4668	: Pg=31.3, Qg=-0.89 -> Pg=60.435, Qg=0.0
% INFO    : Gen at bus 4668	: Vg=0.998951 -> Vg=1.0
% INFO    : Gen at bus 4670	: Pg=330.71, Qg=4.92 -> Pg=450.0, Qg=80.0
% INFO    : Gen at bus 4670	: Vg=1.043049 -> Vg=1.0
% INFO    : Gen at bus 4671	: Pg=38.79, Qg=7.11 -> Pg=62.93, Qg=10.0
% INFO    : Gen at bus 4671	: Vg=1.035838 -> Vg=1.0
% INFO    : Gen at bus 4675	: Pg=40.49, Qg=8.06 -> Pg=63.495, Qg=10.0
% INFO    : Gen at bus 4675	: Vg=1.036966 -> Vg=1.0
% INFO    : Gen at bus 4676	: Pg=67.83, Qg=2.97 -> Pg=122.61, Qg=20.0
% INFO    : Gen at bus 4676	: Vg=1.059275 -> Vg=1.0
% INFO    : Gen at bus 4677	: Pg=67.83, Qg=2.97 -> Pg=122.61, Qg=20.0
% INFO    : Gen at bus 4677	: Vg=1.059275 -> Vg=1.0
% INFO    : Gen at bus 4678	: Pg=67.83, Qg=2.97 -> Pg=122.61, Qg=20.0
% INFO    : Gen at bus 4678	: Vg=1.059275 -> Vg=1.0
% INFO    : Gen at bus 4679	: Pg=86.9, Qg=4.11 -> Pg=128.965, Qg=20.0
% INFO    : Gen at bus 4679	: Vg=1.052163 -> Vg=1.0
% INFO    : Gen at bus 4680	: Pg=86.9, Qg=4.11 -> Pg=128.965, Qg=20.0
% INFO    : Gen at bus 4680	: Vg=1.052163 -> Vg=1.0
% INFO    : Gen at bus 4683	: Pg=79.77, Qg=4.15 -> Pg=126.59, Qg=20.0
% INFO    : Gen at bus 4683	: Vg=1.047117 -> Vg=1.0
% INFO    : Gen at bus 4686	: Pg=50.96, Qg=2.69 -> Pg=116.985, Qg=20.0
% INFO    : Gen at bus 4686	: Vg=1.028648 -> Vg=1.0
% INFO    : Gen at bus 4690	: Pg=32.57, Qg=7.29 -> Pg=60.855, Qg=10.0
% INFO    : Gen at bus 4690	: Vg=1.041748 -> Vg=1.0
% INFO    : Gen at bus 4691	: Pg=89.93, Qg=16.64 -> Pg=129.975, Qg=20.0
% INFO    : Gen at bus 4691	: Vg=1.037993 -> Vg=1.0
% INFO    : Gen at bus 4692	: Pg=219.98, Qg=31.44 -> Pg=300.0, Qg=80.0
% INFO    : Gen at bus 4692	: Vg=1.026746 -> Vg=1.0
% INFO    : Gen at bus 4694	: Pg=32.57, Qg=7.29 -> Pg=60.855, Qg=10.0
% INFO    : Gen at bus 4694	: Vg=1.041748 -> Vg=1.0
% INFO    : Gen at bus 4695	: Pg=253.65, Qg=108.56 -> Pg=350.0, Qg=50.0
% INFO    : Gen at bus 4695	: Vg=1.038587 -> Vg=1.0
% INFO    : Gen at bus 4697	: Pg=60.81, Qg=1.23 -> Pg=120.27, Qg=20.0
% INFO    : Gen at bus 4697	: Vg=1.039251 -> Vg=1.0
% INFO    : Gen at bus 4698	: Pg=89.93, Qg=16.64 -> Pg=129.975, Qg=20.0
% INFO    : Gen at bus 4698	: Vg=1.037993 -> Vg=1.0
% INFO    : Gen at bus 4699	: Pg=89.93, Qg=16.64 -> Pg=129.975, Qg=20.0
% INFO    : Gen at bus 4699	: Vg=1.037993 -> Vg=1.0
% INFO    : Gen at bus 4702	: Pg=32.57, Qg=7.29 -> Pg=60.855, Qg=10.0
% INFO    : Gen at bus 4702	: Vg=1.041748 -> Vg=1.0
% INFO    : Gen at bus 4703	: Pg=55.22, Qg=8.96 -> Pg=118.405, Qg=15.0
% INFO    : Gen at bus 4703	: Vg=1.017828 -> Vg=1.0
% INFO    : Gen at bus 4704	: Pg=45.0, Qg=-3.79 -> Pg=65.0, Qg=0.0
% INFO    : Gen at bus 4704	: Vg=0.939142 -> Vg=1.0
% INFO    : Gen at bus 4707	: Pg=32.57, Qg=7.29 -> Pg=60.855, Qg=10.0
% INFO    : Gen at bus 4707	: Vg=1.041748 -> Vg=1.0
% INFO    : Gen at bus 4709	: Pg=18.76, Qg=6.31 -> Pg=56.255, Qg=10.0
% INFO    : Gen at bus 4709	: Vg=1.033648 -> Vg=1.0
% INFO    : Gen at bus 4710	: Pg=350.89, Qg=113.2 -> Pg=500.0, Qg=80.0
% INFO    : Gen at bus 4710	: Vg=1.0447 -> Vg=1.0
% INFO    : Gen at bus 4715	: Pg=25.35, Qg=8.5 -> Pg=58.45, Qg=15.0
% INFO    : Gen at bus 4715	: Vg=1.018631 -> Vg=1.0
% INFO    : Gen at bus 4718	: Pg=287.65, Qg=2.21 -> Pg=350.0, Qg=80.0
% INFO    : Gen at bus 4718	: Vg=1.045544 -> Vg=1.0
% INFO    : Gen at bus 4722	: Pg=91.94, Qg=33.76 -> Pg=130.645, Qg=20.0
% INFO    : Gen at bus 4722	: Vg=1.048656 -> Vg=1.0
% INFO    : Gen at bus 4723	: Pg=91.94, Qg=33.76 -> Pg=130.645, Qg=20.0
% INFO    : Gen at bus 4723	: Vg=1.048656 -> Vg=1.0
% INFO    : Gen at bus 4724	: Pg=91.94, Qg=33.76 -> Pg=130.645, Qg=20.0
% INFO    : Gen at bus 4724	: Vg=1.048656 -> Vg=1.0
% INFO    : Gen at bus 4725	: Pg=91.94, Qg=33.76 -> Pg=130.645, Qg=20.0
% INFO    : Gen at bus 4725	: Vg=1.048656 -> Vg=1.0
% INFO    : Gen at bus 4726	: Pg=91.94, Qg=33.76 -> Pg=130.645, Qg=20.0
% INFO    : Gen at bus 4726	: Vg=1.048656 -> Vg=1.0
% INFO    : Gen at bus 4727	: Pg=91.94, Qg=33.76 -> Pg=130.645, Qg=20.0
% INFO    : Gen at bus 4727	: Vg=1.048656 -> Vg=1.0
% INFO    : Gen at bus 4728	: Pg=91.94, Qg=33.76 -> Pg=130.645, Qg=20.0
% INFO    : Gen at bus 4728	: Vg=1.048656 -> Vg=1.0
% INFO    : Gen at bus 4729	: Pg=91.94, Qg=33.76 -> Pg=130.645, Qg=20.0
% INFO    : Gen at bus 4729	: Vg=1.048656 -> Vg=1.0
% INFO    : Gen at bus 4733	: Pg=26.6, Qg=23.03 -> Pg=58.865, Qg=10.0
% INFO    : Gen at bus 4733	: Vg=1.043092 -> Vg=1.0
% INFO    : Gen at bus 4738	: Pg=26.6, Qg=23.03 -> Pg=58.865, Qg=10.0
% INFO    : Gen at bus 4738	: Vg=1.043092 -> Vg=1.0
% INFO    : Gen at bus 4745	: Pg=56.07, Qg=3.64 -> Pg=118.69, Qg=20.0
% INFO    : Gen at bus 4745	: Vg=1.04834 -> Vg=1.0
% INFO    : Gen at bus 4746	: Pg=1.46, Qg=0.07 -> Pg=50.49, Qg=0.0
% INFO    : Gen at bus 4746	: Vg=1.026568 -> Vg=1.0
% INFO    : Gen at bus 4751	: Pg=91.88, Qg=4.87 -> Pg=130.625, Qg=20.0
% INFO    : Gen at bus 4751	: Vg=1.046359 -> Vg=1.0
% INFO    : Gen at bus 4752	: Pg=88.85, Qg=23.49 -> Pg=129.615, Qg=20.0
% INFO    : Gen at bus 4752	: Vg=1.032344 -> Vg=1.0
% INFO    : Gen at bus 4753	: Pg=91.88, Qg=4.87 -> Pg=130.625, Qg=20.0
% INFO    : Gen at bus 4753	: Vg=1.046359 -> Vg=1.0
% INFO    : Gen at bus 4757	: Pg=262.9, Qg=48.53 -> Pg=350.0, Qg=60.0
% INFO    : Gen at bus 4757	: Vg=1.027461 -> Vg=1.0
% INFO    : Gen at bus 4763	: Pg=36.11, Qg=3.87 -> Pg=62.035, Qg=10.0
% INFO    : Gen at bus 4763	: Vg=1.024544 -> Vg=1.0
% INFO    : Gen at bus 4764	: Pg=42.35, Qg=6.03 -> Pg=64.115, Qg=15.0
% INFO    : Gen at bus 4764	: Vg=1.030832 -> Vg=1.0
% INFO    : Gen at bus 4770	: Pg=58.52, Qg=23.33 -> Pg=119.505, Qg=15.0
% INFO    : Gen at bus 4770	: Vg=1.023397 -> Vg=1.0
% INFO    : Gen at bus 4771	: Pg=37.44, Qg=17.23 -> Pg=62.48, Qg=15.0
% INFO    : Gen at bus 4771	: Vg=1.022819 -> Vg=1.0
% INFO    : Gen at bus 4772	: Pg=58.52, Qg=23.33 -> Pg=119.505, Qg=15.0
% INFO    : Gen at bus 4772	: Vg=1.023397 -> Vg=1.0
% INFO    : Gen at bus 4773	: Pg=58.52, Qg=23.33 -> Pg=119.505, Qg=15.0
% INFO    : Gen at bus 4773	: Vg=1.023397 -> Vg=1.0
% INFO    : Gen at bus 4774	: Pg=37.45, Qg=15.75 -> Pg=62.485, Qg=15.0
% INFO    : Gen at bus 4774	: Vg=1.026206 -> Vg=1.0
% INFO    : Gen at bus 4775	: Pg=50.0, Qg=-2.27 -> Pg=66.665, Qg=0.0
% INFO    : Gen at bus 4775	: Vg=0.993383 -> Vg=1.0
% INFO    : Gen at bus 4777	: Pg=34.86, Qg=4.81 -> Pg=61.62, Qg=10.0
% INFO    : Gen at bus 4777	: Vg=1.050901 -> Vg=1.0
% INFO    : Gen at bus 4786	: Pg=62.5, Qg=10.73 -> Pg=120.835, Qg=10.0
% INFO    : Gen at bus 4786	: Vg=1.000057 -> Vg=1.0
% INFO    : Gen at bus 4791	: Pg=42.5, Qg=5.74 -> Pg=64.165, Qg=15.0
% INFO    : Gen at bus 4791	: Vg=1.031502 -> Vg=1.0
% INFO    : Gen at bus 4792	: Pg=42.5, Qg=5.74 -> Pg=64.165, Qg=15.0
% INFO    : Gen at bus 4792	: Vg=1.031502 -> Vg=1.0
% INFO    : Gen at bus 4793	: Pg=32.51, Qg=6.89 -> Pg=60.835, Qg=10.0
% INFO    : Gen at bus 4793	: Vg=1.011478 -> Vg=1.0
% INFO    : Gen at bus 4796	: Pg=15.0, Qg=5.62 -> Pg=55.0, Qg=5.0
% INFO    : Gen at bus 4796	: Vg=1.034961 -> Vg=1.0
% INFO    : Gen at bus 4809	: Pg=97.12, Qg=8.38 -> Pg=132.375, Qg=20.0
% INFO    : Gen at bus 4809	: Vg=1.040009 -> Vg=1.0
% INFO    : Gen at bus 4810	: Pg=97.12, Qg=8.38 -> Pg=132.375, Qg=20.0
% INFO    : Gen at bus 4810	: Vg=1.040009 -> Vg=1.0
% INFO    : Gen at bus 4811	: Pg=97.12, Qg=8.38 -> Pg=132.375, Qg=20.0
% INFO    : Gen at bus 4811	: Vg=1.040009 -> Vg=1.0
% INFO    : Gen at bus 4814	: Pg=90.17, Qg=24.56 -> Pg=130.055, Qg=20.0
% INFO    : Gen at bus 4814	: Vg=1.06019 -> Vg=1.0
% INFO    : Gen at bus 4823	: Pg=22.0, Qg=10.36 -> Pg=57.335, Qg=10.0
% INFO    : Gen at bus 4823	: Vg=1.014332 -> Vg=1.0
% INFO    : Gen at bus 4837	: Pg=65.21, Qg=12.85 -> Pg=121.735, Qg=20.0
% INFO    : Gen at bus 4837	: Vg=1.026243 -> Vg=1.0
% INFO    : Gen at bus 4843	: Pg=65.21, Qg=12.85 -> Pg=121.735, Qg=20.0
% INFO    : Gen at bus 4843	: Vg=1.026243 -> Vg=1.0
% INFO    : Gen at bus 4844	: Pg=65.21, Qg=12.85 -> Pg=121.735, Qg=20.0
% INFO    : Gen at bus 4844	: Vg=1.026243 -> Vg=1.0
% INFO    : Gen at bus 4845	: Pg=65.21, Qg=12.85 -> Pg=121.735, Qg=20.0
% INFO    : Gen at bus 4845	: Vg=1.026243 -> Vg=1.0
% INFO    : Gen at bus 4846	: Pg=65.21, Qg=12.85 -> Pg=121.735, Qg=20.0
% INFO    : Gen at bus 4846	: Vg=1.026243 -> Vg=1.0
% INFO    : Gen at bus 4847	: Pg=65.21, Qg=12.85 -> Pg=121.735, Qg=20.0
% INFO    : Gen at bus 4847	: Vg=1.026243 -> Vg=1.0
% INFO    : Gen at bus 4855	: Pg=288.69, Qg=133.24 -> Pg=350.0, Qg=60.0
% INFO    : Gen at bus 4855	: Vg=1.060956 -> Vg=1.0
% INFO    : Gen at bus 4856	: Pg=288.69, Qg=133.24 -> Pg=350.0, Qg=60.0
% INFO    : Gen at bus 4856	: Vg=1.060956 -> Vg=1.0
% INFO    : Gen at bus 4857	: Pg=256.4, Qg=117.4 -> Pg=350.0, Qg=60.0
% INFO    : Gen at bus 4857	: Vg=1.062536 -> Vg=1.0
% INFO    : Gen at bus 4858	: Pg=256.4, Qg=117.4 -> Pg=350.0, Qg=60.0
% INFO    : Gen at bus 4858	: Vg=1.062536 -> Vg=1.0
% INFO    : Gen at bus 4859	: Pg=222.47, Qg=102.94 -> Pg=300.0, Qg=60.0
% INFO    : Gen at bus 4859	: Vg=1.059942 -> Vg=1.0
% INFO    : Gen at bus 4861	: Pg=279.23, Qg=123.34 -> Pg=350.0, Qg=60.0
% INFO    : Gen at bus 4861	: Vg=1.05948 -> Vg=1.0
% INFO    : Gen at bus 4862	: Pg=279.23, Qg=123.34 -> Pg=350.0, Qg=60.0
% INFO    : Gen at bus 4862	: Vg=1.05948 -> Vg=1.0
% INFO    : Gen at bus 4864	: Pg=222.47, Qg=102.94 -> Pg=300.0, Qg=60.0
% INFO    : Gen at bus 4864	: Vg=1.059942 -> Vg=1.0
% INFO    : Gen at bus 4870	: Pg=18.74, Qg=3.61 -> Pg=56.245, Qg=10.0
% INFO    : Gen at bus 4870	: Vg=1.025271 -> Vg=1.0
% INFO    : Gen at bus 4887	: Pg=331.89, Qg=-5.79 -> Pg=450.0, Qg=80.0
% INFO    : Gen at bus 4887	: Vg=1.01898 -> Vg=1.0
% INFO    : Gen at bus 4888	: Pg=331.89, Qg=-5.79 -> Pg=450.0, Qg=80.0
% INFO    : Gen at bus 4888	: Vg=1.01898 -> Vg=1.0
% INFO    : Gen at bus 4892	: Pg=280.8, Qg=38.38 -> Pg=350.0, Qg=60.0
% INFO    : Gen at bus 4892	: Vg=1.024711 -> Vg=1.0
% INFO    : Gen at bus 4893	: Pg=280.8, Qg=38.38 -> Pg=350.0, Qg=60.0
% INFO    : Gen at bus 4893	: Vg=1.024711 -> Vg=1.0
% INFO    : Gen at bus 4896	: Pg=280.8, Qg=38.38 -> Pg=350.0, Qg=60.0
% INFO    : Gen at bus 4896	: Vg=1.024711 -> Vg=1.0
% INFO    : Gen at bus 4897	: Pg=280.8, Qg=38.38 -> Pg=350.0, Qg=60.0
% INFO    : Gen at bus 4897	: Vg=1.024711 -> Vg=1.0
% INFO    : Gen at bus 4902	: Pg=22.8, Qg=8.85 -> Pg=57.6, Qg=10.0
% INFO    : Gen at bus 4902	: Vg=1.045936 -> Vg=1.0
% INFO    : Gen at bus 4903	: Pg=22.8, Qg=8.85 -> Pg=57.6, Qg=10.0
% INFO    : Gen at bus 4903	: Vg=1.045936 -> Vg=1.0
% INFO    : Gen at bus 4904	: Pg=27.65, Qg=6.22 -> Pg=59.215, Qg=10.0
% INFO    : Gen at bus 4904	: Vg=1.058505 -> Vg=1.0
% INFO    : Gen at bus 4905	: Pg=27.65, Qg=6.22 -> Pg=59.215, Qg=10.0
% INFO    : Gen at bus 4905	: Vg=1.058505 -> Vg=1.0
% INFO    : Gen at bus 4910	: Pg=35.74, Qg=6.84 -> Pg=61.915, Qg=10.0
% INFO    : Gen at bus 4910	: Vg=1.040138 -> Vg=1.0
% INFO    : Gen at bus 4917	: Pg=21.0, Qg=0.7 -> Pg=57.0, Qg=0.0
% INFO    : Gen at bus 4917	: Vg=0.989071 -> Vg=1.0
% INFO    : Gen at bus 4918	: Pg=39.1, Qg=-2.22 -> Pg=63.035, Qg=0.0
% INFO    : Gen at bus 4918	: Vg=0.943436 -> Vg=1.0
% INFO    : Gen at bus 4922	: Pg=47.29, Qg=6.72 -> Pg=65.765, Qg=15.0
% INFO    : Gen at bus 4922	: Vg=1.04826 -> Vg=1.0
% INFO    : Gen at bus 4924	: Pg=56.84, Qg=10.43 -> Pg=118.945, Qg=15.0
% INFO    : Gen at bus 4924	: Vg=1.025724 -> Vg=1.0
% INFO    : Gen at bus 4925	: Pg=35.69, Qg=7.89 -> Pg=61.895, Qg=10.0
% INFO    : Gen at bus 4925	: Vg=1.017601 -> Vg=1.0
% INFO    : Gen at bus 4926	: Pg=19.96, Qg=23.09 -> Pg=56.655, Qg=10.0
% INFO    : Gen at bus 4926	: Vg=1.036433 -> Vg=1.0
% INFO    : Gen at bus 4928	: Pg=277.26, Qg=31.82 -> Pg=350.0, Qg=80.0
% INFO    : Gen at bus 4928	: Vg=1.04876 -> Vg=1.0
% INFO    : Gen at bus 4931	: Pg=36.7, Qg=9.55 -> Pg=62.235, Qg=10.0
% INFO    : Gen at bus 4931	: Vg=1.037501 -> Vg=1.0
% INFO    : Gen at bus 4932	: Pg=36.7, Qg=9.55 -> Pg=62.235, Qg=10.0
% INFO    : Gen at bus 4932	: Vg=1.037501 -> Vg=1.0
% INFO    : Gen at bus 4934	: Pg=36.91, Qg=13.33 -> Pg=62.305, Qg=10.0
% INFO    : Gen at bus 4934	: Vg=1.037973 -> Vg=1.0
% INFO    : Gen at bus 4938	: Pg=37.67, Qg=5.32 -> Pg=62.56, Qg=5.0
% INFO    : Gen at bus 4938	: Vg=1.027032 -> Vg=1.0
% INFO    : Gen at bus 4939	: Pg=38.53, Qg=9.19 -> Pg=62.845, Qg=10.0
% INFO    : Gen at bus 4939	: Vg=1.03611 -> Vg=1.0
% INFO    : Gen at bus 4942	: Pg=23.63, Qg=8.01 -> Pg=57.875, Qg=10.0
% INFO    : Gen at bus 4942	: Vg=1.038474 -> Vg=1.0
% INFO    : Gen at bus 4943	: Pg=23.63, Qg=8.01 -> Pg=57.875, Qg=10.0
% INFO    : Gen at bus 4943	: Vg=1.038474 -> Vg=1.0
% INFO    : Gen at bus 4945	: Pg=24.77, Qg=15.08 -> Pg=58.255, Qg=10.0
% INFO    : Gen at bus 4945	: Vg=1.042258 -> Vg=1.0
% INFO    : Gen at bus 4946	: Pg=24.77, Qg=15.08 -> Pg=58.255, Qg=10.0
% INFO    : Gen at bus 4946	: Vg=1.042258 -> Vg=1.0
% INFO    : Gen at bus 4949	: Pg=48.42, Qg=9.78 -> Pg=66.14, Qg=15.0
% INFO    : Gen at bus 4949	: Vg=1.01601 -> Vg=1.0
% INFO    : Gen at bus 4952	: Pg=249.55, Qg=64.24 -> Pg=300.0, Qg=80.0
% INFO    : Gen at bus 4952	: Vg=1.03281 -> Vg=1.0
% INFO    : Gen at bus 4958	: Pg=50.82, Qg=16.11 -> Pg=116.94, Qg=15.0
% INFO    : Gen at bus 4958	: Vg=1.025082 -> Vg=1.0
% INFO    : Gen at bus 4959	: Pg=677.41, Qg=27.58 -> Pg=900.0, Qg=200.0
% INFO    : Gen at bus 4959	: Vg=1.024274 -> Vg=1.0
% INFO    : Gen at bus 4963	: Pg=57.59, Qg=10.86 -> Pg=119.195, Qg=15.0
% INFO    : Gen at bus 4963	: Vg=1.019736 -> Vg=1.0
% INFO    : Gen at bus 4964	: Pg=57.59, Qg=10.86 -> Pg=119.195, Qg=15.0
% INFO    : Gen at bus 4964	: Vg=1.019736 -> Vg=1.0
% INFO    : Gen at bus 4967	: Pg=16.67, Qg=4.68 -> Pg=55.555, Qg=10.0
% INFO    : Gen at bus 4967	: Vg=1.013686 -> Vg=1.0
% INFO    : Gen at bus 4982	: Pg=98.46, Qg=12.34 -> Pg=132.82, Qg=20.0
% INFO    : Gen at bus 4982	: Vg=1.01458 -> Vg=1.0
% INFO    : Gen at bus 4983	: Pg=7.0, Qg=0.65 -> Pg=52.335, Qg=0.0
% INFO    : Gen at bus 4983	: Vg=0.995619 -> Vg=1.0
% INFO    : Gen at bus 4985	: Pg=37.96, Qg=13.4 -> Pg=62.655, Qg=10.0
% INFO    : Gen at bus 4985	: Vg=1.073911 -> Vg=1.0
% INFO    : Gen at bus 4987	: Pg=38.04, Qg=7.18 -> Pg=62.68, Qg=10.0
% INFO    : Gen at bus 4987	: Vg=1.020265 -> Vg=1.0
% INFO    : Gen at bus 4988	: Pg=24.84, Qg=4.52 -> Pg=58.28, Qg=10.0
% INFO    : Gen at bus 4988	: Vg=1.022099 -> Vg=1.0
% INFO    : Gen at bus 4998	: Pg=72.47, Qg=11.44 -> Pg=124.155, Qg=20.0
% INFO    : Gen at bus 4998	: Vg=1.019231 -> Vg=1.0
% INFO    : Gen at bus 5000	: Pg=2.94, Qg=0.27 -> Pg=50.98, Qg=0.0
% INFO    : Gen at bus 5000	: Vg=1.008736 -> Vg=1.0
% INFO    : Gen at bus 5007	: Pg=34.37, Qg=6.67 -> Pg=61.455, Qg=10.0
% INFO    : Gen at bus 5007	: Vg=1.035406 -> Vg=1.0
% INFO    : Gen at bus 5008	: Pg=34.37, Qg=6.67 -> Pg=61.455, Qg=10.0
% INFO    : Gen at bus 5008	: Vg=1.035406 -> Vg=1.0
% INFO    : Gen at bus 5009	: Pg=34.37, Qg=6.67 -> Pg=61.455, Qg=10.0
% INFO    : Gen at bus 5009	: Vg=1.035406 -> Vg=1.0
% INFO    : Gen at bus 5012	: Pg=74.36, Qg=21.23 -> Pg=124.785, Qg=20.0
% INFO    : Gen at bus 5012	: Vg=1.032132 -> Vg=1.0
% INFO    : Gen at bus 5013	: Pg=74.36, Qg=21.23 -> Pg=124.785, Qg=20.0
% INFO    : Gen at bus 5013	: Vg=1.032132 -> Vg=1.0
% INFO    : Gen at bus 5017	: Pg=69.35, Qg=21.13 -> Pg=123.115, Qg=20.0
% INFO    : Gen at bus 5017	: Vg=1.032238 -> Vg=1.0
% INFO    : Gen at bus 5018	: Pg=69.35, Qg=21.13 -> Pg=123.115, Qg=20.0
% INFO    : Gen at bus 5018	: Vg=1.032238 -> Vg=1.0
% INFO    : Gen at bus 5023	: Pg=229.56, Qg=74.98 -> Pg=300.0, Qg=80.0
% INFO    : Gen at bus 5023	: Vg=1.052394 -> Vg=1.0
% INFO    : Gen at bus 5025	: Pg=21.69, Qg=5.19 -> Pg=57.23, Qg=10.0
% INFO    : Gen at bus 5025	: Vg=1.050987 -> Vg=1.0
% INFO    : Gen at bus 5029	: Pg=31.79, Qg=7.29 -> Pg=60.595, Qg=10.0
% INFO    : Gen at bus 5029	: Vg=1.005112 -> Vg=1.0
% INFO    : Gen at bus 5034	: Pg=256.62, Qg=49.7 -> Pg=350.0, Qg=80.0
% INFO    : Gen at bus 5034	: Vg=1.019932 -> Vg=1.0
% INFO    : Gen at bus 5036	: Pg=26.41, Qg=7.43 -> Pg=58.805, Qg=10.0
% INFO    : Gen at bus 5036	: Vg=1.038011 -> Vg=1.0
% INFO    : Gen at bus 5037	: Pg=16.71, Qg=0.01 -> Pg=55.57, Qg=10.0
% INFO    : Gen at bus 5037	: Vg=1.030988 -> Vg=1.0
% INFO    : Gen at bus 5038	: Pg=28.97, Qg=5.47 -> Pg=59.655, Qg=10.0
% INFO    : Gen at bus 5038	: Vg=1.043059 -> Vg=1.0
% INFO    : Gen at bus 5050	: Pg=17.0, Qg=0.3 -> Pg=55.665, Qg=0.0
% INFO    : Gen at bus 5050	: Vg=0.987146 -> Vg=1.0
% INFO    : Gen at bus 5051	: Pg=37.85, Qg=8.46 -> Pg=62.615, Qg=10.0
% INFO    : Gen at bus 5051	: Vg=1.035412 -> Vg=1.0
% INFO    : Gen at bus 5052	: Pg=37.85, Qg=8.46 -> Pg=62.615, Qg=10.0
% INFO    : Gen at bus 5052	: Vg=1.035412 -> Vg=1.0
% INFO    : Gen at bus 5053	: Pg=37.85, Qg=8.46 -> Pg=62.615, Qg=10.0
% INFO    : Gen at bus 5053	: Vg=1.035412 -> Vg=1.0
% INFO    : Gen at bus 5054	: Pg=17.6, Qg=22.53 -> Pg=55.865, Qg=10.0
% INFO    : Gen at bus 5054	: Vg=1.05667 -> Vg=1.0
% INFO    : Gen at bus 5055	: Pg=17.6, Qg=22.53 -> Pg=55.865, Qg=10.0
% INFO    : Gen at bus 5055	: Vg=1.05667 -> Vg=1.0
% INFO    : Gen at bus 5056	: Pg=17.6, Qg=22.53 -> Pg=55.865, Qg=10.0
% INFO    : Gen at bus 5056	: Vg=1.05667 -> Vg=1.0
% INFO    : Gen at bus 5057	: Pg=17.6, Qg=22.53 -> Pg=55.865, Qg=10.0
% INFO    : Gen at bus 5057	: Vg=1.05667 -> Vg=1.0
% INFO    : Gen at bus 5058	: Pg=349.51, Qg=198.35 -> Pg=450.0, Qg=80.0
% INFO    : Gen at bus 5058	: Vg=1.049254 -> Vg=1.0
% INFO    : Gen at bus 5059	: Pg=210.14, Qg=188.39 -> Pg=300.0, Qg=80.0
% INFO    : Gen at bus 5059	: Vg=1.083018 -> Vg=1.0
% INFO    : Gen at bus 5060	: Pg=210.14, Qg=188.39 -> Pg=300.0, Qg=80.0
% INFO    : Gen at bus 5060	: Vg=1.083018 -> Vg=1.0
% INFO    : Gen at bus 5061	: Pg=10.5, Qg=-0.35 -> Pg=53.5, Qg=0.0
% INFO    : Gen at bus 5061	: Vg=0.994858 -> Vg=1.0
% INFO    : Gen at bus 5062	: Pg=279.8, Qg=200.76 -> Pg=350.0, Qg=80.0
% INFO    : Gen at bus 5062	: Vg=1.056742 -> Vg=1.0
% INFO    : Gen at bus 5063	: Pg=279.8, Qg=200.76 -> Pg=350.0, Qg=80.0
% INFO    : Gen at bus 5063	: Vg=1.056742 -> Vg=1.0
% INFO    : Gen at bus 5064	: Pg=279.8, Qg=200.76 -> Pg=350.0, Qg=80.0
% INFO    : Gen at bus 5064	: Vg=1.056742 -> Vg=1.0
% INFO    : Gen at bus 5065	: Pg=349.51, Qg=198.35 -> Pg=450.0, Qg=80.0
% INFO    : Gen at bus 5065	: Vg=1.049254 -> Vg=1.0
% INFO    : Gen at bus 5069	: Pg=18.8, Qg=7.03 -> Pg=56.265, Qg=10.0
% INFO    : Gen at bus 5069	: Vg=0.995797 -> Vg=1.0
% INFO    : Gen at bus 5070	: Pg=15.94, Qg=-1.51 -> Pg=55.315, Qg=0.0
% INFO    : Gen at bus 5070	: Vg=0.999202 -> Vg=1.0
% INFO    : Gen at bus 5071	: Pg=18.8, Qg=7.03 -> Pg=56.265, Qg=10.0
% INFO    : Gen at bus 5071	: Vg=0.995797 -> Vg=1.0
% INFO    : Gen at bus 5072	: Pg=18.8, Qg=7.03 -> Pg=56.265, Qg=10.0
% INFO    : Gen at bus 5072	: Vg=0.995797 -> Vg=1.0
% INFO    : Gen at bus 5073	: Pg=18.8, Qg=7.03 -> Pg=56.265, Qg=10.0
% INFO    : Gen at bus 5073	: Vg=0.995797 -> Vg=1.0
% INFO    : Gen at bus 5074	: Pg=18.8, Qg=7.03 -> Pg=56.265, Qg=10.0
% INFO    : Gen at bus 5074	: Vg=0.995797 -> Vg=1.0
% INFO    : Gen at bus 5076	: Pg=19.26, Qg=2.33 -> Pg=56.42, Qg=10.0
% INFO    : Gen at bus 5076	: Vg=1.049756 -> Vg=1.0
% INFO    : Gen at bus 5077	: Pg=19.26, Qg=2.33 -> Pg=56.42, Qg=10.0
% INFO    : Gen at bus 5077	: Vg=1.049756 -> Vg=1.0
% INFO    : Gen at bus 5078	: Pg=19.26, Qg=2.33 -> Pg=56.42, Qg=10.0
% INFO    : Gen at bus 5078	: Vg=1.049756 -> Vg=1.0
% INFO    : Gen at bus 5082	: Pg=85.48, Qg=16.54 -> Pg=128.495, Qg=20.0
% INFO    : Gen at bus 5082	: Vg=1.029323 -> Vg=1.0
% INFO    : Gen at bus 5084	: Pg=227.2, Qg=71.82 -> Pg=300.0, Qg=80.0
% INFO    : Gen at bus 5084	: Vg=1.06339 -> Vg=1.0
% INFO    : Gen at bus 5085	: Pg=83.48, Qg=36.7 -> Pg=127.825, Qg=20.0
% INFO    : Gen at bus 5085	: Vg=1.041566 -> Vg=1.0
% INFO    : Gen at bus 5086	: Pg=83.48, Qg=36.7 -> Pg=127.825, Qg=20.0
% INFO    : Gen at bus 5086	: Vg=1.041566 -> Vg=1.0
% INFO    : Gen at bus 5089	: Pg=83.47, Qg=36.43 -> Pg=127.825, Qg=20.0
% INFO    : Gen at bus 5089	: Vg=1.039883 -> Vg=1.0
% INFO    : Gen at bus 5090	: Pg=83.47, Qg=36.43 -> Pg=127.825, Qg=20.0
% INFO    : Gen at bus 5090	: Vg=1.039883 -> Vg=1.0
% INFO    : Gen at bus 5091	: Pg=83.48, Qg=36.7 -> Pg=127.825, Qg=20.0
% INFO    : Gen at bus 5091	: Vg=1.041566 -> Vg=1.0
% INFO    : Gen at bus 5092	: Pg=83.48, Qg=36.7 -> Pg=127.825, Qg=20.0
% INFO    : Gen at bus 5092	: Vg=1.041566 -> Vg=1.0
% INFO    : Gen at bus 5099	: Pg=29.83, Qg=8.08 -> Pg=59.945, Qg=10.0
% INFO    : Gen at bus 5099	: Vg=1.015374 -> Vg=1.0
% INFO    : Gen at bus 5109	: Pg=21.17, Qg=9.91 -> Pg=57.055, Qg=10.0
% INFO    : Gen at bus 5109	: Vg=1.048748 -> Vg=1.0
% INFO    : Gen at bus 5111	: Pg=6.52, Qg=0.05 -> Pg=52.175, Qg=0.0
% INFO    : Gen at bus 5111	: Vg=0.996117 -> Vg=1.0
% INFO    : Gen at bus 5116	: Pg=32.34, Qg=-0.25 -> Pg=60.78, Qg=5.0
% INFO    : Gen at bus 5116	: Vg=1.013887 -> Vg=1.0
% INFO    : Gen at bus 5122	: Pg=19.12, Qg=15.11 -> Pg=56.375, Qg=10.0
% INFO    : Gen at bus 5122	: Vg=1.030744 -> Vg=1.0
% INFO    : Gen at bus 5123	: Pg=33.69, Qg=12.78 -> Pg=61.23, Qg=10.0
% INFO    : Gen at bus 5123	: Vg=1.043216 -> Vg=1.0
% INFO    : Gen at bus 5126	: Pg=38.57, Qg=10.56 -> Pg=62.855, Qg=10.0
% INFO    : Gen at bus 5126	: Vg=1.045141 -> Vg=1.0
% INFO    : Gen at bus 5127	: Pg=38.57, Qg=10.56 -> Pg=62.855, Qg=10.0
% INFO    : Gen at bus 5127	: Vg=1.045141 -> Vg=1.0
% INFO    : Gen at bus 5128	: Pg=19.12, Qg=15.11 -> Pg=56.375, Qg=10.0
% INFO    : Gen at bus 5128	: Vg=1.030744 -> Vg=1.0
% INFO    : Gen at bus 5129	: Pg=19.12, Qg=15.11 -> Pg=56.375, Qg=10.0
% INFO    : Gen at bus 5129	: Vg=1.030744 -> Vg=1.0
% INFO    : Gen at bus 5130	: Pg=19.12, Qg=15.11 -> Pg=56.375, Qg=10.0
% INFO    : Gen at bus 5130	: Vg=1.030744 -> Vg=1.0
% INFO    : Gen at bus 5131	: Pg=19.12, Qg=15.11 -> Pg=56.375, Qg=10.0
% INFO    : Gen at bus 5131	: Vg=1.030744 -> Vg=1.0
% INFO    : Gen at bus 5133	: Pg=19.12, Qg=15.11 -> Pg=56.375, Qg=10.0
% INFO    : Gen at bus 5133	: Vg=1.030744 -> Vg=1.0
% INFO    : Gen at bus 5134	: Pg=30.93, Qg=8.23 -> Pg=60.31, Qg=10.0
% INFO    : Gen at bus 5134	: Vg=1.035888 -> Vg=1.0
% INFO    : Gen at bus 5135	: Pg=319.18, Qg=33.68 -> Pg=450.0, Qg=80.0
% INFO    : Gen at bus 5135	: Vg=1.026027 -> Vg=1.0
% INFO    : Gen at bus 5138	: Pg=26.75, Qg=6.78 -> Pg=58.915, Qg=15.0
% INFO    : Gen at bus 5138	: Vg=1.024572 -> Vg=1.0
% INFO    : Gen at bus 5143	: Pg=96.9, Qg=14.27 -> Pg=132.3, Qg=20.0
% INFO    : Gen at bus 5143	: Vg=1.033735 -> Vg=1.0
% INFO    : Gen at bus 5144	: Pg=35.99, Qg=7.92 -> Pg=61.995, Qg=10.0
% INFO    : Gen at bus 5144	: Vg=1.017192 -> Vg=1.0
% INFO    : Gen at bus 5145	: Pg=18.68, Qg=3.68 -> Pg=56.225, Qg=10.0
% INFO    : Gen at bus 5145	: Vg=1.01785 -> Vg=1.0
% INFO    : Gen at bus 5146	: Pg=18.68, Qg=3.68 -> Pg=56.225, Qg=10.0
% INFO    : Gen at bus 5146	: Vg=1.01785 -> Vg=1.0
% INFO    : Gen at bus 5147	: Pg=18.68, Qg=3.68 -> Pg=56.225, Qg=10.0
% INFO    : Gen at bus 5147	: Vg=1.01785 -> Vg=1.0
% INFO    : Gen at bus 5148	: Pg=30.26, Qg=9.8 -> Pg=60.085, Qg=10.0
% INFO    : Gen at bus 5148	: Vg=1.024966 -> Vg=1.0
% INFO    : Gen at bus 5151	: Pg=18.67, Qg=5.94 -> Pg=56.225, Qg=10.0
% INFO    : Gen at bus 5151	: Vg=1.015505 -> Vg=1.0
% INFO    : Gen at bus 5155	: Pg=147.93, Qg=31.02 -> Pg=199.31, Qg=60.0
% INFO    : Gen at bus 5155	: Vg=1.044772 -> Vg=1.0
% INFO    : Gen at bus 5158	: Pg=141.75, Qg=-12.6 -> Pg=197.25, Qg=0.0
% INFO    : Gen at bus 5158	: Vg=0.98522 -> Vg=1.0
% INFO    : Gen at bus 5159	: Pg=96.9, Qg=14.27 -> Pg=132.3, Qg=20.0
% INFO    : Gen at bus 5159	: Vg=1.033735 -> Vg=1.0
% INFO    : Gen at bus 5162	: Pg=10.0, Qg=2.6 -> Pg=53.335, Qg=0.0
% INFO    : Gen at bus 5162	: Vg=1.008964 -> Vg=1.0
% INFO    : Gen at bus 5163	: Pg=96.9, Qg=14.27 -> Pg=132.3, Qg=20.0
% INFO    : Gen at bus 5163	: Vg=1.033735 -> Vg=1.0
% INFO    : Gen at bus 5166	: Pg=44.9, Qg=-0.09 -> Pg=64.965, Qg=20.0
% INFO    : Gen at bus 5166	: Vg=1.017024 -> Vg=1.0
% INFO    : Gen at bus 5169	: Pg=19.9, Qg=1.8 -> Pg=56.635, Qg=5.0
% INFO    : Gen at bus 5169	: Vg=1.040788 -> Vg=1.0
% INFO    : Gen at bus 5177	: Pg=25.46, Qg=7.25 -> Pg=58.485, Qg=10.0
% INFO    : Gen at bus 5177	: Vg=1.023095 -> Vg=1.0
% INFO    : Gen at bus 5178	: Pg=25.46, Qg=7.25 -> Pg=58.485, Qg=10.0
% INFO    : Gen at bus 5178	: Vg=1.023095 -> Vg=1.0
% INFO    : Gen at bus 5187	: Pg=37.08, Qg=5.51 -> Pg=62.36, Qg=10.0
% INFO    : Gen at bus 5187	: Vg=1.021005 -> Vg=1.0
% INFO    : Gen at bus 5188	: Pg=40.49, Qg=8.06 -> Pg=63.495, Qg=10.0
% INFO    : Gen at bus 5188	: Vg=1.036966 -> Vg=1.0
% INFO    : Gen at bus 5192	: Pg=180.86, Qg=44.37 -> Pg=250.0, Qg=60.0
% INFO    : Gen at bus 5192	: Vg=1.044001 -> Vg=1.0
% INFO    : Gen at bus 5196	: Pg=32.36, Qg=7.22 -> Pg=60.785, Qg=10.0
% INFO    : Gen at bus 5196	: Vg=1.028002 -> Vg=1.0
% INFO    : Gen at bus 5202	: Pg=30.6, Qg=-1.46 -> Pg=60.2, Qg=0.0
% INFO    : Gen at bus 5202	: Vg=0.99834 -> Vg=1.0
% INFO    : Gen at bus 5207	: Pg=332.21, Qg=116.49 -> Pg=450.0, Qg=80.0
% INFO    : Gen at bus 5207	: Vg=1.047444 -> Vg=1.0
% INFO    : Gen at bus 5208	: Pg=332.21, Qg=116.49 -> Pg=450.0, Qg=80.0
% INFO    : Gen at bus 5208	: Vg=1.047444 -> Vg=1.0
% INFO    : Gen at bus 5210	: Pg=0.51, Qg=0.04 -> Pg=50.17, Qg=0.0
% INFO    : Gen at bus 5210	: Vg=1.029935 -> Vg=1.0
% INFO    : Gen at bus 5212	: Pg=67.5, Qg=7.59 -> Pg=122.5, Qg=15.0
% INFO    : Gen at bus 5212	: Vg=1.021725 -> Vg=1.0
% INFO    : Gen at bus 5223	: Pg=359.06, Qg=76.72 -> Pg=500.0, Qg=80.0
% INFO    : Gen at bus 5223	: Vg=1.054235 -> Vg=1.0
% INFO    : Gen at bus 5225	: Pg=50.33, Qg=11.56 -> Pg=116.775, Qg=15.0
% INFO    : Gen at bus 5225	: Vg=1.037142 -> Vg=1.0
% INFO    : Gen at bus 5226	: Pg=50.33, Qg=11.56 -> Pg=116.775, Qg=15.0
% INFO    : Gen at bus 5226	: Vg=1.037142 -> Vg=1.0
% INFO    : Gen at bus 5228	: Pg=50.33, Qg=11.56 -> Pg=116.775, Qg=15.0
% INFO    : Gen at bus 5228	: Vg=1.037142 -> Vg=1.0
% INFO    : Gen at bus 5229	: Pg=50.33, Qg=11.56 -> Pg=116.775, Qg=15.0
% INFO    : Gen at bus 5229	: Vg=1.037142 -> Vg=1.0
% INFO    : Gen at bus 5242	: Pg=72.17, Qg=16.24 -> Pg=124.055, Qg=20.0
% INFO    : Gen at bus 5242	: Vg=1.022616 -> Vg=1.0
% INFO    : Gen at bus 5243	: Pg=56.17, Qg=4.09 -> Pg=118.725, Qg=20.0
% INFO    : Gen at bus 5243	: Vg=1.003094 -> Vg=1.0
% INFO    : Gen at bus 5245	: Pg=46.8, Qg=8.97 -> Pg=65.6, Qg=20.0
% INFO    : Gen at bus 5245	: Vg=0.993793 -> Vg=1.0
% INFO    : Gen at bus 5246	: Pg=72.17, Qg=16.24 -> Pg=124.055, Qg=20.0
% INFO    : Gen at bus 5246	: Vg=1.022616 -> Vg=1.0
% INFO    : Gen at bus 5252	: Pg=48.81, Qg=10.42 -> Pg=66.27, Qg=15.0
% INFO    : Gen at bus 5252	: Vg=1.017273 -> Vg=1.0
% INFO    : Gen at bus 5254	: Pg=0.26, Qg=-0.09 -> Pg=50.085, Qg=0.0
% INFO    : Gen at bus 5254	: Vg=1.024094 -> Vg=1.0
% INFO    : Gen at bus 5260	: Pg=286.96, Qg=43.74 -> Pg=350.0, Qg=60.0
% INFO    : Gen at bus 5260	: Vg=1.028088 -> Vg=1.0
% INFO    : Gen at bus 5261	: Pg=48.81, Qg=10.42 -> Pg=66.27, Qg=15.0
% INFO    : Gen at bus 5261	: Vg=1.017273 -> Vg=1.0
% INFO    : Gen at bus 5262	: Pg=48.81, Qg=10.42 -> Pg=66.27, Qg=15.0
% INFO    : Gen at bus 5262	: Vg=1.017273 -> Vg=1.0
% INFO    : Gen at bus 5270	: Pg=57.51, Qg=17.72 -> Pg=119.17, Qg=15.0
% INFO    : Gen at bus 5270	: Vg=1.029323 -> Vg=1.0
% INFO    : Gen at bus 5271	: Pg=57.51, Qg=17.72 -> Pg=119.17, Qg=15.0
% INFO    : Gen at bus 5271	: Vg=1.029323 -> Vg=1.0
% INFO    : Gen at bus 5274	: Pg=55.04, Qg=14.65 -> Pg=118.345, Qg=15.0
% INFO    : Gen at bus 5274	: Vg=1.023803 -> Vg=1.0
% INFO    : Gen at bus 5275	: Pg=55.04, Qg=14.65 -> Pg=118.345, Qg=15.0
% INFO    : Gen at bus 5275	: Vg=1.023803 -> Vg=1.0
% INFO    : Gen at bus 5276	: Pg=55.04, Qg=14.65 -> Pg=118.345, Qg=15.0
% INFO    : Gen at bus 5276	: Vg=1.023803 -> Vg=1.0
% INFO    : Gen at bus 5277	: Pg=55.04, Qg=14.65 -> Pg=118.345, Qg=15.0
% INFO    : Gen at bus 5277	: Vg=1.023803 -> Vg=1.0
% INFO    : Gen at bus 5278	: Pg=57.51, Qg=17.72 -> Pg=119.17, Qg=15.0
% INFO    : Gen at bus 5278	: Vg=1.029323 -> Vg=1.0
% INFO    : Gen at bus 5279	: Pg=57.51, Qg=17.72 -> Pg=119.17, Qg=15.0
% INFO    : Gen at bus 5279	: Vg=1.029323 -> Vg=1.0
% INFO    : Gen at bus 5281	: Pg=155.0, Qg=-15.46 -> Pg=250.0, Qg=0.0
% INFO    : Gen at bus 5281	: Vg=0.98306 -> Vg=1.0
% INFO    : Gen at bus 5286	: Pg=70.12, Qg=2.87 -> Pg=123.375, Qg=20.0
% INFO    : Gen at bus 5286	: Vg=1.023526 -> Vg=1.0
% INFO    : Gen at bus 5287	: Pg=70.12, Qg=2.87 -> Pg=123.375, Qg=20.0
% INFO    : Gen at bus 5287	: Vg=1.023526 -> Vg=1.0
% INFO    : Gen at bus 5289	: Pg=8.2, Qg=-0.77 -> Pg=52.735, Qg=0.0
% INFO    : Gen at bus 5289	: Vg=1.00746 -> Vg=1.0
% INFO    : Gen at bus 5292	: Pg=34.86, Qg=4.81 -> Pg=61.62, Qg=10.0
% INFO    : Gen at bus 5292	: Vg=1.050901 -> Vg=1.0
% INFO    : Gen at bus 5301	: Pg=50.71, Qg=5.07 -> Pg=116.905, Qg=15.0
% INFO    : Gen at bus 5301	: Vg=1.021316 -> Vg=1.0
% INFO    : Gen at bus 5302	: Pg=52.8, Qg=0.59 -> Pg=117.6, Qg=15.0
% INFO    : Gen at bus 5302	: Vg=1.017834 -> Vg=1.0
% INFO    : Gen at bus 5303	: Pg=43.28, Qg=11.6 -> Pg=64.425, Qg=15.0
% INFO    : Gen at bus 5303	: Vg=1.024054 -> Vg=1.0
% INFO    : Gen at bus 5304	: Pg=43.28, Qg=11.6 -> Pg=64.425, Qg=15.0
% INFO    : Gen at bus 5304	: Vg=1.024054 -> Vg=1.0
% INFO    : Gen at bus 5305	: Pg=39.88, Qg=8.02 -> Pg=63.295, Qg=15.0
% INFO    : Gen at bus 5305	: Vg=1.03032 -> Vg=1.0
% INFO    : Gen at bus 5306	: Pg=39.88, Qg=8.02 -> Pg=63.295, Qg=15.0
% INFO    : Gen at bus 5306	: Vg=1.03032 -> Vg=1.0
% INFO    : Gen at bus 5307	: Pg=39.88, Qg=7.99 -> Pg=63.295, Qg=15.0
% INFO    : Gen at bus 5307	: Vg=1.030262 -> Vg=1.0
% INFO    : Gen at bus 5308	: Pg=39.88, Qg=7.99 -> Pg=63.295, Qg=15.0
% INFO    : Gen at bus 5308	: Vg=1.030262 -> Vg=1.0
% INFO    : Gen at bus 5309	: Pg=58.06, Qg=14.52 -> Pg=119.355, Qg=15.0
% INFO    : Gen at bus 5309	: Vg=1.033768 -> Vg=1.0
% INFO    : Gen at bus 5310	: Pg=58.06, Qg=14.52 -> Pg=119.355, Qg=15.0
% INFO    : Gen at bus 5310	: Vg=1.033768 -> Vg=1.0
% INFO    : Gen at bus 5311	: Pg=233.91, Qg=82.52 -> Pg=300.0, Qg=80.0
% INFO    : Gen at bus 5311	: Vg=1.057062 -> Vg=1.0
% INFO    : Gen at bus 5314	: Pg=93.45, Qg=15.84 -> Pg=131.15, Qg=15.0
% INFO    : Gen at bus 5314	: Vg=0.984098 -> Vg=1.0
% INFO    : Gen at bus 5316	: Pg=3.19, Qg=-0.17 -> Pg=51.06, Qg=0.0
% INFO    : Gen at bus 5316	: Vg=1.002922 -> Vg=1.0
% INFO    : Gen at bus 5317	: Pg=77.25, Qg=12.22 -> Pg=125.75, Qg=20.0
% INFO    : Gen at bus 5317	: Vg=1.034048 -> Vg=1.0
% INFO    : Gen at bus 5319	: Pg=377.38, Qg=119.4 -> Pg=500.0, Qg=80.0
% INFO    : Gen at bus 5319	: Vg=1.071081 -> Vg=1.0
% INFO    : Gen at bus 5322	: Pg=24.81, Qg=-3.88 -> Pg=58.27, Qg=10.0
% INFO    : Gen at bus 5322	: Vg=0.99879 -> Vg=1.0
% INFO    : Gen at bus 5323	: Pg=87.75, Qg=8.05 -> Pg=129.25, Qg=20.0
% INFO    : Gen at bus 5323	: Vg=1.011203 -> Vg=1.0
% INFO    : Gen at bus 5324	: Pg=87.75, Qg=8.05 -> Pg=129.25, Qg=20.0
% INFO    : Gen at bus 5324	: Vg=1.011203 -> Vg=1.0
% INFO    : Gen at bus 5325	: Pg=87.75, Qg=8.05 -> Pg=129.25, Qg=20.0
% INFO    : Gen at bus 5325	: Vg=1.011203 -> Vg=1.0
% INFO    : Gen at bus 5326	: Pg=87.75, Qg=8.05 -> Pg=129.25, Qg=20.0
% INFO    : Gen at bus 5326	: Vg=1.011203 -> Vg=1.0
% INFO    : Gen at bus 5327	: Pg=87.75, Qg=8.05 -> Pg=129.25, Qg=20.0
% INFO    : Gen at bus 5327	: Vg=1.011203 -> Vg=1.0
% INFO    : Gen at bus 5328	: Pg=87.75, Qg=8.05 -> Pg=129.25, Qg=20.0
% INFO    : Gen at bus 5328	: Vg=1.011203 -> Vg=1.0
% INFO    : Gen at bus 5330	: Pg=27.96, Qg=5.11 -> Pg=59.32, Qg=10.0
% INFO    : Gen at bus 5330	: Vg=1.029009 -> Vg=1.0
% INFO    : Gen at bus 5332	: Pg=32.36, Qg=7.22 -> Pg=60.785, Qg=10.0
% INFO    : Gen at bus 5332	: Vg=1.028002 -> Vg=1.0
% INFO    : Gen at bus 5333	: Pg=1.12, Qg=0.09 -> Pg=50.375, Qg=0.0
% INFO    : Gen at bus 5333	: Vg=1.03063 -> Vg=1.0
% INFO    : Gen at bus 5335	: Pg=87.35, Qg=17.85 -> Pg=129.115, Qg=20.0
% INFO    : Gen at bus 5335	: Vg=1.033768 -> Vg=1.0
% INFO    : Gen at bus 5341	: Pg=89.91, Qg=48.94 -> Pg=129.97, Qg=20.0
% INFO    : Gen at bus 5341	: Vg=1.065506 -> Vg=1.0
% INFO    : Gen at bus 5342	: Pg=57.59, Qg=10.86 -> Pg=119.195, Qg=15.0
% INFO    : Gen at bus 5342	: Vg=1.019736 -> Vg=1.0
% INFO    : Gen at bus 5343	: Pg=158.9, Qg=55.92 -> Pg=250.0, Qg=35.0
% INFO    : Gen at bus 5343	: Vg=1.000957 -> Vg=1.0
% INFO    : Gen at bus 5347	: Pg=90.48, Qg=33.58 -> Pg=130.16, Qg=20.0
% INFO    : Gen at bus 5347	: Vg=1.043665 -> Vg=1.0
% INFO    : Gen at bus 5350	: Pg=19.27, Qg=11.16 -> Pg=56.425, Qg=10.0
% INFO    : Gen at bus 5350	: Vg=1.021475 -> Vg=1.0
% INFO    : Gen at bus 5352	: Pg=30.32, Qg=6.61 -> Pg=60.105, Qg=10.0
% INFO    : Gen at bus 5352	: Vg=1.007679 -> Vg=1.0
% INFO    : Gen at bus 5354	: Pg=224.68, Qg=-13.42 -> Pg=300.0, Qg=80.0
% INFO    : Gen at bus 5354	: Vg=1.039621 -> Vg=1.0
% INFO    : Gen at bus 5356	: Pg=89.73, Qg=17.85 -> Pg=129.91, Qg=20.0
% INFO    : Gen at bus 5356	: Vg=1.041223 -> Vg=1.0
% INFO    : Gen at bus 5359	: Pg=14.52, Qg=2.12 -> Pg=54.84, Qg=0.0
% INFO    : Gen at bus 5359	: Vg=1.054892 -> Vg=1.0
% INFO    : Gen at bus 5365	: Pg=38.53, Qg=9.19 -> Pg=62.845, Qg=10.0
% INFO    : Gen at bus 5365	: Vg=1.03611 -> Vg=1.0
% INFO    : Gen at bus 5366	: Pg=38.53, Qg=9.19 -> Pg=62.845, Qg=10.0
% INFO    : Gen at bus 5366	: Vg=1.03611 -> Vg=1.0
% INFO    : Gen at bus 5368	: Pg=83.89, Qg=24.93 -> Pg=127.965, Qg=20.0
% INFO    : Gen at bus 5368	: Vg=1.023161 -> Vg=1.0
% INFO    : Gen at bus 5369	: Pg=83.89, Qg=24.93 -> Pg=127.965, Qg=20.0
% INFO    : Gen at bus 5369	: Vg=1.023161 -> Vg=1.0
% INFO    : Gen at bus 5370	: Pg=83.89, Qg=24.93 -> Pg=127.965, Qg=20.0
% INFO    : Gen at bus 5370	: Vg=1.023161 -> Vg=1.0
% INFO    : Gen at bus 5371	: Pg=83.89, Qg=24.93 -> Pg=127.965, Qg=20.0
% INFO    : Gen at bus 5371	: Vg=1.023161 -> Vg=1.0
% INFO    : Gen at bus 5382	: Pg=57.59, Qg=10.86 -> Pg=119.195, Qg=15.0
% INFO    : Gen at bus 5382	: Vg=1.019736 -> Vg=1.0
% INFO    : Gen at bus 5384	: Pg=6.38, Qg=-0.43 -> Pg=52.125, Qg=0.0
% INFO    : Gen at bus 5384	: Vg=0.962211 -> Vg=1.0
% INFO    : Gen at bus 5385	: Pg=30.28, Qg=3.51 -> Pg=60.095, Qg=10.0
% INFO    : Gen at bus 5385	: Vg=1.018125 -> Vg=1.0
% INFO    : Gen at bus 5388	: Pg=39.03, Qg=10.16 -> Pg=63.01, Qg=10.0
% INFO    : Gen at bus 5388	: Vg=1.033359 -> Vg=1.0
% INFO    : Gen at bus 5391	: Pg=34.92, Qg=9.74 -> Pg=61.64, Qg=10.0
% INFO    : Gen at bus 5391	: Vg=1.043492 -> Vg=1.0
% INFO    : Gen at bus 5397	: Pg=29.4, Qg=8.8 -> Pg=59.8, Qg=5.0
% INFO    : Gen at bus 5397	: Vg=1.01809 -> Vg=1.0
% INFO    : Gen at bus 5401	: Pg=38.85, Qg=7.6 -> Pg=62.95, Qg=10.0
% INFO    : Gen at bus 5401	: Vg=1.028342 -> Vg=1.0
% INFO    : Gen at bus 5403	: Pg=-128.54, Qg=-23.93 -> Pg=-35.69, Qg=-5.0
% INFO    : Gen at bus 5403	: Vg=1.018098 -> Vg=1.0
% INFO    : Gen at bus 5406	: Pg=41.92, Qg=5.34 -> Pg=63.975, Qg=15.0
% INFO    : Gen at bus 5406	: Vg=1.007636 -> Vg=1.0
% INFO    : Gen at bus 5408	: Pg=6.52, Qg=0.05 -> Pg=52.175, Qg=0.0
% INFO    : Gen at bus 5408	: Vg=0.996117 -> Vg=1.0
% INFO    : Gen at bus 5411	: Pg=34.83, Qg=7.05 -> Pg=61.61, Qg=15.0
% INFO    : Gen at bus 5411	: Vg=0.991559 -> Vg=1.0
% INFO    : Gen at bus 5416	: Pg=33.15, Qg=0.93 -> Pg=61.05, Qg=10.0
% INFO    : Gen at bus 5416	: Vg=1.024669 -> Vg=1.0
% INFO    : Gen at bus 5418	: Pg=8.33, Qg=2.0 -> Pg=52.775, Qg=0.0
% INFO    : Gen at bus 5418	: Vg=0.978998 -> Vg=1.0
% INFO    : Gen at bus 5420	: Pg=34.31, Qg=1.99 -> Pg=61.435, Qg=10.0
% INFO    : Gen at bus 5420	: Vg=1.015531 -> Vg=1.0
% INFO    : Gen at bus 5439	: Pg=36.91, Qg=13.33 -> Pg=62.305, Qg=10.0
% INFO    : Gen at bus 5439	: Vg=1.037973 -> Vg=1.0
% INFO    : Gen at bus 5444	: Pg=97.68, Qg=6.22 -> Pg=132.56, Qg=20.0
% INFO    : Gen at bus 5444	: Vg=1.017679 -> Vg=1.0
% INFO    : Gen at bus 5455	: Pg=112.0, Qg=11.12 -> Pg=187.335, Qg=20.0
% INFO    : Gen at bus 5455	: Vg=1.018325 -> Vg=1.0
% INFO    : Gen at bus 5456	: Pg=64.65, Qg=13.16 -> Pg=121.55, Qg=20.0
% INFO    : Gen at bus 5456	: Vg=1.009683 -> Vg=1.0
% INFO    : Gen at bus 5463	: Pg=38.42, Qg=21.93 -> Pg=62.805, Qg=10.0
% INFO    : Gen at bus 5463	: Vg=1.054031 -> Vg=1.0
% INFO    : Gen at bus 5464	: Pg=84.0, Qg=2.79 -> Pg=128.0, Qg=5.0
% INFO    : Gen at bus 5464	: Vg=1.011467 -> Vg=1.0
% INFO    : Gen at bus 5466	: Pg=39.44, Qg=10.06 -> Pg=63.145, Qg=15.0
% INFO    : Gen at bus 5466	: Vg=1.021987 -> Vg=1.0
% INFO    : Gen at bus 5467	: Pg=39.44, Qg=10.06 -> Pg=63.145, Qg=15.0
% INFO    : Gen at bus 5467	: Vg=1.021987 -> Vg=1.0
% INFO    : Gen at bus 5468	: Pg=39.44, Qg=10.06 -> Pg=63.145, Qg=15.0
% INFO    : Gen at bus 5468	: Vg=1.021987 -> Vg=1.0
% INFO    : Gen at bus 5473	: Pg=77.25, Qg=12.22 -> Pg=125.75, Qg=20.0
% INFO    : Gen at bus 5473	: Vg=1.034048 -> Vg=1.0
% INFO    : Gen at bus 5476	: Pg=42.41, Qg=17.68 -> Pg=64.135, Qg=20.0
% INFO    : Gen at bus 5476	: Vg=1.058287 -> Vg=1.0
% INFO    : Gen at bus 5484	: Pg=40.0, Qg=4.52 -> Pg=63.335, Qg=0.0
% INFO    : Gen at bus 5484	: Vg=0.956073 -> Vg=1.0
% INFO    : Gen at bus 5490	: Pg=21.35, Qg=3.86 -> Pg=57.115, Qg=5.0
% INFO    : Gen at bus 5490	: Vg=1.028982 -> Vg=1.0
% INFO    : Gen at bus 5494	: Pg=25.6, Qg=-1.25 -> Pg=58.535, Qg=0.0
% INFO    : Gen at bus 5494	: Vg=0.991002 -> Vg=1.0
% INFO    : Gen at bus 5498	: Pg=32.94, Qg=16.6 -> Pg=60.98, Qg=10.0
% INFO    : Gen at bus 5498	: Vg=1.041198 -> Vg=1.0
% INFO    : Gen at bus 5503	: Pg=174.4, Qg=15.0 -> Pg=250.0, Qg=80.0
% INFO    : Gen at bus 5503	: Vg=1.032124 -> Vg=1.0
% INFO    : Gen at bus 5510	: Pg=89.26, Qg=20.01 -> Pg=129.755, Qg=20.0
% INFO    : Gen at bus 5510	: Vg=1.05632 -> Vg=1.0
% INFO    : Gen at bus 5512	: Pg=27.76, Qg=14.88 -> Pg=59.255, Qg=10.0
% INFO    : Gen at bus 5512	: Vg=1.014266 -> Vg=1.0
% INFO    : Gen at bus 5514	: Pg=89.26, Qg=20.01 -> Pg=129.755, Qg=20.0
% INFO    : Gen at bus 5514	: Vg=1.05632 -> Vg=1.0
% INFO    : Gen at bus 5517	: Pg=219.5, Qg=66.99 -> Pg=300.0, Qg=80.0
% INFO    : Gen at bus 5517	: Vg=1.03284 -> Vg=1.0
% INFO    : Gen at bus 5523	: Pg=89.93, Qg=16.64 -> Pg=129.975, Qg=20.0
% INFO    : Gen at bus 5523	: Vg=1.037993 -> Vg=1.0
% INFO    : Gen at bus 5528	: Pg=38.95, Qg=5.12 -> Pg=62.985, Qg=10.0
% INFO    : Gen at bus 5528	: Vg=1.009486 -> Vg=1.0
% INFO    : Gen at bus 5530	: Pg=89.93, Qg=16.64 -> Pg=129.975, Qg=20.0
% INFO    : Gen at bus 5530	: Vg=1.037993 -> Vg=1.0
% INFO    : Gen at bus 5534	: Pg=228.19, Qg=49.03 -> Pg=300.0, Qg=80.0
% INFO    : Gen at bus 5534	: Vg=1.020332 -> Vg=1.0
% INFO    : Gen at bus 5540	: Pg=31.59, Qg=4.82 -> Pg=60.53, Qg=10.0
% INFO    : Gen at bus 5540	: Vg=1.045359 -> Vg=1.0
% INFO    : Gen at bus 5542	: Pg=40.0, Qg=-1.34 -> Pg=63.335, Qg=0.0
% INFO    : Gen at bus 5542	: Vg=1.010203 -> Vg=1.0
% INFO    : Gen at bus 5546	: Pg=92.69, Qg=14.48 -> Pg=130.895, Qg=20.0
% INFO    : Gen at bus 5546	: Vg=1.026207 -> Vg=1.0
% INFO    : Gen at bus 5548	: Pg=16.71, Qg=0.01 -> Pg=55.57, Qg=10.0
% INFO    : Gen at bus 5548	: Vg=1.030988 -> Vg=1.0
% INFO    : Gen at bus 5575	: Pg=26.19, Qg=8.11 -> Pg=58.73, Qg=10.0
% INFO    : Gen at bus 5575	: Vg=1.031736 -> Vg=1.0
% INFO    : Gen at bus 5576	: Pg=168.75, Qg=16.36 -> Pg=250.0, Qg=5.0
% INFO    : Gen at bus 5576	: Vg=0.976475 -> Vg=1.0
% INFO    : Gen at bus 5581	: Pg=381.8, Qg=21.67 -> Pg=500.0, Qg=80.0
% INFO    : Gen at bus 5581	: Vg=1.063714 -> Vg=1.0
% INFO    : Gen at bus 5587	: Pg=417.43, Qg=19.88 -> Pg=550.0, Qg=100.0
% INFO    : Gen at bus 5587	: Vg=1.041875 -> Vg=1.0
% INFO    : Gen at bus 5592	: Pg=64.28, Qg=29.97 -> Pg=121.425, Qg=20.0
% INFO    : Gen at bus 5592	: Vg=1.00876 -> Vg=1.0
% INFO    : Gen at bus 5593	: Pg=22.87, Qg=9.78 -> Pg=57.625, Qg=10.0
% INFO    : Gen at bus 5593	: Vg=1.014635 -> Vg=1.0
% INFO    : Gen at bus 5594	: Pg=32.36, Qg=7.22 -> Pg=60.785, Qg=10.0
% INFO    : Gen at bus 5594	: Vg=1.028002 -> Vg=1.0
% INFO    : Gen at bus 5607	: Pg=34.32, Qg=1.14 -> Pg=61.44, Qg=5.0
% INFO    : Gen at bus 5607	: Vg=1.025746 -> Vg=1.0
% INFO    : Gen at bus 5608	: Pg=22.77, Qg=10.64 -> Pg=57.59, Qg=10.0
% INFO    : Gen at bus 5608	: Vg=1.045989 -> Vg=1.0
% INFO    : Gen at bus 5610	: Pg=34.32, Qg=1.14 -> Pg=61.44, Qg=5.0
% INFO    : Gen at bus 5610	: Vg=1.025746 -> Vg=1.0
% INFO    : Gen at bus 5611	: Pg=25.33, Qg=9.63 -> Pg=58.445, Qg=10.0
% INFO    : Gen at bus 5611	: Vg=1.047982 -> Vg=1.0
% INFO    : Gen at bus 5612	: Pg=25.33, Qg=9.63 -> Pg=58.445, Qg=10.0
% INFO    : Gen at bus 5612	: Vg=1.047982 -> Vg=1.0
% INFO    : Gen at bus 5613	: Pg=22.77, Qg=10.64 -> Pg=57.59, Qg=10.0
% INFO    : Gen at bus 5613	: Vg=1.045989 -> Vg=1.0
% INFO    : Gen at bus 5614	: Pg=31.68, Qg=9.78 -> Pg=60.56, Qg=10.0
% INFO    : Gen at bus 5614	: Vg=1.047806 -> Vg=1.0
% INFO    : Gen at bus 5619	: Pg=21.53, Qg=3.36 -> Pg=57.175, Qg=10.0
% INFO    : Gen at bus 5619	: Vg=1.049918 -> Vg=1.0
% INFO    : Gen at bus 5622	: Pg=34.27, Qg=11.44 -> Pg=61.425, Qg=10.0
% INFO    : Gen at bus 5622	: Vg=1.03975 -> Vg=1.0
% INFO    : Gen at bus 5627	: Pg=219.98, Qg=31.44 -> Pg=300.0, Qg=80.0
% INFO    : Gen at bus 5627	: Vg=1.026746 -> Vg=1.0
% INFO    : Gen at bus 5628	: Pg=23.9, Qg=13.28 -> Pg=57.965, Qg=10.0
% INFO    : Gen at bus 5628	: Vg=1.020137 -> Vg=1.0
% INFO    : Gen at bus 5629	: Pg=23.9, Qg=13.28 -> Pg=57.965, Qg=10.0
% INFO    : Gen at bus 5629	: Vg=1.020137 -> Vg=1.0
% INFO    : Gen at bus 5630	: Pg=10.76, Qg=-0.13 -> Pg=53.585, Qg=0.0
% INFO    : Gen at bus 5630	: Vg=0.976217 -> Vg=1.0
% INFO    : Gen at bus 5631	: Pg=30.93, Qg=5.5 -> Pg=60.31, Qg=10.0
% INFO    : Gen at bus 5631	: Vg=1.009821 -> Vg=1.0
% INFO    : Gen at bus 5632	: Pg=16.28, Qg=6.64 -> Pg=55.425, Qg=10.0
% INFO    : Gen at bus 5632	: Vg=1.015993 -> Vg=1.0
% INFO    : Gen at bus 5634	: Pg=30.93, Qg=5.5 -> Pg=60.31, Qg=10.0
% INFO    : Gen at bus 5634	: Vg=1.009821 -> Vg=1.0
% INFO    : Gen at bus 5637	: Pg=214.01, Qg=124.9 -> Pg=300.0, Qg=60.0
% INFO    : Gen at bus 5637	: Vg=1.043748 -> Vg=1.0
% INFO    : Gen at bus 5640	: Pg=227.2, Qg=71.82 -> Pg=300.0, Qg=80.0
% INFO    : Gen at bus 5640	: Vg=1.06339 -> Vg=1.0
% INFO    : Gen at bus 5641	: Pg=38.02, Qg=11.21 -> Pg=62.675, Qg=10.0
% INFO    : Gen at bus 5641	: Vg=1.043087 -> Vg=1.0
% INFO    : Gen at bus 5645	: Pg=53.13, Qg=-3.75 -> Pg=117.71, Qg=0.0
% INFO    : Gen at bus 5645	: Vg=1.003179 -> Vg=1.0
% INFO    : Gen at bus 5653	: Pg=24.86, Qg=7.42 -> Pg=58.285, Qg=10.0
% INFO    : Gen at bus 5653	: Vg=1.01212 -> Vg=1.0
% INFO    : Gen at bus 5654	: Pg=227.2, Qg=72.57 -> Pg=300.0, Qg=80.0
% INFO    : Gen at bus 5654	: Vg=1.063453 -> Vg=1.0
% INFO    : Gen at bus 5657	: Pg=279.13, Qg=130.91 -> Pg=350.0, Qg=80.0
% INFO    : Gen at bus 5657	: Vg=1.048637 -> Vg=1.0
% INFO    : Gen at bus 5658	: Pg=0.99, Qg=-0.05 -> Pg=50.33, Qg=0.0
% INFO    : Gen at bus 5658	: Vg=1.015919 -> Vg=1.0
% INFO    : Gen at bus 5660	: Pg=29.35, Qg=12.59 -> Pg=59.785, Qg=10.0
% INFO    : Gen at bus 5660	: Vg=1.05544 -> Vg=1.0
% INFO    : Gen at bus 5668	: Pg=32.52, Qg=9.41 -> Pg=60.84, Qg=10.0
% INFO    : Gen at bus 5668	: Vg=1.028707 -> Vg=1.0
% INFO    : Gen at bus 5670	: Pg=32.52, Qg=9.41 -> Pg=60.84, Qg=10.0
% INFO    : Gen at bus 5670	: Vg=1.028707 -> Vg=1.0
% INFO    : Gen at bus 5672	: Pg=36.8, Qg=6.62 -> Pg=62.265, Qg=10.0
% INFO    : Gen at bus 5672	: Vg=1.03058 -> Vg=1.0
% INFO    : Gen at bus 5674	: Pg=382.77, Qg=9.72 -> Pg=500.0, Qg=80.0
% INFO    : Gen at bus 5674	: Vg=1.043874 -> Vg=1.0
% INFO    : Gen at bus 5676	: Pg=50.82, Qg=16.11 -> Pg=116.94, Qg=15.0
% INFO    : Gen at bus 5676	: Vg=1.025082 -> Vg=1.0
% INFO    : Gen at bus 5679	: Pg=4.8, Qg=-0.12 -> Pg=51.6, Qg=0.0
% INFO    : Gen at bus 5679	: Vg=0.996318 -> Vg=1.0
% INFO    : Gen at bus 5681	: Pg=62.5, Qg=10.73 -> Pg=120.835, Qg=10.0
% INFO    : Gen at bus 5681	: Vg=1.000057 -> Vg=1.0
% INFO    : Gen at bus 5695	: Pg=62.61, Qg=24.83 -> Pg=120.87, Qg=20.0
% INFO    : Gen at bus 5695	: Vg=1.034646 -> Vg=1.0
% INFO    : Gen at bus 5697	: Pg=8.06, Qg=0.42 -> Pg=52.685, Qg=0.0
% INFO    : Gen at bus 5697	: Vg=1.002466 -> Vg=1.0
% INFO    : Gen at bus 5702	: Pg=6.32, Qg=-0.32 -> Pg=52.105, Qg=0.0
% INFO    : Gen at bus 5702	: Vg=1.027418 -> Vg=1.0
% INFO    : Gen at bus 5704	: Pg=359.93, Qg=62.09 -> Pg=500.0, Qg=80.0
% INFO    : Gen at bus 5704	: Vg=1.053462 -> Vg=1.0
% INFO    : Gen at bus 5705	: Pg=359.94, Qg=62.42 -> Pg=500.0, Qg=80.0
% INFO    : Gen at bus 5705	: Vg=1.053459 -> Vg=1.0
% INFO    : Gen at bus 5706	: Pg=246.54, Qg=77.85 -> Pg=300.0, Qg=80.0
% INFO    : Gen at bus 5706	: Vg=1.056281 -> Vg=1.0
% INFO    : Gen at bus 5707	: Pg=246.54, Qg=77.85 -> Pg=300.0, Qg=80.0
% INFO    : Gen at bus 5707	: Vg=1.056281 -> Vg=1.0
% INFO    : Gen at bus 5708	: Pg=227.21, Qg=72.6 -> Pg=300.0, Qg=80.0
% INFO    : Gen at bus 5708	: Vg=1.063449 -> Vg=1.0
% INFO    : Gen at bus 5714	: Pg=362.55, Qg=145.9 -> Pg=500.0, Qg=80.0
% INFO    : Gen at bus 5714	: Vg=1.041293 -> Vg=1.0
% INFO    : Gen at bus 5715	: Pg=38.18, Qg=10.06 -> Pg=62.725, Qg=10.0
% INFO    : Gen at bus 5715	: Vg=1.019539 -> Vg=1.0
% INFO    : Gen at bus 5716	: Pg=27.62, Qg=3.89 -> Pg=59.205, Qg=5.0
% INFO    : Gen at bus 5716	: Vg=1.006233 -> Vg=1.0
% INFO    : Gen at bus 5718	: Pg=214.01, Qg=124.9 -> Pg=300.0, Qg=60.0
% INFO    : Gen at bus 5718	: Vg=1.043748 -> Vg=1.0
% INFO    : Gen at bus 5723	: Pg=36.77, Qg=13.93 -> Pg=62.255, Qg=10.0
% INFO    : Gen at bus 5723	: Vg=1.042317 -> Vg=1.0
% INFO    : Gen at bus 5728	: Pg=97.89, Qg=27.09 -> Pg=132.63, Qg=20.0
% INFO    : Gen at bus 5728	: Vg=1.044132 -> Vg=1.0
% INFO    : Gen at bus 5729	: Pg=97.89, Qg=27.09 -> Pg=132.63, Qg=20.0
% INFO    : Gen at bus 5729	: Vg=1.044132 -> Vg=1.0
% INFO    : Gen at bus 5730	: Pg=97.89, Qg=27.09 -> Pg=132.63, Qg=20.0
% INFO    : Gen at bus 5730	: Vg=1.044132 -> Vg=1.0
% INFO    : Gen at bus 5731	: Pg=97.89, Qg=27.09 -> Pg=132.63, Qg=20.0
% INFO    : Gen at bus 5731	: Vg=1.044132 -> Vg=1.0
% INFO    : Gen at bus 5732	: Pg=87.9, Qg=19.61 -> Pg=129.3, Qg=20.0
% INFO    : Gen at bus 5732	: Vg=1.034671 -> Vg=1.0
% INFO    : Gen at bus 5739	: Pg=35.02, Qg=1.75 -> Pg=61.675, Qg=10.0
% INFO    : Gen at bus 5739	: Vg=1.038438 -> Vg=1.0
% INFO    : Gen at bus 5741	: Pg=36.03, Qg=16.08 -> Pg=62.01, Qg=10.0
% INFO    : Gen at bus 5741	: Vg=1.045359 -> Vg=1.0
% INFO    : Gen at bus 5742	: Pg=209.95, Qg=44.18 -> Pg=300.0, Qg=55.0
% INFO    : Gen at bus 5742	: Vg=0.973258 -> Vg=1.0
% INFO    : Gen at bus 5746	: Pg=32.37, Qg=5.79 -> Pg=60.79, Qg=5.0
% INFO    : Gen at bus 5746	: Vg=1.037284 -> Vg=1.0
% INFO    : Gen at bus 5750	: Pg=52.06, Qg=9.48 -> Pg=117.355, Qg=15.0
% INFO    : Gen at bus 5750	: Vg=1.028771 -> Vg=1.0
% INFO    : Gen at bus 5751	: Pg=47.57, Qg=7.97 -> Pg=65.855, Qg=15.0
% INFO    : Gen at bus 5751	: Vg=1.022435 -> Vg=1.0
% INFO    : Gen at bus 5761	: Pg=34.96, Qg=12.97 -> Pg=61.655, Qg=10.0
% INFO    : Gen at bus 5761	: Vg=1.054937 -> Vg=1.0
% INFO    : Gen at bus 5764	: Pg=34.86, Qg=4.81 -> Pg=61.62, Qg=10.0
% INFO    : Gen at bus 5764	: Vg=1.050901 -> Vg=1.0
% INFO    : Gen at bus 5765	: Pg=37.29, Qg=8.19 -> Pg=62.43, Qg=10.0
% INFO    : Gen at bus 5765	: Vg=1.030566 -> Vg=1.0
% INFO    : Gen at bus 5769	: Pg=53.07, Qg=7.74 -> Pg=117.69, Qg=15.0
% INFO    : Gen at bus 5769	: Vg=1.025333 -> Vg=1.0
% INFO    : Gen at bus 5770	: Pg=40.44, Qg=13.81 -> Pg=63.48, Qg=15.0
% INFO    : Gen at bus 5770	: Vg=1.025019 -> Vg=1.0
% INFO    : Gen at bus 5771	: Pg=40.44, Qg=13.81 -> Pg=63.48, Qg=15.0
% INFO    : Gen at bus 5771	: Vg=1.025019 -> Vg=1.0
% INFO    : Gen at bus 5772	: Pg=53.07, Qg=7.74 -> Pg=117.69, Qg=15.0
% INFO    : Gen at bus 5772	: Vg=1.025333 -> Vg=1.0
% INFO    : Gen at bus 5776	: Pg=351.74, Qg=73.14 -> Pg=500.0, Qg=80.0
% INFO    : Gen at bus 5776	: Vg=1.039438 -> Vg=1.0
% INFO    : Gen at bus 5777	: Pg=351.74, Qg=73.14 -> Pg=500.0, Qg=80.0
% INFO    : Gen at bus 5777	: Vg=1.039438 -> Vg=1.0
% INFO    : Gen at bus 5781	: Pg=351.74, Qg=73.14 -> Pg=500.0, Qg=80.0
% INFO    : Gen at bus 5781	: Vg=1.039438 -> Vg=1.0
% INFO    : Gen at bus 5782	: Pg=351.74, Qg=73.14 -> Pg=500.0, Qg=80.0
% INFO    : Gen at bus 5782	: Vg=1.039438 -> Vg=1.0
% INFO    : Gen at bus 5797	: Pg=235.87, Qg=0.58 -> Pg=300.0, Qg=80.0
% INFO    : Gen at bus 5797	: Vg=1.042461 -> Vg=1.0
% INFO    : Gen at bus 5804	: Pg=35.74, Qg=6.84 -> Pg=61.915, Qg=10.0
% INFO    : Gen at bus 5804	: Vg=1.040138 -> Vg=1.0
% INFO    : Gen at bus 5805	: Pg=31.29, Qg=6.48 -> Pg=60.43, Qg=10.0
% INFO    : Gen at bus 5805	: Vg=1.024788 -> Vg=1.0
% INFO    : Gen at bus 5816	: Pg=313.39, Qg=68.14 -> Pg=450.0, Qg=80.0
% INFO    : Gen at bus 5816	: Vg=1.035914 -> Vg=1.0
% INFO    : Gen at bus 5825	: Pg=19.27, Qg=11.16 -> Pg=56.425, Qg=10.0
% INFO    : Gen at bus 5825	: Vg=1.021452 -> Vg=1.0
% INFO    : Gen at bus 5826	: Pg=15.75, Qg=3.03 -> Pg=55.25, Qg=5.0
% INFO    : Gen at bus 5826	: Vg=1.013783 -> Vg=1.0
% INFO    : Gen at bus 5830	: Pg=62.37, Qg=25.07 -> Pg=120.79, Qg=20.0
% INFO    : Gen at bus 5830	: Vg=1.030828 -> Vg=1.0
% INFO    : Gen at bus 5831	: Pg=17.21, Qg=5.28 -> Pg=55.735, Qg=10.0
% INFO    : Gen at bus 5831	: Vg=1.020161 -> Vg=1.0
% INFO    : Gen at bus 5832	: Pg=17.21, Qg=5.28 -> Pg=55.735, Qg=10.0
% INFO    : Gen at bus 5832	: Vg=1.020161 -> Vg=1.0
% INFO    : Gen at bus 5838	: Pg=518.28, Qg=-15.34 -> Pg=700.0, Qg=200.0
% INFO    : Gen at bus 5838	: Vg=1.032652 -> Vg=1.0
% INFO    : Gen at bus 5842	: Pg=29.89, Qg=15.39 -> Pg=59.965, Qg=10.0
% INFO    : Gen at bus 5842	: Vg=1.024479 -> Vg=1.0
% INFO    : Gen at bus 5847	: Pg=36.88, Qg=19.22 -> Pg=62.295, Qg=10.0
% INFO    : Gen at bus 5847	: Vg=1.037296 -> Vg=1.0
% INFO    : Gen at bus 5849	: Pg=37.8, Qg=19.78 -> Pg=62.6, Qg=10.0
% INFO    : Gen at bus 5849	: Vg=1.031737 -> Vg=1.0
% INFO    : Gen at bus 5850	: Pg=99.68, Qg=14.71 -> Pg=133.225, Qg=20.0
% INFO    : Gen at bus 5850	: Vg=1.035207 -> Vg=1.0
% INFO    : Gen at bus 5856	: Pg=159.8, Qg=43.16 -> Pg=250.0, Qg=60.0
% INFO    : Gen at bus 5856	: Vg=1.056042 -> Vg=1.0
% INFO    : Gen at bus 5858	: Pg=159.8, Qg=43.16 -> Pg=250.0, Qg=60.0
% INFO    : Gen at bus 5858	: Vg=1.056042 -> Vg=1.0
% INFO    : Gen at bus 5864	: Pg=45.28, Qg=10.84 -> Pg=65.095, Qg=15.0
% INFO    : Gen at bus 5864	: Vg=1.043738 -> Vg=1.0
% INFO    : Gen at bus 5868	: Pg=90.17, Qg=24.56 -> Pg=130.055, Qg=20.0
% INFO    : Gen at bus 5868	: Vg=1.06019 -> Vg=1.0
% INFO    : Gen at bus 5880	: Pg=81.07, Qg=20.71 -> Pg=127.025, Qg=20.0
% INFO    : Gen at bus 5880	: Vg=1.021915 -> Vg=1.0
% INFO    : Gen at bus 5881	: Pg=269.27, Qg=88.74 -> Pg=350.0, Qg=60.0
% INFO    : Gen at bus 5881	: Vg=1.035485 -> Vg=1.0
% INFO    : Gen at bus 5882	: Pg=269.15, Qg=67.63 -> Pg=350.0, Qg=60.0
% INFO    : Gen at bus 5882	: Vg=1.052667 -> Vg=1.0
% INFO    : Gen at bus 5883	: Pg=269.15, Qg=67.63 -> Pg=350.0, Qg=60.0
% INFO    : Gen at bus 5883	: Vg=1.052667 -> Vg=1.0
% INFO    : Gen at bus 5884	: Pg=269.15, Qg=67.63 -> Pg=350.0, Qg=60.0
% INFO    : Gen at bus 5884	: Vg=1.052667 -> Vg=1.0
% INFO    : Gen at bus 5885	: Pg=81.07, Qg=20.71 -> Pg=127.025, Qg=20.0
% INFO    : Gen at bus 5885	: Vg=1.021915 -> Vg=1.0
% INFO    : Gen at bus 5886	: Pg=81.07, Qg=20.71 -> Pg=127.025, Qg=20.0
% INFO    : Gen at bus 5886	: Vg=1.021915 -> Vg=1.0
% INFO    : Gen at bus 5887	: Pg=256.21, Qg=65.38 -> Pg=350.0, Qg=60.0
% INFO    : Gen at bus 5887	: Vg=1.052481 -> Vg=1.0
% INFO    : Gen at bus 5889	: Pg=256.21, Qg=65.38 -> Pg=350.0, Qg=60.0
% INFO    : Gen at bus 5889	: Vg=1.052481 -> Vg=1.0
% INFO    : Gen at bus 5896	: Pg=56.36, Qg=7.67 -> Pg=118.785, Qg=15.0
% INFO    : Gen at bus 5896	: Vg=1.024375 -> Vg=1.0
% INFO    : Gen at bus 5897	: Pg=87.39, Qg=49.11 -> Pg=129.13, Qg=20.0
% INFO    : Gen at bus 5897	: Vg=1.054462 -> Vg=1.0
% INFO    : Gen at bus 5898	: Pg=87.39, Qg=49.11 -> Pg=129.13, Qg=20.0
% INFO    : Gen at bus 5898	: Vg=1.054462 -> Vg=1.0
% INFO    : Gen at bus 5900	: Pg=87.39, Qg=49.12 -> Pg=129.13, Qg=20.0
% INFO    : Gen at bus 5900	: Vg=1.05445 -> Vg=1.0
% INFO    : Gen at bus 5901	: Pg=87.39, Qg=49.12 -> Pg=129.13, Qg=20.0
% INFO    : Gen at bus 5901	: Vg=1.05445 -> Vg=1.0
% INFO    : Gen at bus 5902	: Pg=87.39, Qg=49.11 -> Pg=129.13, Qg=20.0
% INFO    : Gen at bus 5902	: Vg=1.054462 -> Vg=1.0
% INFO    : Gen at bus 5905	: Pg=130.5, Qg=-4.01 -> Pg=193.5, Qg=0.0
% INFO    : Gen at bus 5905	: Vg=0.994923 -> Vg=1.0
% INFO    : Gen at bus 5911	: Pg=25.74, Qg=8.25 -> Pg=58.58, Qg=10.0
% INFO    : Gen at bus 5911	: Vg=1.037214 -> Vg=1.0
% INFO    : Gen at bus 5924	: Pg=31.28, Qg=-0.92 -> Pg=60.425, Qg=10.0
% INFO    : Gen at bus 5924	: Vg=1.009892 -> Vg=1.0
% INFO    : Gen at bus 5928	: Pg=32.64, Qg=6.67 -> Pg=60.88, Qg=10.0
% INFO    : Gen at bus 5928	: Vg=1.044924 -> Vg=1.0
% INFO    : Gen at bus 5929	: Pg=35.06, Qg=4.02 -> Pg=61.685, Qg=10.0
% INFO    : Gen at bus 5929	: Vg=1.032126 -> Vg=1.0
% INFO    : Gen at bus 5930	: Pg=35.06, Qg=4.02 -> Pg=61.685, Qg=10.0
% INFO    : Gen at bus 5930	: Vg=1.032126 -> Vg=1.0
% INFO    : Gen at bus 5931	: Pg=33.37, Qg=14.47 -> Pg=61.125, Qg=10.0
% INFO    : Gen at bus 5931	: Vg=1.0234 -> Vg=1.0
% INFO    : Gen at bus 5932	: Pg=35.06, Qg=4.02 -> Pg=61.685, Qg=10.0
% INFO    : Gen at bus 5932	: Vg=1.032126 -> Vg=1.0
% INFO    : Gen at bus 5933	: Pg=35.06, Qg=4.02 -> Pg=61.685, Qg=10.0
% INFO    : Gen at bus 5933	: Vg=1.032126 -> Vg=1.0
% INFO    : Gen at bus 5934	: Pg=35.06, Qg=4.02 -> Pg=61.685, Qg=10.0
% INFO    : Gen at bus 5934	: Vg=1.032126 -> Vg=1.0
% INFO    : Gen at bus 5935	: Pg=25.6, Qg=3.9 -> Pg=58.535, Qg=10.0
% INFO    : Gen at bus 5935	: Vg=1.03284 -> Vg=1.0
% INFO    : Gen at bus 5936	: Pg=25.6, Qg=3.9 -> Pg=58.535, Qg=10.0
% INFO    : Gen at bus 5936	: Vg=1.03284 -> Vg=1.0
% INFO    : Gen at bus 5961	: Pg=33.21, Qg=5.47 -> Pg=61.07, Qg=10.0
% INFO    : Gen at bus 5961	: Vg=1.022689 -> Vg=1.0
% INFO    : Gen at bus 5963	: Pg=26.62, Qg=13.25 -> Pg=58.875, Qg=10.0
% INFO    : Gen at bus 5963	: Vg=1.040642 -> Vg=1.0
% INFO    : Gen at bus 5964	: Pg=135.0, Qg=10.29 -> Pg=195.0, Qg=25.0
% INFO    : Gen at bus 5964	: Vg=1.008348 -> Vg=1.0
% INFO    : Gen at bus 5965	: Pg=175.1, Qg=24.83 -> Pg=250.0, Qg=15.0
% INFO    : Gen at bus 5965	: Vg=0.985995 -> Vg=1.0
% INFO    : Gen at bus 5973	: Pg=17.82, Qg=3.95 -> Pg=55.94, Qg=10.0
% INFO    : Gen at bus 5973	: Vg=1.066829 -> Vg=1.0
% INFO    : Gen at bus 5977	: Pg=29.43, Qg=7.09 -> Pg=59.81, Qg=10.0
% INFO    : Gen at bus 5977	: Vg=1.028438 -> Vg=1.0
% INFO    : Gen at bus 5978	: Pg=79.8, Qg=19.8 -> Pg=126.6, Qg=20.0
% INFO    : Gen at bus 5978	: Vg=1.02806 -> Vg=1.0
% INFO    : Gen at bus 5979	: Pg=37.23, Qg=4.01 -> Pg=62.41, Qg=10.0
% INFO    : Gen at bus 5979	: Vg=1.028283 -> Vg=1.0
% INFO    : Gen at bus 5982	: Pg=5.2, Qg=0.53 -> Pg=51.735, Qg=0.0
% INFO    : Gen at bus 5982	: Vg=1.031159 -> Vg=1.0
% INFO    : Gen at bus 5984	: Pg=32.72, Qg=7.26 -> Pg=60.905, Qg=10.0
% INFO    : Gen at bus 5984	: Vg=1.016616 -> Vg=1.0
% INFO    : Gen at bus 5987	: Pg=612.07, Qg=246.66 -> Pg=850.0, Qg=200.0
% INFO    : Gen at bus 5987	: Vg=1.041616 -> Vg=1.0
% INFO    : Gen at bus 5988	: Pg=612.07, Qg=246.66 -> Pg=850.0, Qg=200.0
% INFO    : Gen at bus 5988	: Vg=1.041616 -> Vg=1.0
% INFO    : Gen at bus 5989	: Pg=612.02, Qg=218.37 -> Pg=850.0, Qg=200.0
% INFO    : Gen at bus 5989	: Vg=1.039304 -> Vg=1.0
% INFO    : Gen at bus 5990	: Pg=612.02, Qg=218.37 -> Pg=850.0, Qg=200.0
% INFO    : Gen at bus 5990	: Vg=1.039304 -> Vg=1.0
% INFO    : Gen at bus 5992	: Pg=35.95, Qg=6.39 -> Pg=61.985, Qg=15.0
% INFO    : Gen at bus 5992	: Vg=1.015185 -> Vg=1.0
% INFO    : Gen at bus 5999	: Pg=50.34, Qg=15.84 -> Pg=116.78, Qg=15.0
% INFO    : Gen at bus 5999	: Vg=1.03143 -> Vg=1.0
% INFO    : Gen at bus 6002	: Pg=63.6, Qg=31.38 -> Pg=121.2, Qg=20.0
% INFO    : Gen at bus 6002	: Vg=1.027152 -> Vg=1.0
% INFO    : Gen at bus 6003	: Pg=63.6, Qg=31.38 -> Pg=121.2, Qg=20.0
% INFO    : Gen at bus 6003	: Vg=1.027152 -> Vg=1.0
% INFO    : Gen at bus 6005	: Pg=63.6, Qg=31.38 -> Pg=121.2, Qg=20.0
% INFO    : Gen at bus 6005	: Vg=1.027152 -> Vg=1.0
% INFO    : Gen at bus 6006	: Pg=63.6, Qg=31.38 -> Pg=121.2, Qg=20.0
% INFO    : Gen at bus 6006	: Vg=1.027152 -> Vg=1.0
% INFO    : Gen at bus 6007	: Pg=63.6, Qg=31.38 -> Pg=121.2, Qg=20.0
% INFO    : Gen at bus 6007	: Vg=1.027152 -> Vg=1.0
% INFO    : Gen at bus 6008	: Pg=63.6, Qg=31.38 -> Pg=121.2, Qg=20.0
% INFO    : Gen at bus 6008	: Vg=1.027152 -> Vg=1.0
% INFO    : Gen at bus 6009	: Pg=4.5, Qg=0.47 -> Pg=51.5, Qg=0.0
% INFO    : Gen at bus 6009	: Vg=1.016602 -> Vg=1.0
% INFO    : Gen at bus 6014	: Pg=50.34, Qg=15.84 -> Pg=116.78, Qg=15.0
% INFO    : Gen at bus 6014	: Vg=1.03143 -> Vg=1.0
% INFO    : Gen at bus 6016	: Pg=33.19, Qg=5.48 -> Pg=61.065, Qg=10.0
% INFO    : Gen at bus 6016	: Vg=0.991806 -> Vg=1.0
% INFO    : Gen at bus 6017	: Pg=163.94, Qg=189.92 -> Pg=250.0, Qg=80.0
% INFO    : Gen at bus 6017	: Vg=1.050579 -> Vg=1.0
% INFO    : Gen at bus 6023	: Pg=383.05, Qg=40.91 -> Pg=500.0, Qg=80.0
% INFO    : Gen at bus 6023	: Vg=1.045612 -> Vg=1.0
% INFO    : Gen at bus 6025	: Pg=92.69, Qg=14.48 -> Pg=130.895, Qg=20.0
% INFO    : Gen at bus 6025	: Vg=1.026207 -> Vg=1.0
% INFO    : Gen at bus 6034	: Pg=31.28, Qg=-0.92 -> Pg=60.425, Qg=10.0
% INFO    : Gen at bus 6034	: Vg=1.009892 -> Vg=1.0
% INFO    : Gen at bus 6038	: Pg=210.0, Qg=16.99 -> Pg=300.0, Qg=35.0
% INFO    : Gen at bus 6038	: Vg=0.981513 -> Vg=1.0
% INFO    : Gen at bus 6039	: Pg=89.25, Qg=12.95 -> Pg=129.75, Qg=20.0
% INFO    : Gen at bus 6039	: Vg=1.054609 -> Vg=1.0
% INFO    : Gen at bus 6040	: Pg=89.25, Qg=12.95 -> Pg=129.75, Qg=20.0
% INFO    : Gen at bus 6040	: Vg=1.054609 -> Vg=1.0
% INFO    : Gen at bus 6048	: Pg=82.3, Qg=25.62 -> Pg=127.435, Qg=20.0
% INFO    : Gen at bus 6048	: Vg=1.055592 -> Vg=1.0
% INFO    : Gen at bus 6049	: Pg=38.79, Qg=7.11 -> Pg=62.93, Qg=10.0
% INFO    : Gen at bus 6049	: Vg=1.035838 -> Vg=1.0
% INFO    : Gen at bus 6055	: Pg=63.72, Qg=11.02 -> Pg=121.24, Qg=15.0
% INFO    : Gen at bus 6055	: Vg=1.030356 -> Vg=1.0
% INFO    : Gen at bus 6058	: Pg=424.18, Qg=1.6 -> Pg=550.0, Qg=100.0
% INFO    : Gen at bus 6058	: Vg=1.036943 -> Vg=1.0
% INFO    : Gen at bus 6066	: Pg=393.28, Qg=141.99 -> Pg=500.0, Qg=80.0
% INFO    : Gen at bus 6066	: Vg=1.019403 -> Vg=1.0
% INFO    : Gen at bus 6068	: Pg=36.91, Qg=13.33 -> Pg=62.305, Qg=10.0
% INFO    : Gen at bus 6068	: Vg=1.037973 -> Vg=1.0
% INFO    : Gen at bus 6072	: Pg=9.1, Qg=-0.32 -> Pg=53.035, Qg=0.0
% INFO    : Gen at bus 6072	: Vg=1.00419 -> Vg=1.0
% INFO    : Gen at bus 6076	: Pg=28.8, Qg=6.92 -> Pg=59.6, Qg=10.0
% INFO    : Gen at bus 6076	: Vg=1.000808 -> Vg=1.0
% INFO    : Gen at bus 6085	: Pg=550.03, Qg=481.13 -> Pg=750.0, Qg=200.0
% INFO    : Gen at bus 6085	: Vg=1.061212 -> Vg=1.0
% INFO    : Gen at bus 6087	: Pg=26.81, Qg=10.09 -> Pg=58.935, Qg=10.0
% INFO    : Gen at bus 6087	: Vg=1.044747 -> Vg=1.0
% INFO    : Gen at bus 6088	: Pg=32.72, Qg=7.26 -> Pg=60.905, Qg=10.0
% INFO    : Gen at bus 6088	: Vg=1.016616 -> Vg=1.0
% INFO    : Gen at bus 6089	: Pg=16.74, Qg=3.04 -> Pg=55.58, Qg=10.0
% INFO    : Gen at bus 6089	: Vg=1.042545 -> Vg=1.0
% INFO    : Gen at bus 6090	: Pg=30.08, Qg=5.21 -> Pg=60.025, Qg=10.0
% INFO    : Gen at bus 6090	: Vg=1.030904 -> Vg=1.0
% INFO    : Gen at bus 6091	: Pg=30.08, Qg=5.21 -> Pg=60.025, Qg=10.0
% INFO    : Gen at bus 6091	: Vg=1.030904 -> Vg=1.0
% INFO    : Gen at bus 6092	: Pg=38.69, Qg=6.26 -> Pg=62.895, Qg=10.0
% INFO    : Gen at bus 6092	: Vg=1.032747 -> Vg=1.0
% INFO    : Gen at bus 6093	: Pg=26.81, Qg=10.09 -> Pg=58.935, Qg=10.0
% INFO    : Gen at bus 6093	: Vg=1.044747 -> Vg=1.0
% INFO    : Gen at bus 6096	: Pg=37.93, Qg=15.04 -> Pg=62.645, Qg=10.0
% INFO    : Gen at bus 6096	: Vg=1.022821 -> Vg=1.0
% INFO    : Gen at bus 6097	: Pg=16.74, Qg=3.04 -> Pg=55.58, Qg=10.0
% INFO    : Gen at bus 6097	: Vg=1.042545 -> Vg=1.0
% INFO    : Gen at bus 6098	: Pg=16.74, Qg=3.04 -> Pg=55.58, Qg=10.0
% INFO    : Gen at bus 6098	: Vg=1.042545 -> Vg=1.0
% INFO    : Gen at bus 6103	: Pg=379.71, Qg=199.24 -> Pg=500.0, Qg=80.0
% INFO    : Gen at bus 6103	: Vg=1.082967 -> Vg=1.0
% INFO    : Gen at bus 6107	: Pg=38.02, Qg=11.21 -> Pg=62.675, Qg=10.0
% INFO    : Gen at bus 6107	: Vg=1.043087 -> Vg=1.0
% INFO    : Gen at bus 6121	: Pg=85.28, Qg=21.31 -> Pg=128.425, Qg=20.0
% INFO    : Gen at bus 6121	: Vg=1.029542 -> Vg=1.0
% INFO    : Gen at bus 6123	: Pg=37.08, Qg=5.51 -> Pg=62.36, Qg=10.0
% INFO    : Gen at bus 6123	: Vg=1.021005 -> Vg=1.0
% INFO    : Gen at bus 6130	: Pg=5.0, Qg=0.52 -> Pg=51.665, Qg=0.0
% INFO    : Gen at bus 6130	: Vg=1.019692 -> Vg=1.0
% INFO    : Gen at bus 6132	: Pg=15.0, Qg=4.65 -> Pg=55.0, Qg=5.0
% INFO    : Gen at bus 6132	: Vg=1.033224 -> Vg=1.0
% INFO    : Gen at bus 6135	: Pg=17.64, Qg=4.13 -> Pg=55.88, Qg=10.0
% INFO    : Gen at bus 6135	: Vg=1.031189 -> Vg=1.0
% INFO    : Gen at bus 6138	: Pg=667.17, Qg=206.58 -> Pg=900.0, Qg=200.0
% INFO    : Gen at bus 6138	: Vg=1.030727 -> Vg=1.0
% INFO    : Gen at bus 6139	: Pg=667.17, Qg=206.58 -> Pg=900.0, Qg=200.0
% INFO    : Gen at bus 6139	: Vg=1.030727 -> Vg=1.0
% INFO    : Gen at bus 6140	: Pg=667.17, Qg=206.58 -> Pg=900.0, Qg=200.0
% INFO    : Gen at bus 6140	: Vg=1.030727 -> Vg=1.0
% INFO    : Gen at bus 6141	: Pg=938.69, Qg=9.52 -> Pg=1250.0, Qg=200.0
% INFO    : Gen at bus 6141	: Vg=1.028568 -> Vg=1.0
% INFO    : Gen at bus 6155	: Pg=31.3, Qg=3.62 -> Pg=60.435, Qg=5.0
% INFO    : Gen at bus 6155	: Vg=1.018029 -> Vg=1.0
% INFO    : Gen at bus 6156	: Pg=31.47, Qg=4.94 -> Pg=60.49, Qg=10.0
% INFO    : Gen at bus 6156	: Vg=1.024861 -> Vg=1.0
% INFO    : Gen at bus 6161	: Pg=64.84, Qg=8.42 -> Pg=121.615, Qg=20.0
% INFO    : Gen at bus 6161	: Vg=1.035942 -> Vg=1.0
% INFO    : Gen at bus 6162	: Pg=64.84, Qg=8.42 -> Pg=121.615, Qg=20.0
% INFO    : Gen at bus 6162	: Vg=1.035942 -> Vg=1.0
% INFO    : Gen at bus 6163	: Pg=4.37, Qg=0.22 -> Pg=51.455, Qg=0.0
% INFO    : Gen at bus 6163	: Vg=1.024003 -> Vg=1.0
% INFO    : Gen at bus 6167	: Pg=20.75, Qg=4.27 -> Pg=56.915, Qg=5.0
% INFO    : Gen at bus 6167	: Vg=1.024289 -> Vg=1.0
% INFO    : Gen at bus 6171	: Pg=12.3, Qg=0.28 -> Pg=54.1, Qg=0.0
% INFO    : Gen at bus 6171	: Vg=1.011745 -> Vg=1.0
% INFO    : Gen at bus 6192	: Pg=17.55, Qg=5.77 -> Pg=55.85, Qg=5.0
% INFO    : Gen at bus 6192	: Vg=1.031157 -> Vg=1.0
% INFO    : Gen at bus 6193	: Pg=254.08, Qg=105.54 -> Pg=350.0, Qg=60.0
% INFO    : Gen at bus 6193	: Vg=1.025991 -> Vg=1.0
% INFO    : Gen at bus 6194	: Pg=254.08, Qg=105.54 -> Pg=350.0, Qg=60.0
% INFO    : Gen at bus 6194	: Vg=1.025991 -> Vg=1.0
% INFO    : Gen at bus 6195	: Pg=25.41, Qg=10.98 -> Pg=58.47, Qg=10.0
% INFO    : Gen at bus 6195	: Vg=1.019411 -> Vg=1.0
% INFO    : Gen at bus 6199	: Pg=27.9, Qg=5.62 -> Pg=59.3, Qg=5.0
% INFO    : Gen at bus 6199	: Vg=1.021456 -> Vg=1.0
% INFO    : Gen at bus 6200	: Pg=7.7, Qg=0.04 -> Pg=52.565, Qg=0.0
% INFO    : Gen at bus 6200	: Vg=0.98149 -> Vg=1.0
% INFO    : Gen at bus 6201	: Pg=685.04, Qg=205.8 -> Pg=900.0, Qg=200.0
% INFO    : Gen at bus 6201	: Vg=1.048523 -> Vg=1.0
% INFO    : Gen at bus 6202	: Pg=685.04, Qg=205.8 -> Pg=900.0, Qg=200.0
% INFO    : Gen at bus 6202	: Vg=1.048523 -> Vg=1.0
% INFO    : Gen at bus 6203	: Pg=685.05, Qg=215.92 -> Pg=900.0, Qg=200.0
% INFO    : Gen at bus 6203	: Vg=1.050193 -> Vg=1.0
% INFO    : Gen at bus 6204	: Pg=685.05, Qg=215.92 -> Pg=900.0, Qg=200.0
% INFO    : Gen at bus 6204	: Vg=1.050193 -> Vg=1.0
% INFO    : Gen at bus 6208	: Pg=685.9, Qg=149.42 -> Pg=900.0, Qg=200.0
% INFO    : Gen at bus 6208	: Vg=1.062519 -> Vg=1.0
% INFO    : Gen at bus 6210	: Pg=36.03, Qg=16.08 -> Pg=62.01, Qg=10.0
% INFO    : Gen at bus 6210	: Vg=1.045359 -> Vg=1.0
% INFO    : Gen at bus 6212	: Pg=179.95, Qg=-207.96 -> Pg=250.0, Qg=0.0
% INFO    : Gen at bus 6212	: Vg=1.021013 -> Vg=1.0
% INFO    : Gen at bus 6213	: Pg=41.19, Qg=12.09 -> Pg=63.73, Qg=15.0
% INFO    : Gen at bus 6213	: Vg=1.029044 -> Vg=1.0
% INFO    : Gen at bus 6215	: Pg=67.23, Qg=14.17 -> Pg=122.41, Qg=15.0
% INFO    : Gen at bus 6215	: Vg=1.023729 -> Vg=1.0
% INFO    : Gen at bus 6218	: Pg=41.19, Qg=12.09 -> Pg=63.73, Qg=15.0
% INFO    : Gen at bus 6218	: Vg=1.029044 -> Vg=1.0
% INFO    : Gen at bus 6219	: Pg=33.39, Qg=17.82 -> Pg=61.13, Qg=15.0
% INFO    : Gen at bus 6219	: Vg=1.025649 -> Vg=1.0
% INFO    : Gen at bus 6220	: Pg=67.23, Qg=14.3 -> Pg=122.41, Qg=15.0
% INFO    : Gen at bus 6220	: Vg=1.023566 -> Vg=1.0
% INFO    : Gen at bus 6225	: Pg=38.79, Qg=7.11 -> Pg=62.93, Qg=10.0
% INFO    : Gen at bus 6225	: Vg=1.035838 -> Vg=1.0
% INFO    : Gen at bus 6226	: Pg=350.16, Qg=118.4 -> Pg=500.0, Qg=80.0
% INFO    : Gen at bus 6226	: Vg=1.062007 -> Vg=1.0
% INFO    : Gen at bus 6227	: Pg=364.79, Qg=160.47 -> Pg=500.0, Qg=80.0
% INFO    : Gen at bus 6227	: Vg=1.050331 -> Vg=1.0
% INFO    : Gen at bus 6254	: Pg=626.68, Qg=236.63 -> Pg=850.0, Qg=200.0
% INFO    : Gen at bus 6254	: Vg=1.051727 -> Vg=1.0
% INFO    : Gen at bus 6262	: Pg=243.32, Qg=23.39 -> Pg=300.0, Qg=80.0
% INFO    : Gen at bus 6262	: Vg=1.055881 -> Vg=1.0
% INFO    : Gen at bus 6272	: Pg=-0.15, Qg=1.91 -> Pg=49.9, Qg=0.0
% INFO    : Gen at bus 6272	: Vg=1.003919 -> Vg=1.0
% INFO    : Gen at bus 6276	: Pg=284.39, Qg=98.98 -> Pg=350.0, Qg=80.0
% INFO    : Gen at bus 6276	: Vg=1.060659 -> Vg=1.0
% INFO    : Gen at bus 6277	: Pg=284.4, Qg=98.98 -> Pg=350.0, Qg=80.0
% INFO    : Gen at bus 6277	: Vg=1.060659 -> Vg=1.0
% INFO    : Gen at bus 6278	: Pg=31.29, Qg=6.48 -> Pg=60.43, Qg=10.0
% INFO    : Gen at bus 6278	: Vg=1.024788 -> Vg=1.0
% INFO    : Gen at bus 6279	: Pg=284.39, Qg=98.98 -> Pg=350.0, Qg=80.0
% INFO    : Gen at bus 6279	: Vg=1.060659 -> Vg=1.0
% INFO    : Gen at bus 6280	: Pg=257.89, Qg=39.7 -> Pg=350.0, Qg=80.0
% INFO    : Gen at bus 6280	: Vg=1.022087 -> Vg=1.0
% INFO    : Gen at bus 6291	: Pg=35.74, Qg=6.84 -> Pg=61.915, Qg=10.0
% INFO    : Gen at bus 6291	: Vg=1.040138 -> Vg=1.0
% INFO    : Gen at bus 6296	: Pg=49.83, Qg=6.62 -> Pg=66.61, Qg=20.0
% INFO    : Gen at bus 6296	: Vg=1.007268 -> Vg=1.0
% INFO    : Gen at bus 6298	: Pg=29.68, Qg=6.45 -> Pg=59.895, Qg=10.0
% INFO    : Gen at bus 6298	: Vg=1.016891 -> Vg=1.0
% INFO    : Gen at bus 6299	: Pg=29.68, Qg=6.45 -> Pg=59.895, Qg=10.0
% INFO    : Gen at bus 6299	: Vg=1.016891 -> Vg=1.0
% INFO    : Gen at bus 6305	: Pg=100.0, Qg=41.35 -> Pg=183.335, Qg=20.0
% INFO    : Gen at bus 6305	: Vg=1.090507 -> Vg=1.0
% INFO    : Gen at bus 6314	: Pg=2.5, Qg=0.07 -> Pg=50.835, Qg=0.0
% INFO    : Gen at bus 6314	: Vg=0.984601 -> Vg=1.0
% INFO    : Gen at bus 6317	: Pg=312.49, Qg=55.02 -> Pg=450.0, Qg=80.0
% INFO    : Gen at bus 6317	: Vg=1.033042 -> Vg=1.0
% INFO    : Gen at bus 6325	: Pg=22.09, Qg=10.91 -> Pg=57.365, Qg=10.0
% INFO    : Gen at bus 6325	: Vg=1.043067 -> Vg=1.0
% INFO    : Gen at bus 6326	: Pg=22.09, Qg=10.91 -> Pg=57.365, Qg=10.0
% INFO    : Gen at bus 6326	: Vg=1.043067 -> Vg=1.0
% INFO    : Gen at bus 6327	: Pg=22.09, Qg=10.91 -> Pg=57.365, Qg=10.0
% INFO    : Gen at bus 6327	: Vg=1.043067 -> Vg=1.0
% INFO    : Gen at bus 6328	: Pg=22.09, Qg=10.91 -> Pg=57.365, Qg=10.0
% INFO    : Gen at bus 6328	: Vg=1.043067 -> Vg=1.0
% INFO    : Gen at bus 6329	: Pg=22.09, Qg=10.91 -> Pg=57.365, Qg=10.0
% INFO    : Gen at bus 6329	: Vg=1.043067 -> Vg=1.0
% INFO    : Gen at bus 6331	: Pg=99.68, Qg=14.71 -> Pg=133.225, Qg=20.0
% INFO    : Gen at bus 6331	: Vg=1.035207 -> Vg=1.0
% INFO    : Gen at bus 6335	: Pg=34.04, Qg=7.33 -> Pg=61.345, Qg=15.0
% INFO    : Gen at bus 6335	: Vg=1.031942 -> Vg=1.0
% INFO    : Gen at bus 6336	: Pg=34.04, Qg=7.33 -> Pg=61.345, Qg=15.0
% INFO    : Gen at bus 6336	: Vg=1.031942 -> Vg=1.0
% INFO    : Gen at bus 6337	: Pg=34.04, Qg=7.33 -> Pg=61.345, Qg=15.0
% INFO    : Gen at bus 6337	: Vg=1.031942 -> Vg=1.0
% INFO    : Gen at bus 6341	: Pg=35.5, Qg=10.89 -> Pg=61.835, Qg=10.0
% INFO    : Gen at bus 6341	: Vg=1.045213 -> Vg=1.0
% INFO    : Gen at bus 6346	: Pg=29.89, Qg=15.39 -> Pg=59.965, Qg=10.0
% INFO    : Gen at bus 6346	: Vg=1.024479 -> Vg=1.0
% INFO    : Gen at bus 6347	: Pg=0.02, Qg=-0.09 -> Pg=50.005, Qg=0.0
% INFO    : Gen at bus 6347	: Vg=1.02409 -> Vg=1.0
% INFO    : Gen at bus 6351	: Pg=289.73, Qg=138.75 -> Pg=350.0, Qg=60.0
% INFO    : Gen at bus 6351	: Vg=1.055778 -> Vg=1.0
% INFO    : Gen at bus 6352	: Pg=289.73, Qg=138.75 -> Pg=350.0, Qg=60.0
% INFO    : Gen at bus 6352	: Vg=1.055778 -> Vg=1.0
% INFO    : Gen at bus 6353	: Pg=201.27, Qg=91.44 -> Pg=300.0, Qg=60.0
% INFO    : Gen at bus 6353	: Vg=1.070329 -> Vg=1.0
% INFO    : Gen at bus 6354	: Pg=201.27, Qg=91.44 -> Pg=300.0, Qg=60.0
% INFO    : Gen at bus 6354	: Vg=1.070329 -> Vg=1.0
% INFO    : Gen at bus 6357	: Pg=206.08, Qg=85.48 -> Pg=300.0, Qg=60.0
% INFO    : Gen at bus 6357	: Vg=1.048705 -> Vg=1.0
% INFO    : Gen at bus 6358	: Pg=206.08, Qg=85.48 -> Pg=300.0, Qg=60.0
% INFO    : Gen at bus 6358	: Vg=1.048705 -> Vg=1.0
% INFO    : Gen at bus 6359	: Pg=18.32, Qg=-0.94 -> Pg=56.105, Qg=0.0
% INFO    : Gen at bus 6359	: Vg=0.995077 -> Vg=1.0
% INFO    : Gen at bus 6360	: Pg=215.66, Qg=145.16 -> Pg=300.0, Qg=60.0
% INFO    : Gen at bus 6360	: Vg=1.043227 -> Vg=1.0
% INFO    : Gen at bus 6361	: Pg=201.27, Qg=91.44 -> Pg=300.0, Qg=60.0
% INFO    : Gen at bus 6361	: Vg=1.070329 -> Vg=1.0
% INFO    : Gen at bus 6363	: Pg=56.36, Qg=7.67 -> Pg=118.785, Qg=15.0
% INFO    : Gen at bus 6363	: Vg=1.024375 -> Vg=1.0
% INFO    : Gen at bus 6368	: Pg=617.47, Qg=92.14 -> Pg=850.0, Qg=200.0
% INFO    : Gen at bus 6368	: Vg=1.032321 -> Vg=1.0
% INFO    : Gen at bus 6369	: Pg=267.35, Qg=24.57 -> Pg=350.0, Qg=60.0
% INFO    : Gen at bus 6369	: Vg=1.014698 -> Vg=1.0
% INFO    : Gen at bus 6370	: Pg=267.35, Qg=24.57 -> Pg=350.0, Qg=60.0
% INFO    : Gen at bus 6370	: Vg=1.014698 -> Vg=1.0
% INFO    : Gen at bus 6371	: Pg=267.35, Qg=24.57 -> Pg=350.0, Qg=60.0
% INFO    : Gen at bus 6371	: Vg=1.014698 -> Vg=1.0
% INFO    : Gen at bus 6372	: Pg=267.35, Qg=24.57 -> Pg=350.0, Qg=60.0
% INFO    : Gen at bus 6372	: Vg=1.014698 -> Vg=1.0
% INFO    : Gen at bus 6383	: Pg=37.0, Qg=0.77 -> Pg=62.335, Qg=0.0
% INFO    : Gen at bus 6383	: Vg=1.003111 -> Vg=1.0
% INFO    : Gen at bus 6391	: Pg=82.6, Qg=2.11 -> Pg=127.535, Qg=20.0
% INFO    : Gen at bus 6391	: Vg=1.02421 -> Vg=1.0
% INFO    : Gen at bus 6398	: Pg=32.64, Qg=6.68 -> Pg=60.88, Qg=10.0
% INFO    : Gen at bus 6398	: Vg=1.044939 -> Vg=1.0
% INFO    : Gen at bus 6401	: Pg=34.22, Qg=10.13 -> Pg=61.405, Qg=10.0
% INFO    : Gen at bus 6401	: Vg=1.052205 -> Vg=1.0
% INFO    : Gen at bus 6402	: Pg=34.22, Qg=10.13 -> Pg=61.405, Qg=10.0
% INFO    : Gen at bus 6402	: Vg=1.052231 -> Vg=1.0
% INFO    : Gen at bus 6404	: Pg=34.22, Qg=10.13 -> Pg=61.405, Qg=10.0
% INFO    : Gen at bus 6404	: Vg=1.052205 -> Vg=1.0
% INFO    : Gen at bus 6405	: Pg=35.55, Qg=14.31 -> Pg=61.85, Qg=10.0
% INFO    : Gen at bus 6405	: Vg=1.047514 -> Vg=1.0
% INFO    : Gen at bus 6406	: Pg=242.59, Qg=1.87 -> Pg=300.0, Qg=80.0
% INFO    : Gen at bus 6406	: Vg=1.040945 -> Vg=1.0
% INFO    : Gen at bus 6407	: Pg=34.22, Qg=10.13 -> Pg=61.405, Qg=10.0
% INFO    : Gen at bus 6407	: Vg=1.052231 -> Vg=1.0
% INFO    : Gen at bus 6408	: Pg=35.55, Qg=14.31 -> Pg=61.85, Qg=10.0
% INFO    : Gen at bus 6408	: Vg=1.047514 -> Vg=1.0
% INFO    : Gen at bus 6409	: Pg=359.06, Qg=76.92 -> Pg=500.0, Qg=80.0
% INFO    : Gen at bus 6409	: Vg=1.054213 -> Vg=1.0
% INFO    : Gen at bus 6417	: Pg=320.2, Qg=176.92 -> Pg=450.0, Qg=80.0
% INFO    : Gen at bus 6417	: Vg=1.054686 -> Vg=1.0
% INFO    : Gen at bus 6418	: Pg=320.2, Qg=176.92 -> Pg=450.0, Qg=80.0
% INFO    : Gen at bus 6418	: Vg=1.054686 -> Vg=1.0
% INFO    : Gen at bus 6420	: Pg=46.29, Qg=9.49 -> Pg=65.43, Qg=20.0
% INFO    : Gen at bus 6420	: Vg=0.994392 -> Vg=1.0
% INFO    : Gen at bus 6421	: Pg=44.03, Qg=4.68 -> Pg=64.675, Qg=20.0
% INFO    : Gen at bus 6421	: Vg=0.994839 -> Vg=1.0
% INFO    : Gen at bus 6422	: Pg=320.2, Qg=176.92 -> Pg=450.0, Qg=80.0
% INFO    : Gen at bus 6422	: Vg=1.054686 -> Vg=1.0
% INFO    : Gen at bus 6429	: Pg=13.29, Qg=-1.25 -> Pg=54.43, Qg=0.0
% INFO    : Gen at bus 6429	: Vg=1.021473 -> Vg=1.0
% INFO    : Gen at bus 6431	: Pg=21.0, Qg=3.83 -> Pg=57.0, Qg=5.0
% INFO    : Gen at bus 6431	: Vg=1.021729 -> Vg=1.0
% INFO    : Gen at bus 6436	: Pg=381.8, Qg=21.67 -> Pg=500.0, Qg=80.0
% INFO    : Gen at bus 6436	: Vg=1.063714 -> Vg=1.0
% INFO    : Gen at bus 6440	: Pg=15.84, Qg=6.64 -> Pg=55.28, Qg=10.0
% INFO    : Gen at bus 6440	: Vg=1.000784 -> Vg=1.0
% INFO    : Gen at bus 6451	: Pg=25.45, Qg=8.23 -> Pg=58.485, Qg=10.0
% INFO    : Gen at bus 6451	: Vg=1.004119 -> Vg=1.0
% INFO    : Gen at bus 6452	: Pg=25.39, Qg=2.92 -> Pg=58.465, Qg=10.0
% INFO    : Gen at bus 6452	: Vg=1.004063 -> Vg=1.0
% INFO    : Gen at bus 6454	: Pg=46.7, Qg=16.39 -> Pg=65.565, Qg=15.0
% INFO    : Gen at bus 6454	: Vg=1.027739 -> Vg=1.0
% INFO    : Gen at bus 6455	: Pg=40.16, Qg=6.22 -> Pg=63.385, Qg=10.0
% INFO    : Gen at bus 6455	: Vg=1.012552 -> Vg=1.0
% INFO    : Gen at bus 6456	: Pg=40.16, Qg=6.22 -> Pg=63.385, Qg=10.0
% INFO    : Gen at bus 6456	: Vg=1.012552 -> Vg=1.0
% INFO    : Gen at bus 6465	: Pg=34.86, Qg=4.81 -> Pg=61.62, Qg=10.0
% INFO    : Gen at bus 6465	: Vg=1.050901 -> Vg=1.0
% INFO    : Gen at bus 6471	: Pg=57.67, Qg=14.65 -> Pg=119.225, Qg=15.0
% INFO    : Gen at bus 6471	: Vg=1.028916 -> Vg=1.0
% INFO    : Gen at bus 6476	: Pg=260.62, Qg=111.59 -> Pg=350.0, Qg=80.0
% INFO    : Gen at bus 6476	: Vg=1.031498 -> Vg=1.0
% INFO    : Gen at bus 6477	: Pg=20.63, Qg=6.57 -> Pg=56.875, Qg=10.0
% INFO    : Gen at bus 6477	: Vg=1.022447 -> Vg=1.0
% INFO    : Gen at bus 6487	: Pg=37.23, Qg=4.01 -> Pg=62.41, Qg=10.0
% INFO    : Gen at bus 6487	: Vg=1.028283 -> Vg=1.0
% INFO    : Gen at bus 6491	: Pg=138.8, Qg=17.14 -> Pg=196.265, Qg=40.0
% INFO    : Gen at bus 6491	: Vg=1.04554 -> Vg=1.0
% INFO    : Gen at bus 6498	: Pg=60.07, Qg=-4.22 -> Pg=120.025, Qg=20.0
% INFO    : Gen at bus 6498	: Vg=1.016868 -> Vg=1.0
% INFO    : Gen at bus 6500	: Pg=277.81, Qg=77.81 -> Pg=350.0, Qg=80.0
% INFO    : Gen at bus 6500	: Vg=1.034935 -> Vg=1.0
% INFO    : Gen at bus 6507	: Pg=31.28, Qg=-0.92 -> Pg=60.425, Qg=10.0
% INFO    : Gen at bus 6507	: Vg=1.009892 -> Vg=1.0
% INFO    : Gen at bus 6527	: Pg=204.0, Qg=41.74 -> Pg=300.0, Qg=45.0
% INFO    : Gen at bus 6527	: Vg=1.035162 -> Vg=1.0
% INFO    : Gen at bus 6539	: Pg=16.79, Qg=7.28 -> Pg=55.595, Qg=10.0
% INFO    : Gen at bus 6539	: Vg=1.042166 -> Vg=1.0
% INFO    : Gen at bus 6541	: Pg=39.88, Qg=15.15 -> Pg=63.295, Qg=10.0
% INFO    : Gen at bus 6541	: Vg=1.024267 -> Vg=1.0
% INFO    : Gen at bus 6542	: Pg=39.88, Qg=15.15 -> Pg=63.295, Qg=10.0
% INFO    : Gen at bus 6542	: Vg=1.024267 -> Vg=1.0
% INFO    : Gen at bus 6543	: Pg=39.88, Qg=15.15 -> Pg=63.295, Qg=10.0
% INFO    : Gen at bus 6543	: Vg=1.024267 -> Vg=1.0
% INFO    : Gen at bus 6544	: Pg=93.64, Qg=6.04 -> Pg=131.215, Qg=20.0
% INFO    : Gen at bus 6544	: Vg=1.023818 -> Vg=1.0
% INFO    : Gen at bus 6545	: Pg=24.99, Qg=21.34 -> Pg=58.33, Qg=10.0
% INFO    : Gen at bus 6545	: Vg=1.019094 -> Vg=1.0
% INFO    : Gen at bus 6547	: Pg=93.64, Qg=6.04 -> Pg=131.215, Qg=20.0
% INFO    : Gen at bus 6547	: Vg=1.023818 -> Vg=1.0
% INFO    : Gen at bus 6548	: Pg=93.64, Qg=6.04 -> Pg=131.215, Qg=20.0
% INFO    : Gen at bus 6548	: Vg=1.023818 -> Vg=1.0
% INFO    : Gen at bus 6557	: Pg=47.94, Qg=3.29 -> Pg=65.98, Qg=15.0
% INFO    : Gen at bus 6557	: Vg=1.023603 -> Vg=1.0
% INFO    : Gen at bus 6563	: Pg=31.3, Qg=-0.89 -> Pg=60.435, Qg=0.0
% INFO    : Gen at bus 6563	: Vg=0.998951 -> Vg=1.0
% INFO    : Gen at bus 6566	: Pg=34.65, Qg=5.41 -> Pg=61.55, Qg=10.0
% INFO    : Gen at bus 6566	: Vg=1.014865 -> Vg=1.0
% INFO    : Gen at bus 6567	: Pg=34.65, Qg=5.41 -> Pg=61.55, Qg=10.0
% INFO    : Gen at bus 6567	: Vg=1.014865 -> Vg=1.0
% INFO    : Gen at bus 6584	: Pg=154.5, Qg=-14.56 -> Pg=250.0, Qg=5.0
% INFO    : Gen at bus 6584	: Vg=0.956299 -> Vg=1.0
% INFO    : Gen at bus 6585	: Pg=114.0, Qg=6.43 -> Pg=188.0, Qg=10.0
% INFO    : Gen at bus 6585	: Vg=0.989649 -> Vg=1.0
% INFO    : Gen at bus 6593	: Pg=38.27, Qg=1.62 -> Pg=62.755, Qg=10.0
% INFO    : Gen at bus 6593	: Vg=1.047126 -> Vg=1.0
% INFO    : Gen at bus 6601	: Pg=192.55, Qg=1.87 -> Pg=250.0, Qg=60.0
% INFO    : Gen at bus 6601	: Vg=1.012099 -> Vg=1.0
% INFO    : Gen at bus 6602	: Pg=37.08, Qg=5.51 -> Pg=62.36, Qg=10.0
% INFO    : Gen at bus 6602	: Vg=1.021005 -> Vg=1.0
% INFO    : Gen at bus 6606	: Pg=88.06, Qg=35.93 -> Pg=129.355, Qg=20.0
% INFO    : Gen at bus 6606	: Vg=1.024151 -> Vg=1.0
% INFO    : Gen at bus 6607	: Pg=88.06, Qg=35.93 -> Pg=129.355, Qg=20.0
% INFO    : Gen at bus 6607	: Vg=1.024151 -> Vg=1.0
% INFO    : Gen at bus 6608	: Pg=88.06, Qg=35.93 -> Pg=129.355, Qg=20.0
% INFO    : Gen at bus 6608	: Vg=1.024151 -> Vg=1.0
% INFO    : Gen at bus 6609	: Pg=88.06, Qg=35.93 -> Pg=129.355, Qg=20.0
% INFO    : Gen at bus 6609	: Vg=1.024151 -> Vg=1.0
% INFO    : Gen at bus 6610	: Pg=88.06, Qg=35.93 -> Pg=129.355, Qg=20.0
% INFO    : Gen at bus 6610	: Vg=1.024151 -> Vg=1.0
% INFO    : Gen at bus 6611	: Pg=88.06, Qg=35.93 -> Pg=129.355, Qg=20.0
% INFO    : Gen at bus 6611	: Vg=1.024151 -> Vg=1.0
% INFO    : Gen at bus 6612	: Pg=88.06, Qg=35.93 -> Pg=129.355, Qg=20.0
% INFO    : Gen at bus 6612	: Vg=1.024151 -> Vg=1.0
% INFO    : Gen at bus 6616	: Pg=138.8, Qg=-5.3 -> Pg=196.265, Qg=40.0
% INFO    : Gen at bus 6616	: Vg=1.029779 -> Vg=1.0
% INFO    : Gen at bus 6620	: Pg=323.35, Qg=77.76 -> Pg=450.0, Qg=80.0
% INFO    : Gen at bus 6620	: Vg=1.058114 -> Vg=1.0
% INFO    : Gen at bus 6621	: Pg=23.65, Qg=10.04 -> Pg=57.885, Qg=10.0
% INFO    : Gen at bus 6621	: Vg=1.059543 -> Vg=1.0
% INFO    : Gen at bus 6622	: Pg=52.64, Qg=8.15 -> Pg=117.545, Qg=10.0
% INFO    : Gen at bus 6622	: Vg=1.030338 -> Vg=1.0
% INFO    : Gen at bus 6623	: Pg=30.67, Qg=11.2 -> Pg=60.225, Qg=10.0
% INFO    : Gen at bus 6623	: Vg=1.040509 -> Vg=1.0
% INFO    : Gen at bus 6624	: Pg=30.67, Qg=11.2 -> Pg=60.225, Qg=10.0
% INFO    : Gen at bus 6624	: Vg=1.040509 -> Vg=1.0
% INFO    : Gen at bus 6628	: Pg=301.72, Qg=83.89 -> Pg=450.0, Qg=80.0
% INFO    : Gen at bus 6628	: Vg=1.041212 -> Vg=1.0
% INFO    : Gen at bus 6630	: Pg=30.67, Qg=11.2 -> Pg=60.225, Qg=10.0
% INFO    : Gen at bus 6630	: Vg=1.040509 -> Vg=1.0
% INFO    : Gen at bus 6631	: Pg=38.52, Qg=8.15 -> Pg=62.84, Qg=10.0
% INFO    : Gen at bus 6631	: Vg=1.04659 -> Vg=1.0
% INFO    : Gen at bus 6639	: Pg=23.85, Qg=6.18 -> Pg=57.95, Qg=15.0
% INFO    : Gen at bus 6639	: Vg=1.031885 -> Vg=1.0
% INFO    : Gen at bus 6640	: Pg=23.85, Qg=6.18 -> Pg=57.95, Qg=15.0
% INFO    : Gen at bus 6640	: Vg=1.031885 -> Vg=1.0
% INFO    : Gen at bus 6641	: Pg=23.85, Qg=6.18 -> Pg=57.95, Qg=15.0
% INFO    : Gen at bus 6641	: Vg=1.031885 -> Vg=1.0
% INFO    : Gen at bus 6642	: Pg=23.85, Qg=6.18 -> Pg=57.95, Qg=15.0
% INFO    : Gen at bus 6642	: Vg=1.031885 -> Vg=1.0
% INFO    : Gen at bus 6649	: Pg=8.2, Qg=-2.56 -> Pg=52.735, Qg=0.0
% INFO    : Gen at bus 6649	: Vg=0.955439 -> Vg=1.0
% INFO    : Gen at bus 6650	: Pg=96.03, Qg=17.22 -> Pg=132.01, Qg=20.0
% INFO    : Gen at bus 6650	: Vg=1.036065 -> Vg=1.0
% INFO    : Gen at bus 6651	: Pg=74.78, Qg=41.98 -> Pg=124.925, Qg=20.0
% INFO    : Gen at bus 6651	: Vg=1.04914 -> Vg=1.0
% INFO    : Gen at bus 6654	: Pg=45.28, Qg=10.84 -> Pg=65.095, Qg=15.0
% INFO    : Gen at bus 6654	: Vg=1.043738 -> Vg=1.0
% INFO    : Gen at bus 6663	: Pg=91.17, Qg=37.8 -> Pg=130.39, Qg=20.0
% INFO    : Gen at bus 6663	: Vg=1.045666 -> Vg=1.0
% INFO    : Gen at bus 6667	: Pg=203.46, Qg=82.67 -> Pg=300.0, Qg=80.0
% INFO    : Gen at bus 6667	: Vg=1.034595 -> Vg=1.0
% INFO    : Gen at bus 6670	: Pg=36.77, Qg=13.93 -> Pg=62.255, Qg=10.0
% INFO    : Gen at bus 6670	: Vg=1.042317 -> Vg=1.0
% INFO    : Gen at bus 6680	: Pg=55.25, Qg=2.21 -> Pg=118.415, Qg=0.0
% INFO    : Gen at bus 6680	: Vg=0.994234 -> Vg=1.0
% INFO    : Gen at bus 6686	: Pg=25.44, Qg=-2.35 -> Pg=58.48, Qg=0.0
% INFO    : Gen at bus 6686	: Vg=0.995022 -> Vg=1.0
% INFO    : Gen at bus 6689	: Pg=49.34, Qg=9.15 -> Pg=66.445, Qg=15.0
% INFO    : Gen at bus 6689	: Vg=1.034597 -> Vg=1.0
% INFO    : Gen at bus 6690	: Pg=49.34, Qg=9.15 -> Pg=66.445, Qg=15.0
% INFO    : Gen at bus 6690	: Vg=1.034597 -> Vg=1.0
% INFO    : Gen at bus 6691	: Pg=49.34, Qg=9.15 -> Pg=66.445, Qg=15.0
% INFO    : Gen at bus 6691	: Vg=1.034597 -> Vg=1.0
% INFO    : Gen at bus 6693	: Pg=50.34, Qg=9.17 -> Pg=116.78, Qg=15.0
% INFO    : Gen at bus 6693	: Vg=1.034532 -> Vg=1.0
% INFO    : Gen at bus 6697	: Pg=50.34, Qg=9.17 -> Pg=116.78, Qg=15.0
% INFO    : Gen at bus 6697	: Vg=1.034532 -> Vg=1.0
% INFO    : Gen at bus 6709	: Pg=16.12, Qg=0.49 -> Pg=55.375, Qg=0.0
% INFO    : Gen at bus 6709	: Vg=1.021634 -> Vg=1.0
% INFO    : Gen at bus 6713	: Pg=57.54, Qg=22.74 -> Pg=119.18, Qg=15.0
% INFO    : Gen at bus 6713	: Vg=1.022626 -> Vg=1.0
% INFO    : Gen at bus 6717	: Pg=2.0, Qg=-0.0 -> Pg=50.665, Qg=0.0
% INFO    : Gen at bus 6717	: Vg=0.996757 -> Vg=1.0
% INFO    : Gen at bus 6719	: Pg=68.89, Qg=5.63 -> Pg=122.965, Qg=20.0
% INFO    : Gen at bus 6719	: Vg=1.028667 -> Vg=1.0
% INFO    : Gen at bus 6721	: Pg=68.89, Qg=5.63 -> Pg=122.965, Qg=20.0
% INFO    : Gen at bus 6721	: Vg=1.028667 -> Vg=1.0
% INFO    : Gen at bus 6726	: Pg=32.05, Qg=4.77 -> Pg=60.685, Qg=5.0
% INFO    : Gen at bus 6726	: Vg=1.016479 -> Vg=1.0
% INFO    : Gen at bus 6729	: Pg=323.35, Qg=77.76 -> Pg=450.0, Qg=80.0
% INFO    : Gen at bus 6729	: Vg=1.058114 -> Vg=1.0
% INFO    : Gen at bus 6731	: Pg=22.46, Qg=14.75 -> Pg=57.485, Qg=10.0
% INFO    : Gen at bus 6731	: Vg=1.043942 -> Vg=1.0
% INFO    : Gen at bus 6734	: Pg=245.73, Qg=1.48 -> Pg=300.0, Qg=60.0
% INFO    : Gen at bus 6734	: Vg=1.005341 -> Vg=1.0
% INFO    : Gen at bus 6747	: Pg=169.6, Qg=14.07 -> Pg=250.0, Qg=25.0
% INFO    : Gen at bus 6747	: Vg=1.016595 -> Vg=1.0
% INFO    : Gen at bus 6749	: Pg=33.68, Qg=6.27 -> Pg=61.225, Qg=10.0
% INFO    : Gen at bus 6749	: Vg=1.046665 -> Vg=1.0
% INFO    : Gen at bus 6754	: Pg=214.6, Qg=55.92 -> Pg=300.0, Qg=80.0
% INFO    : Gen at bus 6754	: Vg=1.073284 -> Vg=1.0
% INFO    : Gen at bus 6757	: Pg=33.84, Qg=9.43 -> Pg=61.28, Qg=10.0
% INFO    : Gen at bus 6757	: Vg=1.043178 -> Vg=1.0
% INFO    : Gen at bus 6758	: Pg=33.84, Qg=9.43 -> Pg=61.28, Qg=10.0
% INFO    : Gen at bus 6758	: Vg=1.043178 -> Vg=1.0
% INFO    : Gen at bus 6759	: Pg=33.84, Qg=9.43 -> Pg=61.28, Qg=10.0
% INFO    : Gen at bus 6759	: Vg=1.043178 -> Vg=1.0
% INFO    : Gen at bus 6760	: Pg=33.84, Qg=9.43 -> Pg=61.28, Qg=10.0
% INFO    : Gen at bus 6760	: Vg=1.043178 -> Vg=1.0
% INFO    : Gen at bus 6761	: Pg=33.84, Qg=9.43 -> Pg=61.28, Qg=10.0
% INFO    : Gen at bus 6761	: Vg=1.043178 -> Vg=1.0
% INFO    : Gen at bus 6762	: Pg=33.84, Qg=9.43 -> Pg=61.28, Qg=10.0
% INFO    : Gen at bus 6762	: Vg=1.043178 -> Vg=1.0
% INFO    : Gen at bus 6763	: Pg=33.84, Qg=9.43 -> Pg=61.28, Qg=10.0
% INFO    : Gen at bus 6763	: Vg=1.043178 -> Vg=1.0
% INFO    : Gen at bus 6764	: Pg=86.6, Qg=49.99 -> Pg=128.865, Qg=20.0
% INFO    : Gen at bus 6764	: Vg=1.041274 -> Vg=1.0
% INFO    : Gen at bus 6765	: Pg=95.35, Qg=51.27 -> Pg=131.785, Qg=20.0
% INFO    : Gen at bus 6765	: Vg=1.042697 -> Vg=1.0
% INFO    : Gen at bus 6769	: Pg=21.03, Qg=9.77 -> Pg=57.01, Qg=10.0
% INFO    : Gen at bus 6769	: Vg=1.034441 -> Vg=1.0
% INFO    : Gen at bus 6773	: Pg=46.38, Qg=17.23 -> Pg=65.46, Qg=15.0
% INFO    : Gen at bus 6773	: Vg=1.048358 -> Vg=1.0
% INFO    : Gen at bus 6774	: Pg=33.61, Qg=7.79 -> Pg=61.205, Qg=10.0
% INFO    : Gen at bus 6774	: Vg=1.005097 -> Vg=1.0
% INFO    : Gen at bus 6780	: Pg=38.79, Qg=7.11 -> Pg=62.93, Qg=10.0
% INFO    : Gen at bus 6780	: Vg=1.035838 -> Vg=1.0
% INFO    : Gen at bus 6784	: Pg=8.4, Qg=0.33 -> Pg=52.8, Qg=0.0
% INFO    : Gen at bus 6784	: Vg=1.014368 -> Vg=1.0
% INFO    : Gen at bus 6785	: Pg=33.61, Qg=7.79 -> Pg=61.205, Qg=10.0
% INFO    : Gen at bus 6785	: Vg=1.005097 -> Vg=1.0
% INFO    : Gen at bus 6789	: Pg=33.61, Qg=7.79 -> Pg=61.205, Qg=10.0
% INFO    : Gen at bus 6789	: Vg=1.005097 -> Vg=1.0
% INFO    : Gen at bus 6792	: Pg=23.13, Qg=4.04 -> Pg=57.71, Qg=10.0
% INFO    : Gen at bus 6792	: Vg=1.024356 -> Vg=1.0
% INFO    : Gen at bus 6793	: Pg=23.13, Qg=4.04 -> Pg=57.71, Qg=10.0
% INFO    : Gen at bus 6793	: Vg=1.024356 -> Vg=1.0
% INFO    : Gen at bus 6794	: Pg=21.19, Qg=8.66 -> Pg=57.065, Qg=10.0
% INFO    : Gen at bus 6794	: Vg=1.017963 -> Vg=1.0
% INFO    : Gen at bus 6795	: Pg=21.19, Qg=8.66 -> Pg=57.065, Qg=10.0
% INFO    : Gen at bus 6795	: Vg=1.017963 -> Vg=1.0
% INFO    : Gen at bus 6797	: Pg=34.86, Qg=9.16 -> Pg=61.62, Qg=10.0
% INFO    : Gen at bus 6797	: Vg=1.014343 -> Vg=1.0
% INFO    : Gen at bus 6798	: Pg=34.86, Qg=9.16 -> Pg=61.62, Qg=10.0
% INFO    : Gen at bus 6798	: Vg=1.014343 -> Vg=1.0
% INFO    : Gen at bus 6799	: Pg=35.01, Qg=1.48 -> Pg=61.67, Qg=10.0
% INFO    : Gen at bus 6799	: Vg=1.032132 -> Vg=1.0
% INFO    : Gen at bus 6801	: Pg=20.77, Qg=8.67 -> Pg=56.925, Qg=10.0
% INFO    : Gen at bus 6801	: Vg=1.040566 -> Vg=1.0
% INFO    : Gen at bus 6802	: Pg=20.77, Qg=8.67 -> Pg=56.925, Qg=10.0
% INFO    : Gen at bus 6802	: Vg=1.040566 -> Vg=1.0
% INFO    : Gen at bus 6806	: Pg=41.79, Qg=9.53 -> Pg=63.93, Qg=15.0
% INFO    : Gen at bus 6806	: Vg=1.021328 -> Vg=1.0
% INFO    : Gen at bus 6807	: Pg=41.79, Qg=9.53 -> Pg=63.93, Qg=15.0
% INFO    : Gen at bus 6807	: Vg=1.021328 -> Vg=1.0
% INFO    : Gen at bus 6808	: Pg=41.79, Qg=9.53 -> Pg=63.93, Qg=15.0
% INFO    : Gen at bus 6808	: Vg=1.021328 -> Vg=1.0
% INFO    : Gen at bus 6814	: Pg=41.79, Qg=9.53 -> Pg=63.93, Qg=15.0
% INFO    : Gen at bus 6814	: Vg=1.021328 -> Vg=1.0
% INFO    : Gen at bus 6815	: Pg=41.79, Qg=9.53 -> Pg=63.93, Qg=15.0
% INFO    : Gen at bus 6815	: Vg=1.021328 -> Vg=1.0
% INFO    : Gen at bus 6820	: Pg=35.5, Qg=10.89 -> Pg=61.835, Qg=10.0
% INFO    : Gen at bus 6820	: Vg=1.045213 -> Vg=1.0
% INFO    : Gen at bus 6822	: Pg=210.0, Qg=37.99 -> Pg=300.0, Qg=60.0
% INFO    : Gen at bus 6822	: Vg=0.991398 -> Vg=1.0
% INFO    : Gen at bus 6836	: Pg=240.6, Qg=61.27 -> Pg=300.0, Qg=35.0
% INFO    : Gen at bus 6836	: Vg=0.990475 -> Vg=1.0
% INFO    : Gen at bus 6842	: Pg=21.03, Qg=9.75 -> Pg=57.01, Qg=10.0
% INFO    : Gen at bus 6842	: Vg=1.034464 -> Vg=1.0
% INFO    : Gen at bus 6846	: Pg=23.5, Qg=5.12 -> Pg=57.835, Qg=10.0
% INFO    : Gen at bus 6846	: Vg=1.029146 -> Vg=1.0
% INFO    : Gen at bus 6847	: Pg=25.08, Qg=6.95 -> Pg=58.36, Qg=10.0
% INFO    : Gen at bus 6847	: Vg=1.024018 -> Vg=1.0
% INFO    : Gen at bus 6861	: Pg=16.28, Qg=8.5 -> Pg=55.425, Qg=10.0
% INFO    : Gen at bus 6861	: Vg=1.027518 -> Vg=1.0
% INFO    : Gen at bus 6862	: Pg=86.61, Qg=21.7 -> Pg=128.87, Qg=20.0
% INFO    : Gen at bus 6862	: Vg=1.039025 -> Vg=1.0
% INFO    : Gen at bus 6864	: Pg=2.5, Qg=0.07 -> Pg=50.835, Qg=0.0
% INFO    : Gen at bus 6864	: Vg=0.984601 -> Vg=1.0
% INFO    : Gen at bus 6865	: Pg=24.84, Qg=13.51 -> Pg=58.28, Qg=10.0
% INFO    : Gen at bus 6865	: Vg=1.036049 -> Vg=1.0
% INFO    : Gen at bus 6870	: Pg=95.02, Qg=8.09 -> Pg=131.675, Qg=20.0
% INFO    : Gen at bus 6870	: Vg=1.023144 -> Vg=1.0
% INFO    : Gen at bus 6871	: Pg=157.5, Qg=-11.97 -> Pg=250.0, Qg=0.0
% INFO    : Gen at bus 6871	: Vg=0.984599 -> Vg=1.0
% INFO    : Gen at bus 6875	: Pg=95.01, Qg=14.99 -> Pg=131.67, Qg=20.0
% INFO    : Gen at bus 6875	: Vg=1.024647 -> Vg=1.0
% INFO    : Gen at bus 6876	: Pg=95.01, Qg=14.99 -> Pg=131.67, Qg=20.0
% INFO    : Gen at bus 6876	: Vg=1.024647 -> Vg=1.0
% INFO    : Gen at bus 6877	: Pg=95.01, Qg=14.99 -> Pg=131.67, Qg=20.0
% INFO    : Gen at bus 6877	: Vg=1.024647 -> Vg=1.0
% INFO    : Gen at bus 6879	: Pg=863.43, Qg=303.77 -> Pg=1150.0, Qg=200.0
% INFO    : Gen at bus 6879	: Vg=1.066491 -> Vg=1.0
% INFO    : Gen at bus 6880	: Pg=863.43, Qg=305.56 -> Pg=1150.0, Qg=200.0
% INFO    : Gen at bus 6880	: Vg=1.066564 -> Vg=1.0
% INFO    : Gen at bus 6885	: Pg=82.46, Qg=55.28 -> Pg=127.485, Qg=20.0
% INFO    : Gen at bus 6885	: Vg=1.127948 -> Vg=1.0
% INFO    : Gen at bus 6886	: Pg=55.94, Qg=27.58 -> Pg=118.645, Qg=15.0
% INFO    : Gen at bus 6886	: Vg=1.023096 -> Vg=1.0
% INFO    : Gen at bus 6903	: Pg=236.37, Qg=0.58 -> Pg=300.0, Qg=80.0
% INFO    : Gen at bus 6903	: Vg=1.042446 -> Vg=1.0
% INFO    : Gen at bus 6909	: Pg=329.87, Qg=46.94 -> Pg=450.0, Qg=80.0
% INFO    : Gen at bus 6909	: Vg=1.023155 -> Vg=1.0
% INFO    : Gen at bus 6910	: Pg=329.87, Qg=46.94 -> Pg=450.0, Qg=80.0
% INFO    : Gen at bus 6910	: Vg=1.023155 -> Vg=1.0
% INFO    : Gen at bus 6912	: Pg=100.41, Qg=11.92 -> Pg=183.47, Qg=20.0
% INFO    : Gen at bus 6912	: Vg=1.038747 -> Vg=1.0
% INFO    : Gen at bus 6918	: Pg=226.17, Qg=144.77 -> Pg=300.0, Qg=80.0
% INFO    : Gen at bus 6918	: Vg=1.073133 -> Vg=1.0
% INFO    : Gen at bus 6930	: Pg=84.12, Qg=16.88 -> Pg=128.04, Qg=20.0
% INFO    : Gen at bus 6930	: Vg=1.028641 -> Vg=1.0
% INFO    : Gen at bus 6931	: Pg=84.12, Qg=16.88 -> Pg=128.04, Qg=20.0
% INFO    : Gen at bus 6931	: Vg=1.028641 -> Vg=1.0
% INFO    : Gen at bus 6939	: Pg=10.5, Qg=-0.35 -> Pg=53.5, Qg=0.0
% INFO    : Gen at bus 6939	: Vg=0.994858 -> Vg=1.0
% INFO    : Gen at bus 6942	: Pg=5.2, Qg=0.51 -> Pg=51.735, Qg=0.0
% INFO    : Gen at bus 6942	: Vg=1.017532 -> Vg=1.0
% INFO    : Gen at bus 6944	: Pg=38.42, Qg=21.93 -> Pg=62.805, Qg=10.0
% INFO    : Gen at bus 6944	: Vg=1.054031 -> Vg=1.0
% INFO    : Gen at bus 6948	: Pg=23.6, Qg=10.13 -> Pg=57.865, Qg=10.0
% INFO    : Gen at bus 6948	: Vg=1.031397 -> Vg=1.0
% INFO    : Gen at bus 6952	: Pg=8.2, Qg=-2.56 -> Pg=52.735, Qg=0.0
% INFO    : Gen at bus 6952	: Vg=0.955439 -> Vg=1.0
% INFO    : Gen at bus 6963	: Pg=37.55, Qg=7.2 -> Pg=62.515, Qg=10.0
% INFO    : Gen at bus 6963	: Vg=1.029893 -> Vg=1.0
% INFO    : Gen at bus 6967	: Pg=38.42, Qg=21.93 -> Pg=62.805, Qg=10.0
% INFO    : Gen at bus 6967	: Vg=1.054031 -> Vg=1.0
% INFO    : Gen at bus 6969	: Pg=38.42, Qg=21.93 -> Pg=62.805, Qg=10.0
% INFO    : Gen at bus 6969	: Vg=1.054031 -> Vg=1.0
% INFO    : Gen at bus 6976	: Pg=31.2, Qg=5.73 -> Pg=60.4, Qg=10.0
% INFO    : Gen at bus 6976	: Vg=1.050684 -> Vg=1.0
% INFO    : Gen at bus 6985	: Pg=77.81, Qg=13.09 -> Pg=125.935, Qg=20.0
% INFO    : Gen at bus 6985	: Vg=1.029991 -> Vg=1.0
% INFO    : Gen at bus 6987	: Pg=77.81, Qg=13.09 -> Pg=125.935, Qg=20.0
% INFO    : Gen at bus 6987	: Vg=1.029991 -> Vg=1.0
% INFO    : Gen at bus 6990	: Pg=24.65, Qg=14.16 -> Pg=58.215, Qg=10.0
% INFO    : Gen at bus 6990	: Vg=1.027131 -> Vg=1.0
% INFO    : Gen at bus 6992	: Pg=32.2, Qg=7.05 -> Pg=60.735, Qg=10.0
% INFO    : Gen at bus 6992	: Vg=1.034688 -> Vg=1.0
% INFO    : Gen at bus 6994	: Pg=5.8, Qg=-0.78 -> Pg=51.935, Qg=0.0
% INFO    : Gen at bus 6994	: Vg=1.003942 -> Vg=1.0
% INFO    : Gen at bus 6996	: Pg=223.39, Qg=-18.71 -> Pg=300.0, Qg=60.0
% INFO    : Gen at bus 6996	: Vg=1.0182 -> Vg=1.0
% INFO    : Gen at bus 6998	: Pg=83.78, Qg=15.02 -> Pg=127.925, Qg=20.0
% INFO    : Gen at bus 6998	: Vg=1.033534 -> Vg=1.0
% INFO    : Gen at bus 7005	: Pg=381.4, Qg=117.77 -> Pg=500.0, Qg=80.0
% INFO    : Gen at bus 7005	: Vg=1.04062 -> Vg=1.0
% INFO    : Gen at bus 7009	: Pg=15.19, Qg=3.2 -> Pg=55.065, Qg=5.0
% INFO    : Gen at bus 7009	: Vg=1.023432 -> Vg=1.0
% INFO    : Gen at bus 7020	: Pg=78.71, Qg=19.55 -> Pg=126.235, Qg=20.0
% INFO    : Gen at bus 7020	: Vg=1.033214 -> Vg=1.0
% INFO    : Gen at bus 7028	: Pg=38.02, Qg=11.21 -> Pg=62.675, Qg=10.0
% INFO    : Gen at bus 7028	: Vg=1.043087 -> Vg=1.0
% INFO    : Gen at bus 7031	: Pg=24.28, Qg=7.01 -> Pg=58.095, Qg=10.0
% INFO    : Gen at bus 7031	: Vg=1.012542 -> Vg=1.0
% INFO    : Gen at bus 7045	: Pg=273.28, Qg=112.89 -> Pg=350.0, Qg=80.0
% INFO    : Gen at bus 7045	: Vg=1.041985 -> Vg=1.0
% INFO    : Gen at bus 7052	: Pg=23.2, Qg=-0.19 -> Pg=57.735, Qg=0.0
% INFO    : Gen at bus 7052	: Vg=0.99693 -> Vg=1.0
% INFO    : Gen at bus 7055	: Pg=88.45, Qg=51.85 -> Pg=129.485, Qg=20.0
% INFO    : Gen at bus 7055	: Vg=1.046478 -> Vg=1.0
% INFO    : Gen at bus 7056	: Pg=31.96, Qg=10.69 -> Pg=60.655, Qg=10.0
% INFO    : Gen at bus 7056	: Vg=1.028102 -> Vg=1.0
% INFO    : Gen at bus 7057	: Pg=35.74, Qg=6.84 -> Pg=61.915, Qg=10.0
% INFO    : Gen at bus 7057	: Vg=1.040138 -> Vg=1.0
% INFO    : Gen at bus 7063	: Pg=617.75, Qg=183.04 -> Pg=850.0, Qg=200.0
% INFO    : Gen at bus 7063	: Vg=1.058676 -> Vg=1.0
% INFO    : Gen at bus 7064	: Pg=34.31, Qg=1.99 -> Pg=61.435, Qg=10.0
% INFO    : Gen at bus 7064	: Vg=1.015531 -> Vg=1.0
% INFO    : Gen at bus 7066	: Pg=6.52, Qg=-0.06 -> Pg=52.175, Qg=0.0
% INFO    : Gen at bus 7066	: Vg=0.994601 -> Vg=1.0
% INFO    : Gen at bus 7068	: Pg=16.1, Qg=3.37 -> Pg=55.365, Qg=5.0
% INFO    : Gen at bus 7068	: Vg=1.026372 -> Vg=1.0
% INFO    : Gen at bus 7070	: Pg=4.56, Qg=0.3 -> Pg=51.52, Qg=0.0
% INFO    : Gen at bus 7070	: Vg=1.002967 -> Vg=1.0
% INFO    : Gen at bus 7071	: Pg=323.35, Qg=77.76 -> Pg=450.0, Qg=80.0
% INFO    : Gen at bus 7071	: Vg=1.058114 -> Vg=1.0
% INFO    : Gen at bus 7072	: Pg=258.95, Qg=65.97 -> Pg=350.0, Qg=80.0
% INFO    : Gen at bus 7072	: Vg=1.036699 -> Vg=1.0
% INFO    : Gen at bus 7073	: Pg=179.12, Qg=14.03 -> Pg=250.0, Qg=60.0
% INFO    : Gen at bus 7073	: Vg=1.034768 -> Vg=1.0
% INFO    : Gen at bus 7075	: Pg=24.89, Qg=5.96 -> Pg=58.295, Qg=10.0
% INFO    : Gen at bus 7075	: Vg=1.042846 -> Vg=1.0
% INFO    : Gen at bus 7079	: Pg=54.05, Qg=11.46 -> Pg=118.015, Qg=15.0
% INFO    : Gen at bus 7079	: Vg=1.024254 -> Vg=1.0
% INFO    : Gen at bus 7080	: Pg=23.66, Qg=2.76 -> Pg=57.885, Qg=10.0
% INFO    : Gen at bus 7080	: Vg=1.020703 -> Vg=1.0
% INFO    : Gen at bus 7081	: Pg=23.66, Qg=2.76 -> Pg=57.885, Qg=10.0
% INFO    : Gen at bus 7081	: Vg=1.020703 -> Vg=1.0
% INFO    : Gen at bus 7082	: Pg=23.66, Qg=2.76 -> Pg=57.885, Qg=10.0
% INFO    : Gen at bus 7082	: Vg=1.020703 -> Vg=1.0
% INFO    : Gen at bus 7083	: Pg=23.66, Qg=2.76 -> Pg=57.885, Qg=10.0
% INFO    : Gen at bus 7083	: Vg=1.020703 -> Vg=1.0
% INFO    : Gen at bus 7084	: Pg=23.96, Qg=4.79 -> Pg=57.985, Qg=10.0
% INFO    : Gen at bus 7084	: Vg=1.007614 -> Vg=1.0
% INFO    : Gen at bus 7085	: Pg=23.66, Qg=2.76 -> Pg=57.885, Qg=10.0
% INFO    : Gen at bus 7085	: Vg=1.020703 -> Vg=1.0
% INFO    : Gen at bus 7087	: Pg=23.96, Qg=4.79 -> Pg=57.985, Qg=10.0
% INFO    : Gen at bus 7087	: Vg=1.007614 -> Vg=1.0
% INFO    : Gen at bus 7105	: Pg=38.79, Qg=7.11 -> Pg=62.93, Qg=10.0
% INFO    : Gen at bus 7105	: Vg=1.035838 -> Vg=1.0
% INFO    : Gen at bus 7110	: Pg=91.41, Qg=18.38 -> Pg=130.47, Qg=20.0
% INFO    : Gen at bus 7110	: Vg=1.020566 -> Vg=1.0
% INFO    : Gen at bus 7111	: Pg=177.84, Qg=-23.15 -> Pg=250.0, Qg=60.0
% INFO    : Gen at bus 7111	: Vg=0.995435 -> Vg=1.0
% INFO    : Gen at bus 7113	: Pg=224.13, Qg=67.46 -> Pg=300.0, Qg=60.0
% INFO    : Gen at bus 7113	: Vg=1.034235 -> Vg=1.0
% INFO    : Gen at bus 7114	: Pg=48.11, Qg=1.87 -> Pg=66.035, Qg=5.0
% INFO    : Gen at bus 7114	: Vg=1.014725 -> Vg=1.0
% INFO    : Gen at bus 7115	: Pg=35.74, Qg=6.84 -> Pg=61.915, Qg=10.0
% INFO    : Gen at bus 7115	: Vg=1.040138 -> Vg=1.0
% INFO    : Gen at bus 7116	: Pg=36.77, Qg=13.93 -> Pg=62.255, Qg=10.0
% INFO    : Gen at bus 7116	: Vg=1.042317 -> Vg=1.0
% INFO    : Gen at bus 7122	: Pg=56.25, Qg=11.12 -> Pg=118.75, Qg=15.0
% INFO    : Gen at bus 7122	: Vg=1.03036 -> Vg=1.0
% INFO    : Gen at bus 7133	: Pg=45.54, Qg=5.69 -> Pg=65.18, Qg=15.0
% INFO    : Gen at bus 7133	: Vg=1.044129 -> Vg=1.0
% INFO    : Gen at bus 7137	: Pg=172.98, Qg=103.13 -> Pg=250.0, Qg=60.0
% INFO    : Gen at bus 7137	: Vg=1.062747 -> Vg=1.0
% INFO    : Gen at bus 7139	: Pg=17.8, Qg=10.21 -> Pg=55.935, Qg=10.0
% INFO    : Gen at bus 7139	: Vg=1.034631 -> Vg=1.0
% INFO    : Gen at bus 7142	: Pg=87.35, Qg=17.85 -> Pg=129.115, Qg=20.0
% INFO    : Gen at bus 7142	: Vg=1.033768 -> Vg=1.0
% INFO    : Gen at bus 7143	: Pg=8.74, Qg=0.02 -> Pg=52.915, Qg=0.0
% INFO    : Gen at bus 7143	: Vg=1.017775 -> Vg=1.0
% INFO    : Gen at bus 7146	: Pg=44.9, Qg=-0.09 -> Pg=64.965, Qg=20.0
% INFO    : Gen at bus 7146	: Vg=1.017024 -> Vg=1.0
% INFO    : Gen at bus 7148	: Pg=86.25, Qg=-3.04 -> Pg=128.75, Qg=-10.0
% INFO    : Gen at bus 7148	: Vg=0.962614 -> Vg=1.0
% INFO    : Gen at bus 7149	: Pg=85.0, Qg=-13.61 -> Pg=128.335, Qg=0.0
% INFO    : Gen at bus 7149	: Vg=0.969146 -> Vg=1.0
% INFO    : Gen at bus 7156	: Pg=38.18, Qg=10.06 -> Pg=62.725, Qg=10.0
% INFO    : Gen at bus 7156	: Vg=1.019539 -> Vg=1.0
% INFO    : Gen at bus 7159	: Pg=13.0, Qg=-2.26 -> Pg=54.335, Qg=0.0
% INFO    : Gen at bus 7159	: Vg=0.989224 -> Vg=1.0
% INFO    : Gen at bus 7163	: Pg=32.25, Qg=9.28 -> Pg=60.75, Qg=15.0
% INFO    : Gen at bus 7163	: Vg=1.025208 -> Vg=1.0
% INFO    : Gen at bus 7164	: Pg=34.96, Qg=12.97 -> Pg=61.655, Qg=10.0
% INFO    : Gen at bus 7164	: Vg=1.054937 -> Vg=1.0
% INFO    : Gen at bus 7168	: Pg=36.03, Qg=16.08 -> Pg=62.01, Qg=10.0
% INFO    : Gen at bus 7168	: Vg=1.045359 -> Vg=1.0
% INFO    : Gen at bus 7170	: Pg=112.0, Qg=-3.86 -> Pg=187.335, Qg=10.0
% INFO    : Gen at bus 7170	: Vg=0.989707 -> Vg=1.0
% INFO    : Gen at bus 7173	: Pg=88.32, Qg=56.36 -> Pg=129.44, Qg=20.0
% INFO    : Gen at bus 7173	: Vg=1.127961 -> Vg=1.0
% INFO    : Gen at bus 7178	: Pg=30.24, Qg=6.83 -> Pg=60.08, Qg=10.0
% INFO    : Gen at bus 7178	: Vg=1.037281 -> Vg=1.0
% INFO    : Gen at bus 7179	: Pg=95.28, Qg=12.14 -> Pg=131.76, Qg=15.0
% INFO    : Gen at bus 7179	: Vg=1.004576 -> Vg=1.0
% INFO    : Gen at bus 7183	: Pg=47.36, Qg=7.24 -> Pg=65.785, Qg=15.0
% INFO    : Gen at bus 7183	: Vg=1.026147 -> Vg=1.0
% INFO    : Gen at bus 7186	: Pg=6.38, Qg=-0.43 -> Pg=52.125, Qg=0.0
% INFO    : Gen at bus 7186	: Vg=0.962211 -> Vg=1.0
% INFO    : Gen at bus 7200	: Pg=47.36, Qg=7.24 -> Pg=65.785, Qg=15.0
% INFO    : Gen at bus 7200	: Vg=1.026147 -> Vg=1.0
% INFO    : Gen at bus 7213	: Pg=12.6, Qg=0.36 -> Pg=54.2, Qg=0.0
% INFO    : Gen at bus 7213	: Vg=1.014795 -> Vg=1.0
% INFO    : Gen at bus 7228	: Pg=32.43, Qg=17.87 -> Pg=60.81, Qg=10.0
% INFO    : Gen at bus 7228	: Vg=1.053647 -> Vg=1.0
% INFO    : Gen at bus 7233	: Pg=209.96, Qg=80.03 -> Pg=300.0, Qg=60.0
% INFO    : Gen at bus 7233	: Vg=1.038999 -> Vg=1.0
% INFO    : Gen at bus 7236	: Pg=23.91, Qg=3.61 -> Pg=57.97, Qg=10.0
% INFO    : Gen at bus 7236	: Vg=1.007821 -> Vg=1.0
% INFO    : Gen at bus 7240	: Pg=35.29, Qg=10.61 -> Pg=61.765, Qg=10.0
% INFO    : Gen at bus 7240	: Vg=1.043764 -> Vg=1.0
% INFO    : Gen at bus 7242	: Pg=31.92, Qg=6.07 -> Pg=60.64, Qg=10.0
% INFO    : Gen at bus 7242	: Vg=1.027264 -> Vg=1.0
% INFO    : Gen at bus 7243	: Pg=6.38, Qg=-2.2 -> Pg=52.125, Qg=0.0
% INFO    : Gen at bus 7243	: Vg=0.958146 -> Vg=1.0
% INFO    : Gen at bus 7249	: Pg=28.48, Qg=6.95 -> Pg=59.495, Qg=10.0
% INFO    : Gen at bus 7249	: Vg=1.005915 -> Vg=1.0
% INFO    : Gen at bus 7250	: Pg=19.82, Qg=3.12 -> Pg=56.605, Qg=5.0
% INFO    : Gen at bus 7250	: Vg=1.020233 -> Vg=1.0
% INFO    : Gen at bus 7252	: Pg=601.87, Qg=179.7 -> Pg=850.0, Qg=200.0
% INFO    : Gen at bus 7252	: Vg=1.037622 -> Vg=1.0
% INFO    : Gen at bus 7257	: Pg=25.0, Qg=4.2 -> Pg=58.335, Qg=5.0
% INFO    : Gen at bus 7257	: Vg=1.03161 -> Vg=1.0
% INFO    : Gen at bus 7261	: Pg=2.5, Qg=0.07 -> Pg=50.835, Qg=0.0
% INFO    : Gen at bus 7261	: Vg=0.984601 -> Vg=1.0
% INFO    : Gen at bus 7262	: Pg=100.89, Qg=15.27 -> Pg=183.63, Qg=20.0
% INFO    : Gen at bus 7262	: Vg=0.991024 -> Vg=1.0
% INFO    : Gen at bus 7267	: Pg=6.52, Qg=0.05 -> Pg=52.175, Qg=0.0
% INFO    : Gen at bus 7267	: Vg=0.996117 -> Vg=1.0
% INFO    : Gen at bus 7282	: Pg=6.96, Qg=1.26 -> Pg=52.32, Qg=0.0
% INFO    : Gen at bus 7282	: Vg=1.041421 -> Vg=1.0
% INFO    : Gen at bus 7289	: Pg=87.35, Qg=17.85 -> Pg=129.115, Qg=20.0
% INFO    : Gen at bus 7289	: Vg=1.033768 -> Vg=1.0
% INFO    : Gen at bus 7291	: Pg=24.37, Qg=4.5 -> Pg=58.125, Qg=10.0
% INFO    : Gen at bus 7291	: Vg=1.00571 -> Vg=1.0
% INFO    : Gen at bus 7297	: Pg=77.25, Qg=12.22 -> Pg=125.75, Qg=20.0
% INFO    : Gen at bus 7297	: Vg=1.034048 -> Vg=1.0
% INFO    : Gen at bus 7304	: Pg=56.25, Qg=11.12 -> Pg=118.75, Qg=15.0
% INFO    : Gen at bus 7304	: Vg=1.03036 -> Vg=1.0
% INFO    : Gen at bus 7317	: Pg=36.42, Qg=7.96 -> Pg=62.14, Qg=10.0
% INFO    : Gen at bus 7317	: Vg=1.029166 -> Vg=1.0
% INFO    : Gen at bus 7327	: Pg=158.9, Qg=39.46 -> Pg=250.0, Qg=35.0
% INFO    : Gen at bus 7327	: Vg=1.020032 -> Vg=1.0
% INFO    : Gen at bus 7329	: Pg=38.0, Qg=-2.61 -> Pg=62.665, Qg=0.0
% INFO    : Gen at bus 7329	: Vg=0.992436 -> Vg=1.0
% INFO    : Gen at bus 7333	: Pg=87.88, Qg=32.08 -> Pg=129.295, Qg=20.0
% INFO    : Gen at bus 7333	: Vg=1.042865 -> Vg=1.0
% INFO    : Gen at bus 7334	: Pg=218.81, Qg=74.1 -> Pg=300.0, Qg=80.0
% INFO    : Gen at bus 7334	: Vg=1.033239 -> Vg=1.0
% INFO    : Gen at bus 7338	: Pg=311.43, Qg=2.71 -> Pg=450.0, Qg=80.0
% INFO    : Gen at bus 7338	: Vg=0.999789 -> Vg=1.0
% INFO    : Gen at bus 7340	: Pg=159.8, Qg=16.39 -> Pg=250.0, Qg=25.0
% INFO    : Gen at bus 7340	: Vg=0.938623 -> Vg=1.0
% INFO    : Gen at bus 7342	: Pg=20.94, Qg=5.59 -> Pg=56.98, Qg=10.0
% INFO    : Gen at bus 7342	: Vg=1.044097 -> Vg=1.0
% INFO    : Gen at bus 7345	: Pg=3.7, Qg=0.68 -> Pg=51.235, Qg=0.0
% INFO    : Gen at bus 7345	: Vg=1.030841 -> Vg=1.0
% INFO    : Gen at bus 7346	: Pg=36.6, Qg=6.27 -> Pg=62.2, Qg=10.0
% INFO    : Gen at bus 7346	: Vg=1.027328 -> Vg=1.0
% INFO    : Gen at bus 7349	: Pg=35.22, Qg=5.06 -> Pg=61.74, Qg=10.0
% INFO    : Gen at bus 7349	: Vg=1.040292 -> Vg=1.0
% INFO    : Gen at bus 7350	: Pg=35.22, Qg=5.06 -> Pg=61.74, Qg=10.0
% INFO    : Gen at bus 7350	: Vg=1.040292 -> Vg=1.0
% INFO    : Gen at bus 7351	: Pg=96.03, Qg=17.22 -> Pg=132.01, Qg=20.0
% INFO    : Gen at bus 7351	: Vg=1.036065 -> Vg=1.0
% INFO    : Gen at bus 7352	: Pg=37.55, Qg=7.2 -> Pg=62.515, Qg=10.0
% INFO    : Gen at bus 7352	: Vg=1.029893 -> Vg=1.0
% INFO    : Gen at bus 7354	: Pg=677.41, Qg=27.58 -> Pg=900.0, Qg=200.0
% INFO    : Gen at bus 7354	: Vg=1.024274 -> Vg=1.0
% INFO    : Gen at bus 7356	: Pg=35.02, Qg=1.75 -> Pg=61.675, Qg=10.0
% INFO    : Gen at bus 7356	: Vg=1.038438 -> Vg=1.0
% INFO    : Gen at bus 7365	: Pg=36.91, Qg=13.33 -> Pg=62.305, Qg=10.0
% INFO    : Gen at bus 7365	: Vg=1.037973 -> Vg=1.0
% INFO    : Gen at bus 7369	: Pg=32.75, Qg=4.43 -> Pg=60.915, Qg=10.0
% INFO    : Gen at bus 7369	: Vg=1.005303 -> Vg=1.0
% INFO    : Gen at bus 7370	: Pg=33.64, Qg=5.18 -> Pg=61.215, Qg=10.0
% INFO    : Gen at bus 7370	: Vg=1.007216 -> Vg=1.0
% INFO    : Gen at bus 7371	: Pg=34.92, Qg=9.74 -> Pg=61.64, Qg=10.0
% INFO    : Gen at bus 7371	: Vg=1.043492 -> Vg=1.0
% INFO    : Gen at bus 7372	: Pg=33.64, Qg=5.18 -> Pg=61.215, Qg=10.0
% INFO    : Gen at bus 7372	: Vg=1.007216 -> Vg=1.0
% INFO    : Gen at bus 7374	: Pg=32.75, Qg=4.43 -> Pg=60.915, Qg=10.0
% INFO    : Gen at bus 7374	: Vg=1.005303 -> Vg=1.0
% INFO    : Gen at bus 7375	: Pg=32.75, Qg=4.43 -> Pg=60.915, Qg=10.0
% INFO    : Gen at bus 7375	: Vg=1.005303 -> Vg=1.0
% INFO    : Gen at bus 7376	: Pg=32.75, Qg=4.43 -> Pg=60.915, Qg=10.0
% INFO    : Gen at bus 7376	: Vg=1.005303 -> Vg=1.0
% INFO    : Gen at bus 7377	: Pg=29.93, Qg=6.22 -> Pg=59.975, Qg=15.0
% INFO    : Gen at bus 7377	: Vg=1.001397 -> Vg=1.0
% INFO    : Gen at bus 7378	: Pg=30.28, Qg=3.94 -> Pg=60.095, Qg=10.0
% INFO    : Gen at bus 7378	: Vg=1.004934 -> Vg=1.0
% INFO    : Gen at bus 7379	: Pg=30.28, Qg=3.94 -> Pg=60.095, Qg=10.0
% INFO    : Gen at bus 7379	: Vg=1.004934 -> Vg=1.0
% INFO    : Gen at bus 7381	: Pg=168.75, Qg=16.36 -> Pg=250.0, Qg=5.0
% INFO    : Gen at bus 7381	: Vg=0.976475 -> Vg=1.0
% INFO    : Gen at bus 7386	: Pg=42.41, Qg=17.68 -> Pg=64.135, Qg=20.0
% INFO    : Gen at bus 7386	: Vg=1.058287 -> Vg=1.0
% INFO    : Gen at bus 7388	: Pg=475.26, Qg=-51.2 -> Pg=650.0, Qg=200.0
% INFO    : Gen at bus 7388	: Vg=1.038881 -> Vg=1.0
% INFO    : Gen at bus 7391	: Pg=40.44, Qg=13.81 -> Pg=63.48, Qg=15.0
% INFO    : Gen at bus 7391	: Vg=1.025019 -> Vg=1.0
% INFO    : Gen at bus 7392	: Pg=38.16, Qg=4.12 -> Pg=62.72, Qg=10.0
% INFO    : Gen at bus 7392	: Vg=1.055337 -> Vg=1.0
% INFO    : Gen at bus 7416	: Pg=18.4, Qg=-1.01 -> Pg=56.135, Qg=0.0
% INFO    : Gen at bus 7416	: Vg=1.003342 -> Vg=1.0
% INFO    : Gen at bus 7426	: Pg=279.66, Qg=54.13 -> Pg=350.0, Qg=80.0
% INFO    : Gen at bus 7426	: Vg=1.030874 -> Vg=1.0
% INFO    : Gen at bus 7428	: Pg=38.56, Qg=8.03 -> Pg=62.855, Qg=10.0
% INFO    : Gen at bus 7428	: Vg=1.049495 -> Vg=1.0
% INFO    : Gen at bus 7430	: Pg=25.6, Qg=-1.25 -> Pg=58.535, Qg=0.0
% INFO    : Gen at bus 7430	: Vg=0.991002 -> Vg=1.0
% INFO    : Gen at bus 7447	: Pg=38.79, Qg=7.11 -> Pg=62.93, Qg=10.0
% INFO    : Gen at bus 7447	: Vg=1.035838 -> Vg=1.0
% INFO    : Gen at bus 7449	: Pg=240.6, Qg=61.27 -> Pg=300.0, Qg=35.0
% INFO    : Gen at bus 7449	: Vg=0.990475 -> Vg=1.0
% INFO    : Gen at bus 7452	: Pg=53.72, Qg=11.91 -> Pg=117.905, Qg=15.0
% INFO    : Gen at bus 7452	: Vg=1.035023 -> Vg=1.0
% INFO    : Gen at bus 7470	: Pg=841.6, Qg=252.59 -> Pg=1100.0, Qg=200.0
% INFO    : Gen at bus 7470	: Vg=1.060213 -> Vg=1.0
% INFO    : Gen at bus 7473	: Pg=23.5, Qg=6.96 -> Pg=57.835, Qg=5.0
% INFO    : Gen at bus 7473	: Vg=1.015521 -> Vg=1.0
% INFO    : Gen at bus 7474	: Pg=34.17, Qg=11.11 -> Pg=61.39, Qg=10.0
% INFO    : Gen at bus 7474	: Vg=1.015682 -> Vg=1.0
% INFO    : Gen at bus 7475	: Pg=35.29, Qg=10.61 -> Pg=61.765, Qg=10.0
% INFO    : Gen at bus 7475	: Vg=1.043764 -> Vg=1.0
% INFO    : Gen at bus 7476	: Pg=262.4, Qg=19.68 -> Pg=350.0, Qg=60.0
% INFO    : Gen at bus 7476	: Vg=1.015161 -> Vg=1.0
% INFO    : Gen at bus 7477	: Pg=262.4, Qg=19.68 -> Pg=350.0, Qg=60.0
% INFO    : Gen at bus 7477	: Vg=1.015161 -> Vg=1.0
% INFO    : Gen at bus 7487	: Pg=45.0, Qg=9.88 -> Pg=65.0, Qg=10.0
% INFO    : Gen at bus 7487	: Vg=1.031445 -> Vg=1.0
% INFO    : Gen at bus 7489	: Pg=261.4, Qg=37.15 -> Pg=350.0, Qg=35.0
% INFO    : Gen at bus 7489	: Vg=0.969605 -> Vg=1.0
% INFO    : Gen at bus 7490	: Pg=31.89, Qg=4.43 -> Pg=60.63, Qg=10.0
% INFO    : Gen at bus 7490	: Vg=1.028453 -> Vg=1.0
% INFO    : Gen at bus 7498	: Pg=78.62, Qg=8.98 -> Pg=126.205, Qg=20.0
% INFO    : Gen at bus 7498	: Vg=1.056333 -> Vg=1.0
% INFO    : Gen at bus 7499	: Pg=97.57, Qg=36.99 -> Pg=132.525, Qg=20.0
% INFO    : Gen at bus 7499	: Vg=1.074058 -> Vg=1.0
% INFO    : Gen at bus 7501	: Pg=25.54, Qg=8.34 -> Pg=58.515, Qg=10.0
% INFO    : Gen at bus 7501	: Vg=1.050494 -> Vg=1.0
% INFO    : Gen at bus 7502	: Pg=18.52, Qg=11.72 -> Pg=56.175, Qg=10.0
% INFO    : Gen at bus 7502	: Vg=1.044704 -> Vg=1.0
% INFO    : Gen at bus 7504	: Pg=18.52, Qg=11.72 -> Pg=56.175, Qg=10.0
% INFO    : Gen at bus 7504	: Vg=1.044704 -> Vg=1.0
% INFO    : Gen at bus 7505	: Pg=18.76, Qg=6.31 -> Pg=56.255, Qg=10.0
% INFO    : Gen at bus 7505	: Vg=1.033648 -> Vg=1.0
% INFO    : Gen at bus 7507	: Pg=25.54, Qg=8.34 -> Pg=58.515, Qg=10.0
% INFO    : Gen at bus 7507	: Vg=1.050494 -> Vg=1.0
% INFO    : Gen at bus 7508	: Pg=27.56, Qg=15.15 -> Pg=59.185, Qg=10.0
% INFO    : Gen at bus 7508	: Vg=1.036203 -> Vg=1.0
% INFO    : Gen at bus 7511	: Pg=164.92, Qg=6.67 -> Pg=250.0, Qg=60.0
% INFO    : Gen at bus 7511	: Vg=1.016367 -> Vg=1.0
% INFO    : Gen at bus 7512	: Pg=32.57, Qg=7.29 -> Pg=60.855, Qg=10.0
% INFO    : Gen at bus 7512	: Vg=1.041748 -> Vg=1.0
% INFO    : Gen at bus 7513	: Pg=20.93, Qg=2.5 -> Pg=56.975, Qg=10.0
% INFO    : Gen at bus 7513	: Vg=1.050204 -> Vg=1.0
% INFO    : Gen at bus 7523	: Pg=88.45, Qg=51.85 -> Pg=129.485, Qg=20.0
% INFO    : Gen at bus 7523	: Vg=1.046478 -> Vg=1.0
% INFO    : Gen at bus 7524	: Pg=88.45, Qg=51.85 -> Pg=129.485, Qg=20.0
% INFO    : Gen at bus 7524	: Vg=1.046478 -> Vg=1.0
% INFO    : Gen at bus 7526	: Pg=88.45, Qg=51.85 -> Pg=129.485, Qg=20.0
% INFO    : Gen at bus 7526	: Vg=1.046478 -> Vg=1.0
% INFO    : Gen at bus 7528	: Pg=88.45, Qg=51.85 -> Pg=129.485, Qg=20.0
% INFO    : Gen at bus 7528	: Vg=1.046478 -> Vg=1.0
% INFO    : Gen at bus 7531	: Pg=279.13, Qg=130.91 -> Pg=350.0, Qg=80.0
% INFO    : Gen at bus 7531	: Vg=1.048637 -> Vg=1.0
% INFO    : Gen at bus 7535	: Pg=138.8, Qg=17.14 -> Pg=196.265, Qg=40.0
% INFO    : Gen at bus 7535	: Vg=1.04554 -> Vg=1.0
% INFO    : Gen at bus 7539	: Pg=92.69, Qg=14.48 -> Pg=130.895, Qg=20.0
% INFO    : Gen at bus 7539	: Vg=1.026207 -> Vg=1.0
% INFO    : Gen at bus 7540	: Pg=37.03, Qg=8.4 -> Pg=62.345, Qg=10.0
% INFO    : Gen at bus 7540	: Vg=1.016705 -> Vg=1.0
% INFO    : Gen at bus 7544	: Pg=86.41, Qg=23.5 -> Pg=128.805, Qg=20.0
% INFO    : Gen at bus 7544	: Vg=1.031898 -> Vg=1.0
% INFO    : Gen at bus 7547	: Pg=20.37, Qg=8.85 -> Pg=56.79, Qg=10.0
% INFO    : Gen at bus 7547	: Vg=1.045375 -> Vg=1.0
% INFO    : Gen at bus 7551	: Pg=98.62, Qg=18.17 -> Pg=132.875, Qg=20.0
% INFO    : Gen at bus 7551	: Vg=1.044493 -> Vg=1.0
% INFO    : Gen at bus 7556	: Pg=94.5, Qg=8.92 -> Pg=131.5, Qg=5.0
% INFO    : Gen at bus 7556	: Vg=0.979015 -> Vg=1.0
% INFO    : Gen at bus 7557	: Pg=40.51, Qg=5.96 -> Pg=63.505, Qg=10.0
% INFO    : Gen at bus 7557	: Vg=1.017287 -> Vg=1.0
% INFO    : Gen at bus 7558	: Pg=40.51, Qg=5.96 -> Pg=63.505, Qg=10.0
% INFO    : Gen at bus 7558	: Vg=1.017287 -> Vg=1.0
% INFO    : Gen at bus 7559	: Pg=40.51, Qg=5.96 -> Pg=63.505, Qg=10.0
% INFO    : Gen at bus 7559	: Vg=1.017287 -> Vg=1.0
% INFO    : Gen at bus 7560	: Pg=40.51, Qg=5.96 -> Pg=63.505, Qg=10.0
% INFO    : Gen at bus 7560	: Vg=1.017287 -> Vg=1.0
% INFO    : Gen at bus 7561	: Pg=89.66, Qg=46.76 -> Pg=129.885, Qg=20.0
% INFO    : Gen at bus 7561	: Vg=1.050891 -> Vg=1.0
% INFO    : Gen at bus 7562	: Pg=22.13, Qg=3.21 -> Pg=57.375, Qg=10.0
% INFO    : Gen at bus 7562	: Vg=1.026207 -> Vg=1.0
% INFO    : Gen at bus 7563	: Pg=22.13, Qg=3.21 -> Pg=57.375, Qg=10.0
% INFO    : Gen at bus 7563	: Vg=1.026207 -> Vg=1.0
% INFO    : Gen at bus 7564	: Pg=17.96, Qg=1.67 -> Pg=55.985, Qg=10.0
% INFO    : Gen at bus 7564	: Vg=1.048808 -> Vg=1.0
% INFO    : Gen at bus 7568	: Pg=31.0, Qg=0.14 -> Pg=60.335, Qg=0.0
% INFO    : Gen at bus 7568	: Vg=1.000449 -> Vg=1.0
% INFO    : Gen at bus 7577	: Pg=17.6, Qg=0.07 -> Pg=55.865, Qg=0.0
% INFO    : Gen at bus 7577	: Vg=0.977562 -> Vg=1.0
% INFO    : Gen at bus 7585	: Pg=31.3, Qg=-0.89 -> Pg=60.435, Qg=0.0
% INFO    : Gen at bus 7585	: Vg=0.998951 -> Vg=1.0
% INFO    : Gen at bus 7593	: Pg=172.2, Qg=56.31 -> Pg=250.0, Qg=35.0
% INFO    : Gen at bus 7593	: Vg=0.999494 -> Vg=1.0
% INFO    : Gen at bus 7598	: Pg=77.03, Qg=9.29 -> Pg=125.675, Qg=20.0
% INFO    : Gen at bus 7598	: Vg=1.039863 -> Vg=1.0
% INFO    : Gen at bus 7599	: Pg=92.1, Qg=33.68 -> Pg=130.7, Qg=20.0
% INFO    : Gen at bus 7599	: Vg=1.056697 -> Vg=1.0
% INFO    : Gen at bus 7600	: Pg=50.34, Qg=9.17 -> Pg=116.78, Qg=15.0
% INFO    : Gen at bus 7600	: Vg=1.034532 -> Vg=1.0
% INFO    : Gen at bus 7613	: Pg=20.21, Qg=8.41 -> Pg=56.735, Qg=10.0
% INFO    : Gen at bus 7613	: Vg=1.012556 -> Vg=1.0
% INFO    : Gen at bus 7625	: Pg=35.74, Qg=6.84 -> Pg=61.915, Qg=10.0
% INFO    : Gen at bus 7625	: Vg=1.040138 -> Vg=1.0
% INFO    : Gen at bus 7628	: Pg=87.95, Qg=47.73 -> Pg=129.315, Qg=20.0
% INFO    : Gen at bus 7628	: Vg=1.052257 -> Vg=1.0
% INFO    : Gen at bus 7634	: Pg=25.22, Qg=5.17 -> Pg=58.405, Qg=10.0
% INFO    : Gen at bus 7634	: Vg=1.04616 -> Vg=1.0
% INFO    : Gen at bus 7636	: Pg=32.57, Qg=6.62 -> Pg=60.855, Qg=10.0
% INFO    : Gen at bus 7636	: Vg=1.059142 -> Vg=1.0
% INFO    : Gen at bus 7637	: Pg=32.57, Qg=6.62 -> Pg=60.855, Qg=10.0
% INFO    : Gen at bus 7637	: Vg=1.059142 -> Vg=1.0
% INFO    : Gen at bus 7639	: Pg=7.32, Qg=2.26 -> Pg=52.44, Qg=0.0
% INFO    : Gen at bus 7639	: Vg=1.005118 -> Vg=1.0
% INFO    : Gen at bus 7640	: Pg=-1344.4, Qg=409.68 -> Pg=-846.265, Qg=0.0
% INFO    : Gen at bus 7640	: Vg=1.020355 -> Vg=1.0
% INFO    : Gen at bus 7641	: Pg=36.8, Qg=-2.54 -> Pg=62.265, Qg=0.0
% INFO    : Gen at bus 7641	: Vg=0.98379 -> Vg=1.0
% INFO    : Gen at bus 7643	: Pg=138.8, Qg=-2.57 -> Pg=196.265, Qg=40.0
% INFO    : Gen at bus 7643	: Vg=0.989847 -> Vg=1.0
% INFO    : Gen at bus 7645	: Pg=279.66, Qg=54.1 -> Pg=350.0, Qg=80.0
% INFO    : Gen at bus 7645	: Vg=1.030879 -> Vg=1.0
% INFO    : Gen at bus 7648	: Pg=279.66, Qg=54.1 -> Pg=350.0, Qg=80.0
% INFO    : Gen at bus 7648	: Vg=1.030879 -> Vg=1.0
% INFO    : Gen at bus 7649	: Pg=279.66, Qg=54.1 -> Pg=350.0, Qg=80.0
% INFO    : Gen at bus 7649	: Vg=1.030879 -> Vg=1.0
% INFO    : Gen at bus 7654	: Pg=204.59, Qg=110.18 -> Pg=300.0, Qg=80.0
% INFO    : Gen at bus 7654	: Vg=1.065374 -> Vg=1.0
% INFO    : Gen at bus 7662	: Pg=240.6, Qg=61.33 -> Pg=300.0, Qg=35.0
% INFO    : Gen at bus 7662	: Vg=0.990464 -> Vg=1.0
% INFO    : Gen at bus 7667	: Pg=100.41, Qg=11.92 -> Pg=183.47, Qg=20.0
% INFO    : Gen at bus 7667	: Vg=1.038747 -> Vg=1.0
% INFO    : Gen at bus 7668	: Pg=31.3, Qg=-0.77 -> Pg=60.435, Qg=10.0
% INFO    : Gen at bus 7668	: Vg=1.018739 -> Vg=1.0
% INFO    : Gen at bus 7670	: Pg=81.04, Qg=47.11 -> Pg=127.015, Qg=20.0
% INFO    : Gen at bus 7670	: Vg=1.043163 -> Vg=1.0
% INFO    : Gen at bus 7671	: Pg=81.04, Qg=47.11 -> Pg=127.015, Qg=20.0
% INFO    : Gen at bus 7671	: Vg=1.043163 -> Vg=1.0
% INFO    : Gen at bus 7672	: Pg=81.04, Qg=47.11 -> Pg=127.015, Qg=20.0
% INFO    : Gen at bus 7672	: Vg=1.043163 -> Vg=1.0
% INFO    : Gen at bus 7674	: Pg=293.92, Qg=111.78 -> Pg=350.0, Qg=80.0
% INFO    : Gen at bus 7674	: Vg=1.039038 -> Vg=1.0
% INFO    : Gen at bus 7675	: Pg=72.73, Qg=50.32 -> Pg=124.245, Qg=20.0
% INFO    : Gen at bus 7675	: Vg=1.038621 -> Vg=1.0
% INFO    : Gen at bus 7676	: Pg=72.73, Qg=50.32 -> Pg=124.245, Qg=20.0
% INFO    : Gen at bus 7676	: Vg=1.038621 -> Vg=1.0
% INFO    : Gen at bus 7677	: Pg=21.5, Qg=5.52 -> Pg=57.165, Qg=5.0
% INFO    : Gen at bus 7677	: Vg=1.012381 -> Vg=1.0
% INFO    : Gen at bus 7681	: Pg=167.4, Qg=-8.63 -> Pg=250.0, Qg=10.0
% INFO    : Gen at bus 7681	: Vg=0.948759 -> Vg=1.0
% INFO    : Gen at bus 7689	: Pg=37.29, Qg=8.19 -> Pg=62.43, Qg=10.0
% INFO    : Gen at bus 7689	: Vg=1.030566 -> Vg=1.0
% INFO    : Gen at bus 7700	: Pg=23.9, Qg=3.61 -> Pg=57.965, Qg=10.0
% INFO    : Gen at bus 7700	: Vg=1.007844 -> Vg=1.0
% INFO    : Gen at bus 7705	: Pg=27.37, Qg=1.37 -> Pg=59.125, Qg=5.0
% INFO    : Gen at bus 7705	: Vg=1.005763 -> Vg=1.0
% INFO    : Gen at bus 7707	: Pg=51.5, Qg=-7.54 -> Pg=117.165, Qg=0.0
% INFO    : Gen at bus 7707	: Vg=0.954584 -> Vg=1.0
% INFO    : Gen at bus 7712	: Pg=20.79, Qg=7.32 -> Pg=56.93, Qg=10.0
% INFO    : Gen at bus 7712	: Vg=1.033848 -> Vg=1.0
% INFO    : Gen at bus 7716	: Pg=79.8, Qg=19.8 -> Pg=126.6, Qg=20.0
% INFO    : Gen at bus 7716	: Vg=1.02806 -> Vg=1.0
% INFO    : Gen at bus 7717	: Pg=79.8, Qg=19.8 -> Pg=126.6, Qg=20.0
% INFO    : Gen at bus 7717	: Vg=1.02806 -> Vg=1.0
% INFO    : Gen at bus 7719	: Pg=79.8, Qg=19.8 -> Pg=126.6, Qg=20.0
% INFO    : Gen at bus 7719	: Vg=1.02806 -> Vg=1.0
% INFO    : Gen at bus 7721	: Pg=79.8, Qg=19.8 -> Pg=126.6, Qg=20.0
% INFO    : Gen at bus 7721	: Vg=1.02806 -> Vg=1.0
% INFO    : Gen at bus 7722	: Pg=79.8, Qg=19.8 -> Pg=126.6, Qg=20.0
% INFO    : Gen at bus 7722	: Vg=1.02806 -> Vg=1.0
% INFO    : Gen at bus 7731	: Pg=0.83, Qg=-0.07 -> Pg=50.275, Qg=0.0
% INFO    : Gen at bus 7731	: Vg=1.015733 -> Vg=1.0
% INFO    : Gen at bus 7732	: Pg=19.93, Qg=2.39 -> Pg=56.645, Qg=10.0
% INFO    : Gen at bus 7732	: Vg=1.050328 -> Vg=1.0
% INFO    : Gen at bus 7734	: Pg=31.6, Qg=11.6 -> Pg=60.535, Qg=10.0
% INFO    : Gen at bus 7734	: Vg=1.04043 -> Vg=1.0
% INFO    : Gen at bus 7736	: Pg=362.93, Qg=192.92 -> Pg=500.0, Qg=80.0
% INFO    : Gen at bus 7736	: Vg=1.064843 -> Vg=1.0
% INFO    : Gen at bus 7740	: Pg=35.5, Qg=10.89 -> Pg=61.835, Qg=10.0
% INFO    : Gen at bus 7740	: Vg=1.045213 -> Vg=1.0
% INFO    : Gen at bus 7742	: Pg=30.0, Qg=5.12 -> Pg=60.0, Qg=5.0
% INFO    : Gen at bus 7742	: Vg=1.022262 -> Vg=1.0
% INFO    : Gen at bus 7743	: Pg=159.8, Qg=33.64 -> Pg=250.0, Qg=25.0
% INFO    : Gen at bus 7743	: Vg=0.993125 -> Vg=1.0
% INFO    : Gen at bus 7750	: Pg=159.8, Qg=20.91 -> Pg=250.0, Qg=30.0
% INFO    : Gen at bus 7750	: Vg=1.008982 -> Vg=1.0
% INFO    : Gen at bus 7751	: Pg=135.0, Qg=10.29 -> Pg=195.0, Qg=25.0
% INFO    : Gen at bus 7751	: Vg=1.008348 -> Vg=1.0
% INFO    : Gen at bus 7754	: Pg=88.85, Qg=23.49 -> Pg=129.615, Qg=20.0
% INFO    : Gen at bus 7754	: Vg=1.032344 -> Vg=1.0
% INFO    : Gen at bus 7768	: Pg=9.0, Qg=0.68 -> Pg=53.0, Qg=0.0
% INFO    : Gen at bus 7768	: Vg=1.011648 -> Vg=1.0
% INFO    : Gen at bus 7776	: Pg=617.47, Qg=92.14 -> Pg=850.0, Qg=200.0
% INFO    : Gen at bus 7776	: Vg=1.032321 -> Vg=1.0
% INFO    : Gen at bus 7777	: Pg=17.5, Qg=5.36 -> Pg=55.835, Qg=5.0
% INFO    : Gen at bus 7777	: Vg=1.009853 -> Vg=1.0
% INFO    : Gen at bus 7784	: Pg=95.02, Qg=8.09 -> Pg=131.675, Qg=20.0
% INFO    : Gen at bus 7784	: Vg=1.023144 -> Vg=1.0
% INFO    : Gen at bus 7808	: Pg=224.46, Qg=15.93 -> Pg=300.0, Qg=80.0
% INFO    : Gen at bus 7808	: Vg=1.031165 -> Vg=1.0
% INFO    : Gen at bus 7812	: Pg=25.75, Qg=4.04 -> Pg=58.585, Qg=10.0
% INFO    : Gen at bus 7812	: Vg=1.026025 -> Vg=1.0
% INFO    : Gen at bus 7814	: Pg=212.35, Qg=111.47 -> Pg=300.0, Qg=60.0
% INFO    : Gen at bus 7814	: Vg=1.064355 -> Vg=1.0
% INFO    : Gen at bus 7825	: Pg=20.25, Qg=1.86 -> Pg=56.75, Qg=5.0
% INFO    : Gen at bus 7825	: Vg=1.027844 -> Vg=1.0
% INFO    : Gen at bus 7833	: Pg=262.9, Qg=48.53 -> Pg=350.0, Qg=60.0
% INFO    : Gen at bus 7833	: Vg=1.027461 -> Vg=1.0
% INFO    : Gen at bus 7841	: Pg=25.27, Qg=3.21 -> Pg=58.425, Qg=10.0
% INFO    : Gen at bus 7841	: Vg=1.006944 -> Vg=1.0
% INFO    : Gen at bus 7842	: Pg=33.61, Qg=7.79 -> Pg=61.205, Qg=10.0
% INFO    : Gen at bus 7842	: Vg=1.005097 -> Vg=1.0
% INFO    : Gen at bus 7844	: Pg=46.38, Qg=17.23 -> Pg=65.46, Qg=15.0
% INFO    : Gen at bus 7844	: Vg=1.048358 -> Vg=1.0
% INFO    : Gen at bus 7846	: Pg=46.38, Qg=17.23 -> Pg=65.46, Qg=15.0
% INFO    : Gen at bus 7846	: Vg=1.048358 -> Vg=1.0
% INFO    : Gen at bus 7847	: Pg=40.23, Qg=5.24 -> Pg=63.41, Qg=10.0
% INFO    : Gen at bus 7847	: Vg=1.006137 -> Vg=1.0
% INFO    : Gen at bus 7848	: Pg=33.61, Qg=7.79 -> Pg=61.205, Qg=10.0
% INFO    : Gen at bus 7848	: Vg=1.005097 -> Vg=1.0
% INFO    : Gen at bus 7849	: Pg=269.64, Qg=16.27 -> Pg=350.0, Qg=80.0
% INFO    : Gen at bus 7849	: Vg=1.041549 -> Vg=1.0
% INFO    : Gen at bus 7851	: Pg=33.61, Qg=7.79 -> Pg=61.205, Qg=10.0
% INFO    : Gen at bus 7851	: Vg=1.005097 -> Vg=1.0
% INFO    : Gen at bus 7857	: Pg=8.4, Qg=0.33 -> Pg=52.8, Qg=0.0
% INFO    : Gen at bus 7857	: Vg=1.014368 -> Vg=1.0
% INFO    : Gen at bus 7858	: Pg=36.91, Qg=13.33 -> Pg=62.305, Qg=10.0
% INFO    : Gen at bus 7858	: Vg=1.037973 -> Vg=1.0
% INFO    : Gen at bus 7859	: Pg=24.84, Qg=4.52 -> Pg=58.28, Qg=10.0
% INFO    : Gen at bus 7859	: Vg=1.022099 -> Vg=1.0
% INFO    : Gen at bus 7875	: Pg=38.16, Qg=4.12 -> Pg=62.72, Qg=10.0
% INFO    : Gen at bus 7875	: Vg=1.055337 -> Vg=1.0
% INFO    : Gen at bus 7877	: Pg=6.52, Qg=0.05 -> Pg=52.175, Qg=0.0
% INFO    : Gen at bus 7877	: Vg=0.996117 -> Vg=1.0
% INFO    : Gen at bus 7890	: Pg=36.11, Qg=3.87 -> Pg=62.035, Qg=10.0
% INFO    : Gen at bus 7890	: Vg=1.024544 -> Vg=1.0
% INFO    : Gen at bus 7899	: Pg=31.98, Qg=14.6 -> Pg=60.66, Qg=10.0
% INFO    : Gen at bus 7899	: Vg=1.034118 -> Vg=1.0
% INFO    : Gen at bus 7901	: Pg=39.83, Qg=14.7 -> Pg=63.275, Qg=10.0
% INFO    : Gen at bus 7901	: Vg=1.037128 -> Vg=1.0
% INFO    : Gen at bus 7902	: Pg=39.83, Qg=14.7 -> Pg=63.275, Qg=10.0
% INFO    : Gen at bus 7902	: Vg=1.037128 -> Vg=1.0
% INFO    : Gen at bus 7903	: Pg=26.6, Qg=10.01 -> Pg=58.865, Qg=10.0
% INFO    : Gen at bus 7903	: Vg=1.016718 -> Vg=1.0
% INFO    : Gen at bus 7904	: Pg=26.6, Qg=10.01 -> Pg=58.865, Qg=10.0
% INFO    : Gen at bus 7904	: Vg=1.016718 -> Vg=1.0
% INFO    : Gen at bus 7905	: Pg=24.89, Qg=5.96 -> Pg=58.295, Qg=10.0
% INFO    : Gen at bus 7905	: Vg=1.042846 -> Vg=1.0
% INFO    : Gen at bus 7908	: Pg=26.6, Qg=10.01 -> Pg=58.865, Qg=10.0
% INFO    : Gen at bus 7908	: Vg=1.016718 -> Vg=1.0
% INFO    : Gen at bus 7918	: Pg=6.52, Qg=-0.06 -> Pg=52.175, Qg=0.0
% INFO    : Gen at bus 7918	: Vg=0.994601 -> Vg=1.0
% INFO    : Gen at bus 7921	: Pg=14.0, Qg=3.19 -> Pg=54.665, Qg=5.0
% INFO    : Gen at bus 7921	: Vg=1.023478 -> Vg=1.0
% INFO    : Gen at bus 7925	: Pg=266.84, Qg=38.78 -> Pg=350.0, Qg=80.0
% INFO    : Gen at bus 7925	: Vg=1.032265 -> Vg=1.0
% INFO    : Gen at bus 7929	: Pg=321.29, Qg=105.87 -> Pg=450.0, Qg=80.0
% INFO    : Gen at bus 7929	: Vg=1.034412 -> Vg=1.0
% INFO    : Gen at bus 7930	: Pg=366.21, Qg=205.07 -> Pg=500.0, Qg=80.0
% INFO    : Gen at bus 7930	: Vg=1.129641 -> Vg=1.0
% INFO    : Gen at bus 7931	: Pg=27.81, Qg=6.76 -> Pg=59.27, Qg=10.0
% INFO    : Gen at bus 7931	: Vg=1.026444 -> Vg=1.0
% INFO    : Gen at bus 7932	: Pg=31.89, Qg=4.43 -> Pg=60.63, Qg=10.0
% INFO    : Gen at bus 7932	: Vg=1.028453 -> Vg=1.0
% INFO    : Gen at bus 7933	: Pg=33.19, Qg=5.48 -> Pg=61.065, Qg=10.0
% INFO    : Gen at bus 7933	: Vg=0.991806 -> Vg=1.0
% INFO    : Gen at bus 7939	: Pg=28.83, Qg=4.62 -> Pg=59.61, Qg=10.0
% INFO    : Gen at bus 7939	: Vg=1.019144 -> Vg=1.0
% INFO    : Gen at bus 7943	: Pg=31.89, Qg=4.43 -> Pg=60.63, Qg=10.0
% INFO    : Gen at bus 7943	: Vg=1.028453 -> Vg=1.0
% INFO    : Gen at bus 7946	: Pg=27.67, Qg=4.45 -> Pg=59.225, Qg=10.0
% INFO    : Gen at bus 7946	: Vg=1.027132 -> Vg=1.0
% INFO    : Gen at bus 7949	: Pg=30.0, Qg=2.24 -> Pg=60.0, Qg=5.0
% INFO    : Gen at bus 7949	: Vg=1.02542 -> Vg=1.0
% INFO    : Gen at bus 7951	: Pg=39.96, Qg=4.13 -> Pg=63.32, Qg=10.0
% INFO    : Gen at bus 7951	: Vg=0.987171 -> Vg=1.0
% INFO    : Gen at bus 7962	: Pg=3.02, Qg=0.33 -> Pg=51.01, Qg=0.0
% INFO    : Gen at bus 7962	: Vg=1.03013 -> Vg=1.0
% INFO    : Gen at bus 7965	: Pg=87.88, Qg=32.08 -> Pg=129.295, Qg=20.0
% INFO    : Gen at bus 7965	: Vg=1.042865 -> Vg=1.0
% INFO    : Gen at bus 7966	: Pg=87.88, Qg=32.08 -> Pg=129.295, Qg=20.0
% INFO    : Gen at bus 7966	: Vg=1.042865 -> Vg=1.0
% INFO    : Gen at bus 7967	: Pg=45.28, Qg=10.84 -> Pg=65.095, Qg=15.0
% INFO    : Gen at bus 7967	: Vg=1.043738 -> Vg=1.0
% INFO    : Gen at bus 7970	: Pg=80.4, Qg=12.89 -> Pg=126.8, Qg=20.0
% INFO    : Gen at bus 7970	: Vg=1.045647 -> Vg=1.0
% INFO    : Gen at bus 7976	: Pg=30.24, Qg=9.06 -> Pg=60.08, Qg=10.0
% INFO    : Gen at bus 7976	: Vg=1.012031 -> Vg=1.0
% INFO    : Gen at bus 7979	: Pg=53.72, Qg=11.91 -> Pg=117.905, Qg=15.0
% INFO    : Gen at bus 7979	: Vg=1.035023 -> Vg=1.0
% INFO    : Gen at bus 7981	: Pg=53.72, Qg=11.91 -> Pg=117.905, Qg=15.0
% INFO    : Gen at bus 7981	: Vg=1.035023 -> Vg=1.0
% INFO    : Gen at bus 7988	: Pg=53.72, Qg=11.91 -> Pg=117.905, Qg=15.0
% INFO    : Gen at bus 7988	: Vg=1.035023 -> Vg=1.0
% INFO    : Gen at bus 7989	: Pg=53.72, Qg=11.91 -> Pg=117.905, Qg=15.0
% INFO    : Gen at bus 7989	: Vg=1.035023 -> Vg=1.0
% INFO    : Gen at bus 7992	: Pg=34.6, Qg=7.46 -> Pg=61.535, Qg=10.0
% INFO    : Gen at bus 7992	: Vg=1.041485 -> Vg=1.0
% INFO    : Gen at bus 7993	: Pg=34.6, Qg=7.46 -> Pg=61.535, Qg=10.0
% INFO    : Gen at bus 7993	: Vg=1.041485 -> Vg=1.0
% INFO    : Gen at bus 7995	: Pg=24.22, Qg=5.78 -> Pg=58.075, Qg=10.0
% INFO    : Gen at bus 7995	: Vg=1.029709 -> Vg=1.0
% INFO    : Gen at bus 7998	: Pg=3.4, Qg=-0.83 -> Pg=51.135, Qg=0.0
% INFO    : Gen at bus 7998	: Vg=0.9865 -> Vg=1.0
% INFO    : Gen at bus 8000	: Pg=24.22, Qg=5.78 -> Pg=58.075, Qg=10.0
% INFO    : Gen at bus 8000	: Vg=1.029709 -> Vg=1.0
% INFO    : Gen at bus 8001	: Pg=24.22, Qg=5.78 -> Pg=58.075, Qg=10.0
% INFO    : Gen at bus 8001	: Vg=1.029709 -> Vg=1.0
% INFO    : Gen at bus 8010	: Pg=18.5, Qg=0.5 -> Pg=56.165, Qg=0.0
% INFO    : Gen at bus 8010	: Vg=0.981441 -> Vg=1.0
% INFO    : Gen at bus 8017	: Pg=87.95, Qg=47.73 -> Pg=129.315, Qg=20.0
% INFO    : Gen at bus 8017	: Vg=1.052257 -> Vg=1.0
% INFO    : Gen at bus 8021	: Pg=87.95, Qg=47.73 -> Pg=129.315, Qg=20.0
% INFO    : Gen at bus 8021	: Vg=1.052257 -> Vg=1.0
% INFO    : Gen at bus 8022	: Pg=87.95, Qg=47.73 -> Pg=129.315, Qg=20.0
% INFO    : Gen at bus 8022	: Vg=1.052257 -> Vg=1.0
% INFO    : Gen at bus 8023	: Pg=43.6, Qg=4.09 -> Pg=64.535, Qg=0.0
% INFO    : Gen at bus 8023	: Vg=0.9595 -> Vg=1.0
% INFO    : Gen at bus 8033	: Pg=75.6, Qg=-2.95 -> Pg=125.2, Qg=5.0
% INFO    : Gen at bus 8033	: Vg=1.010732 -> Vg=1.0
% INFO    : Gen at bus 8039	: Pg=18.13, Qg=3.85 -> Pg=56.045, Qg=10.0
% INFO    : Gen at bus 8039	: Vg=1.016716 -> Vg=1.0
% INFO    : Gen at bus 8053	: Pg=31.89, Qg=4.43 -> Pg=60.63, Qg=10.0
% INFO    : Gen at bus 8053	: Vg=1.028453 -> Vg=1.0
% INFO    : Gen at bus 8055	: Pg=31.89, Qg=4.43 -> Pg=60.63, Qg=10.0
% INFO    : Gen at bus 8055	: Vg=1.028453 -> Vg=1.0
% INFO    : Gen at bus 8056	: Pg=31.89, Qg=4.43 -> Pg=60.63, Qg=10.0
% INFO    : Gen at bus 8056	: Vg=1.028453 -> Vg=1.0
% INFO    : Gen at bus 8060	: Pg=45.0, Qg=-3.79 -> Pg=65.0, Qg=0.0
% INFO    : Gen at bus 8060	: Vg=0.939142 -> Vg=1.0
% INFO    : Gen at bus 8063	: Pg=36.42, Qg=7.96 -> Pg=62.14, Qg=10.0
% INFO    : Gen at bus 8063	: Vg=1.029166 -> Vg=1.0
% INFO    : Gen at bus 8067	: Pg=37.08, Qg=5.51 -> Pg=62.36, Qg=10.0
% INFO    : Gen at bus 8067	: Vg=1.021005 -> Vg=1.0
% INFO    : Gen at bus 8088	: Pg=201.01, Qg=93.92 -> Pg=300.0, Qg=60.0
% INFO    : Gen at bus 8088	: Vg=1.055956 -> Vg=1.0
% INFO    : Gen at bus 8089	: Pg=28.04, Qg=8.11 -> Pg=59.345, Qg=10.0
% INFO    : Gen at bus 8089	: Vg=1.017878 -> Vg=1.0
% INFO    : Gen at bus 8090	: Pg=201.01, Qg=93.92 -> Pg=300.0, Qg=60.0
% INFO    : Gen at bus 8090	: Vg=1.055956 -> Vg=1.0
% INFO    : Gen at bus 8091	: Pg=64.18, Qg=-6.8 -> Pg=121.395, Qg=0.0
% INFO    : Gen at bus 8091	: Vg=0.951565 -> Vg=1.0
% INFO    : Gen at bus 8092	: Pg=36.13, Qg=4.17 -> Pg=62.045, Qg=10.0
% INFO    : Gen at bus 8092	: Vg=1.027348 -> Vg=1.0
% INFO    : Gen at bus 8096	: Pg=30.9, Qg=1.92 -> Pg=60.3, Qg=10.0
% INFO    : Gen at bus 8096	: Vg=1.015954 -> Vg=1.0
% INFO    : Gen at bus 8097	: Pg=369.99, Qg=86.96 -> Pg=500.0, Qg=80.0
% INFO    : Gen at bus 8097	: Vg=1.043138 -> Vg=1.0
% INFO    : Gen at bus 8099	: Pg=41.8, Qg=9.39 -> Pg=63.935, Qg=15.0
% INFO    : Gen at bus 8099	: Vg=1.028604 -> Vg=1.0
% INFO    : Gen at bus 8109	: Pg=24.99, Qg=2.31 -> Pg=58.33, Qg=10.0
% INFO    : Gen at bus 8109	: Vg=1.010466 -> Vg=1.0
% INFO    : Gen at bus 8110	: Pg=34.69, Qg=8.62 -> Pg=61.565, Qg=10.0
% INFO    : Gen at bus 8110	: Vg=1.055415 -> Vg=1.0
% INFO    : Gen at bus 8111	: Pg=36.88, Qg=11.22 -> Pg=62.295, Qg=10.0
% INFO    : Gen at bus 8111	: Vg=1.049781 -> Vg=1.0
% INFO    : Gen at bus 8112	: Pg=34.69, Qg=8.62 -> Pg=61.565, Qg=10.0
% INFO    : Gen at bus 8112	: Vg=1.055415 -> Vg=1.0
% INFO    : Gen at bus 8113	: Pg=37.48, Qg=8.43 -> Pg=62.495, Qg=10.0
% INFO    : Gen at bus 8113	: Vg=1.051968 -> Vg=1.0
% INFO    : Gen at bus 8114	: Pg=36.88, Qg=11.22 -> Pg=62.295, Qg=10.0
% INFO    : Gen at bus 8114	: Vg=1.049781 -> Vg=1.0
% INFO    : Gen at bus 8116	: Pg=37.48, Qg=8.43 -> Pg=62.495, Qg=10.0
% INFO    : Gen at bus 8116	: Vg=1.051968 -> Vg=1.0
% INFO    : Gen at bus 8121	: Pg=23.0, Qg=-6.16 -> Pg=57.665, Qg=0.0
% INFO    : Gen at bus 8121	: Vg=0.989111 -> Vg=1.0
% INFO    : Gen at bus 8122	: Pg=2.5, Qg=0.07 -> Pg=50.835, Qg=0.0
% INFO    : Gen at bus 8122	: Vg=0.984601 -> Vg=1.0
% INFO    : Gen at bus 8123	: Pg=81.96, Qg=34.23 -> Pg=127.32, Qg=20.0
% INFO    : Gen at bus 8123	: Vg=1.031098 -> Vg=1.0
% INFO    : Gen at bus 8125	: Pg=88.86, Qg=16.51 -> Pg=129.62, Qg=20.0
% INFO    : Gen at bus 8125	: Vg=1.020649 -> Vg=1.0
% INFO    : Gen at bus 8126	: Pg=81.96, Qg=34.23 -> Pg=127.32, Qg=20.0
% INFO    : Gen at bus 8126	: Vg=1.031098 -> Vg=1.0
% INFO    : Gen at bus 8127	: Pg=88.86, Qg=16.51 -> Pg=129.62, Qg=20.0
% INFO    : Gen at bus 8127	: Vg=1.020649 -> Vg=1.0
% INFO    : Gen at bus 8128	: Pg=88.86, Qg=16.51 -> Pg=129.62, Qg=20.0
% INFO    : Gen at bus 8128	: Vg=1.020649 -> Vg=1.0
% INFO    : Gen at bus 8130	: Pg=33.68, Qg=6.27 -> Pg=61.225, Qg=10.0
% INFO    : Gen at bus 8130	: Vg=1.046665 -> Vg=1.0
% INFO    : Gen at bus 8141	: Pg=16.1, Qg=3.37 -> Pg=55.365, Qg=5.0
% INFO    : Gen at bus 8141	: Vg=1.026372 -> Vg=1.0
% INFO    : Gen at bus 8143	: Pg=85.28, Qg=21.31 -> Pg=128.425, Qg=20.0
% INFO    : Gen at bus 8143	: Vg=1.029542 -> Vg=1.0
% INFO    : Gen at bus 8145	: Pg=97.82, Qg=33.17 -> Pg=132.605, Qg=20.0
% INFO    : Gen at bus 8145	: Vg=1.055063 -> Vg=1.0
% INFO    : Gen at bus 8146	: Pg=97.52, Qg=42.26 -> Pg=132.505, Qg=20.0
% INFO    : Gen at bus 8146	: Vg=1.053776 -> Vg=1.0
% INFO    : Gen at bus 8147	: Pg=97.74, Qg=41.58 -> Pg=132.58, Qg=20.0
% INFO    : Gen at bus 8147	: Vg=1.050978 -> Vg=1.0
% INFO    : Gen at bus 8148	: Pg=97.74, Qg=41.58 -> Pg=132.58, Qg=20.0
% INFO    : Gen at bus 8148	: Vg=1.050978 -> Vg=1.0
% INFO    : Gen at bus 8149	: Pg=97.52, Qg=42.26 -> Pg=132.505, Qg=20.0
% INFO    : Gen at bus 8149	: Vg=1.053776 -> Vg=1.0
% INFO    : Gen at bus 8151	: Pg=97.77, Qg=42.1 -> Pg=132.59, Qg=20.0
% INFO    : Gen at bus 8151	: Vg=1.051219 -> Vg=1.0
% INFO    : Gen at bus 8153	: Pg=97.74, Qg=41.58 -> Pg=132.58, Qg=20.0
% INFO    : Gen at bus 8153	: Vg=1.050978 -> Vg=1.0
% INFO    : Gen at bus 8154	: Pg=97.77, Qg=42.1 -> Pg=132.59, Qg=20.0
% INFO    : Gen at bus 8154	: Vg=1.051219 -> Vg=1.0
% INFO    : Gen at bus 8157	: Pg=23.04, Qg=1.33 -> Pg=57.68, Qg=0.0
% INFO    : Gen at bus 8157	: Vg=0.996935 -> Vg=1.0
% INFO    : Gen at bus 8159	: Pg=35.74, Qg=6.84 -> Pg=61.915, Qg=10.0
% INFO    : Gen at bus 8159	: Vg=1.040138 -> Vg=1.0
% INFO    : Gen at bus 8162	: Pg=87.39, Qg=49.11 -> Pg=129.13, Qg=20.0
% INFO    : Gen at bus 8162	: Vg=1.054462 -> Vg=1.0
% INFO    : Gen at bus 8163	: Pg=15.0, Qg=-0.86 -> Pg=55.0, Qg=0.0
% INFO    : Gen at bus 8163	: Vg=0.992395 -> Vg=1.0
% INFO    : Gen at bus 8167	: Pg=274.92, Qg=131.33 -> Pg=350.0, Qg=80.0
% INFO    : Gen at bus 8167	: Vg=1.086148 -> Vg=1.0
% INFO    : Gen at bus 8173	: Pg=87.39, Qg=49.11 -> Pg=129.13, Qg=20.0
% INFO    : Gen at bus 8173	: Vg=1.054462 -> Vg=1.0
% INFO    : Gen at bus 8179	: Pg=96.96, Qg=-6.25 -> Pg=132.32, Qg=0.0
% INFO    : Gen at bus 8179	: Vg=0.997286 -> Vg=1.0
% INFO    : Gen at bus 8191	: Pg=34.86, Qg=4.81 -> Pg=61.62, Qg=10.0
% INFO    : Gen at bus 8191	: Vg=1.050901 -> Vg=1.0
% INFO    : Gen at bus 8193	: Pg=6.51, Qg=0.2 -> Pg=52.17, Qg=0.0
% INFO    : Gen at bus 8193	: Vg=1.013271 -> Vg=1.0
% INFO    : Gen at bus 8202	: Pg=60.0, Qg=-6.94 -> Pg=120.0, Qg=0.0
% INFO    : Gen at bus 8202	: Vg=0.959478 -> Vg=1.0
% INFO    : Gen at bus 8205	: Pg=28.35, Qg=17.5 -> Pg=59.45, Qg=10.0
% INFO    : Gen at bus 8205	: Vg=1.042184 -> Vg=1.0
% INFO    : Gen at bus 8206	: Pg=26.33, Qg=10.66 -> Pg=58.775, Qg=10.0
% INFO    : Gen at bus 8206	: Vg=1.01282 -> Vg=1.0
% INFO    : Gen at bus 8218	: Pg=33.1, Qg=8.3 -> Pg=61.035, Qg=10.0
% INFO    : Gen at bus 8218	: Vg=1.041811 -> Vg=1.0
% INFO    : Gen at bus 8219	: Pg=33.1, Qg=8.3 -> Pg=61.035, Qg=10.0
% INFO    : Gen at bus 8219	: Vg=1.041811 -> Vg=1.0
% INFO    : Gen at bus 8220	: Pg=33.1, Qg=8.3 -> Pg=61.035, Qg=10.0
% INFO    : Gen at bus 8220	: Vg=1.041811 -> Vg=1.0
% INFO    : Gen at bus 8221	: Pg=33.1, Qg=8.3 -> Pg=61.035, Qg=10.0
% INFO    : Gen at bus 8221	: Vg=1.041811 -> Vg=1.0
% INFO    : Gen at bus 8222	: Pg=33.1, Qg=8.3 -> Pg=61.035, Qg=10.0
% INFO    : Gen at bus 8222	: Vg=1.041811 -> Vg=1.0
% INFO    : Gen at bus 8223	: Pg=33.1, Qg=8.3 -> Pg=61.035, Qg=10.0
% INFO    : Gen at bus 8223	: Vg=1.041811 -> Vg=1.0
% INFO    : Gen at bus 8224	: Pg=33.1, Qg=8.3 -> Pg=61.035, Qg=10.0
% INFO    : Gen at bus 8224	: Vg=1.041811 -> Vg=1.0
% INFO    : Gen at bus 8246	: Pg=0.26, Qg=-0.09 -> Pg=50.085, Qg=0.0
% INFO    : Gen at bus 8246	: Vg=1.024094 -> Vg=1.0
% INFO    : Gen at bus 8253	: Pg=20.0, Qg=-2.63 -> Pg=56.665, Qg=10.0
% INFO    : Gen at bus 8253	: Vg=1.010291 -> Vg=1.0
% INFO    : Gen at bus 8274	: Pg=61.36, Qg=4.64 -> Pg=120.455, Qg=15.0
% INFO    : Gen at bus 8274	: Vg=1.014321 -> Vg=1.0
% INFO    : Gen at bus 8275	: Pg=61.36, Qg=4.64 -> Pg=120.455, Qg=15.0
% INFO    : Gen at bus 8275	: Vg=1.014321 -> Vg=1.0
% INFO    : Gen at bus 8276	: Pg=61.36, Qg=4.64 -> Pg=120.455, Qg=15.0
% INFO    : Gen at bus 8276	: Vg=1.014321 -> Vg=1.0
% INFO    : Gen at bus 8290	: Pg=100.0, Qg=10.54 -> Pg=183.335, Qg=20.0
% INFO    : Gen at bus 8290	: Vg=1.01208 -> Vg=1.0
% INFO    : Gen at bus 8299	: Pg=10.5, Qg=-0.76 -> Pg=53.5, Qg=0.0
% INFO    : Gen at bus 8299	: Vg=1.011227 -> Vg=1.0
% INFO    : Gen at bus 8301	: Pg=65.58, Qg=12.54 -> Pg=121.86, Qg=20.0
% INFO    : Gen at bus 8301	: Vg=1.029941 -> Vg=1.0
% INFO    : Gen at bus 8308	: Pg=88.86, Qg=16.51 -> Pg=129.62, Qg=20.0
% INFO    : Gen at bus 8308	: Vg=1.020649 -> Vg=1.0
% INFO    : Gen at bus 8317	: Pg=45.63, Qg=24.24 -> Pg=65.21, Qg=15.0
% INFO    : Gen at bus 8317	: Vg=1.060899 -> Vg=1.0
% INFO    : Gen at bus 8319	: Pg=45.63, Qg=24.24 -> Pg=65.21, Qg=15.0
% INFO    : Gen at bus 8319	: Vg=1.060899 -> Vg=1.0
% INFO    : Gen at bus 8320	: Pg=45.63, Qg=24.24 -> Pg=65.21, Qg=15.0
% INFO    : Gen at bus 8320	: Vg=1.060899 -> Vg=1.0
% INFO    : Gen at bus 8321	: Pg=-42.07, Qg=-6.87 -> Pg=21.955, Qg=-15.0
% INFO    : Gen at bus 8321	: Vg=0.998025 -> Vg=1.0
% INFO    : Gen at bus 8323	: Pg=25.6, Qg=3.9 -> Pg=58.535, Qg=10.0
% INFO    : Gen at bus 8323	: Vg=1.03284 -> Vg=1.0
% INFO    : Gen at bus 8326	: Pg=27.2, Qg=3.82 -> Pg=59.065, Qg=10.0
% INFO    : Gen at bus 8326	: Vg=1.024762 -> Vg=1.0
% INFO    : Gen at bus 8342	: Pg=81.31, Qg=8.06 -> Pg=127.105, Qg=20.0
% INFO    : Gen at bus 8342	: Vg=1.043619 -> Vg=1.0
% INFO    : Gen at bus 8343	: Pg=58.19, Qg=6.99 -> Pg=119.395, Qg=15.0
% INFO    : Gen at bus 8343	: Vg=1.028736 -> Vg=1.0
% INFO    : Gen at bus 8352	: Pg=25.0, Qg=4.2 -> Pg=58.335, Qg=5.0
% INFO    : Gen at bus 8352	: Vg=1.03161 -> Vg=1.0
% INFO    : Gen at bus 8354	: Pg=58.19, Qg=6.99 -> Pg=119.395, Qg=15.0
% INFO    : Gen at bus 8354	: Vg=1.028736 -> Vg=1.0
% INFO    : Gen at bus 8357	: Pg=58.19, Qg=6.99 -> Pg=119.395, Qg=15.0
% INFO    : Gen at bus 8357	: Vg=1.028736 -> Vg=1.0
% INFO    : Gen at bus 8359	: Pg=6.97, Qg=0.62 -> Pg=52.325, Qg=0.0
% INFO    : Gen at bus 8359	: Vg=1.028038 -> Vg=1.0
% INFO    : Gen at bus 8367	: Pg=36.11, Qg=3.87 -> Pg=62.035, Qg=10.0
% INFO    : Gen at bus 8367	: Vg=1.024544 -> Vg=1.0
% INFO    : Gen at bus 8369	: Pg=33.32, Qg=9.67 -> Pg=61.105, Qg=10.0
% INFO    : Gen at bus 8369	: Vg=1.032797 -> Vg=1.0
% INFO    : Gen at bus 8370	: Pg=35.74, Qg=6.84 -> Pg=61.915, Qg=10.0
% INFO    : Gen at bus 8370	: Vg=1.040138 -> Vg=1.0
% INFO    : Gen at bus 8373	: Pg=36.0, Qg=6.45 -> Pg=62.0, Qg=10.0
% INFO    : Gen at bus 8373	: Vg=1.034215 -> Vg=1.0
% INFO    : Gen at bus 8378	: Pg=36.0, Qg=6.45 -> Pg=62.0, Qg=10.0
% INFO    : Gen at bus 8378	: Vg=1.034215 -> Vg=1.0
% INFO    : Gen at bus 8380	: Pg=33.32, Qg=9.67 -> Pg=61.105, Qg=10.0
% INFO    : Gen at bus 8380	: Vg=1.032797 -> Vg=1.0
% INFO    : Gen at bus 8385	: Pg=30.0, Qg=5.04 -> Pg=60.0, Qg=5.0
% INFO    : Gen at bus 8385	: Vg=1.023034 -> Vg=1.0
% INFO    : Gen at bus 8386	: Pg=24.22, Qg=5.78 -> Pg=58.075, Qg=10.0
% INFO    : Gen at bus 8386	: Vg=1.029709 -> Vg=1.0
% INFO    : Gen at bus 8387	: Pg=84.68, Qg=7.94 -> Pg=128.225, Qg=20.0
% INFO    : Gen at bus 8387	: Vg=1.00657 -> Vg=1.0
% INFO    : Gen at bus 8388	: Pg=261.4, Qg=61.75 -> Pg=350.0, Qg=35.0
% INFO    : Gen at bus 8388	: Vg=0.988817 -> Vg=1.0
% INFO    : Gen at bus 8389	: Pg=92.69, Qg=14.48 -> Pg=130.895, Qg=20.0
% INFO    : Gen at bus 8389	: Vg=1.026207 -> Vg=1.0
% INFO    : Gen at bus 8393	: Pg=15.4, Qg=0.45 -> Pg=55.135, Qg=5.0
% INFO    : Gen at bus 8393	: Vg=1.066894 -> Vg=1.0
% INFO    : Gen at bus 8394	: Pg=86.25, Qg=-3.04 -> Pg=128.75, Qg=-10.0
% INFO    : Gen at bus 8394	: Vg=0.962614 -> Vg=1.0
% INFO    : Gen at bus 8396	: Pg=4.28, Qg=0.36 -> Pg=51.425, Qg=0.0
% INFO    : Gen at bus 8396	: Vg=1.020502 -> Vg=1.0
% INFO    : Gen at bus 8397	: Pg=33.53, Qg=16.02 -> Pg=61.175, Qg=10.0
% INFO    : Gen at bus 8397	: Vg=1.021376 -> Vg=1.0
% INFO    : Gen at bus 8402	: Pg=33.53, Qg=16.02 -> Pg=61.175, Qg=10.0
% INFO    : Gen at bus 8402	: Vg=1.021376 -> Vg=1.0
% INFO    : Gen at bus 8409	: Pg=24.63, Qg=12.17 -> Pg=58.21, Qg=10.0
% INFO    : Gen at bus 8409	: Vg=1.026822 -> Vg=1.0
% INFO    : Gen at bus 8413	: Pg=40.0, Qg=-0.67 -> Pg=63.335, Qg=0.0
% INFO    : Gen at bus 8413	: Vg=1.00358 -> Vg=1.0
% INFO    : Gen at bus 8415	: Pg=21.45, Qg=5.94 -> Pg=57.15, Qg=10.0
% INFO    : Gen at bus 8415	: Vg=1.013179 -> Vg=1.0
% INFO    : Gen at bus 8421	: Pg=25.41, Qg=10.96 -> Pg=58.47, Qg=10.0
% INFO    : Gen at bus 8421	: Vg=1.019405 -> Vg=1.0
% INFO    : Gen at bus 8423	: Pg=257.89, Qg=39.7 -> Pg=350.0, Qg=80.0
% INFO    : Gen at bus 8423	: Vg=1.022087 -> Vg=1.0
% INFO    : Gen at bus 8424	: Pg=257.89, Qg=39.7 -> Pg=350.0, Qg=80.0
% INFO    : Gen at bus 8424	: Vg=1.022087 -> Vg=1.0
% INFO    : Gen at bus 8425	: Pg=10.36, Qg=-1.27 -> Pg=53.455, Qg=0.0
% INFO    : Gen at bus 8425	: Vg=1.004419 -> Vg=1.0
% INFO    : Gen at bus 8433	: Pg=55.8, Qg=16.15 -> Pg=118.6, Qg=5.0
% INFO    : Gen at bus 8433	: Vg=1.022285 -> Vg=1.0
% INFO    : Gen at bus 8436	: Pg=43.5, Qg=1.21 -> Pg=64.5, Qg=0.0
% INFO    : Gen at bus 8436	: Vg=1.007757 -> Vg=1.0
% INFO    : Gen at bus 8439	: Pg=91.17, Qg=37.8 -> Pg=130.39, Qg=20.0
% INFO    : Gen at bus 8439	: Vg=1.045666 -> Vg=1.0
% INFO    : Gen at bus 8441	: Pg=15.64, Qg=-1.08 -> Pg=55.215, Qg=0.0
% INFO    : Gen at bus 8441	: Vg=1.023837 -> Vg=1.0
% INFO    : Gen at bus 8444	: Pg=97.77, Qg=42.1 -> Pg=132.59, Qg=20.0
% INFO    : Gen at bus 8444	: Vg=1.051219 -> Vg=1.0
% INFO    : Gen at bus 8445	: Pg=24.72, Qg=4.34 -> Pg=58.24, Qg=10.0
% INFO    : Gen at bus 8445	: Vg=1.039546 -> Vg=1.0
% INFO    : Gen at bus 8447	: Pg=22.22, Qg=6.81 -> Pg=57.405, Qg=10.0
% INFO    : Gen at bus 8447	: Vg=1.03758 -> Vg=1.0
% INFO    : Gen at bus 8451	: Pg=40.75, Qg=3.68 -> Pg=63.585, Qg=20.0
% INFO    : Gen at bus 8451	: Vg=0.992069 -> Vg=1.0
% INFO    : Gen at bus 8453	: Pg=323.05, Qg=-7.03 -> Pg=450.0, Qg=-5.0
% INFO    : Gen at bus 8453	: Vg=0.972158 -> Vg=1.0
% INFO    : Gen at bus 8456	: Pg=55.55, Qg=12.64 -> Pg=118.515, Qg=15.0
% INFO    : Gen at bus 8456	: Vg=1.024324 -> Vg=1.0
% INFO    : Gen at bus 8457	: Pg=25.65, Qg=3.95 -> Pg=58.55, Qg=10.0
% INFO    : Gen at bus 8457	: Vg=1.02611 -> Vg=1.0
% INFO    : Gen at bus 8459	: Pg=25.65, Qg=3.95 -> Pg=58.55, Qg=10.0
% INFO    : Gen at bus 8459	: Vg=1.02611 -> Vg=1.0
% INFO    : Gen at bus 8470	: Pg=66.31, Qg=16.47 -> Pg=122.105, Qg=20.0
% INFO    : Gen at bus 8470	: Vg=1.020956 -> Vg=1.0
% INFO    : Gen at bus 8471	: Pg=66.31, Qg=16.47 -> Pg=122.105, Qg=20.0
% INFO    : Gen at bus 8471	: Vg=1.020956 -> Vg=1.0
% INFO    : Gen at bus 8473	: Pg=66.31, Qg=16.47 -> Pg=122.105, Qg=20.0
% INFO    : Gen at bus 8473	: Vg=1.020956 -> Vg=1.0
% INFO    : Gen at bus 8474	: Pg=66.31, Qg=16.47 -> Pg=122.105, Qg=20.0
% INFO    : Gen at bus 8474	: Vg=1.020956 -> Vg=1.0
% INFO    : Gen at bus 8476	: Pg=8.0, Qg=0.73 -> Pg=52.665, Qg=0.0
% INFO    : Gen at bus 8476	: Vg=1.000621 -> Vg=1.0
% INFO    : Gen at bus 8479	: Pg=19.98, Qg=0.98 -> Pg=56.66, Qg=10.0
% INFO    : Gen at bus 8479	: Vg=1.029635 -> Vg=1.0
% INFO    : Gen at bus 8483	: Pg=300.0, Qg=-14.29 -> Pg=450.0, Qg=0.0
% INFO    : Gen at bus 8483	: Vg=1.001419 -> Vg=1.0
% INFO    : Gen at bus 8488	: Pg=11.25, Qg=5.25 -> Pg=53.75, Qg=5.0
% INFO    : Gen at bus 8488	: Vg=1.042782 -> Vg=1.0
% INFO    : Gen at bus 8490	: Pg=34.31, Qg=1.99 -> Pg=61.435, Qg=10.0
% INFO    : Gen at bus 8490	: Vg=1.015531 -> Vg=1.0
% INFO    : Gen at bus 8493	: Pg=4.0, Qg=1.81 -> Pg=51.335, Qg=0.0
% INFO    : Gen at bus 8493	: Vg=1.024481 -> Vg=1.0
% INFO    : Gen at bus 8499	: Pg=165.0, Qg=33.72 -> Pg=250.0, Qg=40.0
% INFO    : Gen at bus 8499	: Vg=0.962508 -> Vg=1.0
% INFO    : Gen at bus 8519	: Pg=92.69, Qg=14.48 -> Pg=130.895, Qg=20.0
% INFO    : Gen at bus 8519	: Vg=1.026207 -> Vg=1.0
% INFO    : Gen at bus 8524	: Pg=38.79, Qg=7.11 -> Pg=62.93, Qg=10.0
% INFO    : Gen at bus 8524	: Vg=1.035838 -> Vg=1.0
% INFO    : Gen at bus 8530	: Pg=19.4, Qg=2.93 -> Pg=56.465, Qg=5.0
% INFO    : Gen at bus 8530	: Vg=1.024655 -> Vg=1.0
% INFO    : Gen at bus 8537	: Pg=74.36, Qg=21.23 -> Pg=124.785, Qg=20.0
% INFO    : Gen at bus 8537	: Vg=1.032132 -> Vg=1.0
% INFO    : Gen at bus 8538	: Pg=68.3, Qg=12.27 -> Pg=122.765, Qg=20.0
% INFO    : Gen at bus 8538	: Vg=1.015227 -> Vg=1.0
% INFO    : Gen at bus 8544	: Pg=63.93, Qg=6.28 -> Pg=121.31, Qg=20.0
% INFO    : Gen at bus 8544	: Vg=1.012697 -> Vg=1.0
% INFO    : Gen at bus 8545	: Pg=69.46, Qg=6.43 -> Pg=123.155, Qg=20.0
% INFO    : Gen at bus 8545	: Vg=1.012641 -> Vg=1.0
% INFO    : Gen at bus 8546	: Pg=69.46, Qg=6.43 -> Pg=123.155, Qg=20.0
% INFO    : Gen at bus 8546	: Vg=1.012641 -> Vg=1.0
% INFO    : Gen at bus 8547	: Pg=68.58, Qg=4.97 -> Pg=122.86, Qg=20.0
% INFO    : Gen at bus 8547	: Vg=1.028244 -> Vg=1.0
% INFO    : Gen at bus 8548	: Pg=68.58, Qg=4.97 -> Pg=122.86, Qg=20.0
% INFO    : Gen at bus 8548	: Vg=1.028244 -> Vg=1.0
% INFO    : Gen at bus 8549	: Pg=68.02, Qg=5.04 -> Pg=122.675, Qg=20.0
% INFO    : Gen at bus 8549	: Vg=1.028456 -> Vg=1.0
% INFO    : Gen at bus 8550	: Pg=68.02, Qg=5.04 -> Pg=122.675, Qg=20.0
% INFO    : Gen at bus 8550	: Vg=1.028456 -> Vg=1.0
% INFO    : Gen at bus 8552	: Pg=81.86, Qg=7.76 -> Pg=127.285, Qg=20.0
% INFO    : Gen at bus 8552	: Vg=1.050589 -> Vg=1.0
% INFO    : Gen at bus 8555	: Pg=31.0, Qg=0.14 -> Pg=60.335, Qg=0.0
% INFO    : Gen at bus 8555	: Vg=1.000449 -> Vg=1.0
% INFO    : Gen at bus 8559	: Pg=57.5, Qg=6.09 -> Pg=119.165, Qg=0.0
% INFO    : Gen at bus 8559	: Vg=0.99654 -> Vg=1.0
% INFO    : Gen at bus 8561	: Pg=172.2, Qg=36.24 -> Pg=250.0, Qg=35.0
% INFO    : Gen at bus 8561	: Vg=0.992794 -> Vg=1.0
% INFO    : Gen at bus 8563	: Pg=18.62, Qg=7.28 -> Pg=56.205, Qg=10.0
% INFO    : Gen at bus 8563	: Vg=1.020659 -> Vg=1.0
% INFO    : Gen at bus 8569	: Pg=863.32, Qg=247.01 -> Pg=1150.0, Qg=200.0
% INFO    : Gen at bus 8569	: Vg=1.043912 -> Vg=1.0
% INFO    : Gen at bus 8570	: Pg=863.33, Qg=248.79 -> Pg=1150.0, Qg=200.0
% INFO    : Gen at bus 8570	: Vg=1.044271 -> Vg=1.0
% INFO    : Gen at bus 8571	: Pg=863.3, Qg=246.84 -> Pg=1150.0, Qg=200.0
% INFO    : Gen at bus 8571	: Vg=1.043938 -> Vg=1.0
% INFO    : Gen at bus 8573	: Pg=26.62, Qg=13.25 -> Pg=58.875, Qg=10.0
% INFO    : Gen at bus 8573	: Vg=1.040642 -> Vg=1.0
% INFO    : Gen at bus 8576	: Pg=31.12, Qg=9.56 -> Pg=60.375, Qg=10.0
% INFO    : Gen at bus 8576	: Vg=1.04434 -> Vg=1.0
% INFO    : Gen at bus 8577	: Pg=21.89, Qg=8.72 -> Pg=57.295, Qg=10.0
% INFO    : Gen at bus 8577	: Vg=1.039495 -> Vg=1.0
% INFO    : Gen at bus 8578	: Pg=21.89, Qg=8.72 -> Pg=57.295, Qg=10.0
% INFO    : Gen at bus 8578	: Vg=1.039495 -> Vg=1.0
% INFO    : Gen at bus 8581	: Pg=29.05, Qg=10.97 -> Pg=59.685, Qg=10.0
% INFO    : Gen at bus 8581	: Vg=1.053599 -> Vg=1.0
% INFO    : Gen at bus 8582	: Pg=29.05, Qg=10.97 -> Pg=59.685, Qg=10.0
% INFO    : Gen at bus 8582	: Vg=1.053599 -> Vg=1.0
% INFO    : Gen at bus 8595	: Pg=5.8, Qg=-0.78 -> Pg=51.935, Qg=0.0
% INFO    : Gen at bus 8595	: Vg=1.003942 -> Vg=1.0
% INFO    : Gen at bus 8598	: Pg=86.41, Qg=23.5 -> Pg=128.805, Qg=20.0
% INFO    : Gen at bus 8598	: Vg=1.031898 -> Vg=1.0
% INFO    : Gen at bus 8604	: Pg=97.67, Qg=41.19 -> Pg=132.555, Qg=20.0
% INFO    : Gen at bus 8604	: Vg=1.052591 -> Vg=1.0
% INFO    : Gen at bus 8609	: Pg=97.67, Qg=41.19 -> Pg=132.555, Qg=20.0
% INFO    : Gen at bus 8609	: Vg=1.052591 -> Vg=1.0
% INFO    : Gen at bus 8610	: Pg=97.67, Qg=41.19 -> Pg=132.555, Qg=20.0
% INFO    : Gen at bus 8610	: Vg=1.052591 -> Vg=1.0
% INFO    : Gen at bus 8632	: Pg=353.02, Qg=203.37 -> Pg=500.0, Qg=80.0
% INFO    : Gen at bus 8632	: Vg=1.128032 -> Vg=1.0
% INFO    : Gen at bus 8635	: Pg=172.2, Qg=6.25 -> Pg=250.0, Qg=35.0
% INFO    : Gen at bus 8635	: Vg=0.968831 -> Vg=1.0
% INFO    : Gen at bus 8637	: Pg=90.48, Qg=33.58 -> Pg=130.16, Qg=20.0
% INFO    : Gen at bus 8637	: Vg=1.043665 -> Vg=1.0
% INFO    : Gen at bus 8639	: Pg=53.01, Qg=8.19 -> Pg=117.67, Qg=15.0
% INFO    : Gen at bus 8639	: Vg=1.026319 -> Vg=1.0
% INFO    : Gen at bus 8644	: Pg=94.5, Qg=8.92 -> Pg=131.5, Qg=5.0
% INFO    : Gen at bus 8644	: Vg=0.979015 -> Vg=1.0
% INFO    : Gen at bus 8647	: Pg=276.46, Qg=124.36 -> Pg=350.0, Qg=60.0
% INFO    : Gen at bus 8647	: Vg=1.052654 -> Vg=1.0
% INFO    : Gen at bus 8648	: Pg=276.46, Qg=124.36 -> Pg=350.0, Qg=60.0
% INFO    : Gen at bus 8648	: Vg=1.052654 -> Vg=1.0
% INFO    : Gen at bus 8651	: Pg=23.81, Qg=8.18 -> Pg=57.935, Qg=10.0
% INFO    : Gen at bus 8651	: Vg=1.024067 -> Vg=1.0
% INFO    : Gen at bus 8654	: Pg=2.5, Qg=0.07 -> Pg=50.835, Qg=0.0
% INFO    : Gen at bus 8654	: Vg=0.984601 -> Vg=1.0
% INFO    : Gen at bus 8655	: Pg=72.47, Qg=11.44 -> Pg=124.155, Qg=20.0
% INFO    : Gen at bus 8655	: Vg=1.019231 -> Vg=1.0
% INFO    : Gen at bus 8656	: Pg=12.0, Qg=-0.74 -> Pg=54.0, Qg=0.0
% INFO    : Gen at bus 8656	: Vg=1.012276 -> Vg=1.0
% INFO    : Gen at bus 8658	: Pg=95.38, Qg=41.05 -> Pg=131.795, Qg=20.0
% INFO    : Gen at bus 8658	: Vg=1.061235 -> Vg=1.0
% INFO    : Gen at bus 8665	: Pg=95.38, Qg=41.05 -> Pg=131.795, Qg=20.0
% INFO    : Gen at bus 8665	: Vg=1.061235 -> Vg=1.0
% INFO    : Gen at bus 8668	: Pg=28.31, Qg=1.9 -> Pg=59.435, Qg=10.0
% INFO    : Gen at bus 8668	: Vg=1.060483 -> Vg=1.0
% INFO    : Gen at bus 8671	: Pg=28.31, Qg=1.9 -> Pg=59.435, Qg=10.0
% INFO    : Gen at bus 8671	: Vg=1.060483 -> Vg=1.0
% INFO    : Gen at bus 8675	: Pg=31.55, Qg=5.32 -> Pg=60.515, Qg=10.0
% INFO    : Gen at bus 8675	: Vg=1.031719 -> Vg=1.0
% INFO    : Gen at bus 8679	: Pg=31.55, Qg=5.32 -> Pg=60.515, Qg=10.0
% INFO    : Gen at bus 8679	: Vg=1.031719 -> Vg=1.0
% INFO    : Gen at bus 8680	: Pg=31.55, Qg=5.32 -> Pg=60.515, Qg=10.0
% INFO    : Gen at bus 8680	: Vg=1.031719 -> Vg=1.0
% INFO    : Gen at bus 8686	: Pg=31.92, Qg=6.07 -> Pg=60.64, Qg=10.0
% INFO    : Gen at bus 8686	: Vg=1.027264 -> Vg=1.0
% INFO    : Gen at bus 8687	: Pg=74.35, Qg=10.28 -> Pg=124.785, Qg=20.0
% INFO    : Gen at bus 8687	: Vg=0.992442 -> Vg=1.0
% INFO    : Gen at bus 8701	: Pg=78.71, Qg=19.55 -> Pg=126.235, Qg=20.0
% INFO    : Gen at bus 8701	: Vg=1.033214 -> Vg=1.0
% INFO    : Gen at bus 8702	: Pg=78.71, Qg=19.55 -> Pg=126.235, Qg=20.0
% INFO    : Gen at bus 8702	: Vg=1.033214 -> Vg=1.0
% INFO    : Gen at bus 8704	: Pg=35.02, Qg=1.75 -> Pg=61.675, Qg=10.0
% INFO    : Gen at bus 8704	: Vg=1.038438 -> Vg=1.0
% INFO    : Gen at bus 8706	: Pg=78.71, Qg=19.51 -> Pg=126.235, Qg=20.0
% INFO    : Gen at bus 8706	: Vg=1.033214 -> Vg=1.0
% INFO    : Gen at bus 8707	: Pg=78.71, Qg=19.51 -> Pg=126.235, Qg=20.0
% INFO    : Gen at bus 8707	: Vg=1.033214 -> Vg=1.0
% INFO    : Gen at bus 8709	: Pg=23.8, Qg=-3.12 -> Pg=57.935, Qg=0.0
% INFO    : Gen at bus 8709	: Vg=0.982549 -> Vg=1.0
% INFO    : Gen at bus 8711	: Pg=626.78, Qg=218.85 -> Pg=850.0, Qg=200.0
% INFO    : Gen at bus 8711	: Vg=1.044461 -> Vg=1.0
% INFO    : Gen at bus 8712	: Pg=626.78, Qg=218.85 -> Pg=850.0, Qg=200.0
% INFO    : Gen at bus 8712	: Vg=1.044461 -> Vg=1.0
% INFO    : Gen at bus 8713	: Pg=626.79, Qg=221.4 -> Pg=850.0, Qg=200.0
% INFO    : Gen at bus 8713	: Vg=1.044893 -> Vg=1.0
% INFO    : Gen at bus 8714	: Pg=626.79, Qg=221.4 -> Pg=850.0, Qg=200.0
% INFO    : Gen at bus 8714	: Vg=1.044893 -> Vg=1.0
% INFO    : Gen at bus 8716	: Pg=259.51, Qg=14.89 -> Pg=350.0, Qg=60.0
% INFO    : Gen at bus 8716	: Vg=1.019095 -> Vg=1.0
% INFO    : Gen at bus 8717	: Pg=259.51, Qg=14.89 -> Pg=350.0, Qg=60.0
% INFO    : Gen at bus 8717	: Vg=1.019095 -> Vg=1.0
% INFO    : Gen at bus 8719	: Pg=29.84, Qg=3.47 -> Pg=59.945, Qg=10.0
% INFO    : Gen at bus 8719	: Vg=1.022039 -> Vg=1.0
% INFO    : Gen at bus 8725	: Pg=23.08, Qg=3.01 -> Pg=57.695, Qg=5.0
% INFO    : Gen at bus 8725	: Vg=1.027819 -> Vg=1.0
% INFO    : Gen at bus 8726	: Pg=15.84, Qg=6.64 -> Pg=55.28, Qg=10.0
% INFO    : Gen at bus 8726	: Vg=1.000784 -> Vg=1.0
% INFO    : Gen at bus 8731	: Pg=94.21, Qg=42.75 -> Pg=131.405, Qg=20.0
% INFO    : Gen at bus 8731	: Vg=1.0598 -> Vg=1.0
% INFO    : Gen at bus 8732	: Pg=94.21, Qg=42.75 -> Pg=131.405, Qg=20.0
% INFO    : Gen at bus 8732	: Vg=1.0598 -> Vg=1.0
% INFO    : Gen at bus 8733	: Pg=94.21, Qg=42.75 -> Pg=131.405, Qg=20.0
% INFO    : Gen at bus 8733	: Vg=1.0598 -> Vg=1.0
% INFO    : Gen at bus 8734	: Pg=94.21, Qg=42.75 -> Pg=131.405, Qg=20.0
% INFO    : Gen at bus 8734	: Vg=1.0598 -> Vg=1.0
% INFO    : Gen at bus 8735	: Pg=94.21, Qg=42.75 -> Pg=131.405, Qg=20.0
% INFO    : Gen at bus 8735	: Vg=1.0598 -> Vg=1.0
% INFO    : Gen at bus 8740	: Pg=260.74, Qg=7.53 -> Pg=350.0, Qg=60.0
% INFO    : Gen at bus 8740	: Vg=0.99389 -> Vg=1.0
% INFO    : Gen at bus 8741	: Pg=274.28, Qg=12.54 -> Pg=350.0, Qg=60.0
% INFO    : Gen at bus 8741	: Vg=0.988223 -> Vg=1.0
% INFO    : Gen at bus 8744	: Pg=50.29, Qg=10.48 -> Pg=116.765, Qg=15.0
% INFO    : Gen at bus 8744	: Vg=1.031165 -> Vg=1.0
% INFO    : Gen at bus 8745	: Pg=50.29, Qg=10.48 -> Pg=116.765, Qg=15.0
% INFO    : Gen at bus 8745	: Vg=1.031165 -> Vg=1.0
% INFO    : Gen at bus 8746	: Pg=50.29, Qg=10.48 -> Pg=116.765, Qg=15.0
% INFO    : Gen at bus 8746	: Vg=1.031165 -> Vg=1.0
% INFO    : Gen at bus 8747	: Pg=50.29, Qg=10.48 -> Pg=116.765, Qg=15.0
% INFO    : Gen at bus 8747	: Vg=1.031165 -> Vg=1.0
% INFO    : Gen at bus 8753	: Pg=74.78, Qg=41.98 -> Pg=124.925, Qg=20.0
% INFO    : Gen at bus 8753	: Vg=1.04914 -> Vg=1.0
% INFO    : Gen at bus 8755	: Pg=50.29, Qg=10.48 -> Pg=116.765, Qg=15.0
% INFO    : Gen at bus 8755	: Vg=1.031165 -> Vg=1.0
% INFO    : Gen at bus 8759	: Pg=239.85, Qg=38.05 -> Pg=300.0, Qg=60.0
% INFO    : Gen at bus 8759	: Vg=1.032762 -> Vg=1.0
% INFO    : Gen at bus 8763	: Pg=31.28, Qg=-0.92 -> Pg=60.425, Qg=10.0
% INFO    : Gen at bus 8763	: Vg=1.009892 -> Vg=1.0
% INFO    : Gen at bus 8764	: Pg=3.41, Qg=0.22 -> Pg=51.14, Qg=0.0
% INFO    : Gen at bus 8764	: Vg=1.030035 -> Vg=1.0
% INFO    : Gen at bus 8770	: Pg=219.68, Qg=138.48 -> Pg=300.0, Qg=60.0
% INFO    : Gen at bus 8770	: Vg=1.048632 -> Vg=1.0
% INFO    : Gen at bus 8772	: Pg=55.14, Qg=27.56 -> Pg=118.38, Qg=15.0
% INFO    : Gen at bus 8772	: Vg=1.023158 -> Vg=1.0
% INFO    : Gen at bus 8773	: Pg=289.8, Qg=143.26 -> Pg=350.0, Qg=60.0
% INFO    : Gen at bus 8773	: Vg=1.042956 -> Vg=1.0
% INFO    : Gen at bus 8774	: Pg=56.25, Qg=11.12 -> Pg=118.75, Qg=15.0
% INFO    : Gen at bus 8774	: Vg=1.03036 -> Vg=1.0
% INFO    : Gen at bus 8776	: Pg=40.0, Qg=-3.06 -> Pg=63.335, Qg=0.0
% INFO    : Gen at bus 8776	: Vg=0.96764 -> Vg=1.0
% INFO    : Gen at bus 8791	: Pg=0.0, Qg=0.58 -> Pg=50.0, Qg=0.0
% INFO    : Gen at bus 8791	: Vg=1.011737 -> Vg=1.0
% INFO    : Gen at bus 8793	: Pg=35.01, Qg=1.48 -> Pg=61.67, Qg=10.0
% INFO    : Gen at bus 8793	: Vg=1.032132 -> Vg=1.0
% INFO    : Gen at bus 8797	: Pg=27.2, Qg=3.82 -> Pg=59.065, Qg=10.0
% INFO    : Gen at bus 8797	: Vg=1.024762 -> Vg=1.0
% INFO    : Gen at bus 8803	: Pg=382.46, Qg=57.23 -> Pg=500.0, Qg=80.0
% INFO    : Gen at bus 8803	: Vg=1.050841 -> Vg=1.0
% INFO    : Gen at bus 8806	: Pg=96.75, Qg=44.18 -> Pg=132.25, Qg=20.0
% INFO    : Gen at bus 8806	: Vg=1.057091 -> Vg=1.0
% INFO    : Gen at bus 8807	: Pg=96.75, Qg=44.18 -> Pg=132.25, Qg=20.0
% INFO    : Gen at bus 8807	: Vg=1.057091 -> Vg=1.0
% INFO    : Gen at bus 8809	: Pg=96.75, Qg=44.18 -> Pg=132.25, Qg=20.0
% INFO    : Gen at bus 8809	: Vg=1.057091 -> Vg=1.0
% INFO    : Gen at bus 8810	: Pg=35.95, Qg=6.39 -> Pg=61.985, Qg=15.0
% INFO    : Gen at bus 8810	: Vg=1.015185 -> Vg=1.0
% INFO    : Gen at bus 8816	: Pg=188.7, Qg=18.36 -> Pg=250.0, Qg=20.0
% INFO    : Gen at bus 8816	: Vg=1.036206 -> Vg=1.0
% INFO    : Gen at bus 8820	: Pg=34.92, Qg=9.74 -> Pg=61.64, Qg=10.0
% INFO    : Gen at bus 8820	: Vg=1.043492 -> Vg=1.0
% INFO    : Gen at bus 8824	: Pg=63.6, Qg=31.38 -> Pg=121.2, Qg=20.0
% INFO    : Gen at bus 8824	: Vg=1.027152 -> Vg=1.0
% INFO    : Gen at bus 8830	: Pg=152.0, Qg=33.4 -> Pg=250.0, Qg=25.0
% INFO    : Gen at bus 8830	: Vg=0.993492 -> Vg=1.0
% INFO    : Gen at bus 8837	: Pg=8.75, Qg=-0.1 -> Pg=52.915, Qg=0.0
% INFO    : Gen at bus 8837	: Vg=0.988686 -> Vg=1.0
% INFO    : Gen at bus 8838	: Pg=63.6, Qg=31.38 -> Pg=121.2, Qg=20.0
% INFO    : Gen at bus 8838	: Vg=1.027152 -> Vg=1.0
% INFO    : Gen at bus 8839	: Pg=81.35, Qg=28.89 -> Pg=127.115, Qg=20.0
% INFO    : Gen at bus 8839	: Vg=1.055981 -> Vg=1.0
% INFO    : Gen at bus 8841	: Pg=364.88, Qg=71.7 -> Pg=500.0, Qg=80.0
% INFO    : Gen at bus 8841	: Vg=1.04706 -> Vg=1.0
% INFO    : Gen at bus 8842	: Pg=364.88, Qg=71.7 -> Pg=500.0, Qg=80.0
% INFO    : Gen at bus 8842	: Vg=1.04706 -> Vg=1.0
% INFO    : Gen at bus 8843	: Pg=364.88, Qg=71.7 -> Pg=500.0, Qg=80.0
% INFO    : Gen at bus 8843	: Vg=1.04706 -> Vg=1.0
% INFO    : Gen at bus 8844	: Pg=364.88, Qg=71.7 -> Pg=500.0, Qg=80.0
% INFO    : Gen at bus 8844	: Vg=1.04706 -> Vg=1.0
% INFO    : Gen at bus 8846	: Pg=153.0, Qg=12.38 -> Pg=250.0, Qg=30.0
% INFO    : Gen at bus 8846	: Vg=1.017859 -> Vg=1.0
% INFO    : Gen at bus 8851	: Pg=35.5, Qg=10.89 -> Pg=61.835, Qg=10.0
% INFO    : Gen at bus 8851	: Vg=1.045213 -> Vg=1.0
% INFO    : Gen at bus 8852	: Pg=36.11, Qg=3.87 -> Pg=62.035, Qg=10.0
% INFO    : Gen at bus 8852	: Vg=1.024544 -> Vg=1.0
% INFO    : Gen at bus 8857	: Pg=7.0, Qg=0.9 -> Pg=52.335, Qg=0.0
% INFO    : Gen at bus 8857	: Vg=1.004314 -> Vg=1.0
% INFO    : Gen at bus 8860	: Pg=25.07, Qg=19.14 -> Pg=58.355, Qg=10.0
% INFO    : Gen at bus 8860	: Vg=1.045495 -> Vg=1.0
% INFO    : Gen at bus 8861	: Pg=25.07, Qg=19.14 -> Pg=58.355, Qg=10.0
% INFO    : Gen at bus 8861	: Vg=1.045495 -> Vg=1.0
% INFO    : Gen at bus 8864	: Pg=30.01, Qg=15.35 -> Pg=60.005, Qg=10.0
% INFO    : Gen at bus 8864	: Vg=1.052369 -> Vg=1.0
% INFO    : Gen at bus 8866	: Pg=30.01, Qg=15.35 -> Pg=60.005, Qg=10.0
% INFO    : Gen at bus 8866	: Vg=1.052369 -> Vg=1.0
% INFO    : Gen at bus 8867	: Pg=30.01, Qg=15.35 -> Pg=60.005, Qg=10.0
% INFO    : Gen at bus 8867	: Vg=1.052369 -> Vg=1.0
% INFO    : Gen at bus 8873	: Pg=52.06, Qg=9.48 -> Pg=117.355, Qg=15.0
% INFO    : Gen at bus 8873	: Vg=1.028771 -> Vg=1.0
% INFO    : Gen at bus 8881	: Pg=10.5, Qg=2.44 -> Pg=53.5, Qg=0.0
% INFO    : Gen at bus 8881	: Vg=1.008788 -> Vg=1.0
% INFO    : Gen at bus 8884	: Pg=84.68, Qg=7.94 -> Pg=128.225, Qg=20.0
% INFO    : Gen at bus 8884	: Vg=1.00657 -> Vg=1.0
% INFO    : Gen at bus 8885	: Pg=96.29, Qg=19.0 -> Pg=132.095, Qg=20.0
% INFO    : Gen at bus 8885	: Vg=1.037131 -> Vg=1.0
% INFO    : Gen at bus 8887	: Pg=40.0, Qg=-1.33 -> Pg=63.335, Qg=0.0
% INFO    : Gen at bus 8887	: Vg=1.010141 -> Vg=1.0
% INFO    : Gen at bus 8893	: Pg=6.52, Qg=-0.06 -> Pg=52.175, Qg=0.0
% INFO    : Gen at bus 8893	: Vg=0.994601 -> Vg=1.0
% INFO    : Gen at bus 8894	: Pg=274.65, Qg=30.64 -> Pg=350.0, Qg=60.0
% INFO    : Gen at bus 8894	: Vg=1.018066 -> Vg=1.0
% INFO    : Gen at bus 8896	: Pg=23.2, Qg=-0.2 -> Pg=57.735, Qg=0.0
% INFO    : Gen at bus 8896	: Vg=0.996866 -> Vg=1.0
% INFO    : Gen at bus 8897	: Pg=80.13, Qg=43.5 -> Pg=126.71, Qg=20.0
% INFO    : Gen at bus 8897	: Vg=1.053937 -> Vg=1.0
% INFO    : Gen at bus 8898	: Pg=80.07, Qg=50.15 -> Pg=126.69, Qg=20.0
% INFO    : Gen at bus 8898	: Vg=1.039942 -> Vg=1.0
% INFO    : Gen at bus 8900	: Pg=29.7, Qg=6.22 -> Pg=59.9, Qg=10.0
% INFO    : Gen at bus 8900	: Vg=1.033776 -> Vg=1.0
% INFO    : Gen at bus 8901	: Pg=24.3, Qg=3.82 -> Pg=58.1, Qg=10.0
% INFO    : Gen at bus 8901	: Vg=1.010028 -> Vg=1.0
% INFO    : Gen at bus 8902	: Pg=24.3, Qg=3.82 -> Pg=58.1, Qg=10.0
% INFO    : Gen at bus 8902	: Vg=1.010028 -> Vg=1.0
% INFO    : Gen at bus 8903	: Pg=24.3, Qg=3.82 -> Pg=58.1, Qg=10.0
% INFO    : Gen at bus 8903	: Vg=1.010028 -> Vg=1.0
% INFO    : Gen at bus 8904	: Pg=79.99, Qg=47.72 -> Pg=126.665, Qg=20.0
% INFO    : Gen at bus 8904	: Vg=1.050006 -> Vg=1.0
% INFO    : Gen at bus 8905	: Pg=79.99, Qg=47.72 -> Pg=126.665, Qg=20.0
% INFO    : Gen at bus 8905	: Vg=1.050006 -> Vg=1.0
% INFO    : Gen at bus 8906	: Pg=24.3, Qg=3.82 -> Pg=58.1, Qg=10.0
% INFO    : Gen at bus 8906	: Vg=1.010028 -> Vg=1.0
% INFO    : Gen at bus 8907	: Pg=79.99, Qg=47.72 -> Pg=126.665, Qg=20.0
% INFO    : Gen at bus 8907	: Vg=1.050006 -> Vg=1.0
% INFO    : Gen at bus 8908	: Pg=80.13, Qg=43.5 -> Pg=126.71, Qg=20.0
% INFO    : Gen at bus 8908	: Vg=1.053937 -> Vg=1.0
% INFO    : Gen at bus 8909	: Pg=80.13, Qg=43.5 -> Pg=126.71, Qg=20.0
% INFO    : Gen at bus 8909	: Vg=1.053937 -> Vg=1.0
% INFO    : Gen at bus 8910	: Pg=80.13, Qg=43.5 -> Pg=126.71, Qg=20.0
% INFO    : Gen at bus 8910	: Vg=1.053937 -> Vg=1.0
% INFO    : Gen at bus 8911	: Pg=321.41, Qg=105.18 -> Pg=450.0, Qg=80.0
% INFO    : Gen at bus 8911	: Vg=1.033947 -> Vg=1.0
% INFO    : Gen at bus 8912	: Pg=72.47, Qg=11.44 -> Pg=124.155, Qg=20.0
% INFO    : Gen at bus 8912	: Vg=1.019231 -> Vg=1.0
% INFO    : Gen at bus 8914	: Pg=22.73, Qg=8.07 -> Pg=57.575, Qg=10.0
% INFO    : Gen at bus 8914	: Vg=1.024089 -> Vg=1.0
% INFO    : Gen at bus 8916	: Pg=2.5, Qg=0.07 -> Pg=50.835, Qg=0.0
% INFO    : Gen at bus 8916	: Vg=0.984601 -> Vg=1.0
% INFO    : Gen at bus 8921	: Pg=243.32, Qg=23.39 -> Pg=300.0, Qg=80.0
% INFO    : Gen at bus 8921	: Vg=1.055881 -> Vg=1.0
% INFO    : Gen at bus 8933	: Pg=15.0, Qg=-0.04 -> Pg=55.0, Qg=0.0
% INFO    : Gen at bus 8933	: Vg=1.011801 -> Vg=1.0
% INFO    : Gen at bus 8937	: Pg=56.84, Qg=10.43 -> Pg=118.945, Qg=15.0
% INFO    : Gen at bus 8937	: Vg=1.025724 -> Vg=1.0
% INFO    : Gen at bus 8938	: Pg=56.84, Qg=10.43 -> Pg=118.945, Qg=15.0
% INFO    : Gen at bus 8938	: Vg=1.025724 -> Vg=1.0
% INFO    : Gen at bus 8939	: Pg=56.84, Qg=10.43 -> Pg=118.945, Qg=15.0
% INFO    : Gen at bus 8939	: Vg=1.025724 -> Vg=1.0
% INFO    : Gen at bus 8941	: Pg=51.75, Qg=8.57 -> Pg=117.25, Qg=15.0
% INFO    : Gen at bus 8941	: Vg=1.019281 -> Vg=1.0
% INFO    : Gen at bus 8942	: Pg=29.68, Qg=6.45 -> Pg=59.895, Qg=10.0
% INFO    : Gen at bus 8942	: Vg=1.016891 -> Vg=1.0
% INFO    : Gen at bus 8943	: Pg=51.75, Qg=8.57 -> Pg=117.25, Qg=15.0
% INFO    : Gen at bus 8943	: Vg=1.019281 -> Vg=1.0
% INFO    : Gen at bus 8944	: Pg=51.75, Qg=8.57 -> Pg=117.25, Qg=15.0
% INFO    : Gen at bus 8944	: Vg=1.019281 -> Vg=1.0
% INFO    : Gen at bus 8945	: Pg=57.27, Qg=17.52 -> Pg=119.09, Qg=15.0
% INFO    : Gen at bus 8945	: Vg=1.017845 -> Vg=1.0
% INFO    : Gen at bus 8952	: Pg=34.31, Qg=5.82 -> Pg=61.435, Qg=10.0
% INFO    : Gen at bus 8952	: Vg=1.037965 -> Vg=1.0
% INFO    : Gen at bus 8953	: Pg=34.31, Qg=5.82 -> Pg=61.435, Qg=10.0
% INFO    : Gen at bus 8953	: Vg=1.037965 -> Vg=1.0
% INFO    : Gen at bus 8954	: Pg=34.31, Qg=5.82 -> Pg=61.435, Qg=10.0
% INFO    : Gen at bus 8954	: Vg=1.037965 -> Vg=1.0
% INFO    : Gen at bus 8955	: Pg=34.31, Qg=5.82 -> Pg=61.435, Qg=10.0
% INFO    : Gen at bus 8955	: Vg=1.037965 -> Vg=1.0
% INFO    : Gen at bus 8956	: Pg=26.01, Qg=11.35 -> Pg=58.67, Qg=10.0
% INFO    : Gen at bus 8956	: Vg=1.062565 -> Vg=1.0
% INFO    : Gen at bus 8958	: Pg=769.34, Qg=-82.54 -> Pg=1050.0, Qg=200.0
% INFO    : Gen at bus 8958	: Vg=0.999428 -> Vg=1.0
% INFO    : Gen at bus 8961	: Pg=27.38, Qg=10.62 -> Pg=59.125, Qg=10.0
% INFO    : Gen at bus 8961	: Vg=1.015042 -> Vg=1.0
% INFO    : Gen at bus 8962	: Pg=34.31, Qg=5.82 -> Pg=61.435, Qg=10.0
% INFO    : Gen at bus 8962	: Vg=1.037965 -> Vg=1.0
% INFO    : Gen at bus 8963	: Pg=34.3, Qg=7.71 -> Pg=61.435, Qg=10.0
% INFO    : Gen at bus 8963	: Vg=1.038216 -> Vg=1.0
% INFO    : Gen at bus 8964	: Pg=77.39, Qg=15.14 -> Pg=125.795, Qg=20.0
% INFO    : Gen at bus 8964	: Vg=1.030057 -> Vg=1.0
% INFO    : Gen at bus 8965	: Pg=77.39, Qg=15.14 -> Pg=125.795, Qg=20.0
% INFO    : Gen at bus 8965	: Vg=1.030057 -> Vg=1.0
% INFO    : Gen at bus 8966	: Pg=77.39, Qg=15.14 -> Pg=125.795, Qg=20.0
% INFO    : Gen at bus 8966	: Vg=1.030057 -> Vg=1.0
% INFO    : Gen at bus 8967	: Pg=77.39, Qg=15.14 -> Pg=125.795, Qg=20.0
% INFO    : Gen at bus 8967	: Vg=1.030057 -> Vg=1.0
% INFO    : Gen at bus 8969	: Pg=16.71, Qg=0.01 -> Pg=55.57, Qg=10.0
% INFO    : Gen at bus 8969	: Vg=1.030988 -> Vg=1.0
% INFO    : Gen at bus 8976	: Pg=74.86, Qg=19.42 -> Pg=124.955, Qg=20.0
% INFO    : Gen at bus 8976	: Vg=1.011998 -> Vg=1.0
% INFO    : Gen at bus 8980	: Pg=21.6, Qg=0.33 -> Pg=57.2, Qg=0.0
% INFO    : Gen at bus 8980	: Vg=0.9829 -> Vg=1.0
% INFO    : Gen at bus 8994	: Pg=78.96, Qg=32.05 -> Pg=126.32, Qg=20.0
% INFO    : Gen at bus 8994	: Vg=1.063361 -> Vg=1.0
% INFO    : Gen at bus 8999	: Pg=22.68, Qg=3.66 -> Pg=57.56, Qg=5.0
% INFO    : Gen at bus 8999	: Vg=1.020283 -> Vg=1.0
% INFO    : Gen at bus 9016	: Pg=40.0, Qg=-3.06 -> Pg=63.335, Qg=0.0
% INFO    : Gen at bus 9016	: Vg=0.96764 -> Vg=1.0
% INFO    : Gen at bus 9024	: Pg=204.0, Qg=85.48 -> Pg=300.0, Qg=45.0
% INFO    : Gen at bus 9024	: Vg=1.02301 -> Vg=1.0
% INFO    : Gen at bus 9028	: Pg=18.52, Qg=11.72 -> Pg=56.175, Qg=10.0
% INFO    : Gen at bus 9028	: Vg=1.044704 -> Vg=1.0
% INFO    : Gen at bus 9033	: Pg=332.24, Qg=91.88 -> Pg=450.0, Qg=80.0
% INFO    : Gen at bus 9033	: Vg=1.046254 -> Vg=1.0
% INFO    : Gen at bus 9034	: Pg=332.24, Qg=91.88 -> Pg=450.0, Qg=80.0
% INFO    : Gen at bus 9034	: Vg=1.046254 -> Vg=1.0
% INFO    : Gen at bus 9035	: Pg=66.65, Qg=5.48 -> Pg=122.215, Qg=20.0
% INFO    : Gen at bus 9035	: Vg=1.01993 -> Vg=1.0
% INFO    : Gen at bus 9041	: Pg=36.03, Qg=16.08 -> Pg=62.01, Qg=10.0
% INFO    : Gen at bus 9041	: Vg=1.045359 -> Vg=1.0
% INFO    : Gen at bus 9045	: Pg=284.4, Qg=98.98 -> Pg=350.0, Qg=80.0
% INFO    : Gen at bus 9045	: Vg=1.060659 -> Vg=1.0
% INFO    : Gen at bus 9047	: Pg=48.3, Qg=8.12 -> Pg=66.1, Qg=15.0
% INFO    : Gen at bus 9047	: Vg=1.021906 -> Vg=1.0
% INFO    : Gen at bus 9049	: Pg=158.9, Qg=5.88 -> Pg=250.0, Qg=35.0
% INFO    : Gen at bus 9049	: Vg=0.968879 -> Vg=1.0
% INFO    : Gen at bus 9051	: Pg=284.51, Qg=138.58 -> Pg=350.0, Qg=80.0
% INFO    : Gen at bus 9051	: Vg=1.065482 -> Vg=1.0
% INFO    : Gen at bus 9054	: Pg=159.8, Qg=34.27 -> Pg=250.0, Qg=30.0
% INFO    : Gen at bus 9054	: Vg=0.978477 -> Vg=1.0
% INFO    : Gen at bus 9056	: Pg=1.16, Qg=0.09 -> Pg=50.385, Qg=0.0
% INFO    : Gen at bus 9056	: Vg=1.030388 -> Vg=1.0
% INFO    : Gen at bus 9060	: Pg=284.51, Qg=138.58 -> Pg=350.0, Qg=80.0
% INFO    : Gen at bus 9060	: Vg=1.065482 -> Vg=1.0
% INFO    : Gen at bus 9061	: Pg=26.62, Qg=13.25 -> Pg=58.875, Qg=10.0
% INFO    : Gen at bus 9061	: Vg=1.040642 -> Vg=1.0
% INFO    : Gen at bus 9074	: Pg=43.84, Qg=6.21 -> Pg=64.615, Qg=20.0
% INFO    : Gen at bus 9074	: Vg=0.991243 -> Vg=1.0
% INFO    : Gen at bus 9075	: Pg=34.2, Qg=13.71 -> Pg=61.4, Qg=10.0
% INFO    : Gen at bus 9075	: Vg=1.044756 -> Vg=1.0
% INFO    : Gen at bus 9081	: Pg=28.35, Qg=17.5 -> Pg=59.45, Qg=10.0
% INFO    : Gen at bus 9081	: Vg=1.042184 -> Vg=1.0
% INFO    : Gen at bus 9084	: Pg=97.68, Qg=6.22 -> Pg=132.56, Qg=20.0
% INFO    : Gen at bus 9084	: Vg=1.017679 -> Vg=1.0
% INFO    : Gen at bus 9088	: Pg=34.65, Qg=8.09 -> Pg=61.55, Qg=10.0
% INFO    : Gen at bus 9088	: Vg=1.039009 -> Vg=1.0
% INFO    : Gen at bus 9102	: Pg=26.91, Qg=8.03 -> Pg=58.97, Qg=10.0
% INFO    : Gen at bus 9102	: Vg=1.04328 -> Vg=1.0
% INFO    : Gen at bus 9106	: Pg=26.91, Qg=8.03 -> Pg=58.97, Qg=10.0
% INFO    : Gen at bus 9106	: Vg=1.04328 -> Vg=1.0
% INFO    : Gen at bus 9107	: Pg=26.91, Qg=8.03 -> Pg=58.97, Qg=10.0
% INFO    : Gen at bus 9107	: Vg=1.04328 -> Vg=1.0
% INFO    : Gen at bus 9110	: Pg=23.58, Qg=-5.0 -> Pg=57.86, Qg=0.0
% INFO    : Gen at bus 9110	: Vg=0.964368 -> Vg=1.0
% INFO    : Gen at bus 9120	: Pg=25.89, Qg=9.83 -> Pg=58.63, Qg=15.0
% INFO    : Gen at bus 9120	: Vg=1.013208 -> Vg=1.0
% INFO    : Gen at bus 9123	: Pg=59.5, Qg=9.44 -> Pg=119.835, Qg=20.0
% INFO    : Gen at bus 9123	: Vg=1.032856 -> Vg=1.0
% INFO    : Gen at bus 9137	: Pg=43.55, Qg=17.11 -> Pg=64.515, Qg=15.0
% INFO    : Gen at bus 9137	: Vg=1.033542 -> Vg=1.0
% INFO    : Gen at bus 9138	: Pg=35.97, Qg=9.16 -> Pg=61.99, Qg=10.0
% INFO    : Gen at bus 9138	: Vg=1.001252 -> Vg=1.0
% INFO    : Gen at bus 9141	: Pg=58.49, Qg=10.33 -> Pg=119.495, Qg=15.0
% INFO    : Gen at bus 9141	: Vg=1.031723 -> Vg=1.0
% INFO    : Gen at bus 9142	: Pg=58.49, Qg=10.33 -> Pg=119.495, Qg=15.0
% INFO    : Gen at bus 9142	: Vg=1.031723 -> Vg=1.0
% INFO    : Gen at bus 9144	: Pg=83.78, Qg=15.02 -> Pg=127.925, Qg=20.0
% INFO    : Gen at bus 9144	: Vg=1.033534 -> Vg=1.0
% INFO    : Gen at bus 9148	: Pg=649.29, Qg=-32.35 -> Pg=850.0, Qg=200.0
% INFO    : Gen at bus 9148	: Vg=1.035363 -> Vg=1.0
% INFO    : Gen at bus 9149	: Pg=37.08, Qg=5.51 -> Pg=62.36, Qg=10.0
% INFO    : Gen at bus 9149	: Vg=1.021005 -> Vg=1.0
% INFO    : Gen at bus 9151	: Pg=9.0, Qg=-0.95 -> Pg=53.0, Qg=0.0
% INFO    : Gen at bus 9151	: Vg=0.943602 -> Vg=1.0
% INFO    : Gen at bus 9152	: Pg=858.21, Qg=148.21 -> Pg=1150.0, Qg=200.0
% INFO    : Gen at bus 9152	: Vg=1.058618 -> Vg=1.0
% INFO    : Gen at bus 9166	: Pg=17.5, Qg=0.21 -> Pg=55.835, Qg=0.0
% INFO    : Gen at bus 9166	: Vg=1.00081 -> Vg=1.0
% INFO    : Gen at bus 9168	: Pg=4.8, Qg=1.5 -> Pg=51.6, Qg=0.0
% INFO    : Gen at bus 9168	: Vg=1.020547 -> Vg=1.0
% INFO    : Gen at bus 9169	: Pg=22.36, Qg=9.77 -> Pg=57.455, Qg=10.0
% INFO    : Gen at bus 9169	: Vg=1.014559 -> Vg=1.0
% INFO    : Gen at bus 9179	: Pg=87.35, Qg=17.85 -> Pg=129.115, Qg=20.0
% INFO    : Gen at bus 9179	: Vg=1.033768 -> Vg=1.0
% INFO    : Gen at bus 9182	: Pg=0.0, Qg=4.21 -> Pg=50.0, Qg=15.0
% INFO    : Gen at bus 9182	: Vg=1.016648 -> Vg=1.0
% INFO    : Gen at bus 9184	: Pg=17.21, Qg=5.28 -> Pg=55.735, Qg=10.0
% INFO    : Gen at bus 9184	: Vg=1.020161 -> Vg=1.0
% INFO    : Gen at bus 9188	: Pg=88.9, Qg=23.56 -> Pg=129.635, Qg=20.0
% INFO    : Gen at bus 9188	: Vg=1.031838 -> Vg=1.0
% INFO    : Gen at bus 9189	: Pg=88.9, Qg=23.56 -> Pg=129.635, Qg=20.0
% INFO    : Gen at bus 9189	: Vg=1.031838 -> Vg=1.0
% INFO    : Gen at bus 9190	: Pg=88.9, Qg=23.56 -> Pg=129.635, Qg=20.0
% INFO    : Gen at bus 9190	: Vg=1.031838 -> Vg=1.0
% INFO    : Gen at bus 9191	: Pg=88.9, Qg=23.56 -> Pg=129.635, Qg=20.0
% INFO    : Gen at bus 9191	: Vg=1.031838 -> Vg=1.0
% INFO    : Gen at bus 9195	: Pg=210.0, Qg=15.07 -> Pg=300.0, Qg=35.0
% INFO    : Gen at bus 9195	: Vg=0.980209 -> Vg=1.0
% INFO    : Gen at bus 9204	: Pg=111.5, Qg=6.79 -> Pg=187.165, Qg=15.0
% INFO    : Gen at bus 9204	: Vg=1.056762 -> Vg=1.0
% INFO    : Gen at bus 9206	: Pg=209.96, Qg=80.01 -> Pg=300.0, Qg=60.0
% INFO    : Gen at bus 9206	: Vg=1.039006 -> Vg=1.0
% INFO    : Gen at bus 9213	: Pg=17.95, Qg=10.38 -> Pg=55.985, Qg=10.0
% INFO    : Gen at bus 9213	: Vg=1.044317 -> Vg=1.0
% INFO    : Gen at bus 9214	: Pg=39.0, Qg=5.27 -> Pg=63.0, Qg=10.0
% INFO    : Gen at bus 9214	: Vg=1.011094 -> Vg=1.0
% INFO    : Gen at bus 9215	: Pg=40.06, Qg=12.17 -> Pg=63.355, Qg=10.0
% INFO    : Gen at bus 9215	: Vg=1.05775 -> Vg=1.0
% INFO    : Gen at bus 9216	: Pg=20.55, Qg=5.71 -> Pg=56.85, Qg=10.0
% INFO    : Gen at bus 9216	: Vg=1.019482 -> Vg=1.0
% INFO    : Gen at bus 9218	: Pg=27.88, Qg=10.37 -> Pg=59.295, Qg=10.0
% INFO    : Gen at bus 9218	: Vg=1.052164 -> Vg=1.0
% INFO    : Gen at bus 9219	: Pg=35.29, Qg=10.61 -> Pg=61.765, Qg=10.0
% INFO    : Gen at bus 9219	: Vg=1.043764 -> Vg=1.0
% INFO    : Gen at bus 9220	: Pg=35.29, Qg=10.61 -> Pg=61.765, Qg=10.0
% INFO    : Gen at bus 9220	: Vg=1.043764 -> Vg=1.0
% INFO    : Gen at bus 9222	: Pg=17.95, Qg=10.38 -> Pg=55.985, Qg=10.0
% INFO    : Gen at bus 9222	: Vg=1.044317 -> Vg=1.0
% INFO    : Gen at bus 9223	: Pg=3.38, Qg=0.57 -> Pg=51.125, Qg=0.0
% INFO    : Gen at bus 9223	: Vg=1.017385 -> Vg=1.0
% INFO    : Gen at bus 9224	: Pg=17.95, Qg=10.38 -> Pg=55.985, Qg=10.0
% INFO    : Gen at bus 9224	: Vg=1.044317 -> Vg=1.0
% INFO    : Gen at bus 9225	: Pg=31.08, Qg=1.51 -> Pg=60.36, Qg=10.0
% INFO    : Gen at bus 9225	: Vg=1.048036 -> Vg=1.0
% INFO    : Gen at bus 9227	: Pg=23.0, Qg=-6.16 -> Pg=57.665, Qg=0.0
% INFO    : Gen at bus 9227	: Vg=0.989111 -> Vg=1.0
% INFO    : Gen at bus 9228	: Pg=95.42, Qg=32.99 -> Pg=131.805, Qg=20.0
% INFO    : Gen at bus 9228	: Vg=1.058394 -> Vg=1.0
% INFO    : Gen at bus 9229	: Pg=95.42, Qg=32.99 -> Pg=131.805, Qg=20.0
% INFO    : Gen at bus 9229	: Vg=1.058394 -> Vg=1.0
% INFO    : Gen at bus 9230	: Pg=95.42, Qg=32.99 -> Pg=131.805, Qg=20.0
% INFO    : Gen at bus 9230	: Vg=1.058394 -> Vg=1.0
% INFO    : Gen at bus 9231	: Pg=95.42, Qg=32.99 -> Pg=131.805, Qg=20.0
% INFO    : Gen at bus 9231	: Vg=1.058394 -> Vg=1.0
% INFO    : Gen at bus 9232	: Pg=95.42, Qg=32.99 -> Pg=131.805, Qg=20.0
% INFO    : Gen at bus 9232	: Vg=1.058394 -> Vg=1.0
% INFO    : Gen at bus 9233	: Pg=95.42, Qg=32.99 -> Pg=131.805, Qg=20.0
% INFO    : Gen at bus 9233	: Vg=1.058394 -> Vg=1.0
% INFO    : Gen at bus 9236	: Pg=35.01, Qg=1.48 -> Pg=61.67, Qg=10.0
% INFO    : Gen at bus 9236	: Vg=1.032132 -> Vg=1.0
% INFO    : Gen at bus 9237	: Pg=95.51, Qg=37.64 -> Pg=131.835, Qg=20.0
% INFO    : Gen at bus 9237	: Vg=1.0608 -> Vg=1.0
% INFO    : Gen at bus 9244	: Pg=34.62, Qg=2.89 -> Pg=61.54, Qg=5.0
% INFO    : Gen at bus 9244	: Vg=1.019266 -> Vg=1.0
% INFO    : Gen at bus 9246	: Pg=55.46, Qg=13.9 -> Pg=118.485, Qg=15.0
% INFO    : Gen at bus 9246	: Vg=1.030174 -> Vg=1.0
% INFO    : Gen at bus 9247	: Pg=55.46, Qg=13.9 -> Pg=118.485, Qg=15.0
% INFO    : Gen at bus 9247	: Vg=1.030174 -> Vg=1.0
% INFO    : Gen at bus 9250	: Pg=221.97, Qg=103.8 -> Pg=300.0, Qg=80.0
% INFO    : Gen at bus 9250	: Vg=1.063388 -> Vg=1.0
% INFO    : Gen at bus 9256	: Pg=279.67, Qg=54.61 -> Pg=350.0, Qg=80.0
% INFO    : Gen at bus 9256	: Vg=1.030939 -> Vg=1.0
% INFO    : Gen at bus 9257	: Pg=279.67, Qg=54.61 -> Pg=350.0, Qg=80.0
% INFO    : Gen at bus 9257	: Vg=1.030939 -> Vg=1.0
% INFO    : Gen at bus 9258	: Pg=279.67, Qg=54.61 -> Pg=350.0, Qg=80.0
% INFO    : Gen at bus 9258	: Vg=1.030939 -> Vg=1.0
% INFO    : Gen at bus 9260	: Pg=279.66, Qg=54.13 -> Pg=350.0, Qg=80.0
% INFO    : Gen at bus 9260	: Vg=1.030874 -> Vg=1.0
% INFO    : Gen at bus 9261	: Pg=279.66, Qg=54.13 -> Pg=350.0, Qg=80.0
% INFO    : Gen at bus 9261	: Vg=1.030874 -> Vg=1.0
% INFO    : Gen at bus 9265	: Pg=261.96, Qg=25.03 -> Pg=350.0, Qg=80.0
% INFO    : Gen at bus 9265	: Vg=1.042062 -> Vg=1.0
% INFO    : Gen at bus 9273	: Pg=35.95, Qg=6.39 -> Pg=61.985, Qg=15.0
% INFO    : Gen at bus 9273	: Vg=1.015185 -> Vg=1.0
% INFO    : Gen at bus 9279	: Pg=84.72, Qg=12.1 -> Pg=128.24, Qg=20.0
% INFO    : Gen at bus 9279	: Vg=1.046178 -> Vg=1.0
% INFO    : Gen at bus 9280	: Pg=34.2, Qg=13.71 -> Pg=61.4, Qg=10.0
% INFO    : Gen at bus 9280	: Vg=1.044756 -> Vg=1.0
% INFO    : Gen at bus 9281	: Pg=214.65, Qg=55.92 -> Pg=300.0, Qg=80.0
% INFO    : Gen at bus 9281	: Vg=1.073284 -> Vg=1.0
% INFO    : Gen at bus 9282	: Pg=50.94, Qg=19.18 -> Pg=116.98, Qg=15.0
% INFO    : Gen at bus 9282	: Vg=1.0136 -> Vg=1.0
% INFO    : Gen at bus 9283	: Pg=280.13, Qg=69.09 -> Pg=350.0, Qg=60.0
% INFO    : Gen at bus 9283	: Vg=1.028417 -> Vg=1.0
% INFO    : Gen at bus 9288	: Pg=24.28, Qg=7.01 -> Pg=58.095, Qg=10.0
% INFO    : Gen at bus 9288	: Vg=1.012542 -> Vg=1.0
% INFO    : Gen at bus 9292	: Pg=30.0, Qg=3.15 -> Pg=60.0, Qg=5.0
% INFO    : Gen at bus 9292	: Vg=1.046548 -> Vg=1.0
% INFO    : Gen at bus 9294	: Pg=336.9, Qg=100.14 -> Pg=450.0, Qg=80.0
% INFO    : Gen at bus 9294	: Vg=1.061222 -> Vg=1.0
% INFO    : Gen at bus 9297	: Pg=36.13, Qg=4.17 -> Pg=62.045, Qg=10.0
% INFO    : Gen at bus 9297	: Vg=1.027348 -> Vg=1.0
% INFO    : Gen at bus 9301	: Pg=79.79, Qg=-1.82 -> Pg=126.595, Qg=20.0
% INFO    : Gen at bus 9301	: Vg=1.024891 -> Vg=1.0
% INFO    : Gen at bus 9312	: Pg=9.02, Qg=-0.08 -> Pg=53.005, Qg=0.0
% INFO    : Gen at bus 9312	: Vg=1.003305 -> Vg=1.0
% INFO    : Gen at bus 9314	: Pg=30.24, Qg=9.06 -> Pg=60.08, Qg=10.0
% INFO    : Gen at bus 9314	: Vg=1.012031 -> Vg=1.0
% INFO    : Gen at bus 9317	: Pg=37.23, Qg=4.01 -> Pg=62.41, Qg=10.0
% INFO    : Gen at bus 9317	: Vg=1.028283 -> Vg=1.0
% INFO    : Gen at bus 9321	: Pg=29.7, Qg=6.22 -> Pg=59.9, Qg=10.0
% INFO    : Gen at bus 9321	: Vg=1.033776 -> Vg=1.0
% INFO    : Gen at bus 9322	: Pg=19.91, Qg=7.13 -> Pg=56.635, Qg=10.0
% INFO    : Gen at bus 9322	: Vg=1.021055 -> Vg=1.0
% INFO    : Gen at bus 9323	: Pg=19.91, Qg=7.13 -> Pg=56.635, Qg=10.0
% INFO    : Gen at bus 9323	: Vg=1.021055 -> Vg=1.0
% INFO    : Gen at bus 9327	: Pg=5.27, Qg=-0.03 -> Pg=51.755, Qg=0.0
% INFO    : Gen at bus 9327	: Vg=1.015617 -> Vg=1.0
% INFO    : Gen at bus 9342	: Pg=26.75, Qg=6.78 -> Pg=58.915, Qg=15.0
% INFO    : Gen at bus 9342	: Vg=1.024572 -> Vg=1.0
% INFO    : Gen at bus 9343	: Pg=57.51, Qg=17.72 -> Pg=119.17, Qg=15.0
% INFO    : Gen at bus 9343	: Vg=1.029323 -> Vg=1.0
% INFO    : Gen at bus 9345	: Pg=36.24, Qg=9.52 -> Pg=62.08, Qg=10.0
% INFO    : Gen at bus 9345	: Vg=1.028588 -> Vg=1.0
% INFO    : Gen at bus 9346	: Pg=36.24, Qg=9.52 -> Pg=62.08, Qg=10.0
% INFO    : Gen at bus 9346	: Vg=1.028588 -> Vg=1.0
% INFO    : Gen at bus 9347	: Pg=36.24, Qg=9.52 -> Pg=62.08, Qg=10.0
% INFO    : Gen at bus 9347	: Vg=1.028588 -> Vg=1.0
% INFO    : Gen at bus 9348	: Pg=36.24, Qg=9.52 -> Pg=62.08, Qg=10.0
% INFO    : Gen at bus 9348	: Vg=1.028588 -> Vg=1.0
% INFO    : Gen at bus 9349	: Pg=36.24, Qg=9.52 -> Pg=62.08, Qg=10.0
% INFO    : Gen at bus 9349	: Vg=1.028588 -> Vg=1.0
% INFO    : Gen at bus 9350	: Pg=36.24, Qg=9.52 -> Pg=62.08, Qg=10.0
% INFO    : Gen at bus 9350	: Vg=1.028588 -> Vg=1.0
% INFO    : Gen at bus 9351	: Pg=36.24, Qg=9.52 -> Pg=62.08, Qg=10.0
% INFO    : Gen at bus 9351	: Vg=1.028588 -> Vg=1.0
% INFO    : Gen at bus 9352	: Pg=36.24, Qg=9.52 -> Pg=62.08, Qg=10.0
% INFO    : Gen at bus 9352	: Vg=1.028588 -> Vg=1.0
% INFO    : Gen at bus 9354	: Pg=37.23, Qg=4.01 -> Pg=62.41, Qg=10.0
% INFO    : Gen at bus 9354	: Vg=1.028283 -> Vg=1.0
% INFO    : Gen at bus 9357	: Pg=56.25, Qg=11.12 -> Pg=118.75, Qg=15.0
% INFO    : Gen at bus 9357	: Vg=1.03036 -> Vg=1.0
% INFO    : Gen at bus 9359	: Pg=84.68, Qg=7.94 -> Pg=128.225, Qg=20.0
% INFO    : Gen at bus 9359	: Vg=1.00657 -> Vg=1.0
% INFO    : Gen at bus 9364	: Pg=240.6, Qg=37.13 -> Pg=300.0, Qg=35.0
% INFO    : Gen at bus 9364	: Vg=0.970854 -> Vg=1.0
% INFO    : Gen at bus 9370	: Pg=214.65, Qg=55.92 -> Pg=300.0, Qg=80.0
% INFO    : Gen at bus 9370	: Vg=1.073284 -> Vg=1.0
% INFO    : Gen at bus 9374	: Pg=36.77, Qg=13.93 -> Pg=62.255, Qg=10.0
% INFO    : Gen at bus 9374	: Vg=1.042317 -> Vg=1.0
% INFO    : Gen at bus 9376	: Pg=31.72, Qg=4.48 -> Pg=60.575, Qg=10.0
% INFO    : Gen at bus 9376	: Vg=1.022192 -> Vg=1.0
% INFO    : Gen at bus 9377	: Pg=31.72, Qg=4.48 -> Pg=60.575, Qg=10.0
% INFO    : Gen at bus 9377	: Vg=1.022192 -> Vg=1.0
% INFO    : Gen at bus 9378	: Pg=31.72, Qg=4.48 -> Pg=60.575, Qg=10.0
% INFO    : Gen at bus 9378	: Vg=1.022192 -> Vg=1.0
% INFO    : Gen at bus 9379	: Pg=31.72, Qg=4.48 -> Pg=60.575, Qg=10.0
% INFO    : Gen at bus 9379	: Vg=1.022192 -> Vg=1.0
% INFO    : Gen at bus 9383	: Pg=31.72, Qg=4.48 -> Pg=60.575, Qg=10.0
% INFO    : Gen at bus 9383	: Vg=1.022192 -> Vg=1.0
% INFO    : Gen at bus 9384	: Pg=31.72, Qg=4.48 -> Pg=60.575, Qg=10.0
% INFO    : Gen at bus 9384	: Vg=1.022192 -> Vg=1.0
% INFO    : Gen at bus 9387	: Pg=19.57, Qg=7.03 -> Pg=56.525, Qg=10.0
% INFO    : Gen at bus 9387	: Vg=1.023156 -> Vg=1.0
% INFO    : Gen at bus 9389	: Pg=9.94, Qg=1.09 -> Pg=53.315, Qg=0.0
% INFO    : Gen at bus 9389	: Vg=0.985384 -> Vg=1.0
% INFO    : Gen at bus 9392	: Pg=322.34, Qg=84.39 -> Pg=450.0, Qg=80.0
% INFO    : Gen at bus 9392	: Vg=1.058231 -> Vg=1.0
% INFO    : Gen at bus 9393	: Pg=63.93, Qg=6.28 -> Pg=121.31, Qg=20.0
% INFO    : Gen at bus 9393	: Vg=1.012697 -> Vg=1.0
% INFO    : Gen at bus 9395	: Pg=60.0, Qg=3.34 -> Pg=120.0, Qg=5.0
% INFO    : Gen at bus 9395	: Vg=1.020595 -> Vg=1.0
% INFO    : Gen at bus 9408	: Pg=97.57, Qg=36.99 -> Pg=132.525, Qg=20.0
% INFO    : Gen at bus 9408	: Vg=1.074058 -> Vg=1.0
% INFO    : Gen at bus 9413	: Pg=2.5, Qg=0.07 -> Pg=50.835, Qg=0.0
% INFO    : Gen at bus 9413	: Vg=0.984601 -> Vg=1.0
% INFO    : Gen at bus 9417	: Pg=57.27, Qg=17.52 -> Pg=119.09, Qg=15.0
% INFO    : Gen at bus 9417	: Vg=1.017845 -> Vg=1.0
% INFO    : Gen at bus 9421	: Pg=0.91, Qg=0.07 -> Pg=50.305, Qg=0.0
% INFO    : Gen at bus 9421	: Vg=1.030419 -> Vg=1.0
% INFO    : Gen at bus 9422	: Pg=74.86, Qg=19.42 -> Pg=124.955, Qg=20.0
% INFO    : Gen at bus 9422	: Vg=1.011998 -> Vg=1.0
% INFO    : Gen at bus 9427	: Pg=33.97, Qg=5.68 -> Pg=61.325, Qg=10.0
% INFO    : Gen at bus 9427	: Vg=1.022889 -> Vg=1.0
% INFO    : Gen at bus 9438	: Pg=68.26, Qg=20.93 -> Pg=122.755, Qg=20.0
% INFO    : Gen at bus 9438	: Vg=1.022995 -> Vg=1.0
% INFO    : Gen at bus 9439	: Pg=300.01, Qg=75.96 -> Pg=450.0, Qg=60.0
% INFO    : Gen at bus 9439	: Vg=1.035797 -> Vg=1.0
% INFO    : Gen at bus 9440	: Pg=68.26, Qg=20.93 -> Pg=122.755, Qg=20.0
% INFO    : Gen at bus 9440	: Vg=1.022995 -> Vg=1.0
% INFO    : Gen at bus 9441	: Pg=68.26, Qg=20.93 -> Pg=122.755, Qg=20.0
% INFO    : Gen at bus 9441	: Vg=1.022995 -> Vg=1.0
% INFO    : Gen at bus 9442	: Pg=68.26, Qg=20.93 -> Pg=122.755, Qg=20.0
% INFO    : Gen at bus 9442	: Vg=1.022995 -> Vg=1.0
% INFO    : Gen at bus 9443	: Pg=68.26, Qg=20.93 -> Pg=122.755, Qg=20.0
% INFO    : Gen at bus 9443	: Vg=1.022995 -> Vg=1.0
% INFO    : Gen at bus 9457	: Pg=157.5, Qg=-11.97 -> Pg=250.0, Qg=0.0
% INFO    : Gen at bus 9457	: Vg=0.984599 -> Vg=1.0
% INFO    : Gen at bus 9461	: Pg=50.0, Qg=-1.48 -> Pg=116.665, Qg=5.0
% INFO    : Gen at bus 9461	: Vg=0.985642 -> Vg=1.0
% INFO    : Gen at bus 9464	: Pg=93.04, Qg=14.9 -> Pg=131.015, Qg=20.0
% INFO    : Gen at bus 9464	: Vg=1.017638 -> Vg=1.0
% INFO    : Gen at bus 9466	: Pg=25.84, Qg=4.48 -> Pg=58.615, Qg=5.0
% INFO    : Gen at bus 9466	: Vg=1.018726 -> Vg=1.0
% INFO    : Gen at bus 9467	: Pg=84.3, Qg=7.63 -> Pg=128.1, Qg=20.0
% INFO    : Gen at bus 9467	: Vg=1.05433 -> Vg=1.0
% INFO    : Gen at bus 9471	: Pg=32.97, Qg=4.46 -> Pg=60.99, Qg=10.0
% INFO    : Gen at bus 9471	: Vg=1.027968 -> Vg=1.0
% INFO    : Gen at bus 9472	: Pg=32.97, Qg=4.46 -> Pg=60.99, Qg=10.0
% INFO    : Gen at bus 9472	: Vg=1.027968 -> Vg=1.0
% INFO    : Gen at bus 9473	: Pg=32.57, Qg=6.88 -> Pg=60.855, Qg=10.0
% INFO    : Gen at bus 9473	: Vg=1.03654 -> Vg=1.0
% INFO    : Gen at bus 9474	: Pg=32.57, Qg=6.88 -> Pg=60.855, Qg=10.0
% INFO    : Gen at bus 9474	: Vg=1.03654 -> Vg=1.0
% INFO    : Gen at bus 9475	: Pg=26.98, Qg=3.71 -> Pg=58.995, Qg=10.0
% INFO    : Gen at bus 9475	: Vg=1.066367 -> Vg=1.0
% INFO    : Gen at bus 9476	: Pg=26.98, Qg=3.71 -> Pg=58.995, Qg=10.0
% INFO    : Gen at bus 9476	: Vg=1.066367 -> Vg=1.0
% INFO    : Gen at bus 9477	: Pg=27.51, Qg=11.78 -> Pg=59.17, Qg=10.0
% INFO    : Gen at bus 9477	: Vg=1.042669 -> Vg=1.0
% INFO    : Gen at bus 9478	: Pg=26.86, Qg=3.11 -> Pg=58.955, Qg=10.0
% INFO    : Gen at bus 9478	: Vg=1.042101 -> Vg=1.0
% INFO    : Gen at bus 9479	: Pg=26.86, Qg=3.11 -> Pg=58.955, Qg=10.0
% INFO    : Gen at bus 9479	: Vg=1.042101 -> Vg=1.0
% INFO    : Gen at bus 9480	: Pg=26.86, Qg=3.11 -> Pg=58.955, Qg=10.0
% INFO    : Gen at bus 9480	: Vg=1.042101 -> Vg=1.0
% INFO    : Gen at bus 9481	: Pg=26.86, Qg=3.11 -> Pg=58.955, Qg=10.0
% INFO    : Gen at bus 9481	: Vg=1.042101 -> Vg=1.0
% INFO    : Gen at bus 9482	: Pg=26.86, Qg=3.11 -> Pg=58.955, Qg=10.0
% INFO    : Gen at bus 9482	: Vg=1.042101 -> Vg=1.0
% INFO    : Gen at bus 9486	: Pg=84.3, Qg=7.63 -> Pg=128.1, Qg=20.0
% INFO    : Gen at bus 9486	: Vg=1.05433 -> Vg=1.0
% INFO    : Gen at bus 9504	: Pg=44.8, Qg=3.17 -> Pg=64.935, Qg=10.0
% INFO    : Gen at bus 9504	: Vg=0.991989 -> Vg=1.0
% INFO    : Gen at bus 9508	: Pg=67.68, Qg=4.49 -> Pg=122.56, Qg=20.0
% INFO    : Gen at bus 9508	: Vg=1.017078 -> Vg=1.0
% INFO    : Gen at bus 9512	: Pg=96.03, Qg=17.22 -> Pg=132.01, Qg=20.0
% INFO    : Gen at bus 9512	: Vg=1.036065 -> Vg=1.0
% INFO    : Gen at bus 9513	: Pg=216.13, Qg=123.79 -> Pg=300.0, Qg=60.0
% INFO    : Gen at bus 9513	: Vg=1.059317 -> Vg=1.0
% INFO    : Gen at bus 9515	: Pg=243.54, Qg=114.28 -> Pg=300.0, Qg=60.0
% INFO    : Gen at bus 9515	: Vg=1.055847 -> Vg=1.0
% INFO    : Gen at bus 9520	: Pg=25.75, Qg=4.04 -> Pg=58.585, Qg=10.0
% INFO    : Gen at bus 9520	: Vg=1.026025 -> Vg=1.0
% INFO    : Gen at bus 9521	: Pg=35.84, Qg=16.6 -> Pg=61.945, Qg=10.0
% INFO    : Gen at bus 9521	: Vg=1.042077 -> Vg=1.0
% INFO    : Gen at bus 9522	: Pg=216.13, Qg=123.79 -> Pg=300.0, Qg=60.0
% INFO    : Gen at bus 9522	: Vg=1.059317 -> Vg=1.0
% INFO    : Gen at bus 9523	: Pg=249.82, Qg=72.04 -> Pg=300.0, Qg=60.0
% INFO    : Gen at bus 9523	: Vg=1.053646 -> Vg=1.0
% INFO    : Gen at bus 9525	: Pg=249.82, Qg=72.04 -> Pg=300.0, Qg=60.0
% INFO    : Gen at bus 9525	: Vg=1.053646 -> Vg=1.0
% INFO    : Gen at bus 9527	: Pg=370.08, Qg=97.24 -> Pg=500.0, Qg=80.0
% INFO    : Gen at bus 9527	: Vg=1.045516 -> Vg=1.0
% INFO    : Gen at bus 9540	: Pg=256.21, Qg=65.38 -> Pg=350.0, Qg=60.0
% INFO    : Gen at bus 9540	: Vg=1.052481 -> Vg=1.0
% INFO    : Gen at bus 9542	: Pg=22.38, Qg=13.57 -> Pg=57.46, Qg=10.0
% INFO    : Gen at bus 9542	: Vg=1.011374 -> Vg=1.0
% INFO    : Gen at bus 9547	: Pg=90.32, Qg=6.14 -> Pg=130.105, Qg=20.0
% INFO    : Gen at bus 9547	: Vg=1.034547 -> Vg=1.0
% INFO    : Gen at bus 9549	: Pg=90.32, Qg=6.14 -> Pg=130.105, Qg=20.0
% INFO    : Gen at bus 9549	: Vg=1.034547 -> Vg=1.0
% INFO    : Gen at bus 9550	: Pg=90.32, Qg=6.14 -> Pg=130.105, Qg=20.0
% INFO    : Gen at bus 9550	: Vg=1.034547 -> Vg=1.0
% INFO    : Gen at bus 9551	: Pg=90.32, Qg=6.14 -> Pg=130.105, Qg=20.0
% INFO    : Gen at bus 9551	: Vg=1.034547 -> Vg=1.0
% INFO    : Gen at bus 9552	: Pg=24.7, Qg=5.64 -> Pg=58.235, Qg=0.0
% INFO    : Gen at bus 9552	: Vg=1.010522 -> Vg=1.0
% INFO    : Gen at bus 9553	: Pg=167.4, Qg=-8.63 -> Pg=250.0, Qg=10.0
% INFO    : Gen at bus 9553	: Vg=0.948759 -> Vg=1.0
% INFO    : Gen at bus 9554	: Pg=2.12, Qg=-0.62 -> Pg=50.705, Qg=0.0
% INFO    : Gen at bus 9554	: Vg=0.962462 -> Vg=1.0
% INFO    : Gen at bus 9556	: Pg=95.83, Qg=32.34 -> Pg=131.945, Qg=20.0
% INFO    : Gen at bus 9556	: Vg=1.012871 -> Vg=1.0
% INFO    : Gen at bus 9573	: Pg=101.0, Qg=24.39 -> Pg=183.665, Qg=20.0
% INFO    : Gen at bus 9573	: Vg=1.022149 -> Vg=1.0
% INFO    : Gen at bus 9574	: Pg=101.0, Qg=24.39 -> Pg=183.665, Qg=20.0
% INFO    : Gen at bus 9574	: Vg=1.022149 -> Vg=1.0
% INFO    : Gen at bus 9579	: Pg=766.83, Qg=2.68 -> Pg=1050.0, Qg=200.0
% INFO    : Gen at bus 9579	: Vg=1.05252 -> Vg=1.0
% INFO    : Gen at bus 9584	: Pg=518.63, Qg=-13.96 -> Pg=700.0, Qg=200.0
% INFO    : Gen at bus 9584	: Vg=1.056808 -> Vg=1.0
% INFO    : Gen at bus 9585	: Pg=518.63, Qg=-13.96 -> Pg=700.0, Qg=200.0
% INFO    : Gen at bus 9585	: Vg=1.056808 -> Vg=1.0
% INFO    : Gen at bus 9586	: Pg=52.53, Qg=15.88 -> Pg=117.51, Qg=15.0
% INFO    : Gen at bus 9586	: Vg=1.02748 -> Vg=1.0
% INFO    : Gen at bus 9587	: Pg=52.53, Qg=15.88 -> Pg=117.51, Qg=15.0
% INFO    : Gen at bus 9587	: Vg=1.02748 -> Vg=1.0
% INFO    : Gen at bus 9588	: Pg=40.17, Qg=5.3 -> Pg=63.39, Qg=15.0
% INFO    : Gen at bus 9588	: Vg=1.030361 -> Vg=1.0
% INFO    : Gen at bus 9589	: Pg=40.17, Qg=5.3 -> Pg=63.39, Qg=15.0
% INFO    : Gen at bus 9589	: Vg=1.030361 -> Vg=1.0
% INFO    : Gen at bus 9590	: Pg=40.17, Qg=5.3 -> Pg=63.39, Qg=15.0
% INFO    : Gen at bus 9590	: Vg=1.030361 -> Vg=1.0
% INFO    : Gen at bus 9591	: Pg=40.17, Qg=5.3 -> Pg=63.39, Qg=15.0
% INFO    : Gen at bus 9591	: Vg=1.030361 -> Vg=1.0
% INFO    : Gen at bus 9597	: Pg=184.49, Qg=7.07 -> Pg=250.0, Qg=80.0
% INFO    : Gen at bus 9597	: Vg=1.044678 -> Vg=1.0
% INFO    : Gen at bus 9602	: Pg=76.5, Qg=12.8 -> Pg=125.5, Qg=15.0
% INFO    : Gen at bus 9602	: Vg=1.034298 -> Vg=1.0
% INFO    : Gen at bus 9613	: Pg=84.68, Qg=7.94 -> Pg=128.225, Qg=20.0
% INFO    : Gen at bus 9613	: Vg=1.00657 -> Vg=1.0
% INFO    : Gen at bus 9614	: Pg=24.84, Qg=4.52 -> Pg=58.28, Qg=10.0
% INFO    : Gen at bus 9614	: Vg=1.022099 -> Vg=1.0
% INFO    : Gen at bus 9616	: Pg=47.18, Qg=14.99 -> Pg=65.725, Qg=15.0
% INFO    : Gen at bus 9616	: Vg=1.021579 -> Vg=1.0
% INFO    : Gen at bus 9617	: Pg=52.42, Qg=24.94 -> Pg=117.475, Qg=15.0
% INFO    : Gen at bus 9617	: Vg=1.023225 -> Vg=1.0
% INFO    : Gen at bus 9618	: Pg=52.42, Qg=24.94 -> Pg=117.475, Qg=15.0
% INFO    : Gen at bus 9618	: Vg=1.023225 -> Vg=1.0
% INFO    : Gen at bus 9619	: Pg=55.06, Qg=16.94 -> Pg=118.355, Qg=15.0
% INFO    : Gen at bus 9619	: Vg=1.025226 -> Vg=1.0
% INFO    : Gen at bus 9622	: Pg=55.06, Qg=16.94 -> Pg=118.355, Qg=15.0
% INFO    : Gen at bus 9622	: Vg=1.025226 -> Vg=1.0
% INFO    : Gen at bus 9623	: Pg=44.71, Qg=9.09 -> Pg=64.905, Qg=15.0
% INFO    : Gen at bus 9623	: Vg=1.024756 -> Vg=1.0
% INFO    : Gen at bus 9627	: Pg=898.67, Qg=496.37 -> Pg=1150.0, Qg=200.0
% INFO    : Gen at bus 9627	: Vg=1.055007 -> Vg=1.0
% INFO    : Gen at bus 9628	: Pg=50.6, Qg=9.92 -> Pg=116.865, Qg=5.0
% INFO    : Gen at bus 9628	: Vg=1.012126 -> Vg=1.0
% INFO    : Gen at bus 9638	: Pg=18.5, Qg=2.5 -> Pg=56.165, Qg=0.0
% INFO    : Gen at bus 9638	: Vg=0.975244 -> Vg=1.0
% INFO    : Gen at bus 9655	: Pg=932.42, Qg=349.72 -> Pg=1250.0, Qg=200.0
% INFO    : Gen at bus 9655	: Vg=1.064074 -> Vg=1.0
% INFO    : Gen at bus 9656	: Pg=932.56, Qg=349.6 -> Pg=1250.0, Qg=200.0
% INFO    : Gen at bus 9656	: Vg=1.064118 -> Vg=1.0
% INFO    : Gen at bus 9659	: Pg=33.84, Qg=9.43 -> Pg=61.28, Qg=10.0
% INFO    : Gen at bus 9659	: Vg=1.043178 -> Vg=1.0
% INFO    : Gen at bus 9662	: Pg=90.48, Qg=33.58 -> Pg=130.16, Qg=20.0
% INFO    : Gen at bus 9662	: Vg=1.043665 -> Vg=1.0
% INFO    : Gen at bus 9679	: Pg=874.56, Qg=115.53 -> Pg=1150.0, Qg=200.0
% INFO    : Gen at bus 9679	: Vg=1.023313 -> Vg=1.0
% INFO    : Gen at bus 9681	: Pg=862.85, Qg=226.06 -> Pg=1150.0, Qg=200.0
% INFO    : Gen at bus 9681	: Vg=1.036584 -> Vg=1.0
% INFO    : Gen at bus 9682	: Pg=862.85, Qg=223.65 -> Pg=1150.0, Qg=200.0
% INFO    : Gen at bus 9682	: Vg=1.036459 -> Vg=1.0
% INFO    : Gen at bus 9687	: Pg=366.21, Qg=205.07 -> Pg=500.0, Qg=80.0
% INFO    : Gen at bus 9687	: Vg=1.129641 -> Vg=1.0
% INFO    : Gen at bus 9690	: Pg=198.91, Qg=5.92 -> Pg=250.0, Qg=80.0
% INFO    : Gen at bus 9690	: Vg=1.031301 -> Vg=1.0
% INFO    : Gen at bus 9693	: Pg=8.93, Qg=-0.3 -> Pg=52.975, Qg=0.0
% INFO    : Gen at bus 9693	: Vg=1.003834 -> Vg=1.0
% INFO    : Gen at bus 9695	: Pg=33.94, Qg=6.74 -> Pg=61.315, Qg=10.0
% INFO    : Gen at bus 9695	: Vg=1.046243 -> Vg=1.0
% INFO    : Gen at bus 9696	: Pg=33.94, Qg=6.74 -> Pg=61.315, Qg=10.0
% INFO    : Gen at bus 9696	: Vg=1.046243 -> Vg=1.0
% INFO    : Gen at bus 9697	: Pg=33.94, Qg=6.74 -> Pg=61.315, Qg=10.0
% INFO    : Gen at bus 9697	: Vg=1.046243 -> Vg=1.0
% INFO    : Gen at bus 9698	: Pg=33.94, Qg=6.74 -> Pg=61.315, Qg=10.0
% INFO    : Gen at bus 9698	: Vg=1.046243 -> Vg=1.0
% INFO    : Gen at bus 9699	: Pg=39.23, Qg=8.3 -> Pg=63.075, Qg=10.0
% INFO    : Gen at bus 9699	: Vg=1.030153 -> Vg=1.0
% INFO    : Gen at bus 9700	: Pg=30.78, Qg=2.48 -> Pg=60.26, Qg=10.0
% INFO    : Gen at bus 9700	: Vg=1.048966 -> Vg=1.0
% INFO    : Gen at bus 9702	: Pg=39.23, Qg=8.3 -> Pg=63.075, Qg=10.0
% INFO    : Gen at bus 9702	: Vg=1.030153 -> Vg=1.0
% INFO    : Gen at bus 9706	: Pg=23.96, Qg=4.79 -> Pg=57.985, Qg=10.0
% INFO    : Gen at bus 9706	: Vg=1.007614 -> Vg=1.0
% INFO    : Gen at bus 9713	: Pg=55.22, Qg=8.96 -> Pg=118.405, Qg=15.0
% INFO    : Gen at bus 9713	: Vg=1.017828 -> Vg=1.0
% INFO    : Gen at bus 9722	: Pg=152.0, Qg=11.5 -> Pg=250.0, Qg=0.0
% INFO    : Gen at bus 9722	: Vg=0.988205 -> Vg=1.0
% INFO    : Gen at bus 9728	: Pg=0.06, Qg=-0.1 -> Pg=50.02, Qg=0.0
% INFO    : Gen at bus 9728	: Vg=1.02351 -> Vg=1.0
% INFO    : Gen at bus 9738	: Pg=200.19, Qg=-0.55 -> Pg=300.0, Qg=60.0
% INFO    : Gen at bus 9738	: Vg=1.039371 -> Vg=1.0
% INFO    : Gen at bus 9742	: Pg=41.8, Qg=9.39 -> Pg=63.935, Qg=15.0
% INFO    : Gen at bus 9742	: Vg=1.028604 -> Vg=1.0
% INFO    : Gen at bus 9748	: Pg=3.65, Qg=0.04 -> Pg=51.215, Qg=0.0
% INFO    : Gen at bus 9748	: Vg=0.982004 -> Vg=1.0
% INFO    : Gen at bus 9751	: Pg=37.85, Qg=19.77 -> Pg=62.615, Qg=10.0
% INFO    : Gen at bus 9751	: Vg=1.057943 -> Vg=1.0
% INFO    : Gen at bus 9753	: Pg=37.86, Qg=19.74 -> Pg=62.62, Qg=10.0
% INFO    : Gen at bus 9753	: Vg=1.057896 -> Vg=1.0
% INFO    : Gen at bus 9754	: Pg=95.62, Qg=39.51 -> Pg=131.875, Qg=20.0
% INFO    : Gen at bus 9754	: Vg=1.057682 -> Vg=1.0
% INFO    : Gen at bus 9756	: Pg=50.94, Qg=19.18 -> Pg=116.98, Qg=15.0
% INFO    : Gen at bus 9756	: Vg=1.0136 -> Vg=1.0
% INFO    : Gen at bus 9757	: Pg=95.65, Qg=38.29 -> Pg=131.885, Qg=20.0
% INFO    : Gen at bus 9757	: Vg=1.058111 -> Vg=1.0
% INFO    : Gen at bus 9758	: Pg=95.65, Qg=38.29 -> Pg=131.885, Qg=20.0
% INFO    : Gen at bus 9758	: Vg=1.058111 -> Vg=1.0
% INFO    : Gen at bus 9759	: Pg=95.62, Qg=39.51 -> Pg=131.875, Qg=20.0
% INFO    : Gen at bus 9759	: Vg=1.057682 -> Vg=1.0
% INFO    : Gen at bus 9761	: Pg=95.65, Qg=38.29 -> Pg=131.885, Qg=20.0
% INFO    : Gen at bus 9761	: Vg=1.058111 -> Vg=1.0
% INFO    : Gen at bus 9762	: Pg=95.65, Qg=38.29 -> Pg=131.885, Qg=20.0
% INFO    : Gen at bus 9762	: Vg=1.058111 -> Vg=1.0
% INFO    : Gen at bus 9763	: Pg=95.65, Qg=38.29 -> Pg=131.885, Qg=20.0
% INFO    : Gen at bus 9763	: Vg=1.058111 -> Vg=1.0
% INFO    : Gen at bus 9764	: Pg=95.65, Qg=38.29 -> Pg=131.885, Qg=20.0
% INFO    : Gen at bus 9764	: Vg=1.058111 -> Vg=1.0
% INFO    : Gen at bus 9766	: Pg=45.0, Qg=6.33 -> Pg=65.0, Qg=10.0
% INFO    : Gen at bus 9766	: Vg=1.024995 -> Vg=1.0
% INFO    : Gen at bus 9775	: Pg=87.35, Qg=17.85 -> Pg=129.115, Qg=20.0
% INFO    : Gen at bus 9775	: Vg=1.033768 -> Vg=1.0
% INFO    : Gen at bus 9778	: Pg=10.77, Qg=0.4 -> Pg=53.59, Qg=0.0
% INFO    : Gen at bus 9778	: Vg=1.00995 -> Vg=1.0
% INFO    : Gen at bus 9781	: Pg=23.07, Qg=4.45 -> Pg=57.69, Qg=10.0
% INFO    : Gen at bus 9781	: Vg=1.026025 -> Vg=1.0
% INFO    : Gen at bus 9785	: Pg=83.69, Qg=18.55 -> Pg=127.895, Qg=20.0
% INFO    : Gen at bus 9785	: Vg=1.037564 -> Vg=1.0
% INFO    : Gen at bus 9793	: Pg=99.7, Qg=4.57 -> Pg=133.235, Qg=20.0
% INFO    : Gen at bus 9793	: Vg=1.028091 -> Vg=1.0
% INFO    : Gen at bus 9797	: Pg=0.18, Qg=-0.15 -> Pg=50.06, Qg=0.0
% INFO    : Gen at bus 9797	: Vg=1.016107 -> Vg=1.0
% INFO    : Gen at bus 9804	: Pg=18.5, Qg=2.5 -> Pg=56.165, Qg=0.0
% INFO    : Gen at bus 9804	: Vg=0.975244 -> Vg=1.0
% INFO    : Gen at bus 9808	: Pg=36.8, Qg=6.62 -> Pg=62.265, Qg=10.0
% INFO    : Gen at bus 9808	: Vg=1.03058 -> Vg=1.0
% INFO    : Gen at bus 9809	: Pg=27.2, Qg=3.82 -> Pg=59.065, Qg=10.0
% INFO    : Gen at bus 9809	: Vg=1.024762 -> Vg=1.0
% INFO    : Gen at bus 9815	: Pg=36.28, Qg=12.54 -> Pg=62.095, Qg=10.0
% INFO    : Gen at bus 9815	: Vg=1.022031 -> Vg=1.0
% INFO    : Gen at bus 9818	: Pg=41.94, Qg=8.5 -> Pg=63.98, Qg=15.0
% INFO    : Gen at bus 9818	: Vg=1.001006 -> Vg=1.0
% INFO    : Gen at bus 9830	: Pg=3.84, Qg=0.45 -> Pg=51.28, Qg=0.0
% INFO    : Gen at bus 9830	: Vg=1.030843 -> Vg=1.0
% INFO    : Gen at bus 9836	: Pg=12.8, Qg=1.08 -> Pg=54.265, Qg=0.0
% INFO    : Gen at bus 9836	: Vg=0.984262 -> Vg=1.0
% INFO    : Gen at bus 9852	: Pg=238.84, Qg=0.87 -> Pg=300.0, Qg=80.0
% INFO    : Gen at bus 9852	: Vg=1.029637 -> Vg=1.0
% INFO    : Gen at bus 9853	: Pg=13.95, Qg=4.91 -> Pg=54.65, Qg=5.0
% INFO    : Gen at bus 9853	: Vg=1.042135 -> Vg=1.0
% INFO    : Gen at bus 9855	: Pg=8.8, Qg=0.68 -> Pg=52.935, Qg=0.0
% INFO    : Gen at bus 9855	: Vg=1.015406 -> Vg=1.0
% INFO    : Gen at bus 9856	: Pg=95.16, Qg=47.93 -> Pg=131.72, Qg=20.0
% INFO    : Gen at bus 9856	: Vg=1.047943 -> Vg=1.0
% INFO    : Gen at bus 9860	: Pg=22.5, Qg=7.8 -> Pg=57.5, Qg=10.0
% INFO    : Gen at bus 9860	: Vg=0.998215 -> Vg=1.0
% INFO    : Gen at bus 9862	: Pg=96.9, Qg=14.27 -> Pg=132.3, Qg=20.0
% INFO    : Gen at bus 9862	: Vg=1.033735 -> Vg=1.0
% INFO    : Gen at bus 9870	: Pg=96.9, Qg=14.27 -> Pg=132.3, Qg=20.0
% INFO    : Gen at bus 9870	: Vg=1.033735 -> Vg=1.0
% INFO    : Gen at bus 9871	: Pg=201.8, Qg=37.41 -> Pg=300.0, Qg=40.0
% INFO    : Gen at bus 9871	: Vg=1.033788 -> Vg=1.0
% INFO    : Gen at bus 9873	: Pg=26.62, Qg=13.25 -> Pg=58.875, Qg=10.0
% INFO    : Gen at bus 9873	: Vg=1.040642 -> Vg=1.0
% INFO    : Gen at bus 9875	: Pg=311.23, Qg=83.72 -> Pg=450.0, Qg=80.0
% INFO    : Gen at bus 9875	: Vg=1.058355 -> Vg=1.0
% INFO    : Gen at bus 9880	: Pg=36.0, Qg=6.82 -> Pg=62.0, Qg=10.0
% INFO    : Gen at bus 9880	: Vg=1.03481 -> Vg=1.0
% INFO    : Gen at bus 9881	: Pg=4.78, Qg=-0.59 -> Pg=51.595, Qg=0.0
% INFO    : Gen at bus 9881	: Vg=1.026644 -> Vg=1.0
% INFO    : Gen at bus 9884	: Pg=34.31, Qg=1.99 -> Pg=61.435, Qg=10.0
% INFO    : Gen at bus 9884	: Vg=1.015531 -> Vg=1.0
% INFO    : Gen at bus 9885	: Pg=36.0, Qg=6.45 -> Pg=62.0, Qg=10.0
% INFO    : Gen at bus 9885	: Vg=1.034215 -> Vg=1.0
% INFO    : Gen at bus 9887	: Pg=36.0, Qg=6.45 -> Pg=62.0, Qg=10.0
% INFO    : Gen at bus 9887	: Vg=1.034215 -> Vg=1.0
% INFO    : Gen at bus 9889	: Pg=300.0, Qg=-22.92 -> Pg=350.0, Qg=0.0
% INFO    : Gen at bus 9889	: Vg=0.97134 -> Vg=1.0
% INFO    : Gen at bus 9890	: Pg=74.22, Qg=5.53 -> Pg=124.74, Qg=20.0
% INFO    : Gen at bus 9890	: Vg=1.027947 -> Vg=1.0
% INFO    : Gen at bus 9896	: Pg=39.74, Qg=12.1 -> Pg=63.245, Qg=10.0
% INFO    : Gen at bus 9896	: Vg=1.035163 -> Vg=1.0
% INFO    : Gen at bus 9897	: Pg=18.61, Qg=5.39 -> Pg=56.205, Qg=10.0
% INFO    : Gen at bus 9897	: Vg=1.016633 -> Vg=1.0
% INFO    : Gen at bus 9900	: Pg=18.61, Qg=5.39 -> Pg=56.205, Qg=10.0
% INFO    : Gen at bus 9900	: Vg=1.016633 -> Vg=1.0
% INFO    : Gen at bus 9901	: Pg=33.97, Qg=5.68 -> Pg=61.325, Qg=10.0
% INFO    : Gen at bus 9901	: Vg=1.022889 -> Vg=1.0
% INFO    : Gen at bus 9902	: Pg=64.18, Qg=-6.8 -> Pg=121.395, Qg=0.0
% INFO    : Gen at bus 9902	: Vg=0.951565 -> Vg=1.0
% INFO    : Gen at bus 9906	: Pg=140.0, Qg=-6.9 -> Pg=196.665, Qg=0.0
% INFO    : Gen at bus 9906	: Vg=0.991405 -> Vg=1.0
% INFO    : Gen at bus 9909	: Pg=81.02, Qg=15.21 -> Pg=127.005, Qg=20.0
% INFO    : Gen at bus 9909	: Vg=1.035421 -> Vg=1.0
% INFO    : Gen at bus 9911	: Pg=81.02, Qg=15.21 -> Pg=127.005, Qg=20.0
% INFO    : Gen at bus 9911	: Vg=1.035421 -> Vg=1.0
% INFO    : Gen at bus 9912	: Pg=81.02, Qg=15.21 -> Pg=127.005, Qg=20.0
% INFO    : Gen at bus 9912	: Vg=1.035421 -> Vg=1.0
% INFO    : Gen at bus 9914	: Pg=30.01, Qg=15.35 -> Pg=60.005, Qg=10.0
% INFO    : Gen at bus 9914	: Vg=1.052369 -> Vg=1.0
% INFO    : Gen at bus 9922	: Pg=32.93, Qg=4.74 -> Pg=60.975, Qg=10.0
% INFO    : Gen at bus 9922	: Vg=1.029161 -> Vg=1.0
% INFO    : Gen at bus 9923	: Pg=29.22, Qg=4.97 -> Pg=59.74, Qg=10.0
% INFO    : Gen at bus 9923	: Vg=1.01017 -> Vg=1.0
% INFO    : Gen at bus 9926	: Pg=38.95, Qg=5.12 -> Pg=62.985, Qg=10.0
% INFO    : Gen at bus 9926	: Vg=1.009486 -> Vg=1.0
% INFO    : Gen at bus 9932	: Pg=28.89, Qg=4.69 -> Pg=59.63, Qg=10.0
% INFO    : Gen at bus 9932	: Vg=1.029382 -> Vg=1.0
% INFO    : Gen at bus 9933	: Pg=32.93, Qg=4.74 -> Pg=60.975, Qg=10.0
% INFO    : Gen at bus 9933	: Vg=1.029161 -> Vg=1.0
% INFO    : Gen at bus 9937	: Pg=100.0, Qg=10.54 -> Pg=183.335, Qg=20.0
% INFO    : Gen at bus 9937	: Vg=1.01208 -> Vg=1.0
% INFO    : Gen at bus 9946	: Pg=26.31, Qg=9.5 -> Pg=58.77, Qg=10.0
% INFO    : Gen at bus 9946	: Vg=1.038225 -> Vg=1.0
% INFO    : Gen at bus 9953	: Pg=93.04, Qg=14.9 -> Pg=131.015, Qg=20.0
% INFO    : Gen at bus 9953	: Vg=1.017638 -> Vg=1.0
% INFO    : Gen at bus 9957	: Pg=20.57, Qg=3.1 -> Pg=56.855, Qg=10.0
% INFO    : Gen at bus 9957	: Vg=1.026081 -> Vg=1.0
% INFO    : Gen at bus 9958	: Pg=20.57, Qg=3.1 -> Pg=56.855, Qg=10.0
% INFO    : Gen at bus 9958	: Vg=1.026081 -> Vg=1.0
% INFO    : Gen at bus 9959	: Pg=20.57, Qg=3.1 -> Pg=56.855, Qg=10.0
% INFO    : Gen at bus 9959	: Vg=1.026081 -> Vg=1.0
% INFO    : Gen at bus 9960	: Pg=82.46, Qg=55.28 -> Pg=127.485, Qg=20.0
% INFO    : Gen at bus 9960	: Vg=1.127948 -> Vg=1.0
% INFO    : Gen at bus 9961	: Pg=23.42, Qg=3.99 -> Pg=57.805, Qg=10.0
% INFO    : Gen at bus 9961	: Vg=1.016605 -> Vg=1.0
% INFO    : Gen at bus 9963	: Pg=27.95, Qg=4.02 -> Pg=59.315, Qg=10.0
% INFO    : Gen at bus 9963	: Vg=1.016461 -> Vg=1.0
% INFO    : Gen at bus 9964	: Pg=23.42, Qg=3.99 -> Pg=57.805, Qg=10.0
% INFO    : Gen at bus 9964	: Vg=1.016605 -> Vg=1.0
% INFO    : Gen at bus 9972	: Pg=153.0, Qg=12.38 -> Pg=250.0, Qg=30.0
% INFO    : Gen at bus 9972	: Vg=1.017859 -> Vg=1.0
% INFO    : Gen at bus 9974	: Pg=32.64, Qg=6.68 -> Pg=60.88, Qg=10.0
% INFO    : Gen at bus 9974	: Vg=1.044939 -> Vg=1.0
% INFO    : Gen at bus 9975	: Pg=40.0, Qg=4.84 -> Pg=63.335, Qg=0.0
% INFO    : Gen at bus 9975	: Vg=0.957116 -> Vg=1.0
% INFO    : Gen at bus 9976	: Pg=23.5, Qg=5.12 -> Pg=57.835, Qg=10.0
% INFO    : Gen at bus 9976	: Vg=1.029146 -> Vg=1.0
% INFO    : Gen at bus 9984	: Pg=65.21, Qg=12.85 -> Pg=121.735, Qg=20.0
% INFO    : Gen at bus 9984	: Vg=1.026243 -> Vg=1.0
% INFO    : Gen at bus 9995	: Pg=50.0, Qg=-2.27 -> Pg=66.665, Qg=0.0
% INFO    : Gen at bus 9995	: Vg=0.993383 -> Vg=1.0
% INFO    : Gen at bus 9997	: Pg=0.08, Qg=-0.15 -> Pg=50.025, Qg=0.0
% INFO    : Gen at bus 9997	: Vg=1.016106 -> Vg=1.0
% INFO    : Gen at bus 10001	: Pg=36.11, Qg=3.87 -> Pg=62.035, Qg=10.0
% INFO    : Gen at bus 10001	: Vg=1.024544 -> Vg=1.0
% INFO    : Gen at bus 10004	: Pg=35.95, Qg=6.39 -> Pg=61.985, Qg=15.0
% INFO    : Gen at bus 10004	: Vg=1.015185 -> Vg=1.0
% INFO    : Gen at bus 10006	: Pg=31.5, Qg=1.72 -> Pg=60.5, Qg=5.0
% INFO    : Gen at bus 10006	: Vg=1.016735 -> Vg=1.0
% INFO    : Gen at bus 10007	: Pg=35.29, Qg=10.61 -> Pg=61.765, Qg=10.0
% INFO    : Gen at bus 10007	: Vg=1.043764 -> Vg=1.0
% INFO    : Gen at bus 10010	: Pg=10.36, Qg=0.68 -> Pg=53.455, Qg=0.0
% INFO    : Gen at bus 10010	: Vg=1.012893 -> Vg=1.0
% INFO    : Gen at bus 10012	: Pg=10.0, Qg=0.56 -> Pg=53.335, Qg=0.0
% INFO    : Gen at bus 10012	: Vg=1.01515 -> Vg=1.0
% INFO    : Gen at bus 10017	: Pg=67.68, Qg=4.49 -> Pg=122.56, Qg=20.0
% INFO    : Gen at bus 10017	: Vg=1.017078 -> Vg=1.0
% INFO    : Gen at bus 10023	: Pg=28.92, Qg=12.55 -> Pg=59.64, Qg=15.0
% INFO    : Gen at bus 10023	: Vg=1.019357 -> Vg=1.0
% INFO    : Gen at bus 10034	: Pg=25.27, Qg=3.21 -> Pg=58.425, Qg=10.0
% INFO    : Gen at bus 10034	: Vg=1.006944 -> Vg=1.0
% INFO    : Gen at bus 10037	: Pg=57.12, Qg=17.95 -> Pg=119.04, Qg=15.0
% INFO    : Gen at bus 10037	: Vg=1.017464 -> Vg=1.0
% INFO    : Gen at bus 10050	: Pg=35.86, Qg=4.09 -> Pg=61.955, Qg=10.0
% INFO    : Gen at bus 10050	: Vg=1.02494 -> Vg=1.0
% INFO    : Gen at bus 10052	: Pg=5.2, Qg=1.64 -> Pg=51.735, Qg=0.0
% INFO    : Gen at bus 10052	: Vg=1.019503 -> Vg=1.0
% INFO    : Gen at bus 10057	: Pg=53.13, Qg=-3.75 -> Pg=117.71, Qg=0.0
% INFO    : Gen at bus 10057	: Vg=1.003179 -> Vg=1.0
% INFO    : Gen at bus 10060	: Pg=617.47, Qg=92.14 -> Pg=850.0, Qg=200.0
% INFO    : Gen at bus 10060	: Vg=1.032321 -> Vg=1.0
% INFO    : Gen at bus 10064	: Pg=858.79, Qg=258.85 -> Pg=1150.0, Qg=200.0
% INFO    : Gen at bus 10064	: Vg=1.033602 -> Vg=1.0
% INFO    : Gen at bus 10065	: Pg=858.83, Qg=258.85 -> Pg=1150.0, Qg=200.0
% INFO    : Gen at bus 10065	: Vg=1.033601 -> Vg=1.0
% INFO    : Gen at bus 10068	: Pg=17.95, Qg=10.38 -> Pg=55.985, Qg=10.0
% INFO    : Gen at bus 10068	: Vg=1.044317 -> Vg=1.0
% INFO    : Gen at bus 10073	: Pg=44.08, Qg=14.37 -> Pg=64.695, Qg=15.0
% INFO    : Gen at bus 10073	: Vg=1.028279 -> Vg=1.0
% INFO    : Gen at bus 10074	: Pg=44.08, Qg=14.37 -> Pg=64.695, Qg=15.0
% INFO    : Gen at bus 10074	: Vg=1.028279 -> Vg=1.0
% INFO    : Gen at bus 10075	: Pg=46.7, Qg=16.39 -> Pg=65.565, Qg=15.0
% INFO    : Gen at bus 10075	: Vg=1.027739 -> Vg=1.0
% INFO    : Gen at bus 10076	: Pg=46.7, Qg=16.39 -> Pg=65.565, Qg=15.0
% INFO    : Gen at bus 10076	: Vg=1.027739 -> Vg=1.0
% INFO    : Gen at bus 10077	: Pg=46.7, Qg=16.39 -> Pg=65.565, Qg=15.0
% INFO    : Gen at bus 10077	: Vg=1.027739 -> Vg=1.0
% INFO    : Gen at bus 10078	: Pg=46.7, Qg=16.39 -> Pg=65.565, Qg=15.0
% INFO    : Gen at bus 10078	: Vg=1.027739 -> Vg=1.0
% INFO    : Gen at bus 10080	: Pg=46.7, Qg=16.39 -> Pg=65.565, Qg=15.0
% INFO    : Gen at bus 10080	: Vg=1.027739 -> Vg=1.0
% INFO    : Gen at bus 10084	: Pg=57.67, Qg=14.65 -> Pg=119.225, Qg=15.0
% INFO    : Gen at bus 10084	: Vg=1.028916 -> Vg=1.0
% INFO    : Gen at bus 10092	: Pg=37.66, Qg=9.24 -> Pg=62.555, Qg=10.0
% INFO    : Gen at bus 10092	: Vg=1.060112 -> Vg=1.0
% INFO    : Gen at bus 10094	: Pg=240.6, Qg=61.33 -> Pg=300.0, Qg=35.0
% INFO    : Gen at bus 10094	: Vg=0.990464 -> Vg=1.0
% INFO    : Gen at bus 10096	: Pg=33.32, Qg=9.67 -> Pg=61.105, Qg=10.0
% INFO    : Gen at bus 10096	: Vg=1.032797 -> Vg=1.0
% INFO    : Gen at bus 10100	: Pg=35.56, Qg=3.76 -> Pg=61.855, Qg=5.0
% INFO    : Gen at bus 10100	: Vg=1.036949 -> Vg=1.0
% INFO    : Gen at bus 10101	: Pg=72.47, Qg=11.44 -> Pg=124.155, Qg=20.0
% INFO    : Gen at bus 10101	: Vg=1.019231 -> Vg=1.0
% INFO    : Gen at bus 10102	: Pg=321.29, Qg=105.87 -> Pg=450.0, Qg=80.0
% INFO    : Gen at bus 10102	: Vg=1.034412 -> Vg=1.0
% INFO    : Gen at bus 10110	: Pg=30.24, Qg=9.06 -> Pg=60.08, Qg=10.0
% INFO    : Gen at bus 10110	: Vg=1.012031 -> Vg=1.0
% INFO    : Gen at bus 10114	: Pg=2.26, Qg=-1.2 -> Pg=50.755, Qg=0.0
% INFO    : Gen at bus 10114	: Vg=0.991929 -> Vg=1.0
% INFO    : Gen at bus 10115	: Pg=301.72, Qg=83.89 -> Pg=450.0, Qg=80.0
% INFO    : Gen at bus 10115	: Vg=1.041212 -> Vg=1.0
% INFO    : Gen at bus 10116	: Pg=301.72, Qg=83.89 -> Pg=450.0, Qg=80.0
% INFO    : Gen at bus 10116	: Vg=1.041212 -> Vg=1.0
% INFO    : Gen at bus 10117	: Pg=301.72, Qg=83.89 -> Pg=450.0, Qg=80.0
% INFO    : Gen at bus 10117	: Vg=1.041212 -> Vg=1.0
% INFO    : Gen at bus 10120	: Pg=83.78, Qg=15.02 -> Pg=127.925, Qg=20.0
% INFO    : Gen at bus 10120	: Vg=1.033534 -> Vg=1.0
% INFO    : Gen at bus 10132	: Pg=33.68, Qg=6.27 -> Pg=61.225, Qg=10.0
% INFO    : Gen at bus 10132	: Vg=1.046665 -> Vg=1.0
% INFO    : Gen at bus 10134	: Pg=33.68, Qg=6.27 -> Pg=61.225, Qg=10.0
% INFO    : Gen at bus 10134	: Vg=1.046665 -> Vg=1.0
% INFO    : Gen at bus 10135	: Pg=33.68, Qg=6.27 -> Pg=61.225, Qg=10.0
% INFO    : Gen at bus 10135	: Vg=1.046665 -> Vg=1.0
% INFO    : Gen at bus 10141	: Pg=92.4, Qg=2.72 -> Pg=130.8, Qg=20.0
% INFO    : Gen at bus 10141	: Vg=1.014507 -> Vg=1.0
% INFO    : Gen at bus 10142	: Pg=92.4, Qg=2.72 -> Pg=130.8, Qg=20.0
% INFO    : Gen at bus 10142	: Vg=1.014507 -> Vg=1.0
% INFO    : Gen at bus 10143	: Pg=92.4, Qg=2.72 -> Pg=130.8, Qg=20.0
% INFO    : Gen at bus 10143	: Vg=1.014507 -> Vg=1.0
% INFO    : Gen at bus 10151	: Pg=33.06, Qg=9.48 -> Pg=61.02, Qg=10.0
% INFO    : Gen at bus 10151	: Vg=1.009173 -> Vg=1.0
% INFO    : Gen at bus 10156	: Pg=159.8, Qg=34.27 -> Pg=250.0, Qg=30.0
% INFO    : Gen at bus 10156	: Vg=0.978477 -> Vg=1.0
% INFO    : Gen at bus 10158	: Pg=29.65, Qg=15.88 -> Pg=59.885, Qg=10.0
% INFO    : Gen at bus 10158	: Vg=1.051307 -> Vg=1.0
% INFO    : Gen at bus 10164	: Pg=33.06, Qg=9.48 -> Pg=61.02, Qg=10.0
% INFO    : Gen at bus 10164	: Vg=1.009173 -> Vg=1.0
% INFO    : Gen at bus 10165	: Pg=367.04, Qg=57.82 -> Pg=500.0, Qg=80.0
% INFO    : Gen at bus 10165	: Vg=1.028579 -> Vg=1.0
% INFO    : Gen at bus 10171	: Pg=90.45, Qg=21.15 -> Pg=130.15, Qg=20.0
% INFO    : Gen at bus 10171	: Vg=1.046641 -> Vg=1.0
% INFO    : Gen at bus 10172	: Pg=90.45, Qg=21.15 -> Pg=130.15, Qg=20.0
% INFO    : Gen at bus 10172	: Vg=1.046641 -> Vg=1.0
% INFO    : Gen at bus 10173	: Pg=90.45, Qg=21.15 -> Pg=130.15, Qg=20.0
% INFO    : Gen at bus 10173	: Vg=1.046641 -> Vg=1.0
% INFO    : Gen at bus 10174	: Pg=90.45, Qg=21.15 -> Pg=130.15, Qg=20.0
% INFO    : Gen at bus 10174	: Vg=1.046641 -> Vg=1.0
% INFO    : Gen at bus 10177	: Pg=161.0, Qg=0.83 -> Pg=250.0, Qg=0.0
% INFO    : Gen at bus 10177	: Vg=1.011416 -> Vg=1.0
% INFO    : Gen at bus 10178	: Pg=34.65, Qg=5.41 -> Pg=61.55, Qg=10.0
% INFO    : Gen at bus 10178	: Vg=1.014865 -> Vg=1.0
% INFO    : Gen at bus 10186	: Pg=5.2, Qg=0.53 -> Pg=51.735, Qg=0.0
% INFO    : Gen at bus 10186	: Vg=1.031159 -> Vg=1.0
% INFO    : Gen at bus 10192	: Pg=25.32, Qg=7.7 -> Pg=58.44, Qg=10.0
% INFO    : Gen at bus 10192	: Vg=1.059619 -> Vg=1.0
% INFO    : Gen at bus 10194	: Pg=25.07, Qg=18.26 -> Pg=58.355, Qg=10.0
% INFO    : Gen at bus 10194	: Vg=1.048908 -> Vg=1.0
% INFO    : Gen at bus 10195	: Pg=25.07, Qg=18.26 -> Pg=58.355, Qg=10.0
% INFO    : Gen at bus 10195	: Vg=1.048908 -> Vg=1.0
% INFO    : Gen at bus 10197	: Pg=22.99, Qg=16.83 -> Pg=57.665, Qg=10.0
% INFO    : Gen at bus 10197	: Vg=1.052604 -> Vg=1.0
% INFO    : Gen at bus 10198	: Pg=22.99, Qg=16.83 -> Pg=57.665, Qg=10.0
% INFO    : Gen at bus 10198	: Vg=1.052604 -> Vg=1.0
% INFO    : Gen at bus 10201	: Pg=26.78, Qg=11.89 -> Pg=58.925, Qg=10.0
% INFO    : Gen at bus 10201	: Vg=1.043753 -> Vg=1.0
% INFO    : Gen at bus 10202	: Pg=26.78, Qg=11.89 -> Pg=58.925, Qg=10.0
% INFO    : Gen at bus 10202	: Vg=1.043753 -> Vg=1.0
% INFO    : Gen at bus 10210	: Pg=38.52, Qg=8.15 -> Pg=62.84, Qg=10.0
% INFO    : Gen at bus 10210	: Vg=1.04659 -> Vg=1.0
% INFO    : Gen at bus 10211	: Pg=228.6, Qg=14.34 -> Pg=300.0, Qg=45.0
% INFO    : Gen at bus 10211	: Vg=0.979798 -> Vg=1.0
% INFO    : Gen at bus 10218	: Pg=28.35, Qg=17.5 -> Pg=59.45, Qg=10.0
% INFO    : Gen at bus 10218	: Vg=1.042184 -> Vg=1.0
% INFO    : Gen at bus 10222	: Pg=33.12, Qg=3.26 -> Pg=61.04, Qg=5.0
% INFO    : Gen at bus 10222	: Vg=1.008414 -> Vg=1.0
% INFO    : Gen at bus 10223	: Pg=32.51, Qg=6.89 -> Pg=60.835, Qg=10.0
% INFO    : Gen at bus 10223	: Vg=1.011478 -> Vg=1.0
% INFO    : Gen at bus 10232	: Pg=23.65, Qg=10.04 -> Pg=57.885, Qg=10.0
% INFO    : Gen at bus 10232	: Vg=1.059543 -> Vg=1.0
% INFO    : Gen at bus 10236	: Pg=24.37, Qg=4.5 -> Pg=58.125, Qg=10.0
% INFO    : Gen at bus 10236	: Vg=1.00571 -> Vg=1.0
% INFO    : Gen at bus 10237	: Pg=2.94, Qg=0.27 -> Pg=50.98, Qg=0.0
% INFO    : Gen at bus 10237	: Vg=1.008736 -> Vg=1.0
% INFO    : Gen at bus 10238	: Pg=24.81, Qg=-3.88 -> Pg=58.27, Qg=10.0
% INFO    : Gen at bus 10238	: Vg=0.99879 -> Vg=1.0
% INFO    : Gen at bus 10239	: Pg=113.64, Qg=7.1 -> Pg=187.88, Qg=10.0
% INFO    : Gen at bus 10239	: Vg=0.989503 -> Vg=1.0
% INFO    : Gen at bus 10241	: Pg=19.5, Qg=-2.56 -> Pg=56.5, Qg=10.0
% INFO    : Gen at bus 10241	: Vg=1.017394 -> Vg=1.0
% INFO    : Gen at bus 10242	: Pg=19.5, Qg=-2.56 -> Pg=56.5, Qg=10.0
% INFO    : Gen at bus 10242	: Vg=1.017394 -> Vg=1.0
% INFO    : Gen at bus 10246	: Pg=26.75, Qg=6.78 -> Pg=58.915, Qg=15.0
% INFO    : Gen at bus 10246	: Vg=1.024572 -> Vg=1.0
% INFO    : Gen at bus 10249	: Pg=34.86, Qg=4.81 -> Pg=61.62, Qg=10.0
% INFO    : Gen at bus 10249	: Vg=1.050901 -> Vg=1.0
% INFO    : Gen at bus 10250	: Pg=163.94, Qg=189.92 -> Pg=250.0, Qg=80.0
% INFO    : Gen at bus 10250	: Vg=1.050579 -> Vg=1.0
% INFO    : Gen at bus 10253	: Pg=81.35, Qg=28.89 -> Pg=127.115, Qg=20.0
% INFO    : Gen at bus 10253	: Vg=1.055981 -> Vg=1.0
% INFO    : Gen at bus 10254	: Pg=81.35, Qg=28.89 -> Pg=127.115, Qg=20.0
% INFO    : Gen at bus 10254	: Vg=1.055981 -> Vg=1.0
% INFO    : Gen at bus 10264	: Pg=41.8, Qg=9.39 -> Pg=63.935, Qg=15.0
% INFO    : Gen at bus 10264	: Vg=1.028604 -> Vg=1.0
% INFO    : Gen at bus 10267	: Pg=98.47, Qg=3.73 -> Pg=132.825, Qg=20.0
% INFO    : Gen at bus 10267	: Vg=1.04126 -> Vg=1.0
% INFO    : Gen at bus 10268	: Pg=98.47, Qg=3.73 -> Pg=132.825, Qg=20.0
% INFO    : Gen at bus 10268	: Vg=1.04126 -> Vg=1.0
% INFO    : Gen at bus 10269	: Pg=57.3, Qg=3.1 -> Pg=119.1, Qg=20.0
% INFO    : Gen at bus 10269	: Vg=1.041091 -> Vg=1.0
% INFO    : Gen at bus 10270	: Pg=57.3, Qg=3.1 -> Pg=119.1, Qg=20.0
% INFO    : Gen at bus 10270	: Vg=1.041091 -> Vg=1.0
% INFO    : Gen at bus 10276	: Pg=9.0, Qg=-0.95 -> Pg=53.0, Qg=0.0
% INFO    : Gen at bus 10276	: Vg=0.943602 -> Vg=1.0
% INFO    : Gen at bus 10281	: Pg=34.01, Qg=4.15 -> Pg=61.335, Qg=10.0
% INFO    : Gen at bus 10281	: Vg=1.014364 -> Vg=1.0
% INFO    : Gen at bus 10283	: Pg=20.91, Qg=7.74 -> Pg=56.97, Qg=10.0
% INFO    : Gen at bus 10283	: Vg=1.014154 -> Vg=1.0
% INFO    : Gen at bus 10285	: Pg=6.1, Qg=0.22 -> Pg=52.035, Qg=0.0
% INFO    : Gen at bus 10285	: Vg=1.00107 -> Vg=1.0
% INFO    : Gen at bus 10287	: Pg=29.01, Qg=1.68 -> Pg=59.67, Qg=5.0
% INFO    : Gen at bus 10287	: Vg=1.010115 -> Vg=1.0
% INFO    : Gen at bus 10295	: Pg=27.37, Qg=3.79 -> Pg=59.125, Qg=5.0
% INFO    : Gen at bus 10295	: Vg=1.003014 -> Vg=1.0
% INFO    : Gen at bus 10298	: Pg=34.96, Qg=5.47 -> Pg=61.655, Qg=0.0
% INFO    : Gen at bus 10298	: Vg=0.935194 -> Vg=1.0
% INFO    : Gen at bus 10302	: Pg=36.1, Qg=4.8 -> Pg=62.035, Qg=5.0
% INFO    : Gen at bus 10302	: Vg=1.016385 -> Vg=1.0
% INFO    : Gen at bus 10311	: Pg=25.68, Qg=12.42 -> Pg=58.56, Qg=10.0
% INFO    : Gen at bus 10311	: Vg=1.052378 -> Vg=1.0
% INFO    : Gen at bus 10315	: Pg=25.35, Qg=8.5 -> Pg=58.45, Qg=15.0
% INFO    : Gen at bus 10315	: Vg=1.018631 -> Vg=1.0
% INFO    : Gen at bus 10324	: Pg=98.05, Qg=38.32 -> Pg=132.685, Qg=20.0
% INFO    : Gen at bus 10324	: Vg=1.058149 -> Vg=1.0
% INFO    : Gen at bus 10328	: Pg=85.34, Qg=16.39 -> Pg=128.445, Qg=20.0
% INFO    : Gen at bus 10328	: Vg=1.053529 -> Vg=1.0
% INFO    : Gen at bus 10329	: Pg=98.05, Qg=38.32 -> Pg=132.685, Qg=20.0
% INFO    : Gen at bus 10329	: Vg=1.058149 -> Vg=1.0
% INFO    : Gen at bus 10330	: Pg=586.88, Qg=407.04 -> Pg=750.0, Qg=200.0
% INFO    : Gen at bus 10330	: Vg=1.052406 -> Vg=1.0
% INFO    : Gen at bus 10337	: Pg=72.99, Qg=3.91 -> Pg=124.33, Qg=20.0
% INFO    : Gen at bus 10337	: Vg=1.019549 -> Vg=1.0
% INFO    : Gen at bus 10339	: Pg=32.57, Qg=7.29 -> Pg=60.855, Qg=10.0
% INFO    : Gen at bus 10339	: Vg=1.041748 -> Vg=1.0
% INFO    : Gen at bus 10343	: Pg=57.4, Qg=4.0 -> Pg=119.135, Qg=20.0
% INFO    : Gen at bus 10343	: Vg=1.02039 -> Vg=1.0
% INFO    : Gen at bus 10348	: Pg=40.23, Qg=5.24 -> Pg=63.41, Qg=10.0
% INFO    : Gen at bus 10348	: Vg=1.006137 -> Vg=1.0
% INFO    : Gen at bus 10352	: Pg=38.79, Qg=7.11 -> Pg=62.93, Qg=10.0
% INFO    : Gen at bus 10352	: Vg=1.035838 -> Vg=1.0
% INFO    : Gen at bus 10355	: Pg=91.55, Qg=46.19 -> Pg=130.515, Qg=20.0
% INFO    : Gen at bus 10355	: Vg=1.056125 -> Vg=1.0
% INFO    : Gen at bus 10357	: Pg=311.23, Qg=83.72 -> Pg=450.0, Qg=80.0
% INFO    : Gen at bus 10357	: Vg=1.058355 -> Vg=1.0
% INFO    : Gen at bus 10361	: Pg=6.78, Qg=-0.39 -> Pg=52.26, Qg=0.0
% INFO    : Gen at bus 10361	: Vg=1.020123 -> Vg=1.0
% INFO    : Gen at bus 10362	: Pg=55.89, Qg=7.86 -> Pg=118.63, Qg=20.0
% INFO    : Gen at bus 10362	: Vg=0.992211 -> Vg=1.0
% INFO    : Gen at bus 10363	: Pg=40.23, Qg=5.24 -> Pg=63.41, Qg=10.0
% INFO    : Gen at bus 10363	: Vg=1.006137 -> Vg=1.0
% INFO    : Gen at bus 10365	: Pg=17.5, Qg=-0.6 -> Pg=55.835, Qg=0.0
% INFO    : Gen at bus 10365	: Vg=0.996564 -> Vg=1.0
% INFO    : Gen at bus 10368	: Pg=82.95, Qg=6.41 -> Pg=127.65, Qg=5.0
% INFO    : Gen at bus 10368	: Vg=0.992945 -> Vg=1.0
% INFO    : Gen at bus 10373	: Pg=99.8, Qg=-17.67 -> Pg=133.265, Qg=40.0
% INFO    : Gen at bus 10373	: Vg=1.029653 -> Vg=1.0
% INFO    : Gen at bus 10374	: Pg=314.64, Qg=49.18 -> Pg=450.0, Qg=80.0
% INFO    : Gen at bus 10374	: Vg=1.022804 -> Vg=1.0
% INFO    : Gen at bus 10375	: Pg=314.64, Qg=49.18 -> Pg=450.0, Qg=80.0
% INFO    : Gen at bus 10375	: Vg=1.022804 -> Vg=1.0
% INFO    : Gen at bus 10376	: Pg=56.1, Qg=11.17 -> Pg=118.7, Qg=0.0
% INFO    : Gen at bus 10376	: Vg=0.927975 -> Vg=1.0
% INFO    : Gen at bus 10377	: Pg=209.47, Qg=121.67 -> Pg=300.0, Qg=80.0
% INFO    : Gen at bus 10377	: Vg=1.027231 -> Vg=1.0
% INFO    : Gen at bus 10378	: Pg=209.47, Qg=121.67 -> Pg=300.0, Qg=80.0
% INFO    : Gen at bus 10378	: Vg=1.027231 -> Vg=1.0
% INFO    : Gen at bus 10384	: Pg=36.03, Qg=16.08 -> Pg=62.01, Qg=10.0
% INFO    : Gen at bus 10384	: Vg=1.045359 -> Vg=1.0
% INFO    : Gen at bus 10386	: Pg=33.15, Qg=0.93 -> Pg=61.05, Qg=10.0
% INFO    : Gen at bus 10386	: Vg=1.024669 -> Vg=1.0
% INFO    : Gen at bus 10388	: Pg=21.03, Qg=9.75 -> Pg=57.01, Qg=10.0
% INFO    : Gen at bus 10388	: Vg=1.034464 -> Vg=1.0
% INFO    : Gen at bus 10390	: Pg=63.63, Qg=44.69 -> Pg=121.21, Qg=20.0
% INFO    : Gen at bus 10390	: Vg=1.058213 -> Vg=1.0
% INFO    : Gen at bus 10401	: Pg=65.58, Qg=12.54 -> Pg=121.86, Qg=20.0
% INFO    : Gen at bus 10401	: Vg=1.029941 -> Vg=1.0
% INFO    : Gen at bus 10402	: Pg=65.58, Qg=12.54 -> Pg=121.86, Qg=20.0
% INFO    : Gen at bus 10402	: Vg=1.029941 -> Vg=1.0
% INFO    : Gen at bus 10404	: Pg=65.58, Qg=12.54 -> Pg=121.86, Qg=20.0
% INFO    : Gen at bus 10404	: Vg=1.029941 -> Vg=1.0
% INFO    : Gen at bus 10405	: Pg=65.58, Qg=12.54 -> Pg=121.86, Qg=20.0
% INFO    : Gen at bus 10405	: Vg=1.029941 -> Vg=1.0
% INFO    : Gen at bus 10406	: Pg=34.22, Qg=12.75 -> Pg=61.405, Qg=5.0
% INFO    : Gen at bus 10406	: Vg=1.04163 -> Vg=1.0
% INFO    : Gen at bus 10408	: Pg=16.79, Qg=7.28 -> Pg=55.595, Qg=10.0
% INFO    : Gen at bus 10408	: Vg=1.042166 -> Vg=1.0
% INFO    : Gen at bus 10409	: Pg=6.3, Qg=0.47 -> Pg=52.1, Qg=0.0
% INFO    : Gen at bus 10409	: Vg=1.012872 -> Vg=1.0
% INFO    : Gen at bus 10410	: Pg=36.0, Qg=6.45 -> Pg=62.0, Qg=10.0
% INFO    : Gen at bus 10410	: Vg=1.034215 -> Vg=1.0
% INFO    : Gen at bus 10417	: Pg=26.56, Qg=10.95 -> Pg=58.855, Qg=10.0
% INFO    : Gen at bus 10417	: Vg=1.002675 -> Vg=1.0
% INFO    : Gen at bus 10418	: Pg=37.9, Qg=13.47 -> Pg=62.635, Qg=10.0
% INFO    : Gen at bus 10418	: Vg=1.0326 -> Vg=1.0
% INFO    : Gen at bus 10422	: Pg=24.72, Qg=4.34 -> Pg=58.24, Qg=10.0
% INFO    : Gen at bus 10422	: Vg=1.039546 -> Vg=1.0
% INFO    : Gen at bus 10423	: Pg=66.31, Qg=16.47 -> Pg=122.105, Qg=20.0
% INFO    : Gen at bus 10423	: Vg=1.020956 -> Vg=1.0
% INFO    : Gen at bus 10426	: Pg=38.16, Qg=5.63 -> Pg=62.72, Qg=10.0
% INFO    : Gen at bus 10426	: Vg=1.015046 -> Vg=1.0
% INFO    : Gen at bus 10427	: Pg=38.16, Qg=5.63 -> Pg=62.72, Qg=10.0
% INFO    : Gen at bus 10427	: Vg=1.015046 -> Vg=1.0
% INFO    : Gen at bus 10428	: Pg=30.0, Qg=3.15 -> Pg=60.0, Qg=5.0
% INFO    : Gen at bus 10428	: Vg=1.046548 -> Vg=1.0
% INFO    : Gen at bus 10432	: Pg=12.66, Qg=5.6 -> Pg=54.22, Qg=10.0
% INFO    : Gen at bus 10432	: Vg=0.998217 -> Vg=1.0
% INFO    : Gen at bus 10433	: Pg=7.46, Qg=-0.12 -> Pg=52.485, Qg=0.0
% INFO    : Gen at bus 10433	: Vg=0.997543 -> Vg=1.0
% INFO    : Gen at bus 10434	: Pg=19.98, Qg=0.98 -> Pg=56.66, Qg=10.0
% INFO    : Gen at bus 10434	: Vg=1.029635 -> Vg=1.0
% INFO    : Gen at bus 10435	: Pg=19.98, Qg=0.98 -> Pg=56.66, Qg=10.0
% INFO    : Gen at bus 10435	: Vg=1.029635 -> Vg=1.0
% INFO    : Gen at bus 10436	: Pg=24.86, Qg=5.7 -> Pg=58.285, Qg=10.0
% INFO    : Gen at bus 10436	: Vg=0.997985 -> Vg=1.0
% INFO    : Gen at bus 10437	: Pg=15.97, Qg=11.98 -> Pg=55.325, Qg=10.0
% INFO    : Gen at bus 10437	: Vg=1.042028 -> Vg=1.0
% INFO    : Gen at bus 10438	: Pg=15.97, Qg=11.98 -> Pg=55.325, Qg=10.0
% INFO    : Gen at bus 10438	: Vg=1.042028 -> Vg=1.0
% INFO    : Gen at bus 10439	: Pg=12.66, Qg=5.6 -> Pg=54.22, Qg=10.0
% INFO    : Gen at bus 10439	: Vg=0.998217 -> Vg=1.0
% INFO    : Gen at bus 10442	: Pg=69.46, Qg=4.37 -> Pg=123.155, Qg=20.0
% INFO    : Gen at bus 10442	: Vg=1.041381 -> Vg=1.0
% INFO    : Gen at bus 10443	: Pg=26.31, Qg=9.5 -> Pg=58.77, Qg=10.0
% INFO    : Gen at bus 10443	: Vg=1.038225 -> Vg=1.0
% INFO    : Gen at bus 10447	: Pg=26.81, Qg=10.09 -> Pg=58.935, Qg=10.0
% INFO    : Gen at bus 10447	: Vg=1.044747 -> Vg=1.0
% INFO    : Gen at bus 10448	: Pg=45.54, Qg=5.69 -> Pg=65.18, Qg=15.0
% INFO    : Gen at bus 10448	: Vg=1.044129 -> Vg=1.0
% INFO    : Gen at bus 10452	: Pg=-0.54, Qg=-3.75 -> Pg=49.64, Qg=0.0
% INFO    : Gen at bus 10452	: Vg=1.014607 -> Vg=1.0
% INFO    : Gen at bus 10453	: Pg=38.91, Qg=13.48 -> Pg=62.97, Qg=15.0
% INFO    : Gen at bus 10453	: Vg=0.994929 -> Vg=1.0
% INFO    : Gen at bus 10456	: Pg=39.24, Qg=8.33 -> Pg=63.08, Qg=10.0
% INFO    : Gen at bus 10456	: Vg=1.009038 -> Vg=1.0
% INFO    : Gen at bus 10461	: Pg=276.1, Qg=40.94 -> Pg=350.0, Qg=60.0
% INFO    : Gen at bus 10461	: Vg=1.035338 -> Vg=1.0
% INFO    : Gen at bus 10462	: Pg=276.1, Qg=40.94 -> Pg=350.0, Qg=60.0
% INFO    : Gen at bus 10462	: Vg=1.035338 -> Vg=1.0
% INFO    : Gen at bus 10466	: Pg=10.0, Qg=2.6 -> Pg=53.335, Qg=0.0
% INFO    : Gen at bus 10466	: Vg=1.008964 -> Vg=1.0
% INFO    : Gen at bus 10469	: Pg=37.08, Qg=5.51 -> Pg=62.36, Qg=10.0
% INFO    : Gen at bus 10469	: Vg=1.021005 -> Vg=1.0
% INFO    : Gen at bus 10470	: Pg=26.81, Qg=10.09 -> Pg=58.935, Qg=10.0
% INFO    : Gen at bus 10470	: Vg=1.044747 -> Vg=1.0
% INFO    : Gen at bus 10472	: Pg=95.38, Qg=41.05 -> Pg=131.795, Qg=20.0
% INFO    : Gen at bus 10472	: Vg=1.061235 -> Vg=1.0
% INFO    : Gen at bus 10473	: Pg=165.0, Qg=33.72 -> Pg=250.0, Qg=40.0
% INFO    : Gen at bus 10473	: Vg=0.962508 -> Vg=1.0
% INFO    : Gen at bus 10474	: Pg=95.38, Qg=41.05 -> Pg=131.795, Qg=20.0
% INFO    : Gen at bus 10474	: Vg=1.061235 -> Vg=1.0
% INFO    : Gen at bus 10475	: Pg=95.38, Qg=41.05 -> Pg=131.795, Qg=20.0
% INFO    : Gen at bus 10475	: Vg=1.061235 -> Vg=1.0
% INFO    : Gen at bus 10476	: Pg=95.38, Qg=41.05 -> Pg=131.795, Qg=20.0
% INFO    : Gen at bus 10476	: Vg=1.061235 -> Vg=1.0
% INFO    : Gen at bus 10479	: Pg=95.45, Qg=36.47 -> Pg=131.815, Qg=20.0
% INFO    : Gen at bus 10479	: Vg=1.060605 -> Vg=1.0
% INFO    : Gen at bus 10480	: Pg=95.45, Qg=36.47 -> Pg=131.815, Qg=20.0
% INFO    : Gen at bus 10480	: Vg=1.060605 -> Vg=1.0
% INFO    : Gen at bus 10488	: Pg=34.04, Qg=7.33 -> Pg=61.345, Qg=15.0
% INFO    : Gen at bus 10488	: Vg=1.031942 -> Vg=1.0
% INFO    : Gen at bus 10489	: Pg=34.04, Qg=7.33 -> Pg=61.345, Qg=15.0
% INFO    : Gen at bus 10489	: Vg=1.031942 -> Vg=1.0
% INFO    : Gen at bus 10501	: Pg=25.2, Qg=-3.93 -> Pg=58.4, Qg=0.0
% INFO    : Gen at bus 10501	: Vg=0.993105 -> Vg=1.0
% INFO    : Gen at bus 10505	: Pg=323.35, Qg=77.76 -> Pg=450.0, Qg=80.0
% INFO    : Gen at bus 10505	: Vg=1.058114 -> Vg=1.0
% INFO    : Gen at bus 10507	: Pg=5.27, Qg=-0.06 -> Pg=51.755, Qg=0.0
% INFO    : Gen at bus 10507	: Vg=1.016731 -> Vg=1.0
% INFO    : Gen at bus 10508	: Pg=10.89, Qg=-0.15 -> Pg=53.63, Qg=0.0
% INFO    : Gen at bus 10508	: Vg=1.009642 -> Vg=1.0
% INFO    : Gen at bus 10521	: Pg=86.41, Qg=23.5 -> Pg=128.805, Qg=20.0
% INFO    : Gen at bus 10521	: Vg=1.031898 -> Vg=1.0
% INFO    : Gen at bus 10522	: Pg=86.41, Qg=23.5 -> Pg=128.805, Qg=20.0
% INFO    : Gen at bus 10522	: Vg=1.031898 -> Vg=1.0
% INFO    : Gen at bus 10527	: Pg=36.42, Qg=7.96 -> Pg=62.14, Qg=10.0
% INFO    : Gen at bus 10527	: Vg=1.029166 -> Vg=1.0
% INFO    : Gen at bus 10530	: Pg=754.17, Qg=238.65 -> Pg=1050.0, Qg=200.0
% INFO    : Gen at bus 10530	: Vg=1.043738 -> Vg=1.0
% INFO    : Gen at bus 10534	: Pg=48.42, Qg=9.78 -> Pg=66.14, Qg=15.0
% INFO    : Gen at bus 10534	: Vg=1.01601 -> Vg=1.0
% INFO    : Gen at bus 10535	: Pg=209.49, Qg=209.89 -> Pg=300.0, Qg=80.0
% INFO    : Gen at bus 10535	: Vg=1.126501 -> Vg=1.0
% INFO    : Gen at bus 10537	: Pg=28.92, Qg=12.55 -> Pg=59.64, Qg=15.0
% INFO    : Gen at bus 10537	: Vg=1.019357 -> Vg=1.0
% INFO    : Gen at bus 10538	: Pg=28.92, Qg=12.55 -> Pg=59.64, Qg=15.0
% INFO    : Gen at bus 10538	: Vg=1.019357 -> Vg=1.0
% INFO    : Gen at bus 10554	: Pg=300.0, Qg=-14.29 -> Pg=450.0, Qg=0.0
% INFO    : Gen at bus 10554	: Vg=1.001419 -> Vg=1.0
% INFO    : Gen at bus 10555	: Pg=858.22, Qg=148.21 -> Pg=1150.0, Qg=200.0
% INFO    : Gen at bus 10555	: Vg=1.058617 -> Vg=1.0
% INFO    : Gen at bus 10556	: Pg=858.23, Qg=148.21 -> Pg=1150.0, Qg=200.0
% INFO    : Gen at bus 10556	: Vg=1.058617 -> Vg=1.0
% INFO    : Gen at bus 10557	: Pg=6.38, Qg=-0.43 -> Pg=52.125, Qg=0.0
% INFO    : Gen at bus 10557	: Vg=0.962211 -> Vg=1.0
% INFO    : Gen at bus 10558	: Pg=858.23, Qg=148.21 -> Pg=1150.0, Qg=200.0
% INFO    : Gen at bus 10558	: Vg=1.058617 -> Vg=1.0
% INFO    : Gen at bus 10567	: Pg=224.32, Qg=74.3 -> Pg=300.0, Qg=80.0
% INFO    : Gen at bus 10567	: Vg=1.033196 -> Vg=1.0
% INFO    : Gen at bus 10575	: Pg=30.07, Qg=6.48 -> Pg=60.025, Qg=10.0
% INFO    : Gen at bus 10575	: Vg=1.058835 -> Vg=1.0
% INFO    : Gen at bus 10580	: Pg=1.2, Qg=0.03 -> Pg=50.4, Qg=0.0
% INFO    : Gen at bus 10580	: Vg=1.003171 -> Vg=1.0
% INFO    : Gen at bus 10588	: Pg=62.5, Qg=10.73 -> Pg=120.835, Qg=10.0
% INFO    : Gen at bus 10588	: Vg=1.000057 -> Vg=1.0
% INFO    : Gen at bus 10589	: Pg=72.47, Qg=11.44 -> Pg=124.155, Qg=20.0
% INFO    : Gen at bus 10589	: Vg=1.019231 -> Vg=1.0
% INFO    : Gen at bus 10598	: Pg=9.8, Qg=-0.3 -> Pg=53.265, Qg=0.0
% INFO    : Gen at bus 10598	: Vg=0.996611 -> Vg=1.0
% INFO    : Gen at bus 10605	: Pg=38.79, Qg=7.11 -> Pg=62.93, Qg=10.0
% INFO    : Gen at bus 10605	: Vg=1.035838 -> Vg=1.0
% INFO    : Gen at bus 10612	: Pg=27.19, Qg=6.05 -> Pg=59.065, Qg=10.0
% INFO    : Gen at bus 10612	: Vg=1.014542 -> Vg=1.0
% INFO    : Gen at bus 10613	: Pg=0.46, Qg=-0.11 -> Pg=50.155, Qg=0.0
% INFO    : Gen at bus 10613	: Vg=1.018329 -> Vg=1.0
% INFO    : Gen at bus 10617	: Pg=84.68, Qg=7.94 -> Pg=128.225, Qg=20.0
% INFO    : Gen at bus 10617	: Vg=1.00657 -> Vg=1.0
% INFO    : Gen at bus 10619	: Pg=81.96, Qg=34.23 -> Pg=127.32, Qg=20.0
% INFO    : Gen at bus 10619	: Vg=1.031098 -> Vg=1.0
% INFO    : Gen at bus 10621	: Pg=29.68, Qg=6.45 -> Pg=59.895, Qg=10.0
% INFO    : Gen at bus 10621	: Vg=1.016891 -> Vg=1.0
% INFO    : Gen at bus 10622	: Pg=35.06, Qg=4.02 -> Pg=61.685, Qg=10.0
% INFO    : Gen at bus 10622	: Vg=1.032126 -> Vg=1.0
% INFO    : Gen at bus 10625	: Pg=29.68, Qg=6.45 -> Pg=59.895, Qg=10.0
% INFO    : Gen at bus 10625	: Vg=1.016891 -> Vg=1.0
% INFO    : Gen at bus 10627	: Pg=84.19, Qg=8.48 -> Pg=128.065, Qg=20.0
% INFO    : Gen at bus 10627	: Vg=1.040259 -> Vg=1.0
% INFO    : Gen at bus 10629	: Pg=100.41, Qg=11.92 -> Pg=183.47, Qg=20.0
% INFO    : Gen at bus 10629	: Vg=1.038747 -> Vg=1.0
% INFO    : Gen at bus 10633	: Pg=90.48, Qg=33.58 -> Pg=130.16, Qg=20.0
% INFO    : Gen at bus 10633	: Vg=1.043665 -> Vg=1.0
% INFO    : Gen at bus 10635	: Pg=54.83, Qg=12.78 -> Pg=118.275, Qg=15.0
% INFO    : Gen at bus 10635	: Vg=1.047752 -> Vg=1.0
% INFO    : Gen at bus 10640	: Pg=188.36, Qg=79.01 -> Pg=250.0, Qg=60.0
% INFO    : Gen at bus 10640	: Vg=1.07025 -> Vg=1.0
% INFO    : Gen at bus 10643	: Pg=92.08, Qg=33.53 -> Pg=130.695, Qg=20.0
% INFO    : Gen at bus 10643	: Vg=1.056442 -> Vg=1.0
% INFO    : Gen at bus 10647	: Pg=209.93, Qg=1.9 -> Pg=300.0, Qg=80.0
% INFO    : Gen at bus 10647	: Vg=1.045549 -> Vg=1.0
% INFO    : Gen at bus 10648	: Pg=26.04, Qg=3.61 -> Pg=58.68, Qg=10.0
% INFO    : Gen at bus 10648	: Vg=1.050191 -> Vg=1.0
% INFO    : Gen at bus 10649	: Pg=26.04, Qg=3.61 -> Pg=58.68, Qg=10.0
% INFO    : Gen at bus 10649	: Vg=1.050191 -> Vg=1.0
% INFO    : Gen at bus 10650	: Pg=6.38, Qg=-2.2 -> Pg=52.125, Qg=0.0
% INFO    : Gen at bus 10650	: Vg=0.958146 -> Vg=1.0
% INFO    : Gen at bus 10652	: Pg=40.0, Qg=-3.06 -> Pg=63.335, Qg=0.0
% INFO    : Gen at bus 10652	: Vg=0.96764 -> Vg=1.0
% INFO    : Gen at bus 10653	: Pg=28.05, Qg=6.93 -> Pg=59.35, Qg=10.0
% INFO    : Gen at bus 10653	: Vg=1.035469 -> Vg=1.0
% INFO    : Gen at bus 10656	: Pg=34.38, Qg=8.21 -> Pg=61.46, Qg=10.0
% INFO    : Gen at bus 10656	: Vg=1.035773 -> Vg=1.0
% INFO    : Gen at bus 10657	: Pg=44.7, Qg=5.86 -> Pg=64.9, Qg=10.0
% INFO    : Gen at bus 10657	: Vg=0.996408 -> Vg=1.0
% INFO    : Gen at bus 10658	: Pg=44.7, Qg=5.86 -> Pg=64.9, Qg=10.0
% INFO    : Gen at bus 10658	: Vg=0.996408 -> Vg=1.0
% INFO    : Gen at bus 10660	: Pg=26.04, Qg=3.61 -> Pg=58.68, Qg=10.0
% INFO    : Gen at bus 10660	: Vg=1.050191 -> Vg=1.0
% INFO    : Gen at bus 10668	: Pg=31.45, Qg=10.87 -> Pg=60.485, Qg=10.0
% INFO    : Gen at bus 10668	: Vg=1.043771 -> Vg=1.0
% INFO    : Gen at bus 10669	: Pg=31.45, Qg=10.87 -> Pg=60.485, Qg=10.0
% INFO    : Gen at bus 10669	: Vg=1.043771 -> Vg=1.0
% INFO    : Gen at bus 10670	: Pg=39.24, Qg=8.33 -> Pg=63.08, Qg=10.0
% INFO    : Gen at bus 10670	: Vg=1.009038 -> Vg=1.0
% INFO    : Gen at bus 10671	: Pg=35.97, Qg=5.34 -> Pg=61.99, Qg=10.0
% INFO    : Gen at bus 10671	: Vg=1.058434 -> Vg=1.0
% INFO    : Gen at bus 10672	: Pg=35.97, Qg=5.34 -> Pg=61.99, Qg=10.0
% INFO    : Gen at bus 10672	: Vg=1.058434 -> Vg=1.0
% INFO    : Gen at bus 10674	: Pg=35.97, Qg=5.34 -> Pg=61.99, Qg=10.0
% INFO    : Gen at bus 10674	: Vg=1.058434 -> Vg=1.0
% INFO    : Gen at bus 10675	: Pg=35.97, Qg=5.34 -> Pg=61.99, Qg=10.0
% INFO    : Gen at bus 10675	: Vg=1.058434 -> Vg=1.0
% INFO    : Gen at bus 10676	: Pg=35.97, Qg=5.34 -> Pg=61.99, Qg=10.0
% INFO    : Gen at bus 10676	: Vg=1.058434 -> Vg=1.0
% INFO    : Gen at bus 10678	: Pg=11.68, Qg=-0.75 -> Pg=53.895, Qg=0.0
% INFO    : Gen at bus 10678	: Vg=1.013602 -> Vg=1.0
% INFO    : Gen at bus 10693	: Pg=5.0, Qg=0.46 -> Pg=51.665, Qg=0.0
% INFO    : Gen at bus 10693	: Vg=1.017738 -> Vg=1.0
% INFO    : Gen at bus 10696	: Pg=31.92, Qg=6.07 -> Pg=60.64, Qg=10.0
% INFO    : Gen at bus 10696	: Vg=1.027264 -> Vg=1.0
% INFO    : Gen at bus 10712	: Pg=33.38, Qg=14.38 -> Pg=61.125, Qg=10.0
% INFO    : Gen at bus 10712	: Vg=1.023574 -> Vg=1.0
% INFO    : Gen at bus 10713	: Pg=25.04, Qg=7.29 -> Pg=58.345, Qg=10.0
% INFO    : Gen at bus 10713	: Vg=1.041679 -> Vg=1.0
% INFO    : Gen at bus 10715	: Pg=330.71, Qg=4.92 -> Pg=450.0, Qg=80.0
% INFO    : Gen at bus 10715	: Vg=1.043049 -> Vg=1.0
% INFO    : Gen at bus 10719	: Pg=22.5, Qg=15.45 -> Pg=57.5, Qg=10.0
% INFO    : Gen at bus 10719	: Vg=1.045442 -> Vg=1.0
% INFO    : Gen at bus 10720	: Pg=22.5, Qg=15.45 -> Pg=57.5, Qg=10.0
% INFO    : Gen at bus 10720	: Vg=1.045442 -> Vg=1.0
% INFO    : Gen at bus 10721	: Pg=25.04, Qg=7.29 -> Pg=58.345, Qg=10.0
% INFO    : Gen at bus 10721	: Vg=1.041679 -> Vg=1.0
% INFO    : Gen at bus 10722	: Pg=25.04, Qg=7.29 -> Pg=58.345, Qg=10.0
% INFO    : Gen at bus 10722	: Vg=1.041679 -> Vg=1.0
% INFO    : Gen at bus 10738	: Pg=74.78, Qg=41.98 -> Pg=124.925, Qg=20.0
% INFO    : Gen at bus 10738	: Vg=1.04914 -> Vg=1.0
% INFO    : Gen at bus 10742	: Pg=25.68, Qg=12.42 -> Pg=58.56, Qg=10.0
% INFO    : Gen at bus 10742	: Vg=1.052378 -> Vg=1.0
% INFO    : Gen at bus 10743	: Pg=23.01, Qg=6.63 -> Pg=57.67, Qg=10.0
% INFO    : Gen at bus 10743	: Vg=1.01964 -> Vg=1.0
% INFO    : Gen at bus 10747	: Pg=85.34, Qg=16.39 -> Pg=128.445, Qg=20.0
% INFO    : Gen at bus 10747	: Vg=1.053529 -> Vg=1.0
% INFO    : Gen at bus 10748	: Pg=81.35, Qg=28.89 -> Pg=127.115, Qg=20.0
% INFO    : Gen at bus 10748	: Vg=1.055981 -> Vg=1.0
% INFO    : Gen at bus 10750	: Pg=72.99, Qg=3.91 -> Pg=124.33, Qg=20.0
% INFO    : Gen at bus 10750	: Vg=1.019549 -> Vg=1.0
% INFO    : Gen at bus 10752	: Pg=57.4, Qg=4.0 -> Pg=119.135, Qg=20.0
% INFO    : Gen at bus 10752	: Vg=1.02039 -> Vg=1.0
% INFO    : Gen at bus 10753	: Pg=59.71, Qg=48.41 -> Pg=119.905, Qg=20.0
% INFO    : Gen at bus 10753	: Vg=1.060516 -> Vg=1.0
% INFO    : Gen at bus 10754	: Pg=59.71, Qg=48.41 -> Pg=119.905, Qg=20.0
% INFO    : Gen at bus 10754	: Vg=1.060516 -> Vg=1.0
% INFO    : Gen at bus 10755	: Pg=72.99, Qg=3.91 -> Pg=124.33, Qg=20.0
% INFO    : Gen at bus 10755	: Vg=1.019549 -> Vg=1.0
% INFO    : Gen at bus 10756	: Pg=72.99, Qg=3.91 -> Pg=124.33, Qg=20.0
% INFO    : Gen at bus 10756	: Vg=1.019549 -> Vg=1.0
% INFO    : Gen at bus 10757	: Pg=10.5, Qg=2.44 -> Pg=53.5, Qg=0.0
% INFO    : Gen at bus 10757	: Vg=1.008788 -> Vg=1.0
% INFO    : Gen at bus 10762	: Pg=332.24, Qg=184.77 -> Pg=450.0, Qg=80.0
% INFO    : Gen at bus 10762	: Vg=1.071277 -> Vg=1.0
% INFO    : Gen at bus 10763	: Pg=332.24, Qg=184.77 -> Pg=450.0, Qg=80.0
% INFO    : Gen at bus 10763	: Vg=1.071277 -> Vg=1.0
% INFO    : Gen at bus 10764	: Pg=332.36, Qg=180.64 -> Pg=450.0, Qg=80.0
% INFO    : Gen at bus 10764	: Vg=1.068762 -> Vg=1.0
% INFO    : Gen at bus 10765	: Pg=332.24, Qg=184.77 -> Pg=450.0, Qg=80.0
% INFO    : Gen at bus 10765	: Vg=1.071277 -> Vg=1.0
% INFO    : Gen at bus 10775	: Pg=69.42, Qg=1.26 -> Pg=123.14, Qg=20.0
% INFO    : Gen at bus 10775	: Vg=1.034738 -> Vg=1.0
% INFO    : Gen at bus 10783	: Pg=67.5, Qg=10.49 -> Pg=122.5, Qg=10.0
% INFO    : Gen at bus 10783	: Vg=1.030285 -> Vg=1.0
% INFO    : Gen at bus 10784	: Pg=40.0, Qg=-1.34 -> Pg=63.335, Qg=0.0
% INFO    : Gen at bus 10784	: Vg=1.010203 -> Vg=1.0
% INFO    : Gen at bus 10785	: Pg=35.74, Qg=6.84 -> Pg=61.915, Qg=10.0
% INFO    : Gen at bus 10785	: Vg=1.040138 -> Vg=1.0
% INFO    : Gen at bus 10788	: Pg=36.8, Qg=6.62 -> Pg=62.265, Qg=10.0
% INFO    : Gen at bus 10788	: Vg=1.03058 -> Vg=1.0
% INFO    : Gen at bus 10803	: Pg=54.83, Qg=12.78 -> Pg=118.275, Qg=15.0
% INFO    : Gen at bus 10803	: Vg=1.047752 -> Vg=1.0
% INFO    : Gen at bus 10804	: Pg=54.83, Qg=12.78 -> Pg=118.275, Qg=15.0
% INFO    : Gen at bus 10804	: Vg=1.047752 -> Vg=1.0
% INFO    : Gen at bus 10808	: Pg=95.02, Qg=8.09 -> Pg=131.675, Qg=20.0
% INFO    : Gen at bus 10808	: Vg=1.023144 -> Vg=1.0
% INFO    : Gen at bus 10809	: Pg=91.34, Qg=21.91 -> Pg=130.445, Qg=20.0
% INFO    : Gen at bus 10809	: Vg=1.030656 -> Vg=1.0
% INFO    : Gen at bus 10811	: Pg=91.94, Qg=33.76 -> Pg=130.645, Qg=20.0
% INFO    : Gen at bus 10811	: Vg=1.048656 -> Vg=1.0
% INFO    : Gen at bus 10814	: Pg=168.75, Qg=16.36 -> Pg=250.0, Qg=5.0
% INFO    : Gen at bus 10814	: Vg=0.976475 -> Vg=1.0
% INFO    : Gen at bus 10825	: Pg=152.0, Qg=11.5 -> Pg=250.0, Qg=0.0
% INFO    : Gen at bus 10825	: Vg=0.988205 -> Vg=1.0
% INFO    : Gen at bus 10829	: Pg=0.93, Qg=0.09 -> Pg=50.31, Qg=0.0
% INFO    : Gen at bus 10829	: Vg=1.03064 -> Vg=1.0
% INFO    : Gen at bus 10835	: Pg=47.25, Qg=-1.74 -> Pg=65.75, Qg=0.0
% INFO    : Gen at bus 10835	: Vg=0.990208 -> Vg=1.0
% INFO    : Gen at bus 10841	: Pg=95.83, Qg=32.34 -> Pg=131.945, Qg=20.0
% INFO    : Gen at bus 10841	: Vg=1.012871 -> Vg=1.0
% INFO    : Gen at bus 10845	: Pg=34.86, Qg=4.81 -> Pg=61.62, Qg=10.0
% INFO    : Gen at bus 10845	: Vg=1.050901 -> Vg=1.0
% INFO    : Gen at bus 10847	: Pg=82.46, Qg=55.28 -> Pg=127.485, Qg=20.0
% INFO    : Gen at bus 10847	: Vg=1.127948 -> Vg=1.0
% INFO    : Gen at bus 10862	: Pg=39.43, Qg=5.93 -> Pg=63.145, Qg=10.0
% INFO    : Gen at bus 10862	: Vg=1.017582 -> Vg=1.0
% INFO    : Gen at bus 10865	: Pg=37.29, Qg=8.19 -> Pg=62.43, Qg=10.0
% INFO    : Gen at bus 10865	: Vg=1.030566 -> Vg=1.0
% INFO    : Gen at bus 10881	: Pg=26.56, Qg=10.95 -> Pg=58.855, Qg=10.0
% INFO    : Gen at bus 10881	: Vg=1.002675 -> Vg=1.0
% INFO    : Gen at bus 10891	: Pg=15.59, Qg=-0.61 -> Pg=55.2, Qg=5.0
% INFO    : Gen at bus 10891	: Vg=1.020801 -> Vg=1.0
% INFO    : Gen at bus 10898	: Pg=25.24, Qg=9.06 -> Pg=58.415, Qg=10.0
% INFO    : Gen at bus 10898	: Vg=1.045295 -> Vg=1.0
% INFO    : Gen at bus 10901	: Pg=72.61, Qg=29.56 -> Pg=124.205, Qg=20.0
% INFO    : Gen at bus 10901	: Vg=1.041629 -> Vg=1.0
% INFO    : Gen at bus 10907	: Pg=93.04, Qg=14.9 -> Pg=131.015, Qg=20.0
% INFO    : Gen at bus 10907	: Vg=1.017638 -> Vg=1.0
% INFO    : Gen at bus 10908	: Pg=257.94, Qg=36.73 -> Pg=350.0, Qg=60.0
% INFO    : Gen at bus 10908	: Vg=1.021858 -> Vg=1.0
% INFO    : Gen at bus 10913	: Pg=78.96, Qg=32.05 -> Pg=126.32, Qg=20.0
% INFO    : Gen at bus 10913	: Vg=1.063361 -> Vg=1.0
% INFO    : Gen at bus 10918	: Pg=74.8, Qg=42.23 -> Pg=124.935, Qg=20.0
% INFO    : Gen at bus 10918	: Vg=1.046905 -> Vg=1.0
% INFO    : Gen at bus 10927	: Pg=289.29, Qg=40.05 -> Pg=350.0, Qg=60.0
% INFO    : Gen at bus 10927	: Vg=1.03324 -> Vg=1.0
% INFO    : Gen at bus 10928	: Pg=289.29, Qg=40.05 -> Pg=350.0, Qg=60.0
% INFO    : Gen at bus 10928	: Vg=1.03324 -> Vg=1.0
% INFO    : Gen at bus 10930	: Pg=289.29, Qg=40.05 -> Pg=350.0, Qg=60.0
% INFO    : Gen at bus 10930	: Vg=1.03324 -> Vg=1.0
% INFO    : Gen at bus 10932	: Pg=150.0, Qg=8.11 -> Pg=200.0, Qg=25.0
% INFO    : Gen at bus 10932	: Vg=0.989744 -> Vg=1.0
% INFO    : Gen at bus 10935	: Pg=25.75, Qg=4.04 -> Pg=58.585, Qg=10.0
% INFO    : Gen at bus 10935	: Vg=1.026025 -> Vg=1.0
% INFO    : Gen at bus 10938	: Pg=21.76, Qg=4.41 -> Pg=57.255, Qg=5.0
% INFO    : Gen at bus 10938	: Vg=1.034618 -> Vg=1.0
% INFO    : Gen at bus 10940	: Pg=40.5, Qg=-3.48 -> Pg=63.5, Qg=0.0
% INFO    : Gen at bus 10940	: Vg=0.963524 -> Vg=1.0
% INFO    : Gen at bus 10945	: Pg=7.0, Qg=-0.2 -> Pg=52.335, Qg=0.0
% INFO    : Gen at bus 10945	: Vg=0.987313 -> Vg=1.0
% INFO    : Gen at bus 10946	: Pg=234.93, Qg=76.89 -> Pg=300.0, Qg=80.0
% INFO    : Gen at bus 10946	: Vg=1.032433 -> Vg=1.0
% INFO    : Gen at bus 10951	: Pg=50.8, Qg=2.36 -> Pg=116.935, Qg=5.0
% INFO    : Gen at bus 10951	: Vg=0.979833 -> Vg=1.0
% INFO    : Gen at bus 10954	: Pg=180.96, Qg=38.95 -> Pg=250.0, Qg=60.0
% INFO    : Gen at bus 10954	: Vg=1.029835 -> Vg=1.0
% INFO    : Gen at bus 10963	: Pg=111.5, Qg=6.79 -> Pg=187.165, Qg=15.0
% INFO    : Gen at bus 10963	: Vg=1.056762 -> Vg=1.0
% INFO    : Gen at bus 10971	: Pg=15.0, Qg=-0.86 -> Pg=55.0, Qg=0.0
% INFO    : Gen at bus 10971	: Vg=0.992395 -> Vg=1.0
% INFO    : Gen at bus 10973	: Pg=89.04, Qg=1.21 -> Pg=129.68, Qg=10.0
% INFO    : Gen at bus 10973	: Vg=1.015065 -> Vg=1.0
% INFO    : Gen at bus 10978	: Pg=39.43, Qg=5.93 -> Pg=63.145, Qg=10.0
% INFO    : Gen at bus 10978	: Vg=1.017582 -> Vg=1.0
% INFO    : Gen at bus 10983	: Pg=21.77, Qg=6.35 -> Pg=57.255, Qg=10.0
% INFO    : Gen at bus 10983	: Vg=1.024499 -> Vg=1.0
% INFO    : Gen at bus 10985	: Pg=87.19, Qg=27.18 -> Pg=129.065, Qg=20.0
% INFO    : Gen at bus 10985	: Vg=1.023338 -> Vg=1.0
% INFO    : Gen at bus 10987	: Pg=20.64, Qg=7.21 -> Pg=56.88, Qg=10.0
% INFO    : Gen at bus 10987	: Vg=1.018866 -> Vg=1.0
% INFO    : Gen at bus 10994	: Pg=23.58, Qg=-5.0 -> Pg=57.86, Qg=0.0
% INFO    : Gen at bus 10994	: Vg=0.964368 -> Vg=1.0
% INFO    : Gen at bus 10998	: Pg=994.84, Qg=302.65 -> Pg=1300.0, Qg=200.0
% INFO    : Gen at bus 10998	: Vg=1.05787 -> Vg=1.0
% INFO    : Gen at bus 11005	: Pg=36.77, Qg=13.93 -> Pg=62.255, Qg=10.0
% INFO    : Gen at bus 11005	: Vg=1.042317 -> Vg=1.0
% INFO    : Gen at bus 11010	: Pg=100.29, Qg=29.56 -> Pg=183.43, Qg=20.0
% INFO    : Gen at bus 11010	: Vg=1.064335 -> Vg=1.0
% INFO    : Gen at bus 11020	: Pg=2.26, Qg=-1.2 -> Pg=50.755, Qg=0.0
% INFO    : Gen at bus 11020	: Vg=0.991929 -> Vg=1.0
% INFO    : Gen at bus 11023	: Pg=42.33, Qg=15.72 -> Pg=64.11, Qg=15.0
% INFO    : Gen at bus 11023	: Vg=1.031695 -> Vg=1.0
% INFO    : Gen at bus 11025	: Pg=42.33, Qg=15.72 -> Pg=64.11, Qg=15.0
% INFO    : Gen at bus 11025	: Vg=1.031695 -> Vg=1.0
% INFO    : Gen at bus 11028	: Pg=58.52, Qg=7.84 -> Pg=119.505, Qg=15.0
% INFO    : Gen at bus 11028	: Vg=1.025977 -> Vg=1.0
% INFO    : Gen at bus 11030	: Pg=99.72, Qg=-12.35 -> Pg=133.24, Qg=20.0
% INFO    : Gen at bus 11030	: Vg=1.021495 -> Vg=1.0
% INFO    : Gen at bus 11032	: Pg=800.47, Qg=18.87 -> Pg=1100.0, Qg=200.0
% INFO    : Gen at bus 11032	: Vg=1.04071 -> Vg=1.0
% INFO    : Gen at bus 11037	: Pg=158.79, Qg=48.73 -> Pg=250.0, Qg=80.0
% INFO    : Gen at bus 11037	: Vg=1.029671 -> Vg=1.0
% INFO    : Gen at bus 11039	: Pg=30.07, Qg=6.48 -> Pg=60.025, Qg=10.0
% INFO    : Gen at bus 11039	: Vg=1.058835 -> Vg=1.0
% INFO    : Gen at bus 11047	: Pg=154.5, Qg=-14.56 -> Pg=250.0, Qg=5.0
% INFO    : Gen at bus 11047	: Vg=0.956299 -> Vg=1.0
% INFO    : Gen at bus 11049	: Pg=100.41, Qg=11.92 -> Pg=183.47, Qg=20.0
% INFO    : Gen at bus 11049	: Vg=1.038747 -> Vg=1.0
% INFO    : Gen at bus 11051	: Pg=72.47, Qg=11.44 -> Pg=124.155, Qg=20.0
% INFO    : Gen at bus 11051	: Vg=1.019231 -> Vg=1.0
% INFO    : Gen at bus 11059	: Pg=50.0, Qg=-2.27 -> Pg=66.665, Qg=0.0
% INFO    : Gen at bus 11059	: Vg=0.993383 -> Vg=1.0
% INFO    : Gen at bus 11065	: Pg=27.19, Qg=6.05 -> Pg=59.065, Qg=10.0
% INFO    : Gen at bus 11065	: Vg=1.014542 -> Vg=1.0
% INFO    : Gen at bus 11076	: Pg=19.96, Qg=5.53 -> Pg=56.655, Qg=10.0
% INFO    : Gen at bus 11076	: Vg=1.011132 -> Vg=1.0
% INFO    : Gen at bus 11085	: Pg=32.44, Qg=9.61 -> Pg=60.815, Qg=10.0
% INFO    : Gen at bus 11085	: Vg=1.038916 -> Vg=1.0
% INFO    : Gen at bus 11086	: Pg=32.44, Qg=9.61 -> Pg=60.815, Qg=10.0
% INFO    : Gen at bus 11086	: Vg=1.038916 -> Vg=1.0
% INFO    : Gen at bus 11087	: Pg=32.44, Qg=9.61 -> Pg=60.815, Qg=10.0
% INFO    : Gen at bus 11087	: Vg=1.038916 -> Vg=1.0
% INFO    : Gen at bus 11088	: Pg=32.44, Qg=9.61 -> Pg=60.815, Qg=10.0
% INFO    : Gen at bus 11088	: Vg=1.038916 -> Vg=1.0
% INFO    : Gen at bus 11090	: Pg=23.94, Qg=10.89 -> Pg=57.98, Qg=10.0
% INFO    : Gen at bus 11090	: Vg=1.042693 -> Vg=1.0
% INFO    : Gen at bus 11095	: Pg=22.02, Qg=10.78 -> Pg=57.34, Qg=10.0
% INFO    : Gen at bus 11095	: Vg=1.026425 -> Vg=1.0
% INFO    : Gen at bus 11096	: Pg=200.33, Qg=74.16 -> Pg=300.0, Qg=80.0
% INFO    : Gen at bus 11096	: Vg=1.024096 -> Vg=1.0
% INFO    : Gen at bus 11099	: Pg=35.6, Qg=15.17 -> Pg=61.865, Qg=10.0
% INFO    : Gen at bus 11099	: Vg=1.026957 -> Vg=1.0
% INFO    : Gen at bus 11102	: Pg=33.73, Qg=12.57 -> Pg=61.245, Qg=10.0
% INFO    : Gen at bus 11102	: Vg=1.035958 -> Vg=1.0
% INFO    : Gen at bus 11104	: Pg=33.73, Qg=12.57 -> Pg=61.245, Qg=10.0
% INFO    : Gen at bus 11104	: Vg=1.035958 -> Vg=1.0
% INFO    : Gen at bus 11106	: Pg=30.35, Qg=8.38 -> Pg=60.115, Qg=10.0
% INFO    : Gen at bus 11106	: Vg=1.053822 -> Vg=1.0
% INFO    : Gen at bus 11107	: Pg=33.73, Qg=12.57 -> Pg=61.245, Qg=10.0
% INFO    : Gen at bus 11107	: Vg=1.035958 -> Vg=1.0
% INFO    : Gen at bus 11108	: Pg=30.35, Qg=8.38 -> Pg=60.115, Qg=10.0
% INFO    : Gen at bus 11108	: Vg=1.053822 -> Vg=1.0
% INFO    : Gen at bus 11109	: Pg=30.35, Qg=8.38 -> Pg=60.115, Qg=10.0
% INFO    : Gen at bus 11109	: Vg=1.053822 -> Vg=1.0
% INFO    : Gen at bus 11110	: Pg=28.95, Qg=9.55 -> Pg=59.65, Qg=10.0
% INFO    : Gen at bus 11110	: Vg=1.01638 -> Vg=1.0
% INFO    : Gen at bus 11111	: Pg=30.35, Qg=8.38 -> Pg=60.115, Qg=10.0
% INFO    : Gen at bus 11111	: Vg=1.053822 -> Vg=1.0
% INFO    : Gen at bus 11115	: Pg=28.83, Qg=4.62 -> Pg=59.61, Qg=10.0
% INFO    : Gen at bus 11115	: Vg=1.019144 -> Vg=1.0
% INFO    : Gen at bus 11118	: Pg=23.6, Qg=12.35 -> Pg=57.865, Qg=10.0
% INFO    : Gen at bus 11118	: Vg=1.042829 -> Vg=1.0
% INFO    : Gen at bus 11119	: Pg=23.6, Qg=12.35 -> Pg=57.865, Qg=10.0
% INFO    : Gen at bus 11119	: Vg=1.042829 -> Vg=1.0
% INFO    : Gen at bus 11120	: Pg=25.54, Qg=10.25 -> Pg=58.515, Qg=10.0
% INFO    : Gen at bus 11120	: Vg=1.035471 -> Vg=1.0
% INFO    : Gen at bus 11121	: Pg=25.54, Qg=10.25 -> Pg=58.515, Qg=10.0
% INFO    : Gen at bus 11121	: Vg=1.035471 -> Vg=1.0
% INFO    : Gen at bus 11122	: Pg=39.54, Qg=11.66 -> Pg=63.18, Qg=10.0
% INFO    : Gen at bus 11122	: Vg=1.055315 -> Vg=1.0
% INFO    : Gen at bus 11124	: Pg=23.6, Qg=12.35 -> Pg=57.865, Qg=10.0
% INFO    : Gen at bus 11124	: Vg=1.042829 -> Vg=1.0
% INFO    : Gen at bus 11125	: Pg=23.6, Qg=12.35 -> Pg=57.865, Qg=10.0
% INFO    : Gen at bus 11125	: Vg=1.042829 -> Vg=1.0
% INFO    : Gen at bus 11128	: Pg=90.48, Qg=33.58 -> Pg=130.16, Qg=20.0
% INFO    : Gen at bus 11128	: Vg=1.043665 -> Vg=1.0
% INFO    : Gen at bus 11129	: Pg=27.67, Qg=4.45 -> Pg=59.225, Qg=10.0
% INFO    : Gen at bus 11129	: Vg=1.027132 -> Vg=1.0
% INFO    : Gen at bus 11130	: Pg=25.54, Qg=10.25 -> Pg=58.515, Qg=10.0
% INFO    : Gen at bus 11130	: Vg=1.035471 -> Vg=1.0
% INFO    : Gen at bus 11131	: Pg=43.29, Qg=23.54 -> Pg=64.43, Qg=20.0
% INFO    : Gen at bus 11131	: Vg=1.035771 -> Vg=1.0
% INFO    : Gen at bus 11132	: Pg=90.23, Qg=10.46 -> Pg=130.075, Qg=20.0
% INFO    : Gen at bus 11132	: Vg=1.028204 -> Vg=1.0
% INFO    : Gen at bus 11133	: Pg=90.23, Qg=10.46 -> Pg=130.075, Qg=20.0
% INFO    : Gen at bus 11133	: Vg=1.028204 -> Vg=1.0
% INFO    : Gen at bus 11137	: Pg=90.23, Qg=10.46 -> Pg=130.075, Qg=20.0
% INFO    : Gen at bus 11137	: Vg=1.028204 -> Vg=1.0
% INFO    : Gen at bus 11138	: Pg=31.5, Qg=1.72 -> Pg=60.5, Qg=5.0
% INFO    : Gen at bus 11138	: Vg=1.016735 -> Vg=1.0
% INFO    : Gen at bus 11145	: Pg=28.8, Qg=6.92 -> Pg=59.6, Qg=10.0
% INFO    : Gen at bus 11145	: Vg=1.000808 -> Vg=1.0
% INFO    : Gen at bus 11154	: Pg=188.36, Qg=79.01 -> Pg=250.0, Qg=60.0
% INFO    : Gen at bus 11154	: Vg=1.07025 -> Vg=1.0
% INFO    : Gen at bus 11155	: Pg=31.92, Qg=6.07 -> Pg=60.64, Qg=10.0
% INFO    : Gen at bus 11155	: Vg=1.027264 -> Vg=1.0
% INFO    : Gen at bus 11158	: Pg=3.2, Qg=1.16 -> Pg=51.065, Qg=0.0
% INFO    : Gen at bus 11158	: Vg=0.991765 -> Vg=1.0
% INFO    : Gen at bus 11167	: Pg=84.19, Qg=8.48 -> Pg=128.065, Qg=20.0
% INFO    : Gen at bus 11167	: Vg=1.040259 -> Vg=1.0
% INFO    : Gen at bus 11170	: Pg=86.25, Qg=-3.04 -> Pg=128.75, Qg=-10.0
% INFO    : Gen at bus 11170	: Vg=0.962614 -> Vg=1.0
% INFO    : Gen at bus 11172	: Pg=84.19, Qg=8.48 -> Pg=128.065, Qg=20.0
% INFO    : Gen at bus 11172	: Vg=1.040259 -> Vg=1.0
% INFO    : Gen at bus 11174	: Pg=84.19, Qg=8.48 -> Pg=128.065, Qg=20.0
% INFO    : Gen at bus 11174	: Vg=1.040259 -> Vg=1.0
% INFO    : Gen at bus 11175	: Pg=84.19, Qg=8.48 -> Pg=128.065, Qg=20.0
% INFO    : Gen at bus 11175	: Vg=1.040259 -> Vg=1.0
% INFO    : Gen at bus 11177	: Pg=10.0, Qg=0.56 -> Pg=53.335, Qg=0.0
% INFO    : Gen at bus 11177	: Vg=1.01515 -> Vg=1.0
% INFO    : Gen at bus 11191	: Pg=43.17, Qg=6.95 -> Pg=64.39, Qg=10.0
% INFO    : Gen at bus 11191	: Vg=1.015029 -> Vg=1.0
% INFO    : Gen at bus 11193	: Pg=43.17, Qg=6.95 -> Pg=64.39, Qg=10.0
% INFO    : Gen at bus 11193	: Vg=1.015029 -> Vg=1.0
% INFO    : Gen at bus 11194	: Pg=43.17, Qg=6.95 -> Pg=64.39, Qg=10.0
% INFO    : Gen at bus 11194	: Vg=1.015029 -> Vg=1.0
% INFO    : Gen at bus 11195	: Pg=43.17, Qg=6.95 -> Pg=64.39, Qg=10.0
% INFO    : Gen at bus 11195	: Vg=1.015029 -> Vg=1.0
% INFO    : Gen at bus 11196	: Pg=43.17, Qg=6.95 -> Pg=64.39, Qg=10.0
% INFO    : Gen at bus 11196	: Vg=1.015029 -> Vg=1.0
% INFO    : Gen at bus 11197	: Pg=43.17, Qg=6.95 -> Pg=64.39, Qg=10.0
% INFO    : Gen at bus 11197	: Vg=1.015029 -> Vg=1.0
% INFO    : Gen at bus 11198	: Pg=43.17, Qg=6.95 -> Pg=64.39, Qg=10.0
% INFO    : Gen at bus 11198	: Vg=1.015029 -> Vg=1.0
% INFO    : Gen at bus 11201	: Pg=318.17, Qg=43.77 -> Pg=450.0, Qg=80.0
% INFO    : Gen at bus 11201	: Vg=1.020879 -> Vg=1.0
% INFO    : Gen at bus 11203	: Pg=17.6, Qg=22.53 -> Pg=55.865, Qg=10.0
% INFO    : Gen at bus 11203	: Vg=1.05667 -> Vg=1.0
% INFO    : Gen at bus 11204	: Pg=318.17, Qg=43.77 -> Pg=450.0, Qg=80.0
% INFO    : Gen at bus 11204	: Vg=1.020879 -> Vg=1.0
% INFO    : Gen at bus 11211	: Pg=33.79, Qg=6.99 -> Pg=61.265, Qg=10.0
% INFO    : Gen at bus 11211	: Vg=1.059581 -> Vg=1.0
% INFO    : Gen at bus 11212	: Pg=33.59, Qg=11.77 -> Pg=61.195, Qg=10.0
% INFO    : Gen at bus 11212	: Vg=1.049265 -> Vg=1.0
% INFO    : Gen at bus 11214	: Pg=26.84, Qg=7.89 -> Pg=58.945, Qg=10.0
% INFO    : Gen at bus 11214	: Vg=1.013527 -> Vg=1.0
% INFO    : Gen at bus 11219	: Pg=78.58, Qg=36.25 -> Pg=126.195, Qg=20.0
% INFO    : Gen at bus 11219	: Vg=1.047402 -> Vg=1.0
% INFO    : Gen at bus 11220	: Pg=84.71, Qg=11.94 -> Pg=128.235, Qg=20.0
% INFO    : Gen at bus 11220	: Vg=1.045943 -> Vg=1.0
% INFO    : Gen at bus 11221	: Pg=36.8, Qg=6.62 -> Pg=62.265, Qg=10.0
% INFO    : Gen at bus 11221	: Vg=1.03058 -> Vg=1.0
% INFO    : Gen at bus 11225	: Pg=34.65, Qg=8.09 -> Pg=61.55, Qg=10.0
% INFO    : Gen at bus 11225	: Vg=1.039009 -> Vg=1.0
% INFO    : Gen at bus 11226	: Pg=99.7, Qg=4.57 -> Pg=133.235, Qg=20.0
% INFO    : Gen at bus 11226	: Vg=1.028091 -> Vg=1.0
% INFO    : Gen at bus 11227	: Pg=32.64, Qg=6.68 -> Pg=60.88, Qg=10.0
% INFO    : Gen at bus 11227	: Vg=1.044939 -> Vg=1.0
% INFO    : Gen at bus 11229	: Pg=34.8, Qg=5.13 -> Pg=61.6, Qg=10.0
% INFO    : Gen at bus 11229	: Vg=1.009652 -> Vg=1.0
% INFO    : Gen at bus 11230	: Pg=1.84, Qg=0.43 -> Pg=50.615, Qg=0.0
% INFO    : Gen at bus 11230	: Vg=1.045545 -> Vg=1.0
% INFO    : Gen at bus 11231	: Pg=32.64, Qg=6.68 -> Pg=60.88, Qg=10.0
% INFO    : Gen at bus 11231	: Vg=1.044939 -> Vg=1.0
% INFO    : Gen at bus 11233	: Pg=61.58, Qg=-0.59 -> Pg=120.525, Qg=20.0
% INFO    : Gen at bus 11233	: Vg=1.041114 -> Vg=1.0
% INFO    : Gen at bus 11235	: Pg=57.74, Qg=17.07 -> Pg=119.245, Qg=20.0
% INFO    : Gen at bus 11235	: Vg=1.05622 -> Vg=1.0
% INFO    : Gen at bus 11236	: Pg=61.58, Qg=-0.59 -> Pg=120.525, Qg=20.0
% INFO    : Gen at bus 11236	: Vg=1.041114 -> Vg=1.0
% INFO    : Gen at bus 11237	: Pg=27.72, Qg=3.43 -> Pg=59.24, Qg=10.0
% INFO    : Gen at bus 11237	: Vg=1.015411 -> Vg=1.0
% INFO    : Gen at bus 11238	: Pg=57.74, Qg=17.07 -> Pg=119.245, Qg=20.0
% INFO    : Gen at bus 11238	: Vg=1.05622 -> Vg=1.0
% INFO    : Gen at bus 11239	: Pg=5.17, Qg=0.23 -> Pg=51.725, Qg=0.0
% INFO    : Gen at bus 11239	: Vg=1.027155 -> Vg=1.0
% INFO    : Gen at bus 11240	: Pg=83.51, Qg=27.65 -> Pg=127.835, Qg=20.0
% INFO    : Gen at bus 11240	: Vg=1.063297 -> Vg=1.0
% INFO    : Gen at bus 11241	: Pg=83.51, Qg=27.65 -> Pg=127.835, Qg=20.0
% INFO    : Gen at bus 11241	: Vg=1.063297 -> Vg=1.0
% INFO    : Gen at bus 11242	: Pg=83.51, Qg=27.65 -> Pg=127.835, Qg=20.0
% INFO    : Gen at bus 11242	: Vg=1.063297 -> Vg=1.0
% INFO    : Gen at bus 11244	: Pg=27.72, Qg=3.43 -> Pg=59.24, Qg=10.0
% INFO    : Gen at bus 11244	: Vg=1.015411 -> Vg=1.0
% INFO    : Gen at bus 11250	: Pg=31.57, Qg=7.72 -> Pg=60.525, Qg=10.0
% INFO    : Gen at bus 11250	: Vg=1.008948 -> Vg=1.0
% INFO    : Gen at bus 11251	: Pg=50.96, Qg=2.69 -> Pg=116.985, Qg=20.0
% INFO    : Gen at bus 11251	: Vg=1.028648 -> Vg=1.0
% INFO    : Gen at bus 11256	: Pg=328.2, Qg=86.92 -> Pg=450.0, Qg=80.0
% INFO    : Gen at bus 11256	: Vg=1.03657 -> Vg=1.0
% INFO    : Gen at bus 11257	: Pg=45.95, Qg=11.1 -> Pg=65.315, Qg=10.0
% INFO    : Gen at bus 11257	: Vg=1.036997 -> Vg=1.0
% INFO    : Gen at bus 11259	: Pg=328.2, Qg=86.92 -> Pg=450.0, Qg=80.0
% INFO    : Gen at bus 11259	: Vg=1.03657 -> Vg=1.0
% INFO    : Gen at bus 11264	: Pg=36.8, Qg=6.62 -> Pg=62.265, Qg=10.0
% INFO    : Gen at bus 11264	: Vg=1.03058 -> Vg=1.0
% INFO    : Gen at bus 11265	: Pg=27.2, Qg=3.82 -> Pg=59.065, Qg=10.0
% INFO    : Gen at bus 11265	: Vg=1.024762 -> Vg=1.0
% INFO    : Gen at bus 11273	: Pg=40.0, Qg=-3.06 -> Pg=63.335, Qg=0.0
% INFO    : Gen at bus 11273	: Vg=0.96764 -> Vg=1.0
% INFO    : Gen at bus 11281	: Pg=15.0, Qg=4.39 -> Pg=55.0, Qg=5.0
% INFO    : Gen at bus 11281	: Vg=1.03858 -> Vg=1.0
% INFO    : Gen at bus 11285	: Pg=88.85, Qg=23.49 -> Pg=129.615, Qg=20.0
% INFO    : Gen at bus 11285	: Vg=1.032344 -> Vg=1.0
% INFO    : Gen at bus 11289	: Pg=34.38, Qg=8.21 -> Pg=61.46, Qg=10.0
% INFO    : Gen at bus 11289	: Vg=1.035773 -> Vg=1.0
% INFO    : Gen at bus 11294	: Pg=951.82, Qg=32.74 -> Pg=1300.0, Qg=200.0
% INFO    : Gen at bus 11294	: Vg=1.01249 -> Vg=1.0
% INFO    : Gen at bus 11299	: Pg=89.91, Qg=48.94 -> Pg=129.97, Qg=20.0
% INFO    : Gen at bus 11299	: Vg=1.065506 -> Vg=1.0
% INFO    : Gen at bus 11305	: Pg=68.26, Qg=9.75 -> Pg=122.755, Qg=20.0
% INFO    : Gen at bus 11305	: Vg=1.028153 -> Vg=1.0
% INFO    : Gen at bus 11307	: Pg=56.07, Qg=3.64 -> Pg=118.69, Qg=20.0
% INFO    : Gen at bus 11307	: Vg=1.04834 -> Vg=1.0
% INFO    : Gen at bus 11308	: Pg=88.6, Qg=0.84 -> Pg=129.535, Qg=20.0
% INFO    : Gen at bus 11308	: Vg=1.03671 -> Vg=1.0
% INFO    : Gen at bus 11309	: Pg=34.38, Qg=8.21 -> Pg=61.46, Qg=10.0
% INFO    : Gen at bus 11309	: Vg=1.035773 -> Vg=1.0
% INFO    : Gen at bus 11311	: Pg=3.65, Qg=0.04 -> Pg=51.215, Qg=0.0
% INFO    : Gen at bus 11311	: Vg=0.982004 -> Vg=1.0
% INFO    : Gen at bus 11312	: Pg=50.83, Qg=3.96 -> Pg=116.945, Qg=20.0
% INFO    : Gen at bus 11312	: Vg=1.049674 -> Vg=1.0
% INFO    : Gen at bus 11315	: Pg=36.11, Qg=3.87 -> Pg=62.035, Qg=10.0
% INFO    : Gen at bus 11315	: Vg=1.024544 -> Vg=1.0
% INFO    : Gen at bus 11325	: Pg=29.57, Qg=20.51 -> Pg=59.855, Qg=10.0
% INFO    : Gen at bus 11325	: Vg=1.041409 -> Vg=1.0
% INFO    : Gen at bus 11327	: Pg=39.88, Qg=15.15 -> Pg=63.295, Qg=10.0
% INFO    : Gen at bus 11327	: Vg=1.024267 -> Vg=1.0
% INFO    : Gen at bus 11328	: Pg=34.86, Qg=4.81 -> Pg=61.62, Qg=10.0
% INFO    : Gen at bus 11328	: Vg=1.050901 -> Vg=1.0
% INFO    : Gen at bus 11329	: Pg=8.4, Qg=-0.55 -> Pg=52.8, Qg=0.0
% INFO    : Gen at bus 11329	: Vg=0.988112 -> Vg=1.0
% INFO    : Gen at bus 11330	: Pg=26.97, Qg=7.32 -> Pg=58.99, Qg=10.0
% INFO    : Gen at bus 11330	: Vg=1.049221 -> Vg=1.0
% INFO    : Gen at bus 11332	: Pg=165.71, Qg=155.15 -> Pg=250.0, Qg=60.0
% INFO    : Gen at bus 11332	: Vg=1.077226 -> Vg=1.0
% INFO    : Gen at bus 11333	: Pg=165.71, Qg=155.15 -> Pg=250.0, Qg=60.0
% INFO    : Gen at bus 11333	: Vg=1.077226 -> Vg=1.0
% INFO    : Gen at bus 11336	: Pg=30.02, Qg=16.69 -> Pg=60.005, Qg=10.0
% INFO    : Gen at bus 11336	: Vg=1.023695 -> Vg=1.0
% INFO    : Gen at bus 11344	: Pg=27.88, Qg=10.37 -> Pg=59.295, Qg=10.0
% INFO    : Gen at bus 11344	: Vg=1.052164 -> Vg=1.0
% INFO    : Gen at bus 11345	: Pg=90.32, Qg=31.5 -> Pg=130.105, Qg=20.0
% INFO    : Gen at bus 11345	: Vg=1.035102 -> Vg=1.0
% INFO    : Gen at bus 11347	: Pg=43.48, Qg=23.86 -> Pg=64.495, Qg=15.0
% INFO    : Gen at bus 11347	: Vg=1.021627 -> Vg=1.0
% INFO    : Gen at bus 11348	: Pg=39.64, Qg=12.04 -> Pg=63.215, Qg=15.0
% INFO    : Gen at bus 11348	: Vg=1.034643 -> Vg=1.0
% INFO    : Gen at bus 11351	: Pg=40.44, Qg=13.81 -> Pg=63.48, Qg=15.0
% INFO    : Gen at bus 11351	: Vg=1.025019 -> Vg=1.0
% INFO    : Gen at bus 11352	: Pg=40.44, Qg=13.81 -> Pg=63.48, Qg=15.0
% INFO    : Gen at bus 11352	: Vg=1.025019 -> Vg=1.0
% INFO    : Gen at bus 11353	: Pg=39.64, Qg=12.04 -> Pg=63.215, Qg=15.0
% INFO    : Gen at bus 11353	: Vg=1.034643 -> Vg=1.0
% INFO    : Gen at bus 11355	: Pg=33.92, Qg=4.57 -> Pg=61.305, Qg=10.0
% INFO    : Gen at bus 11355	: Vg=1.012747 -> Vg=1.0
% INFO    : Gen at bus 11360	: Pg=274.92, Qg=131.33 -> Pg=350.0, Qg=80.0
% INFO    : Gen at bus 11360	: Vg=1.086148 -> Vg=1.0
% INFO    : Gen at bus 11361	: Pg=354.27, Qg=134.78 -> Pg=500.0, Qg=80.0
% INFO    : Gen at bus 11361	: Vg=1.085902 -> Vg=1.0
% INFO    : Gen at bus 11362	: Pg=354.27, Qg=134.78 -> Pg=500.0, Qg=80.0
% INFO    : Gen at bus 11362	: Vg=1.085902 -> Vg=1.0
% INFO    : Gen at bus 11363	: Pg=269.77, Qg=119.39 -> Pg=350.0, Qg=80.0
% INFO    : Gen at bus 11363	: Vg=1.02099 -> Vg=1.0
% INFO    : Gen at bus 11364	: Pg=90.17, Qg=24.56 -> Pg=130.055, Qg=20.0
% INFO    : Gen at bus 11364	: Vg=1.06019 -> Vg=1.0
% INFO    : Gen at bus 11367	: Pg=90.17, Qg=24.56 -> Pg=130.055, Qg=20.0
% INFO    : Gen at bus 11367	: Vg=1.06019 -> Vg=1.0
% INFO    : Gen at bus 11368	: Pg=90.17, Qg=24.56 -> Pg=130.055, Qg=20.0
% INFO    : Gen at bus 11368	: Vg=1.06019 -> Vg=1.0
% INFO    : Gen at bus 11369	: Pg=90.17, Qg=24.56 -> Pg=130.055, Qg=20.0
% INFO    : Gen at bus 11369	: Vg=1.06019 -> Vg=1.0
% INFO    : Gen at bus 11370	: Pg=90.17, Qg=24.56 -> Pg=130.055, Qg=20.0
% INFO    : Gen at bus 11370	: Vg=1.06019 -> Vg=1.0
% INFO    : Gen at bus 11377	: Pg=275.46, Qg=31.72 -> Pg=350.0, Qg=60.0
% INFO    : Gen at bus 11377	: Vg=1.005433 -> Vg=1.0
% INFO    : Gen at bus 11393	: Pg=0.08, Qg=-0.15 -> Pg=50.025, Qg=0.0
% INFO    : Gen at bus 11393	: Vg=1.016106 -> Vg=1.0
% INFO    : Gen at bus 11401	: Pg=19.93, Qg=2.39 -> Pg=56.645, Qg=10.0
% INFO    : Gen at bus 11401	: Vg=1.050328 -> Vg=1.0
% INFO    : Gen at bus 11403	: Pg=293.92, Qg=111.78 -> Pg=350.0, Qg=80.0
% INFO    : Gen at bus 11403	: Vg=1.039038 -> Vg=1.0
% INFO    : Gen at bus 11406	: Pg=382.46, Qg=57.23 -> Pg=500.0, Qg=80.0
% INFO    : Gen at bus 11406	: Vg=1.050841 -> Vg=1.0
% INFO    : Gen at bus 11408	: Pg=169.22, Qg=17.53 -> Pg=250.0, Qg=60.0
% INFO    : Gen at bus 11408	: Vg=1.013014 -> Vg=1.0
% INFO    : Gen at bus 11409	: Pg=169.22, Qg=17.53 -> Pg=250.0, Qg=60.0
% INFO    : Gen at bus 11409	: Vg=1.013014 -> Vg=1.0
% INFO    : Gen at bus 11410	: Pg=84.71, Qg=3.25 -> Pg=128.235, Qg=15.0
% INFO    : Gen at bus 11410	: Vg=1.030034 -> Vg=1.0
% INFO    : Gen at bus 11411	: Pg=68.89, Qg=19.23 -> Pg=122.965, Qg=20.0
% INFO    : Gen at bus 11411	: Vg=1.035618 -> Vg=1.0
% INFO    : Gen at bus 11412	: Pg=68.89, Qg=19.23 -> Pg=122.965, Qg=20.0
% INFO    : Gen at bus 11412	: Vg=1.035618 -> Vg=1.0
% INFO    : Gen at bus 11414	: Pg=68.89, Qg=19.23 -> Pg=122.965, Qg=20.0
% INFO    : Gen at bus 11414	: Vg=1.035618 -> Vg=1.0
% INFO    : Gen at bus 11416	: Pg=68.89, Qg=19.23 -> Pg=122.965, Qg=20.0
% INFO    : Gen at bus 11416	: Vg=1.035618 -> Vg=1.0
% INFO    : Gen at bus 11418	: Pg=638.57, Qg=231.71 -> Pg=850.0, Qg=200.0
% INFO    : Gen at bus 11418	: Vg=1.051278 -> Vg=1.0
% INFO    : Gen at bus 11419	: Pg=638.58, Qg=231.71 -> Pg=850.0, Qg=200.0
% INFO    : Gen at bus 11419	: Vg=1.051278 -> Vg=1.0
% INFO    : Gen at bus 11440	: Pg=2.5, Qg=0.07 -> Pg=50.835, Qg=0.0
% INFO    : Gen at bus 11440	: Vg=0.984601 -> Vg=1.0
% INFO    : Gen at bus 11454	: Pg=28.52, Qg=8.46 -> Pg=59.505, Qg=10.0
% INFO    : Gen at bus 11454	: Vg=1.013471 -> Vg=1.0
% INFO    : Gen at bus 11455	: Pg=28.52, Qg=8.46 -> Pg=59.505, Qg=10.0
% INFO    : Gen at bus 11455	: Vg=1.013471 -> Vg=1.0
% INFO    : Gen at bus 11456	: Pg=30.24, Qg=3.01 -> Pg=60.08, Qg=5.0
% INFO    : Gen at bus 11456	: Vg=1.001613 -> Vg=1.0
% INFO    : Gen at bus 11467	: Pg=26.62, Qg=13.25 -> Pg=58.875, Qg=10.0
% INFO    : Gen at bus 11467	: Vg=1.040642 -> Vg=1.0
% INFO    : Gen at bus 11471	: Pg=19.85, Qg=-1.9 -> Pg=56.615, Qg=10.0
% INFO    : Gen at bus 11471	: Vg=1.026413 -> Vg=1.0
% INFO    : Gen at bus 11472	: Pg=206.33, Qg=45.76 -> Pg=300.0, Qg=60.0
% INFO    : Gen at bus 11472	: Vg=1.035329 -> Vg=1.0
% INFO    : Gen at bus 11473	: Pg=35.69, Qg=7.89 -> Pg=61.895, Qg=10.0
% INFO    : Gen at bus 11473	: Vg=1.017601 -> Vg=1.0
% INFO    : Gen at bus 11474	: Pg=24.84, Qg=13.51 -> Pg=58.28, Qg=10.0
% INFO    : Gen at bus 11474	: Vg=1.036049 -> Vg=1.0
% INFO    : Gen at bus 11475	: Pg=206.33, Qg=45.6 -> Pg=300.0, Qg=60.0
% INFO    : Gen at bus 11475	: Vg=1.035259 -> Vg=1.0
% INFO    : Gen at bus 11477	: Pg=206.33, Qg=45.76 -> Pg=300.0, Qg=60.0
% INFO    : Gen at bus 11477	: Vg=1.035329 -> Vg=1.0
% INFO    : Gen at bus 11478	: Pg=206.33, Qg=45.6 -> Pg=300.0, Qg=60.0
% INFO    : Gen at bus 11478	: Vg=1.035259 -> Vg=1.0
% INFO    : Gen at bus 11479	: Pg=206.32, Qg=45.91 -> Pg=300.0, Qg=60.0
% INFO    : Gen at bus 11479	: Vg=1.035499 -> Vg=1.0
% INFO    : Gen at bus 11480	: Pg=206.32, Qg=45.73 -> Pg=300.0, Qg=60.0
% INFO    : Gen at bus 11480	: Vg=1.035431 -> Vg=1.0
% INFO    : Gen at bus 11481	: Pg=28.04, Qg=16.4 -> Pg=59.345, Qg=10.0
% INFO    : Gen at bus 11481	: Vg=1.019623 -> Vg=1.0
% INFO    : Gen at bus 11482	: Pg=29.84, Qg=3.47 -> Pg=59.945, Qg=10.0
% INFO    : Gen at bus 11482	: Vg=1.022039 -> Vg=1.0
% INFO    : Gen at bus 11483	: Pg=381.8, Qg=21.67 -> Pg=500.0, Qg=80.0
% INFO    : Gen at bus 11483	: Vg=1.063714 -> Vg=1.0
% INFO    : Gen at bus 11484	: Pg=20.43, Qg=6.2 -> Pg=56.81, Qg=10.0
% INFO    : Gen at bus 11484	: Vg=1.037469 -> Vg=1.0
% INFO    : Gen at bus 11487	: Pg=36.77, Qg=13.93 -> Pg=62.255, Qg=10.0
% INFO    : Gen at bus 11487	: Vg=1.042317 -> Vg=1.0
% INFO    : Gen at bus 11492	: Pg=240.6, Qg=37.13 -> Pg=300.0, Qg=35.0
% INFO    : Gen at bus 11492	: Vg=0.970854 -> Vg=1.0
% INFO    : Gen at bus 11496	: Pg=53.99, Qg=18.23 -> Pg=117.995, Qg=15.0
% INFO    : Gen at bus 11496	: Vg=1.062896 -> Vg=1.0
% INFO    : Gen at bus 11497	: Pg=27.96, Qg=5.11 -> Pg=59.32, Qg=10.0
% INFO    : Gen at bus 11497	: Vg=1.029009 -> Vg=1.0
% INFO    : Gen at bus 11498	: Pg=27.96, Qg=5.11 -> Pg=59.32, Qg=10.0
% INFO    : Gen at bus 11498	: Vg=1.029009 -> Vg=1.0
% INFO    : Gen at bus 11499	: Pg=27.96, Qg=5.11 -> Pg=59.32, Qg=10.0
% INFO    : Gen at bus 11499	: Vg=1.029009 -> Vg=1.0
% INFO    : Gen at bus 11500	: Pg=27.96, Qg=5.11 -> Pg=59.32, Qg=10.0
% INFO    : Gen at bus 11500	: Vg=1.029009 -> Vg=1.0
% INFO    : Gen at bus 11502	: Pg=11.05, Qg=2.35 -> Pg=53.685, Qg=5.0
% INFO    : Gen at bus 11502	: Vg=1.017349 -> Vg=1.0
% INFO    : Gen at bus 11504	: Pg=55.79, Qg=12.28 -> Pg=118.595, Qg=15.0
% INFO    : Gen at bus 11504	: Vg=1.022885 -> Vg=1.0
% INFO    : Gen at bus 11506	: Pg=53.99, Qg=18.23 -> Pg=117.995, Qg=15.0
% INFO    : Gen at bus 11506	: Vg=1.062896 -> Vg=1.0
% INFO    : Gen at bus 11507	: Pg=53.99, Qg=18.23 -> Pg=117.995, Qg=15.0
% INFO    : Gen at bus 11507	: Vg=1.062896 -> Vg=1.0
% INFO    : Gen at bus 11509	: Pg=70.0, Qg=2.13 -> Pg=123.335, Qg=10.0
% INFO    : Gen at bus 11509	: Vg=1.013195 -> Vg=1.0
% INFO    : Gen at bus 11510	: Pg=289.29, Qg=40.05 -> Pg=350.0, Qg=60.0
% INFO    : Gen at bus 11510	: Vg=1.03324 -> Vg=1.0
% INFO    : Gen at bus 11520	: Pg=277.24, Qg=62.37 -> Pg=350.0, Qg=60.0
% INFO    : Gen at bus 11520	: Vg=1.023361 -> Vg=1.0
% INFO    : Gen at bus 11521	: Pg=677.41, Qg=27.58 -> Pg=900.0, Qg=200.0
% INFO    : Gen at bus 11521	: Vg=1.024274 -> Vg=1.0
% INFO    : Gen at bus 11523	: Pg=48.33, Qg=15.81 -> Pg=66.11, Qg=15.0
% INFO    : Gen at bus 11523	: Vg=1.031502 -> Vg=1.0
% INFO    : Gen at bus 11524	: Pg=48.33, Qg=15.81 -> Pg=66.11, Qg=15.0
% INFO    : Gen at bus 11524	: Vg=1.031502 -> Vg=1.0
% INFO    : Gen at bus 11525	: Pg=48.33, Qg=15.81 -> Pg=66.11, Qg=15.0
% INFO    : Gen at bus 11525	: Vg=1.031502 -> Vg=1.0
% INFO    : Gen at bus 11526	: Pg=48.33, Qg=15.81 -> Pg=66.11, Qg=15.0
% INFO    : Gen at bus 11526	: Vg=1.031502 -> Vg=1.0
% INFO    : Gen at bus 11527	: Pg=55.69, Qg=15.93 -> Pg=118.565, Qg=15.0
% INFO    : Gen at bus 11527	: Vg=1.03122 -> Vg=1.0
% INFO    : Gen at bus 11528	: Pg=55.69, Qg=15.93 -> Pg=118.565, Qg=15.0
% INFO    : Gen at bus 11528	: Vg=1.03122 -> Vg=1.0
% INFO    : Gen at bus 11529	: Pg=33.64, Qg=5.18 -> Pg=61.215, Qg=10.0
% INFO    : Gen at bus 11529	: Vg=1.007216 -> Vg=1.0
% INFO    : Gen at bus 11530	: Pg=55.69, Qg=15.93 -> Pg=118.565, Qg=15.0
% INFO    : Gen at bus 11530	: Vg=1.03122 -> Vg=1.0
% INFO    : Gen at bus 11536	: Pg=277.24, Qg=62.37 -> Pg=350.0, Qg=60.0
% INFO    : Gen at bus 11536	: Vg=1.023361 -> Vg=1.0
% INFO    : Gen at bus 11539	: Pg=111.5, Qg=6.79 -> Pg=187.165, Qg=15.0
% INFO    : Gen at bus 11539	: Vg=1.056762 -> Vg=1.0
% INFO    : Gen at bus 11549	: Pg=88.2, Qg=-9.06 -> Pg=129.4, Qg=0.0
% INFO    : Gen at bus 11549	: Vg=0.995145 -> Vg=1.0
% INFO    : Gen at bus 11551	: Pg=32.98, Qg=7.31 -> Pg=60.995, Qg=10.0
% INFO    : Gen at bus 11551	: Vg=1.054159 -> Vg=1.0
% INFO    : Gen at bus 11558	: Pg=72.47, Qg=11.44 -> Pg=124.155, Qg=20.0
% INFO    : Gen at bus 11558	: Vg=1.019231 -> Vg=1.0
% INFO    : Gen at bus 11564	: Pg=321.41, Qg=105.18 -> Pg=450.0, Qg=80.0
% INFO    : Gen at bus 11564	: Vg=1.033947 -> Vg=1.0
% INFO    : Gen at bus 11568	: Pg=69.35, Qg=21.13 -> Pg=123.115, Qg=20.0
% INFO    : Gen at bus 11568	: Vg=1.032238 -> Vg=1.0
% INFO    : Gen at bus 11569	: Pg=69.35, Qg=21.13 -> Pg=123.115, Qg=20.0
% INFO    : Gen at bus 11569	: Vg=1.032238 -> Vg=1.0
% INFO    : Gen at bus 11570	: Pg=53.01, Qg=8.19 -> Pg=117.67, Qg=15.0
% INFO    : Gen at bus 11570	: Vg=1.026319 -> Vg=1.0
% INFO    : Gen at bus 11577	: Pg=20.33, Qg=6.46 -> Pg=56.775, Qg=10.0
% INFO    : Gen at bus 11577	: Vg=0.990908 -> Vg=1.0
% INFO    : Gen at bus 11578	: Pg=28.41, Qg=6.81 -> Pg=59.47, Qg=10.0
% INFO    : Gen at bus 11578	: Vg=1.016999 -> Vg=1.0
% INFO    : Gen at bus 11579	: Pg=21.69, Qg=5.19 -> Pg=57.23, Qg=10.0
% INFO    : Gen at bus 11579	: Vg=1.050987 -> Vg=1.0
% INFO    : Gen at bus 11580	: Pg=54.06, Qg=11.61 -> Pg=118.02, Qg=15.0
% INFO    : Gen at bus 11580	: Vg=1.023809 -> Vg=1.0
% INFO    : Gen at bus 11581	: Pg=25.44, Qg=-2.35 -> Pg=58.48, Qg=0.0
% INFO    : Gen at bus 11581	: Vg=0.995022 -> Vg=1.0
% INFO    : Gen at bus 11584	: Pg=9.1, Qg=-0.32 -> Pg=53.035, Qg=0.0
% INFO    : Gen at bus 11584	: Vg=1.00419 -> Vg=1.0
% INFO    : Gen at bus 11586	: Pg=229.56, Qg=74.98 -> Pg=300.0, Qg=80.0
% INFO    : Gen at bus 11586	: Vg=1.052394 -> Vg=1.0
% INFO    : Gen at bus 11588	: Pg=23.61, Qg=14.88 -> Pg=57.87, Qg=10.0
% INFO    : Gen at bus 11588	: Vg=1.029344 -> Vg=1.0
% INFO    : Gen at bus 11599	: Pg=31.59, Qg=4.82 -> Pg=60.53, Qg=10.0
% INFO    : Gen at bus 11599	: Vg=1.045359 -> Vg=1.0
% INFO    : Gen at bus 11600	: Pg=39.86, Qg=5.41 -> Pg=63.285, Qg=10.0
% INFO    : Gen at bus 11600	: Vg=1.031054 -> Vg=1.0
% INFO    : Gen at bus 11602	: Pg=31.59, Qg=4.82 -> Pg=60.53, Qg=10.0
% INFO    : Gen at bus 11602	: Vg=1.045359 -> Vg=1.0
% INFO    : Gen at bus 11603	: Pg=28.46, Qg=8.42 -> Pg=59.485, Qg=10.0
% INFO    : Gen at bus 11603	: Vg=1.022352 -> Vg=1.0
% INFO    : Gen at bus 11604	: Pg=28.46, Qg=8.42 -> Pg=59.485, Qg=10.0
% INFO    : Gen at bus 11604	: Vg=1.022352 -> Vg=1.0
% INFO    : Gen at bus 11605	: Pg=39.86, Qg=5.41 -> Pg=63.285, Qg=10.0
% INFO    : Gen at bus 11605	: Vg=1.031054 -> Vg=1.0
% INFO    : Gen at bus 11606	: Pg=39.86, Qg=5.41 -> Pg=63.285, Qg=10.0
% INFO    : Gen at bus 11606	: Vg=1.031054 -> Vg=1.0
% INFO    : Gen at bus 11611	: Pg=28.97, Qg=5.47 -> Pg=59.655, Qg=10.0
% INFO    : Gen at bus 11611	: Vg=1.043059 -> Vg=1.0
% INFO    : Gen at bus 11617	: Pg=33.06, Qg=9.48 -> Pg=61.02, Qg=10.0
% INFO    : Gen at bus 11617	: Vg=1.009173 -> Vg=1.0
% INFO    : Gen at bus 11619	: Pg=237.72, Qg=5.93 -> Pg=300.0, Qg=60.0
% INFO    : Gen at bus 11619	: Vg=1.041353 -> Vg=1.0
% INFO    : Gen at bus 11623	: Pg=33.06, Qg=9.48 -> Pg=61.02, Qg=10.0
% INFO    : Gen at bus 11623	: Vg=1.009173 -> Vg=1.0
% INFO    : Gen at bus 11624	: Pg=33.06, Qg=9.48 -> Pg=61.02, Qg=10.0
% INFO    : Gen at bus 11624	: Vg=1.009173 -> Vg=1.0
% INFO    : Gen at bus 11625	: Pg=34.65, Qg=5.41 -> Pg=61.55, Qg=10.0
% INFO    : Gen at bus 11625	: Vg=1.014865 -> Vg=1.0
% INFO    : Gen at bus 11626	: Pg=34.65, Qg=5.41 -> Pg=61.55, Qg=10.0
% INFO    : Gen at bus 11626	: Vg=1.014865 -> Vg=1.0
% INFO    : Gen at bus 11630	: Pg=44.8, Qg=3.17 -> Pg=64.935, Qg=10.0
% INFO    : Gen at bus 11630	: Vg=0.991989 -> Vg=1.0
% INFO    : Gen at bus 11631	: Pg=28.74, Qg=18.23 -> Pg=59.58, Qg=10.0
% INFO    : Gen at bus 11631	: Vg=1.050944 -> Vg=1.0
% INFO    : Gen at bus 11632	: Pg=28.49, Qg=18.25 -> Pg=59.495, Qg=10.0
% INFO    : Gen at bus 11632	: Vg=1.0508 -> Vg=1.0
% INFO    : Gen at bus 11633	: Pg=32.46, Qg=19.3 -> Pg=60.82, Qg=10.0
% INFO    : Gen at bus 11633	: Vg=1.04927 -> Vg=1.0
% INFO    : Gen at bus 11634	: Pg=28.74, Qg=18.23 -> Pg=59.58, Qg=10.0
% INFO    : Gen at bus 11634	: Vg=1.050944 -> Vg=1.0
% INFO    : Gen at bus 11635	: Pg=28.49, Qg=18.25 -> Pg=59.495, Qg=10.0
% INFO    : Gen at bus 11635	: Vg=1.0508 -> Vg=1.0
% INFO    : Gen at bus 11638	: Pg=20.38, Qg=9.61 -> Pg=56.795, Qg=10.0
% INFO    : Gen at bus 11638	: Vg=1.012679 -> Vg=1.0
% INFO    : Gen at bus 11641	: Pg=8.2, Qg=-0.77 -> Pg=52.735, Qg=0.0
% INFO    : Gen at bus 11641	: Vg=1.00746 -> Vg=1.0
% INFO    : Gen at bus 11643	: Pg=43.29, Qg=23.54 -> Pg=64.43, Qg=20.0
% INFO    : Gen at bus 11643	: Vg=1.035771 -> Vg=1.0
% INFO    : Gen at bus 11648	: Pg=36.42, Qg=7.96 -> Pg=62.14, Qg=10.0
% INFO    : Gen at bus 11648	: Vg=1.029166 -> Vg=1.0
% INFO    : Gen at bus 11649	: Pg=277.21, Qg=61.8 -> Pg=350.0, Qg=60.0
% INFO    : Gen at bus 11649	: Vg=1.023418 -> Vg=1.0
% INFO    : Gen at bus 11652	: Pg=29.83, Qg=8.08 -> Pg=59.945, Qg=10.0
% INFO    : Gen at bus 11652	: Vg=1.015374 -> Vg=1.0
% INFO    : Gen at bus 11654	: Pg=31.92, Qg=6.07 -> Pg=60.64, Qg=10.0
% INFO    : Gen at bus 11654	: Vg=1.027264 -> Vg=1.0
% INFO    : Gen at bus 11665	: Pg=153.3, Qg=-6.31 -> Pg=250.0, Qg=10.0
% INFO    : Gen at bus 11665	: Vg=0.947933 -> Vg=1.0
% INFO    : Gen at bus 11666	: Pg=57.11, Qg=19.46 -> Pg=119.035, Qg=20.0
% INFO    : Gen at bus 11666	: Vg=1.032102 -> Vg=1.0
% INFO    : Gen at bus 11667	: Pg=57.11, Qg=19.46 -> Pg=119.035, Qg=20.0
% INFO    : Gen at bus 11667	: Vg=1.032102 -> Vg=1.0
% INFO    : Gen at bus 11668	: Pg=57.11, Qg=19.46 -> Pg=119.035, Qg=20.0
% INFO    : Gen at bus 11668	: Vg=1.032102 -> Vg=1.0
% INFO    : Gen at bus 11669	: Pg=57.11, Qg=19.46 -> Pg=119.035, Qg=20.0
% INFO    : Gen at bus 11669	: Vg=1.032102 -> Vg=1.0
% INFO    : Gen at bus 11670	: Pg=57.11, Qg=19.46 -> Pg=119.035, Qg=20.0
% INFO    : Gen at bus 11670	: Vg=1.032102 -> Vg=1.0
% INFO    : Gen at bus 11672	: Pg=0.02, Qg=1.34 -> Pg=50.005, Qg=0.0
% INFO    : Gen at bus 11672	: Vg=1.018847 -> Vg=1.0
% INFO    : Gen at bus 11677	: Pg=63.63, Qg=44.69 -> Pg=121.21, Qg=20.0
% INFO    : Gen at bus 11677	: Vg=1.058213 -> Vg=1.0
% INFO    : Gen at bus 11680	: Pg=319.18, Qg=33.68 -> Pg=450.0, Qg=80.0
% INFO    : Gen at bus 11680	: Vg=1.026027 -> Vg=1.0
% INFO    : Gen at bus 11686	: Pg=18.67, Qg=5.94 -> Pg=56.225, Qg=10.0
% INFO    : Gen at bus 11686	: Vg=1.015505 -> Vg=1.0
% INFO    : Gen at bus 11687	: Pg=38.91, Qg=13.65 -> Pg=62.97, Qg=10.0
% INFO    : Gen at bus 11687	: Vg=1.01946 -> Vg=1.0
% INFO    : Gen at bus 11689	: Pg=24.03, Qg=8.37 -> Pg=58.01, Qg=10.0
% INFO    : Gen at bus 11689	: Vg=1.005775 -> Vg=1.0
% INFO    : Gen at bus 11690	: Pg=24.03, Qg=8.37 -> Pg=58.01, Qg=10.0
% INFO    : Gen at bus 11690	: Vg=1.005775 -> Vg=1.0
% INFO    : Gen at bus 11691	: Pg=24.03, Qg=8.37 -> Pg=58.01, Qg=10.0
% INFO    : Gen at bus 11691	: Vg=1.005775 -> Vg=1.0
% INFO    : Gen at bus 11692	: Pg=24.03, Qg=8.37 -> Pg=58.01, Qg=10.0
% INFO    : Gen at bus 11692	: Vg=1.005775 -> Vg=1.0
% INFO    : Gen at bus 11693	: Pg=24.03, Qg=8.37 -> Pg=58.01, Qg=10.0
% INFO    : Gen at bus 11693	: Vg=1.005775 -> Vg=1.0
% INFO    : Gen at bus 11694	: Pg=43.17, Qg=6.95 -> Pg=64.39, Qg=10.0
% INFO    : Gen at bus 11694	: Vg=1.015029 -> Vg=1.0
% INFO    : Gen at bus 11695	: Pg=43.17, Qg=6.95 -> Pg=64.39, Qg=10.0
% INFO    : Gen at bus 11695	: Vg=1.015029 -> Vg=1.0
% INFO    : Gen at bus 11699	: Pg=38.79, Qg=7.11 -> Pg=62.93, Qg=10.0
% INFO    : Gen at bus 11699	: Vg=1.035838 -> Vg=1.0
% INFO    : Gen at bus 11704	: Pg=299.72, Qg=120.65 -> Pg=350.0, Qg=60.0
% INFO    : Gen at bus 11704	: Vg=1.047549 -> Vg=1.0
% INFO    : Gen at bus 11705	: Pg=13.26, Qg=-0.68 -> Pg=54.42, Qg=0.0
% INFO    : Gen at bus 11705	: Vg=1.003732 -> Vg=1.0
% INFO    : Gen at bus 11713	: Pg=223.39, Qg=-18.71 -> Pg=300.0, Qg=60.0
% INFO    : Gen at bus 11713	: Vg=1.0182 -> Vg=1.0
% INFO    : Gen at bus 11714	: Pg=223.39, Qg=-18.71 -> Pg=300.0, Qg=60.0
% INFO    : Gen at bus 11714	: Vg=1.0182 -> Vg=1.0
% INFO    : Gen at bus 11716	: Pg=31.47, Qg=4.94 -> Pg=60.49, Qg=10.0
% INFO    : Gen at bus 11716	: Vg=1.024861 -> Vg=1.0
% INFO    : Gen at bus 11717	: Pg=223.02, Qg=66.59 -> Pg=300.0, Qg=60.0
% INFO    : Gen at bus 11717	: Vg=1.042492 -> Vg=1.0
% INFO    : Gen at bus 11723	: Pg=25.54, Qg=8.34 -> Pg=58.515, Qg=10.0
% INFO    : Gen at bus 11723	: Vg=1.050494 -> Vg=1.0
% INFO    : Gen at bus 11729	: Pg=40.49, Qg=8.06 -> Pg=63.495, Qg=10.0
% INFO    : Gen at bus 11729	: Vg=1.036966 -> Vg=1.0
% INFO    : Gen at bus 11736	: Pg=99.76, Qg=14.18 -> Pg=133.255, Qg=20.0
% INFO    : Gen at bus 11736	: Vg=1.046239 -> Vg=1.0
% INFO    : Gen at bus 11745	: Pg=60.81, Qg=1.23 -> Pg=120.27, Qg=20.0
% INFO    : Gen at bus 11745	: Vg=1.039251 -> Vg=1.0
% INFO    : Gen at bus 11749	: Pg=55.22, Qg=8.96 -> Pg=118.405, Qg=15.0
% INFO    : Gen at bus 11749	: Vg=1.017828 -> Vg=1.0
% INFO    : Gen at bus 11752	: Pg=40.51, Qg=5.96 -> Pg=63.505, Qg=10.0
% INFO    : Gen at bus 11752	: Vg=1.017287 -> Vg=1.0
% INFO    : Gen at bus 11755	: Pg=40.97, Qg=7.11 -> Pg=63.655, Qg=15.0
% INFO    : Gen at bus 11755	: Vg=1.019643 -> Vg=1.0
% INFO    : Gen at bus 11756	: Pg=40.97, Qg=7.11 -> Pg=63.655, Qg=15.0
% INFO    : Gen at bus 11756	: Vg=1.019643 -> Vg=1.0
% INFO    : Gen at bus 11757	: Pg=40.97, Qg=7.11 -> Pg=63.655, Qg=15.0
% INFO    : Gen at bus 11757	: Vg=1.019643 -> Vg=1.0
% INFO    : Gen at bus 11758	: Pg=50.33, Qg=11.56 -> Pg=116.775, Qg=15.0
% INFO    : Gen at bus 11758	: Vg=1.037142 -> Vg=1.0
% INFO    : Gen at bus 11759	: Pg=50.33, Qg=11.56 -> Pg=116.775, Qg=15.0
% INFO    : Gen at bus 11759	: Vg=1.037142 -> Vg=1.0
% INFO    : Gen at bus 11760	: Pg=50.33, Qg=11.56 -> Pg=116.775, Qg=15.0
% INFO    : Gen at bus 11760	: Vg=1.037142 -> Vg=1.0
% INFO    : Gen at bus 11761	: Pg=25.35, Qg=8.5 -> Pg=58.45, Qg=15.0
% INFO    : Gen at bus 11761	: Vg=1.018631 -> Vg=1.0
% INFO    : Gen at bus 11762	: Pg=50.33, Qg=11.56 -> Pg=116.775, Qg=15.0
% INFO    : Gen at bus 11762	: Vg=1.037142 -> Vg=1.0
% INFO    : Gen at bus 11763	: Pg=50.33, Qg=11.56 -> Pg=116.775, Qg=15.0
% INFO    : Gen at bus 11763	: Vg=1.037142 -> Vg=1.0
% INFO    : Gen at bus 11768	: Pg=50.4, Qg=3.24 -> Pg=116.8, Qg=0.0
% INFO    : Gen at bus 11768	: Vg=1.023993 -> Vg=1.0
% INFO    : Gen at bus 11773	: Pg=31.57, Qg=7.72 -> Pg=60.525, Qg=10.0
% INFO    : Gen at bus 11773	: Vg=1.008948 -> Vg=1.0
% INFO    : Gen at bus 11781	: Pg=0.96, Qg=0.09 -> Pg=50.32, Qg=0.0
% INFO    : Gen at bus 11781	: Vg=1.03053 -> Vg=1.0
% INFO    : Gen at bus 11786	: Pg=323.35, Qg=77.76 -> Pg=450.0, Qg=80.0
% INFO    : Gen at bus 11786	: Vg=1.058114 -> Vg=1.0
% INFO    : Gen at bus 11789	: Pg=6.52, Qg=0.05 -> Pg=52.175, Qg=0.0
% INFO    : Gen at bus 11789	: Vg=0.996117 -> Vg=1.0
% INFO    : Gen at bus 11796	: Pg=46.26, Qg=7.53 -> Pg=65.42, Qg=15.0
% INFO    : Gen at bus 11796	: Vg=1.015006 -> Vg=1.0
% INFO    : Gen at bus 11797	: Pg=262.9, Qg=48.53 -> Pg=350.0, Qg=60.0
% INFO    : Gen at bus 11797	: Vg=1.027461 -> Vg=1.0
% INFO    : Gen at bus 11803	: Pg=59.71, Qg=48.45 -> Pg=119.905, Qg=20.0
% INFO    : Gen at bus 11803	: Vg=1.060489 -> Vg=1.0
% INFO    : Gen at bus 11805	: Pg=42.35, Qg=6.03 -> Pg=64.115, Qg=15.0
% INFO    : Gen at bus 11805	: Vg=1.030832 -> Vg=1.0
% INFO    : Gen at bus 11806	: Pg=45.38, Qg=12.31 -> Pg=65.125, Qg=20.0
% INFO    : Gen at bus 11806	: Vg=0.990977 -> Vg=1.0
% INFO    : Gen at bus 11810	: Pg=58.52, Qg=23.33 -> Pg=119.505, Qg=15.0
% INFO    : Gen at bus 11810	: Vg=1.023397 -> Vg=1.0
% INFO    : Gen at bus 11811	: Pg=57.02, Qg=14.41 -> Pg=119.005, Qg=15.0
% INFO    : Gen at bus 11811	: Vg=1.026579 -> Vg=1.0
% INFO    : Gen at bus 11813	: Pg=22.46, Qg=14.34 -> Pg=57.485, Qg=15.0
% INFO    : Gen at bus 11813	: Vg=1.024687 -> Vg=1.0
% INFO    : Gen at bus 11814	: Pg=22.46, Qg=14.34 -> Pg=57.485, Qg=15.0
% INFO    : Gen at bus 11814	: Vg=1.024687 -> Vg=1.0
% INFO    : Gen at bus 11815	: Pg=57.02, Qg=14.41 -> Pg=119.005, Qg=15.0
% INFO    : Gen at bus 11815	: Vg=1.026579 -> Vg=1.0
% INFO    : Gen at bus 11816	: Pg=57.02, Qg=14.41 -> Pg=119.005, Qg=15.0
% INFO    : Gen at bus 11816	: Vg=1.026579 -> Vg=1.0
% INFO    : Gen at bus 11817	: Pg=57.51, Qg=17.72 -> Pg=119.17, Qg=15.0
% INFO    : Gen at bus 11817	: Vg=1.029323 -> Vg=1.0
% INFO    : Gen at bus 11818	: Pg=57.51, Qg=17.72 -> Pg=119.17, Qg=15.0
% INFO    : Gen at bus 11818	: Vg=1.029323 -> Vg=1.0
% INFO    : Gen at bus 11819	: Pg=22.46, Qg=14.34 -> Pg=57.485, Qg=15.0
% INFO    : Gen at bus 11819	: Vg=1.024687 -> Vg=1.0
% INFO    : Gen at bus 11820	: Pg=22.46, Qg=14.34 -> Pg=57.485, Qg=15.0
% INFO    : Gen at bus 11820	: Vg=1.024687 -> Vg=1.0
% INFO    : Gen at bus 11822	: Pg=34.86, Qg=4.81 -> Pg=61.62, Qg=10.0
% INFO    : Gen at bus 11822	: Vg=1.050901 -> Vg=1.0
% INFO    : Gen at bus 11825	: Pg=-172.6, Qg=2.92 -> Pg=-65.065, Qg=0.0
% INFO    : Gen at bus 11825	: Vg=1.024059 -> Vg=1.0
% INFO    : Gen at bus 11849	: Pg=97.12, Qg=8.38 -> Pg=132.375, Qg=20.0
% INFO    : Gen at bus 11849	: Vg=1.040009 -> Vg=1.0
% INFO    : Gen at bus 11850	: Pg=8.2, Qg=-2.56 -> Pg=52.735, Qg=0.0
% INFO    : Gen at bus 11850	: Vg=0.955439 -> Vg=1.0
% INFO    : Gen at bus 11851	: Pg=300.0, Qg=86.58 -> Pg=450.0, Qg=80.0
% INFO    : Gen at bus 11851	: Vg=1.056682 -> Vg=1.0
% INFO    : Gen at bus 11853	: Pg=233.91, Qg=82.52 -> Pg=300.0, Qg=80.0
% INFO    : Gen at bus 11853	: Vg=1.057062 -> Vg=1.0
% INFO    : Gen at bus 11854	: Pg=300.0, Qg=86.58 -> Pg=450.0, Qg=80.0
% INFO    : Gen at bus 11854	: Vg=1.056682 -> Vg=1.0
% INFO    : Gen at bus 11856	: Pg=201.8, Qg=24.53 -> Pg=300.0, Qg=40.0
% INFO    : Gen at bus 11856	: Vg=1.021695 -> Vg=1.0
% INFO    : Gen at bus 11859	: Pg=5.0, Qg=2.04 -> Pg=51.665, Qg=0.0
% INFO    : Gen at bus 11859	: Vg=1.009821 -> Vg=1.0
% INFO    : Gen at bus 11875	: Pg=32.72, Qg=7.26 -> Pg=60.905, Qg=10.0
% INFO    : Gen at bus 11875	: Vg=1.016616 -> Vg=1.0
% INFO    : Gen at bus 11880	: Pg=24.99, Qg=2.31 -> Pg=58.33, Qg=10.0
% INFO    : Gen at bus 11880	: Vg=1.010466 -> Vg=1.0
% INFO    : Gen at bus 11886	: Pg=28.39, Qg=6.61 -> Pg=59.465, Qg=15.0
% INFO    : Gen at bus 11886	: Vg=1.013429 -> Vg=1.0
% INFO    : Gen at bus 11889	: Pg=206.37, Qg=113.42 -> Pg=300.0, Qg=60.0
% INFO    : Gen at bus 11889	: Vg=1.061603 -> Vg=1.0
% INFO    : Gen at bus 11891	: Pg=35.02, Qg=1.75 -> Pg=61.675, Qg=10.0
% INFO    : Gen at bus 11891	: Vg=1.038438 -> Vg=1.0
% INFO    : Gen at bus 11892	: Pg=40.51, Qg=5.96 -> Pg=63.505, Qg=10.0
% INFO    : Gen at bus 11892	: Vg=1.017287 -> Vg=1.0
% INFO    : Gen at bus 11894	: Pg=87.19, Qg=27.18 -> Pg=129.065, Qg=20.0
% INFO    : Gen at bus 11894	: Vg=1.023338 -> Vg=1.0
% INFO    : Gen at bus 11895	: Pg=50.92, Qg=11.1 -> Pg=116.975, Qg=15.0
% INFO    : Gen at bus 11895	: Vg=1.010998 -> Vg=1.0
% INFO    : Gen at bus 11897	: Pg=206.37, Qg=113.42 -> Pg=300.0, Qg=60.0
% INFO    : Gen at bus 11897	: Vg=1.061603 -> Vg=1.0
% INFO    : Gen at bus 11898	: Pg=256.4, Qg=117.4 -> Pg=350.0, Qg=60.0
% INFO    : Gen at bus 11898	: Vg=1.062536 -> Vg=1.0
% INFO    : Gen at bus 11900	: Pg=23.58, Qg=-5.0 -> Pg=57.86, Qg=0.0
% INFO    : Gen at bus 11900	: Vg=0.964368 -> Vg=1.0
% INFO    : Gen at bus 11903	: Pg=3.02, Qg=0.33 -> Pg=51.01, Qg=0.0
% INFO    : Gen at bus 11903	: Vg=1.03013 -> Vg=1.0
% INFO    : Gen at bus 11909	: Pg=938.69, Qg=9.52 -> Pg=1250.0, Qg=200.0
% INFO    : Gen at bus 11909	: Vg=1.028568 -> Vg=1.0
% INFO    : Gen at bus 11913	: Pg=39.03, Qg=10.16 -> Pg=63.01, Qg=10.0
% INFO    : Gen at bus 11913	: Vg=1.033359 -> Vg=1.0
% INFO    : Gen at bus 11914	: Pg=39.03, Qg=10.16 -> Pg=63.01, Qg=10.0
% INFO    : Gen at bus 11914	: Vg=1.033359 -> Vg=1.0
% INFO    : Gen at bus 11916	: Pg=35.6, Qg=15.17 -> Pg=61.865, Qg=10.0
% INFO    : Gen at bus 11916	: Vg=1.026957 -> Vg=1.0
% INFO    : Gen at bus 11919	: Pg=35.6, Qg=15.17 -> Pg=61.865, Qg=10.0
% INFO    : Gen at bus 11919	: Vg=1.026957 -> Vg=1.0
% INFO    : Gen at bus 11920	: Pg=31.3, Qg=-0.89 -> Pg=60.435, Qg=0.0
% INFO    : Gen at bus 11920	: Vg=0.998951 -> Vg=1.0
% INFO    : Gen at bus 11922	: Pg=28.89, Qg=4.69 -> Pg=59.63, Qg=10.0
% INFO    : Gen at bus 11922	: Vg=1.029382 -> Vg=1.0
% INFO    : Gen at bus 11924	: Pg=95.51, Qg=37.64 -> Pg=131.835, Qg=20.0
% INFO    : Gen at bus 11924	: Vg=1.0608 -> Vg=1.0
% INFO    : Gen at bus 11927	: Pg=992.0, Qg=834.49 -> Pg=1300.0, Qg=0.0
% INFO    : Gen at bus 11927	: Vg=1.058046 -> Vg=1.0
% INFO    : Gen at bus 11935	: Pg=55.25, Qg=2.21 -> Pg=118.415, Qg=0.0
% INFO    : Gen at bus 11935	: Vg=0.994234 -> Vg=1.0
% INFO    : Gen at bus 11945	: Pg=10.36, Qg=0.68 -> Pg=53.455, Qg=0.0
% INFO    : Gen at bus 11945	: Vg=1.012893 -> Vg=1.0
% INFO    : Gen at bus 11946	: Pg=78.71, Qg=19.55 -> Pg=126.235, Qg=20.0
% INFO    : Gen at bus 11946	: Vg=1.033214 -> Vg=1.0
% INFO    : Gen at bus 11950	: Pg=285.52, Qg=89.66 -> Pg=350.0, Qg=80.0
% INFO    : Gen at bus 11950	: Vg=1.04459 -> Vg=1.0
% INFO    : Gen at bus 11953	: Pg=64.18, Qg=-6.8 -> Pg=121.395, Qg=0.0
% INFO    : Gen at bus 11953	: Vg=0.951565 -> Vg=1.0
% INFO    : Gen at bus 11959	: Pg=78.71, Qg=19.51 -> Pg=126.235, Qg=20.0
% INFO    : Gen at bus 11959	: Vg=1.033214 -> Vg=1.0
% INFO    : Gen at bus 11962	: Pg=78.71, Qg=19.51 -> Pg=126.235, Qg=20.0
% INFO    : Gen at bus 11962	: Vg=1.033214 -> Vg=1.0
% INFO    : Gen at bus 11967	: Pg=5.2, Qg=1.64 -> Pg=51.735, Qg=0.0
% INFO    : Gen at bus 11967	: Vg=1.019503 -> Vg=1.0
% INFO    : Gen at bus 11968	: Pg=95.02, Qg=8.09 -> Pg=131.675, Qg=20.0
% INFO    : Gen at bus 11968	: Vg=1.023144 -> Vg=1.0
% INFO    : Gen at bus 11970	: Pg=8.4, Qg=-0.55 -> Pg=52.8, Qg=0.0
% INFO    : Gen at bus 11970	: Vg=0.988112 -> Vg=1.0
% INFO    : Gen at bus 11975	: Pg=68.3, Qg=12.27 -> Pg=122.765, Qg=20.0
% INFO    : Gen at bus 11975	: Vg=1.015227 -> Vg=1.0
% INFO    : Gen at bus 11976	: Pg=47.29, Qg=6.72 -> Pg=65.765, Qg=15.0
% INFO    : Gen at bus 11976	: Vg=1.04826 -> Vg=1.0
% INFO    : Gen at bus 11978	: Pg=93.77, Qg=48.62 -> Pg=131.255, Qg=20.0
% INFO    : Gen at bus 11978	: Vg=1.054388 -> Vg=1.0
% INFO    : Gen at bus 11979	: Pg=93.77, Qg=48.62 -> Pg=131.255, Qg=20.0
% INFO    : Gen at bus 11979	: Vg=1.054388 -> Vg=1.0
% INFO    : Gen at bus 11980	: Pg=93.77, Qg=48.62 -> Pg=131.255, Qg=20.0
% INFO    : Gen at bus 11980	: Vg=1.054388 -> Vg=1.0
% INFO    : Gen at bus 11982	: Pg=277.26, Qg=31.82 -> Pg=350.0, Qg=80.0
% INFO    : Gen at bus 11982	: Vg=1.04876 -> Vg=1.0
% INFO    : Gen at bus 11986	: Pg=48.42, Qg=9.78 -> Pg=66.14, Qg=15.0
% INFO    : Gen at bus 11986	: Vg=1.01601 -> Vg=1.0
% INFO    : Gen at bus 11987	: Pg=290.0, Qg=-23.36 -> Pg=350.0, Qg=0.0
% INFO    : Gen at bus 11987	: Vg=0.971901 -> Vg=1.0
% INFO    : Gen at bus 11988	: Pg=36.91, Qg=13.33 -> Pg=62.305, Qg=10.0
% INFO    : Gen at bus 11988	: Vg=1.037973 -> Vg=1.0
% INFO    : Gen at bus 11990	: Pg=19.75, Qg=-0.1 -> Pg=56.585, Qg=0.0
% INFO    : Gen at bus 11990	: Vg=1.002465 -> Vg=1.0
% INFO    : Gen at bus 11996	: Pg=35.01, Qg=1.48 -> Pg=61.67, Qg=10.0
% INFO    : Gen at bus 11996	: Vg=1.032132 -> Vg=1.0
% INFO    : Gen at bus 12001	: Pg=168.0, Qg=14.06 -> Pg=250.0, Qg=25.0
% INFO    : Gen at bus 12001	: Vg=1.016606 -> Vg=1.0
% INFO    : Gen at bus 12013	: Pg=156.71, Qg=14.75 -> Pg=250.0, Qg=35.0
% INFO    : Gen at bus 12013	: Vg=1.008914 -> Vg=1.0
% INFO    : Gen at bus 12016	: Pg=214.52, Qg=110.59 -> Pg=300.0, Qg=80.0
% INFO    : Gen at bus 12016	: Vg=1.065343 -> Vg=1.0
% INFO    : Gen at bus 12020	: Pg=26.22, Qg=3.21 -> Pg=58.74, Qg=10.0
% INFO    : Gen at bus 12020	: Vg=1.015252 -> Vg=1.0
% INFO    : Gen at bus 12021	: Pg=43.5, Qg=8.1 -> Pg=64.5, Qg=10.0
% INFO    : Gen at bus 12021	: Vg=1.018676 -> Vg=1.0
% INFO    : Gen at bus 12024	: Pg=77.25, Qg=12.22 -> Pg=125.75, Qg=20.0
% INFO    : Gen at bus 12024	: Vg=1.034048 -> Vg=1.0
% INFO    : Gen at bus 12025	: Pg=53.45, Qg=18.98 -> Pg=117.815, Qg=15.0
% INFO    : Gen at bus 12025	: Vg=1.030499 -> Vg=1.0
% INFO    : Gen at bus 12027	: Pg=20.4, Qg=2.66 -> Pg=56.8, Qg=5.0
% INFO    : Gen at bus 12027	: Vg=1.042665 -> Vg=1.0
% INFO    : Gen at bus 12035	: Pg=38.79, Qg=7.11 -> Pg=62.93, Qg=10.0
% INFO    : Gen at bus 12035	: Vg=1.035838 -> Vg=1.0
% INFO    : Gen at bus 12042	: Pg=21.72, Qg=6.92 -> Pg=57.24, Qg=10.0
% INFO    : Gen at bus 12042	: Vg=1.014428 -> Vg=1.0
% INFO    : Gen at bus 12045	: Pg=40.16, Qg=7.07 -> Pg=63.385, Qg=10.0
% INFO    : Gen at bus 12045	: Vg=1.013722 -> Vg=1.0
% INFO    : Gen at bus 12049	: Pg=37.96, Qg=13.4 -> Pg=62.655, Qg=10.0
% INFO    : Gen at bus 12049	: Vg=1.073911 -> Vg=1.0
% INFO    : Gen at bus 12050	: Pg=135.0, Qg=10.29 -> Pg=195.0, Qg=25.0
% INFO    : Gen at bus 12050	: Vg=1.008348 -> Vg=1.0
% INFO    : Gen at bus 12060	: Pg=4.8, Qg=-0.11 -> Pg=51.6, Qg=0.0
% INFO    : Gen at bus 12060	: Vg=0.996411 -> Vg=1.0
% INFO    : Gen at bus 12065	: Pg=224.46, Qg=15.93 -> Pg=300.0, Qg=80.0
% INFO    : Gen at bus 12065	: Vg=1.031165 -> Vg=1.0
% INFO    : Gen at bus 12069	: Pg=34.37, Qg=6.67 -> Pg=61.455, Qg=10.0
% INFO    : Gen at bus 12069	: Vg=1.035406 -> Vg=1.0
% INFO    : Gen at bus 12070	: Pg=34.37, Qg=6.67 -> Pg=61.455, Qg=10.0
% INFO    : Gen at bus 12070	: Vg=1.035406 -> Vg=1.0
% INFO    : Gen at bus 12071	: Pg=34.37, Qg=6.67 -> Pg=61.455, Qg=10.0
% INFO    : Gen at bus 12071	: Vg=1.035406 -> Vg=1.0
% INFO    : Gen at bus 12072	: Pg=96.57, Qg=34.4 -> Pg=132.19, Qg=20.0
% INFO    : Gen at bus 12072	: Vg=1.051326 -> Vg=1.0
% INFO    : Gen at bus 12073	: Pg=34.37, Qg=6.67 -> Pg=61.455, Qg=10.0
% INFO    : Gen at bus 12073	: Vg=1.035406 -> Vg=1.0
% INFO    : Gen at bus 12074	: Pg=34.37, Qg=6.67 -> Pg=61.455, Qg=10.0
% INFO    : Gen at bus 12074	: Vg=1.035406 -> Vg=1.0
% INFO    : Gen at bus 12075	: Pg=34.37, Qg=6.67 -> Pg=61.455, Qg=10.0
% INFO    : Gen at bus 12075	: Vg=1.035406 -> Vg=1.0
% INFO    : Gen at bus 12076	: Pg=34.37, Qg=6.67 -> Pg=61.455, Qg=10.0
% INFO    : Gen at bus 12076	: Vg=1.035406 -> Vg=1.0
% INFO    : Gen at bus 12084	: Pg=60.08, Qg=4.3 -> Pg=120.025, Qg=20.0
% INFO    : Gen at bus 12084	: Vg=1.012034 -> Vg=1.0
% INFO    : Gen at bus 12085	: Pg=60.08, Qg=4.3 -> Pg=120.025, Qg=20.0
% INFO    : Gen at bus 12085	: Vg=1.012034 -> Vg=1.0
% INFO    : Gen at bus 12088	: Pg=28.66, Qg=14.89 -> Pg=59.555, Qg=10.0
% INFO    : Gen at bus 12088	: Vg=1.014269 -> Vg=1.0
% INFO    : Gen at bus 12091	: Pg=31.79, Qg=7.29 -> Pg=60.595, Qg=10.0
% INFO    : Gen at bus 12091	: Vg=1.005112 -> Vg=1.0
% INFO    : Gen at bus 12093	: Pg=91.55, Qg=46.19 -> Pg=130.515, Qg=20.0
% INFO    : Gen at bus 12093	: Vg=1.056125 -> Vg=1.0
% INFO    : Gen at bus 12095	: Pg=95.01, Qg=14.99 -> Pg=131.67, Qg=20.0
% INFO    : Gen at bus 12095	: Vg=1.024647 -> Vg=1.0
% INFO    : Gen at bus 12097	: Pg=92.69, Qg=14.48 -> Pg=130.895, Qg=20.0
% INFO    : Gen at bus 12097	: Vg=1.026207 -> Vg=1.0
% INFO    : Gen at bus 12099	: Pg=16.71, Qg=0.01 -> Pg=55.57, Qg=10.0
% INFO    : Gen at bus 12099	: Vg=1.030988 -> Vg=1.0
% INFO    : Gen at bus 12102	: Pg=93.64, Qg=6.04 -> Pg=131.215, Qg=20.0
% INFO    : Gen at bus 12102	: Vg=1.023818 -> Vg=1.0
% INFO    : Gen at bus 12106	: Pg=39.88, Qg=15.15 -> Pg=63.295, Qg=10.0
% INFO    : Gen at bus 12106	: Vg=1.024267 -> Vg=1.0
% INFO    : Gen at bus 12116	: Pg=42.33, Qg=15.72 -> Pg=64.11, Qg=15.0
% INFO    : Gen at bus 12116	: Vg=1.031695 -> Vg=1.0
% INFO    : Gen at bus 12121	: Pg=19.26, Qg=2.33 -> Pg=56.42, Qg=10.0
% INFO    : Gen at bus 12121	: Vg=1.049756 -> Vg=1.0
% INFO    : Gen at bus 12123	: Pg=4.5, Qg=-0.83 -> Pg=51.5, Qg=0.0
% INFO    : Gen at bus 12123	: Vg=1.003288 -> Vg=1.0
% INFO    : Gen at bus 12124	: Pg=18.74, Qg=3.61 -> Pg=56.245, Qg=10.0
% INFO    : Gen at bus 12124	: Vg=1.025271 -> Vg=1.0
% INFO    : Gen at bus 12126	: Pg=29.14, Qg=3.85 -> Pg=59.715, Qg=10.0
% INFO    : Gen at bus 12126	: Vg=1.025372 -> Vg=1.0
% INFO    : Gen at bus 12127	: Pg=29.14, Qg=3.85 -> Pg=59.715, Qg=10.0
% INFO    : Gen at bus 12127	: Vg=1.025372 -> Vg=1.0
% INFO    : Gen at bus 12131	: Pg=83.47, Qg=36.43 -> Pg=127.825, Qg=20.0
% INFO    : Gen at bus 12131	: Vg=1.039883 -> Vg=1.0
% INFO    : Gen at bus 12132	: Pg=83.47, Qg=36.43 -> Pg=127.825, Qg=20.0
% INFO    : Gen at bus 12132	: Vg=1.039883 -> Vg=1.0
% INFO    : Gen at bus 12133	: Pg=90.97, Qg=23.14 -> Pg=130.325, Qg=20.0
% INFO    : Gen at bus 12133	: Vg=1.033722 -> Vg=1.0
% INFO    : Gen at bus 12134	: Pg=90.97, Qg=23.14 -> Pg=130.325, Qg=20.0
% INFO    : Gen at bus 12134	: Vg=1.033722 -> Vg=1.0
% INFO    : Gen at bus 12135	: Pg=90.97, Qg=23.14 -> Pg=130.325, Qg=20.0
% INFO    : Gen at bus 12135	: Vg=1.033722 -> Vg=1.0
% INFO    : Gen at bus 12136	: Pg=90.97, Qg=23.14 -> Pg=130.325, Qg=20.0
% INFO    : Gen at bus 12136	: Vg=1.033722 -> Vg=1.0
% INFO    : Gen at bus 12137	: Pg=90.94, Qg=17.93 -> Pg=130.315, Qg=20.0
% INFO    : Gen at bus 12137	: Vg=1.033736 -> Vg=1.0
% INFO    : Gen at bus 12138	: Pg=90.94, Qg=17.93 -> Pg=130.315, Qg=20.0
% INFO    : Gen at bus 12138	: Vg=1.033736 -> Vg=1.0
% INFO    : Gen at bus 12139	: Pg=90.94, Qg=17.93 -> Pg=130.315, Qg=20.0
% INFO    : Gen at bus 12139	: Vg=1.033736 -> Vg=1.0
% INFO    : Gen at bus 12140	: Pg=90.94, Qg=17.93 -> Pg=130.315, Qg=20.0
% INFO    : Gen at bus 12140	: Vg=1.033736 -> Vg=1.0
% INFO    : Gen at bus 12152	: Pg=91.34, Qg=21.91 -> Pg=130.445, Qg=20.0
% INFO    : Gen at bus 12152	: Vg=1.030656 -> Vg=1.0
% INFO    : Gen at bus 12163	: Pg=17.6, Qg=22.53 -> Pg=55.865, Qg=10.0
% INFO    : Gen at bus 12163	: Vg=1.05667 -> Vg=1.0
% INFO    : Gen at bus 12164	: Pg=17.6, Qg=22.53 -> Pg=55.865, Qg=10.0
% INFO    : Gen at bus 12164	: Vg=1.05667 -> Vg=1.0
% INFO    : Gen at bus 12166	: Pg=30.64, Qg=2.43 -> Pg=60.215, Qg=10.0
% INFO    : Gen at bus 12166	: Vg=1.030179 -> Vg=1.0
% INFO    : Gen at bus 12167	: Pg=30.64, Qg=2.43 -> Pg=60.215, Qg=10.0
% INFO    : Gen at bus 12167	: Vg=1.030179 -> Vg=1.0
% INFO    : Gen at bus 12168	: Pg=30.64, Qg=2.43 -> Pg=60.215, Qg=10.0
% INFO    : Gen at bus 12168	: Vg=1.030179 -> Vg=1.0
% INFO    : Gen at bus 12169	: Pg=30.64, Qg=2.43 -> Pg=60.215, Qg=10.0
% INFO    : Gen at bus 12169	: Vg=1.030179 -> Vg=1.0
% INFO    : Gen at bus 12170	: Pg=17.6, Qg=22.53 -> Pg=55.865, Qg=10.0
% INFO    : Gen at bus 12170	: Vg=1.05667 -> Vg=1.0
% INFO    : Gen at bus 12171	: Pg=17.6, Qg=22.53 -> Pg=55.865, Qg=10.0
% INFO    : Gen at bus 12171	: Vg=1.05667 -> Vg=1.0
% INFO    : Gen at bus 12172	: Pg=30.64, Qg=2.43 -> Pg=60.215, Qg=10.0
% INFO    : Gen at bus 12172	: Vg=1.030179 -> Vg=1.0
% INFO    : Gen at bus 12173	: Pg=800.47, Qg=18.87 -> Pg=1100.0, Qg=200.0
% INFO    : Gen at bus 12173	: Vg=1.04071 -> Vg=1.0
% INFO    : Gen at bus 12175	: Pg=30.93, Qg=8.23 -> Pg=60.31, Qg=10.0
% INFO    : Gen at bus 12175	: Vg=1.035888 -> Vg=1.0
% INFO    : Gen at bus 12178	: Pg=49.1, Qg=2.32 -> Pg=66.365, Qg=5.0
% INFO    : Gen at bus 12178	: Vg=1.014358 -> Vg=1.0
% INFO    : Gen at bus 12189	: Pg=18.1, Qg=0.8 -> Pg=56.035, Qg=0.0
% INFO    : Gen at bus 12189	: Vg=1.007227 -> Vg=1.0
% INFO    : Gen at bus 12191	: Pg=23.7, Qg=5.77 -> Pg=57.9, Qg=10.0
% INFO    : Gen at bus 12191	: Vg=1.013974 -> Vg=1.0
% INFO    : Gen at bus 12192	: Pg=23.7, Qg=5.77 -> Pg=57.9, Qg=10.0
% INFO    : Gen at bus 12192	: Vg=1.013974 -> Vg=1.0
% INFO    : Gen at bus 12193	: Pg=18.91, Qg=10.94 -> Pg=56.305, Qg=10.0
% INFO    : Gen at bus 12193	: Vg=1.015043 -> Vg=1.0
% INFO    : Gen at bus 12194	: Pg=18.91, Qg=10.94 -> Pg=56.305, Qg=10.0
% INFO    : Gen at bus 12194	: Vg=1.015043 -> Vg=1.0
% INFO    : Gen at bus 12195	: Pg=21.17, Qg=9.91 -> Pg=57.055, Qg=10.0
% INFO    : Gen at bus 12195	: Vg=1.048748 -> Vg=1.0
% INFO    : Gen at bus 12199	: Pg=210.0, Qg=37.99 -> Pg=300.0, Qg=60.0
% INFO    : Gen at bus 12199	: Vg=0.991398 -> Vg=1.0
% INFO    : Gen at bus 12200	: Pg=29.92, Qg=13.61 -> Pg=59.975, Qg=10.0
% INFO    : Gen at bus 12200	: Vg=1.031553 -> Vg=1.0
% INFO    : Gen at bus 12204	: Pg=298.7, Qg=3.31 -> Pg=350.0, Qg=35.0
% INFO    : Gen at bus 12204	: Vg=0.975834 -> Vg=1.0
% INFO    : Gen at bus 12208	: Pg=382.77, Qg=9.72 -> Pg=500.0, Qg=80.0
% INFO    : Gen at bus 12208	: Vg=1.043874 -> Vg=1.0
% INFO    : Gen at bus 12211	: Pg=319.18, Qg=33.68 -> Pg=450.0, Qg=80.0
% INFO    : Gen at bus 12211	: Vg=1.026027 -> Vg=1.0
% INFO    : Gen at bus 12216	: Pg=37.08, Qg=5.51 -> Pg=62.36, Qg=10.0
% INFO    : Gen at bus 12216	: Vg=1.021005 -> Vg=1.0
% INFO    : Gen at bus 12217	: Pg=40.49, Qg=8.06 -> Pg=63.495, Qg=10.0
% INFO    : Gen at bus 12217	: Vg=1.036966 -> Vg=1.0
% INFO    : Gen at bus 12219	: Pg=22.46, Qg=14.75 -> Pg=57.485, Qg=10.0
% INFO    : Gen at bus 12219	: Vg=1.043942 -> Vg=1.0
% INFO    : Gen at bus 12221	: Pg=3.13, Qg=0.12 -> Pg=51.045, Qg=0.0
% INFO    : Gen at bus 12221	: Vg=1.029545 -> Vg=1.0
% INFO    : Gen at bus 12222	: Pg=35.86, Qg=4.09 -> Pg=61.955, Qg=10.0
% INFO    : Gen at bus 12222	: Vg=1.02494 -> Vg=1.0
% INFO    : Gen at bus 12227	: Pg=38.02, Qg=11.21 -> Pg=62.675, Qg=10.0
% INFO    : Gen at bus 12227	: Vg=1.043087 -> Vg=1.0
% INFO    : Gen at bus 12232	: Pg=89.93, Qg=16.64 -> Pg=129.975, Qg=20.0
% INFO    : Gen at bus 12232	: Vg=1.037993 -> Vg=1.0
% INFO    : Gen at bus 12240	: Pg=51.04, Qg=7.37 -> Pg=117.015, Qg=10.0
% INFO    : Gen at bus 12240	: Vg=1.022424 -> Vg=1.0
% INFO    : Gen at bus 12245	: Pg=30.24, Qg=6.83 -> Pg=60.08, Qg=10.0
% INFO    : Gen at bus 12245	: Vg=1.037281 -> Vg=1.0
% INFO    : Gen at bus 12248	: Pg=261.4, Qg=61.75 -> Pg=350.0, Qg=35.0
% INFO    : Gen at bus 12248	: Vg=0.988817 -> Vg=1.0
% INFO    : Gen at bus 12252	: Pg=227.21, Qg=72.31 -> Pg=300.0, Qg=80.0
% INFO    : Gen at bus 12252	: Vg=1.063358 -> Vg=1.0
% INFO    : Gen at bus 12255	: Pg=323.89, Qg=98.77 -> Pg=450.0, Qg=80.0
% INFO    : Gen at bus 12255	: Vg=1.062762 -> Vg=1.0
% INFO    : Gen at bus 12259	: Pg=227.21, Qg=72.6 -> Pg=300.0, Qg=80.0
% INFO    : Gen at bus 12259	: Vg=1.06345 -> Vg=1.0
% INFO    : Gen at bus 12266	: Pg=155.5, Qg=12.42 -> Pg=250.0, Qg=15.0
% INFO    : Gen at bus 12266	: Vg=1.034282 -> Vg=1.0
% INFO    : Gen at bus 12275	: Pg=83.29, Qg=7.43 -> Pg=127.765, Qg=20.0
% INFO    : Gen at bus 12275	: Vg=1.042396 -> Vg=1.0
% INFO    : Gen at bus 12276	: Pg=83.29, Qg=7.43 -> Pg=127.765, Qg=20.0
% INFO    : Gen at bus 12276	: Vg=1.042396 -> Vg=1.0
% INFO    : Gen at bus 12277	: Pg=6.1, Qg=0.22 -> Pg=52.035, Qg=0.0
% INFO    : Gen at bus 12277	: Vg=1.00107 -> Vg=1.0
% INFO    : Gen at bus 12278	: Pg=79.77, Qg=4.15 -> Pg=126.59, Qg=20.0
% INFO    : Gen at bus 12278	: Vg=1.047117 -> Vg=1.0
% INFO    : Gen at bus 12279	: Pg=79.77, Qg=4.15 -> Pg=126.59, Qg=20.0
% INFO    : Gen at bus 12279	: Vg=1.047117 -> Vg=1.0
% INFO    : Gen at bus 12280	: Pg=83.29, Qg=7.43 -> Pg=127.765, Qg=20.0
% INFO    : Gen at bus 12280	: Vg=1.042396 -> Vg=1.0
% INFO    : Gen at bus 12281	: Pg=79.77, Qg=4.15 -> Pg=126.59, Qg=20.0
% INFO    : Gen at bus 12281	: Vg=1.047117 -> Vg=1.0
% INFO    : Gen at bus 12282	: Pg=37.23, Qg=4.01 -> Pg=62.41, Qg=10.0
% INFO    : Gen at bus 12282	: Vg=1.028283 -> Vg=1.0
% INFO    : Gen at bus 12285	: Pg=3.2, Qg=1.16 -> Pg=51.065, Qg=0.0
% INFO    : Gen at bus 12285	: Vg=0.991765 -> Vg=1.0
% INFO    : Gen at bus 12286	: Pg=55.25, Qg=0.75 -> Pg=118.415, Qg=0.0
% INFO    : Gen at bus 12286	: Vg=0.959658 -> Vg=1.0
% INFO    : Gen at bus 12287	: Pg=159.8, Qg=33.64 -> Pg=250.0, Qg=25.0
% INFO    : Gen at bus 12287	: Vg=0.993125 -> Vg=1.0
% INFO    : Gen at bus 12291	: Pg=240.6, Qg=61.33 -> Pg=300.0, Qg=35.0
% INFO    : Gen at bus 12291	: Vg=0.990464 -> Vg=1.0
% INFO    : Gen at bus 12302	: Pg=40.71, Qg=13.63 -> Pg=63.57, Qg=15.0
% INFO    : Gen at bus 12302	: Vg=1.028425 -> Vg=1.0
% INFO    : Gen at bus 12303	: Pg=40.71, Qg=13.63 -> Pg=63.57, Qg=15.0
% INFO    : Gen at bus 12303	: Vg=1.028425 -> Vg=1.0
% INFO    : Gen at bus 12304	: Pg=40.71, Qg=13.63 -> Pg=63.57, Qg=15.0
% INFO    : Gen at bus 12304	: Vg=1.028425 -> Vg=1.0
% INFO    : Gen at bus 12306	: Pg=37.35, Qg=7.36 -> Pg=62.45, Qg=15.0
% INFO    : Gen at bus 12306	: Vg=1.026363 -> Vg=1.0
% INFO    : Gen at bus 12307	: Pg=40.71, Qg=13.63 -> Pg=63.57, Qg=15.0
% INFO    : Gen at bus 12307	: Vg=1.028425 -> Vg=1.0
% INFO    : Gen at bus 12310	: Pg=34.96, Qg=12.97 -> Pg=61.655, Qg=10.0
% INFO    : Gen at bus 12310	: Vg=1.054937 -> Vg=1.0
% INFO    : Gen at bus 12319	: Pg=52.29, Qg=8.76 -> Pg=117.43, Qg=15.0
% INFO    : Gen at bus 12319	: Vg=1.021414 -> Vg=1.0
% INFO    : Gen at bus 12321	: Pg=34.86, Qg=4.81 -> Pg=61.62, Qg=10.0
% INFO    : Gen at bus 12321	: Vg=1.050901 -> Vg=1.0
% INFO    : Gen at bus 12325	: Pg=52.29, Qg=8.76 -> Pg=117.43, Qg=15.0
% INFO    : Gen at bus 12325	: Vg=1.021414 -> Vg=1.0
% INFO    : Gen at bus 12330	: Pg=63.72, Qg=11.02 -> Pg=121.24, Qg=15.0
% INFO    : Gen at bus 12330	: Vg=1.030356 -> Vg=1.0
% INFO    : Gen at bus 12332	: Pg=63.72, Qg=11.02 -> Pg=121.24, Qg=15.0
% INFO    : Gen at bus 12332	: Vg=1.030356 -> Vg=1.0
% INFO    : Gen at bus 12333	: Pg=63.72, Qg=11.02 -> Pg=121.24, Qg=15.0
% INFO    : Gen at bus 12333	: Vg=1.030356 -> Vg=1.0
% INFO    : Gen at bus 12334	: Pg=63.72, Qg=11.02 -> Pg=121.24, Qg=15.0
% INFO    : Gen at bus 12334	: Vg=1.030356 -> Vg=1.0
% INFO    : Gen at bus 12337	: Pg=39.88, Qg=8.05 -> Pg=63.295, Qg=15.0
% INFO    : Gen at bus 12337	: Vg=1.030375 -> Vg=1.0
% INFO    : Gen at bus 12338	: Pg=39.88, Qg=8.05 -> Pg=63.295, Qg=15.0
% INFO    : Gen at bus 12338	: Vg=1.030375 -> Vg=1.0
% INFO    : Gen at bus 12341	: Pg=77.25, Qg=12.22 -> Pg=125.75, Qg=20.0
% INFO    : Gen at bus 12341	: Vg=1.034048 -> Vg=1.0
% INFO    : Gen at bus 12346	: Pg=325.03, Qg=139.06 -> Pg=450.0, Qg=80.0
% INFO    : Gen at bus 12346	: Vg=1.059619 -> Vg=1.0
% INFO    : Gen at bus 12348	: Pg=289.92, Qg=105.36 -> Pg=350.0, Qg=80.0
% INFO    : Gen at bus 12348	: Vg=1.057338 -> Vg=1.0
% INFO    : Gen at bus 12358	: Pg=10.0, Qg=0.51 -> Pg=53.335, Qg=0.0
% INFO    : Gen at bus 12358	: Vg=1.016383 -> Vg=1.0
% INFO    : Gen at bus 12359	: Pg=6.1, Qg=0.22 -> Pg=52.035, Qg=0.0
% INFO    : Gen at bus 12359	: Vg=1.00107 -> Vg=1.0
% INFO    : Gen at bus 12367	: Pg=210.0, Qg=16.99 -> Pg=300.0, Qg=35.0
% INFO    : Gen at bus 12367	: Vg=0.981513 -> Vg=1.0
% INFO    : Gen at bus 12373	: Pg=313.39, Qg=68.14 -> Pg=450.0, Qg=80.0
% INFO    : Gen at bus 12373	: Vg=1.035914 -> Vg=1.0
% INFO    : Gen at bus 12375	: Pg=126.0, Qg=-10.22 -> Pg=192.0, Qg=15.0
% INFO    : Gen at bus 12375	: Vg=1.007198 -> Vg=1.0
% INFO    : Gen at bus 12381	: Pg=19.27, Qg=11.16 -> Pg=56.425, Qg=10.0
% INFO    : Gen at bus 12381	: Vg=1.021475 -> Vg=1.0
% INFO    : Gen at bus 12383	: Pg=52.88, Qg=1.71 -> Pg=117.625, Qg=5.0
% INFO    : Gen at bus 12383	: Vg=1.017202 -> Vg=1.0
% INFO    : Gen at bus 12387	: Pg=24.98, Qg=14.2 -> Pg=58.325, Qg=10.0
% INFO    : Gen at bus 12387	: Vg=1.031726 -> Vg=1.0
% INFO    : Gen at bus 12388	: Pg=57.12, Qg=17.95 -> Pg=119.04, Qg=15.0
% INFO    : Gen at bus 12388	: Vg=1.017464 -> Vg=1.0
% INFO    : Gen at bus 12390	: Pg=224.68, Qg=-13.42 -> Pg=300.0, Qg=80.0
% INFO    : Gen at bus 12390	: Vg=1.039621 -> Vg=1.0
% INFO    : Gen at bus 12393	: Pg=100.0, Qg=41.35 -> Pg=183.335, Qg=20.0
% INFO    : Gen at bus 12393	: Vg=1.090507 -> Vg=1.0
% INFO    : Gen at bus 12398	: Pg=44.1, Qg=5.46 -> Pg=64.7, Qg=15.0
% INFO    : Gen at bus 12398	: Vg=0.988831 -> Vg=1.0
% INFO    : Gen at bus 12400	: Pg=29.89, Qg=15.39 -> Pg=59.965, Qg=10.0
% INFO    : Gen at bus 12400	: Vg=1.024479 -> Vg=1.0
% INFO    : Gen at bus 12401	: Pg=99.0, Qg=2.05 -> Pg=133.0, Qg=5.0
% INFO    : Gen at bus 12401	: Vg=1.019049 -> Vg=1.0
% INFO    : Gen at bus 12411	: Pg=99.68, Qg=14.71 -> Pg=133.225, Qg=20.0
% INFO    : Gen at bus 12411	: Vg=1.035207 -> Vg=1.0
% INFO    : Gen at bus 12415	: Pg=227.37, Qg=10.01 -> Pg=300.0, Qg=60.0
% INFO    : Gen at bus 12415	: Vg=1.028414 -> Vg=1.0
% INFO    : Gen at bus 12419	: Pg=25.89, Qg=9.83 -> Pg=58.63, Qg=15.0
% INFO    : Gen at bus 12419	: Vg=1.013208 -> Vg=1.0
% INFO    : Gen at bus 12421	: Pg=5.0, Qg=-1.11 -> Pg=51.665, Qg=0.0
% INFO    : Gen at bus 12421	: Vg=0.981334 -> Vg=1.0
% INFO    : Gen at bus 12428	: Pg=59.66, Qg=11.27 -> Pg=119.885, Qg=15.0
% INFO    : Gen at bus 12428	: Vg=1.027725 -> Vg=1.0
% INFO    : Gen at bus 12429	: Pg=59.66, Qg=11.27 -> Pg=119.885, Qg=15.0
% INFO    : Gen at bus 12429	: Vg=1.027725 -> Vg=1.0
% INFO    : Gen at bus 12430	: Pg=59.66, Qg=11.27 -> Pg=119.885, Qg=15.0
% INFO    : Gen at bus 12430	: Vg=1.027725 -> Vg=1.0
% INFO    : Gen at bus 12431	: Pg=59.66, Qg=11.27 -> Pg=119.885, Qg=15.0
% INFO    : Gen at bus 12431	: Vg=1.027725 -> Vg=1.0
% INFO    : Gen at bus 12433	: Pg=59.66, Qg=11.27 -> Pg=119.885, Qg=15.0
% INFO    : Gen at bus 12433	: Vg=1.027725 -> Vg=1.0
% INFO    : Gen at bus 12434	: Pg=49.88, Qg=7.11 -> Pg=66.625, Qg=15.0
% INFO    : Gen at bus 12434	: Vg=1.013219 -> Vg=1.0
% INFO    : Gen at bus 12440	: Pg=45.28, Qg=10.84 -> Pg=65.095, Qg=15.0
% INFO    : Gen at bus 12440	: Vg=1.043738 -> Vg=1.0
% INFO    : Gen at bus 12441	: Pg=7.32, Qg=2.25 -> Pg=52.44, Qg=0.0
% INFO    : Gen at bus 12441	: Vg=1.004719 -> Vg=1.0
% INFO    : Gen at bus 12447	: Pg=68.89, Qg=5.63 -> Pg=122.965, Qg=20.0
% INFO    : Gen at bus 12447	: Vg=1.028667 -> Vg=1.0
% INFO    : Gen at bus 12448	: Pg=40.49, Qg=8.06 -> Pg=63.495, Qg=10.0
% INFO    : Gen at bus 12448	: Vg=1.036966 -> Vg=1.0
% INFO    : Gen at bus 12451	: Pg=33.15, Qg=0.93 -> Pg=61.05, Qg=10.0
% INFO    : Gen at bus 12451	: Vg=1.024669 -> Vg=1.0
% INFO    : Gen at bus 12452	: Pg=240.2, Qg=86.73 -> Pg=300.0, Qg=60.0
% INFO    : Gen at bus 12452	: Vg=1.035311 -> Vg=1.0
% INFO    : Gen at bus 12453	: Pg=240.2, Qg=86.86 -> Pg=300.0, Qg=60.0
% INFO    : Gen at bus 12453	: Vg=1.035255 -> Vg=1.0
% INFO    : Gen at bus 12454	: Pg=230.51, Qg=50.58 -> Pg=300.0, Qg=60.0
% INFO    : Gen at bus 12454	: Vg=1.016573 -> Vg=1.0
% INFO    : Gen at bus 12455	: Pg=68.89, Qg=5.63 -> Pg=122.965, Qg=20.0
% INFO    : Gen at bus 12455	: Vg=1.028667 -> Vg=1.0
% INFO    : Gen at bus 12459	: Pg=47.29, Qg=6.72 -> Pg=65.765, Qg=15.0
% INFO    : Gen at bus 12459	: Vg=1.04826 -> Vg=1.0
% INFO    : Gen at bus 12461	: Pg=88.02, Qg=46.54 -> Pg=129.34, Qg=20.0
% INFO    : Gen at bus 12461	: Vg=1.057713 -> Vg=1.0
% INFO    : Gen at bus 12462	: Pg=88.02, Qg=46.54 -> Pg=129.34, Qg=20.0
% INFO    : Gen at bus 12462	: Vg=1.057713 -> Vg=1.0
% INFO    : Gen at bus 12464	: Pg=88.02, Qg=46.54 -> Pg=129.34, Qg=20.0
% INFO    : Gen at bus 12464	: Vg=1.057713 -> Vg=1.0
% INFO    : Gen at bus 12465	: Pg=87.39, Qg=49.12 -> Pg=129.13, Qg=20.0
% INFO    : Gen at bus 12465	: Vg=1.05445 -> Vg=1.0
% INFO    : Gen at bus 12466	: Pg=88.02, Qg=46.54 -> Pg=129.34, Qg=20.0
% INFO    : Gen at bus 12466	: Vg=1.057713 -> Vg=1.0
% INFO    : Gen at bus 12467	: Pg=88.02, Qg=46.54 -> Pg=129.34, Qg=20.0
% INFO    : Gen at bus 12467	: Vg=1.057713 -> Vg=1.0
% INFO    : Gen at bus 12469	: Pg=87.39, Qg=49.12 -> Pg=129.13, Qg=20.0
% INFO    : Gen at bus 12469	: Vg=1.05445 -> Vg=1.0
% INFO    : Gen at bus 12470	: Pg=87.39, Qg=49.12 -> Pg=129.13, Qg=20.0
% INFO    : Gen at bus 12470	: Vg=1.05445 -> Vg=1.0
% INFO    : Gen at bus 12477	: Pg=25.74, Qg=8.25 -> Pg=58.58, Qg=10.0
% INFO    : Gen at bus 12477	: Vg=1.037214 -> Vg=1.0
% INFO    : Gen at bus 12494	: Pg=66.65, Qg=5.48 -> Pg=122.215, Qg=20.0
% INFO    : Gen at bus 12494	: Vg=1.01993 -> Vg=1.0
% INFO    : Gen at bus 12499	: Pg=12.15, Qg=5.1 -> Pg=54.05, Qg=5.0
% INFO    : Gen at bus 12499	: Vg=1.040719 -> Vg=1.0
% INFO    : Gen at bus 12500	: Pg=31.2, Qg=5.73 -> Pg=60.4, Qg=10.0
% INFO    : Gen at bus 12500	: Vg=1.050684 -> Vg=1.0
% INFO    : Gen at bus 12505	: Pg=77.81, Qg=13.09 -> Pg=125.935, Qg=20.0
% INFO    : Gen at bus 12505	: Vg=1.029991 -> Vg=1.0
% INFO    : Gen at bus 12506	: Pg=77.81, Qg=13.09 -> Pg=125.935, Qg=20.0
% INFO    : Gen at bus 12506	: Vg=1.029991 -> Vg=1.0
% INFO    : Gen at bus 12507	: Pg=0.83, Qg=-0.07 -> Pg=50.275, Qg=0.0
% INFO    : Gen at bus 12507	: Vg=1.015733 -> Vg=1.0
% INFO    : Gen at bus 12509	: Pg=284.39, Qg=98.98 -> Pg=350.0, Qg=80.0
% INFO    : Gen at bus 12509	: Vg=1.060659 -> Vg=1.0
% INFO    : Gen at bus 12517	: Pg=54.05, Qg=11.46 -> Pg=118.015, Qg=15.0
% INFO    : Gen at bus 12517	: Vg=1.024254 -> Vg=1.0
% INFO    : Gen at bus 12518	: Pg=280.13, Qg=69.09 -> Pg=350.0, Qg=60.0
% INFO    : Gen at bus 12518	: Vg=1.028417 -> Vg=1.0
% INFO    : Gen at bus 12519	: Pg=96.75, Qg=44.18 -> Pg=132.25, Qg=20.0
% INFO    : Gen at bus 12519	: Vg=1.057091 -> Vg=1.0
% INFO    : Gen at bus 12521	: Pg=33.21, Qg=5.47 -> Pg=61.07, Qg=10.0
% INFO    : Gen at bus 12521	: Vg=1.022689 -> Vg=1.0
% INFO    : Gen at bus 12522	: Pg=33.21, Qg=5.47 -> Pg=61.07, Qg=10.0
% INFO    : Gen at bus 12522	: Vg=1.022689 -> Vg=1.0
% INFO    : Gen at bus 12523	: Pg=33.21, Qg=5.47 -> Pg=61.07, Qg=10.0
% INFO    : Gen at bus 12523	: Vg=1.022689 -> Vg=1.0
% INFO    : Gen at bus 12525	: Pg=224.13, Qg=67.46 -> Pg=300.0, Qg=60.0
% INFO    : Gen at bus 12525	: Vg=1.034235 -> Vg=1.0
% INFO    : Gen at bus 12526	: Pg=224.13, Qg=67.46 -> Pg=300.0, Qg=60.0
% INFO    : Gen at bus 12526	: Vg=1.034235 -> Vg=1.0
% INFO    : Gen at bus 12528	: Pg=26.62, Qg=13.25 -> Pg=58.875, Qg=10.0
% INFO    : Gen at bus 12528	: Vg=1.040642 -> Vg=1.0
% INFO    : Gen at bus 12529	: Pg=88.06, Qg=35.93 -> Pg=129.355, Qg=20.0
% INFO    : Gen at bus 12529	: Vg=1.024151 -> Vg=1.0
% INFO    : Gen at bus 12537	: Pg=649.26, Qg=-32.35 -> Pg=850.0, Qg=200.0
% INFO    : Gen at bus 12537	: Vg=1.035364 -> Vg=1.0
% INFO    : Gen at bus 12541	: Pg=0.76, Qg=0.04 -> Pg=50.255, Qg=0.0
% INFO    : Gen at bus 12541	: Vg=1.02993 -> Vg=1.0
% INFO    : Gen at bus 12542	: Pg=29.43, Qg=7.09 -> Pg=59.81, Qg=10.0
% INFO    : Gen at bus 12542	: Vg=1.028438 -> Vg=1.0
% INFO    : Gen at bus 12551	: Pg=17.8, Qg=10.21 -> Pg=55.935, Qg=10.0
% INFO    : Gen at bus 12551	: Vg=1.034631 -> Vg=1.0
% INFO    : Gen at bus 12555	: Pg=8.93, Qg=-0.3 -> Pg=52.975, Qg=0.0
% INFO    : Gen at bus 12555	: Vg=1.003834 -> Vg=1.0
% INFO    : Gen at bus 12556	: Pg=180.96, Qg=38.95 -> Pg=250.0, Qg=60.0
% INFO    : Gen at bus 12556	: Vg=1.029835 -> Vg=1.0
% INFO    : Gen at bus 12558	: Pg=6.03, Qg=-2.37 -> Pg=52.01, Qg=0.0
% INFO    : Gen at bus 12558	: Vg=0.971908 -> Vg=1.0
% INFO    : Gen at bus 12563	: Pg=355.56, Qg=-18.65 -> Pg=500.0, Qg=80.0
% INFO    : Gen at bus 12563	: Vg=1.020396 -> Vg=1.0
% INFO    : Gen at bus 12570	: Pg=20.63, Qg=6.57 -> Pg=56.875, Qg=10.0
% INFO    : Gen at bus 12570	: Vg=1.022447 -> Vg=1.0
% INFO    : Gen at bus 12572	: Pg=112.0, Qg=-3.86 -> Pg=187.335, Qg=10.0
% INFO    : Gen at bus 12572	: Vg=0.989707 -> Vg=1.0
% INFO    : Gen at bus 12579	: Pg=627.0, Qg=28.92 -> Pg=850.0, Qg=65.0
% INFO    : Gen at bus 12579	: Vg=0.960771 -> Vg=1.0
% INFO    : Gen at bus 12582	: Pg=38.56, Qg=8.03 -> Pg=62.855, Qg=10.0
% INFO    : Gen at bus 12582	: Vg=1.049495 -> Vg=1.0
% INFO    : Gen at bus 12583	: Pg=38.56, Qg=8.03 -> Pg=62.855, Qg=10.0
% INFO    : Gen at bus 12583	: Vg=1.049495 -> Vg=1.0
% INFO    : Gen at bus 12586	: Pg=42.41, Qg=17.68 -> Pg=64.135, Qg=20.0
% INFO    : Gen at bus 12586	: Vg=1.058287 -> Vg=1.0
% INFO    : Gen at bus 12587	: Pg=-310.36, Qg=-575.04 -> Pg=-156.91, Qg=0.0
% INFO    : Gen at bus 12587	: Vg=1.016947 -> Vg=1.0
% INFO    : Gen at bus 12589	: Pg=42.41, Qg=17.68 -> Pg=64.135, Qg=20.0
% INFO    : Gen at bus 12589	: Vg=1.058287 -> Vg=1.0
% INFO    : Gen at bus 12590	: Pg=42.41, Qg=17.68 -> Pg=64.135, Qg=20.0
% INFO    : Gen at bus 12590	: Vg=1.058287 -> Vg=1.0
% INFO    : Gen at bus 12591	: Pg=42.41, Qg=17.68 -> Pg=64.135, Qg=20.0
% INFO    : Gen at bus 12591	: Vg=1.058287 -> Vg=1.0
% INFO    : Gen at bus 12592	: Pg=42.41, Qg=17.68 -> Pg=64.135, Qg=20.0
% INFO    : Gen at bus 12592	: Vg=1.058287 -> Vg=1.0
% INFO    : Gen at bus 12599	: Pg=52.46, Qg=9.17 -> Pg=117.485, Qg=20.0
% INFO    : Gen at bus 12599	: Vg=1.033945 -> Vg=1.0
% INFO    : Gen at bus 12600	: Pg=52.46, Qg=9.17 -> Pg=117.485, Qg=20.0
% INFO    : Gen at bus 12600	: Vg=1.033945 -> Vg=1.0
% INFO    : Gen at bus 12601	: Pg=52.46, Qg=9.17 -> Pg=117.485, Qg=20.0
% INFO    : Gen at bus 12601	: Vg=1.033945 -> Vg=1.0
% INFO    : Gen at bus 12603	: Pg=153.3, Qg=-6.31 -> Pg=250.0, Qg=10.0
% INFO    : Gen at bus 12603	: Vg=0.947933 -> Vg=1.0
% INFO    : Gen at bus 12606	: Pg=228.19, Qg=49.03 -> Pg=300.0, Qg=80.0
% INFO    : Gen at bus 12606	: Vg=1.020332 -> Vg=1.0
% INFO    : Gen at bus 12607	: Pg=61.89, Qg=15.66 -> Pg=120.63, Qg=15.0
% INFO    : Gen at bus 12607	: Vg=1.026221 -> Vg=1.0
% INFO    : Gen at bus 12610	: Pg=61.89, Qg=15.66 -> Pg=120.63, Qg=15.0
% INFO    : Gen at bus 12610	: Vg=1.026221 -> Vg=1.0
% INFO    : Gen at bus 12612	: Pg=16.71, Qg=0.01 -> Pg=55.57, Qg=10.0
% INFO    : Gen at bus 12612	: Vg=1.030988 -> Vg=1.0
% INFO    : Gen at bus 12616	: Pg=6.52, Qg=0.05 -> Pg=52.175, Qg=0.0
% INFO    : Gen at bus 12616	: Vg=0.996117 -> Vg=1.0
% INFO    : Gen at bus 12625	: Pg=167.4, Qg=-8.63 -> Pg=250.0, Qg=10.0
% INFO    : Gen at bus 12625	: Vg=0.948759 -> Vg=1.0
% INFO    : Gen at bus 12636	: Pg=23.91, Qg=3.61 -> Pg=57.97, Qg=10.0
% INFO    : Gen at bus 12636	: Vg=1.007821 -> Vg=1.0
% INFO    : Gen at bus 12641	: Pg=177.84, Qg=-23.15 -> Pg=250.0, Qg=60.0
% INFO    : Gen at bus 12641	: Vg=0.995435 -> Vg=1.0
% INFO    : Gen at bus 12646	: Pg=23.94, Qg=10.89 -> Pg=57.98, Qg=10.0
% INFO    : Gen at bus 12646	: Vg=1.042693 -> Vg=1.0
% INFO    : Gen at bus 12647	: Pg=85.48, Qg=16.57 -> Pg=128.495, Qg=20.0
% INFO    : Gen at bus 12647	: Vg=1.029333 -> Vg=1.0
% INFO    : Gen at bus 12648	: Pg=85.48, Qg=16.57 -> Pg=128.495, Qg=20.0
% INFO    : Gen at bus 12648	: Vg=1.029333 -> Vg=1.0
% INFO    : Gen at bus 12650	: Pg=85.48, Qg=16.57 -> Pg=128.495, Qg=20.0
% INFO    : Gen at bus 12650	: Vg=1.029333 -> Vg=1.0
% INFO    : Gen at bus 12651	: Pg=85.48, Qg=16.54 -> Pg=128.495, Qg=20.0
% INFO    : Gen at bus 12651	: Vg=1.029323 -> Vg=1.0
% INFO    : Gen at bus 12652	: Pg=85.48, Qg=16.54 -> Pg=128.495, Qg=20.0
% INFO    : Gen at bus 12652	: Vg=1.029323 -> Vg=1.0
% INFO    : Gen at bus 12653	: Pg=85.48, Qg=16.57 -> Pg=128.495, Qg=20.0
% INFO    : Gen at bus 12653	: Vg=1.029333 -> Vg=1.0
% INFO    : Gen at bus 12654	: Pg=85.48, Qg=16.54 -> Pg=128.495, Qg=20.0
% INFO    : Gen at bus 12654	: Vg=1.029323 -> Vg=1.0
% INFO    : Gen at bus 12656	: Pg=38.52, Qg=8.15 -> Pg=62.84, Qg=10.0
% INFO    : Gen at bus 12656	: Vg=1.04659 -> Vg=1.0
% INFO    : Gen at bus 12657	: Pg=5.0, Qg=0.46 -> Pg=51.665, Qg=0.0
% INFO    : Gen at bus 12657	: Vg=1.017738 -> Vg=1.0
% INFO    : Gen at bus 12658	: Pg=40.0, Qg=4.52 -> Pg=63.335, Qg=0.0
% INFO    : Gen at bus 12658	: Vg=0.956073 -> Vg=1.0
% INFO    : Gen at bus 12659	: Pg=54.32, Qg=19.31 -> Pg=118.105, Qg=15.0
% INFO    : Gen at bus 12659	: Vg=1.040793 -> Vg=1.0
% INFO    : Gen at bus 12664	: Pg=20.43, Qg=6.2 -> Pg=56.81, Qg=10.0
% INFO    : Gen at bus 12664	: Vg=1.037469 -> Vg=1.0
% INFO    : Gen at bus 12665	: Pg=419.21, Qg=7.57 -> Pg=550.0, Qg=100.0
% INFO    : Gen at bus 12665	: Vg=1.038308 -> Vg=1.0
% INFO    : Gen at bus 12673	: Pg=54.32, Qg=19.31 -> Pg=118.105, Qg=15.0
% INFO    : Gen at bus 12673	: Vg=1.040793 -> Vg=1.0
% INFO    : Gen at bus 12678	: Pg=100.0, Qg=41.35 -> Pg=183.335, Qg=20.0
% INFO    : Gen at bus 12678	: Vg=1.090507 -> Vg=1.0
% INFO    : Gen at bus 12681	: Pg=22.87, Qg=9.78 -> Pg=57.625, Qg=10.0
% INFO    : Gen at bus 12681	: Vg=1.014635 -> Vg=1.0
% INFO    : Gen at bus 12687	: Pg=30.45, Qg=8.8 -> Pg=60.15, Qg=5.0
% INFO    : Gen at bus 12687	: Vg=1.01812 -> Vg=1.0
% INFO    : Gen at bus 12688	: Pg=300.0, Qg=-14.29 -> Pg=450.0, Qg=0.0
% INFO    : Gen at bus 12688	: Vg=1.001419 -> Vg=1.0
% INFO    : Gen at bus 12690	: Pg=54.32, Qg=19.31 -> Pg=118.105, Qg=15.0
% INFO    : Gen at bus 12690	: Vg=1.040793 -> Vg=1.0
% INFO    : Gen at bus 12692	: Pg=18.9, Qg=0.51 -> Pg=56.3, Qg=0.0
% INFO    : Gen at bus 12692	: Vg=1.015529 -> Vg=1.0
% INFO    : Gen at bus 12697	: Pg=27.67, Qg=4.45 -> Pg=59.225, Qg=10.0
% INFO    : Gen at bus 12697	: Vg=1.027132 -> Vg=1.0
% INFO    : Gen at bus 12699	: Pg=27.67, Qg=4.45 -> Pg=59.225, Qg=10.0
% INFO    : Gen at bus 12699	: Vg=1.027132 -> Vg=1.0
% INFO    : Gen at bus 12701	: Pg=34.08, Qg=12.69 -> Pg=61.36, Qg=10.0
% INFO    : Gen at bus 12701	: Vg=1.041939 -> Vg=1.0
% INFO    : Gen at bus 12702	: Pg=27.67, Qg=4.45 -> Pg=59.225, Qg=10.0
% INFO    : Gen at bus 12702	: Vg=1.027132 -> Vg=1.0
% INFO    : Gen at bus 12704	: Pg=34.08, Qg=12.69 -> Pg=61.36, Qg=10.0
% INFO    : Gen at bus 12704	: Vg=1.041939 -> Vg=1.0
% INFO    : Gen at bus 12705	: Pg=34.27, Qg=11.44 -> Pg=61.425, Qg=10.0
% INFO    : Gen at bus 12705	: Vg=1.03975 -> Vg=1.0
% INFO    : Gen at bus 12706	: Pg=34.27, Qg=11.44 -> Pg=61.425, Qg=10.0
% INFO    : Gen at bus 12706	: Vg=1.03975 -> Vg=1.0
% INFO    : Gen at bus 12708	: Pg=15.86, Qg=9.49 -> Pg=55.285, Qg=10.0
% INFO    : Gen at bus 12708	: Vg=1.017238 -> Vg=1.0
% INFO    : Gen at bus 12709	: Pg=30.04, Qg=7.71 -> Pg=60.015, Qg=10.0
% INFO    : Gen at bus 12709	: Vg=1.011489 -> Vg=1.0
% INFO    : Gen at bus 12711	: Pg=31.76, Qg=6.93 -> Pg=60.585, Qg=5.0
% INFO    : Gen at bus 12711	: Vg=1.007801 -> Vg=1.0
% INFO    : Gen at bus 12713	: Pg=32.17, Qg=5.12 -> Pg=60.725, Qg=10.0
% INFO    : Gen at bus 12713	: Vg=1.009886 -> Vg=1.0
% INFO    : Gen at bus 12714	: Pg=15.86, Qg=9.49 -> Pg=55.285, Qg=10.0
% INFO    : Gen at bus 12714	: Vg=1.017238 -> Vg=1.0
% INFO    : Gen at bus 12717	: Pg=38.02, Qg=11.21 -> Pg=62.675, Qg=10.0
% INFO    : Gen at bus 12717	: Vg=1.043087 -> Vg=1.0
% INFO    : Gen at bus 12723	: Pg=27.72, Qg=3.43 -> Pg=59.24, Qg=10.0
% INFO    : Gen at bus 12723	: Vg=1.015411 -> Vg=1.0
% INFO    : Gen at bus 12726	: Pg=276.1, Qg=40.94 -> Pg=350.0, Qg=60.0
% INFO    : Gen at bus 12726	: Vg=1.035338 -> Vg=1.0
% INFO    : Gen at bus 12727	: Pg=85.28, Qg=21.31 -> Pg=128.425, Qg=20.0
% INFO    : Gen at bus 12727	: Vg=1.029542 -> Vg=1.0
% INFO    : Gen at bus 12728	: Pg=36.8, Qg=6.62 -> Pg=62.265, Qg=10.0
% INFO    : Gen at bus 12728	: Vg=1.03058 -> Vg=1.0
% INFO    : Gen at bus 12730	: Pg=70.0, Qg=0.5 -> Pg=123.335, Qg=5.0
% INFO    : Gen at bus 12730	: Vg=1.017293 -> Vg=1.0
% INFO    : Gen at bus 12736	: Pg=40.0, Qg=4.84 -> Pg=63.335, Qg=0.0
% INFO    : Gen at bus 12736	: Vg=0.957116 -> Vg=1.0
% INFO    : Gen at bus 12738	: Pg=32.97, Qg=4.46 -> Pg=60.99, Qg=10.0
% INFO    : Gen at bus 12738	: Vg=1.027968 -> Vg=1.0
% INFO    : Gen at bus 12742	: Pg=33.73, Qg=12.57 -> Pg=61.245, Qg=10.0
% INFO    : Gen at bus 12742	: Vg=1.035958 -> Vg=1.0
% INFO    : Gen at bus 12747	: Pg=33.73, Qg=12.57 -> Pg=61.245, Qg=10.0
% INFO    : Gen at bus 12747	: Vg=1.035958 -> Vg=1.0
% INFO    : Gen at bus 12748	: Pg=2.5, Qg=0.07 -> Pg=50.835, Qg=0.0
% INFO    : Gen at bus 12748	: Vg=0.9846 -> Vg=1.0
% INFO    : Gen at bus 12758	: Pg=95.51, Qg=37.64 -> Pg=131.835, Qg=20.0
% INFO    : Gen at bus 12758	: Vg=1.0608 -> Vg=1.0
% INFO    : Gen at bus 12760	: Pg=58.19, Qg=6.99 -> Pg=119.395, Qg=15.0
% INFO    : Gen at bus 12760	: Vg=1.028736 -> Vg=1.0
% INFO    : Gen at bus 12761	: Pg=58.19, Qg=6.99 -> Pg=119.395, Qg=15.0
% INFO    : Gen at bus 12761	: Vg=1.028736 -> Vg=1.0
% INFO    : Gen at bus 12763	: Pg=58.19, Qg=6.99 -> Pg=119.395, Qg=15.0
% INFO    : Gen at bus 12763	: Vg=1.028736 -> Vg=1.0
% INFO    : Gen at bus 12764	: Pg=69.92, Qg=41.17 -> Pg=123.305, Qg=20.0
% INFO    : Gen at bus 12764	: Vg=1.051947 -> Vg=1.0
% INFO    : Gen at bus 12765	: Pg=69.92, Qg=41.17 -> Pg=123.305, Qg=20.0
% INFO    : Gen at bus 12765	: Vg=1.051947 -> Vg=1.0
% INFO    : Gen at bus 12772	: Pg=364.88, Qg=71.7 -> Pg=500.0, Qg=80.0
% INFO    : Gen at bus 12772	: Vg=1.04706 -> Vg=1.0
% INFO    : Gen at bus 12775	: Pg=158.9, Qg=5.88 -> Pg=250.0, Qg=35.0
% INFO    : Gen at bus 12775	: Vg=0.968879 -> Vg=1.0
% INFO    : Gen at bus 12777	: Pg=25.64, Qg=1.96 -> Pg=58.545, Qg=5.0
% INFO    : Gen at bus 12777	: Vg=1.010323 -> Vg=1.0
% INFO    : Gen at bus 12782	: Pg=21.35, Qg=0.38 -> Pg=57.115, Qg=5.0
% INFO    : Gen at bus 12782	: Vg=1.033617 -> Vg=1.0
% INFO    : Gen at bus 12786	: Pg=56.25, Qg=11.12 -> Pg=118.75, Qg=15.0
% INFO    : Gen at bus 12786	: Vg=1.03036 -> Vg=1.0
% INFO    : Gen at bus 12788	: Pg=74.67, Qg=51.83 -> Pg=124.89, Qg=20.0
% INFO    : Gen at bus 12788	: Vg=1.045385 -> Vg=1.0
% INFO    : Gen at bus 12789	: Pg=74.67, Qg=51.83 -> Pg=124.89, Qg=20.0
% INFO    : Gen at bus 12789	: Vg=1.045385 -> Vg=1.0
% INFO    : Gen at bus 12790	: Pg=74.67, Qg=51.83 -> Pg=124.89, Qg=20.0
% INFO    : Gen at bus 12790	: Vg=1.045385 -> Vg=1.0
% INFO    : Gen at bus 12791	: Pg=74.67, Qg=51.83 -> Pg=124.89, Qg=20.0
% INFO    : Gen at bus 12791	: Vg=1.045385 -> Vg=1.0
% INFO    : Gen at bus 12794	: Pg=331.23, Qg=145.12 -> Pg=450.0, Qg=80.0
% INFO    : Gen at bus 12794	: Vg=1.041485 -> Vg=1.0
% INFO    : Gen at bus 12799	: Pg=50.96, Qg=2.69 -> Pg=116.985, Qg=20.0
% INFO    : Gen at bus 12799	: Vg=1.028648 -> Vg=1.0
% INFO    : Gen at bus 12802	: Pg=77.24, Qg=16.07 -> Pg=125.745, Qg=20.0
% INFO    : Gen at bus 12802	: Vg=1.027025 -> Vg=1.0
% INFO    : Gen at bus 12803	: Pg=78.62, Qg=8.98 -> Pg=126.205, Qg=20.0
% INFO    : Gen at bus 12803	: Vg=1.056333 -> Vg=1.0
% INFO    : Gen at bus 12806	: Pg=97.7, Qg=2.58 -> Pg=132.565, Qg=20.0
% INFO    : Gen at bus 12806	: Vg=1.053741 -> Vg=1.0
% INFO    : Gen at bus 12807	: Pg=97.7, Qg=2.58 -> Pg=132.565, Qg=20.0
% INFO    : Gen at bus 12807	: Vg=1.053741 -> Vg=1.0
% INFO    : Gen at bus 12808	: Pg=97.7, Qg=2.58 -> Pg=132.565, Qg=20.0
% INFO    : Gen at bus 12808	: Vg=1.053741 -> Vg=1.0
% INFO    : Gen at bus 12814	: Pg=96.57, Qg=34.4 -> Pg=132.19, Qg=20.0
% INFO    : Gen at bus 12814	: Vg=1.051326 -> Vg=1.0
% INFO    : Gen at bus 12815	: Pg=31.0, Qg=6.15 -> Pg=60.335, Qg=5.0
% INFO    : Gen at bus 12815	: Vg=1.046995 -> Vg=1.0
% INFO    : Gen at bus 12816	: Pg=18.4, Qg=-1.01 -> Pg=56.135, Qg=0.0
% INFO    : Gen at bus 12816	: Vg=1.003342 -> Vg=1.0
% INFO    : Gen at bus 12817	: Pg=685.9, Qg=148.95 -> Pg=900.0, Qg=200.0
% INFO    : Gen at bus 12817	: Vg=1.062539 -> Vg=1.0
% INFO    : Gen at bus 12818	: Pg=685.9, Qg=148.95 -> Pg=900.0, Qg=200.0
% INFO    : Gen at bus 12818	: Vg=1.062539 -> Vg=1.0
% INFO    : Gen at bus 12819	: Pg=33.97, Qg=5.68 -> Pg=61.325, Qg=10.0
% INFO    : Gen at bus 12819	: Vg=1.022889 -> Vg=1.0
% INFO    : Gen at bus 12822	: Pg=36.03, Qg=16.08 -> Pg=62.01, Qg=10.0
% INFO    : Gen at bus 12822	: Vg=1.045359 -> Vg=1.0
% INFO    : Gen at bus 12825	: Pg=39.54, Qg=11.66 -> Pg=63.18, Qg=10.0
% INFO    : Gen at bus 12825	: Vg=1.055315 -> Vg=1.0
% INFO    : Gen at bus 12829	: Pg=34.96, Qg=5.47 -> Pg=61.655, Qg=0.0
% INFO    : Gen at bus 12829	: Vg=0.935194 -> Vg=1.0
% INFO    : Gen at bus 12833	: Pg=226.17, Qg=144.77 -> Pg=300.0, Qg=80.0
% INFO    : Gen at bus 12833	: Vg=1.073133 -> Vg=1.0
% INFO    : Gen at bus 12840	: Pg=30.01, Qg=15.35 -> Pg=60.005, Qg=10.0
% INFO    : Gen at bus 12840	: Vg=1.052369 -> Vg=1.0
% INFO    : Gen at bus 12843	: Pg=30.01, Qg=15.35 -> Pg=60.005, Qg=10.0
% INFO    : Gen at bus 12843	: Vg=1.052369 -> Vg=1.0
% INFO    : Gen at bus 12847	: Pg=10.89, Qg=0.26 -> Pg=53.63, Qg=0.0
% INFO    : Gen at bus 12847	: Vg=1.023718 -> Vg=1.0
% INFO    : Gen at bus 12855	: Pg=623.11, Qg=488.64 -> Pg=850.0, Qg=200.0
% INFO    : Gen at bus 12855	: Vg=1.057579 -> Vg=1.0
% INFO    : Gen at bus 12856	: Pg=30.01, Qg=15.35 -> Pg=60.005, Qg=10.0
% INFO    : Gen at bus 12856	: Vg=1.052369 -> Vg=1.0
% INFO    : Gen at bus 12859	: Pg=243.32, Qg=23.39 -> Pg=300.0, Qg=80.0
% INFO    : Gen at bus 12859	: Vg=1.055881 -> Vg=1.0
% INFO    : Gen at bus 12863	: Pg=5.26, Qg=0.32 -> Pg=51.755, Qg=0.0
% INFO    : Gen at bus 12863	: Vg=1.017634 -> Vg=1.0
% INFO    : Gen at bus 12864	: Pg=18.6, Qg=0.67 -> Pg=56.2, Qg=0.0
% INFO    : Gen at bus 12864	: Vg=0.999314 -> Vg=1.0
% INFO    : Gen at bus 12865	: Pg=172.8, Qg=-7.44 -> Pg=250.0, Qg=25.0
% INFO    : Gen at bus 12865	: Vg=1.029957 -> Vg=1.0
% INFO    : Gen at bus 12869	: Pg=90.23, Qg=10.46 -> Pg=130.075, Qg=20.0
% INFO    : Gen at bus 12869	: Vg=1.028204 -> Vg=1.0
% INFO    : Gen at bus 12873	: Pg=12.6, Qg=0.36 -> Pg=54.2, Qg=0.0
% INFO    : Gen at bus 12873	: Vg=1.014795 -> Vg=1.0
% INFO    : Gen at bus 12874	: Pg=235.87, Qg=0.58 -> Pg=300.0, Qg=80.0
% INFO    : Gen at bus 12874	: Vg=1.042461 -> Vg=1.0
% INFO    : Gen at bus 12878	: Pg=284.4, Qg=98.98 -> Pg=350.0, Qg=80.0
% INFO    : Gen at bus 12878	: Vg=1.060659 -> Vg=1.0
% INFO    : Gen at bus 12880	: Pg=284.51, Qg=138.58 -> Pg=350.0, Qg=80.0
% INFO    : Gen at bus 12880	: Vg=1.065482 -> Vg=1.0
% INFO    : Gen at bus 12882	: Pg=284.51, Qg=138.58 -> Pg=350.0, Qg=80.0
% INFO    : Gen at bus 12882	: Vg=1.065482 -> Vg=1.0
% INFO    : Gen at bus 12883	: Pg=284.51, Qg=138.58 -> Pg=350.0, Qg=80.0
% INFO    : Gen at bus 12883	: Vg=1.065482 -> Vg=1.0
% INFO    : Gen at bus 12884	: Pg=284.51, Qg=138.58 -> Pg=350.0, Qg=80.0
% INFO    : Gen at bus 12884	: Vg=1.065482 -> Vg=1.0
% INFO    : Gen at bus 12887	: Pg=5.27, Qg=0.39 -> Pg=51.755, Qg=0.0
% INFO    : Gen at bus 12887	: Vg=1.019063 -> Vg=1.0
% INFO    : Gen at bus 12896	: Pg=18.32, Qg=-0.94 -> Pg=56.105, Qg=0.0
% INFO    : Gen at bus 12896	: Vg=0.995077 -> Vg=1.0
% INFO    : Gen at bus 12900	: Pg=49.83, Qg=6.62 -> Pg=66.61, Qg=20.0
% INFO    : Gen at bus 12900	: Vg=1.007268 -> Vg=1.0
% INFO    : Gen at bus 12902	: Pg=29.54, Qg=8.16 -> Pg=59.845, Qg=5.0
% INFO    : Gen at bus 12902	: Vg=1.030509 -> Vg=1.0
% INFO    : Gen at bus 12904	: Pg=24.99, Qg=21.34 -> Pg=58.33, Qg=10.0
% INFO    : Gen at bus 12904	: Vg=1.019094 -> Vg=1.0
% INFO    : Gen at bus 12906	: Pg=17.21, Qg=5.28 -> Pg=55.735, Qg=10.0
% INFO    : Gen at bus 12906	: Vg=1.020161 -> Vg=1.0
% INFO    : Gen at bus 12907	: Pg=17.21, Qg=5.28 -> Pg=55.735, Qg=10.0
% INFO    : Gen at bus 12907	: Vg=1.020161 -> Vg=1.0
% INFO    : Gen at bus 12908	: Pg=17.21, Qg=5.28 -> Pg=55.735, Qg=10.0
% INFO    : Gen at bus 12908	: Vg=1.020161 -> Vg=1.0
% INFO    : Gen at bus 12910	: Pg=17.21, Qg=5.28 -> Pg=55.735, Qg=10.0
% INFO    : Gen at bus 12910	: Vg=1.020161 -> Vg=1.0
% INFO    : Gen at bus 12911	: Pg=36.03, Qg=16.08 -> Pg=62.01, Qg=10.0
% INFO    : Gen at bus 12911	: Vg=1.045359 -> Vg=1.0
% INFO    : Gen at bus 12912	: Pg=17.21, Qg=5.28 -> Pg=55.735, Qg=10.0
% INFO    : Gen at bus 12912	: Vg=1.020161 -> Vg=1.0
% INFO    : Gen at bus 12914	: Pg=19.27, Qg=11.16 -> Pg=56.425, Qg=10.0
% INFO    : Gen at bus 12914	: Vg=1.021452 -> Vg=1.0
% INFO    : Gen at bus 12915	: Pg=96.9, Qg=14.27 -> Pg=132.3, Qg=20.0
% INFO    : Gen at bus 12915	: Vg=1.033735 -> Vg=1.0
% INFO    : Gen at bus 12916	: Pg=17.21, Qg=5.28 -> Pg=55.735, Qg=10.0
% INFO    : Gen at bus 12916	: Vg=1.020161 -> Vg=1.0
% INFO    : Gen at bus 12917	: Pg=17.21, Qg=5.28 -> Pg=55.735, Qg=10.0
% INFO    : Gen at bus 12917	: Vg=1.020161 -> Vg=1.0
% INFO    : Gen at bus 12920	: Pg=617.34, Qg=197.21 -> Pg=850.0, Qg=200.0
% INFO    : Gen at bus 12920	: Vg=1.038461 -> Vg=1.0
% INFO    : Gen at bus 12921	: Pg=617.34, Qg=197.21 -> Pg=850.0, Qg=200.0
% INFO    : Gen at bus 12921	: Vg=1.038461 -> Vg=1.0
% INFO    : Gen at bus 12925	: Pg=617.35, Qg=197.21 -> Pg=850.0, Qg=200.0
% INFO    : Gen at bus 12925	: Vg=1.038461 -> Vg=1.0
% INFO    : Gen at bus 12929	: Pg=36.88, Qg=19.22 -> Pg=62.295, Qg=10.0
% INFO    : Gen at bus 12929	: Vg=1.037296 -> Vg=1.0
% INFO    : Gen at bus 12930	: Pg=32.94, Qg=16.6 -> Pg=60.98, Qg=10.0
% INFO    : Gen at bus 12930	: Vg=1.041198 -> Vg=1.0
% INFO    : Gen at bus 12934	: Pg=99.68, Qg=14.71 -> Pg=133.225, Qg=20.0
% INFO    : Gen at bus 12934	: Vg=1.035207 -> Vg=1.0
% INFO    : Gen at bus 12937	: Pg=617.35, Qg=197.21 -> Pg=850.0, Qg=200.0
% INFO    : Gen at bus 12937	: Vg=1.038461 -> Vg=1.0
% INFO    : Gen at bus 12946	: Pg=31.3, Qg=-0.89 -> Pg=60.435, Qg=0.0
% INFO    : Gen at bus 12946	: Vg=0.998951 -> Vg=1.0
% INFO    : Gen at bus 12949	: Pg=32.72, Qg=3.89 -> Pg=60.905, Qg=5.0
% INFO    : Gen at bus 12949	: Vg=1.002664 -> Vg=1.0
% INFO    : Gen at bus 12962	: Pg=366.21, Qg=205.07 -> Pg=500.0, Qg=80.0
% INFO    : Gen at bus 12962	: Vg=1.129641 -> Vg=1.0
% INFO    : Gen at bus 12965	: Pg=215.66, Qg=145.16 -> Pg=300.0, Qg=60.0
% INFO    : Gen at bus 12965	: Vg=1.043227 -> Vg=1.0
% INFO    : Gen at bus 12966	: Pg=17.6, Qg=0.07 -> Pg=55.865, Qg=0.0
% INFO    : Gen at bus 12966	: Vg=0.977562 -> Vg=1.0
% INFO    : Gen at bus 12968	: Pg=626.62, Qg=195.6 -> Pg=850.0, Qg=200.0
% INFO    : Gen at bus 12968	: Vg=1.053159 -> Vg=1.0
% INFO    : Gen at bus 12969	: Pg=249.81, Qg=71.56 -> Pg=300.0, Qg=60.0
% INFO    : Gen at bus 12969	: Vg=1.053581 -> Vg=1.0
% INFO    : Gen at bus 12970	: Pg=249.81, Qg=71.56 -> Pg=300.0, Qg=60.0
% INFO    : Gen at bus 12970	: Vg=1.053581 -> Vg=1.0
% INFO    : Gen at bus 12973	: Pg=25.08, Qg=6.95 -> Pg=58.36, Qg=10.0
% INFO    : Gen at bus 12973	: Vg=1.024018 -> Vg=1.0
% INFO    : Gen at bus 12983	: Pg=150.0, Qg=8.11 -> Pg=200.0, Qg=25.0
% INFO    : Gen at bus 12983	: Vg=0.989744 -> Vg=1.0
% INFO    : Gen at bus 12984	: Pg=29.77, Qg=17.28 -> Pg=59.925, Qg=10.0
% INFO    : Gen at bus 12984	: Vg=1.046953 -> Vg=1.0
% INFO    : Gen at bus 12986	: Pg=29.77, Qg=17.28 -> Pg=59.925, Qg=10.0
% INFO    : Gen at bus 12986	: Vg=1.046953 -> Vg=1.0
% INFO    : Gen at bus 12989	: Pg=33.35, Qg=5.71 -> Pg=61.115, Qg=5.0
% INFO    : Gen at bus 12989	: Vg=1.021989 -> Vg=1.0
% INFO    : Gen at bus 12993	: Pg=19.96, Qg=23.09 -> Pg=56.655, Qg=10.0
% INFO    : Gen at bus 12993	: Vg=1.036433 -> Vg=1.0
% INFO    : Gen at bus 12994	: Pg=19.96, Qg=23.09 -> Pg=56.655, Qg=10.0
% INFO    : Gen at bus 12994	: Vg=1.036433 -> Vg=1.0
% INFO    : Gen at bus 13002	: Pg=172.8, Qg=-48.69 -> Pg=250.0, Qg=25.0
% INFO    : Gen at bus 13002	: Vg=0.960023 -> Vg=1.0
% INFO    : Gen at bus 13007	: Pg=32.99, Qg=2.77 -> Pg=60.995, Qg=10.0
% INFO    : Gen at bus 13007	: Vg=1.041919 -> Vg=1.0
% INFO    : Gen at bus 13008	: Pg=32.99, Qg=2.77 -> Pg=60.995, Qg=10.0
% INFO    : Gen at bus 13008	: Vg=1.041919 -> Vg=1.0
% INFO    : Gen at bus 13009	: Pg=32.99, Qg=2.77 -> Pg=60.995, Qg=10.0
% INFO    : Gen at bus 13009	: Vg=1.041919 -> Vg=1.0
% INFO    : Gen at bus 13010	: Pg=100.0, Qg=41.35 -> Pg=183.335, Qg=20.0
% INFO    : Gen at bus 13010	: Vg=1.090507 -> Vg=1.0
% INFO    : Gen at bus 13012	: Pg=248.87, Qg=83.85 -> Pg=300.0, Qg=80.0
% INFO    : Gen at bus 13012	: Vg=1.033471 -> Vg=1.0
% INFO    : Gen at bus 13027	: Pg=19.3, Qg=4.46 -> Pg=56.435, Qg=5.0
% INFO    : Gen at bus 13027	: Vg=1.024979 -> Vg=1.0
% INFO    : Gen at bus 13029	: Pg=10.86, Qg=0.1 -> Pg=53.62, Qg=0.0
% INFO    : Gen at bus 13029	: Vg=1.0018 -> Vg=1.0
% INFO    : Gen at bus 13032	: Pg=16.44, Qg=0.07 -> Pg=55.48, Qg=0.0
% INFO    : Gen at bus 13032	: Vg=1.011811 -> Vg=1.0
% INFO    : Gen at bus 13037	: Pg=12.95, Qg=0.5 -> Pg=54.315, Qg=5.0
% INFO    : Gen at bus 13037	: Vg=1.067719 -> Vg=1.0
% INFO    : Gen at bus 13041	: Pg=26.62, Qg=13.25 -> Pg=58.875, Qg=10.0
% INFO    : Gen at bus 13041	: Vg=1.040642 -> Vg=1.0
% INFO    : Gen at bus 13043	: Pg=24.3, Qg=3.82 -> Pg=58.1, Qg=10.0
% INFO    : Gen at bus 13043	: Vg=1.010028 -> Vg=1.0
% INFO    : Gen at bus 13046	: Pg=24.3, Qg=3.82 -> Pg=58.1, Qg=10.0
% INFO    : Gen at bus 13046	: Vg=1.010028 -> Vg=1.0
% INFO    : Gen at bus 13047	: Pg=21.61, Qg=4.62 -> Pg=57.205, Qg=10.0
% INFO    : Gen at bus 13047	: Vg=1.007128 -> Vg=1.0
% INFO    : Gen at bus 13048	: Pg=21.61, Qg=4.62 -> Pg=57.205, Qg=10.0
% INFO    : Gen at bus 13048	: Vg=1.007128 -> Vg=1.0
% INFO    : Gen at bus 13049	: Pg=21.61, Qg=4.62 -> Pg=57.205, Qg=10.0
% INFO    : Gen at bus 13049	: Vg=1.007128 -> Vg=1.0
% INFO    : Gen at bus 13052	: Pg=21.61, Qg=4.62 -> Pg=57.205, Qg=10.0
% INFO    : Gen at bus 13052	: Vg=1.007128 -> Vg=1.0
% INFO    : Gen at bus 13053	: Pg=21.61, Qg=4.62 -> Pg=57.205, Qg=10.0
% INFO    : Gen at bus 13053	: Vg=1.007128 -> Vg=1.0
% INFO    : Gen at bus 13054	: Pg=21.61, Qg=4.62 -> Pg=57.205, Qg=10.0
% INFO    : Gen at bus 13054	: Vg=1.007128 -> Vg=1.0
% INFO    : Gen at bus 13055	: Pg=24.3, Qg=3.82 -> Pg=58.1, Qg=10.0
% INFO    : Gen at bus 13055	: Vg=1.010028 -> Vg=1.0
% INFO    : Gen at bus 13057	: Pg=30.32, Qg=6.61 -> Pg=60.105, Qg=10.0
% INFO    : Gen at bus 13057	: Vg=1.007679 -> Vg=1.0
% INFO    : Gen at bus 13058	: Pg=30.32, Qg=6.61 -> Pg=60.105, Qg=10.0
% INFO    : Gen at bus 13058	: Vg=1.007679 -> Vg=1.0
% INFO    : Gen at bus 13059	: Pg=24.3, Qg=3.82 -> Pg=58.1, Qg=10.0
% INFO    : Gen at bus 13059	: Vg=1.010028 -> Vg=1.0
% INFO    : Gen at bus 13060	: Pg=24.3, Qg=3.82 -> Pg=58.1, Qg=10.0
% INFO    : Gen at bus 13060	: Vg=1.010028 -> Vg=1.0
% INFO    : Gen at bus 13062	: Pg=84.19, Qg=8.48 -> Pg=128.065, Qg=20.0
% INFO    : Gen at bus 13062	: Vg=1.040259 -> Vg=1.0
% INFO    : Gen at bus 13064	: Pg=24.3, Qg=3.82 -> Pg=58.1, Qg=10.0
% INFO    : Gen at bus 13064	: Vg=1.010028 -> Vg=1.0
% INFO    : Gen at bus 13066	: Pg=84.19, Qg=8.48 -> Pg=128.065, Qg=20.0
% INFO    : Gen at bus 13066	: Vg=1.040259 -> Vg=1.0
% INFO    : Gen at bus 13069	: Pg=93.64, Qg=6.04 -> Pg=131.215, Qg=20.0
% INFO    : Gen at bus 13069	: Vg=1.023818 -> Vg=1.0
% INFO    : Gen at bus 13075	: Pg=2.06, Qg=0.62 -> Pg=50.685, Qg=0.0
% INFO    : Gen at bus 13075	: Vg=1.021202 -> Vg=1.0
% INFO    : Gen at bus 13079	: Pg=223.23, Qg=111.08 -> Pg=300.0, Qg=80.0
% INFO    : Gen at bus 13079	: Vg=1.065314 -> Vg=1.0
% INFO    : Gen at bus 13080	: Pg=49.34, Qg=9.15 -> Pg=66.445, Qg=15.0
% INFO    : Gen at bus 13080	: Vg=1.034597 -> Vg=1.0
% INFO    : Gen at bus 13081	: Pg=35.55, Qg=16.64 -> Pg=61.85, Qg=10.0
% INFO    : Gen at bus 13081	: Vg=1.024595 -> Vg=1.0
% INFO    : Gen at bus 13082	: Pg=6.55, Qg=-0.21 -> Pg=52.185, Qg=0.0
% INFO    : Gen at bus 13082	: Vg=1.003807 -> Vg=1.0
% INFO    : Gen at bus 13086	: Pg=33.19, Qg=5.48 -> Pg=61.065, Qg=10.0
% INFO    : Gen at bus 13086	: Vg=0.991806 -> Vg=1.0
% INFO    : Gen at bus 13087	: Pg=15.73, Qg=-3.4 -> Pg=55.245, Qg=-5.0
% INFO    : Gen at bus 13087	: Vg=0.975077 -> Vg=1.0
% INFO    : Gen at bus 13090	: Pg=240.6, Qg=37.13 -> Pg=300.0, Qg=35.0
% INFO    : Gen at bus 13090	: Vg=0.970854 -> Vg=1.0
% INFO    : Gen at bus 13091	: Pg=101.0, Qg=24.39 -> Pg=183.665, Qg=20.0
% INFO    : Gen at bus 13091	: Vg=1.022149 -> Vg=1.0
% INFO    : Gen at bus 13093	: Pg=47.94, Qg=3.29 -> Pg=65.98, Qg=15.0
% INFO    : Gen at bus 13093	: Vg=1.023603 -> Vg=1.0
% INFO    : Gen at bus 13095	: Pg=58.57, Qg=21.97 -> Pg=119.525, Qg=15.0
% INFO    : Gen at bus 13095	: Vg=1.034376 -> Vg=1.0
% INFO    : Gen at bus 13096	: Pg=43.6, Qg=4.09 -> Pg=64.535, Qg=0.0
% INFO    : Gen at bus 13096	: Vg=0.9595 -> Vg=1.0
% INFO    : Gen at bus 13101	: Pg=49.34, Qg=9.15 -> Pg=66.445, Qg=15.0
% INFO    : Gen at bus 13101	: Vg=1.034597 -> Vg=1.0
% INFO    : Gen at bus 13108	: Pg=50.34, Qg=9.17 -> Pg=116.78, Qg=15.0
% INFO    : Gen at bus 13108	: Vg=1.034532 -> Vg=1.0
% INFO    : Gen at bus 13112	: Pg=14.0, Qg=0.14 -> Pg=54.665, Qg=0.0
% INFO    : Gen at bus 13112	: Vg=0.994692 -> Vg=1.0
% INFO    : Gen at bus 13122	: Pg=38.79, Qg=7.11 -> Pg=62.93, Qg=10.0
% INFO    : Gen at bus 13122	: Vg=1.035838 -> Vg=1.0
% INFO    : Gen at bus 13123	: Pg=277.81, Qg=77.81 -> Pg=350.0, Qg=80.0
% INFO    : Gen at bus 13123	: Vg=1.034935 -> Vg=1.0
% INFO    : Gen at bus 13131	: Pg=23.5, Qg=6.96 -> Pg=57.835, Qg=5.0
% INFO    : Gen at bus 13131	: Vg=1.015521 -> Vg=1.0
% INFO    : Gen at bus 13133	: Pg=34.31, Qg=1.99 -> Pg=61.435, Qg=10.0
% INFO    : Gen at bus 13133	: Vg=1.015531 -> Vg=1.0
% INFO    : Gen at bus 13137	: Pg=322.34, Qg=84.39 -> Pg=450.0, Qg=80.0
% INFO    : Gen at bus 13137	: Vg=1.058231 -> Vg=1.0
% INFO    : Gen at bus 13143	: Pg=168.0, Qg=14.06 -> Pg=250.0, Qg=25.0
% INFO    : Gen at bus 13143	: Vg=1.016606 -> Vg=1.0
% INFO    : Gen at bus 13145	: Pg=257.97, Qg=-14.76 -> Pg=350.0, Qg=80.0
% INFO    : Gen at bus 13145	: Vg=1.029219 -> Vg=1.0
% INFO    : Gen at bus 13147	: Pg=32.2, Qg=7.05 -> Pg=60.735, Qg=10.0
% INFO    : Gen at bus 13147	: Vg=1.034688 -> Vg=1.0
% INFO    : Gen at bus 13158	: Pg=424.18, Qg=1.63 -> Pg=550.0, Qg=100.0
% INFO    : Gen at bus 13158	: Vg=1.036955 -> Vg=1.0
% INFO    : Gen at bus 13159	: Pg=4.2, Qg=-0.51 -> Pg=51.4, Qg=0.0
% INFO    : Gen at bus 13159	: Vg=0.974729 -> Vg=1.0
% INFO    : Gen at bus 13160	: Pg=43.17, Qg=6.95 -> Pg=64.39, Qg=10.0
% INFO    : Gen at bus 13160	: Vg=1.015029 -> Vg=1.0
% INFO    : Gen at bus 13163	: Pg=35.6, Qg=15.17 -> Pg=61.865, Qg=10.0
% INFO    : Gen at bus 13163	: Vg=1.026957 -> Vg=1.0
% INFO    : Gen at bus 13165	: Pg=5.2, Qg=0.53 -> Pg=51.735, Qg=0.0
% INFO    : Gen at bus 13165	: Vg=1.031159 -> Vg=1.0
% INFO    : Gen at bus 13174	: Pg=38.02, Qg=11.21 -> Pg=62.675, Qg=10.0
% INFO    : Gen at bus 13174	: Vg=1.043087 -> Vg=1.0
% INFO    : Gen at bus 13182	: Pg=-12.51, Qg=-2.52 -> Pg=41.66, Qg=0.0
% INFO    : Gen at bus 13182	: Vg=0.975956 -> Vg=1.0
% INFO    : Gen at bus 13188	: Pg=274.11, Qg=117.05 -> Pg=350.0, Qg=60.0
% INFO    : Gen at bus 13188	: Vg=1.051387 -> Vg=1.0
% INFO    : Gen at bus 13189	: Pg=274.11, Qg=117.05 -> Pg=350.0, Qg=60.0
% INFO    : Gen at bus 13189	: Vg=1.051387 -> Vg=1.0
% INFO    : Gen at bus 13190	: Pg=274.11, Qg=117.05 -> Pg=350.0, Qg=60.0
% INFO    : Gen at bus 13190	: Vg=1.051387 -> Vg=1.0
% INFO    : Gen at bus 13191	: Pg=158.9, Qg=39.46 -> Pg=250.0, Qg=35.0
% INFO    : Gen at bus 13191	: Vg=1.020032 -> Vg=1.0
% INFO    : Gen at bus 13192	: Pg=952.11, Qg=346.75 -> Pg=1300.0, Qg=200.0
% INFO    : Gen at bus 13192	: Vg=1.038082 -> Vg=1.0
% INFO    : Gen at bus 13193	: Pg=1.2, Qg=0.03 -> Pg=50.4, Qg=0.0
% INFO    : Gen at bus 13193	: Vg=1.003171 -> Vg=1.0
% INFO    : Gen at bus 13195	: Pg=36.8, Qg=-2.54 -> Pg=62.265, Qg=0.0
% INFO    : Gen at bus 13195	: Vg=0.98379 -> Vg=1.0
% INFO    : Gen at bus 13200	: Pg=57.5, Qg=6.09 -> Pg=119.165, Qg=0.0
% INFO    : Gen at bus 13200	: Vg=0.99654 -> Vg=1.0
% INFO    : Gen at bus 13209	: Pg=180.96, Qg=38.95 -> Pg=250.0, Qg=60.0
% INFO    : Gen at bus 13209	: Vg=1.029835 -> Vg=1.0
% INFO    : Gen at bus 13212	: Pg=6.1, Qg=0.22 -> Pg=52.035, Qg=0.0
% INFO    : Gen at bus 13212	: Vg=1.00107 -> Vg=1.0
% INFO    : Gen at bus 13218	: Pg=135.0, Qg=10.29 -> Pg=195.0, Qg=25.0
% INFO    : Gen at bus 13218	: Vg=1.008348 -> Vg=1.0
% INFO    : Gen at bus 13222	: Pg=39.1, Qg=-2.22 -> Pg=63.035, Qg=0.0
% INFO    : Gen at bus 13222	: Vg=0.943436 -> Vg=1.0
% INFO    : Gen at bus 13223	: Pg=37.08, Qg=5.51 -> Pg=62.36, Qg=10.0
% INFO    : Gen at bus 13223	: Vg=1.021005 -> Vg=1.0
% INFO    : Gen at bus 13226	: Pg=8.2, Qg=-0.77 -> Pg=52.735, Qg=0.0
% INFO    : Gen at bus 13226	: Vg=1.00746 -> Vg=1.0
% INFO    : Gen at bus 13232	: Pg=50.92, Qg=11.1 -> Pg=116.975, Qg=15.0
% INFO    : Gen at bus 13232	: Vg=1.010998 -> Vg=1.0
% INFO    : Gen at bus 13235	: Pg=323.35, Qg=77.76 -> Pg=450.0, Qg=80.0
% INFO    : Gen at bus 13235	: Vg=1.058114 -> Vg=1.0
% INFO    : Gen at bus 13238	: Pg=58.8, Qg=-10.54 -> Pg=119.6, Qg=0.0
% INFO    : Gen at bus 13238	: Vg=0.9646 -> Vg=1.0
% INFO    : Gen at bus 13265	: Pg=10.26, Qg=0.48 -> Pg=53.42, Qg=0.0
% INFO    : Gen at bus 13265	: Vg=1.000157 -> Vg=1.0
% INFO    : Gen at bus 13268	: Pg=16.6, Qg=0.7 -> Pg=55.535, Qg=0.0
% INFO    : Gen at bus 13268	: Vg=1.016188 -> Vg=1.0
% INFO    : Gen at bus 13270	: Pg=5.0, Qg=-1.11 -> Pg=51.665, Qg=0.0
% INFO    : Gen at bus 13270	: Vg=0.981334 -> Vg=1.0
% INFO    : Gen at bus 13285	: Pg=51.75, Qg=8.57 -> Pg=117.25, Qg=15.0
% INFO    : Gen at bus 13285	: Vg=1.019281 -> Vg=1.0
% INFO    : Gen at bus 13292	: Pg=36.77, Qg=13.93 -> Pg=62.255, Qg=10.0
% INFO    : Gen at bus 13292	: Vg=1.042317 -> Vg=1.0
% INFO    : Gen at bus 13298	: Pg=25.41, Qg=10.98 -> Pg=58.47, Qg=10.0
% INFO    : Gen at bus 13298	: Vg=1.019411 -> Vg=1.0
% INFO    : Gen at bus 13303	: Pg=36.03, Qg=16.08 -> Pg=62.01, Qg=10.0
% INFO    : Gen at bus 13303	: Vg=1.045359 -> Vg=1.0
% INFO    : Gen at bus 13310	: Pg=33.39, Qg=17.82 -> Pg=61.13, Qg=15.0
% INFO    : Gen at bus 13310	: Vg=1.025649 -> Vg=1.0
% INFO    : Gen at bus 13311	: Pg=33.45, Qg=6.28 -> Pg=61.15, Qg=15.0
% INFO    : Gen at bus 13311	: Vg=1.055904 -> Vg=1.0
% INFO    : Gen at bus 13312	: Pg=3.5, Qg=-0.25 -> Pg=51.165, Qg=0.0
% INFO    : Gen at bus 13312	: Vg=0.995346 -> Vg=1.0
% INFO    : Gen at bus 13313	: Pg=54.06, Qg=11.61 -> Pg=118.02, Qg=15.0
% INFO    : Gen at bus 13313	: Vg=1.023809 -> Vg=1.0
% INFO    : Gen at bus 13316	: Pg=50.34, Qg=9.17 -> Pg=116.78, Qg=15.0
% INFO    : Gen at bus 13316	: Vg=1.034532 -> Vg=1.0
% INFO    : Gen at bus 13322	: Pg=330.71, Qg=4.92 -> Pg=450.0, Qg=80.0
% INFO    : Gen at bus 13322	: Vg=1.043049 -> Vg=1.0
% INFO    : Gen at bus 13327	: Pg=378.98, Qg=209.33 -> Pg=500.0, Qg=80.0
% INFO    : Gen at bus 13327	: Vg=1.117446 -> Vg=1.0
% INFO    : Gen at bus 13330	: Pg=32.51, Qg=6.89 -> Pg=60.835, Qg=10.0
% INFO    : Gen at bus 13330	: Vg=1.011478 -> Vg=1.0
% INFO    : Gen at bus 13333	: Pg=214.52, Qg=110.59 -> Pg=300.0, Qg=80.0
% INFO    : Gen at bus 13333	: Vg=1.065343 -> Vg=1.0
% INFO    : Gen at bus 13338	: Pg=62.5, Qg=10.73 -> Pg=120.835, Qg=10.0
% INFO    : Gen at bus 13338	: Vg=1.000057 -> Vg=1.0
% INFO    : Gen at bus 13345	: Pg=40.44, Qg=13.81 -> Pg=63.48, Qg=15.0
% INFO    : Gen at bus 13345	: Vg=1.025019 -> Vg=1.0
% INFO    : Gen at bus 13363	: Pg=26.01, Qg=11.35 -> Pg=58.67, Qg=10.0
% INFO    : Gen at bus 13363	: Vg=1.062565 -> Vg=1.0
% INFO    : Gen at bus 13370	: Pg=31.29, Qg=6.48 -> Pg=60.43, Qg=10.0
% INFO    : Gen at bus 13370	: Vg=1.024788 -> Vg=1.0
% INFO    : Gen at bus 13371	: Pg=20.4, Qg=3.27 -> Pg=56.8, Qg=5.0
% INFO    : Gen at bus 13371	: Vg=1.027307 -> Vg=1.0
% INFO    : Gen at bus 13379	: Pg=423.72, Qg=187.67 -> Pg=550.0, Qg=85.0
% INFO    : Gen at bus 13379	: Vg=1.052254 -> Vg=1.0
% INFO    : Gen at bus 13383	: Pg=83.51, Qg=27.65 -> Pg=127.835, Qg=20.0
% INFO    : Gen at bus 13383	: Vg=1.063297 -> Vg=1.0
% INFO    : Gen at bus 13385	: Pg=62.37, Qg=25.07 -> Pg=120.79, Qg=20.0
% INFO    : Gen at bus 13385	: Vg=1.030828 -> Vg=1.0
% INFO    : Gen at bus 13386	: Pg=62.37, Qg=25.07 -> Pg=120.79, Qg=20.0
% INFO    : Gen at bus 13386	: Vg=1.030828 -> Vg=1.0
% INFO    : Gen at bus 13387	: Pg=62.37, Qg=25.07 -> Pg=120.79, Qg=20.0
% INFO    : Gen at bus 13387	: Vg=1.030828 -> Vg=1.0
% INFO    : Gen at bus 13388	: Pg=82.89, Qg=46.38 -> Pg=127.63, Qg=20.0
% INFO    : Gen at bus 13388	: Vg=1.055605 -> Vg=1.0
% INFO    : Gen at bus 13389	: Pg=82.89, Qg=46.38 -> Pg=127.63, Qg=20.0
% INFO    : Gen at bus 13389	: Vg=1.055605 -> Vg=1.0
% INFO    : Gen at bus 13390	: Pg=29.68, Qg=6.45 -> Pg=59.895, Qg=10.0
% INFO    : Gen at bus 13390	: Vg=1.016891 -> Vg=1.0
% INFO    : Gen at bus 13391	: Pg=29.68, Qg=6.45 -> Pg=59.895, Qg=10.0
% INFO    : Gen at bus 13391	: Vg=1.016891 -> Vg=1.0
% INFO    : Gen at bus 13392	: Pg=33.84, Qg=9.43 -> Pg=61.28, Qg=10.0
% INFO    : Gen at bus 13392	: Vg=1.043178 -> Vg=1.0
% INFO    : Gen at bus 13393	: Pg=29.68, Qg=6.45 -> Pg=59.895, Qg=10.0
% INFO    : Gen at bus 13393	: Vg=1.016891 -> Vg=1.0
% INFO    : Gen at bus 13394	: Pg=29.68, Qg=6.45 -> Pg=59.895, Qg=10.0
% INFO    : Gen at bus 13394	: Vg=1.016891 -> Vg=1.0
% INFO    : Gen at bus 13395	: Pg=29.68, Qg=6.45 -> Pg=59.895, Qg=10.0
% INFO    : Gen at bus 13395	: Vg=1.016891 -> Vg=1.0
% INFO    : Gen at bus 13397	: Pg=82.89, Qg=46.38 -> Pg=127.63, Qg=20.0
% INFO    : Gen at bus 13397	: Vg=1.055605 -> Vg=1.0
% INFO    : Gen at bus 13398	: Pg=82.89, Qg=46.38 -> Pg=127.63, Qg=20.0
% INFO    : Gen at bus 13398	: Vg=1.055605 -> Vg=1.0
% INFO    : Gen at bus 13399	: Pg=82.89, Qg=46.38 -> Pg=127.63, Qg=20.0
% INFO    : Gen at bus 13399	: Vg=1.055605 -> Vg=1.0
% INFO    : Gen at bus 13407	: Pg=25.2, Qg=-7.17 -> Pg=58.4, Qg=0.0
% INFO    : Gen at bus 13407	: Vg=0.965886 -> Vg=1.0
% INFO    : Gen at bus 13409	: Pg=30.9, Qg=1.92 -> Pg=60.3, Qg=10.0
% INFO    : Gen at bus 13409	: Vg=1.015954 -> Vg=1.0
% INFO    : Gen at bus 13411	: Pg=81.31, Qg=8.06 -> Pg=127.105, Qg=20.0
% INFO    : Gen at bus 13411	: Vg=1.043619 -> Vg=1.0
% INFO    : Gen at bus 13412	: Pg=31.92, Qg=6.07 -> Pg=60.64, Qg=10.0
% INFO    : Gen at bus 13412	: Vg=1.027264 -> Vg=1.0
% INFO    : Gen at bus 13419	: Pg=22.46, Qg=14.75 -> Pg=57.485, Qg=10.0
% INFO    : Gen at bus 13419	: Vg=1.043942 -> Vg=1.0
% INFO    : Gen at bus 13421	: Pg=35.86, Qg=4.09 -> Pg=61.955, Qg=10.0
% INFO    : Gen at bus 13421	: Vg=1.02494 -> Vg=1.0
% INFO    : Gen at bus 13423	: Pg=35.86, Qg=4.09 -> Pg=61.955, Qg=10.0
% INFO    : Gen at bus 13423	: Vg=1.02494 -> Vg=1.0
% INFO    : Gen at bus 13424	: Pg=35.86, Qg=4.09 -> Pg=61.955, Qg=10.0
% INFO    : Gen at bus 13424	: Vg=1.02494 -> Vg=1.0
% INFO    : Gen at bus 13425	: Pg=27.44, Qg=5.18 -> Pg=59.145, Qg=15.0
% INFO    : Gen at bus 13425	: Vg=1.025625 -> Vg=1.0
% INFO    : Gen at bus 13426	: Pg=63.42, Qg=10.31 -> Pg=121.14, Qg=15.0
% INFO    : Gen at bus 13426	: Vg=1.03448 -> Vg=1.0
% INFO    : Gen at bus 13433	: Pg=52.29, Qg=8.76 -> Pg=117.43, Qg=15.0
% INFO    : Gen at bus 13433	: Vg=1.021414 -> Vg=1.0
% INFO    : Gen at bus 13437	: Pg=52.29, Qg=8.76 -> Pg=117.43, Qg=15.0
% INFO    : Gen at bus 13437	: Vg=1.021414 -> Vg=1.0
% INFO    : Gen at bus 13439	: Pg=52.29, Qg=8.76 -> Pg=117.43, Qg=15.0
% INFO    : Gen at bus 13439	: Vg=1.021414 -> Vg=1.0
% INFO    : Gen at bus 13440	: Pg=33.96, Qg=3.76 -> Pg=61.32, Qg=5.0
% INFO    : Gen at bus 13440	: Vg=1.014614 -> Vg=1.0
% INFO    : Gen at bus 13447	: Pg=12.3, Qg=0.28 -> Pg=54.1, Qg=0.0
% INFO    : Gen at bus 13447	: Vg=1.011745 -> Vg=1.0
% INFO    : Gen at bus 13456	: Pg=28.48, Qg=6.95 -> Pg=59.495, Qg=10.0
% INFO    : Gen at bus 13456	: Vg=1.005915 -> Vg=1.0
% INFO    : Gen at bus 13466	: Pg=53.99, Qg=18.23 -> Pg=117.995, Qg=15.0
% INFO    : Gen at bus 13466	: Vg=1.062896 -> Vg=1.0
% INFO    : Gen at bus 13467	: Pg=14.92, Qg=-0.69 -> Pg=54.975, Qg=0.0
% INFO    : Gen at bus 13467	: Vg=0.989708 -> Vg=1.0
% INFO    : Gen at bus 13468	: Pg=56.36, Qg=7.67 -> Pg=118.785, Qg=15.0
% INFO    : Gen at bus 13468	: Vg=1.024375 -> Vg=1.0
% INFO    : Gen at bus 13482	: Pg=53.99, Qg=18.23 -> Pg=117.995, Qg=15.0
% INFO    : Gen at bus 13482	: Vg=1.062896 -> Vg=1.0
% INFO    : Gen at bus 13486	: Pg=53.99, Qg=18.23 -> Pg=117.995, Qg=15.0
% INFO    : Gen at bus 13486	: Vg=1.062896 -> Vg=1.0
% INFO    : Gen at bus 13487	: Pg=50.34, Qg=15.84 -> Pg=116.78, Qg=15.0
% INFO    : Gen at bus 13487	: Vg=1.03143 -> Vg=1.0
% INFO    : Gen at bus 13489	: Pg=80.74, Qg=25.03 -> Pg=126.915, Qg=20.0
% INFO    : Gen at bus 13489	: Vg=1.061099 -> Vg=1.0
% INFO    : Gen at bus 13491	: Pg=20.57, Qg=3.1 -> Pg=56.855, Qg=10.0
% INFO    : Gen at bus 13491	: Vg=1.026081 -> Vg=1.0
% INFO    : Gen at bus 13493	: Pg=344.6, Qg=7.8 -> Pg=450.0, Qg=20.0
% INFO    : Gen at bus 13493	: Vg=0.97953 -> Vg=1.0
% INFO    : Gen at bus 13496	: Pg=32.64, Qg=6.67 -> Pg=60.88, Qg=10.0
% INFO    : Gen at bus 13496	: Vg=1.044924 -> Vg=1.0
% INFO    : Gen at bus 13497	: Pg=32.64, Qg=6.67 -> Pg=60.88, Qg=10.0
% INFO    : Gen at bus 13497	: Vg=1.044924 -> Vg=1.0
% INFO    : Gen at bus 13500	: Pg=32.64, Qg=6.68 -> Pg=60.88, Qg=10.0
% INFO    : Gen at bus 13500	: Vg=1.044939 -> Vg=1.0
% INFO    : Gen at bus 13502	: Pg=32.64, Qg=6.68 -> Pg=60.88, Qg=10.0
% INFO    : Gen at bus 13502	: Vg=1.044939 -> Vg=1.0
% INFO    : Gen at bus 13505	: Pg=32.64, Qg=6.67 -> Pg=60.88, Qg=10.0
% INFO    : Gen at bus 13505	: Vg=1.044924 -> Vg=1.0
% INFO    : Gen at bus 13506	: Pg=32.64, Qg=6.67 -> Pg=60.88, Qg=10.0
% INFO    : Gen at bus 13506	: Vg=1.044924 -> Vg=1.0
% INFO    : Gen at bus 13507	: Pg=32.64, Qg=6.67 -> Pg=60.88, Qg=10.0
% INFO    : Gen at bus 13507	: Vg=1.044924 -> Vg=1.0
% INFO    : Gen at bus 13510	: Pg=0.2, Qg=-0.15 -> Pg=50.07, Qg=0.0
% INFO    : Gen at bus 13510	: Vg=1.016107 -> Vg=1.0
% INFO    : Gen at bus 13512	: Pg=27.73, Qg=2.0 -> Pg=59.245, Qg=10.0
% INFO    : Gen at bus 13512	: Vg=1.030407 -> Vg=1.0
% INFO    : Gen at bus 13514	: Pg=31.0, Qg=0.14 -> Pg=60.335, Qg=0.0
% INFO    : Gen at bus 13514	: Vg=1.000449 -> Vg=1.0
% INFO    : Gen at bus 13520	: Pg=80.74, Qg=25.03 -> Pg=126.915, Qg=20.0
% INFO    : Gen at bus 13520	: Vg=1.061099 -> Vg=1.0
% INFO    : Gen at bus 13525	: Pg=53.07, Qg=7.74 -> Pg=117.69, Qg=15.0
% INFO    : Gen at bus 13525	: Vg=1.025333 -> Vg=1.0
% INFO    : Gen at bus 13526	: Pg=200.87, Qg=149.13 -> Pg=300.0, Qg=80.0
% INFO    : Gen at bus 13526	: Vg=1.062073 -> Vg=1.0
% INFO    : Gen at bus 13530	: Pg=236.37, Qg=0.58 -> Pg=300.0, Qg=80.0
% INFO    : Gen at bus 13530	: Vg=1.042446 -> Vg=1.0
% INFO    : Gen at bus 13549	: Pg=23.04, Qg=1.33 -> Pg=57.68, Qg=0.0
% INFO    : Gen at bus 13549	: Vg=0.996935 -> Vg=1.0
% INFO    : Gen at bus 13550	: Pg=31.5, Qg=1.72 -> Pg=60.5, Qg=5.0
% INFO    : Gen at bus 13550	: Vg=1.016735 -> Vg=1.0
% INFO    : Gen at bus 13551	: Pg=2.5, Qg=0.07 -> Pg=50.835, Qg=0.0
% INFO    : Gen at bus 13551	: Vg=0.984601 -> Vg=1.0
% INFO    : Gen at bus 13556	: Pg=6.52, Qg=-0.06 -> Pg=52.175, Qg=0.0
% INFO    : Gen at bus 13556	: Vg=0.994601 -> Vg=1.0
% INFO    : Gen at bus 13560	: Pg=218.81, Qg=74.1 -> Pg=300.0, Qg=80.0
% INFO    : Gen at bus 13560	: Vg=1.033239 -> Vg=1.0
% INFO    : Gen at bus 13569	: Pg=96.03, Qg=17.22 -> Pg=132.01, Qg=20.0
% INFO    : Gen at bus 13569	: Vg=1.036065 -> Vg=1.0
% INFO    : Gen at bus 13577	: Pg=49.34, Qg=9.15 -> Pg=66.445, Qg=15.0
% INFO    : Gen at bus 13577	: Vg=1.034597 -> Vg=1.0
% INFO    : Gen at bus 13580	: Pg=33.84, Qg=9.43 -> Pg=61.28, Qg=10.0
% INFO    : Gen at bus 13580	: Vg=1.043178 -> Vg=1.0
% INFO    : Gen at bus 13582	: Pg=33.84, Qg=9.43 -> Pg=61.28, Qg=10.0
% INFO    : Gen at bus 13582	: Vg=1.043178 -> Vg=1.0
% INFO    : Gen at bus 13584	: Pg=19.12, Qg=15.11 -> Pg=56.375, Qg=10.0
% INFO    : Gen at bus 13584	: Vg=1.030744 -> Vg=1.0
% INFO    : Gen at bus 13585	: Pg=22.27, Qg=8.99 -> Pg=57.425, Qg=10.0
% INFO    : Gen at bus 13585	: Vg=1.04545 -> Vg=1.0
% INFO    : Gen at bus 13589	: Pg=22.27, Qg=8.99 -> Pg=57.425, Qg=10.0
% INFO    : Gen at bus 13589	: Vg=1.04545 -> Vg=1.0
% INFO    : Gen at bus 13590	: Pg=86.25, Qg=-3.04 -> Pg=128.75, Qg=-10.0
% INFO    : Gen at bus 13590	: Vg=0.962614 -> Vg=1.0
% INFO    : Gen at bus 13592	: Pg=326.27, Qg=128.78 -> Pg=450.0, Qg=80.0
% INFO    : Gen at bus 13592	: Vg=1.051118 -> Vg=1.0
% INFO    : Gen at bus 13594	: Pg=20.37, Qg=8.85 -> Pg=56.79, Qg=10.0
% INFO    : Gen at bus 13594	: Vg=1.045375 -> Vg=1.0
% INFO    : Gen at bus 13597	: Pg=20.37, Qg=8.85 -> Pg=56.79, Qg=10.0
% INFO    : Gen at bus 13597	: Vg=1.045375 -> Vg=1.0
% INFO    : Gen at bus 13601	: Pg=21.74, Qg=6.85 -> Pg=57.245, Qg=10.0
% INFO    : Gen at bus 13601	: Vg=1.050175 -> Vg=1.0
% INFO    : Gen at bus 13604	: Pg=22.27, Qg=8.99 -> Pg=57.425, Qg=10.0
% INFO    : Gen at bus 13604	: Vg=1.04545 -> Vg=1.0
% INFO    : Gen at bus 13607	: Pg=38.04, Qg=7.18 -> Pg=62.68, Qg=10.0
% INFO    : Gen at bus 13607	: Vg=1.020265 -> Vg=1.0
% INFO    : Gen at bus 13609	: Pg=22.0, Qg=9.29 -> Pg=57.335, Qg=10.0
% INFO    : Gen at bus 13609	: Vg=1.030852 -> Vg=1.0
% INFO    : Gen at bus 13617	: Pg=2.26, Qg=-1.2 -> Pg=50.755, Qg=0.0
% INFO    : Gen at bus 13617	: Vg=0.991929 -> Vg=1.0
% INFO    : Gen at bus 13620	: Pg=277.81, Qg=77.81 -> Pg=350.0, Qg=80.0
% INFO    : Gen at bus 13620	: Vg=1.034935 -> Vg=1.0
% INFO    : Gen at bus 13633	: Pg=50.34, Qg=15.84 -> Pg=116.78, Qg=15.0
% INFO    : Gen at bus 13633	: Vg=1.03143 -> Vg=1.0
% INFO    : Gen at bus 13639	: Pg=29.92, Qg=0.94 -> Pg=59.975, Qg=5.0
% INFO    : Gen at bus 13639	: Vg=0.980011 -> Vg=1.0
% INFO    : Gen at bus 13643	: Pg=18.32, Qg=-0.94 -> Pg=56.105, Qg=0.0
% INFO    : Gen at bus 13643	: Vg=0.995077 -> Vg=1.0
% INFO    : Gen at bus 13648	: Pg=50.34, Qg=15.84 -> Pg=116.78, Qg=15.0
% INFO    : Gen at bus 13648	: Vg=1.03143 -> Vg=1.0
% INFO    : Gen at bus 13651	: Pg=16.79, Qg=7.28 -> Pg=55.595, Qg=10.0
% INFO    : Gen at bus 13651	: Vg=1.042166 -> Vg=1.0
% INFO    : Gen at bus 13654	: Pg=-0.0, Qg=27.02 -> Pg=50.0, Qg=185.0
% INFO    : Gen at bus 13654	: Vg=1.079579 -> Vg=1.0
% INFO    : Gen at bus 13655	: Pg=20.46, Qg=6.24 -> Pg=56.82, Qg=10.0
% INFO    : Gen at bus 13655	: Vg=0.992821 -> Vg=1.0
% INFO    : Gen at bus 13658	: Pg=26.41, Qg=7.43 -> Pg=58.805, Qg=10.0
% INFO    : Gen at bus 13658	: Vg=1.038011 -> Vg=1.0
% INFO    : 
% INFO    : === Writing Matpower Case File Notes ===
