%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%                                                                  %%%%%
%%%%    IEEE PES Power Grid Library - Optimal Power Flow - v23.07     %%%%%
%%%%          (https://github.com/power-grid-lib/pglib-opf)           %%%%%
%%%%               Benchmark Group - Typical Operations               %%%%%
%%%%                         23 - July - 2023                         %%%%%
%%%%                                                                  %%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%CASE1888RTE
%   AC Power flow data for French system.
%   Please see CASEFORMAT for details on the case file format.
%
%   This case accurately represents the size and complexity of French
%   very high voltage transmission network.
%   Part of this data was sampled in the offline platform of iTesla.
%   These data can be used to validate mathematical methods and tools.
%   These data should NOT be used for operation
%   nor planning of the French or European grids.
%
%   When publishing results using this data, please cite:
%     C. Josz, S. Fliscounakis, J. Maeght, and P. Panciatici,
%     "AC Power Flow Data in MATPOWER and QCQP Format: iTesla, RTE Snapshots, and PEGASE"
%     http://arxiv.org/abs/1603.01533
%
%   Contacts (primary contact for this file : Jean Maeght):
%   Cédric Josz, Stéphane Fliscounakis, Jean Maeght, Patrick Panciatici
%   firstname.lastname@rte-france.com
%   Réseau de Transport d'Electricité (French Transmission System Operator)
%   Département Expertise Système, Immeuble "Le Colbert"
%   9 rue de la Porte de Buc, 78000 Versailles Cedex, France
%   March 4th, 2016
%
%   Copyright (c) 2016 by Cédric Josz, Stéphane Fliscounakis, Jean Maeght,
%   and Patrick Panciatici
%   Licensed under the Creative Commons Attribution 4.0 International license,
%   http://creativecommons.org/licenses/by/4.0/
%
function mpc = pglib_opf_case1888_rte
mpc.version = '2';
mpc.baseMVA = 100.0;

%% bus data
%	bus_i	type	Pd	Qd	Gs	Bs	area	Vm	Va	baseKV	zone	Vmax	Vmin
mpc.bus = [
	1	 1	 5.8	 -5.8	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	2	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07552	    0.00000	 380.0	 1	    1.10263	    1.04841;
	3	 1	 142.5	 -13.4	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	4	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00334	    0.00000	 150.0	 1	    1.10667	    0.90000;
	5	 1	 32.8	 -5.3	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	6	 1	 40.2	 4.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	7	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	8	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	9	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04739	    0.00000	 225.0	 1	    1.09035	    1.00444;
	10	 1	 148.8	 14.9	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	11	 1	 25.6	 5.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	12	 1	 39.1	 8.7	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	13	 1	 70.5	 17.2	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	14	 1	 36.0	 -4.2	 0.0	 0.0	 1	    1.01626	    0.00000	 225.0	 1	    1.08252	    0.95000;
	15	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	16	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	17	 1	 23.7	 -12.4	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	18	 1	 5.9	 -4.8	 0.0	 0.0	 1	    1.04150	    0.00000	 225.0	 1	    1.09633	    0.98667;
	19	 1	 34.0	 3.7	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	20	 1	 6.9	 0.8	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	21	 1	 9.2	 -29.1	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	22	 1	 67.7	 -3.6	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	23	 1	 25.4	 -2.7	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	25	 1	 64.0	 4.6	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	27	 1	 71.6	 46.7	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	28	 1	 105.4	 6.9	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	29	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07684	    0.00000	 380.0	 1	    1.10526	    1.04842;
	30	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07684	    0.00000	 380.0	 1	    1.10526	    1.04842;
	31	 1	 21.7	 0.9	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	33	 1	 68.9	 2.6	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	34	 1	 50.6	 12.7	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	35	 1	 17.0	 2.1	 0.0	 0.0	 1	    1.02333	    0.00000	 150.0	 1	    1.08000	    0.96667;
	36	 1	 38.2	 6.3	 0.0	 0.0	 1	    1.04606	    0.00000	 225.0	 1	    1.09212	    1.00000;
	37	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07655	    0.00000	 380.0	 1	    1.10526	    1.04785;
	38	 1	 89.0	 9.6	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2050	 1	 0.0	 0.0	 0.0	 -64.0	 1	    1.15000	    0.00000	 20.0	 1	    1.50000	    0.80000;
	39	 1	 70.9	 -2.3	 0.0	 0.0	 1	    1.02889	    0.00000	 225.0	 1	    1.08889	    0.96889;
	40	 1	 136.2	 -10.7	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	41	 1	 64.6	 17.3	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	42	 1	 13.4	 3.3	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	43	 1	 33.3	 4.7	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	44	 1	 211.6	 -1.3	 0.0	 0.0	 1	    1.04470	    0.00000	 225.0	 1	    1.08496	    1.00444;
	45	 1	 92.1	 -9.1	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	46	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00422	    0.00000	 150.0	 1	    1.10843	    0.90000;
	47	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	48	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	49	 1	 63.7	 84.5	 0.0	 -80.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	50	 1	 10.4	 6.6	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	51	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	52	 1	 68.7	 16.5	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	53	 1	 101.2	 15.9	 0.0	 0.0	 1	    1.02889	    0.00000	 225.0	 1	    1.08889	    0.96889;
	54	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	55	 1	 28.9	 10.6	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	56	 1	 28.2	 2.1	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	1827	 1	 109.6	 -12.9	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	57	 1	 27.3	 -10.9	 0.0	 0.0	 1	    1.01139	    0.00000	 225.0	 1	    1.08945	    0.93333;
	58	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00431	    0.00000	 150.0	 1	    1.10862	    0.90000;
	59	 1	 36.8	 20.3	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	60	 1	 36.5	 30.8	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	61	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	62	 1	 8.4	 -0.3	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	63	 1	 13.2	 -6.3	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	64	 1	 13.2	 3.3	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	65	 1	 22.7	 2.5	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	66	 1	 11.4	 -9.7	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	67	 1	 10.2	 -1.3	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	68	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	69	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	70	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05921	    0.00000	 380.0	 1	    1.10526	    1.01316;
	71	 1	 39.2	 2.8	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	72	 1	 19.3	 3.3	 0.0	 -80.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	73	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	74	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	75	 1	 131.9	 3.2	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	76	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	77	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	78	 1	 94.6	 -1.9	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	79	 1	 -1.7	 -4.6	 0.0	 0.0	 1	    1.04690	    0.00000	 225.0	 1	    1.08936	    1.00444;
	80	 1	 3.6	 -7.2	 0.0	 0.0	 1	    1.04690	    0.00000	 225.0	 1	    1.08936	    1.00444;
	81	 1	 35.4	 10.9	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	82	 1	 15.1	 0.7	 0.0	 0.0	 1	    1.01562	    0.00000	 225.0	 1	    1.08124	    0.95000;
	83	 1	 57.4	 18.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	84	 1	 89.9	 -5.8	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	85	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	86	 1	 239.8	 17.5	 0.0	 0.0	 1	    1.07798	    0.00000	 380.0	 1	    1.10526	    1.05070;
	87	 1	 35.5	 16.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	88	 1	 76.1	 23.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	89	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	90	 1	 21.3	 12.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	91	 1	 11.2	 -5.2	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	92	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	93	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	96	 1	 11.7	 1.3	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	97	 1	 6.1	 1.4	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	98	 1	 31.6	 2.6	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	99	 1	 68.9	 -11.7	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	100	 2	 0.2	 -0.0	 0.0	 0.0	 1	    1.01647	    0.00000	 225.0	 1	    1.08294	    0.95000;
	101	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	102	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	103	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	104	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1828	 1	 30.1	 3.8	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	105	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	106	 1	 12.1	 4.5	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	107	 1	 106.1	 -0.3	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	108	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	109	 1	 43.3	 8.4	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	110	 1	 33.2	 -7.5	 0.0	 0.0	 1	    1.04715	    0.00000	 225.0	 1	    1.08986	    1.00444;
	111	 1	 99.5	 -12.4	 0.0	 0.0	 1	    1.04806	    0.00000	 225.0	 1	    1.09612	    1.00000;
	112	 1	 116.4	 -6.7	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	113	 1	 65.7	 14.7	 0.0	 0.0	 1	    1.04740	    0.00000	 225.0	 1	    1.09036	    1.00444;
	114	 1	 107.2	 21.2	 0.0	 0.0	 1	    1.00667	    0.00000	 225.0	 1	    1.08889	    0.92444;
	115	 1	 56.9	 -2.7	 0.0	 0.0	 1	    1.04140	    0.00000	 225.0	 1	    1.09614	    0.98667;
	117	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	119	 1	 123.6	 -19.8	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	2051	 1	 0.0	 0.0	 0.0	 -64.0	 1	    1.10000	    0.00000	 20.0	 1	    1.40000	    0.80000;
	120	 1	 33.3	 -21.3	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	121	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.06579	    0.00000	 380.0	 1	    1.10263	    1.02895;
	122	 1	 1.7	 -4.4	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	123	 1	 140.3	 17.3	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	124	 1	 33.7	 -1.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	125	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01238	    0.00000	 225.0	 1	    1.07476	    0.95000;
	126	 1	 -1.9	 -5.4	 0.0	 0.0	 1	    1.04884	    0.00000	 225.0	 1	    1.09768	    1.00000;
	127	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10526	    1.05263;
	128	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10526	    1.05263;
	129	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10526	    1.05263;
	130	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10526	    1.05263;
	131	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04156	    0.00000	 225.0	 1	    1.09645	    0.98667;
	132	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04156	    0.00000	 225.0	 1	    1.09645	    0.98667;
	133	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	134	 1	 77.3	 -10.6	 0.0	 0.0	 1	    1.02889	    0.00000	 225.0	 1	    1.08889	    0.96889;
	135	 1	 28.1	 3.8	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	136	 1	 -5.2	 -9.4	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	137	 1	 106.4	 8.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	138	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	140	 1	 113.7	 -8.3	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	141	 1	 44.6	 0.5	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	142	 1	 165.2	 -11.8	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	143	 1	 29.2	 2.1	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	144	 1	 32.8	 4.4	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	145	 1	 19.0	 -18.1	 0.0	 0.0	 1	    1.04698	    0.00000	 225.0	 1	    1.08952	    1.00444;
	146	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04739	    0.00000	 225.0	 1	    1.09478	    1.00000;
	147	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04739	    0.00000	 225.0	 1	    1.09478	    1.00000;
	148	 1	 37.1	 5.6	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	149	 1	 20.0	 -3.9	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	150	 1	 38.1	 1.6	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	151	 1	 24.8	 -1.8	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	152	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	153	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	154	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	155	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.06579	    0.00000	 380.0	 1	    1.10263	    1.02895;
	156	 1	 155.3	 26.5	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	157	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04883	    0.00000	 225.0	 1	    1.09766	    1.00000;
	158	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10526	    1.05263;
	159	 1	 21.5	 4.4	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	160	 1	 26.2	 2.1	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	161	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	162	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	163	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	164	 1	 55.3	 -11.4	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	165	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	166	 1	 30.0	 12.3	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2019	 1	 0.0	 0.0	 0.0	 -64.0	 1	    1.15000	    0.00000	 20.0	 1	    1.40000	    0.90000;
	167	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04470	    0.00000	 225.0	 1	    1.08941	    1.00000;
	168	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10526	    1.05263;
	169	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 225.0	 1	    1.10000	    0.90000;
	170	 1	 17.8	 2.6	 0.0	 0.0	 1	    1.02333	    0.00000	 150.0	 1	    1.08000	    0.96667;
	171	 1	 25.3	 -3.2	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	172	 1	 -3.7	 -2.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	173	 1	 37.3	 0.7	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	181	 1	 107.9	 3.9	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	182	 1	 29.5	 6.8	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	183	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	184	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	185	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	186	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	187	 1	 28.1	 -10.0	 0.0	 0.0	 1	    1.00667	    0.00000	 225.0	 1	    1.08889	    0.92444;
	188	 1	 -2.0	 -1.1	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	189	 1	 65.8	 19.1	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	190	 1	 -2.3	 1.2	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	191	 1	 -2.3	 1.4	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	192	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	193	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	194	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	195	 1	 83.6	 -8.6	 0.0	 0.0	 1	    1.02889	    0.00000	 225.0	 1	    1.08889	    0.96889;
	196	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	197	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	198	 1	 57.5	 10.2	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	199	 1	 177.4	 -31.4	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	200	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	201	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	202	 1	 124.2	 -3.2	 0.0	 0.0	 1	    1.02000	    0.00000	 225.0	 1	    1.08889	    0.95111;
	203	 1	 35.3	 1.9	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	204	 1	 51.6	 -4.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2086	 1	 0.0	 0.0	 0.0	 -64.0	 1	    1.10000	    0.00000	 20.0	 1	    1.40000	    0.80000;
	205	 1	 16.9	 -1.8	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	206	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.06579	    0.00000	 380.0	 1	    1.10263	    1.02895;
	207	 1	 38.6	 -0.7	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1829	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01429	    0.00000	 225.0	 1	    1.07859	    0.95000;
	208	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	209	 1	 171.1	 24.7	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	210	 1	 46.3	 14.3	 0.0	 0.0	 1	    1.04085	    0.00000	 225.0	 1	    1.09504	    0.98667;
	211	 1	 58.6	 9.8	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	212	 1	 14.6	 -0.7	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	213	 1	 75.4	 25.3	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	215	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	216	 1	 74.9	 -2.9	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	217	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	218	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	219	 1	 55.6	 14.5	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	220	 1	 -0.1	 0.8	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	221	 1	 11.0	 -0.4	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	222	 1	 39.3	 5.6	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	223	 1	 21.6	 1.4	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	224	 1	 16.7	 2.3	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	225	 1	 2.0	 -1.4	 0.0	 0.0	 1	    1.02667	    0.00000	 150.0	 1	    1.10667	    0.94667;
	1830	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	226	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	227	 1	 119.3	 -16.4	 0.0	 0.0	 1	    1.04897	    0.00000	 225.0	 1	    1.09795	    1.00000;
	228	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07773	    0.00000	 380.0	 1	    1.10526	    1.05019;
	229	 1	 72.1	 6.0	 0.0	 0.0	 1	    1.00000	    0.00000	 225.0	 1	    1.08889	    0.91111;
	230	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	231	 1	 16.1	 1.9	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	232	 1	 14.9	 0.9	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	233	 1	 6.1	 1.7	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	234	 1	 1.1	 1.7	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	235	 1	 2.0	 -3.9	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	236	 1	 2.6	 2.4	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	237	 1	 129.0	 -3.4	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	238	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	239	 1	 25.8	 4.4	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	240	 1	 31.9	 3.6	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	241	 2	 4.3	 -1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.10000	    0.90000;
	242	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02333	    0.00000	 150.0	 1	    1.08000	    0.96667;
	243	 1	 -3.4	 -9.5	 0.0	 0.0	 1	    1.07674	    0.00000	 380.0	 1	    1.11402	    1.03947;
	244	 1	 30.9	 7.4	 0.0	 0.0	 1	    1.07714	    0.00000	 380.0	 1	    1.11482	    1.03947;
	245	 1	 11.7	 0.6	 0.0	 0.0	 1	    1.07605	    0.00000	 380.0	 1	    1.11264	    1.03947;
	246	 1	 -18.3	 -23.8	 0.0	 0.0	 1	    1.07715	    0.00000	 380.0	 1	    1.11483	    1.03947;
	247	 1	 45.0	 5.3	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2029	 1	 0.0	 0.0	 0.0	 -64.0	 1	    1.15000	    0.00000	 20.0	 1	    1.40000	    0.90000;
	2030	 1	 0.0	 0.0	 0.0	 -64.0	 1	    1.15000	    0.00000	 20.0	 1	    1.40000	    0.90000;
	248	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	249	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	250	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07773	    0.00000	 380.0	 1	    1.10526	    1.05019;
	251	 1	 0.7	 -3.7	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	252	 1	 92.9	 -6.0	 0.0	 0.0	 1	    1.07031	    0.00000	 380.0	 1	    1.10526	    1.03537;
	2025	 1	 0.0	 0.0	 0.0	 -58.0	 1	    1.15000	    0.00000	 20.0	 1	    1.40000	    0.90000;
	2031	 1	 0.0	 0.0	 0.0	 -128.0	 1	    1.15000	    0.00000	 20.0	 1	    1.40000	    0.90000;
	2032	 1	 0.0	 0.0	 0.0	 -58.0	 1	    1.15000	    0.00000	 20.0	 1	    1.40000	    0.90000;
	2046	 1	 0.0	 0.0	 0.0	 -58.0	 1	    1.15000	    0.00000	 20.0	 1	    1.40000	    0.90000;
	253	 1	 3.2	 -0.8	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	254	 1	 3.9	 3.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	255	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	257	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	258	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	259	 1	 106.5	 20.7	 0.0	 0.0	 1	    1.00889	    0.00000	 225.0	 1	    1.08889	    0.92889;
	260	 1	 157.5	 -28.3	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	261	 1	 91.4	 -3.2	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	262	 1	 5.5	 -1.3	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	263	 1	 208.0	 14.9	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	267	 1	 250.6	 22.2	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	268	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	269	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	270	 2	 46.4	 27.4	 0.0	 0.0	 1	    1.00923	    0.00000	 20.0	 1	    1.06846	    0.95000;
	271	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	272	 1	 159.3	 40.7	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	273	 1	 203.1	 3.9	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	274	 1	 50.0	 8.3	 0.0	 0.0	 1	    1.04139	    0.00000	 225.0	 1	    1.09611	    0.98667;
	275	 1	 17.6	 -2.4	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	276	 1	 22.7	 -2.9	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	278	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.15000	    0.00000	 20.0	 1	    1.40000	    0.90000;
	279	 1	 36.2	 -22.3	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	280	 1	 169.5	 24.1	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	281	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04480	    0.00000	 225.0	 1	    1.08959	    1.00000;
	282	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04480	    0.00000	 225.0	 1	    1.08959	    1.00000;
	283	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02333	    0.00000	 150.0	 1	    1.08000	    0.96667;
	284	 1	 25.8	 -6.7	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	285	 1	 65.6	 -1.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	286	 1	 52.2	 0.8	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	287	 1	 19.7	 -0.8	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	288	 1	 17.6	 2.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	289	 1	 58.8	 -0.8	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2062	 1	 0.0	 0.0	 0.0	 -64.0	 1	    1.15000	    0.00000	 20.0	 1	    1.40000	    0.90000;
	290	 1	 108.4	 -13.2	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	291	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	292	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	293	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	294	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	295	 1	 160.9	 1.6	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	296	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	297	 1	 34.4	 6.6	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	298	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	299	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	300	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	301	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	302	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	303	 1	 184.2	 -18.9	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	304	 1	 -15.6	 -17.2	 0.0	 0.0	 1	    1.05809	    0.00000	 380.0	 1	    1.11618	    1.00000;
	305	 1	 -23.2	 0.6	 0.0	 0.0	 1	    1.05851	    0.00000	 380.0	 1	    1.11703	    1.00000;
	306	 1	 42.2	 -0.7	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	2047	 1	 0.0	 0.0	 0.0	 -64.0	 1	    1.15000	    0.00000	 20.0	 1	    1.40000	    0.90000;
	307	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	308	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	309	 1	 96.9	 -28.2	 0.0	 0.0	 1	    1.04723	    0.00000	 225.0	 1	    1.09445	    1.00000;
	310	 1	 -1.7	 -3.4	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	311	 1	 -10.7	 -3.4	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	312	 1	 -7.2	 -9.3	 0.0	 0.0	 1	    1.01114	    0.00000	 225.0	 1	    1.08895	    0.93333;
	313	 1	 87.6	 -1.8	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	314	 1	 32.2	 7.9	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	315	 1	 28.6	 2.6	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	316	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	317	 1	 141.6	 32.1	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	318	 1	 30.1	 -3.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	319	 1	 8.2	 4.4	 0.0	 0.0	 1	    1.00334	    0.00000	 150.0	 1	    1.10667	    0.90000;
	320	 1	 91.6	 8.9	 0.0	 0.0	 1	    1.04510	    0.00000	 225.0	 1	    1.08576	    1.00444;
	321	 1	 2.9	 -9.7	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	323	 1	 94.6	 -5.5	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	324	 1	 17.7	 6.3	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	325	 1	 91.8	 -15.3	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	326	 1	 29.0	 -1.9	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	327	 1	 22.1	 -5.8	 0.0	 0.0	 1	    1.15000	    0.00000	 20.0	 1	    1.40000	    0.90000;
	328	 1	 26.3	 1.4	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	329	 1	 106.1	 10.1	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	330	 1	 42.6	 6.9	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	331	 1	 19.5	 5.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	332	 1	 17.7	 -2.8	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	333	 1	 47.6	 -5.2	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2072	 1	 110.4	 -2.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	334	 1	 111.9	 35.6	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	335	 1	 218.9	 -21.9	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	336	 1	 -0.0	 -0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	337	 1	 -0.6	 6.7	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	338	 1	 -0.8	 0.3	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	339	 1	 -1.5	 2.5	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	340	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	341	 1	 33.8	 7.7	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	342	 1	 25.1	 2.5	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	343	 1	 90.0	 0.8	 0.0	 -80.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	345	 1	 40.6	 -7.8	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	346	 1	 120.4	 8.9	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	347	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	348	 1	 -1.7	 0.4	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	350	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	351	 1	 94.8	 -2.9	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	352	 1	 -6.2	 -11.5	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	353	 1	 73.9	 -6.2	 0.0	 0.0	 1	    1.03866	    0.00000	 225.0	 1	    1.09066	    0.98667;
	354	 1	 111.6	 -8.6	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	355	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 225.0	 1	    1.10000	    0.90000;
	356	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01705	    0.00000	 225.0	 1	    1.08410	    0.95000;
	357	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10263	    1.05526;
	358	 1	 21.1	 15.6	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	359	 1	 54.0	 -15.6	 0.0	 0.0	 1	    1.04531	    0.00000	 225.0	 1	    1.08618	    1.00444;
	360	 1	 7.3	 -14.5	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	361	 1	 19.1	 5.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	362	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	363	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.06996	    0.00000	 380.0	 1	    1.10526	    1.03467;
	364	 1	 23.9	 -12.1	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	365	 1	 113.3	 2.9	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	366	 1	 -12.9	 13.9	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	367	 1	 55.9	 -12.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	2014	 1	 0.0	 0.0	 0.0	 -80.0	 1	    1.15000	    0.00000	 20.0	 1	    1.40000	    0.90000;
	368	 1	 114.8	 16.5	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	369	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	370	 1	 52.4	 7.6	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	371	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	372	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	373	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	374	 1	 25.6	 5.5	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	375	 1	 24.1	 2.2	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	376	 1	 -2.9	 -7.4	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	377	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	378	 1	 51.5	 21.6	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	379	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	380	 1	 0.2	 0.1	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	381	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10526	    1.05263;
	382	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10526	    1.05263;
	383	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10526	    1.05263;
	384	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10526	    1.05263;
	385	 1	 12.8	 1.6	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	386	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02333	    0.00000	 150.0	 1	    1.08000	    0.96667;
	387	 1	 76.0	 0.3	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	388	 1	 90.6	 16.2	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	390	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10526	    1.05263;
	391	 1	 1.4	 -0.4	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	392	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	393	 1	 10.3	 -1.3	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	394	 1	 70.2	 9.1	 0.0	 0.0	 1	    1.04091	    0.00000	 225.0	 1	    1.09515	    0.98667;
	395	 1	 44.8	 -25.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	396	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.10000	    0.90000;
	397	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02333	    0.00000	 150.0	 1	    1.08000	    0.96667;
	398	 1	 159.8	 -1.9	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	399	 1	 52.9	 18.2	 0.0	 0.0	 1	    0.99896	    0.00000	 225.0	 1	    1.09125	    0.90667;
	400	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	401	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	402	 1	 33.0	 11.5	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	403	 1	 74.8	 9.4	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	404	 1	 25.3	 -19.4	 0.0	 0.0	 1	    1.00445	    0.00000	 225.0	 1	    1.08889	    0.92000;
	405	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	406	 1	 151.6	 7.9	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	407	 1	 28.1	 1.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	408	 1	 48.6	 -17.6	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	409	 1	 103.5	 -2.1	 0.0	 0.0	 1	    1.04446	    0.00000	 225.0	 1	    1.08449	    1.00444;
	410	 1	 17.9	 2.6	 0.0	 0.0	 1	    1.04736	    0.00000	 225.0	 1	    1.09028	    1.00444;
	411	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04227	    0.00000	 225.0	 1	    1.09787	    0.98667;
	412	 1	 45.4	 4.6	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	413	 1	 59.3	 -1.6	 0.0	 0.0	 1	    1.04222	    0.00000	 225.0	 1	    1.09778	    0.98667;
	414	 1	 139.2	 -6.3	 0.0	 0.0	 1	    1.03830	    0.00000	 225.0	 1	    1.08994	    0.98667;
	416	 1	 97.9	 14.3	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	418	 1	 39.8	 11.4	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	419	 1	 12.4	 -12.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	420	 1	 67.3	 -48.8	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	421	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	422	 1	 55.2	 21.1	 0.0	 0.0	 1	    0.99778	    0.00000	 225.0	 1	    1.08889	    0.90667;
	423	 1	 54.2	 -25.9	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	424	 1	 29.5	 4.9	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	425	 1	 3.5	 -5.7	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	426	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02667	    0.00000	 150.0	 1	    1.10667	    0.94667;
	427	 1	 0.0	 -0.5	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	428	 1	 29.8	 -0.8	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	429	 1	 15.6	 -0.3	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	430	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	431	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	432	 1	 65.1	 1.4	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	433	 1	 82.9	 54.3	 0.0	 0.0	 1	    1.01333	    0.00000	 225.0	 1	    1.04444	    0.98222;
	434	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	435	 1	 110.0	 -8.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	436	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	437	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 225.0	 1	    1.15556	    0.88889;
	438	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02222	    0.00000	 225.0	 1	    1.15556	    0.88889;
	439	 1	 59.2	 -11.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	2020	 1	 0.0	 0.0	 0.0	 -64.0	 1	    1.02064	    0.00000	 20.0	 1	    1.05000	    0.99128;
	440	 1	 84.4	 -24.6	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	441	 1	 91.2	 6.1	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	442	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	443	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10526	    1.05263;
	444	 1	 59.8	 8.6	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	445	 1	 25.8	 1.1	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	446	 1	 18.6	 6.2	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	447	 1	 3.3	 0.6	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	448	 1	 126.9	 4.6	 0.0	 0.0	 1	    1.01761	    0.00000	 225.0	 1	    1.08522	    0.95000;
	449	 1	 4.1	 -16.5	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	450	 1	 40.9	 3.2	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	451	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	452	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	453	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	454	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	455	 1	 42.8	 6.6	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	456	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	458	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	459	 1	 99.1	 5.3	 0.0	 0.0	 1	    1.02889	    0.00000	 225.0	 1	    1.08889	    0.96889;
	460	 1	 24.2	 14.3	 0.0	 0.0	 1	    1.01333	    0.00000	 225.0	 1	    1.04444	    0.98222;
	2033	 1	 0.0	 0.0	 0.0	 -64.0	 1	    0.99330	    0.00000	 20.0	 1	    1.05000	    0.93660;
	461	 1	 84.1	 -55.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	462	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	463	 1	 31.5	 -6.1	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	464	 1	 148.6	 11.4	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	465	 1	 2.0	 -3.9	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	466	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	467	 1	 8.4	 -7.4	 0.0	 0.0	 1	    1.02333	    0.00000	 150.0	 1	    1.08000	    0.96667;
	468	 1	 141.4	 14.3	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	469	 1	 36.6	 6.7	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	470	 1	 22.9	 3.4	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	471	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01710	    0.00000	 225.0	 1	    1.08421	    0.95000;
	472	 1	 27.9	 -0.6	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	473	 1	 177.2	 7.1	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	474	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01533	    0.00000	 225.0	 1	    1.08067	    0.95000;
	475	 1	 -10.3	 -2.6	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1832	 1	 1.8	 -7.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	476	 1	 64.9	 12.4	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	477	 1	 89.6	 -2.1	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	478	 1	 58.5	 -1.2	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	479	 1	 159.0	 16.1	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	480	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07469	    0.00000	 380.0	 1	    1.10992	    1.03947;
	481	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07469	    0.00000	 380.0	 1	    1.10992	    1.03947;
	482	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04228	    0.00000	 225.0	 1	    1.09790	    0.98667;
	483	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04228	    0.00000	 225.0	 1	    1.09790	    0.98667;
	484	 1	 37.7	 8.8	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	485	 1	 28.7	 -15.2	 0.0	 0.0	 1	    1.04523	    0.00000	 225.0	 1	    1.08889	    1.00158;
	486	 1	 41.1	 4.0	 0.0	 0.0	 1	    1.04523	    0.00000	 225.0	 1	    1.08889	    1.00158;
	487	 1	 27.9	 -4.6	 0.0	 0.0	 1	    1.04523	    0.00000	 225.0	 1	    1.08889	    1.00158;
	488	 1	 37.4	 1.0	 0.0	 0.0	 1	    1.04523	    0.00000	 225.0	 1	    1.08889	    1.00158;
	489	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04525	    0.00000	 225.0	 1	    1.08889	    1.00161;
	490	 1	 89.1	 35.7	 0.0	 0.0	 1	    1.01556	    0.00000	 225.0	 1	    1.08889	    0.94222;
	491	 1	 34.1	 3.7	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	492	 1	 37.1	 6.3	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	493	 1	 99.1	 -8.1	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	494	 1	 16.7	 -0.1	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	495	 1	 69.1	 0.9	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	496	 1	 -0.3	 2.5	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	497	 1	 -0.3	 2.5	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	498	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	499	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	500	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	501	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	502	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	503	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	504	 1	 25.7	 -17.1	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	506	 1	 4.8	 3.6	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	507	 1	 18.4	 -9.8	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	508	 1	 0.3	 -2.3	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	509	 1	 0.3	 -4.2	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	510	 1	 14.6	 12.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	511	 1	 3.8	 -3.3	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	512	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	513	 1	 199.7	 12.7	 0.0	 0.0	 1	    1.04567	    0.00000	 225.0	 1	    1.08690	    1.00444;
	515	 1	 123.1	 27.4	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	516	 1	 84.2	 7.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	517	 1	 149.8	 10.6	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	519	 1	 64.7	 -1.7	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	520	 1	 18.4	 5.7	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	521	 1	 18.6	 1.1	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	522	 1	 23.4	 4.1	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	523	 1	 52.8	 5.5	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	524	 1	 94.3	 11.5	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	525	 1	 79.9	 -5.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	526	 1	 23.7	 -1.2	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	527	 1	 18.7	 -0.2	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	528	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	529	 1	 123.6	 1.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	530	 1	 69.8	 5.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	531	 1	 37.1	 17.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	532	 1	 -11.2	 -3.3	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	533	 1	 62.1	 6.1	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	534	 1	 34.0	 -26.8	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	535	 1	 10.6	 -4.6	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	536	 1	 15.3	 1.5	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	537	 1	 51.9	 9.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	538	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	539	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	540	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	541	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	542	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	544	 1	 107.7	 7.9	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	545	 1	 23.0	 -4.2	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	546	 1	 70.1	 2.1	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	547	 1	 37.1	 -0.2	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	548	 1	 24.9	 1.7	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	549	 1	 52.1	 5.9	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	550	 1	 38.1	 -11.2	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	2021	 1	 0.0	 0.0	 0.0	 -64.0	 1	    1.15000	    0.00000	 20.0	 1	    1.40000	    0.90000;
	551	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	553	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10526	    1.05263;
	554	 1	 86.2	 -22.3	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	555	 1	 26.1	 46.7	 0.0	 0.0	 1	    1.01556	    0.00000	 225.0	 1	    1.08889	    0.94222;
	556	 1	 197.1	 -2.9	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	557	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	558	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	559	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	560	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	561	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	562	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	563	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	564	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	565	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	566	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	567	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	568	 1	 103.3	 16.9	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	569	 1	 182.2	 -4.5	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	570	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	572	 1	 12.7	 -1.1	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	573	 1	 14.5	 0.6	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	574	 1	 86.6	 -8.2	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	575	 1	 93.3	 33.6	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	576	 1	 -11.2	 -3.5	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10526	    1.05263;
	577	 1	 2.9	 -7.5	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10526	    1.05263;
	578	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04596	    0.00000	 225.0	 1	    1.09192	    1.00000;
	579	 1	 0.1	 -8.5	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	580	 1	 71.3	 -22.5	 0.0	 0.0	 1	    1.04465	    0.00000	 225.0	 1	    1.08930	    1.00000;
	581	 1	 21.9	 -5.4	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	582	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01149	    0.00000	 150.0	 1	    1.12298	    0.90000;
	583	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	584	 1	 128.9	 5.3	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	585	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	586	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	587	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	588	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	589	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	590	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	591	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	592	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	593	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	594	 1	 2.0	 -9.4	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	595	 1	 151.1	 -0.1	 0.0	 0.0	 1	    1.00264	    0.00000	 63.0	 1	    1.06878	    0.93651;
	596	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	597	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	598	 1	 76.2	 3.8	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	599	 1	 45.9	 -15.2	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	600	 1	 32.4	 -7.8	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	601	 1	 110.7	 11.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	2015	 1	 0.0	 0.0	 0.0	 -64.0	 1	    1.15000	    0.00000	 20.0	 1	    1.40000	    0.90000;
	602	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	603	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	604	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 225.0	 1	    1.08889	    0.91111;
	605	 1	 61.5	 16.8	 0.0	 0.0	 1	    1.00000	    0.00000	 225.0	 1	    1.08889	    0.91111;
	606	 1	 91.6	 2.7	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	607	 1	 128.1	 5.6	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	608	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	609	 1	 97.1	 -16.3	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	610	 1	 98.3	 -14.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	611	 1	 40.3	 -0.5	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	612	 1	 41.2	 -1.5	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	613	 1	 43.2	 6.2	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	614	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02667	    0.00000	 150.0	 1	    1.10667	    0.94667;
	615	 1	 59.7	 5.1	 0.0	 0.0	 1	    1.02222	    0.00000	 225.0	 1	    1.08889	    0.95556;
	616	 1	 50.6	 11.4	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	617	 1	 21.0	 6.5	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	618	 1	 409.4	 101.8	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	619	 1	 20.6	 -40.2	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	620	 1	 -1.8	 4.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	621	 1	 0.9	 3.4	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	622	 1	 97.2	 9.6	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	623	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	624	 1	 42.8	 -0.4	 0.0	 0.0	 1	    1.04681	    0.00000	 225.0	 1	    1.08918	    1.00444;
	625	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	626	 1	 102.9	 4.3	 0.0	 0.0	 1	    1.02889	    0.00000	 225.0	 1	    1.08889	    0.96889;
	627	 1	 44.1	 49.5	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	628	 1	 43.9	 60.5	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	629	 1	 20.1	 3.1	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	630	 1	 33.4	 2.3	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	631	 1	 17.9	 -0.2	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	632	 1	 71.2	 0.7	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	633	 1	 8.3	 2.3	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	635	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	637	 1	 -2.8	 2.5	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	638	 1	 9.8	 0.5	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	639	 1	 15.9	 6.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	640	 1	 66.6	 4.9	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	641	 1	 53.7	 -8.9	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	642	 1	 40.7	 -0.7	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	643	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	644	 1	 56.4	 18.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	645	 1	 2.3	 -4.2	 0.0	 0.0	 1	    1.07002	    0.00000	 380.0	 1	    1.10526	    1.03478;
	646	 1	 27.1	 9.6	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	647	 1	 60.6	 -7.1	 0.0	 0.0	 1	    1.02889	    0.00000	 225.0	 1	    1.08889	    0.96889;
	648	 1	 2.0	 1.6	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	649	 1	 0.0	 -0.7	 0.0	 0.0	 1	    0.83000	    0.00000	 150.0	 1	    1.00000	    0.66000;
	650	 1	 27.8	 -20.7	 0.0	 0.0	 1	    1.04581	    0.00000	 225.0	 1	    1.09162	    1.00000;
	651	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	652	 1	 19.3	 -1.2	 0.0	 0.0	 1	    1.04775	    0.00000	 225.0	 1	    1.09550	    1.00000;
	653	 1	 95.3	 13.6	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	654	 1	 57.4	 -4.3	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	655	 1	 25.3	 2.0	 0.0	 0.0	 1	    1.04692	    0.00000	 225.0	 1	    1.08939	    1.00444;
	656	 1	 23.8	 1.8	 0.0	 0.0	 1	    1.04692	    0.00000	 225.0	 1	    1.08939	    1.00444;
	657	 1	 12.2	 4.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	658	 1	 98.7	 -12.4	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	659	 1	 -0.0	 -0.0	 0.0	 0.0	 1	    1.04008	    0.00000	 225.0	 1	    1.09349	    0.98667;
	660	 1	 103.9	 3.7	 0.0	 0.0	 1	    1.00667	    0.00000	 225.0	 1	    1.08889	    0.92444;
	662	 1	 -73.5	 -35.5	 0.0	 0.0	 1	    1.01333	    0.00000	 225.0	 1	    1.04444	    0.98222;
	663	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01333	    0.00000	 225.0	 1	    1.04444	    0.98222;
	664	 1	 43.6	 20.3	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	665	 1	 78.3	 11.9	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10526	    1.05263;
	666	 1	 92.8	 -9.9	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	667	 1	 76.1	 10.9	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	668	 1	 42.6	 -1.3	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	669	 1	 44.5	 3.1	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	670	 1	 134.1	 -13.3	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	671	 1	 31.1	 7.5	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	672	 1	 22.0	 -0.6	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	673	 1	 38.9	 6.9	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	674	 1	 188.3	 15.5	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	675	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07515	    0.00000	 380.0	 1	    1.10263	    1.04767;
	676	 1	 119.6	 -5.6	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	677	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	678	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	679	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	680	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00321	    0.00000	 150.0	 1	    1.10642	    0.90000;
	681	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	682	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	683	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	684	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	685	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	686	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	687	 1	 52.6	 0.4	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	690	 1	 7.7	 5.6	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	691	 1	 11.4	 5.8	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	692	 1	 3.4	 -2.3	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	693	 1	 6.7	 -2.9	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	694	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	695	 1	 51.1	 -7.6	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	696	 1	 56.1	 1.4	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	697	 1	 33.2	 13.8	 0.0	 0.0	 1	    1.03942	    0.00000	 225.0	 1	    1.09218	    0.98667;
	698	 1	 179.2	 26.4	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	699	 1	 30.5	 1.3	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	700	 1	 66.4	 7.3	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	701	 1	 -13.4	 -22.0	 0.0	 0.0	 1	    1.00517	    0.00000	 150.0	 1	    1.11033	    0.90000;
	702	 1	 67.8	 -6.3	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	703	 1	 25.8	 2.2	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	704	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	705	 1	 247.2	 26.7	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	707	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 225.0	 1	    1.10000	    0.90000;
	708	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1833	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	709	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	710	 1	 11.3	 24.4	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	711	 1	 145.6	 -55.6	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	712	 1	 159.8	 -47.4	 0.0	 0.0	 1	    1.04615	    0.00000	 225.0	 1	    1.08787	    1.00444;
	713	 1	 112.0	 18.8	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	715	 1	 103.4	 -12.1	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	716	 1	 18.1	 -2.2	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	717	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04551	    0.00000	 225.0	 1	    1.09102	    1.00000;
	718	 1	 112.5	 12.8	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	719	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10526	    1.05263;
	720	 1	 11.1	 6.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	721	 1	 11.0	 3.8	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	722	 1	 0.0	 -0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	723	 1	 15.4	 1.8	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	724	 1	 28.7	 3.9	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	725	 1	 23.1	 4.6	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	726	 1	 42.3	 1.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	727	 1	 3.7	 -10.5	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	728	 1	 78.8	 17.5	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	729	 1	 31.1	 17.2	 0.0	 0.0	 1	    1.02333	    0.00000	 150.0	 1	    1.08000	    0.96667;
	730	 1	 72.1	 -16.6	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	731	 1	 109.4	 -16.3	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	732	 1	 145.8	 22.5	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	733	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	734	 1	 112.6	 -11.7	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	735	 1	 29.6	 8.3	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	736	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00334	    0.00000	 150.0	 1	    1.10667	    0.90000;
	737	 1	 20.8	 -8.2	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	738	 1	 142.1	 6.2	 0.0	 0.0	 1	    1.02889	    0.00000	 225.0	 1	    1.08889	    0.96889;
	739	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	740	 1	 116.6	 -35.3	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	741	 1	 170.6	 10.8	 0.0	 0.0	 1	    1.02989	    0.00000	 90.0	 1	    1.08201	    0.97778;
	742	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	743	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	744	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	745	 1	 35.6	 -8.4	 0.0	 0.0	 1	    1.02889	    0.00000	 225.0	 1	    1.08889	    0.96889;
	746	 1	 93.0	 6.3	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	747	 1	 8.0	 -0.5	 0.0	 0.0	 1	    1.00405	    0.00000	 20.0	 1	    1.10810	    0.90000;
	748	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00396	    0.00000	 150.0	 1	    1.10792	    0.90000;
	750	 1	 25.5	 -5.1	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	751	 1	 3.0	 -2.6	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	752	 1	 63.3	 2.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	753	 1	 4.8	 1.5	 0.0	 0.0	 1	    1.01614	    0.00000	 150.0	 1	    1.13227	    0.90000;
	754	 1	 113.7	 1.1	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	755	 1	 13.5	 8.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	756	 1	 31.1	 3.4	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	757	 1	 55.0	 -7.2	 0.0	 0.0	 1	    1.03796	    0.00000	 225.0	 1	    1.08926	    0.98667;
	758	 1	 61.9	 10.1	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	759	 1	 20.7	 8.2	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	760	 1	 100.0	 14.1	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	761	 1	 211.1	 3.6	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	762	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	2052	 1	 0.0	 0.0	 0.0	 -64.0	 1	    1.15000	    0.00000	 20.0	 1	    1.40000	    0.90000;
	763	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	764	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	765	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	766	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	767	 1	 86.7	 -28.4	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	768	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	769	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	770	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04579	    0.00000	 225.0	 1	    1.09158	    1.00000;
	771	 1	 55.8	 -10.6	 0.0	 0.0	 1	    1.01153	    0.00000	 225.0	 1	    1.08972	    0.93333;
	772	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	774	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	2016	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98753	    0.00000	 20.0	 1	    1.05000	    0.92505;
	775	 1	 29.8	 -7.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	776	 1	 184.2	 -16.3	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	777	 1	 37.5	 6.5	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	778	 1	 19.0	 -6.4	 0.0	 0.0	 1	    1.03855	    0.00000	 225.0	 1	    1.09044	    0.98667;
	779	 1	 81.9	 -27.9	 0.0	 0.0	 1	    1.01309	    0.00000	 63.0	 1	    1.10555	    0.92063;
	780	 1	 102.1	 11.4	 0.0	 0.0	 1	    1.01309	    0.00000	 63.0	 1	    1.10555	    0.92063;
	783	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04659	    0.00000	 225.0	 1	    1.09318	    1.00000;
	784	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07642	    0.00000	 380.0	 1	    1.10526	    1.04758;
	2043	 1	 0.0	 0.0	 0.0	 -64.0	 1	    1.01505	    0.00000	 20.0	 1	    1.05000	    0.98010;
	2059	 1	 0.0	 0.0	 0.0	 -64.0	 1	    1.01505	    0.00000	 20.0	 1	    1.05000	    0.98010;
	785	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	786	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	787	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	788	 1	 150.5	 2.4	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	789	 1	 72.5	 -0.8	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	790	 1	 56.0	 -3.7	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	791	 1	 1.9	 -0.3	 0.0	 0.0	 1	    1.02222	    0.00000	 225.0	 1	    1.08889	    0.95556;
	792	 1	 72.2	 1.6	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	793	 1	 56.3	 12.8	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	794	 1	 80.6	 -23.4	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	795	 1	 76.2	 31.8	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	796	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03961	    0.00000	 225.0	 1	    1.09255	    0.98667;
	797	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03961	    0.00000	 225.0	 1	    1.09255	    0.98667;
	798	 1	 52.8	 5.6	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	799	 1	 32.1	 9.5	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	800	 1	 10.5	 -2.7	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	801	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.99009	    0.00000	 225.0	 1	    1.09130	    0.88889;
	802	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	803	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01288	    0.00000	 225.0	 1	    1.07577	    0.95000;
	804	 1	 25.1	 -4.5	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	805	 1	 0.0	 0.0	 0.0	 -214.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	806	 1	 25.7	 8.3	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	807	 1	 23.0	 10.3	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	808	 1	 -1.4	 -20.3	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	809	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04496	    0.00000	 225.0	 1	    1.08992	    1.00000;
	810	 1	 75.9	 4.7	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	811	 1	 4.0	 -3.1	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	812	 1	 42.8	 -3.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	2063	 1	 0.0	 0.0	 0.0	 -58.0	 1	    1.15000	    0.00000	 20.0	 1	    1.40000	    0.90000;
	2064	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.15000	    0.00000	 20.0	 1	    1.40000	    0.90000;
	813	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	814	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	815	 1	 -0.0	 0.0	 0.0	 0.0	 1	    1.00439	    0.00000	 150.0	 1	    1.10877	    0.90000;
	816	 1	 -5.8	 2.5	 0.0	 0.0	 1	    1.04762	    0.00000	 225.0	 1	    1.09524	    1.00000;
	817	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00423	    0.00000	 150.0	 1	    1.10847	    0.90000;
	818	 1	 54.7	 -10.5	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	819	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	820	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	821	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	822	 1	 37.6	 -6.8	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	823	 1	 37.8	 2.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	824	 1	 33.8	 3.5	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	825	 1	 85.4	 8.3	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	826	 1	 -0.2	 -1.4	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	827	 1	 75.5	 -14.0	 0.0	 0.0	 1	    1.04574	    0.00000	 225.0	 1	    1.09148	    1.00000;
	829	 1	 82.0	 -14.8	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	830	 1	 58.2	 8.2	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	831	 1	 57.8	 18.8	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	832	 1	 2.3	 2.1	 0.0	 0.0	 1	    1.00422	    0.00000	 150.0	 1	    1.10844	    0.90000;
	833	 1	 14.9	 -0.4	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	834	 1	 10.2	 -8.2	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2065	 1	 0.0	 0.0	 0.0	 -60.0	 1	    1.15000	    0.00000	 20.0	 1	    1.40000	    0.90000;
	2078	 1	 0.0	 0.0	 0.0	 -60.0	 1	    1.15000	    0.00000	 20.0	 1	    1.40000	    0.90000;
	835	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	836	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	837	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	838	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07116	    0.00000	 380.0	 1	    1.10526	    1.03706;
	839	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07116	    0.00000	 380.0	 1	    1.10526	    1.03706;
	840	 1	 113.3	 -2.7	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	841	 1	 85.1	 6.4	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	842	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	843	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	844	 1	 101.6	 19.4	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	845	 1	 146.0	 3.9	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	846	 1	 223.4	 -22.0	 0.0	 0.0	 1	    1.04689	    0.00000	 225.0	 1	    1.09377	    1.00000;
	847	 1	 39.1	 0.1	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	848	 1	 86.8	 -12.0	 0.0	 -80.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	849	 1	 66.8	 2.5	 0.0	 0.0	 1	    1.03867	    0.00000	 225.0	 1	    1.09068	    0.98667;
	851	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	853	 1	 76.2	 30.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	2036	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.15000	    0.00000	 20.0	 1	    1.40000	    0.90000;
	2037	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.15000	    0.00000	 20.0	 1	    1.40000	    0.90000;
	854	 1	 72.3	 5.8	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	857	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10526	    1.05263;
	858	 1	 -1.2	 2.4	 0.0	 0.0	 1	    1.01931	    0.00000	 225.0	 1	    1.08861	    0.95000;
	859	 1	 32.0	 -3.6	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	860	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	861	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	862	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.08006	    0.00000	 380.0	 1	    1.10780	    1.05233;
	863	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.08003	    0.00000	 380.0	 1	    1.10791	    1.05214;
	864	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.08003	    0.00000	 380.0	 1	    1.10791	    1.05214;
	865	 1	 99.3	 9.3	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	866	 1	 39.9	 -4.8	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	867	 1	 32.8	 -2.8	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	868	 1	 81.3	 -2.9	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	869	 1	 54.3	 0.5	 0.0	 0.0	 1	    1.04073	    0.00000	 225.0	 1	    1.09480	    0.98667;
	870	 1	 131.9	 12.9	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	871	 1	 17.3	 -5.8	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	872	 1	 51.2	 -3.1	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	873	 1	 26.1	 3.4	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	874	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	875	 1	 49.7	 -11.8	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	876	 1	 -2.2	 -1.4	 0.0	 0.0	 1	    1.01811	    0.00000	 225.0	 1	    1.08623	    0.95000;
	877	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	878	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	880	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	881	 1	 17.5	 27.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	882	 1	 134.5	 4.1	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	883	 1	 29.7	 2.2	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	884	 1	 22.5	 -9.8	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	885	 1	 23.7	 -2.0	 0.0	 0.0	 1	    1.01893	    0.00000	 225.0	 1	    1.08787	    0.95000;
	886	 1	 6.2	 0.6	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	887	 1	 71.0	 12.9	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	888	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	889	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04543	    0.00000	 380.0	 1	    1.10263	    0.98824;
	890	 1	 6.4	 -16.9	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	891	 1	 51.5	 -16.8	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	892	 1	 55.4	 9.7	 0.0	 -80.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	893	 1	 111.1	 -49.1	 0.0	 0.0	 1	    1.05096	    0.00000	 225.0	 1	    1.10192	    1.00000;
	894	 1	 23.0	 2.5	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	895	 1	 17.8	 -1.2	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	896	 1	 94.1	 9.2	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	897	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	898	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	899	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.06579	    0.00000	 380.0	 1	    1.10263	    1.02895;
	900	 1	 -1.6	 -0.7	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	901	 1	 0.7	 0.6	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	902	 1	 21.4	 33.6	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	903	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	904	 1	 74.4	 -7.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	905	 1	 65.6	 8.9	 0.0	 0.0	 1	    0.99556	    0.00000	 225.0	 1	    1.08889	    0.90222;
	906	 1	 4.1	 0.1	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	907	 1	 0.7	 1.3	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	908	 2	 2.1	 0.0	 0.0	 0.0	 1	    1.00439	    0.00000	 150.0	 1	    1.10879	    0.90000;
	909	 1	 62.5	 6.5	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	910	 1	 88.5	 23.8	 0.0	 0.0	 1	    1.04480	    0.00000	 225.0	 1	    1.08889	    1.00072;
	911	 1	 24.8	 -13.4	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	912	 1	 27.2	 3.6	 0.0	 0.0	 1	    1.04683	    0.00000	 225.0	 1	    1.08923	    1.00444;
	913	 1	 20.9	 4.4	 0.0	 0.0	 1	    1.04683	    0.00000	 225.0	 1	    1.08923	    1.00444;
	914	 1	 23.2	 1.9	 0.0	 0.0	 1	    1.04683	    0.00000	 225.0	 1	    1.08923	    1.00444;
	915	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	916	 1	 -1.8	 -0.7	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	917	 1	 28.4	 26.5	 0.0	 0.0	 1	    1.01333	    0.00000	 225.0	 1	    1.04444	    0.98222;
	918	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	919	 1	 106.4	 -4.2	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	920	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	921	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	922	 1	 11.9	 1.8	 0.0	 0.0	 1	    1.04721	    0.00000	 225.0	 1	    1.08998	    1.00444;
	923	 1	 100.6	 8.6	 0.0	 0.0	 1	    1.00222	    0.00000	 225.0	 1	    1.08889	    0.91556;
	924	 1	 41.2	 3.9	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	925	 1	 79.1	 2.3	 0.0	 0.0	 1	    1.04757	    0.00000	 225.0	 1	    1.09070	    1.00444;
	926	 1	 -4.1	 -1.6	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	927	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	928	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	929	 1	 32.6	 5.4	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	930	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04153	    0.00000	 225.0	 1	    1.09639	    0.98667;
	931	 1	 76.3	 21.8	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	932	 1	 8.5	 0.2	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	933	 1	 193.5	 28.4	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	934	 1	 0.0	 -0.2	 0.0	 0.0	 1	    1.07730	    0.00000	 380.0	 1	    1.11249	    1.04211;
	935	 1	 33.8	 17.9	 0.0	 0.0	 1	    1.07730	    0.00000	 380.0	 1	    1.11249	    1.04211;
	936	 1	 3.6	 -5.2	 0.0	 0.0	 1	    1.07730	    0.00000	 380.0	 1	    1.11249	    1.04211;
	937	 1	 29.1	 15.2	 0.0	 0.0	 1	    1.07730	    0.00000	 380.0	 1	    1.11249	    1.04211;
	938	 1	 174.4	 9.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	939	 1	 0.1	 0.3	 0.0	 0.0	 1	    1.04524	    0.00000	 225.0	 1	    1.08604	    1.00444;
	940	 1	 4.8	 4.0	 0.0	 0.0	 1	    1.04524	    0.00000	 225.0	 1	    1.08604	    1.00444;
	941	 1	 47.8	 3.4	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	942	 1	 35.4	 6.3	 0.0	 0.0	 1	    1.04427	    0.00000	 225.0	 1	    1.08889	    0.99965;
	943	 1	 86.3	 8.3	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	944	 1	 67.9	 9.6	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	945	 1	 21.4	 -16.2	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	946	 1	 68.1	 -0.8	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	947	 1	 87.0	 -0.1	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	948	 1	 0.0	 -4.3	 0.0	 0.0	 1	    1.03949	    0.00000	 225.0	 1	    1.09232	    0.98667;
	949	 1	 12.4	 -3.3	 0.0	 0.0	 1	    1.07048	    0.00000	 380.0	 1	    1.10526	    1.03570;
	950	 1	 122.1	 -16.7	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	951	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07418	    0.00000	 380.0	 1	    1.10626	    1.04211;
	952	 1	 -27.2	 -7.6	 0.0	 0.0	 1	    1.07418	    0.00000	 380.0	 1	    1.10626	    1.04211;
	953	 1	 101.1	 -8.5	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	954	 1	 24.6	 -5.3	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	955	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	956	 1	 20.3	 -0.9	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	957	 1	 52.5	 0.8	 0.0	 0.0	 1	    1.02445	    0.00000	 225.0	 1	    1.08889	    0.96000;
	958	 1	 210.6	 25.4	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	959	 1	 65.1	 4.1	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	960	 1	 4.8	 0.9	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	961	 1	 -9.1	 3.1	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	962	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04690	    0.00000	 225.0	 1	    1.08935	    1.00444;
	963	 1	 118.0	 -7.9	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10526	    1.05263;
	964	 1	 37.4	 -1.4	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	965	 1	 33.0	 -13.3	 0.0	 0.0	 1	    0.95000	    0.00000	 150.0	 1	    1.10000	    0.80000;
	966	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	967	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04544	    0.00000	 380.0	 1	    1.10263	    0.98824;
	968	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	969	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	970	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	971	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	972	 1	 170.4	 23.9	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	973	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01855	    0.00000	 150.0	 1	    1.13710	    0.90000;
	974	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	975	 2	 17.4	 -14.2	 0.0	 0.0	 1	    1.00000	    0.00000	 225.0	 1	    1.10000	    0.90000;
	976	 1	 31.7	 -12.6	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	977	 1	 293.2	 8.6	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	978	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	979	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	980	 1	 89.1	 2.3	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	981	 1	 114.0	 17.8	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	982	 1	 37.4	 1.5	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	983	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.06579	    0.00000	 380.0	 1	    1.10263	    1.02895;
	984	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	985	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	986	 1	 4.7	 1.3	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	987	 1	 37.1	 15.4	 0.0	 0.0	 1	    1.00889	    0.00000	 225.0	 1	    1.08889	    0.92889;
	988	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	989	 1	 44.0	 2.4	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	990	 1	 154.9	 24.4	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	991	 1	 125.5	 14.7	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	992	 1	 65.5	 -2.5	 0.0	 0.0	 1	    1.03960	    0.00000	 225.0	 1	    1.09254	    0.98667;
	993	 1	 24.6	 -0.1	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	994	 1	 24.7	 -8.6	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	995	 1	 71.3	 13.5	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	996	 1	 67.0	 -7.8	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	997	 1	 34.9	 9.3	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	998	 1	 16.4	 19.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	999	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	1000	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	1001	 1	 7.8	 5.7	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1002	 1	 1.6	 1.5	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1003	 1	 15.8	 -12.6	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	1004	 1	 33.2	 -6.9	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	1005	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00521	    0.00000	 150.0	 1	    1.11042	    0.90000;
	1006	 1	 10.9	 -4.2	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1007	 1	 46.6	 -5.4	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	1008	 1	 8.9	 -0.3	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	1010	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1011	 1	 49.0	 4.6	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	2053	 1	 0.0	 0.0	 0.0	 -60.0	 1	    1.15000	    0.00000	 20.0	 1	    1.40000	    0.90000;
	2054	 1	 0.0	 0.0	 0.0	 -60.0	 1	    1.15000	    0.00000	 20.0	 1	    1.40000	    0.90000;
	1012	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1013	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1014	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1015	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1017	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07122	    0.00000	 380.0	 1	    1.10526	    1.03718;
	1018	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07122	    0.00000	 380.0	 1	    1.10526	    1.03718;
	1021	 1	 112.7	 15.3	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	1022	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	1023	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07188	    0.00000	 380.0	 1	    1.10263	    1.04114;
	1024	 1	 135.0	 23.1	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1025	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1026	 1	 35.7	 -0.9	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1027	 1	 86.2	 3.2	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	1028	 1	 106.1	 107.2	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1029	 1	 39.1	 12.2	 0.0	 0.0	 1	    1.03924	    0.00000	 225.0	 1	    1.09182	    0.98667;
	1030	 1	 125.1	 6.6	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	1031	 1	 121.7	 5.8	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	1032	 1	 72.7	 -10.0	 0.0	 0.0	 1	    1.00667	    0.00000	 225.0	 1	    1.08889	    0.92444;
	1033	 1	 125.9	 13.2	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1035	 1	 244.5	 11.4	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1036	 1	 17.7	 4.6	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1037	 1	 9.1	 3.1	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1038	 1	 88.1	 47.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1834	 1	 -1.5	 -2.8	 0.0	 0.0	 1	    1.03787	    0.00000	 225.0	 1	    1.08907	    0.98667;
	1039	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	1040	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04482	    0.00000	 225.0	 1	    1.08519	    1.00444;
	1041	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	1042	 1	 49.1	 3.5	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1043	 1	 106.6	 -8.1	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1044	 1	 99.0	 9.3	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	1045	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	1046	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	1047	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	1048	 1	 14.7	 -13.0	 0.0	 0.0	 1	    1.00450	    0.00000	 150.0	 1	    1.10901	    0.90000;
	1049	 1	 -5.2	 -9.5	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1050	 1	 85.1	 -25.1	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1051	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	1052	 1	 150.5	 9.7	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	1053	 1	 39.6	 3.8	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	1054	 1	 79.1	 21.5	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1055	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	1056	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.06579	    0.00000	 380.0	 1	    1.10263	    1.02895;
	1057	 1	 20.5	 -3.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	1058	 1	 37.0	 4.9	 0.0	 0.0	 1	    0.98957	    0.00000	 225.0	 1	    1.09025	    0.88889;
	1059	 1	 169.5	 22.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1060	 1	 20.4	 -3.5	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	1061	 1	 3.5	 2.6	 0.0	 0.0	 1	    1.04091	    0.00000	 225.0	 1	    1.09515	    0.98667;
	1062	 1	 184.5	 10.5	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	1064	 1	 22.8	 11.2	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	1065	 1	 19.7	 -13.8	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	1066	 1	 52.7	 27.3	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	1067	 1	 1.5	 -1.2	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1068	 1	 4.1	 0.8	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	1069	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04323	    0.00000	 225.0	 1	    1.08444	    1.00202;
	1070	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04323	    0.00000	 225.0	 1	    1.08444	    1.00202;
	1071	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	1072	 1	 11.5	 1.9	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	1073	 1	 0.5	 -0.8	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1074	 1	 13.2	 -0.2	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1075	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	1076	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	1077	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	1078	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	1079	 1	 86.3	 -15.1	 0.0	 0.0	 1	    1.04103	    0.00000	 225.0	 1	    1.09539	    0.98667;
	1080	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07092	    0.00000	 380.0	 1	    1.10526	    1.03658;
	1081	 1	 18.8	 -13.6	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1082	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1083	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1084	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1085	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1086	 1	 27.0	 -5.1	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1087	 1	 16.8	 1.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1088	 1	 38.1	 8.6	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1089	 1	 45.7	 -16.5	 0.0	 0.0	 1	    1.04170	    0.00000	 225.0	 1	    1.09673	    0.98667;
	1090	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	1092	 1	 45.6	 2.6	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1093	 1	 55.0	 -2.2	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	1095	 1	 59.4	 -8.5	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1096	 1	 119.0	 -0.4	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1097	 1	 31.1	 -1.4	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1098	 1	 24.1	 -0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1099	 1	 30.1	 10.9	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	1100	 1	 3.7	 5.2	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1101	 1	 75.6	 -5.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	1103	 1	 35.6	 -9.6	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1104	 1	 62.2	 28.5	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1105	 1	 30.1	 -1.1	 0.0	 -80.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1106	 1	 22.1	 -10.8	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1107	 1	 93.5	 10.1	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	1108	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1109	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1110	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	1112	 1	 10.5	 14.6	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	1113	 1	 -0.7	 5.3	 0.0	 0.0	 1	    1.02333	    0.00000	 150.0	 1	    1.08000	    0.96667;
	1114	 1	 11.0	 -2.6	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	1115	 1	 124.8	 6.9	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1116	 1	 23.3	 -2.5	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1117	 1	 17.5	 -0.7	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1118	 1	 78.0	 7.9	 0.0	 0.0	 1	    1.01384	    0.00000	 225.0	 1	    1.07769	    0.95000;
	1119	 1	 37.5	 -25.1	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1120	 1	 -2.3	 -1.3	 0.0	 0.0	 1	    1.02333	    0.00000	 150.0	 1	    1.08000	    0.96667;
	1121	 1	 132.9	 17.8	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	1123	 1	 41.9	 -5.4	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1124	 1	 31.2	 -5.3	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	2048	 1	 0.0	 0.0	 0.0	 -64.0	 1	    1.15000	    0.00000	 20.0	 1	    1.40000	    0.90000;
	1125	 1	 26.7	 -4.5	 0.0	 0.0	 1	    1.04570	    0.00000	 225.0	 1	    1.09140	    1.00000;
	1126	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07930	    0.00000	 380.0	 1	    1.10597	    1.05263;
	1127	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1128	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	1129	 1	 4.8	 3.3	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1130	 1	 26.4	 5.4	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1131	 1	 59.6	 20.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1132	 1	 14.0	 4.1	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1133	 1	 0.3	 -0.9	 0.0	 0.0	 1	    1.04748	    0.00000	 225.0	 1	    1.09053	    1.00444;
	1134	 1	 5.8	 -0.3	 0.0	 0.0	 1	    1.04748	    0.00000	 225.0	 1	    1.09053	    1.00444;
	1135	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1136	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1137	 1	 92.0	 15.6	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1138	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1139	 1	 -19.4	 -20.7	 0.0	 0.0	 1	    1.03972	    0.00000	 225.0	 1	    1.09277	    0.98667;
	1140	 1	 81.6	 -2.2	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1141	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	1142	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	1143	 1	 59.7	 6.9	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1144	 1	 141.0	 9.4	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1145	 1	 40.2	 10.9	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1146	 1	 63.5	 22.1	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1147	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04612	    0.00000	 225.0	 1	    1.09224	    1.00000;
	1148	 1	 1.9	 -7.8	 0.0	 0.0	 1	    1.03796	    0.00000	 225.0	 1	    1.08925	    0.98667;
	1149	 1	 99.5	 -9.7	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1150	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10526	    1.05263;
	1151	 1	 15.8	 3.1	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1152	 1	 72.1	 16.8	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1153	 1	 24.6	 0.2	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	1154	 1	 54.1	 -2.6	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1155	 1	 9.3	 -14.8	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	2049	 1	 0.0	 0.0	 0.0	 -58.0	 1	    1.15000	    0.00000	 20.0	 1	    1.40000	    0.90000;
	1156	 1	 32.1	 5.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1157	 1	 9.3	 -3.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1158	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.06945	    0.00000	 380.0	 1	    1.10526	    1.03364;
	1159	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1160	 1	 4.9	 -0.5	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1161	 1	 11.7	 -13.7	 0.0	 0.0	 1	    1.01284	    0.00000	 225.0	 1	    1.09235	    0.93333;
	1162	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1163	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	1164	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1165	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1166	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1167	 1	 18.9	 7.6	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1168	 1	 54.4	 8.5	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1169	 1	 14.6	 1.1	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1170	 1	 118.2	 16.2	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	1171	 1	 18.3	 0.3	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1172	 1	 51.8	 10.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	2038	 1	 0.0	 0.0	 0.0	 -64.0	 1	    1.15000	    0.00000	 20.0	 1	    1.40000	    0.90000;
	1173	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1174	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	1175	 1	 21.9	 5.5	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1176	 1	 67.6	 4.3	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1177	 1	 38.9	 5.2	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	1178	 1	 48.8	 5.4	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1179	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1180	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	1181	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	1182	 1	 9.3	 -4.3	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1183	 1	 152.2	 -34.1	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	1184	 1	 43.4	 -5.9	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	1185	 1	 144.2	 5.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1186	 1	 0.2	 -3.8	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1187	 1	 0.3	 -1.4	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1188	 1	 47.9	 -1.8	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1189	 1	 98.9	 -10.8	 0.0	 0.0	 1	    1.02889	    0.00000	 225.0	 1	    1.08889	    0.96889;
	1190	 1	 61.7	 -33.7	 0.0	 0.0	 1	    1.04538	    0.00000	 225.0	 1	    1.08632	    1.00444;
	1191	 1	 6.8	 6.5	 0.0	 0.0	 1	    1.00351	    0.00000	 150.0	 1	    1.10701	    0.90000;
	1192	 1	 12.9	 2.1	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1193	 1	 125.9	 9.4	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	1194	 1	 2.9	 -1.1	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	1195	 1	 2.9	 -1.2	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	1835	 1	 35.6	 -10.5	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1836	 1	 52.8	 4.7	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1196	 1	 11.9	 -1.6	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1197	 1	 94.2	 3.8	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1198	 1	 79.1	 14.1	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	1199	 1	 185.8	 19.7	 0.0	 0.0	 1	    1.04198	    0.00000	 225.0	 1	    1.09730	    0.98667;
	1200	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07458	    0.00000	 380.0	 1	    1.10969	    1.03947;
	1201	 1	 15.7	 0.2	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	1202	 1	 66.6	 6.5	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1203	 1	 24.3	 -2.7	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1204	 1	 12.4	 0.8	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1205	 1	 53.9	 -5.7	 0.0	 0.0	 1	    1.04680	    0.00000	 225.0	 1	    1.08917	    1.00444;
	1206	 1	 133.9	 19.8	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	1207	 1	 28.5	 9.1	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	1208	 1	 105.0	 19.8	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1209	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1210	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	1211	 1	 12.7	 -4.2	 0.0	 0.0	 1	    1.02333	    0.00000	 150.0	 1	    1.08000	    0.96667;
	1212	 1	 1.0	 3.3	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	1213	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	1214	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	2039	 1	 0.0	 0.0	 0.0	 -64.0	 1	    1.15000	    0.00000	 20.0	 1	    1.40000	    0.90000;
	1215	 1	 96.8	 -3.1	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1216	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	1217	 1	 62.3	 6.7	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	1218	 1	 44.3	 -17.5	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1219	 1	 73.8	 6.6	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	1220	 1	 78.7	 -4.4	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	1221	 2	 10.8	 -11.9	 0.0	 0.0	 1	    1.00000	    0.00000	 225.0	 1	    1.10000	    0.90000;
	1222	 1	 104.1	 45.4	 0.0	 0.0	 1	    1.04093	    0.00000	 225.0	 1	    1.09520	    0.98667;
	1223	 1	 82.8	 -2.2	 0.0	 0.0	 1	    1.04093	    0.00000	 225.0	 1	    1.09520	    0.98667;
	1224	 1	 131.5	 1.7	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	1225	 1	 126.4	 26.6	 0.0	 0.0	 1	    1.03961	    0.00000	 225.0	 1	    1.09255	    0.98667;
	1226	 1	 35.6	 1.5	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	1227	 1	 54.5	 1.4	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1228	 1	 21.2	 -2.1	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1229	 1	 77.0	 -5.3	 0.0	 0.0	 1	    1.03799	    0.00000	 225.0	 1	    1.08931	    0.98667;
	1230	 1	 35.4	 6.6	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	1231	 1	 68.0	 -5.5	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1232	 1	 64.4	 11.8	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1233	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04574	    0.00000	 225.0	 1	    1.09148	    1.00000;
	1234	 1	 20.4	 5.4	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1235	 1	 19.1	 0.6	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1236	 1	 84.6	 2.8	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1237	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02738	    0.00000	 150.0	 1	    1.08809	    0.96667;
	1238	 1	 54.3	 -0.7	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	1239	 1	 29.8	 -0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1240	 1	 135.5	 22.4	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1241	 1	 118.9	 2.1	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1242	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	1243	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	1246	 1	 44.7	 -1.8	 0.0	 0.0	 1	    1.02889	    0.00000	 225.0	 1	    1.08889	    0.96889;
	1247	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1248	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1249	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1250	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1251	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1252	 1	 3.1	 -5.0	 0.0	 0.0	 1	    1.03887	    0.00000	 225.0	 1	    1.09108	    0.98667;
	1253	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02333	    0.00000	 150.0	 1	    1.08000	    0.96667;
	1254	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	1255	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01587	    0.00000	 225.0	 1	    1.08174	    0.95000;
	1256	 1	 56.3	 -11.1	 0.0	 0.0	 1	    1.01333	    0.00000	 225.0	 1	    1.08889	    0.93778;
	1257	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02333	    0.00000	 150.0	 1	    1.08000	    0.96667;
	1258	 1	 56.9	 4.6	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	1259	 1	 5.0	 -5.2	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	1260	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	1261	 1	 34.8	 -6.3	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1262	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1263	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07416	    0.00000	 380.0	 1	    1.10526	    1.04306;
	1264	 1	 -0.6	 -11.5	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1265	 1	 28.6	 2.4	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1266	 1	 41.3	 17.9	 0.0	 0.0	 1	    1.04708	    0.00000	 225.0	 1	    1.09416	    1.00000;
	1267	 1	 74.9	 -13.1	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	1268	 2	 115.0	 44.3	 0.0	 0.0	 1	    1.01773	    0.00000	 225.0	 1	    1.08546	    0.95000;
	1269	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	1270	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	1271	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07568	    0.00000	 380.0	 1	    1.10263	    1.04873;
	1272	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	1273	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	1274	 1	 84.8	 17.6	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1275	 1	 42.1	 3.4	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1276	 1	 198.5	 -12.3	 0.0	 0.0	 1	    1.02778	    0.00000	 90.0	 1	    1.07778	    0.97778;
	1277	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	1278	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	1279	 1	 92.3	 14.2	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	1280	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1281	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	1282	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	1285	 1	 250.4	 -0.9	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	1286	 1	 68.7	 -18.8	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1287	 1	 10.9	 -2.8	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1288	 1	 25.6	 4.2	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1289	 1	 161.2	 -7.3	 0.0	 0.0	 1	    1.03014	    0.00000	 90.0	 1	    1.08250	    0.97778;
	1290	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	1291	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	1292	 1	 48.8	 9.1	 0.0	 0.0	 1	    1.04557	    0.00000	 225.0	 1	    1.08889	    1.00226;
	1294	 1	 49.8	 7.8	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1295	 1	 222.5	 12.3	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	1296	 1	 37.1	 -3.9	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1297	 1	 43.1	 -6.8	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	2040	 1	 0.0	 0.0	 0.0	 -54.0	 1	    1.15000	    0.00000	 20.0	 1	    1.40000	    0.90000;
	1298	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1299	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	1300	 1	 36.3	 -18.0	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1301	 1	 116.6	 22.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	1302	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.06579	    0.00000	 380.0	 1	    1.10263	    1.02895;
	1303	 1	 142.0	 23.8	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	1304	 1	 92.0	 17.4	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1305	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	1306	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	1307	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	1308	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03333	    0.00000	 225.0	 1	    1.08889	    0.97778;
	1309	 1	 41.2	 9.1	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1310	 1	 2.0	 2.8	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1311	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	1312	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	1313	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	1314	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	1315	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	1316	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	1317	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	1318	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	1319	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	1320	 3	 0.0	 0.0	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10263	    1.05526;
	1321	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00423	    0.00000	 150.0	 1	    1.10847	    0.90000;
	1322	 1	 107.7	 13.1	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1323	 1	 0.8	 1.2	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1324	 1	 24.7	 6.5	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1838	 1	 7.1	 -1.1	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1325	 1	 29.5	 3.8	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1326	 1	 4.1	 -7.7	 0.0	 0.0	 1	    1.04110	    0.00000	 225.0	 1	    1.09553	    0.98667;
	1327	 1	 26.2	 3.9	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	1328	 1	 4.0	 -2.6	 0.0	 0.0	 1	    1.04469	    0.00000	 225.0	 1	    1.08494	    1.00444;
	1329	 1	 104.5	 6.4	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	1330	 1	 42.6	 12.8	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1331	 1	 22.7	 23.6	 0.0	 0.0	 1	    1.01333	    0.00000	 225.0	 1	    1.04444	    0.98222;
	1332	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1333	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1334	 1	 77.9	 4.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1335	 2	 7.2	 1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1336	 1	 46.0	 -13.2	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	1337	 1	 1.4	 -7.3	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	1338	 1	 80.1	 8.7	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1339	 1	 43.5	 1.8	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1340	 1	 43.5	 -8.1	 0.0	 0.0	 1	    1.04773	    0.00000	 225.0	 1	    1.09103	    1.00444;
	1341	 1	 48.7	 1.5	 0.0	 0.0	 1	    1.04091	    0.00000	 225.0	 1	    1.09515	    0.98667;
	1342	 1	 54.1	 -11.7	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	1343	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.06736	    0.00000	 380.0	 1	    1.10526	    1.02945;
	1344	 1	 100.9	 15.4	 0.0	 0.0	 1	    1.04710	    0.00000	 225.0	 1	    1.08975	    1.00444;
	1345	 1	 36.0	 -16.4	 0.0	 0.0	 1	    1.04710	    0.00000	 225.0	 1	    1.08975	    1.00444;
	1347	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	1348	 1	 48.7	 5.5	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1349	 1	 104.7	 10.6	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1350	 1	 -18.6	 -13.6	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	2055	 1	 0.0	 0.0	 0.0	 -64.0	 1	    1.15000	    0.00000	 20.0	 1	    1.40000	    0.90000;
	1351	 1	 45.2	 -12.6	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1352	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07895	    0.00000	 380.0	 1	    1.10526	    1.05263;
	1353	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	1354	 1	 27.0	 -10.5	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1355	 1	 151.5	 -36.8	 0.0	 0.0	 1	    1.04445	    0.00000	 225.0	 1	    1.08889	    1.00000;
	1356	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01408	    0.00000	 225.0	 1	    1.07815	    0.95000;
	1357	 1	 74.2	 15.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1358	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1359	 1	 80.1	 -23.2	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	1360	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1361	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03947	    0.00000	 380.0	 1	    1.10526	    0.97368;
	1362	 1	 5.9	 0.7	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1363	 1	 29.6	 -10.9	 0.0	 0.0	 1	    1.03909	    0.00000	 225.0	 1	    1.09152	    0.98667;
	1364	 1	 30.1	 -6.1	 0.0	 0.0	 1	    1.03909	    0.00000	 225.0	 1	    1.09152	    0.98667;
	1365	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	1366	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03983	    0.00000	 225.0	 1	    1.09299	    0.98667;
	1367	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	1368	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	1371	 1	 19.3	 -0.1	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1372	 1	 41.3	 10.4	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1373	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 150.0	 1	    1.10000	    0.90000;
	1374	 1	 90.8	 11.8	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1375	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	1376	 1	 88.8	 -2.4	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	1377	 1	 138.9	 9.2	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	1378	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1379	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1380	 1	 50.5	 0.7	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1381	 1	 82.6	 19.3	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1382	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	1383	 1	 32.7	 -18.7	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	2041	 1	 0.0	 0.0	 0.0	 -60.0	 1	    1.15000	    0.00000	 20.0	 1	    1.40000	    0.90000;
	2042	 1	 0.0	 0.0	 0.0	 -58.0	 1	    1.15000	    0.00000	 20.0	 1	    1.40000	    0.90000;
	2060	 1	 0.0	 0.0	 0.0	 -58.0	 1	    1.15000	    0.00000	 20.0	 1	    1.40000	    0.90000;
	2073	 1	 0.0	 0.0	 0.0	 -60.0	 1	    1.15000	    0.00000	 20.0	 1	    1.40000	    0.90000;
	1384	 1	 62.0	 18.7	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1385	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1386	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	1387	 1	 92.1	 -2.7	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	1388	 1	 1.5	 -4.6	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1389	 1	 161.8	 -26.3	 0.0	 0.0	 1	    1.02222	    0.00000	 90.0	 1	    1.06667	    0.97778;
	1390	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	1391	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	2056	 1	 0.0	 0.0	 0.0	 -64.0	 1	    1.15000	    0.00000	 20.0	 1	    1.40000	    0.90000;
	2057	 1	 0.0	 0.0	 0.0	 -56.0	 1	    1.15000	    0.00000	 20.0	 1	    1.40000	    0.90000;
	2079	 1	 0.0	 0.0	 0.0	 -60.0	 1	    1.15000	    0.00000	 20.0	 1	    1.40000	    0.90000;
	1392	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1393	 1	 67.7	 -9.1	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1394	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07063	    0.00000	 380.0	 1	    1.10526	    1.03600;
	1395	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07063	    0.00000	 380.0	 1	    1.10526	    1.03600;
	1397	 1	 45.5	 -4.6	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1398	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1399	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1400	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1402	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1403	 1	 56.3	 0.5	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1404	 1	 34.9	 -4.7	 0.0	 0.0	 1	    1.04356	    0.00000	 225.0	 1	    1.10045	    0.98667;
	1405	 1	 51.1	 14.9	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1406	 1	 65.3	 2.4	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1407	 1	 79.9	 11.4	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1408	 1	 1.5	 1.9	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1409	 1	 -6.6	 -13.1	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1410	 1	 33.6	 -3.3	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1839	 1	 43.9	 0.1	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1411	 1	 92.8	 13.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1412	 1	 170.4	 61.3	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1413	 1	 71.0	 5.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	1414	 1	 1.8	 -11.5	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1415	 1	 0.2	 -5.3	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1416	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	1418	 1	 8.8	 4.5	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1419	 1	 15.0	 2.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1420	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1421	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	1422	 1	 27.2	 10.4	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1423	 1	 15.6	 10.5	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1424	 1	 2.4	 1.2	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1425	 1	 51.2	 6.8	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1840	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1426	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	1427	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04463	    0.00000	 225.0	 1	    1.08482	    1.00444;
	1428	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.99333	    0.00000	 225.0	 1	    1.13333	    0.85333;
	1429	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03764	    0.00000	 150.0	 1	    1.10862	    0.96667;
	1430	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04690	    0.00000	 225.0	 1	    1.08935	    1.00444;
	1431	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04692	    0.00000	 225.0	 1	    1.08941	    1.00444;
	1432	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.99333	    0.00000	 225.0	 1	    1.13333	    0.85333;
	1433	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1434	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.09333	    1.00000;
	1435	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.99333	    0.00000	 225.0	 1	    1.13333	    0.85333;
	1436	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1437	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	1438	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1439	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02333	    0.00000	 150.0	 1	    1.08000	    0.96667;
	1440	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1441	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	1442	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.99224	    0.00000	 225.0	 1	    1.09559	    0.88889;
	1443	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1444	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	1445	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1446	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1447	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1448	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07369	    0.00000	 380.0	 1	    1.10526	    1.04211;
	1449	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00334	    0.00000	 150.0	 1	    1.10667	    0.90000;
	1450	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1451	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1452	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	1453	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	1454	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.09333	    1.00000;
	1455	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1456	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1457	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.99333	    0.00000	 225.0	 1	    1.13333	    0.85333;
	1458	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1459	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1460	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.09333	    1.00000;
	1461	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	1462	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.99333	    0.00000	 225.0	 1	    1.13333	    0.85333;
	1463	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1464	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.09333	    1.00000;
	1465	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1466	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	1467	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1468	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1469	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1470	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1471	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04693	    0.00000	 225.0	 1	    1.08943	    1.00444;
	1472	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1473	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.99130	    0.00000	 225.0	 1	    1.09372	    0.88889;
	1474	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	1475	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	1476	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1477	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1478	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	1479	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1480	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.99333	    0.00000	 225.0	 1	    1.13333	    0.85333;
	1481	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1482	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1483	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1484	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.99119	    0.00000	 225.0	 1	    1.09350	    0.88889;
	1485	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	1486	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1487	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1488	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	1489	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	1490	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1491	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.09333	    1.00000;
	1492	 1	 -6.9	 -0.5	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1493	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.09333	    1.00000;
	1494	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1495	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1496	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1497	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1498	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1499	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98906	    0.00000	 225.0	 1	    1.08923	    0.88889;
	1500	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1501	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98924	    0.00000	 225.0	 1	    1.08960	    0.88889;
	1502	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1503	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	1504	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	1505	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1506	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.09333	    1.00000;
	1507	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03757	    0.00000	 150.0	 1	    1.10847	    0.96667;
	1508	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1509	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1510	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1511	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.03773	    0.00000	 150.0	 1	    1.10879	    0.96667;
	1512	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04719	    0.00000	 225.0	 1	    1.08994	    1.00444;
	1513	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 63.0	 1	    1.07937	    0.92063;
	1514	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.99155	    0.00000	 225.0	 1	    1.09422	    0.88889;
	1515	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	1516	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	1517	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02280	    0.00000	 150.0	 1	    1.06648	    0.97911;
	1518	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.09333	    1.00000;
	1519	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1520	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.99333	    0.00000	 225.0	 1	    1.13333	    0.85333;
	1521	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04480	    0.00000	 225.0	 1	    1.08515	    1.00444;
	1522	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	1523	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1524	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1525	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1526	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1527	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1528	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.02333	    0.00000	 150.0	 1	    1.08000	    0.96667;
	1529	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.99333	    0.00000	 225.0	 1	    1.13333	    0.85333;
	1530	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.99333	    0.00000	 225.0	 1	    1.13333	    0.85333;
	1531	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1532	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	1533	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1534	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04586	    0.00000	 225.0	 1	    1.09172	    1.00000;
	1535	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1536	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08889	    1.00444;
	1537	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	1538	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	1539	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	1540	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1541	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.09333	    1.00000;
	1542	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.09333	    1.00000;
	1543	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1544	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04444	    0.00000	 225.0	 1	    1.08444	    1.00444;
	1545	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.99333	    0.00000	 225.0	 1	    1.13333	    0.85333;
	1546	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07057	    0.00000	 380.0	 1	    1.10263	    1.03851;
	1547	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.04712	    0.00000	 225.0	 1	    1.08980	    1.00444;
	1548	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1549	 1	 0.0	 0.0	 0.0	 0.0	 1	    0.99333	    0.00000	 225.0	 1	    1.13333	    0.85333;
	1551	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.06579	    0.00000	 380.0	 1	    1.10526	    1.02632;
	1552	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05790	    0.00000	 380.0	 1	    1.31579	    0.80000;
	1553	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05790	    0.00000	 380.0	 1	    1.31579	    0.80000;
	1554	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.20000	    0.80000;
	1555	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.18421	    0.92105;
	1556	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07168	    0.00000	 380.0	 1	    1.10526	    1.03811;
	1557	 1	 0.1	 32.1	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	1558	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	1559	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.06579	    0.00000	 380.0	 1	    1.10526	    1.02632;
	1560	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	1561	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07058	    0.00000	 380.0	 1	    1.10263	    1.03854;
	1562	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.06579	    0.00000	 380.0	 1	    1.10526	    1.02632;
	1563	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.18421	    0.92105;
	1564	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	1565	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.20000	    0.80000;
	1566	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05790	    0.00000	 380.0	 1	    1.31579	    0.80000;
	1567	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.18421	    0.92105;
	1568	 1	 -0.0	 -0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	1569	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.20000	    0.80000;
	1570	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.18421	    0.92105;
	1571	 1	 -7.7	 55.7	 0.0	 0.0	 1	    1.06666	    0.00000	 225.0	 1	    1.24444	    0.88889;
	1572	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.06579	    0.00000	 380.0	 1	    1.10526	    1.02632;
	1573	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.20000	    0.80000;
	1574	 1	 0.2	 69.7	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	1575	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.18421	    0.92105;
	1576	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07064	    0.00000	 380.0	 1	    1.10526	    1.03601;
	1577	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05790	    0.00000	 380.0	 1	    1.31579	    0.80000;
	1578	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.20000	    0.80000;
	1579	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05790	    0.00000	 380.0	 1	    1.31579	    0.80000;
	1580	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.20000	    0.80000;
	1581	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.06976	    0.00000	 380.0	 1	    1.10526	    1.03427;
	1582	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	1583	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.20000	    0.80000;
	1584	 1	 0.1	 69.0	 0.0	 0.0	 1	    1.03327	    0.00000	 380.0	 1	    1.10526	    0.96127;
	1585	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07056	    0.00000	 380.0	 1	    1.10263	    1.03848;
	1586	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.06579	    0.00000	 380.0	 1	    1.10526	    1.02632;
	1587	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.18421	    0.92105;
	1588	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	1589	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.18421	    0.92105;
	1590	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.20000	    0.80000;
	1591	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05790	    0.00000	 380.0	 1	    1.31579	    0.80000;
	1592	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.18421	    0.92105;
	1593	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.20000	    0.80000;
	1594	 1	 -7.2	 97.0	 0.0	 0.0	 1	    1.06666	    0.00000	 225.0	 1	    1.24444	    0.88889;
	1595	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.20000	    0.80000;
	1596	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 380.0	 1	    1.20000	    0.80000;
	1597	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.18421	    0.92105;
	1598	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.18421	    0.92105;
	1599	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.06522	    0.00000	 380.0	 1	    1.10526	    1.02519;
	1600	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.06579	    0.00000	 380.0	 1	    1.10526	    1.02632;
	1601	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	1602	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.18421	    0.92105;
	1603	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.18421	    0.92105;
	1604	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.18421	    0.92105;
	1605	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.06196	    0.00000	 380.0	 1	    1.10526	    1.01867;
	1606	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.06579	    0.00000	 380.0	 1	    1.10526	    1.02632;
	1607	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.18421	    0.92105;
	1608	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.18421	    0.92105;
	1609	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.18421	    0.92105;
	1610	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.06579	    0.00000	 380.0	 1	    1.10526	    1.02632;
	1611	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.18421	    0.92105;
	1612	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.18421	    0.92105;
	1613	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.18421	    0.92105;
	1614	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	1615	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.18421	    0.92105;
	1616	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.18421	    0.92105;
	1617	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.18421	    0.92105;
	1618	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.06579	    0.00000	 380.0	 1	    1.10526	    1.02632;
	1619	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.18421	    0.92105;
	1620	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.18421	    0.92105;
	1621	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.18421	    0.92105;
	1622	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.18421	    0.92105;
	1623	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.08300	    0.00000	 380.0	 1	    1.13968	    1.02632;
	1624	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10263	    1.04211;
	1625	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.06579	    0.00000	 380.0	 1	    1.10526	    1.02632;
	1626	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.18421	    0.92105;
	1627	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.18421	    0.92105;
	1628	 2	 -0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.05000	    0.95000;
	1629	 2	 -0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.05000	    0.95000;
	1844	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00776	    0.00000	 10.0	 1	    1.13096	    0.88456;
	1630	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.98876	    0.00000	 11.0	 1	    1.05000	    0.92753;
	1631	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.98996	    0.00000	 11.0	 1	    1.05000	    0.92991;
	1846	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 4.0	 1	    1.10000	    0.90000;
	1632	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 4.0	 1	    1.10000	    0.90000;
	1847	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 4.0	 1	    1.10000	    0.90000;
	1848	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 4.0	 1	    1.10000	    0.90000;
	1852	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 10.0	 1	    1.10000	    0.90000;
	1854	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 10.0	 1	    1.10000	    0.90000;
	1633	 2	 37.0	 16.0	 0.0	 0.0	 1	    1.00135	    0.00000	 24.0	 1	    1.05271	    0.95000;
	1634	 2	 40.1	 16.0	 0.0	 0.0	 1	    1.00053	    0.00000	 24.0	 1	    1.05105	    0.95000;
	1635	 2	 37.0	 16.0	 0.0	 0.0	 1	    1.00053	    0.00000	 24.0	 1	    1.05106	    0.95000;
	1636	 2	 37.0	 16.0	 0.0	 0.0	 1	    1.00000	    0.00000	 24.0	 1	    1.05000	    0.95000;
	1637	 2	 16.0	 11.0	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.05000	    0.95000;
	1638	 2	 14.0	 11.0	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.05000	    0.95000;
	1639	 2	 13.1	 10.3	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.05000	    0.95000;
	1640	 2	 -0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 17.0	 1	    1.05000	    0.95000;
	1641	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00373	    0.00000	 15.0	 1	    1.05747	    0.95000;
	1642	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 10.0	 1	    1.10000	    0.90000;
	1643	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 10.0	 1	    1.10000	    0.90000;
	1855	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 10.0	 1	    1.10000	    0.90000;
	1644	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 10.0	 1	    1.10000	    0.90000;
	1645	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 10.0	 1	    1.10000	    0.90000;
	1646	 2	 13.0	 7.0	 0.0	 0.0	 1	    1.00036	    0.00000	 20.0	 1	    1.05072	    0.95000;
	1647	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 5.0	 1	    1.10000	    0.90000;
	1861	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 10.0	 1	    1.10000	    0.90000;
	1648	 2	 31.0	 13.0	 0.0	 0.0	 1	    0.99083	    0.00000	 24.0	 1	    1.05000	    0.93167;
	1649	 2	 31.0	 13.0	 0.0	 0.0	 1	    0.98954	    0.00000	 24.0	 1	    1.05000	    0.92908;
	1650	 2	 38.0	 16.0	 0.0	 0.0	 1	    0.98754	    0.00000	 24.0	 1	    1.05000	    0.92508;
	1651	 2	 38.0	 16.0	 0.0	 0.0	 1	    0.99460	    0.00000	 24.0	 1	    1.05000	    0.93921;
	1652	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.99759	    0.00000	 20.0	 1	    1.05000	    0.94518;
	1862	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.99881	    0.00000	 20.0	 1	    1.05000	    0.94762;
	1653	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 4.0	 1	    1.10000	    0.90000;
	1654	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 4.0	 1	    1.10000	    0.90000;
	1655	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 4.0	 1	    1.10000	    0.90000;
	1656	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 4.0	 1	    1.10000	    0.90000;
	1657	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 4.0	 1	    1.10000	    0.90000;
	1658	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 4.0	 1	    1.10000	    0.90000;
	1863	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 10.0	 1	    1.10000	    0.90000;
	1659	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 10.0	 1	    1.10000	    0.90000;
	1660	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 10.0	 1	    1.10000	    0.90000;
	1661	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 10.0	 1	    1.10000	    0.90000;
	1662	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 10.0	 1	    1.10000	    0.90000;
	1663	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 10.0	 1	    1.10000	    0.90000;
	1865	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 5.0	 1	    1.10000	    0.90000;
	1866	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 10.0	 1	    1.10000	    0.90000;
	1664	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 10.0	 1	    1.10000	    0.90000;
	1665	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 10.0	 1	    1.10000	    0.90000;
	1867	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 10.0	 1	    1.10000	    0.90000;
	1666	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 10.0	 1	    1.10000	    0.90000;
	1868	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 10.0	 1	    1.10000	    0.90000;
	1667	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.99649	    0.00000	 20.0	 1	    1.05000	    0.94298;
	1668	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.99502	    0.00000	 20.0	 1	    1.05000	    0.94004;
	1669	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.99328	    0.00000	 20.0	 1	    1.05000	    0.93655;
	1670	 2	 1.4	 0.0	 0.0	 0.0	 1	    1.00942	    0.00000	 20.0	 1	    1.10244	    0.91640;
	1873	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 15.0	 1	    1.10000	    0.90000;
	1874	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 15.0	 1	    1.10000	    0.90000;
	1671	 2	 43.0	 18.0	 0.0	 0.0	 1	    1.00000	    0.00000	 24.0	 1	    1.05000	    0.95000;
	1673	 2	 43.0	 18.0	 0.0	 0.0	 1	    1.00000	    0.00000	 24.0	 1	    1.05000	    0.95000;
	1674	 2	 43.0	 18.0	 0.0	 0.0	 1	    0.99957	    0.00000	 24.0	 1	    1.05000	    0.94914;
	1675	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.99963	    0.00000	 20.0	 1	    1.05544	    0.94383;
	1676	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00522	    0.00000	 20.0	 1	    1.06044	    0.95000;
	1875	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.05000	    0.95000;
	1677	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.05000	    0.95000;
	2022	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 15.0	 1	    1.10000	    0.90000;
	1876	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 15.0	 1	    1.10000	    0.90000;
	1877	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 15.0	 1	    1.10000	    0.90000;
	1878	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 15.0	 1	    1.10000	    0.90000;
	1678	 2	 3.5	 2.2	 0.0	 0.0	 1	    1.00000	    0.00000	 15.0	 1	    1.05000	    0.95000;
	1679	 2	 3.5	 2.2	 0.0	 0.0	 1	    1.00000	    0.00000	 15.0	 1	    1.05000	    0.95000;
	1680	 2	 4.2	 2.3	 0.0	 0.0	 1	    1.00000	    0.00000	 14.0	 1	    1.05000	    0.95000;
	1681	 2	 0.0	 -0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.05000	    0.95000;
	1682	 2	 30.0	 14.0	 0.0	 0.0	 1	    0.98022	    0.00000	 20.0	 1	    1.05000	    0.91044;
	1683	 2	 5.6	 2.6	 0.0	 0.0	 1	    0.98002	    0.00000	 20.0	 1	    1.05000	    0.91005;
	1684	 2	 -0.0	 -0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.05000	    0.95000;
	1881	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 10.0	 1	    1.10000	    0.90000;
	1882	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 10.0	 1	    1.10000	    0.90000;
	1685	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 10.0	 1	    1.10000	    0.90000;
	1883	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 10.0	 1	    1.10000	    0.90000;
	1884	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 10.0	 1	    1.10000	    0.90000;
	1885	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 10.0	 1	    1.10000	    0.90000;
	1686	 2	 40.0	 18.0	 0.0	 0.0	 1	    1.00000	    0.00000	 24.0	 1	    1.05000	    0.95000;
	1687	 2	 40.0	 18.0	 0.0	 0.0	 1	    1.00000	    0.00000	 24.0	 1	    1.05000	    0.95000;
	1688	 2	 40.0	 18.0	 0.0	 0.0	 1	    1.00000	    0.00000	 24.0	 1	    1.05000	    0.95000;
	1689	 2	 40.0	 18.0	 0.0	 0.0	 1	    1.00000	    0.00000	 24.0	 1	    1.05000	    0.95000;
	1888	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 10.0	 1	    1.10000	    0.90000;
	1690	 2	 0.8	 0.6	 0.0	 0.0	 1	    0.98588	    0.00000	 21.0	 1	    1.05000	    0.92176;
	1691	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 15.0	 1	    1.05000	    0.95000;
	1692	 2	 0.0	 -0.0	 0.0	 0.0	 1	    1.01132	    0.00000	 19.0	 1	    1.07264	    0.95000;
	1693	 2	 -0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 15.0	 1	    1.05000	    0.95000;
	1694	 2	 0.0	 -0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 15.0	 1	    1.05000	    0.95000;
	1695	 2	 8.6	 5.1	 0.0	 0.0	 1	    1.00000	    0.00000	 18.0	 1	    1.05000	    0.95000;
	1696	 2	 10.0	 6.0	 0.0	 0.0	 1	    1.00000	    0.00000	 18.0	 1	    1.05000	    0.95000;
	1697	 2	 40.0	 17.0	 0.0	 0.0	 1	    1.00000	    0.00000	 24.0	 1	    1.05000	    0.95000;
	1698	 2	 40.0	 17.0	 0.0	 0.0	 1	    1.00000	    0.00000	 24.0	 1	    1.05000	    0.95000;
	1699	 2	 40.0	 17.0	 0.0	 0.0	 1	    1.00000	    0.00000	 24.0	 1	    1.05000	    0.95000;
	1700	 2	 36.9	 15.8	 0.0	 0.0	 1	    1.00000	    0.00000	 24.0	 1	    1.05000	    0.95000;
	1701	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	1702	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 10.0	 1	    1.10000	    0.90000;
	1703	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 10.0	 1	    1.10000	    0.90000;
	1889	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 10.0	 1	    1.10000	    0.90000;
	1704	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.05000	    0.95000;
	1705	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.05000	    0.95000;
	1890	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 3.0	 1	    1.10000	    0.90000;
	1891	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 3.0	 1	    1.10000	    0.90000;
	1892	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 3.0	 1	    1.10000	    0.90000;
	1706	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 3.0	 1	    1.10000	    0.90000;
	1707	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 3.0	 1	    1.10000	    0.90000;
	2026	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 3.0	 1	    1.10000	    0.90000;
	1898	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 3.0	 1	    1.10000	    0.90000;
	1708	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 3.0	 1	    1.10000	    0.90000;
	1709	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 3.0	 1	    1.10000	    0.90000;
	1710	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 4.0	 1	    1.10000	    0.90000;
	1711	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 4.0	 1	    1.10000	    0.90000;
	1712	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.05000	    0.95000;
	1713	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00198	    0.00000	 20.0	 1	    1.05397	    0.95000;
	1714	 2	 -0.4	 -0.3	 0.0	 0.0	 1	    1.01466	    0.00000	 21.0	 1	    1.07932	    0.95000;
	1715	 2	 37.0	 15.0	 0.0	 0.0	 1	    1.00000	    0.00000	 24.0	 1	    1.05000	    0.95000;
	1716	 2	 37.0	 15.0	 0.0	 0.0	 1	    1.00000	    0.00000	 24.0	 1	    1.05000	    0.95000;
	1717	 2	 37.0	 15.0	 0.0	 0.0	 1	    0.99360	    0.00000	 24.0	 1	    1.05603	    0.93116;
	1718	 2	 37.0	 15.0	 0.0	 0.0	 1	    0.99876	    0.00000	 24.0	 1	    1.05000	    0.94752;
	1719	 2	 37.0	 15.0	 0.0	 0.0	 1	    1.00000	    0.00000	 24.0	 1	    1.05000	    0.95000;
	1720	 2	 31.7	 14.7	 0.0	 0.0	 1	    1.00000	    0.00000	 24.0	 1	    1.05000	    0.95000;
	1721	 2	 15.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.05000	    0.95000;
	1906	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 15.0	 1	    1.10000	    0.90000;
	1907	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 15.0	 1	    1.10000	    0.90000;
	1908	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 15.0	 1	    1.10000	    0.90000;
	1909	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 15.0	 1	    1.10000	    0.90000;
	1910	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 15.0	 1	    1.10000	    0.90000;
	1911	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 15.0	 1	    1.10000	    0.90000;
	1912	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 15.0	 1	    1.10000	    0.90000;
	1913	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 15.0	 1	    1.10000	    0.90000;
	1722	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 18.0	 1	    1.05000	    0.95000;
	1723	 2	 8.4	 5.1	 0.0	 0.0	 1	    1.00550	    0.00000	 20.0	 1	    1.06101	    0.95000;
	1724	 2	 -0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.05000	    0.95000;
	1725	 2	 4.0	 1.8	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.05000	    0.95000;
	1919	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 8.0	 1	    1.10000	    0.90000;
	1920	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 8.0	 1	    1.10000	    0.90000;
	1921	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 8.0	 1	    1.10000	    0.90000;
	1922	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 8.0	 1	    1.10000	    0.90000;
	1923	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00306	    0.00000	 8.0	 1	    1.10611	    0.90000;
	1924	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00070	    0.00000	 8.0	 1	    1.10141	    0.90000;
	1726	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 10.0	 1	    1.10000	    0.90000;
	1727	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 10.0	 1	    1.10000	    0.90000;
	1728	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 10.0	 1	    1.10000	    0.90000;
	1928	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 10.0	 1	    1.10000	    0.90000;
	1729	 2	 8.4	 0.0	 0.0	 0.0	 1	    0.99639	    0.00000	 20.0	 1	    1.05000	    0.94278;
	1931	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 10.0	 1	    1.10000	    0.90000;
	1932	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.99648	    0.00000	 10.0	 1	    1.10000	    0.89295;
	1934	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 10.0	 1	    1.10000	    0.90000;
	1935	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 5.0	 1	    1.10000	    0.90000;
	1936	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 5.0	 1	    1.10000	    0.90000;
	1937	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 5.0	 1	    1.10000	    0.90000;
	1938	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 5.0	 1	    1.10000	    0.90000;
	1730	 2	 14.0	 8.0	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.05000	    0.95000;
	1731	 2	 9.6	 5.5	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.05000	    0.95000;
	1944	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.97404	    0.00000	 5.0	 1	    1.10000	    0.84808;
	1732	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.05000	    0.95000;
	1733	 2	 -0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 15.0	 1	    1.05000	    0.95000;
	1734	 2	 -0.0	 -0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 15.0	 1	    1.05000	    0.95000;
	1950	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	1951	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	1952	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	1953	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 18.0	 1	    1.10000	    0.90000;
	1735	 2	 30.0	 12.0	 0.0	 0.0	 1	    0.99924	    0.00000	 24.0	 1	    1.05000	    0.94847;
	1736	 2	 30.0	 12.0	 0.0	 0.0	 1	    0.99898	    0.00000	 24.0	 1	    1.05000	    0.94796;
	1737	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 10.0	 1	    1.10000	    0.90000;
	1738	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 10.0	 1	    1.10000	    0.90000;
	1739	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 10.0	 1	    1.10000	    0.90000;
	1740	 2	 -0.0	 0.0	 0.0	 0.0	 1	    1.00019	    0.00000	 17.0	 1	    1.05038	    0.95000;
	1741	 2	 6.1	 1.5	 0.0	 0.0	 1	    0.99092	    0.00000	 17.0	 1	    1.05000	    0.93184;
	1742	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.05000	    0.95000;
	1958	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 10.0	 1	    1.10000	    0.90000;
	1959	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 10.0	 1	    1.10000	    0.90000;
	1743	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00157	    0.00000	 10.0	 1	    1.10313	    0.90000;
	1744	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.05000	    0.95000;
	1745	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.99905	    0.00000	 20.0	 1	    1.05268	    0.94542;
	1746	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.05000	    0.95000;
	1961	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00533	    0.00000	 20.0	 1	    1.06065	    0.95000;
	1747	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 10.0	 1	    1.10000	    0.90000;
	1748	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.05000	    0.95000;
	1749	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.05000	    0.95000;
	1750	 2	 -0.0	 -0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.05000	    0.95000;
	1751	 2	 0.0	 -0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.05000	    0.95000;
	1752	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.05000	    0.95000;
	1753	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.05000	    0.95000;
	2058	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 5.0	 1	    1.10000	    0.90000;
	1754	 2	 9.1	 0.0	 0.0	 0.0	 1	    0.98930	    0.00000	 20.0	 1	    1.05000	    0.92859;
	1755	 2	 6.2	 0.0	 0.0	 0.0	 1	    0.98861	    0.00000	 20.0	 1	    1.05000	    0.92721;
	1756	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 11.0	 1	    1.10000	    0.90000;
	1757	 2	 -1.7	 -1.4	 0.0	 0.0	 1	    1.01423	    0.00000	 20.0	 1	    1.07847	    0.95000;
	1758	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 3.0	 1	    1.10000	    0.90000;
	1759	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 3.0	 1	    1.10000	    0.90000;
	1760	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 3.0	 1	    1.10000	    0.90000;
	1970	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 10.0	 1	    1.10000	    0.90000;
	1971	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 10.0	 1	    1.10000	    0.90000;
	1972	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 10.0	 1	    1.10000	    0.90000;
	1973	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 10.0	 1	    1.10000	    0.90000;
	1974	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.0	 1	    1.10000	    0.90000;
	1975	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00314	    0.00000	 13.0	 1	    1.10629	    0.90000;
	1976	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.0	 1	    1.10000	    0.90000;
	1977	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00145	    0.00000	 13.0	 1	    1.10290	    0.90000;
	1761	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 10.0	 1	    1.10000	    0.90000;
	1762	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 10.0	 1	    1.10000	    0.90000;
	1978	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 10.0	 1	    1.10000	    0.90000;
	1769	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 4.0	 1	    1.10000	    0.90000;
	1770	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 4.0	 1	    1.10000	    0.90000;
	1979	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 5.0	 1	    1.10000	    0.90000;
	1980	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 5.0	 1	    1.10000	    0.90000;
	1771	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 10.0	 1	    1.10000	    0.90000;
	1993	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 15.0	 1	    1.10000	    0.90000;
	1772	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.99758	    0.00000	 20.0	 1	    1.05000	    0.94515;
	1995	 2	 0.0	 0.0	 0.0	 0.0	 1	    0.99645	    0.00000	 20.0	 1	    1.05000	    0.94290;
	1773	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 20.0	 1	    1.05000	    0.95000;
	1774	 2	 8.8	 0.0	 0.0	 0.0	 1	    0.99851	    0.00000	 20.0	 1	    1.05000	    0.94701;
	1775	 2	 3.7	 2.1	 0.0	 0.0	 1	    0.99716	    0.00000	 19.0	 1	    1.05000	    0.94432;
	1776	 2	 2.6	 1.5	 0.0	 0.0	 1	    0.99442	    0.00000	 19.0	 1	    1.05000	    0.93884;
	1996	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 5.0	 1	    1.10000	    0.90000;
	1997	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 5.0	 1	    1.10000	    0.90000;
	2000	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 10.0	 1	    1.10000	    0.90000;
	1777	 2	 41.0	 15.0	 0.0	 0.0	 1	    0.99670	    0.00000	 24.0	 1	    1.05000	    0.94340;
	1778	 2	 41.0	 15.0	 0.0	 0.0	 1	    0.99918	    0.00000	 24.0	 1	    1.05000	    0.94836;
	1779	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 5.0	 1	    1.10000	    0.90000;
	2002	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 5.0	 1	    1.10000	    0.90000;
	1780	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01060	    0.00000	 3.0	 1	    1.12120	    0.90000;
	2028	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01086	    0.00000	 3.0	 1	    1.12172	    0.90000;
	1781	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01077	    0.00000	 3.0	 1	    1.12155	    0.90000;
	1782	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.01072	    0.00000	 3.0	 1	    1.12143	    0.90000;
	2004	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 15.0	 1	    1.10000	    0.90000;
	2023	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 15.0	 1	    1.10000	    0.90000;
	2024	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 15.0	 1	    1.10000	    0.90000;
	2005	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 15.0	 1	    1.10000	    0.90000;
	1783	 2	 35.0	 18.0	 0.0	 0.0	 1	    1.00000	    0.00000	 24.0	 1	    1.05000	    0.95000;
	1784	 2	 35.0	 13.0	 0.0	 0.0	 1	    1.00000	    0.00000	 24.0	 1	    1.05000	    0.95000;
	1785	 2	 35.0	 13.0	 0.0	 0.0	 1	    1.00000	    0.00000	 24.0	 1	    1.05000	    0.95000;
	1786	 2	 35.0	 13.0	 0.0	 0.0	 1	    1.00000	    0.00000	 24.0	 1	    1.05000	    0.95000;
	1787	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 15.0	 1	    1.05000	    0.95000;
	1788	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 15.0	 1	    1.05000	    0.95000;
	1789	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 15.0	 1	    1.05000	    0.95000;
	1790	 2	 18.0	 10.0	 0.0	 0.0	 1	    0.99737	    0.00000	 20.0	 1	    1.05357	    0.94117;
	1791	 2	 18.0	 10.0	 0.0	 0.0	 1	    0.99403	    0.00000	 20.0	 1	    1.05000	    0.93805;
	1792	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 10.0	 1	    1.10000	    0.90000;
	2011	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 10.0	 1	    1.10000	    0.90000;
	2012	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 10.0	 1	    1.10000	    0.90000;
	1793	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00069	    0.00000	 10.0	 1	    1.10138	    0.90000;
	1794	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00072	    0.00000	 10.0	 1	    1.10144	    0.90000;
	1795	 1	 515.7	 340.4	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	1796	 1	 512.7	 317.4	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	1797	 1	 -60.2	 0.6	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1798	 1	 677.6	 -43.9	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	1799	 1	 89.9	 63.1	 0.0	 0.0	 1	    1.04606	    0.00000	 225.0	 1	    1.09212	    1.00000;
	1800	 1	 357.2	 -60.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	1801	 1	 256.0	 28.9	 0.0	 0.0	 1	    1.03867	    0.00000	 225.0	 1	    1.09068	    0.98667;
	1802	 1	 253.5	 30.3	 0.0	 0.0	 1	    1.01893	    0.00000	 225.0	 1	    1.08787	    0.95000;
	1803	 1	 343.6	 -37.9	 0.0	 0.0	 1	    1.05263	    0.00000	 380.0	 1	    1.10526	    1.00000;
	1804	 1	 681.9	 -103.4	 0.0	 0.0	 1	    1.05921	    0.00000	 380.0	 1	    1.10526	    1.01316;
	1805	 1	 -1.4	 -21.1	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	1806	 1	 504.0	 -89.7	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	1807	 1	 29.6	 26.0	 0.0	 0.0	 1	    1.00000	    0.00000	 225.0	 1	    1.10000	    0.90000;
	1808	 1	 122.0	 26.6	 0.0	 0.0	 1	    1.04666	    0.00000	 225.0	 1	    1.08444	    1.00889;
	1809	 1	 -50.8	 46.8	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	1810	 1	 71.1	 -22.6	 0.0	 0.0	 1	    1.03778	    0.00000	 225.0	 1	    1.08889	    0.98667;
	1811	 1	 433.8	 -124.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	1812	 1	 0.0	 -2.9	 0.0	 0.0	 1	    1.04198	    0.00000	 225.0	 1	    1.09730	    0.98667;
	1813	 1	 52.0	 -76.6	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	1814	 1	 231.5	 -121.8	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	1815	 1	 282.2	 28.5	 0.0	 0.0	 1	    0.98889	    0.00000	 225.0	 1	    1.08889	    0.88889;
	1816	 1	 520.1	 -183.3	 0.0	 0.0	 1	    1.07655	    0.00000	 380.0	 1	    1.10526	    1.04785;
	1817	 1	 351.2	 -56.4	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	1818	 1	 28.0	 -3.3	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1819	 1	 390.4	 -33.8	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	1820	 1	 710.5	 35.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	1821	 1	 31.2	 -9.6	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1822	 1	 330.0	 -90.0	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	1823	 1	 137.7	 -21.3	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1824	 1	 137.5	 -21.2	 0.0	 0.0	 1	    1.01111	    0.00000	 225.0	 1	    1.08889	    0.93333;
	1825	 1	 356.3	 -41.8	 0.0	 0.0	 1	    1.07237	    0.00000	 380.0	 1	    1.10526	    1.03947;
	1826	 1	 398.1	 -58.5	 0.0	 0.0	 1	    1.07798	    0.00000	 380.0	 1	    1.10526	    1.05070;
];

%% generator data
%	bus	Pg	Qg	Qmax	Qmin	Vg	mBase	status	Pmax	Pmin
mpc.gen = [
	1268	 44.5	 9.0	 27.0	 -9.0	 1.01773	 100.0	 1	 45.0	 44.0; % NG
	1268	 44.5	 9.0	 27.0	 -9.0	 1.01773	 100.0	 1	 45.0	 44.0; % PEL
	1356	 13.2	 -2.5	 7.0	 -12.0	 1.014075	 100.0	 1	 22.0	 4.4; % PEL
	89	 15.0	 2.0	 13.0	 -9.0	 1.0	 100.0	 1	 25.0	 5.0; % PEL
	125	 14.04	 -4.5	 8.0	 -17.0	 1.01238	 100.0	 1	 23.4	 4.68; % PEL
	908	 12.0	 1.95	 2.0	 1.9	 1.004395	 100.0	 1	 20.0	 4.0; % NG
	817	 0.0	 0.0	 1.0	 0.9	 1.004235	 100.0	 0	 12.0	 2.4; % NG
	817	 8.4	 0.95	 1.0	 0.9	 1.004235	 100.0	 1	 14.0	 2.8; % COW
	817	 0.0	 0.0	 1.0	 0.9	 1.004235	 100.0	 0	 12.0	 2.4; % NG
	1335	 18.0	 0.0	 10.0	 -10.0	 1.0	 100.0	 1	 30.0	 6.0; % PEL
	396	 6.6	 3.0	 5.0	 1.0	 1.0	 100.0	 1	 11.0	 2.2; % COW
	396	 6.6	 3.0	 5.0	 1.0	 1.0	 100.0	 1	 11.0	 2.2; % PEL
	975	 21.0	 0.0	 15.0	 -15.0	 1.0	 100.0	 1	 35.0	 7.0; % NG
	858	 33.24	 0.0	 0.0	 0.0	 1.019305	 100.0	 1	 55.4	 11.08; % NG
	921	 25.2	 2.5	 25.0	 -20.0	 1.0	 100.0	 1	 42.0	 8.4; % NG
	921	 25.2	 2.5	 25.0	 -20.0	 1.0	 100.0	 1	 42.0	 8.4; % NG
	1255	 52.2	 0.87	 26.1	 -24.36	 1.01587	 100.0	 1	 87.0	 17.4; % NG
	169	 4.98	 0.0	 8.3	 -8.3	 1.0	 100.0	 1	 8.3	 1.66; % COW
	448	 2.0	 0.0	 0.0	 0.0	 1.01761	 100.0	 1	 4.0	 0.0; % NG
	241	 7.8	 0.0	 5.0	 -5.0	 1.0	 100.0	 1	 13.0	 2.6; % NG
	241	 7.8	 0.0	 5.0	 -5.0	 1.0	 100.0	 1	 13.0	 2.6; % NG
	241	 7.8	 0.0	 5.0	 -5.0	 1.0	 100.0	 1	 13.0	 2.6; % NG
	241	 7.8	 0.0	 5.0	 -5.0	 1.0	 100.0	 1	 13.0	 2.6; % NG
	270	 30.0	 9.0	 27.0	 -9.0	 1.00923	 100.0	 1	 50.0	 10.0; % NG
	885	 4.8	 0.0	 0.0	 0.0	 1.018935	 100.0	 1	 8.0	 1.6; % NG
	885	 4.8	 0.0	 0.0	 0.0	 1.018935	 100.0	 1	 8.0	 1.6; % COW
	876	 32.4	 0.0	 0.0	 0.0	 1.018115	 100.0	 1	 54.0	 10.8; % COW
	46	 18.0	 3.0	 10.0	 -4.0	 1.004215	 100.0	 1	 30.0	 6.0; % PEL
	803	 8.28	 -0.465	 4.63	 -5.56	 1.012885	 100.0	 1	 13.8	 2.76; % NG
	356	 24.84	 0.415	 12.42	 -11.59	 1.01705	 100.0	 1	 41.4	 8.28; % NG
	100	 78.0	 16.5	 59.0	 -26.0	 1.01647	 100.0	 1	 130.0	 26.0; % NG
	707	 12.6	 0.0	 8.0	 -8.0	 1.0	 100.0	 1	 21.0	 4.2; % NG
	973	 -0.0	 0.0	 0.0	 0.0	 1.01855	 100.0	 0	 0.0	 -8.0; % SYNC
	973	 31.8	 3.5	 17.0	 -10.0	 1.01855	 100.0	 1	 53.0	 10.6; % NG
	1118	 33.0	 0.0	 0.0	 0.0	 1.013845	 100.0	 1	 55.0	 11.0; % NG
	897	 16.2	 3.5	 10.0	 -3.0	 1.0	 100.0	 1	 27.0	 5.4; % PEL
	897	 16.2	 3.5	 10.0	 -3.0	 1.0	 100.0	 1	 27.0	 5.4; % NG
	58	 0.0	 0.0	 2.0	 1.9	 1.00431	 100.0	 0	 6.0	 1.2; % NG
	82	 15.18	 0.0	 0.0	 0.0	 1.01562	 100.0	 1	 25.3	 5.06; % NG
	474	 31.2	 -1.5	 10.0	 -13.0	 1.015335	 100.0	 1	 52.0	 10.4; % NG
	1221	 34.8	 0.0	 35.0	 -35.0	 1.0	 100.0	 1	 58.0	 11.6; % PEL
	355	 37.2	 0.0	 40.0	 -40.0	 1.0	 100.0	 1	 62.0	 12.4; % NG
	471	 46.8	 0.5	 1.0	 0.0	 1.017105	 100.0	 1	 78.0	 15.6; % NG
	1321	 6.6	 0.95	 1.0	 0.9	 1.004235	 100.0	 1	 11.0	 2.2; % NG
	1321	 1.25	 0.0	 0.1	 -0.1	 1.004235	 100.0	 1	 2.5	 0.0; % PEL
	1829	 14.1	 0.0	 8.0	 -8.0	 1.014295	 100.0	 1	 23.5	 4.7; % NG
	1005	 23.4	 0.0	 19.0	 -19.0	 1.00521	 100.0	 1	 39.0	 7.8; % PEL
	14	 16.56	 0.0	 0.0	 0.0	 1.01626	 100.0	 1	 27.6	 5.52; % PEL
	14	 14.4	 0.0	 0.0	 0.0	 1.01626	 100.0	 1	 24.0	 4.8; % PEL
	1628	 435.0	 -31.125	 155.3	 -217.55	 1.0	 100.0	 1	 670.0	 200.0; % NUC
	1629	 420.0	 20.405	 231.39	 -190.58	 1.0	 100.0	 1	 700.0	 140.0; % PEL
	1844	 16.2	 4.62	 24.62	 -15.38	 1.0077585	 100.0	 1	 27.0	 5.4; % NG
	1630	 51.6	 17.68	 43.86	 -8.5	 0.9887625	 100.0	 1	 86.0	 17.2; % NG
	1631	 29.4	 6.23	 22.19	 -9.73	 0.989957	 100.0	 1	 49.0	 9.8; % NG
	1846	 19.2	 0.0	 8.36	 -8.36	 1.0	 100.0	 1	 32.0	 6.4; % PEL
	1632	 19.2	 0.0	 8.36	 -8.36	 1.0	 100.0	 1	 32.0	 6.4; % PEL
	1847	 19.2	 -0.21	 8.15	 -8.57	 1.0	 100.0	 1	 32.0	 6.4; % PEL
	1848	 19.2	 -0.21	 8.15	 -8.57	 1.0	 100.0	 1	 32.0	 6.4; % NG
	1852	 55.2	 9.57	 54.57	 -35.43	 1.0	 100.0	 1	 92.0	 18.4; % NG
	1854	 55.2	 11.48	 56.48	 -33.52	 1.0	 100.0	 1	 92.0	 18.4; % NG
	1633	 600.075	 22.385	 421.39	 -376.62	 1.001355	 100.0	 1	 945.08	 255.07; % NUC
	1634	 633.045	 29.81	 428.83	 -369.21	 1.000525	 100.0	 1	 978.04	 288.05; % COW
	1635	 616.08	 29.075	 428.07	 -369.92	 1.00053	 100.0	 1	 976.08	 256.08; % COW
	1636	 598.075	 21.865	 420.86	 -377.13	 1.0	 100.0	 1	 943.08	 253.07; % COW
	1637	 204.0	 31.4	 153.03	 -90.23	 1.0	 100.0	 1	 252.0	 156.0; % NG
	1638	 202.0	 30.815	 152.44	 -90.81	 1.0	 100.0	 1	 250.0	 154.0; % NG
	1639	 202.0	 23.7	 105.68	 -58.28	 1.0	 100.0	 1	 250.0	 154.0; % NG
	1640	 213.5	 34.45	 228.81	 -159.91	 1.0	 100.0	 1	 305.0	 122.0; % NG
	1641	 122.0	 9.84	 94.32	 -74.64	 1.003735	 100.0	 1	 155.0	 89.0; % NG
	1642	 34.8	 1.44	 21.65	 -18.77	 1.0	 100.0	 1	 58.0	 11.6; % PEL
	1643	 34.8	 2.675	 16.01	 -10.66	 1.0	 100.0	 1	 58.0	 11.6; % PEL
	1855	 34.8	 1.26	 21.47	 -18.95	 1.0	 100.0	 1	 58.0	 11.6; % PEL
	1644	 34.8	 2.715	 16.05	 -10.62	 1.0	 100.0	 1	 58.0	 11.6; % COW
	1645	 34.8	 2.475	 15.81	 -10.86	 1.0	 100.0	 1	 58.0	 11.6; % NG
	1646	 198.0	 28.135	 146.45	 -90.18	 1.00036	 100.0	 1	 263.0	 133.0; % NG
	1647	 26.975	 6.29	 50.67	 -38.09	 1.0	 100.0	 1	 44.96	 8.99; % NG
	1861	 19.2	 1.75	 19.75	 -16.25	 1.0	 100.0	 1	 32.0	 6.4; % PEL
	1648	 601.29	 186.38	 530.99	 -158.23	 0.990834	 100.0	 1	 936.29	 266.29; % COW
	1649	 607.82	 188.81	 533.69	 -156.07	 0.9895395	 100.0	 1	 942.82	 272.82; % COW
	1650	 599.28	 192.43	 537.68	 -152.82	 0.9875395	 100.0	 1	 924.28	 274.28; % COW
	1651	 597.8	 184.5	 529.89	 -160.89	 0.994603	 100.0	 1	 922.8	 272.8; % COW
	1652	 813.0	 264.02	 681.04	 -153.0	 0.9975895	 100.0	 1	 1308.0	 318.0; % NUC
	1862	 813.0	 264.015	 681.03	 -153.0	 0.99881	 100.0	 1	 1308.0	 318.0; % COW
	1653	 21.0	 2.08	 6.08	 -1.92	 1.0	 100.0	 1	 35.0	 7.0; % PEL
	1654	 21.0	 2.21	 6.21	 -1.79	 1.0	 100.0	 1	 35.0	 7.0; % PEL
	1655	 21.0	 2.21	 6.21	 -1.79	 1.0	 100.0	 1	 35.0	 7.0; % NG
	1656	 21.0	 2.11	 6.11	 -1.89	 1.0	 100.0	 1	 35.0	 7.0; % PEL
	1657	 21.0	 2.11	 6.11	 -1.89	 1.0	 100.0	 1	 35.0	 7.0; % NG
	1658	 21.0	 2.11	 6.11	 -1.89	 1.0	 100.0	 1	 35.0	 7.0; % NG
	1863	 22.18	 2.645	 18.45	 -13.16	 1.0	 100.0	 1	 36.97	 7.39; % NG
	1659	 22.18	 2.645	 18.45	 -13.16	 1.0	 100.0	 1	 36.97	 7.39; % PEL
	1660	 22.18	 3.55	 18.45	 -11.35	 1.0	 100.0	 1	 36.97	 7.39; % NG
	1661	 22.18	 3.205	 18.11	 -11.7	 1.0	 100.0	 1	 36.97	 7.39; % NG
	1662	 22.18	 2.4	 18.21	 -13.41	 1.0	 100.0	 1	 36.97	 7.39; % PEL
	1663	 22.18	 2.75	 18.55	 -13.05	 1.0	 100.0	 1	 36.97	 7.39; % NG
	1865	 12.0	 2.32	 12.32	 -7.68	 1.0	 100.0	 1	 20.0	 4.0; % NG
	1866	 18.59	 2.03	 17.85	 -13.79	 1.0	 100.0	 1	 30.98	 6.2; % PEL
	1664	 18.59	 2.03	 17.85	 -13.79	 1.0	 100.0	 1	 30.98	 6.2; % COW
	1665	 18.59	 2.195	 18.01	 -13.62	 1.0	 100.0	 1	 30.98	 6.2; % NG
	1867	 18.59	 2.195	 18.01	 -13.62	 1.0	 100.0	 1	 30.98	 6.2; % NG
	1666	 18.59	 2.07	 17.89	 -13.75	 1.0	 100.0	 1	 30.98	 6.2; % NG
	1868	 18.59	 1.915	 17.74	 -13.91	 1.0	 100.0	 1	 30.98	 6.2; % PEL
	1667	 833.5	 235.585	 656.06	 -184.89	 0.996488	 100.0	 1	 1330.0	 337.0; % COW
	1668	 863.5	 236.51	 656.92	 -183.9	 0.995021	 100.0	 1	 1360.0	 367.0; % COW
	1669	 863.5	 227.615	 648.03	 -192.8	 0.993275	 100.0	 1	 1360.0	 367.0; % NUC
	1670	 1.45	 88.775	 281.46	 -103.91	 1.0094195	 100.0	 1	 1.5	 1.4; % PEL
	1873	 144.0	 24.03	 94.03	 -45.97	 1.0	 100.0	 1	 240.0	 48.0; % NG
	1874	 144.0	 25.11	 95.11	 -44.89	 1.0	 100.0	 1	 240.0	 48.0; % NG
	1671	 587.72	 208.7	 524.6	 -107.2	 1.0	 100.0	 1	 942.72	 232.72; % NUC
	1673	 598.74	 206.28	 511.64	 -99.08	 1.0	 100.0	 1	 953.74	 243.74; % COW
	1674	 597.74	 228.045	 555.41	 -99.32	 0.9995685	 100.0	 1	 952.74	 242.74; % NG
	1675	 953.0	 277.96	 682.28	 -126.36	 0.9996345	 100.0	 1	 1503.0	 403.0; % COW
	1676	 953.0	 282.755	 687.17	 -121.66	 1.00522	 100.0	 1	 1503.0	 403.0; % COW
	1875	 948.0	 28.58	 409.45	 -352.29	 1.0	 100.0	 1	 1498.0	 398.0; % COW
	1677	 948.0	 28.545	 409.42	 -352.33	 1.0	 100.0	 1	 1498.0	 398.0; % COW
	2022	 45.0	 6.72	 51.88	 -38.44	 1.0	 100.0	 1	 75.0	 15.0; % COW
	1876	 45.0	 6.72	 51.88	 -38.44	 1.0	 100.0	 1	 75.0	 15.0; % PEL
	1877	 45.0	 6.72	 51.88	 -38.44	 1.0	 100.0	 1	 75.0	 15.0; % COW
	1878	 45.0	 6.72	 51.88	 -38.44	 1.0	 100.0	 1	 75.0	 15.0; % NG
	1678	 51.75	 21.36	 104.12	 -61.4	 1.0	 100.0	 1	 95.0	 8.5; % NG
	1679	 51.75	 21.18	 103.94	 -61.58	 1.0	 100.0	 1	 95.0	 8.5; % NG
	1680	 76.2	 38.01	 86.67	 -10.65	 1.0	 100.0	 1	 148.2	 4.2; % NG
	1681	 432.5	 80.525	 220.22	 -59.17	 1.0	 100.0	 1	 685.0	 180.0; % COW
	1682	 460.0	 82.52	 330.28	 -165.24	 0.9802185	 100.0	 1	 610.0	 310.0; % COW
	1683	 460.0	 52.92	 297.67	 -191.83	 0.980023	 100.0	 1	 610.0	 310.0; % NUC
	1684	 452.5	 -19.415	 254.82	 -293.65	 1.0	 100.0	 1	 700.0	 205.0; % COW
	1881	 30.0	 0.9	 15.6	 -13.8	 1.0	 100.0	 1	 50.0	 10.0; % NG
	1882	 30.0	 0.5	 15.2	 -14.2	 1.0	 100.0	 1	 50.0	 10.0; % NG
	1685	 30.0	 1.105	 15.81	 -13.6	 1.0	 100.0	 1	 50.0	 10.0; % NG
	1883	 30.0	 1.105	 15.81	 -13.6	 1.0	 100.0	 1	 50.0	 10.0; % NG
	1884	 30.0	 1.105	 15.81	 -13.6	 1.0	 100.0	 1	 50.0	 10.0; % NG
	1885	 30.0	 0.9	 15.6	 -13.8	 1.0	 100.0	 1	 50.0	 10.0; % COW
	1686	 640.0	 221.385	 532.91	 -90.14	 1.0	 100.0	 1	 1000.0	 280.0; % COW
	1687	 640.0	 223.92	 535.45	 -87.61	 1.0	 100.0	 1	 1000.0	 280.0; % COW
	1688	 640.0	 239.705	 567.71	 -88.3	 1.0	 100.0	 1	 1000.0	 280.0; % NG
	1689	 0.0	 0.0	 559.16	 -96.85	 1.0	 100.0	 0	 930.0	 280.0; % NUC
	1888	 34.2	 0.0	 17.35	 -17.35	 1.0	 100.0	 1	 57.0	 11.4; % NG
	1690	 345.0	 32.025	 219.77	 -155.72	 0.9858785	 100.0	 1	 451.0	 239.0; % COW
	1691	 42.0	 20.31	 51.25	 -10.63	 1.0	 100.0	 1	 63.0	 21.0; % NG
	1692	 341.3	 37.96	 258.1	 -182.18	 1.01132	 100.0	 1	 433.8	 248.8; % COW
	1693	 124.99	 13.48	 71.21	 -44.25	 1.0	 100.0	 1	 168.17	 81.81; % NG
	1694	 125.44	 17.825	 73.34	 -37.69	 1.0	 100.0	 1	 168.6	 82.28; % NG
	1695	 151.06	 34.915	 113.53	 -43.7	 1.0	 100.0	 1	 248.21	 53.91; % NG
	1696	 141.03	 20.78	 100.92	 -59.36	 1.0	 100.0	 1	 238.09	 43.97; % COW
	1697	 574.69	 218.265	 525.14	 -88.61	 1.0	 100.0	 1	 919.69	 229.69; % COW
	1698	 574.69	 218.265	 525.14	 -88.61	 1.0	 100.0	 1	 919.69	 229.69; % NG
	1699	 581.69	 219.89	 526.77	 -86.99	 1.0	 100.0	 1	 926.69	 236.69; % COW
	1700	 596.69	 223.405	 530.29	 -83.48	 1.0	 100.0	 1	 941.69	 251.69; % COW
	1701	 19.2	 0.32	 10.32	 -9.68	 1.0	 100.0	 1	 32.0	 6.4; % PEL
	1702	 23.93	 0.775	 19.22	 -17.67	 1.0	 100.0	 1	 39.88	 7.98; % NG
	1703	 23.93	 0.8	 19.34	 -17.74	 1.0	 100.0	 1	 39.88	 7.98; % COW
	1889	 23.93	 0.79	 19.24	 -17.66	 1.0	 100.0	 1	 39.88	 7.98; % NG
	1704	 860.0	 0.765	 398.39	 -396.86	 1.0	 100.0	 1	 1380.0	 340.0; % NUC
	1705	 860.0	 -26.54	 371.08	 -424.16	 1.0	 100.0	 1	 1380.0	 340.0; % COW
	1890	 14.4	 1.39	 5.35	 -2.57	 1.0	 100.0	 1	 24.0	 4.8; % NG
	1891	 14.4	 1.525	 5.48	 -2.43	 1.0	 100.0	 1	 24.0	 4.8; % PEL
	1892	 14.4	 1.035	 5.0	 -2.93	 1.0	 100.0	 1	 24.0	 4.8; % PEL
	1706	 14.4	 1.33	 5.29	 -2.63	 1.0	 100.0	 1	 24.0	 4.8; % PEL
	1707	 14.395	 2.51	 10.0	 -4.98	 1.0	 100.0	 1	 23.99	 4.8; % PEL
	2026	 14.395	 0.735	 8.26	 -6.79	 1.0	 100.0	 1	 23.99	 4.8; % PEL
	1898	 14.395	 2.685	 10.17	 -4.8	 1.0	 100.0	 1	 23.99	 4.8; % PEL
	1708	 14.395	 1.805	 1.81	 1.8	 1.0	 100.0	 1	 23.99	 4.8; % NG
	1709	 14.395	 2.675	 10.16	 -4.81	 1.0	 100.0	 1	 23.99	 4.8; % PEL
	1710	 17.39	 2.34	 12.23	 -7.55	 1.0	 100.0	 1	 28.98	 5.8; % NG
	1711	 17.39	 2.425	 12.31	 -7.46	 1.0	 100.0	 1	 28.98	 5.8; % PEL
	1712	 798.0	 87.935	 615.09	 -439.22	 1.0	 100.0	 1	 1308.0	 288.0; % NG
	1713	 798.0	 87.48	 614.63	 -439.67	 1.001985	 100.0	 1	 1308.0	 288.0; % COW
	1714	 273.76	 85.9	 255.9	 -84.1	 1.01466	 100.0	 1	 458.26	 89.26; % NG
	1715	 592.0	 213.325	 524.88	 -98.23	 1.0	 100.0	 1	 947.0	 237.0; % COW
	1716	 607.0	 216.68	 528.27	 -94.91	 1.0	 100.0	 1	 947.0	 267.0; % COW
	1717	 592.0	 217.915	 529.5	 -93.67	 0.993595	 100.0	 1	 947.0	 237.0; % COW
	1718	 592.0	 217.03	 528.59	 -94.53	 0.9987595	 100.0	 1	 947.0	 237.0; % NUC
	1719	 592.0	 217.94	 529.53	 -93.65	 1.0	 100.0	 1	 947.0	 237.0; % COW
	1720	 592.0	 192.575	 504.13	 -118.98	 1.0	 100.0	 1	 947.0	 237.0; % COW
	1721	 182.5	 33.75	 104.81	 -37.31	 1.0	 100.0	 1	 240.0	 125.0; % NG
	1906	 101.64	 -3.68	 69.06	 -76.42	 1.0	 100.0	 1	 169.4	 33.88; % NG
	1907	 101.64	 -3.71	 69.08	 -76.5	 1.0	 100.0	 1	 169.4	 33.88; % COW
	1908	 101.64	 -3.785	 68.92	 -76.49	 1.0	 100.0	 1	 169.4	 33.88; % NG
	1909	 101.64	 -3.86	 68.97	 -76.69	 1.0	 100.0	 1	 169.4	 33.88; % NG
	1910	 101.64	 -3.74	 69.1	 -76.58	 1.0	 100.0	 1	 169.4	 33.88; % NG
	1911	 101.64	 -3.72	 69.1	 -76.54	 1.0	 100.0	 1	 169.4	 33.88; % PEL
	1912	 101.64	 -4.09	 68.67	 -76.85	 1.0	 100.0	 1	 169.4	 33.88; % COW
	1913	 101.64	 -4.115	 68.69	 -76.92	 1.0	 100.0	 1	 169.4	 33.88; % COW
	1722	 336.8	 72.9	 272.9	 -127.1	 1.0	 100.0	 1	 456.8	 216.8; % COW
	1723	 195.0	 39.71	 159.71	 -80.29	 1.005505	 100.0	 1	 260.0	 130.0; % NG
	1724	 0.0	 0.0	 198.66	 -190.41	 1.0	 100.0	 0	 585.0	 250.0; % NG
	1725	 417.5	 4.815	 199.31	 -189.68	 1.0	 100.0	 1	 585.0	 250.0; % COW
	1919	 11.99	 0.745	 20.64	 -19.15	 1.0	 100.0	 1	 19.98	 4.0; % NG
	1920	 14.39	 0.525	 20.43	 -19.38	 1.0	 100.0	 1	 23.98	 4.8; % PEL
	1921	 14.39	 1.17	 21.0	 -18.66	 1.0	 100.0	 1	 23.98	 4.8; % PEL
	1922	 14.39	 0.865	 20.73	 -19.0	 1.0	 100.0	 1	 23.98	 4.8; % PEL
	1923	 14.39	 1.445	 21.26	 -18.37	 1.003055	 100.0	 1	 23.98	 4.8; % NG
	1924	 14.39	 1.445	 21.26	 -18.37	 1.000705	 100.0	 1	 23.98	 4.8; % PEL
	1726	 21.0	 0.48	 9.31	 -8.35	 1.0	 100.0	 1	 35.0	 7.0; % PEL
	1727	 21.0	 0.29	 9.12	 -8.54	 1.0	 100.0	 1	 35.0	 7.0; % NG
	1728	 21.0	 -1.465	 10.16	 -13.09	 1.0	 100.0	 1	 35.0	 7.0; % NG
	1928	 21.0	 0.48	 9.31	 -8.35	 1.0	 100.0	 1	 35.0	 7.0; % PEL
	1729	 177.5	 -20.12	 104.52	 -144.76	 0.9963875	 100.0	 1	 235.0	 120.0; % COW
	1931	 43.8	 5.56	 47.31	 -36.19	 1.0	 100.0	 1	 73.0	 14.6; % NG
	1932	 41.4	 9.295	 51.14	 -32.55	 0.9964755	 100.0	 1	 69.0	 13.8; % NG
	1934	 46.5	 5.685	 46.31	 -34.94	 1.0	 100.0	 1	 77.5	 15.5; % NG
	1935	 18.6	 1.24	 13.16	 -10.68	 1.0	 100.0	 1	 31.0	 6.2; % PEL
	1936	 18.6	 1.39	 13.31	 -10.53	 1.0	 100.0	 1	 31.0	 6.2; % COW
	1937	 18.6	 1.55	 13.47	 -10.37	 1.0	 100.0	 1	 31.0	 6.2; % PEL
	1938	 30.0	 6.185	 28.9	 -16.53	 1.0	 100.0	 1	 50.0	 10.0; % NG
	1730	 193.5	 68.385	 158.82	 -22.05	 1.0	 100.0	 1	 250.0	 137.0; % NG
	1731	 193.5	 66.855	 157.29	 -23.58	 1.0	 100.0	 1	 250.0	 137.0; % NG
	1944	 11.4	 1.15	 11.15	 -8.85	 0.9740405	 100.0	 1	 19.0	 3.8; % NG
	1732	 310.9	 14.29	 198.93	 -170.35	 1.0	 100.0	 1	 419.9	 201.9; % COW
	1733	 95.0	 20.015	 83.82	 -43.79	 1.0	 100.0	 1	 185.0	 5.0; % NG
	1734	 95.0	 20.015	 83.82	 -43.79	 1.0	 100.0	 1	 185.0	 5.0; % NG
	1950	 136.2	 37.94	 163.7	 -87.82	 1.0	 100.0	 1	 227.0	 45.4; % COW
	1951	 136.2	 54.21	 179.99	 -71.57	 1.0	 100.0	 1	 227.0	 45.4; % NG
	1952	 136.2	 31.98	 157.76	 -93.8	 1.0	 100.0	 1	 227.0	 45.4; % NG
	1953	 136.2	 32.315	 158.1	 -93.47	 1.0	 100.0	 1	 227.0	 45.4; % COW
	1735	 593.5	 204.83	 501.44	 -91.78	 0.9992375	 100.0	 1	 950.0	 237.0; % COW
	1736	 593.5	 209.005	 505.62	 -87.61	 0.9989805	 100.0	 1	 950.0	 237.0; % COW
	1737	 22.705	 0.09	 19.48	 -19.3	 1.0	 100.0	 1	 37.84	 7.57; % NG
	1738	 22.705	 0.64	 19.6	 -18.32	 1.0	 100.0	 1	 37.84	 7.57; % NG
	1739	 22.71	 0.285	 19.12	 -18.55	 1.0	 100.0	 1	 37.85	 7.57; % PEL
	1740	 242.0	 2.83	 175.05	 -169.39	 1.00019	 100.0	 1	 316.0	 168.0; % NG
	1741	 230.0	 -12.955	 158.67	 -184.58	 0.990919	 100.0	 1	 304.0	 156.0; % COW
	1742	 824.5	 272.075	 674.32	 -130.17	 1.0	 100.0	 1	 1360.0	 289.0; % NUC
	1958	 36.6	 0.48	 27.09	 -26.13	 1.0	 100.0	 1	 61.0	 12.2; % NG
	1959	 36.6	 0.64	 27.25	 -25.97	 1.0	 100.0	 1	 61.0	 12.2; % NG
	1743	 21.57	 2.095	 19.17	 -14.98	 1.001565	 100.0	 1	 35.95	 7.19; % NG
	1744	 865.0	 229.47	 644.47	 -185.53	 1.0	 100.0	 1	 1380.0	 350.0; % COW
	1745	 865.0	 231.67	 646.63	 -183.29	 0.9990525	 100.0	 1	 1380.0	 350.0; % COW
	1746	 865.0	 228.305	 637.86	 -181.25	 1.0	 100.0	 1	 1380.0	 350.0; % COW
	1961	 820.0	 229.305	 644.28	 -185.67	 1.005325	 100.0	 1	 1290.0	 350.0; % COW
	1747	 25.9	 2.57	 26.57	 -21.43	 1.0	 100.0	 1	 51.0	 0.8; % NG
	1748	 860.0	 242.775	 637.77	 -152.22	 1.0	 100.0	 1	 1380.0	 340.0; % COW
	1749	 860.0	 234.935	 629.93	 -160.06	 1.0	 100.0	 1	 1380.0	 340.0; % COW
	1750	 380.0	 58.21	 232.65	 -116.23	 1.0	 100.0	 1	 585.0	 175.0; % COW
	1751	 380.0	 58.21	 232.65	 -116.23	 1.0	 100.0	 1	 585.0	 175.0; % NG
	1752	 393.0	 140.7	 314.58	 -33.18	 1.0	 100.0	 1	 598.0	 188.0; % NUC
	1753	 380.0	 57.39	 231.39	 -116.61	 1.0	 100.0	 1	 585.0	 175.0; % COW
	2058	 22.8	 0.95	 1.0	 0.9	 1.0	 100.0	 1	 38.0	 7.6; % NG
	1754	 165.0	 18.665	 117.72	 -80.39	 0.989297	 100.0	 1	 245.0	 85.0; % COW
	1755	 450.0	 25.65	 219.39	 -168.09	 0.988606	 100.0	 1	 605.0	 295.0; % COW
	1756	 34.8	 14.63	 59.63	 -30.37	 1.0	 100.0	 1	 58.0	 11.6; % PEL
	1757	 335.3	 93.085	 187.44	 -1.27	 1.014235	 100.0	 1	 439.8	 230.8; % NG
	1758	 48.0	 -4.18	 8.16	 -16.52	 1.0	 100.0	 1	 80.0	 16.0; % NG
	1759	 48.0	 -4.18	 8.16	 -16.52	 1.0	 100.0	 1	 80.0	 16.0; % NG
	1760	 48.0	 -4.22	 8.12	 -16.56	 1.0	 100.0	 1	 80.0	 16.0; % NG
	1970	 19.2	 4.16	 19.16	 -10.84	 1.0	 100.0	 1	 32.0	 6.4; % NG
	1971	 19.2	 0.75	 15.75	 -14.25	 1.0	 100.0	 1	 32.0	 6.4; % NG
	1972	 19.2	 4.16	 19.16	 -10.84	 1.0	 100.0	 1	 32.0	 6.4; % PEL
	1973	 19.2	 0.75	 15.75	 -14.25	 1.0	 100.0	 1	 32.0	 6.4; % PEL
	1974	 108.0	 8.27	 110.99	 -94.45	 1.0	 100.0	 1	 180.0	 36.0; % NG
	1975	 108.0	 1.96	 105.25	 -101.33	 1.003145	 100.0	 1	 180.0	 36.0; % NG
	1976	 108.0	 7.975	 110.69	 -94.74	 1.0	 100.0	 1	 180.0	 36.0; % NG
	1977	 108.0	 7.955	 110.67	 -94.76	 1.00145	 100.0	 1	 180.0	 36.0; % COW
	1761	 22.59	 1.605	 11.32	 -8.11	 1.0	 100.0	 1	 37.65	 7.53; % COW
	1762	 22.59	 1.545	 11.25	 -8.16	 1.0	 100.0	 1	 37.65	 7.53; % NG
	1978	 22.585	 1.425	 11.12	 -8.27	 1.0	 100.0	 1	 37.64	 7.53; % PEL
	1769	 20.485	 -2.625	 7.16	 -12.41	 1.0	 100.0	 1	 39.97	 1.0; % NG
	1770	 20.485	 -2.375	 7.4	 -12.15	 1.0	 100.0	 1	 39.97	 1.0; % NG
	1979	 26.4	 0.27	 10.62	 -10.08	 1.0	 100.0	 1	 44.0	 8.8; % NG
	1980	 18.6	 2.41	 18.75	 -13.93	 1.0	 100.0	 1	 31.0	 6.2; % PEL
	1771	 19.8	 1.72	 16.72	 -13.28	 1.0	 100.0	 1	 33.0	 6.6; % PEL
	1993	 78.0	 4.765	 26.99	 -17.46	 1.0	 100.0	 1	 130.0	 26.0; % NG
	1772	 807.0	 245.74	 640.85	 -149.37	 0.997577	 100.0	 1	 1332.0	 282.0; % COW
	1995	 807.0	 239.41	 634.52	 -155.7	 0.9964485	 100.0	 1	 1332.0	 282.0; % COW
	1773	 217.5	 89.165	 164.14	 14.19	 1.0	 100.0	 1	 285.0	 150.0; % COW
	1774	 410.0	 37.3	 221.3	 -146.7	 0.9985055	 100.0	 1	 595.0	 225.0; % COW
	1775	 285.0	 59.22	 89.22	 29.22	 0.997161	 100.0	 1	 443.0	 127.0; % NG
	1776	 0.0	 0.0	 97.27	 37.27	 0.9944205	 100.0	 0	 443.0	 127.0; % COW
	1996	 30.0	 -0.585	 25.51	 -26.68	 1.0	 100.0	 1	 50.0	 10.0; % NG
	1997	 30.0	 0.04	 26.13	 -26.05	 1.0	 100.0	 1	 50.0	 10.0; % NG
	2000	 51.0	 12.91	 50.47	 -24.65	 1.0	 100.0	 1	 85.0	 17.0; % NG
	1777	 593.37	 216.67	 543.74	 -110.4	 0.9967005	 100.0	 1	 953.37	 233.37; % COW
	1778	 596.37	 213.27	 540.34	 -113.8	 0.9991795	 100.0	 1	 956.37	 236.37; % COW
	1779	 29.4	 -0.25	 18.53	 -19.03	 1.0	 100.0	 1	 49.0	 9.8; % COW
	2002	 29.4	 -0.25	 18.53	 -19.03	 1.0	 100.0	 1	 49.0	 9.8; % NG
	1780	 14.215	 3.59	 8.62	 -1.44	 1.0106	 100.0	 1	 23.69	 4.74; % PEL
	2028	 14.215	 3.59	 8.62	 -1.44	 1.01086	 100.0	 1	 23.69	 4.74; % PEL
	1781	 14.215	 3.59	 8.62	 -1.44	 1.010775	 100.0	 1	 23.69	 4.74; % PEL
	1782	 14.215	 3.515	 8.55	 -1.52	 1.010715	 100.0	 1	 23.69	 4.74; % NG
	2004	 96.6	 6.74	 86.74	 -73.26	 1.0	 100.0	 1	 161.0	 32.2; % COW
	2023	 96.6	 6.74	 86.74	 -73.26	 1.0	 100.0	 1	 161.0	 32.2; % NG
	2024	 96.6	 6.74	 86.74	 -73.26	 1.0	 100.0	 1	 161.0	 32.2; % COW
	2005	 96.6	 6.74	 86.74	 -73.26	 1.0	 100.0	 1	 161.0	 32.2; % COW
	1783	 630.0	 157.545	 414.21	 -99.12	 1.0	 100.0	 1	 985.0	 275.0; % COW
	1784	 630.0	 146.6	 403.28	 -110.08	 1.0	 100.0	 1	 985.0	 275.0; % COW
	1785	 630.0	 159.9	 416.57	 -96.77	 1.0	 100.0	 1	 985.0	 275.0; % COW
	1786	 630.0	 160.115	 416.79	 -96.56	 1.0	 100.0	 1	 985.0	 275.0; % COW
	1787	 128.5	 18.895	 83.56	 -45.77	 1.0	 100.0	 1	 185.0	 72.0; % NG
	1788	 128.5	 19.845	 83.56	 -43.87	 1.0	 100.0	 1	 185.0	 72.0; % NG
	1789	 128.5	 19.845	 83.56	 -43.87	 1.0	 100.0	 1	 185.0	 72.0; % NG
	1790	 203.0	 36.265	 140.78	 -68.25	 0.9973695	 100.0	 1	 268.0	 138.0; % NG
	1791	 203.0	 31.265	 135.78	 -73.25	 0.994026	 100.0	 1	 268.0	 138.0; % COW
	1792	 20.98	 -3.94	 12.09	 -19.97	 1.0	 100.0	 1	 34.97	 6.99; % NG
	2011	 20.98	 -3.94	 12.09	 -19.97	 1.0	 100.0	 1	 34.97	 6.99; % NG
	2012	 20.975	 -3.96	 12.08	 -20.0	 1.0	 100.0	 1	 34.96	 6.99; % PEL
	1793	 81.6	 16.95	 106.95	 -73.05	 1.00069	 100.0	 1	 136.0	 27.2; % NG
	1794	 76.8	 15.68	 100.68	 -69.32	 1.00072	 100.0	 1	 128.0	 25.6; % NG
];

%% generator cost data
%	2	startup	shutdown	n	c(n-1)	...	c0
mpc.gencost = [
	2	 0.0	 0.0	 3	   0.000000	  36.879614	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 102.818703	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 123.867753	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 106.230210	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 111.337642	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  37.203873	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.778795	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.586445	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  21.586989	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 102.922605	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  23.347606	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 110.721100	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  26.419861	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.601438	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.569564	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.993553	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.335599	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.937230	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.757753	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.622515	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  46.406787	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.911806	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.483516	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.323377	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.744730	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  13.975616	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  48.070538	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 111.022896	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  44.772489	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.154786	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.003663	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.811093	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000; % SYNC
	2	 0.0	 0.0	 3	   0.000000	  34.301794	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.860956	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 120.918113	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  24.962467	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.859582	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.589808	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.660132	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  89.794302	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  32.095030	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.473234	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.179533	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 106.557899	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  14.407526	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 119.630609	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 116.533424	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 126.010118	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	   6.745408	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	 107.069234	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  29.420074	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.885121	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.833663	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 119.431558	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 121.989784	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 104.195581	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  65.052207	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.924115	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  42.564627	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   6.450082	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  24.823632	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.414781	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  31.215842	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.015136	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  31.598869	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.829022	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.078606	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  50.521495	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  95.047113	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 114.295845	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 103.134064	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  30.579540	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  20.312818	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.670303	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.533901	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 106.652079	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  25.143778	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  18.119992	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.421775	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  15.660903	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   5.667664	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  19.797917	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 109.357263	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 116.925701	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  38.911893	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 103.504481	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  29.879728	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  54.667442	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.644799	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 100.151990	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  53.625088	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.773174	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 129.451325	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  45.436313	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.091670	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  99.401859	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  21.662259	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  45.541664	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  49.469415	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.311689	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 119.347719	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  23.547369	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   2.859808	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   6.864972	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  99.497152	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  31.789207	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.540539	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   6.793600	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  34.083995	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  54.297341	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.405366	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  26.762535	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.545621	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  33.616738	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  37.617069	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 107.884528	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  19.721211	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.911063	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  24.383565	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.281971	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.253167	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.853896	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.384789	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   6.758840	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  24.457229	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.314700	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  29.429072	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.273721	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  48.176458	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.299742	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  17.076737	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  16.588831	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  19.318277	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  18.680412	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   6.633383	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  41.475369	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.079350	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  37.665860	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.878714	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  28.952303	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.359034	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.353015	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.111097	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  41.652275	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.441246	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.797956	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  13.786673	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 112.501633	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  45.184068	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.242997	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.732720	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   7.072944	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	   7.190143	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.024814	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 111.973759	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 121.864221	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 123.841827	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 106.668799	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  97.191384	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 101.011895	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  43.474735	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 114.499177	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  34.889776	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 111.696301	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  27.980534	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.408853	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.166895	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.130730	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.139349	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  35.693046	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   6.813815	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  25.239496	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.058610	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  52.977338	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.002061	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.412444	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  38.385621	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  23.937604	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.588644	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 121.788286	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  22.180489	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  15.118668	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  19.235965	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  41.308627	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.331328	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  32.923634	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  37.787385	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 115.799925	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 125.358723	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 106.839232	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  37.470049	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 113.967568	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 115.113942	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  25.222493	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  13.647219	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 103.342463	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  38.215685	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  48.344191	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  27.309325	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.403946	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 110.713088	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  26.135622	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 121.847407	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  46.328098	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.772212	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.928321	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  40.046977	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.215423	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.151677	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.256590	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  21.265771	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  24.386048	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.433826	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  19.551393	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.394640	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  21.657813	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  10.825654	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.444518	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  77.209822	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  40.718392	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.369578	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   7.443288	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  27.444414	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  45.307370	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.884473	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.703538	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  16.121548	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.581295	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.669454	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	   9.142467	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.906404	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  19.249273	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  29.662639	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.320495	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   7.508354	   0.000000; % NUC
	2	 0.0	 0.0	 3	   0.000000	  40.521380	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.123945	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  15.636607	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.535048	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	 108.347590	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  20.404845	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  51.186207	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.222781	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.538923	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  30.822152	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  36.570849	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 117.606154	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 103.660535	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  25.974471	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.958046	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  41.029010	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  39.324385	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.360941	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.846338	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  99.546478	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  44.513057	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  25.827509	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  10.045374	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 105.987833	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  99.978003	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  38.865077	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  20.142044	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  23.309031	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  13.359216	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  18.012933	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  30.381701	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  37.990395	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  22.059642	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	   6.474270	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  44.861896	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  28.429820	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  10.693332	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.446711	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  64.461675	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	 118.875628	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 122.385004	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	 126.688114	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  26.640965	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  18.034861	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  34.601688	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  34.755944	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  40.379488	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  19.197845	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  25.961059	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.133823	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  27.790165	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  52.405877	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  43.144225	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  26.643664	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  35.293605	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  33.589452	   0.000000; % COW
	2	 0.0	 0.0	 3	   0.000000	  32.336169	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  22.022236	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  99.719212	   0.000000; % PEL
	2	 0.0	 0.0	 3	   0.000000	  31.269080	   0.000000; % NG
	2	 0.0	 0.0	 3	   0.000000	  38.652489	   0.000000; % NG
];

%% branch data
%	fbus	tbus	r	x	b	rateA	rateB	rateC	ratio	angle	status	angmin	angmax
mpc.branch = [
	1833	 1	 0.002607	 0.017462	 0.0324	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29	 2	 2.1e-05	 0.000125	 0.1386	 737.0	 737.0	 737.0	 0.0	 0.0	 1	 -30.0	 30.0;
	675	 2	 0.000145	 0.001877	 0.0635	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1271	 2	 0.000319	 0.003234	 0.0838	 1841.0	 1841.0	 1841.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30	 2	 2.1e-05	 0.000125	 0.1386	 737.0	 737.0	 737.0	 0.0	 0.0	 1	 -30.0	 30.0;
	142	 3	 0.006163	 0.041067	 0.0759	 446.0	 446.0	 446.0	 0.0	 0.0	 1	 -30.0	 30.0;
	677	 3	 0.000652	 0.004369	 0.0081	 558.0	 558.0	 558.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1048	 4	 0.009733	 0.034089	 0.0185	 905	 905	 905	 0.0	 0.0	 1	 -30.0	 30.0;
	101	 5	 0.000277	 0.002015	 0.003	 288.0	 288.0	 288.0	 0.0	 0.0	 1	 -30.0	 30.0;
	286	 6	 0.00881	 0.033995	 0.0607	 289.0	 289.0	 289.0	 0.0	 0.0	 1	 -30.0	 30.0;
	329	 6	 0.004642	 0.019832	 0.0354	 255.0	 255.0	 255.0	 0.0	 0.0	 1	 -30.0	 30.0;
	737	 5	 0.008861	 0.03506	 0.0623	 288.0	 288.0	 288.0	 0.0	 0.0	 1	 -30.0	 30.0;
	760	 5	 0.006993	 0.032869	 0.0557	 255.0	 255.0	 255.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1330	 6	 0.002173	 0.008731	 0.0152	 3441	 3441	 3441	 0.0	 0.0	 1	 -30.0	 30.0;
	1350	 5	 0.00077	 0.003121	 0.0051	 9629	 9629	 9629	 0.0	 0.0	 1	 -30.0	 30.0;
	1523	 6	 0.004109	 0.016138	 0.0284	 288.0	 288.0	 288.0	 0.0	 0.0	 1	 -30.0	 30.0;
	102	 8	 8.3e-05	 0.000907	 0.0202	 1034.0	 1034.0	 1034.0	 0.0	 0.0	 1	 -30.0	 30.0;
	316	 8	 0.000552	 0.006726	 0.0939	 1786.0	 1786.0	 1786.0	 0.0	 0.0	 1	 -30.0	 30.0;
	623	 8	 0.000512	 0.008012	 0.2455	 2462.0	 2462.0	 2462.0	 0.0	 0.0	 1	 -30.0	 30.0;
	882	 8	 0.001107	 0.00918	 0.1906	 1644.0	 1644.0	 1644.0	 0.0	 0.0	 1	 -30.0	 30.0;
	103	 7	 6.2e-05	 0.000741	 0.0173	 1095.0	 1095.0	 1095.0	 0.0	 0.0	 1	 -30.0	 30.0;
	623	 8	 0.000512	 0.008019	 0.2455	 2462.0	 2462.0	 2462.0	 0.0	 0.0	 1	 -30.0	 30.0;
	623	 7	 0.001153	 0.013123	 0.1841	 1433.0	 1433.0	 1433.0	 0.0	 0.0	 1	 -30.0	 30.0;
	113	 9	 0.000158	 0.000672	 0.0719	 331.0	 331.0	 331.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1134	 9	 4.5e-05	 8.9e-05	 0.002	 268.0	 268.0	 268.0	 0.0	 0.0	 1	 -30.0	 30.0;
	346	 10	 0.00478	 0.028622	 0.0547	 455.0	 455.0	 455.0	 0.0	 0.0	 1	 -30.0	 30.0;
	345	 10	 0.00478	 0.028583	 0.0547	 455.0	 455.0	 455.0	 0.0	 0.0	 1	 -30.0	 30.0;
	106	 11	 0.000257	 0.000514	 0.0294	 53862	 53862	 53862	 0.0	 0.0	 1	 -30.0	 30.0;
	758	 12	 0.000257	 0.002153	 0.2147	 452.0	 452.0	 452.0	 0.0	 0.0	 1	 -30.0	 30.0;
	962	 12	 0.000277	 0.000869	 0.0931	 481.0	 481.0	 481.0	 0.0	 0.0	 1	 -30.0	 30.0;
	955	 13	 0.000237	 0.00083	 0.1863	 268.0	 268.0	 268.0	 0.0	 0.0	 1	 -30.0	 30.0;
	995	 13	 0.000178	 0.000612	 0.1377	 268.0	 268.0	 268.0	 0.0	 0.0	 1	 -30.0	 30.0;
	39	 14	 0.002568	 0.011753	 0.0203	 424.0	 424.0	 424.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1428	 14	 0.002568	 0.011615	 0.0228	 290.0	 290.0	 290.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1054	 16	 9.9e-05	 0.00077	 0.078	 379.0	 379.0	 379.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1054	 15	 9.9e-05	 0.00077	 0.077	 379.0	 379.0	 379.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1428	 17	 0.000514	 0.003437	 0.0061	 290.0	 290.0	 290.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1432	 17	 0.005476	 0.036879	 0.1255	 522.0	 522.0	 522.0	 0.0	 0.0	 1	 -30.0	 30.0;
	39	 17	 0.000514	 0.003457	 0.0061	 418.0	 418.0	 418.0	 0.0	 0.0	 1	 -30.0	 30.0;
	869	 18	 0.003477	 0.01118	 0.0187	 304.0	 304.0	 304.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1089	 18	 0.000612	 0.003121	 0.0152	 270.0	 270.0	 270.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1164	 20	 2.4e-05	 0.000144	 0.0213	 701.0	 701.0	 701.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1164	 19	 7.1e-05	 0.000162	 0.0162	 251.0	 251.0	 251.0	 0.0	 0.0	 1	 -30.0	 30.0;
	972	 21	 0.000257	 0.001165	 0.002	 405.0	 405.0	 405.0	 0.0	 0.0	 1	 -30.0	 30.0;
	476	 22	 0.005709	 0.037926	 0.0688	 492.0	 492.0	 492.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1497	 22	 0.001758	 0.011654	 0.0208	 492.0	 492.0	 492.0	 0.0	 0.0	 1	 -30.0	 30.0;
	69	 23	 0.001383	 0.009462	 0.0172	 463.0	 463.0	 463.0	 0.0	 0.0	 1	 -30.0	 30.0;
	446	 23	 0.00156	 0.006933	 0.0121	 432.0	 432.0	 432.0	 0.0	 0.0	 1	 -30.0	 30.0;
	605	 23	 0.006376	 0.028733	 0.0506	 432.0	 432.0	 432.0	 0.0	 0.0	 1	 -30.0	 30.0;
	987	 23	 0.00158	 0.010627	 0.0192	 481.0	 481.0	 481.0	 0.0	 0.0	 1	 -30.0	 30.0;
	845	 25	 0.001086	 0.003536	 0.3766	 506.0	 506.0	 506.0	 0.0	 0.0	 1	 -30.0	 30.0;
	845	 25	 0.001086	 0.003536	 0.3766	 506.0	 506.0	 506.0	 0.0	 0.0	 1	 -30.0	 30.0;
	123	 27	 0.004741	 0.020385	 0.0334	 1479	 1479	 1479	 0.0	 0.0	 1	 -30.0	 30.0;
	1479	 27	 0.009027	 0.048869	 0.084	 351.0	 351.0	 351.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1500	 27	 0.003516	 0.016257	 0.0273	 311.0	 311.0	 311.0	 0.0	 0.0	 1	 -30.0	 30.0;
	289	 28	 0.000514	 0.003417	 0.0278	 452.0	 452.0	 452.0	 0.0	 0.0	 1	 -30.0	 30.0;
	307	 28	 0.001084	 0.007198	 0.0132	 448.0	 448.0	 448.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1451	 28	 0.000523	 0.002436	 0.0167	 348.0	 348.0	 348.0	 0.0	 0.0	 1	 -30.0	 30.0;
	289	 28	 0.000514	 0.003457	 0.0203	 356.0	 356.0	 356.0	 0.0	 0.0	 1	 -30.0	 30.0;
	307	 28	 0.001086	 0.007249	 0.0132	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1450	 28	 0.000553	 0.002469	 0.0157	 405.0	 405.0	 405.0	 0.0	 0.0	 1	 -30.0	 30.0;
	307	 28	 0.001086	 0.007269	 0.0132	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	842	 31	 0.001837	 0.011694	 0.0759	 467.0	 467.0	 467.0	 0.0	 0.0	 1	 -30.0	 30.0;
	960	 31	 0.001067	 0.007131	 0.0132	 413.0	 413.0	 413.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1269	 31	 0.001284	 0.008593	 0.0152	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1270	 31	 0.001284	 0.008593	 0.0162	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1270	 31	 0.001284	 0.008533	 0.0162	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	212	 33	 0.000494	 0.000928	 0.0699	 29203	 29203	 29203	 0.0	 0.0	 1	 -30.0	 30.0;
	326	 33	 0.000184	 0.00159	 0.1661	 422.0	 422.0	 422.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1153	 33	 0.000198	 0.001711	 0.1711	 385.0	 385.0	 385.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1170	 33	 0.000751	 0.003358	 0.1534	 385.0	 385.0	 385.0	 0.0	 0.0	 1	 -30.0	 30.0;
	343	 34	 0.000178	 0.001047	 0.1499	 452.0	 452.0	 452.0	 0.0	 0.0	 1	 -30.0	 30.0;
	955	 34	 0.000316	 0.002232	 0.2774	 452.0	 452.0	 452.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1257	 35	 0.037227	 0.106836	 0.0328	 270	 270	 270	 0.0	 0.0	 1	 -30.0	 30.0;
	1439	 35	 0.006089	 0.020756	 0.0067	 1408	 1408	 1408	 0.0	 0.0	 1	 -30.0	 30.0;
	846	 36	 0.000729	 0.005118	 0.0933	 389.0	 389.0	 389.0	 0.0	 0.0	 1	 -30.0	 30.0;
	846	 36	 0.000755	 0.005235	 0.0909	 419.0	 419.0	 419.0	 0.0	 0.0	 1	 -30.0	 30.0;
	228	 37	 0.001787	 0.01946	 0.4214	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	477	 38	 0.001719	 0.00877	 0.0157	 321.0	 321.0	 321.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1179	 38	 0.009165	 0.04318	 0.077	 321.0	 321.0	 321.0	 0.0	 0.0	 1	 -30.0	 30.0;
	134	 39	 0.004879	 0.032454	 0.0602	 487.0	 487.0	 487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	195	 39	 0.006341	 0.042746	 0.0785	 418.0	 418.0	 418.0	 0.0	 0.0	 1	 -30.0	 30.0;
	208	 39	 0.006914	 0.031249	 0.0547	 327.0	 327.0	 327.0	 0.0	 0.0	 1	 -30.0	 30.0;
	296	 40	 0.000582	 0.007652	 0.2643	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	766	 40	 0.001648	 0.021634	 0.748	 1470	 1470	 1470	 0.0	 0.0	 1	 -30.0	 30.0;
	950	 40	 0.000838	 0.014301	 0.5198	 2227	 2227	 2227	 0.0	 0.0	 1	 -30.0	 30.0;
	1282	 40	 0.001163	 0.015312	 0.5285	 2077	 2077	 2077	 0.0	 0.0	 1	 -30.0	 30.0;
	296	 40	 0.000575	 0.007576	 0.2614	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	766	 40	 0.001646	 0.021633	 0.7479	 1470	 1470	 1470	 0.0	 0.0	 1	 -30.0	 30.0;
	950	 40	 0.000838	 0.014287	 0.5198	 2229	 2229	 2229	 0.0	 0.0	 1	 -30.0	 30.0;
	1281	 40	 0.00117	 0.015339	 0.5285	 2074	 2074	 2074	 0.0	 0.0	 1	 -30.0	 30.0;
	1282	 40	 0.001821	 0.017874	 0.4318	 1382.0	 1382.0	 1382.0	 0.0	 0.0	 1	 -30.0	 30.0;
	558	 41	 0.000672	 0.003477	 0.0365	 254.0	 254.0	 254.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1420	 42	 0.000632	 0.004188	 0.0081	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1420	 43	 0.000612	 0.004148	 0.0071	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1040	 44	 0.000672	 0.004405	 0.0081	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1521	 44	 0.000968	 0.004602	 0.0081	 304.0	 304.0	 304.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1040	 44	 0.000632	 0.004444	 0.0081	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1524	 45	 0.001975	 0.013215	 0.0243	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1525	 45	 0.001956	 0.013037	 0.0243	 2348	 2348	 2348	 0.0	 0.0	 1	 -30.0	 30.0;
	1321	 46	 0.002933	 0.010267	 0.0032	 3004	 3004	 3004	 0.0	 0.0	 1	 -30.0	 30.0;
	1429	 46	 0.0028	 0.007511	 0.0022	 4003	 4003	 4003	 0.0	 0.0	 1	 -30.0	 30.0;
	49	 48	 2e-05	 0.000198	 0.0121	 261.0	 261.0	 261.0	 0.0	 0.0	 1	 -30.0	 30.0;
	49	 47	 2e-05	 0.000198	 0.0142	 261.0	 261.0	 261.0	 0.0	 0.0	 1	 -30.0	 30.0;
	298	 49	 0.002037	 0.010904	 0.0187	 352.0	 352.0	 352.0	 0.0	 0.0	 1	 -30.0	 30.0;
	318	 49	 0.000415	 0.002015	 0.1266	 428.0	 428.0	 428.0	 0.0	 0.0	 1	 -30.0	 30.0;
	370	 49	 0.000395	 0.00156	 0.1893	 426.0	 426.0	 426.0	 0.0	 0.0	 1	 -30.0	 30.0;
	608	 49	 4e-05	 0.000178	 0.0152	 169660	 169660	 169660	 0.0	 0.0	 1	 -30.0	 30.0;
	836	 49	 0.001323	 0.012444	 0.0678	 935.0	 935.0	 935.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1227	 49	 0.000454	 0.002133	 0.2511	 268.0	 268.0	 268.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1381	 49	 0.000119	 0.000691	 0.1002	 387.0	 387.0	 387.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1411	 49	 0.00083	 0.005175	 0.0203	 323.0	 323.0	 323.0	 0.0	 0.0	 1	 -30.0	 30.0;
	836	 49	 0.001314	 0.012115	 0.0673	 943.0	 943.0	 943.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1379	 49	 5.9e-05	 0.000217	 0.0496	 323.0	 323.0	 323.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1378	 49	 5.9e-05	 0.000217	 0.0466	 323.0	 323.0	 323.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1169	 50	 0.000158	 0.000948	 0.002	 348.0	 348.0	 348.0	 0.0	 0.0	 1	 -30.0	 30.0;
	704	 51	 0.001521	 0.007076	 0.0118	 302.0	 302.0	 302.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1265	 51	 0.002469	 0.011457	 0.0203	 315.0	 315.0	 315.0	 0.0	 0.0	 1	 -30.0	 30.0;
	404	 52	 0.001442	 0.009699	 0.0172	 566.0	 566.0	 566.0	 0.0	 0.0	 1	 -30.0	 30.0;
	427	 52	 0.001422	 0.009541	 0.0172	 566.0	 566.0	 566.0	 0.0	 0.0	 1	 -30.0	 30.0;
	459	 53	 0.004681	 0.028227	 0.0516	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	765	 53	 0.001185	 0.008	 0.0152	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1529	 53	 0.005333	 0.02722	 0.0491	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	766	 54	 0.000145	 0.001911	 0.0661	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1416	 54	 0.000253	 0.003323	 0.1148	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1101	 56	 0.000494	 0.002252	 0.004	 406.0	 406.0	 406.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1101	 55	 0.000494	 0.002252	 0.004	 406.0	 406.0	 406.0	 0.0	 0.0	 1	 -30.0	 30.0;
	320	 1827	 0.009857	 0.04478	 0.077	 405.0	 405.0	 405.0	 0.0	 0.0	 1	 -30.0	 30.0;
	813	 1827	 0.017106	 0.078321	 0.1387	 362.0	 362.0	 362.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1287	 1827	 0.010272	 0.048691	 0.0866	 354.0	 354.0	 354.0	 0.0	 0.0	 1	 -30.0	 30.0;
	461	 57	 0.012978	 0.059338	 0.1002	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	827	 57	 0.01197	 0.056632	 0.0942	 262.0	 262.0	 262.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1429	 58	 0.000578	 0.001156	 0.0004	 24825	 24825	 24825	 0.0	 0.0	 1	 -30.0	 30.0;
	1090	 60	 0.000316	 0.001679	 0.0192	 17970	 17970	 17970	 0.0	 0.0	 1	 -30.0	 30.0;
	1090	 59	 0.000316	 0.001679	 0.0192	 17970	 17970	 17970	 0.0	 0.0	 1	 -30.0	 30.0;
	713	 61	 0.000277	 0.000573	 0.0334	 48541	 48541	 48541	 0.0	 0.0	 1	 -30.0	 30.0;
	1032	 62	 0.001055	 0.004836	 0.0081	 432.0	 432.0	 432.0	 0.0	 0.0	 1	 -30.0	 30.0;
	998	 63	 0.002114	 0.008553	 0.0152	 346.0	 346.0	 346.0	 0.0	 0.0	 1	 -30.0	 30.0;
	342	 65	 0.000158	 0.000652	 0.084	 46138	 46138	 46138	 0.0	 0.0	 1	 -30.0	 30.0;
	894	 64	 0.000198	 0.000731	 0.0942	 385.0	 385.0	 385.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1265	 66	 0.00324	 0.012616	 0.0225	 302.0	 302.0	 302.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1397	 67	 0.007522	 0.029736	 0.0496	 303.0	 303.0	 303.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1543	 67	 0.006809	 0.03043	 0.0521	 380.0	 380.0	 380.0	 0.0	 0.0	 1	 -30.0	 30.0;
	404	 69	 0.002153	 0.014736	 0.0273	 565.0	 565.0	 565.0	 0.0	 0.0	 1	 -30.0	 30.0;
	469	 68	 0.000581	 0.003838	 0.0071	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	791	 68	 0.001857	 0.020306	 0.0557	 566.0	 566.0	 566.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1348	 69	 0.002331	 0.015526	 0.0278	 549.0	 549.0	 549.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1480	 68	 0.001345	 0.008968	 0.0162	 566.0	 566.0	 566.0	 0.0	 0.0	 1	 -30.0	 30.0;
	470	 68	 0.000573	 0.003911	 0.0071	 415.0	 415.0	 415.0	 0.0	 0.0	 1	 -30.0	 30.0;
	640	 68	 0.001896	 0.012701	 0.0233	 501.0	 501.0	 501.0	 0.0	 0.0	 1	 -30.0	 30.0;
	556	 70	 0.000602	 0.006717	 0.1357	 1725.0	 1725.0	 1725.0	 0.0	 0.0	 1	 -30.0	 30.0;
	792	 70	 0.00063	 0.007098	 0.1588	 1916.0	 1916.0	 1916.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1421	 70	 0.000367	 0.004631	 0.1126	 2275.0	 2275.0	 2275.0	 0.0	 0.0	 1	 -30.0	 30.0;
	792	 70	 0.000472	 0.006201	 0.2137	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1416	 70	 0.001504	 0.019298	 0.4577	 1648	 1648	 1648	 0.0	 0.0	 1	 -30.0	 30.0;
	203	 72	 0.000158	 0.001106	 0.1357	 461.0	 461.0	 461.0	 0.0	 0.0	 1	 -30.0	 30.0;
	375	 71	 0.000219	 0.00193	 0.1954	 407.0	 407.0	 407.0	 0.0	 0.0	 1	 -30.0	 30.0;
	403	 71	 0.000158	 0.000909	 0.1316	 428.0	 428.0	 428.0	 0.0	 0.0	 1	 -30.0	 30.0;
	982	 71	 0.000411	 0.00356	 0.3564	 416.0	 416.0	 416.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1104	 72	 0.000158	 0.001264	 0.1286	 416.0	 416.0	 416.0	 0.0	 0.0	 1	 -30.0	 30.0;
	842	 73	 0.000198	 0.001383	 0.003	 420.0	 420.0	 420.0	 0.0	 0.0	 1	 -30.0	 30.0;
	842	 74	 0.000217	 0.001402	 0.003	 420.0	 420.0	 420.0	 0.0	 0.0	 1	 -30.0	 30.0;
	387	 75	 0.001304	 0.008691	 0.0152	 525.0	 525.0	 525.0	 0.0	 0.0	 1	 -30.0	 30.0;
	842	 75	 0.000691	 0.004662	 0.0091	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78	 76	 9.9e-05	 0.000415	 0.0456	 434.0	 434.0	 434.0	 0.0	 0.0	 1	 -30.0	 30.0;
	300	 77	 1e-06	 0.000104	 0.078	 1051.0	 1051.0	 1051.0	 0.0	 0.0	 1	 -30.0	 30.0;
	436	 77	 0.000353	 0.004584	 0.1184	 2357.0	 2357.0	 2357.0	 0.0	 0.0	 1	 -30.0	 30.0;
	705	 77	 0.000699	 0.009179	 0.3177	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	436	 77	 0.000353	 0.004584	 0.1184	 2357.0	 2357.0	 2357.0	 0.0	 0.0	 1	 -30.0	 30.0;
	705	 77	 0.000734	 0.009245	 0.3148	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	302	 77	 7e-06	 0.000104	 0.0029	 1382.0	 1382.0	 1382.0	 0.0	 0.0	 1	 -30.0	 30.0;
	301	 77	 7e-06	 0.000104	 0.0029	 1382.0	 1382.0	 1382.0	 0.0	 0.0	 1	 -30.0	 30.0;
	435	 78	 0.002556	 0.017333	 0.0805	 418.0	 418.0	 418.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1040	 78	 0.008849	 0.062617	 0.1144	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1431	 79	 2.2e-05	 9.9e-05	 0.001	 405.0	 405.0	 405.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1430	 80	 2e-05	 9.9e-05	 0.0	 306724	 306724	 306724	 0.0	 0.0	 1	 -30.0	 30.0;
	745	 81	 0.000573	 0.002588	 0.0051	 388.0	 388.0	 388.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1432	 82	 2e-05	 0.000198	 0.001	 566.0	 566.0	 566.0	 0.0	 0.0	 1	 -30.0	 30.0;
	626	 83	 0.000138	 0.00077	 0.001	 272.0	 272.0	 272.0	 0.0	 0.0	 1	 -30.0	 30.0;
	181	 84	 0.001171	 0.007842	 0.0166	 296.0	 296.0	 296.0	 0.0	 0.0	 1	 -30.0	 30.0;
	854	 84	 0.002212	 0.014979	 0.0388	 401.0	 401.0	 401.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1186	 85	 0.000691	 0.002588	 0.1691	 11556	 11556	 11556	 0.0	 0.0	 1	 -30.0	 30.0;
	1187	 85	 0.000691	 0.002588	 0.1509	 11556	 11556	 11556	 0.0	 0.0	 1	 -30.0	 30.0;
	553	 86	 0.001627	 0.014855	 0.3899	 1717.0	 1717.0	 1717.0	 0.0	 0.0	 1	 -30.0	 30.0;
	553	 86	 0.001676	 0.013899	 0.4216	 1711.0	 1711.0	 1711.0	 0.0	 0.0	 1	 -30.0	 30.0;
	519	 87	 0.003081	 0.020286	 0.0365	 420.0	 420.0	 420.0	 0.0	 0.0	 1	 -30.0	 30.0;
	870	 87	 0.00241	 0.01603	 0.0294	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1300	 88	 0.000176	 0.001385	 0.1521	 378.0	 378.0	 378.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1351	 88	 0.001817	 0.012642	 0.0233	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1351	 88	 0.001865	 0.012502	 0.0229	 502.0	 502.0	 502.0	 0.0	 0.0	 1	 -30.0	 30.0;
	283	 89	 0.007422	 0.024489	 0.0081	 1227	 1227	 1227	 0.0	 0.0	 1	 -30.0	 30.0;
	467	 89	 0.028356	 0.083956	 0.0274	 355	 355	 355	 0.0	 0.0	 1	 -30.0	 30.0;
	729	 89	 0.016844	 0.058489	 0.0198	 516	 516	 516	 0.0	 0.0	 1	 -30.0	 30.0;
	1335	 89	 0.009067	 0.028133	 0.0095	 1069	 1069	 1069	 0.0	 0.0	 1	 -30.0	 30.0;
	1433	 90	 0.000593	 0.00401	 0.0071	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	376	 91	 0.010351	 0.032395	 0.0562	 903	 903	 903	 0.0	 0.0	 1	 -30.0	 30.0;
	1489	 91	 0.009146	 0.025778	 0.041	 1123	 1123	 1123	 0.0	 0.0	 1	 -30.0	 30.0;
	934	 93	 0.000395	 0.006648	 0.2426	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	950	 93	 0.000492	 0.008345	 0.3032	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1062	 92	 0.001198	 0.015699	 0.5401	 2026	 2026	 2026	 0.0	 0.0	 1	 -30.0	 30.0;
	1110	 93	 0.000734	 0.010623	 0.2772	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1282	 92	 0.001479	 0.019446	 0.6729	 1636	 1636	 1636	 0.0	 0.0	 1	 -30.0	 30.0;
	1347	 92	 0.000305	 0.003975	 0.1386	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	935	 92	 0.000395	 0.006641	 0.2426	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	950	 92	 0.000492	 0.008338	 0.3032	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1062	 93	 0.001184	 0.015568	 0.5372	 2043	 2043	 2043	 0.0	 0.0	 1	 -30.0	 30.0;
	1110	 92	 0.000734	 0.010623	 0.2772	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1281	 93	 0.001482	 0.019467	 0.6729	 1634	 1634	 1634	 0.0	 0.0	 1	 -30.0	 30.0;
	1347	 93	 0.000305	 0.003982	 0.1386	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	937	 92	 0.000388	 0.0066	 0.2397	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	936	 93	 0.000388	 0.006593	 0.2397	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1149	 96	 0.001817	 0.012049	 0.0233	 439.0	 439.0	 439.0	 0.0	 0.0	 1	 -30.0	 30.0;
	149	 97	 0.003496	 0.023269	 0.0425	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	680	 98	 0.030213	 0.105538	 0.0315	 291	 291	 291	 0.0	 0.0	 1	 -30.0	 30.0;
	701	 98	 0.019498	 0.06712	 0.0206	 459	 459	 459	 0.0	 0.0	 1	 -30.0	 30.0;
	702	 99	 0.006262	 0.040849	 0.0749	 398.0	 398.0	 398.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1232	 100	 2e-05	 0.000198	 0.003	 155143	 155143	 155143	 0.0	 0.0	 1	 -30.0	 30.0;
	616	 101	 0.001936	 0.0128	 0.0182	 357.0	 357.0	 357.0	 0.0	 0.0	 1	 -30.0	 30.0;
	231	 104	 2e-05	 0.000198	 0.0081	 155535	 155535	 155535	 0.0	 0.0	 1	 -30.0	 30.0;
	955	 104	 0.000296	 0.000988	 0.2207	 288.0	 288.0	 288.0	 0.0	 0.0	 1	 -30.0	 30.0;
	232	 1828	 8.5e-05	 0.000198	 0.0192	 386.0	 386.0	 386.0	 0.0	 0.0	 1	 -30.0	 30.0;
	542	 105	 0.002487	 0.016492	 0.0304	 434.0	 434.0	 434.0	 0.0	 0.0	 1	 -30.0	 30.0;
	628	 105	 0.000873	 0.003563	 0.004	 370.0	 370.0	 370.0	 0.0	 0.0	 1	 -30.0	 30.0;
	772	 105	 0.003563	 0.023682	 0.044	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1059	 105	 0.002724	 0.018108	 0.0334	 383.0	 383.0	 383.0	 0.0	 0.0	 1	 -30.0	 30.0;
	627	 105	 0.000873	 0.003563	 0.004	 370.0	 370.0	 370.0	 0.0	 0.0	 1	 -30.0	 30.0;
	955	 106	 0.000257	 0.000928	 0.1134	 331.0	 331.0	 331.0	 0.0	 0.0	 1	 -30.0	 30.0;
	122	 107	 0.002291	 0.009936	 0.0304	 307.0	 307.0	 307.0	 0.0	 0.0	 1	 -30.0	 30.0;
	872	 107	 0.004168	 0.028918	 0.0597	 389.0	 389.0	 389.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1127	 107	 0.002054	 0.024691	 0.1276	 584.0	 584.0	 584.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1168	 107	 0.004879	 0.032533	 0.0607	 344.0	 344.0	 344.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1405	 107	 0.005294	 0.036998	 0.0668	 428.0	 428.0	 428.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1436	 107	 0.001422	 0.009896	 0.0172	 428.0	 428.0	 428.0	 0.0	 0.0	 1	 -30.0	 30.0;
	554	 108	 0.002168	 0.029238	 0.9906	 1087	 1087	 1087	 0.0	 0.0	 1	 -30.0	 30.0;
	596	 108	 0.001468	 0.01491	 0.3841	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	776	 108	 0.002479	 0.028151	 0.6296	 1128	 1128	 1128	 0.0	 0.0	 1	 -30.0	 30.0;
	1128	 108	 0.00072	 0.00946	 0.3263	 1382.0	 1382.0	 1382.0	 0.0	 0.0	 1	 -30.0	 30.0;
	597	 108	 0.00142	 0.01617	 0.3636	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	776	 108	 0.002486	 0.028165	 0.6296	 1127	 1127	 1127	 0.0	 0.0	 1	 -30.0	 30.0;
	1216	 108	 0.001184	 0.016073	 0.4869	 1979	 1979	 1979	 0.0	 0.0	 1	 -30.0	 30.0;
	854	 109	 0.000521	 0.002315	 0.019	 13045	 13045	 13045	 0.0	 0.0	 1	 -30.0	 30.0;
	145	 110	 0.000178	 0.000909	 0.002	 405.0	 405.0	 405.0	 0.0	 0.0	 1	 -30.0	 30.0;
	227	 111	 0.00241	 0.015694	 0.0294	 413.0	 413.0	 413.0	 0.0	 0.0	 1	 -30.0	 30.0;
	783	 111	 0.006874	 0.044761	 0.0835	 413.0	 413.0	 413.0	 0.0	 0.0	 1	 -30.0	 30.0;
	772	 112	 0.001521	 0.021728	 0.0871	 831.0	 831.0	 831.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1533	 112	 0.001304	 0.017205	 0.0729	 935.0	 935.0	 935.0	 0.0	 0.0	 1	 -30.0	 30.0;
	297	 113	 0.000336	 0.001363	 0.1499	 331.0	 331.0	 331.0	 0.0	 0.0	 1	 -30.0	 30.0;
	371	 113	 0.000178	 0.001422	 0.1448	 339.0	 339.0	 339.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1348	 114	 0.002252	 0.011951	 0.0218	 432.0	 432.0	 432.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1435	 114	 0.00079	 0.005333	 0.0101	 432.0	 432.0	 432.0	 0.0	 0.0	 1	 -30.0	 30.0;
	394	 115	 0.001501	 0.010015	 0.0182	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	413	 115	 0.003103	 0.021146	 0.04	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1341	 115	 0.00162	 0.010765	 0.0203	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1514	 115	 0.001807	 0.017201	 0.0618	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	132	 115	 0.000217	 0.001442	 0.003	 545.0	 545.0	 545.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1341	 115	 0.00162	 0.010726	 0.0203	 535.0	 535.0	 535.0	 0.0	 0.0	 1	 -30.0	 30.0;
	131	 115	 0.000119	 0.001086	 0.004	 545.0	 545.0	 545.0	 0.0	 0.0	 1	 -30.0	 30.0;
	651	 117	 0.00072	 0.009453	 0.3263	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	774	 117	 0.003206	 0.03536	 0.9025	 899	 899	 899	 0.0	 0.0	 1	 -30.0	 30.0;
	1367	 117	 0.000616	 0.008054	 0.2772	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	651	 117	 0.000713	 0.009384	 0.3235	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1368	 117	 0.000616	 0.008061	 0.2772	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	133	 117	 3.5e-05	 0.000374	 0.0087	 921.0	 921.0	 921.0	 0.0	 0.0	 1	 -30.0	 30.0;
	990	 119	 0.013393	 0.069551	 0.1261	 391.0	 391.0	 391.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1031	 119	 0.013491	 0.070361	 0.1271	 412.0	 412.0	 412.0	 0.0	 0.0	 1	 -30.0	 30.0;
	845	 120	 0.001956	 0.010469	 0.3286	 461.0	 461.0	 461.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1021	 120	 0.001402	 0.010173	 0.2673	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1302	 121	 0.000648	 0.00657	 0.1704	 1633.0	 1633.0	 1633.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1302	 121	 0.000651	 0.006572	 0.1704	 1633.0	 1633.0	 1633.0	 0.0	 0.0	 1	 -30.0	 30.0;
	622	 123	 0.00332	 0.015328	 0.0267	 288.0	 288.0	 288.0	 0.0	 0.0	 1	 -30.0	 30.0;
	716	 124	 0.007307	 0.029226	 0.0316	 1010	 1010	 1010	 0.0	 0.0	 1	 -30.0	 30.0;
	1487	 124	 0.006551	 0.01285	 0.0128	 2109	 2109	 2109	 0.0	 0.0	 1	 -30.0	 30.0;
	1437	 125	 2.4e-05	 9.7e-05	 0.001	 473.0	 473.0	 473.0	 0.0	 0.0	 1	 -30.0	 30.0;
	157	 126	 9.9e-05	 0.000198	 0.0223	 288.0	 288.0	 288.0	 0.0	 0.0	 1	 -30.0	 30.0;
	158	 130	 1.4e-05	 0.000145	 0.0029	 1382.0	 1382.0	 1382.0	 0.0	 0.0	 1	 -30.0	 30.0;
	158	 127	 7e-06	 0.000159	 0.0029	 1382.0	 1382.0	 1382.0	 0.0	 0.0	 1	 -30.0	 30.0;
	158	 128	 1.4e-05	 0.000166	 0.0058	 1737.0	 1737.0	 1737.0	 0.0	 0.0	 1	 -30.0	 30.0;
	158	 129	 1.4e-05	 0.00018	 0.0058	 1382.0	 1382.0	 1382.0	 0.0	 0.0	 1	 -30.0	 30.0;
	845	 135	 0.000251	 0.002177	 0.2187	 405.0	 405.0	 405.0	 0.0	 0.0	 1	 -30.0	 30.0;
	839	 136	 0.001084	 0.014247	 0.491	 2232	 2232	 2232	 0.0	 0.0	 1	 -30.0	 30.0;
	890	 136	 0.000492	 0.006489	 0.2224	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	915	 136	 7e-06	 0.000152	 0.0058	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	838	 136	 0.001112	 0.01462	 0.5054	 2175	 2175	 2175	 0.0	 0.0	 1	 -30.0	 30.0;
	891	 136	 0.000492	 0.006489	 0.2238	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	916	 136	 7e-06	 0.000104	 0.0029	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	395	 137	 0.001264	 0.00964	 0.0375	 399.0	 399.0	 399.0	 0.0	 0.0	 1	 -30.0	 30.0;
	408	 137	 0.001264	 0.008415	 0.0152	 502.0	 502.0	 502.0	 0.0	 0.0	 1	 -30.0	 30.0;
	811	 137	 0.002627	 0.012188	 0.0218	 292.0	 292.0	 292.0	 0.0	 0.0	 1	 -30.0	 30.0;
	812	 137	 0.001063	 0.007064	 0.0132	 433.0	 433.0	 433.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1241	 137	 0.002489	 0.016711	 0.0304	 433.0	 433.0	 433.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1486	 137	 0.0016	 0.014933	 0.0537	 384.0	 384.0	 384.0	 0.0	 0.0	 1	 -30.0	 30.0;
	395	 137	 0.001264	 0.009659	 0.0405	 399.0	 399.0	 399.0	 0.0	 0.0	 1	 -30.0	 30.0;
	263	 138	 0.000501	 0.005472	 0.1155	 1429.0	 1429.0	 1429.0	 0.0	 0.0	 1	 -30.0	 30.0;
	821	 138	 0.000429	 0.004737	 0.1011	 1711.0	 1711.0	 1711.0	 0.0	 0.0	 1	 -30.0	 30.0;
	376	 140	 0.000553	 0.003714	 0.0116	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	416	 140	 0.003951	 0.020148	 0.0511	 369.0	 369.0	 369.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1279	 141	 0.007447	 0.034884	 0.0628	 369.0	 369.0	 369.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1314	 140	 0.000632	 0.004286	 0.0081	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	376	 140	 0.000553	 0.003714	 0.0121	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	986	 140	 0.001106	 0.005353	 0.0091	 5617	 5617	 5617	 0.0	 0.0	 1	 -30.0	 30.0;
	1314	 141	 0.000672	 0.004543	 0.0081	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	919	 142	 0.004188	 0.027872	 0.0516	 485.0	 485.0	 485.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1336	 142	 0.00322	 0.022183	 0.0395	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1336	 142	 0.00322	 0.022183	 0.0395	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	395	 143	 0.000217	 0.00081	 0.1013	 434.0	 434.0	 434.0	 0.0	 0.0	 1	 -30.0	 30.0;
	395	 144	 0.000257	 0.000988	 0.1215	 271.0	 271.0	 271.0	 0.0	 0.0	 1	 -30.0	 30.0;
	813	 145	 0.003358	 0.02242	 0.0415	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1524	 145	 0.003437	 0.022933	 0.0425	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	827	 146	 0.002145	 0.009679	 0.017	 296.0	 296.0	 296.0	 0.0	 0.0	 1	 -30.0	 30.0;
	827	 147	 0.002125	 0.009576	 0.0168	 296.0	 296.0	 296.0	 0.0	 0.0	 1	 -30.0	 30.0;
	517	 148	 0.000691	 0.001383	 0.2045	 20021	 20021	 20021	 0.0	 0.0	 1	 -30.0	 30.0;
	1108	 149	 0.001699	 0.011299	 0.0213	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	416	 150	 0.0048	 0.022637	 0.0405	 384.0	 384.0	 384.0	 0.0	 0.0	 1	 -30.0	 30.0;
	871	 150	 0.003319	 0.015664	 0.0263	 384.0	 384.0	 384.0	 0.0	 0.0	 1	 -30.0	 30.0;
	181	 151	 0.000514	 0.001541	 0.1144	 19054	 19054	 19054	 0.0	 0.0	 1	 -30.0	 30.0;
	354	 153	 0.00324	 0.034272	 0.1336	 892	 892	 892	 0.0	 0.0	 1	 -30.0	 30.0;
	494	 154	 0.005077	 0.023783	 0.0425	 369.0	 369.0	 369.0	 0.0	 0.0	 1	 -30.0	 30.0;
	918	 154	 0.002368	 0.018825	 0.0511	 519.0	 519.0	 519.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1027	 154	 0.003279	 0.043101	 0.1822	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1238	 154	 0.0014	 0.011018	 0.0192	 519.0	 519.0	 519.0	 0.0	 0.0	 1	 -30.0	 30.0;
	153	 152	 4.8e-05	 8.8e-05	 0.004	 935.0	 935.0	 935.0	 0.0	 0.0	 1	 -30.0	 30.0;
	983	 155	 0.000102	 0.001632	 0.0491	 2450.0	 2450.0	 2450.0	 0.0	 0.0	 1	 -30.0	 30.0;
	438	 156	 0.001027	 0.017738	 0.0101	 1954	 1954	 1954	 0.0	 0.0	 1	 -30.0	 30.0;
	626	 156	 0.000318	 0.002424	 0.0052	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	437	 156	 0.001027	 0.017738	 0.0101	 1954	 1954	 1954	 0.0	 0.0	 1	 -30.0	 30.0;
	626	 156	 0.000397	 0.002657	 0.0051	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	857	 158	 0.000637	 0.008255	 0.2123	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	979	 158	 0.000688	 0.009993	 0.257	 2368.0	 2368.0	 2368.0	 0.0	 0.0	 1	 -30.0	 30.0;
	390	 158	 0.000443	 0.006454	 0.1675	 2368.0	 2368.0	 2368.0	 0.0	 0.0	 1	 -30.0	 30.0;
	978	 158	 0.000688	 0.009993	 0.257	 2368.0	 2368.0	 2368.0	 0.0	 0.0	 1	 -30.0	 30.0;
	390	 158	 0.000464	 0.006766	 0.1762	 2368.0	 2368.0	 2368.0	 0.0	 0.0	 1	 -30.0	 30.0;
	390	 158	 0.000464	 0.006773	 0.1762	 2368.0	 2368.0	 2368.0	 0.0	 0.0	 1	 -30.0	 30.0;
	980	 159	 0.001025	 0.004614	 0.0081	 380.0	 380.0	 380.0	 0.0	 0.0	 1	 -30.0	 30.0;
	947	 160	 0.001934	 0.01293	 0.024	 428.0	 428.0	 428.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1351	 160	 0.004642	 0.03089	 0.0573	 428.0	 428.0	 428.0	 0.0	 0.0	 1	 -30.0	 30.0;
	164	 163	 0.000968	 0.001975	 0.0081	 337.0	 337.0	 337.0	 0.0	 0.0	 1	 -30.0	 30.0;
	164	 161	 0.000968	 0.001975	 0.001	 335.0	 335.0	 335.0	 0.0	 0.0	 1	 -30.0	 30.0;
	164	 162	 0.000968	 0.001975	 0.001	 335.0	 335.0	 335.0	 0.0	 0.0	 1	 -30.0	 30.0;
	785	 164	 0.00348	 0.023956	 0.0456	 535.0	 535.0	 535.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1007	 164	 0.002449	 0.017106	 0.0304	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1453	 164	 0.006001	 0.041452	 0.078	 515.0	 515.0	 515.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1500	 165	 4e-05	 0.000198	 0.0	 153231	 153231	 153231	 0.0	 0.0	 1	 -30.0	 30.0;
	658	 166	 0.001205	 0.005511	 0.0091	 325.0	 325.0	 325.0	 0.0	 0.0	 1	 -30.0	 30.0;
	574	 167	 0.01438	 0.065067	 0.1154	 328.0	 328.0	 328.0	 0.0	 0.0	 1	 -30.0	 30.0;
	827	 167	 0.003538	 0.016484	 0.0273	 325.0	 325.0	 325.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1006	 167	 0.012634	 0.056573	 0.1008	 328.0	 328.0	 328.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1460	 167	 0.003516	 0.016158	 0.0273	 328.0	 328.0	 328.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1464	 167	 0.00316	 0.014914	 0.0253	 305.0	 305.0	 305.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1542	 167	 0.007704	 0.034647	 0.0607	 328.0	 328.0	 328.0	 0.0	 0.0	 1	 -30.0	 30.0;
	827	 167	 0.002489	 0.016257	 0.0294	 418.0	 418.0	 418.0	 0.0	 0.0	 1	 -30.0	 30.0;
	282	 167	 0.003457	 0.015467	 0.0273	 309.0	 309.0	 309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	776	 168	 0.006579	 0.049467	 1.0137	 639	 639	 639	 0.0	 0.0	 1	 -30.0	 30.0;
	1126	 168	 0.001357	 0.014821	 0.3321	 1171.0	 1171.0	 1171.0	 0.0	 0.0	 1	 -30.0	 30.0;
	760	 169	 0.00352	 0.014823	 0.0263	 2065	 2065	 2065	 0.0	 0.0	 1	 -30.0	 30.0;
	1439	 170	 0.001111	 0.003244	 0.0014	 8880	 8880	 8880	 0.0	 0.0	 1	 -30.0	 30.0;
	1438	 172	 2e-05	 0.000198	 0.0223	 155535	 155535	 155535	 0.0	 0.0	 1	 -30.0	 30.0;
	1440	 171	 9.9e-05	 0.000296	 0.004	 99170	 99170	 99170	 0.0	 0.0	 1	 -30.0	 30.0;
	1415	 173	 0.000936	 0.006236	 0.0146	 441.0	 441.0	 441.0	 0.0	 0.0	 1	 -30.0	 30.0;
	958	 181	 0.001636	 0.010939	 0.0216	 296.0	 296.0	 296.0	 0.0	 0.0	 1	 -30.0	 30.0;
	769	 182	 0.000257	 0.001758	 0.003	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1082	 182	 0.00162	 0.011121	 0.0213	 408.0	 408.0	 408.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1242	 186	 1.4e-05	 0.000173	 0.0982	 183736	 183736	 183736	 0.0	 0.0	 1	 -30.0	 30.0;
	1243	 185	 1.4e-05	 0.000187	 0.0809	 170060	 170060	 170060	 0.0	 0.0	 1	 -30.0	 30.0;
	1242	 183	 1.4e-05	 0.000201	 0.0058	 158275	 158275	 158275	 0.0	 0.0	 1	 -30.0	 30.0;
	1243	 184	 1.4e-05	 0.000201	 0.0058	 158275	 158275	 158275	 0.0	 0.0	 1	 -30.0	 30.0;
	1032	 187	 0.005215	 0.035002	 0.0638	 487.0	 487.0	 487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	477	 188	 0.001397	 0.009306	 0.0172	 340.0	 340.0	 340.0	 0.0	 0.0	 1	 -30.0	 30.0;
	763	 188	 0.003415	 0.021827	 0.04	 325.0	 325.0	 325.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1441	 189	 2e-05	 9.9e-05	 0.0	 394.0	 394.0	 394.0	 0.0	 0.0	 1	 -30.0	 30.0;
	554	 190	 7e-06	 0.000132	 0.0058	 1842.0	 1842.0	 1842.0	 0.0	 0.0	 1	 -30.0	 30.0;
	554	 191	 7e-06	 0.000104	 0.0029	 1842.0	 1842.0	 1842.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1274	 192	 0.000237	 0.000573	 0.078	 268.0	 268.0	 268.0	 0.0	 0.0	 1	 -30.0	 30.0;
	674	 194	 0.000869	 0.003891	 0.0116	 414.0	 414.0	 414.0	 0.0	 0.0	 1	 -30.0	 30.0;
	674	 193	 0.000869	 0.003891	 0.0116	 414.0	 414.0	 414.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1443	 197	 0.002706	 0.0128	 0.0213	 292.0	 292.0	 292.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1452	 198	 0.00237	 0.015803	 0.0294	 558.0	 558.0	 558.0	 0.0	 0.0	 1	 -30.0	 30.0;
	493	 199	 0.003554	 0.024524	 0.0466	 404.0	 404.0	 404.0	 0.0	 0.0	 1	 -30.0	 30.0;
	586	 199	 0.006493	 0.043265	 0.08	 558.0	 558.0	 558.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1183	 199	 0.007921	 0.053985	 0.1013	 558.0	 558.0	 558.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1478	 199	 0.004543	 0.030262	 0.0557	 485.0	 485.0	 485.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1238	 200	 0.001126	 0.004978	 0.0091	 6053	 6053	 6053	 0.0	 0.0	 1	 -30.0	 30.0;
	267	 201	 0.003536	 0.01683	 0.0284	 306.0	 306.0	 306.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1212	 201	 0.001541	 0.009936	 0.0258	 3054	 3054	 3054	 0.0	 0.0	 1	 -30.0	 30.0;
	1328	 201	 0.008375	 0.039704	 0.0658	 274.0	 274.0	 274.0	 0.0	 0.0	 1	 -30.0	 30.0;
	229	 202	 0.011378	 0.053886	 0.0957	 311.0	 311.0	 311.0	 0.0	 0.0	 1	 -30.0	 30.0;
	708	 202	 0.003457	 0.023724	 0.0445	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	750	 202	 0.008415	 0.041422	 0.0739	 362.0	 362.0	 362.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1176	 202	 0.003793	 0.017007	 0.0294	 413.0	 413.0	 413.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1530	 202	 0.004701	 0.026726	 0.0481	 413.0	 413.0	 413.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1833	 202	 0.001877	 0.018252	 0.0638	 604.0	 604.0	 604.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1833	 202	 0.001857	 0.017521	 0.0648	 935.0	 935.0	 935.0	 0.0	 0.0	 1	 -30.0	 30.0;
	447	 203	 4.8e-05	 8.8e-05	 0.0051	 308785	 308785	 308785	 0.0	 0.0	 1	 -30.0	 30.0;
	1156	 203	 0.000533	 0.004642	 0.4647	 461.0	 461.0	 461.0	 0.0	 0.0	 1	 -30.0	 30.0;
	477	 204	 0.002827	 0.011058	 0.0192	 363.0	 363.0	 363.0	 0.0	 0.0	 1	 -30.0	 30.0;
	763	 204	 0.002258	 0.00946	 0.0172	 363.0	 363.0	 363.0	 0.0	 0.0	 1	 -30.0	 30.0;
	730	 205	 0.001363	 0.009126	 0.0172	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1329	 205	 0.0016	 0.010825	 0.0203	 470.0	 470.0	 470.0	 0.0	 0.0	 1	 -30.0	 30.0;
	730	 205	 0.001402	 0.009422	 0.0172	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1329	 205	 0.00162	 0.010963	 0.0213	 470.0	 470.0	 470.0	 0.0	 0.0	 1	 -30.0	 30.0;
	121	 206	 0.001153	 0.010798	 0.283	 1355.0	 1355.0	 1355.0	 0.0	 0.0	 1	 -30.0	 30.0;
	121	 206	 0.00115	 0.010796	 0.283	 1355.0	 1355.0	 1355.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1025	 207	 0.000377	 0.00069	 0.0273	 39366	 39366	 39366	 0.0	 0.0	 1	 -30.0	 30.0;
	1104	 207	 0.000336	 0.001304	 0.2906	 22986	 22986	 22986	 0.0	 0.0	 1	 -30.0	 30.0;
	208	 1829	 2e-05	 0.000198	 0.001	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1189	 208	 0.005472	 0.024889	 0.0445	 327.0	 327.0	 327.0	 0.0	 0.0	 1	 -30.0	 30.0;
	440	 209	 0.002015	 0.013551	 0.0764	 449.0	 449.0	 449.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1052	 209	 0.012484	 0.056454	 0.1002	 362.0	 362.0	 362.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1071	 209	 0.000869	 0.003911	 0.0071	 304.0	 304.0	 304.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1072	 209	 0.000869	 0.003911	 0.0071	 304.0	 304.0	 304.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1539	 209	 0.001001	 0.006712	 0.0121	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1442	 210	 0.000614	 0.004093	 0.0278	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	479	 211	 0.000523	 0.002596	 0.2992	 342.0	 342.0	 342.0	 0.0	 0.0	 1	 -30.0	 30.0;
	196	 213	 0.00484	 0.021393	 0.0385	 292.0	 292.0	 292.0	 0.0	 0.0	 1	 -30.0	 30.0;
	218	 213	 0.001541	 0.007309	 0.0121	 292.0	 292.0	 292.0	 0.0	 0.0	 1	 -30.0	 30.0;
	251	 213	 0.000672	 0.004602	 0.0152	 430.0	 430.0	 430.0	 0.0	 0.0	 1	 -30.0	 30.0;
	567	 213	 0.00243	 0.011477	 0.0192	 333.0	 333.0	 333.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1338	 213	 0.002311	 0.011378	 0.0233	 333.0	 333.0	 333.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1447	 213	 0.000474	 0.002331	 0.0081	 333.0	 333.0	 333.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1455	 213	 0.002825	 0.019082	 0.0344	 423.0	 423.0	 423.0	 0.0	 0.0	 1	 -30.0	 30.0;
	544	 213	 0.004286	 0.029037	 0.0527	 423.0	 423.0	 423.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1443	 213	 0.002074	 0.009758	 0.0162	 292.0	 292.0	 292.0	 0.0	 0.0	 1	 -30.0	 30.0;
	263	 215	 0.001566	 0.015874	 0.4101	 1711.0	 1711.0	 1711.0	 0.0	 0.0	 1	 -30.0	 30.0;
	357	 215	 0.001309	 0.01286	 0.335	 1611.0	 1611.0	 1611.0	 0.0	 0.0	 1	 -30.0	 30.0;
	260	 216	 7e-06	 0.000125	 0.0029	 552.0	 552.0	 552.0	 0.0	 0.0	 1	 -30.0	 30.0;
	559	 216	 0.000693	 0.007687	 0.1704	 1355.0	 1355.0	 1355.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1443	 217	 0.000691	 0.003279	 0.0051	 292.0	 292.0	 292.0	 0.0	 0.0	 1	 -30.0	 30.0;
	425	 220	 0.000277	 0.001916	 0.003	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	425	 219	 0.000277	 0.001936	 0.003	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1055	 221	 0.000217	 0.001205	 0.0086	 257.0	 257.0	 257.0	 0.0	 0.0	 1	 -30.0	 30.0;
	448	 222	 0.00162	 0.007447	 0.0132	 322.0	 322.0	 322.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1050	 222	 0.000889	 0.005965	 0.0111	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	479	 223	 0.000533	 0.003536	 0.0061	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1444	 224	 0.000178	 0.001185	 0.002	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	614	 225	 0.002889	 0.0064	 0.0022	 4554	 4554	 4554	 0.0	 0.0	 1	 -30.0	 30.0;
	1030	 1830	 0.000205	 0.002108	 0.2577	 546.0	 546.0	 546.0	 0.0	 0.0	 1	 -30.0	 30.0;
	350	 226	 0.002899	 0.029385	 0.7595	 1075	 1075	 1075	 0.0	 0.0	 1	 -30.0	 30.0;
	787	 226	 0.002045	 0.020735	 0.5343	 1524	 1524	 1524	 0.0	 0.0	 1	 -30.0	 30.0;
	783	 227	 0.00924	 0.060219	 0.1124	 413.0	 413.0	 413.0	 0.0	 0.0	 1	 -30.0	 30.0;
	846	 227	 0.009007	 0.066726	 0.1192	 467	 467	 467	 0.0	 0.0	 1	 -30.0	 30.0;
	893	 227	 0.004543	 0.030479	 0.0547	 420.0	 420.0	 420.0	 0.0	 0.0	 1	 -30.0	 30.0;
	893	 227	 0.004326	 0.029037	 0.0527	 389.0	 389.0	 389.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1150	 228	 0.001357	 0.017597	 0.3494	 1807	 1807	 1807	 0.0	 0.0	 1	 -30.0	 30.0;
	1150	 228	 0.001343	 0.01741	 0.3437	 1827	 1827	 1827	 0.0	 0.0	 1	 -30.0	 30.0;
	1032	 229	 0.003615	 0.024178	 0.0445	 566.0	 566.0	 566.0	 0.0	 0.0	 1	 -30.0	 30.0;
	739	 230	 0.001136	 0.012154	 0.2657	 1708.0	 1708.0	 1708.0	 0.0	 0.0	 1	 -30.0	 30.0;
	792	 230	 0.001309	 0.013996	 0.3061	 1917.0	 1917.0	 1917.0	 0.0	 0.0	 1	 -30.0	 30.0;
	910	 232	 0.000257	 0.001521	 0.162	 335.0	 335.0	 335.0	 0.0	 0.0	 1	 -30.0	 30.0;
	942	 232	 0.000259	 0.000506	 0.042	 272.0	 272.0	 272.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1173	 233	 0.000928	 0.006202	 0.0111	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1173	 234	 0.000928	 0.006202	 0.0111	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1446	 235	 2e-05	 0.000198	 0.001	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1445	 236	 2e-05	 0.000198	 0.001	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	581	 237	 0.001067	 0.00723	 0.0132	 335.0	 335.0	 335.0	 0.0	 0.0	 1	 -30.0	 30.0;
	841	 238	 0.003358	 0.022341	 0.0415	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1012	 237	 0.00318	 0.020938	 0.0395	 335.0	 335.0	 335.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1280	 237	 0.000928	 0.008968	 0.0314	 935.0	 935.0	 935.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1547	 238	 0.004899	 0.022815	 0.0405	 300.0	 300.0	 300.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1280	 238	 0.000889	 0.008415	 0.0314	 935.0	 935.0	 935.0	 0.0	 0.0	 1	 -30.0	 30.0;
	632	 239	 0.000237	 0.001422	 0.1686	 21471	 21471	 21471	 0.0	 0.0	 1	 -30.0	 30.0;
	848	 240	 0.000277	 0.001086	 0.1417	 27618	 27618	 27618	 0.0	 0.0	 1	 -30.0	 30.0;
	1178	 240	 0.000296	 0.000672	 0.0678	 42153	 42153	 42153	 0.0	 0.0	 1	 -30.0	 30.0;
	386	 242	 0.002267	 0.007156	 0.0022	 4057	 4057	 4057	 0.0	 0.0	 1	 -30.0	 30.0;
	1367	 243	 0.000286	 0.004868	 0.1762	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1367	 244	 0.000287	 0.004892	 0.1776	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1368	 245	 0.000283	 0.004814	 0.1762	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1368	 246	 0.000285	 0.004843	 0.1733	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	997	 247	 0.000514	 0.001383	 0.0952	 20979	 20979	 20979	 0.0	 0.0	 1	 -30.0	 30.0;
	1164	 247	 0.000247	 0.001084	 0.1478	 403.0	 403.0	 403.0	 0.0	 0.0	 1	 -30.0	 30.0;
	670	 249	 0.013096	 0.066153	 0.12	 336.0	 336.0	 336.0	 0.0	 0.0	 1	 -30.0	 30.0;
	702	 248	 0.002074	 0.009956	 0.0172	 336.0	 336.0	 336.0	 0.0	 0.0	 1	 -30.0	 30.0;
	702	 248	 0.001533	 0.009225	 0.0172	 422.0	 422.0	 422.0	 0.0	 0.0	 1	 -30.0	 30.0;
	702	 249	 0.00156	 0.009343	 0.0172	 422.0	 422.0	 422.0	 0.0	 0.0	 1	 -30.0	 30.0;
	784	 250	 0.001452	 0.020223	 0.6741	 1573	 1573	 1573	 0.0	 0.0	 1	 -30.0	 30.0;
	1352	 250	 0.001672	 0.022177	 0.7607	 1434	 1434	 1434	 0.0	 0.0	 1	 -30.0	 30.0;
	784	 250	 0.001447	 0.020166	 0.6721	 1578	 1578	 1578	 0.0	 0.0	 1	 -30.0	 30.0;
	1352	 250	 0.001669	 0.022168	 0.7624	 1435	 1435	 1435	 0.0	 0.0	 1	 -30.0	 30.0;
	891	 252	 0.002874	 0.022174	 0.4476	 1397.0	 1397.0	 1397.0	 0.0	 0.0	 1	 -30.0	 30.0;
	949	 252	 0.000139	 0.001115	 0.0231	 1486.0	 1486.0	 1486.0	 0.0	 0.0	 1	 -30.0	 30.0;
	972	 255	 0.00322	 0.021136	 0.0395	 460.0	 460.0	 460.0	 0.0	 0.0	 1	 -30.0	 30.0;
	991	 255	 0.000553	 0.003694	 0.0071	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1482	 253	 0.000494	 0.005689	 0.0142	 720.0	 720.0	 720.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1494	 255	 0.000652	 0.004504	 0.0081	 437.0	 437.0	 437.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1495	 255	 0.000652	 0.004504	 0.0081	 524.0	 524.0	 524.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1481	 253	 0.000514	 0.005689	 0.0142	 720.0	 720.0	 720.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1469	 254	 0.000869	 0.008435	 0.0339	 935.0	 935.0	 935.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1470	 254	 0.000889	 0.008553	 0.039	 935.0	 935.0	 935.0	 0.0	 0.0	 1	 -30.0	 30.0;
	814	 258	 0.000686	 0.007091	 0.1747	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1282	 258	 0.000609	 0.006378	 0.1473	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	814	 257	 0.000686	 0.007119	 0.1747	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1281	 257	 0.000609	 0.006406	 0.1487	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1360	 259	 0.002074	 0.013847	 0.0253	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1360	 259	 0.002074	 0.013847	 0.0253	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	295	 261	 0.00083	 0.005649	 0.0111	 558.0	 558.0	 558.0	 0.0	 0.0	 1	 -30.0	 30.0;
	348	 261	 0.002193	 0.014894	 0.0284	 558.0	 558.0	 558.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1447	 262	 0.00638	 0.031486	 0.0537	 333.0	 333.0	 333.0	 0.0	 0.0	 1	 -30.0	 30.0;
	357	 263	 0.002877	 0.028829	 0.7494	 1100	 1100	 1100	 0.0	 0.0	 1	 -30.0	 30.0;
	363	 263	 0.002188	 0.024233	 0.5227	 1311	 1311	 1311	 0.0	 0.0	 1	 -30.0	 30.0;
	623	 263	 0.000997	 0.014175	 0.465	 2245	 2245	 2245	 0.0	 0.0	 1	 -30.0	 30.0;
	821	 263	 0.000376	 0.002891	 0.0606	 1308.0	 1308.0	 1308.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1008	 263	 0.000976	 0.009886	 0.2541	 1711.0	 1711.0	 1711.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1243	 263	 0.000389	 0.003951	 0.1011	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	363	 263	 0.001562	 0.01912	 0.4274	 1567.0	 1567.0	 1567.0	 0.0	 0.0	 1	 -30.0	 30.0;
	623	 263	 0.000998	 0.014177	 0.465	 2244	 2244	 2244	 0.0	 0.0	 1	 -30.0	 30.0;
	821	 263	 0.000199	 0.002553	 0.0838	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1008	 263	 0.000976	 0.009891	 0.2541	 1711.0	 1711.0	 1711.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1242	 263	 0.000388	 0.003954	 0.1011	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1242	 263	 0.000395	 0.004003	 0.104	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1243	 263	 0.000395	 0.004003	 0.104	 1711.0	 1711.0	 1711.0	 0.0	 0.0	 1	 -30.0	 30.0;
	420	 267	 0.003101	 0.020859	 0.0375	 406.0	 406.0	 406.0	 0.0	 0.0	 1	 -30.0	 30.0;
	420	 267	 0.004978	 0.022005	 0.0359	 406.0	 406.0	 406.0	 0.0	 0.0	 1	 -30.0	 30.0;
	420	 267	 0.003121	 0.0208	 0.0506	 492.0	 492.0	 492.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1353	 269	 0.000499	 0.005048	 0.13	 1380.0	 1380.0	 1380.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1353	 268	 0.000499	 0.005042	 0.13	 1380.0	 1380.0	 1380.0	 0.0	 0.0	 1	 -30.0	 30.0;
	500	 271	 0.002193	 0.010884	 0.0197	 321.0	 321.0	 321.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1179	 271	 0.004049	 0.018272	 0.0324	 302.0	 302.0	 302.0	 0.0	 0.0	 1	 -30.0	 30.0;
	365	 272	 0.011032	 0.050442	 0.0871	 325.0	 325.0	 325.0	 0.0	 0.0	 1	 -30.0	 30.0;
	602	 272	 0.001481	 0.013926	 0.0516	 604.0	 604.0	 604.0	 0.0	 0.0	 1	 -30.0	 30.0;
	602	 272	 0.001481	 0.013926	 0.0516	 604.0	 604.0	 604.0	 0.0	 0.0	 1	 -30.0	 30.0;
	436	 273	 0.0016	 0.017334	 0.4043	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	705	 273	 0.000312	 0.004044	 0.1386	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1041	 273	 0.000824	 0.010499	 0.3754	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1390	 273	 0.00133	 0.014252	 0.3263	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	705	 273	 0.000312	 0.004044	 0.1386	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1041	 273	 0.000824	 0.010505	 0.3754	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1079	 274	 0.001936	 0.012879	 0.0243	 535.0	 535.0	 535.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1236	 275	 0.000164	 0.001106	 0.002	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	318	 276	 0.000336	 0.000849	 0.1448	 428.0	 428.0	 428.0	 0.0	 0.0	 1	 -30.0	 30.0;
	341	 276	 0.000178	 0.000691	 0.1002	 311.0	 311.0	 311.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1371	 276	 0.000316	 0.001304	 0.1863	 404.0	 404.0	 404.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1381	 276	 9.9e-05	 0.000612	 0.082	 387.0	 387.0	 387.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1334	 279	 0.001146	 0.007111	 0.2238	 298.0	 298.0	 298.0	 0.0	 0.0	 1	 -30.0	 30.0;
	596	 280	 0.001136	 0.012874	 0.2917	 1611.0	 1611.0	 1611.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1008	 280	 0.000547	 0.010021	 0.2801	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1243	 280	 0.001184	 0.012029	 0.309	 1711.0	 1711.0	 1711.0	 0.0	 0.0	 1	 -30.0	 30.0;
	458	 280	 0.000369	 0.006726	 0.1892	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	597	 280	 0.001136	 0.012874	 0.2917	 1611.0	 1611.0	 1611.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1242	 280	 0.001177	 0.012029	 0.309	 1711.0	 1711.0	 1711.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1460	 281	 7.9e-05	 0.000316	 0.001	 328.0	 328.0	 328.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1120	 283	 0.001956	 0.008844	 0.0027	 3362	 3362	 3362	 0.0	 0.0	 1	 -30.0	 30.0;
	1527	 285	 0.000198	 0.000672	 0.1509	 257.0	 257.0	 257.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1526	 284	 0.000198	 0.000691	 0.1529	 257.0	 257.0	 257.0	 0.0	 0.0	 1	 -30.0	 30.0;
	557	 286	 0.009264	 0.031822	 0.0567	 289.0	 289.0	 289.0	 0.0	 0.0	 1	 -30.0	 30.0;
	398	 288	 2e-05	 0.000198	 0.0051	 154266	 154266	 154266	 0.0	 0.0	 1	 -30.0	 30.0;
	398	 287	 4e-05	 0.000198	 0.0061	 151981	 151981	 151981	 0.0	 0.0	 1	 -30.0	 30.0;
	1169	 289	 0.00322	 0.021689	 0.0688	 452.0	 452.0	 452.0	 0.0	 0.0	 1	 -30.0	 30.0;
	406	 290	 0.003516	 0.016415	 0.0273	 354.0	 354.0	 354.0	 0.0	 0.0	 1	 -30.0	 30.0;
	896	 290	 0.004168	 0.028346	 0.0537	 356.0	 356.0	 356.0	 0.0	 0.0	 1	 -30.0	 30.0;
	945	 290	 0.001936	 0.00883	 0.0445	 3425	 3425	 3425	 0.0	 0.0	 1	 -30.0	 30.0;
	1115	 290	 0.008099	 0.036603	 0.0901	 369.0	 369.0	 369.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1409	 290	 0.000948	 0.005886	 0.0289	 5192	 5192	 5192	 0.0	 0.0	 1	 -30.0	 30.0;
	406	 290	 0.002331	 0.015724	 0.0451	 428.0	 428.0	 428.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1408	 290	 0.000948	 0.005748	 0.0304	 5314	 5314	 5314	 0.0	 0.0	 1	 -30.0	 30.0;
	406	 290	 0.002311	 0.015763	 0.0435	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1067	 290	 0.000336	 0.002331	 0.004	 356.0	 356.0	 356.0	 0.0	 0.0	 1	 -30.0	 30.0;
	861	 290	 0.000211	 0.001199	 0.0405	 307.0	 307.0	 307.0	 0.0	 0.0	 1	 -30.0	 30.0;
	860	 290	 0.000209	 0.001189	 0.0405	 307.0	 307.0	 307.0	 0.0	 0.0	 1	 -30.0	 30.0;
	294	 291	 2.1e-05	 0.000208	 0.0058	 1828.0	 1828.0	 1828.0	 0.0	 0.0	 1	 -30.0	 30.0;
	308	 291	 0.00126	 0.014141	 0.2845	 1191.0	 1191.0	 1191.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1068	 293	 7.9e-05	 0.000859	 0.0173	 1204.0	 1204.0	 1204.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1260	 292	 0.001904	 0.021302	 0.4679	 1490	 1490	 1490	 0.0	 0.0	 1	 -30.0	 30.0;
	1383	 293	 0.001517	 0.01687	 0.3494	 1659.0	 1659.0	 1659.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1448	 292	 2.1e-05	 0.000187	 0.0029	 1828.0	 1828.0	 1828.0	 0.0	 0.0	 1	 -30.0	 30.0;
	294	 292	 2.1e-05	 0.000208	 0.0058	 1828.0	 1828.0	 1828.0	 0.0	 0.0	 1	 -30.0	 30.0;
	308	 291	 0.00126	 0.01412	 0.2859	 1191.0	 1191.0	 1191.0	 0.0	 0.0	 1	 -30.0	 30.0;
	839	 293	 0.000983	 0.010949	 0.2397	 1711.0	 1711.0	 1711.0	 0.0	 0.0	 1	 -30.0	 30.0;
	891	 293	 0.001711	 0.017348	 0.4476	 1828.0	 1828.0	 1828.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1260	 293	 0.001281	 0.018476	 0.491	 1720	 1720	 1720	 0.0	 0.0	 1	 -30.0	 30.0;
	1260	 293	 0.001274	 0.018324	 0.4837	 1735	 1735	 1735	 0.0	 0.0	 1	 -30.0	 30.0;
	348	 295	 0.002943	 0.02001	 0.0375	 524.0	 524.0	 524.0	 0.0	 0.0	 1	 -30.0	 30.0;
	810	 295	 0.005926	 0.04079	 0.077	 558.0	 558.0	 558.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1057	 295	 0.004571	 0.030552	 0.0557	 558.0	 558.0	 558.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1359	 295	 0.002121	 0.009661	 0.0162	 355.0	 355.0	 355.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1461	 295	 0.002969	 0.013217	 0.0233	 400.0	 400.0	 400.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1488	 295	 0.005551	 0.025146	 0.0445	 391.0	 391.0	 391.0	 0.0	 0.0	 1	 -30.0	 30.0;
	556	 296	 0.000409	 0.005409	 0.1877	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	709	 296	 0.001371	 0.013871	 0.361	 1828.0	 1828.0	 1828.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1416	 296	 0.002154	 0.021884	 0.566	 1451	 1451	 1451	 0.0	 0.0	 1	 -30.0	 30.0;
	556	 296	 0.000416	 0.005443	 0.1877	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	709	 296	 0.001364	 0.01383	 0.3596	 1828.0	 1828.0	 1828.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1416	 296	 0.002154	 0.021877	 0.566	 1451	 1451	 1451	 0.0	 0.0	 1	 -30.0	 30.0;
	342	 297	 0.000968	 0.002943	 0.3453	 9991	 9991	 9991	 0.0	 0.0	 1	 -30.0	 30.0;
	371	 297	 0.000217	 0.000849	 0.0931	 331.0	 331.0	 331.0	 0.0	 0.0	 1	 -30.0	 30.0;
	895	 297	 0.001205	 0.002746	 0.4668	 10322	 10322	 10322	 0.0	 0.0	 1	 -30.0	 30.0;
	1130	 297	 0.000454	 0.002331	 0.0516	 272.0	 272.0	 272.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1385	 297	 0.001284	 0.0096	 0.038	 335.0	 335.0	 335.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1411	 298	 0.001225	 0.006104	 0.0203	 323.0	 323.0	 323.0	 0.0	 0.0	 1	 -30.0	 30.0;
	370	 298	 0.000257	 0.000849	 0.1893	 268.0	 268.0	 268.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1131	 298	 0.000553	 0.002548	 0.0486	 272.0	 272.0	 272.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1385	 297	 0.001284	 0.00956	 0.038	 335.0	 335.0	 335.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1385	 297	 0.000909	 0.00879	 0.039	 833.0	 833.0	 833.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1502	 297	 0.000533	 0.005096	 0.0248	 935.0	 935.0	 935.0	 0.0	 0.0	 1	 -30.0	 30.0;
	623	 299	 0.000277	 0.002618	 0.0693	 921.0	 921.0	 921.0	 0.0	 0.0	 1	 -30.0	 30.0;
	435	 303	 0.007802	 0.052444	 0.1018	 401.0	 401.0	 401.0	 0.0	 0.0	 1	 -30.0	 30.0;
	794	 303	 0.003101	 0.020563	 0.0385	 558.0	 558.0	 558.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1057	 303	 0.003761	 0.025235	 0.0456	 558.0	 558.0	 558.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1413	 303	 0.008889	 0.032197	 0.0537	 357.0	 357.0	 357.0	 0.0	 0.0	 1	 -30.0	 30.0;
	435	 303	 0.01442	 0.071763	 0.1291	 372.0	 372.0	 372.0	 0.0	 0.0	 1	 -30.0	 30.0;
	739	 304	 0.000381	 0.007008	 0.2079	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	739	 305	 0.000374	 0.006434	 0.2209	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	801	 306	 0.001679	 0.017284	 0.0582	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	801	 306	 0.001501	 0.018568	 0.0562	 388.0	 388.0	 388.0	 0.0	 0.0	 1	 -30.0	 30.0;
	734	 307	 0.00079	 0.005345	 0.0354	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	759	 307	 0.00255	 0.017084	 0.0309	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	734	 307	 0.000745	 0.005047	 0.0349	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	550	 308	 0.000741	 0.009716	 0.335	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1386	 308	 0.000422	 0.004709	 0.0953	 1774.0	 1774.0	 1774.0	 0.0	 0.0	 1	 -30.0	 30.0;
	550	 308	 0.000741	 0.009709	 0.335	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1386	 308	 0.000422	 0.004758	 0.0953	 1774.0	 1774.0	 1774.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1386	 308	 0.000644	 0.005035	 0.1112	 1397.0	 1397.0	 1397.0	 0.0	 0.0	 1	 -30.0	 30.0;
	854	 309	 0.004514	 0.029863	 0.1096	 439.0	 439.0	 439.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1337	 311	 1.4e-05	 0.000208	 0.0058	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1337	 310	 2.1e-05	 0.000242	 0.0087	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	516	 312	 0.002402	 0.015149	 0.0582	 472.0	 472.0	 472.0	 0.0	 0.0	 1	 -30.0	 30.0;
	667	 312	 0.000889	 0.005333	 0.0101	 473.0	 473.0	 473.0	 0.0	 0.0	 1	 -30.0	 30.0;
	619	 313	 0.000751	 0.004978	 0.0091	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	767	 313	 0.001738	 0.011694	 0.0213	 558.0	 558.0	 558.0	 0.0	 0.0	 1	 -30.0	 30.0;
	619	 313	 0.000652	 0.004346	 0.0081	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	427	 314	 0.000593	 0.002667	 0.0051	 374.0	 374.0	 374.0	 0.0	 0.0	 1	 -30.0	 30.0;
	427	 315	 0.000591	 0.00268	 0.0046	 432.0	 432.0	 432.0	 0.0	 0.0	 1	 -30.0	 30.0;
	999	 316	 0.000972	 0.012113	 0.1636	 1786.0	 1786.0	 1786.0	 0.0	 0.0	 1	 -30.0	 30.0;
	442	 317	 0.003477	 0.023249	 0.0425	 416.0	 416.0	 416.0	 0.0	 0.0	 1	 -30.0	 30.0;
	610	 317	 0.006341	 0.042232	 0.078	 415.0	 415.0	 415.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1449	 319	 4.5e-05	 8.9e-05	 0.0007	 320583	 320583	 320583	 0.0	 0.0	 1	 -30.0	 30.0;
	359	 320	 0.002601	 0.017284	 0.0324	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1427	 320	 0.008257	 0.036427	 0.0582	 379.0	 379.0	 379.0	 0.0	 0.0	 1	 -30.0	 30.0;
	658	 321	 0.001857	 0.014461	 0.0481	 376.0	 376.0	 376.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1364	 321	 0.003202	 0.030829	 0.1164	 376.0	 376.0	 376.0	 0.0	 0.0	 1	 -30.0	 30.0;
	708	 323	 0.006005	 0.02878	 0.0496	 370.0	 370.0	 370.0	 0.0	 0.0	 1	 -30.0	 30.0;
	841	 323	 0.003595	 0.0176	 0.0294	 354.0	 354.0	 354.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1405	 324	 0.002133	 0.014756	 0.0294	 2077	 2077	 2077	 0.0	 0.0	 1	 -30.0	 30.0;
	1030	 325	 0.00642	 0.043852	 0.083	 391.0	 391.0	 391.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1193	 325	 0.003002	 0.020227	 0.0385	 391.0	 391.0	 391.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1044	 326	 8.9e-05	 0.000751	 0.079	 426.0	 426.0	 426.0	 0.0	 0.0	 1	 -30.0	 30.0;
	361	 328	 0.003477	 0.018074	 0.0304	 311.0	 311.0	 311.0	 0.0	 0.0	 1	 -30.0	 30.0;
	825	 328	 0.003141	 0.015526	 0.0268	 253.0	 253.0	 253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	941	 328	 0.000237	 0.001541	 0.0091	 420.0	 420.0	 420.0	 0.0	 0.0	 1	 -30.0	 30.0;
	616	 329	 0.001086	 0.00642	 0.0121	 455.0	 455.0	 455.0	 0.0	 0.0	 1	 -30.0	 30.0;
	760	 329	 0.004464	 0.021452	 0.0385	 255.0	 255.0	 255.0	 0.0	 0.0	 1	 -30.0	 30.0;
	703	 330	 0.000158	 0.000474	 0.0506	 278.0	 278.0	 278.0	 0.0	 0.0	 1	 -30.0	 30.0;
	848	 330	 0.000198	 0.00077	 0.0972	 311.0	 311.0	 311.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1451	 331	 1.6e-05	 9.9e-05	 0.001	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1450	 332	 1.6e-05	 9.9e-05	 0.001	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1109	 333	 0.005531	 0.037215	 0.0678	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1298	 2072	 0.004365	 0.029491	 0.0537	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1109	 2072	 0.005452	 0.036365	 0.0668	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	427	 334	 0.003002	 0.014163	 0.0253	 432.0	 432.0	 432.0	 0.0	 0.0	 1	 -30.0	 30.0;
	555	 334	 0.001778	 0.009837	 0.0248	 432.0	 432.0	 432.0	 0.0	 0.0	 1	 -30.0	 30.0;
	435	 335	 0.005491	 0.037076	 0.0658	 535.0	 535.0	 535.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1201	 335	 0.000454	 0.0032	 0.0051	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1452	 335	 0.00083	 0.005669	 0.0111	 558.0	 558.0	 558.0	 0.0	 0.0	 1	 -30.0	 30.0;
	435	 335	 0.005412	 0.036543	 0.0658	 558.0	 558.0	 558.0	 0.0	 0.0	 1	 -30.0	 30.0;
	435	 335	 0.005432	 0.036543	 0.0658	 558.0	 558.0	 558.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1010	 340	 0.00877	 0.026489	 0.0435	 1110	 1110	 1110	 0.0	 0.0	 1	 -30.0	 30.0;
	1159	 340	 0.000968	 0.003516	 0.0061	 8488	 8488	 8488	 0.0	 0.0	 1	 -30.0	 30.0;
	1531	 340	 0.008099	 0.028247	 0.0466	 1054	 1054	 1054	 0.0	 0.0	 1	 -30.0	 30.0;
	988	 340	 0.001521	 0.00721	 0.0121	 270.0	 270.0	 270.0	 0.0	 0.0	 1	 -30.0	 30.0;
	484	 341	 0.000138	 0.000573	 0.0699	 259.0	 259.0	 259.0	 0.0	 0.0	 1	 -30.0	 30.0;
	892	 343	 0.000198	 0.000731	 0.647	 420.0	 420.0	 420.0	 0.0	 0.0	 1	 -30.0	 30.0;
	955	 343	 0.000652	 0.002351	 0.5123	 288.0	 288.0	 288.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1482	 343	 0.000593	 0.005649	 0.0223	 656.0	 656.0	 656.0	 0.0	 0.0	 1	 -30.0	 30.0;
	892	 343	 0.000182	 0.000622	 0.5559	 420.0	 420.0	 420.0	 0.0	 0.0	 1	 -30.0	 30.0;
	955	 343	 0.000652	 0.00237	 0.5133	 288.0	 288.0	 288.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1481	 343	 0.000612	 0.005669	 0.0278	 935.0	 935.0	 935.0	 0.0	 0.0	 1	 -30.0	 30.0;
	892	 343	 0.000237	 0.002114	 0.1954	 426.0	 426.0	 426.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1469	 343	 0.000217	 0.002054	 0.0197	 935.0	 935.0	 935.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1470	 343	 0.000217	 0.002035	 0.0147	 935.0	 935.0	 935.0	 0.0	 0.0	 1	 -30.0	 30.0;
	981	 345	 0.00287	 0.017709	 0.0334	 455.0	 455.0	 455.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1456	 346	 0.002015	 0.012879	 0.0243	 296.0	 296.0	 296.0	 0.0	 0.0	 1	 -30.0	 30.0;
	557	 345	 0.00482	 0.03119	 0.0577	 296.0	 296.0	 296.0	 0.0	 0.0	 1	 -30.0	 30.0;
	559	 347	 0.000529	 0.008085	 0.2498	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	882	 347	 0.001142	 0.014569	 0.3855	 1746.0	 1746.0	 1746.0	 0.0	 0.0	 1	 -30.0	 30.0;
	607	 348	 0.002884	 0.019358	 0.0714	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	990	 348	 0.004978	 0.024514	 0.0435	 383.0	 383.0	 383.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1031	 348	 0.015328	 0.102262	 0.1903	 297	 297	 297	 0.0	 0.0	 1	 -30.0	 30.0;
	1224	 348	 0.005531	 0.02797	 0.0567	 357.0	 357.0	 357.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1515	 348	 0.001067	 0.007289	 0.0486	 487.0	 487.0	 487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	338	 348	 5.9e-05	 0.000889	 0.003	 935.0	 935.0	 935.0	 0.0	 0.0	 1	 -30.0	 30.0;
	990	 348	 0.002805	 0.019002	 0.0365	 558.0	 558.0	 558.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1488	 348	 0.001027	 0.006775	 0.0121	 558.0	 558.0	 558.0	 0.0	 0.0	 1	 -30.0	 30.0;
	336	 348	 7.9e-05	 0.00083	 0.002	 935.0	 935.0	 935.0	 0.0	 0.0	 1	 -30.0	 30.0;
	337	 348	 5.9e-05	 0.000652	 0.001	 935.0	 935.0	 935.0	 0.0	 0.0	 1	 -30.0	 30.0;
	436	 350	 0.003102	 0.031524	 0.8202	 1002	 1002	 1002	 0.0	 0.0	 1	 -30.0	 30.0;
	742	 350	 0.001168	 0.011767	 0.3018	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	436	 350	 0.00313	 0.031724	 0.8202	 996	 996	 996	 0.0	 0.0	 1	 -30.0	 30.0;
	743	 350	 0.001163	 0.011728	 0.3018	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	786	 350	 0.004905	 0.049964	 1.301	 633	 633	 633	 0.0	 0.0	 1	 -30.0	 30.0;
	339	 350	 2.1e-05	 0.000249	 0.0058	 921.0	 921.0	 921.0	 0.0	 0.0	 1	 -30.0	 30.0;
	352	 351	 0.001027	 0.004721	 0.0081	 354.0	 354.0	 354.0	 0.0	 0.0	 1	 -30.0	 30.0;
	836	 351	 0.001027	 0.004899	 0.0091	 408.0	 408.0	 408.0	 0.0	 0.0	 1	 -30.0	 30.0;
	826	 352	 0.002548	 0.012346	 0.0203	 405.0	 405.0	 405.0	 0.0	 0.0	 1	 -30.0	 30.0;
	365	 353	 0.004721	 0.031348	 0.0587	 434.0	 434.0	 434.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1363	 353	 0.003556	 0.023585	 0.0435	 416.0	 416.0	 416.0	 0.0	 0.0	 1	 -30.0	 30.0;
	473	 354	 0.00156	 0.01039	 0.0192	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	547	 354	 0.001084	 0.005086	 0.0111	 361.0	 361.0	 361.0	 0.0	 0.0	 1	 -30.0	 30.0;
	898	 354	 0.002153	 0.012978	 0.0243	 454.0	 454.0	 454.0	 0.0	 0.0	 1	 -30.0	 30.0;
	547	 354	 0.0011	 0.004978	 0.0142	 353.0	 353.0	 353.0	 0.0	 0.0	 1	 -30.0	 30.0;
	898	 354	 0.002173	 0.013017	 0.0243	 454.0	 454.0	 454.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1454	 355	 0.000158	 0.000691	 0.001	 274.0	 274.0	 274.0	 0.0	 0.0	 1	 -30.0	 30.0;
	858	 356	 0.002544	 0.02015	 0.0348	 561.0	 561.0	 561.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1239	 356	 0.003727	 0.028836	 0.0527	 562.0	 562.0	 562.0	 0.0	 0.0	 1	 -30.0	 30.0;
	382	 357	 3.5e-05	 0.000512	 0.0144	 1382.0	 1382.0	 1382.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1008	 357	 0.001887	 0.019088	 0.4938	 1611.0	 1611.0	 1611.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1271	 357	 0.001579	 0.01509	 0.4087	 1611.0	 1611.0	 1611.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1320	 357	 0.000949	 0.009342	 0.2426	 1611.0	 1611.0	 1611.0	 0.0	 0.0	 1	 -30.0	 30.0;
	381	 357	 3.5e-05	 0.000506	 0.0144	 1382.0	 1382.0	 1382.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1008	 357	 0.001874	 0.018954	 0.491	 1611.0	 1611.0	 1611.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1320	 357	 0.00097	 0.009536	 0.2484	 1611.0	 1611.0	 1611.0	 0.0	 0.0	 1	 -30.0	 30.0;
	383	 357	 3.5e-05	 0.000547	 0.0144	 1382.0	 1382.0	 1382.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1320	 357	 0.00097	 0.009536	 0.2484	 1611.0	 1611.0	 1611.0	 0.0	 0.0	 1	 -30.0	 30.0;
	384	 357	 3.5e-05	 0.000547	 0.0144	 1382.0	 1382.0	 1382.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1455	 358	 0.000869	 0.006025	 0.0101	 502.0	 502.0	 502.0	 0.0	 0.0	 1	 -30.0	 30.0;
	478	 361	 0.001027	 0.006677	 0.0121	 488.0	 488.0	 488.0	 0.0	 0.0	 1	 -30.0	 30.0;
	601	 360	 0.009521	 0.064237	 0.1215	 375.0	 375.0	 375.0	 0.0	 0.0	 1	 -30.0	 30.0;
	825	 361	 0.002133	 0.023348	 0.0648	 502.0	 502.0	 502.0	 0.0	 0.0	 1	 -30.0	 30.0;
	941	 362	 0.002232	 0.007802	 0.0142	 287.0	 287.0	 287.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1137	 360	 0.000593	 0.002588	 0.0162	 261.0	 261.0	 261.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1166	 360	 2e-05	 0.015803	 0.0	 287.0	 287.0	 287.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1182	 361	 0.001778	 0.016356	 0.0405	 502.0	 502.0	 502.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1258	 361	 0.011694	 0.078657	 0.1519	 375.0	 375.0	 375.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1531	 361	 0.000237	 0.00156	 0.0142	 19617	 19617	 19617	 0.0	 0.0	 1	 -30.0	 30.0;
	478	 360	 0.001027	 0.006657	 0.0121	 464.0	 464.0	 464.0	 0.0	 0.0	 1	 -30.0	 30.0;
	988	 360	 0.00476	 0.022499	 0.0375	 333.0	 333.0	 333.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1166	 362	 2e-05	 0.000198	 0.0	 155535	 155535	 155535	 0.0	 0.0	 1	 -30.0	 30.0;
	1343	 363	 0.000462	 0.006438	 0.1689	 1842.0	 1842.0	 1842.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1343	 363	 0.000462	 0.006434	 0.1689	 1842.0	 1842.0	 1842.0	 0.0	 0.0	 1	 -30.0	 30.0;
	527	 364	 0.003234	 0.01923	 0.0365	 410.0	 410.0	 410.0	 0.0	 0.0	 1	 -30.0	 30.0;
	557	 364	 0.019951	 0.071546	 0.1144	 417	 417	 417	 0.0	 0.0	 1	 -30.0	 30.0;
	933	 364	 0.016	 0.053472	 0.0861	 555	 555	 555	 0.0	 0.0	 1	 -30.0	 30.0;
	996	 365	 0.005472	 0.037728	 0.0709	 411.0	 411.0	 411.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1268	 365	 0.000968	 0.00638	 0.0111	 399.0	 399.0	 399.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1499	 365	 0.005669	 0.025639	 0.0456	 333.0	 333.0	 333.0	 0.0	 0.0	 1	 -30.0	 30.0;
	657	 366	 0.082196	 0.171444	 0.0486	 167	 167	 167	 0.0	 0.0	 1	 -30.0	 30.0;
	605	 367	 0.002825	 0.018765	 0.0349	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	722	 367	 0.000474	 0.003101	 0.0061	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1420	 367	 0.00173	 0.01154	 0.0213	 566.0	 566.0	 566.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1420	 367	 0.001719	 0.011496	 0.0289	 368.0	 368.0	 368.0	 0.0	 0.0	 1	 -30.0	 30.0;
	533	 368	 0.013472	 0.067378	 0.1215	 413.0	 413.0	 413.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1106	 368	 0.004563	 0.02448	 0.0425	 413.0	 413.0	 413.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1433	 368	 0.010627	 0.045511	 0.0749	 302.0	 302.0	 302.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1501	 368	 0.009798	 0.045748	 0.0815	 337.0	 337.0	 337.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1519	 368	 0.011674	 0.053096	 0.0921	 331.0	 331.0	 331.0	 0.0	 0.0	 1	 -30.0	 30.0;
	890	 369	 0.000812	 0.006278	 0.1271	 1397.0	 1397.0	 1397.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1080	 369	 0.001797	 0.019272	 0.4216	 1648	 1648	 1648	 0.0	 0.0	 1	 -30.0	 30.0;
	1365	 369	 0.003831	 0.029281	 0.592	 1080	 1080	 1080	 0.0	 0.0	 1	 -30.0	 30.0;
	573	 371	 0.000198	 0.0016	 0.162	 434.0	 434.0	 434.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1133	 371	 0.000454	 0.001106	 0.1002	 268.0	 268.0	 268.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1294	 370	 0.000316	 0.000948	 0.1094	 268.0	 268.0	 268.0	 0.0	 0.0	 1	 -30.0	 30.0;
	559	 372	 0.00077	 0.011178	 0.312	 1974.0	 1974.0	 1974.0	 0.0	 0.0	 1	 -30.0	 30.0;
	623	 372	 0.00088	 0.012722	 0.3292	 2200.0	 2200.0	 2200.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1242	 372	 0.000312	 0.004467	 0.1155	 2200.0	 2200.0	 2200.0	 0.0	 0.0	 1	 -30.0	 30.0;
	559	 373	 0.000771	 0.011192	 0.291	 1842.0	 1842.0	 1842.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1243	 373	 0.000312	 0.004467	 0.1155	 2200.0	 2200.0	 2200.0	 0.0	 0.0	 1	 -30.0	 30.0;
	512	 374	 2e-05	 0.000198	 0.003	 155535	 155535	 155535	 0.0	 0.0	 1	 -30.0	 30.0;
	1274	 375	 0.000178	 0.000632	 0.078	 370.0	 370.0	 370.0	 0.0	 0.0	 1	 -30.0	 30.0;
	660	 377	 0.00077	 0.005195	 0.0091	 545.0	 545.0	 545.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1026	 377	 0.000553	 0.003694	 0.0157	 435.0	 435.0	 435.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1117	 377	 0.000514	 0.001007	 0.1499	 27378	 27378	 27378	 0.0	 0.0	 1	 -30.0	 30.0;
	1358	 377	 0.001679	 0.008296	 0.0152	 432.0	 432.0	 432.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1420	 377	 0.002548	 0.016968	 0.0314	 566.0	 566.0	 566.0	 0.0	 0.0	 1	 -30.0	 30.0;
	660	 377	 0.000731	 0.004938	 0.0091	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1026	 377	 0.000533	 0.003635	 0.0061	 566.0	 566.0	 566.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1116	 377	 0.000494	 0.001007	 0.1488	 27596	 27596	 27596	 0.0	 0.0	 1	 -30.0	 30.0;
	530	 378	 0.000514	 0.001185	 0.0719	 23964	 23964	 23964	 0.0	 0.0	 1	 -30.0	 30.0;
	574	 379	 0.000138	 0.000573	 0.001	 329.0	 329.0	 329.0	 0.0	 0.0	 1	 -30.0	 30.0;
	752	 380	 0.000632	 0.004168	 0.0081	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1456	 385	 2e-05	 0.000198	 0.003	 354.0	 354.0	 354.0	 0.0	 0.0	 1	 -30.0	 30.0;
	397	 386	 0.0004	 0.001244	 0.0004	 23302	 23302	 23302	 0.0	 0.0	 1	 -30.0	 30.0;
	467	 386	 0.019956	 0.0604	 0.0198	 479	 479	 479	 0.0	 0.0	 1	 -30.0	 30.0;
	1113	 386	 0.017467	 0.063733	 0.0216	 461	 461	 461	 0.0	 0.0	 1	 -30.0	 30.0;
	1485	 387	 0.001233	 0.008227	 0.0147	 525.0	 525.0	 525.0	 0.0	 0.0	 1	 -30.0	 30.0;
	598	 388	 0.003911	 0.027062	 0.0486	 438.0	 438.0	 438.0	 0.0	 0.0	 1	 -30.0	 30.0;
	854	 388	 0.000711	 0.006894	 0.0223	 865.0	 865.0	 865.0	 0.0	 0.0	 1	 -30.0	 30.0;
	865	 388	 0.007012	 0.030617	 0.0511	 455.0	 455.0	 455.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1322	 388	 0.007639	 0.051542	 0.2291	 502.0	 502.0	 502.0	 0.0	 0.0	 1	 -30.0	 30.0;
	443	 390	 0.002597	 0.034127	 1.1812	 932	 932	 932	 0.0	 0.0	 1	 -30.0	 30.0;
	963	 390	 0.002999	 0.033656	 0.6729	 944	 944	 944	 0.0	 0.0	 1	 -30.0	 30.0;
	1150	 390	 0.001302	 0.013172	 0.3408	 1727.0	 1727.0	 1727.0	 0.0	 0.0	 1	 -30.0	 30.0;
	443	 390	 0.002597	 0.034127	 1.1783	 932	 932	 932	 0.0	 0.0	 1	 -30.0	 30.0;
	857	 390	 0.000256	 0.002701	 0.0693	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1150	 390	 0.001309	 0.013255	 0.3437	 1727.0	 1727.0	 1727.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1360	 391	 0.002765	 0.01843	 0.0344	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	601	 392	 0.002114	 0.012662	 0.0233	 374.0	 374.0	 374.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1437	 392	 0.000595	 0.004024	 0.0081	 503.0	 503.0	 503.0	 0.0	 0.0	 1	 -30.0	 30.0;
	602	 393	 0.001264	 0.008415	 0.0152	 433.0	 433.0	 433.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1835	 395	 0.000731	 0.001383	 0.1853	 19787	 19787	 19787	 0.0	 0.0	 1	 -30.0	 30.0;
	420	 398	 0.005867	 0.03919	 0.083	 448.0	 448.0	 448.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1466	 398	 0.003812	 0.025482	 0.0466	 356.0	 356.0	 356.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1058	 399	 0.00316	 0.021017	 0.0375	 528.0	 528.0	 528.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1079	 399	 0.004612	 0.030706	 0.0547	 524.0	 524.0	 524.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1090	 401	 0.000138	 0.001363	 0.2025	 22551	 22551	 22551	 0.0	 0.0	 1	 -30.0	 30.0;
	1090	 400	 0.000158	 0.001323	 0.1822	 23186	 23186	 23186	 0.0	 0.0	 1	 -30.0	 30.0;
	520	 402	 0.000559	 0.001024	 0.0729	 26532	 26532	 26532	 0.0	 0.0	 1	 -30.0	 30.0;
	1164	 403	 0.000292	 0.002538	 0.2546	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1348	 404	 0.000632	 0.004306	 0.0081	 566.0	 566.0	 566.0	 0.0	 0.0	 1	 -30.0	 30.0;
	964	 405	 0.001244	 0.008415	 0.0309	 388.0	 388.0	 388.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1169	 405	 0.002114	 0.014242	 0.0486	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1393	 407	 0.001719	 0.008	 0.0132	 274.0	 274.0	 274.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1427	 409	 0.000608	 0.004067	 0.0071	 379.0	 379.0	 379.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1521	 409	 0.002054	 0.013689	 0.0253	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	573	 410	 0.000356	 0.000731	 0.0415	 38142	 38142	 38142	 0.0	 0.0	 1	 -30.0	 30.0;
	413	 411	 2e-05	 9.8e-05	 0.0111	 314576	 314576	 314576	 0.0	 0.0	 1	 -30.0	 30.0;
	730	 412	 0.000968	 0.005906	 0.0602	 461.0	 461.0	 461.0	 0.0	 0.0	 1	 -30.0	 30.0;
	845	 412	 0.001331	 0.009015	 0.0906	 461.0	 461.0	 461.0	 0.0	 0.0	 1	 -30.0	 30.0;
	698	 413	 0.00561	 0.030894	 0.0567	 413.0	 413.0	 413.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1404	 413	 0.003812	 0.025383	 0.0471	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1363	 414	 0.005233	 0.024413	 0.0435	 337.0	 337.0	 337.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1499	 414	 0.002252	 0.01037	 0.0182	 333.0	 333.0	 333.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1364	 414	 0.00397	 0.02639	 0.0537	 413.0	 413.0	 413.0	 0.0	 0.0	 1	 -30.0	 30.0;
	752	 416	 0.005314	 0.024119	 0.0425	 384.0	 384.0	 384.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1314	 416	 0.003398	 0.017541	 0.0314	 384.0	 384.0	 384.0	 0.0	 0.0	 1	 -30.0	 30.0;
	752	 416	 0.005412	 0.024571	 0.0461	 384.0	 384.0	 384.0	 0.0	 0.0	 1	 -30.0	 30.0;
	279	 418	 0.001256	 0.008251	 0.2389	 375.0	 375.0	 375.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1334	 418	 0.000158	 0.000652	 0.0729	 413.0	 413.0	 413.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1459	 419	 0.001047	 0.006973	 0.0132	 354.0	 354.0	 354.0	 0.0	 0.0	 1	 -30.0	 30.0;
	620	 420	 0.005393	 0.029649	 0.0638	 348.0	 348.0	 348.0	 0.0	 0.0	 1	 -30.0	 30.0;
	621	 420	 0.005393	 0.02963	 0.0638	 348.0	 348.0	 348.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1466	 420	 0.001877	 0.012543	 0.0344	 448.0	 448.0	 448.0	 0.0	 0.0	 1	 -30.0	 30.0;
	550	 421	 0.000589	 0.007708	 0.2628	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1353	 421	 0.00115	 0.01169	 0.3032	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1426	 421	 0.00241	 0.024446	 0.6325	 1297	 1297	 1297	 0.0	 0.0	 1	 -30.0	 30.0;
	550	 421	 0.000589	 0.007708	 0.2628	 2389.0	 2389.0	 2389.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1353	 421	 0.00115	 0.01169	 0.3032	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1386	 421	 0.00153	 0.015526	 0.4014	 1828.0	 1828.0	 1828.0	 0.0	 0.0	 1	 -30.0	 30.0;
	905	 422	 0.004464	 0.029669	 0.0547	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1360	 422	 0.005156	 0.034489	 0.0638	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1322	 423	 0.008122	 0.036857	 0.0655	 329.0	 329.0	 329.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1355	 423	 0.011081	 0.049936	 0.0891	 265.0	 265.0	 265.0	 0.0	 0.0	 1	 -30.0	 30.0;
	619	 424	 0.000336	 0.002173	 0.004	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	504	 425	 0.00156	 0.01041	 0.0192	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	583	 425	 0.000178	 0.001659	 0.0061	 818.0	 818.0	 818.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1053	 425	 0.002035	 0.012563	 0.1094	 378.0	 378.0	 378.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1060	 425	 0.000257	 0.001659	 0.003	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	504	 425	 0.001432	 0.009557	 0.0223	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1060	 425	 0.000158	 0.001067	 0.0046	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	614	 426	 0.008542	 0.029422	 0.0095	 1044	 1044	 1044	 0.0	 0.0	 1	 -30.0	 30.0;
	791	 427	 0.003368	 0.036373	 0.0273	 420.0	 420.0	 420.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1349	 428	 0.000375	 0.001383	 0.1711	 313.0	 313.0	 313.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1414	 429	 0.000903	 0.006023	 0.0111	 522.0	 522.0	 522.0	 0.0	 0.0	 1	 -30.0	 30.0;
	772	 432	 0.002359	 0.016431	 0.0203	 319.0	 319.0	 319.0	 0.0	 0.0	 1	 -30.0	 30.0;
	662	 433	 4e-05	 0.000988	 0.004	 1363.0	 1363.0	 1363.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1305	 433	 5.9e-05	 0.001185	 0.004	 1363.0	 1363.0	 1363.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1312	 433	 4e-05	 0.000988	 0.004	 1363.0	 1363.0	 1363.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1544	 434	 0.000968	 0.00644	 0.0121	 545.0	 545.0	 545.0	 0.0	 0.0	 1	 -30.0	 30.0;
	919	 435	 0.011773	 0.053926	 0.0962	 427.0	 427.0	 427.0	 0.0	 0.0	 1	 -30.0	 30.0;
	679	 436	 0.000966	 0.009803	 0.2526	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	961	 436	 0.002015	 0.020838	 0.5401	 1517	 1517	 1517	 0.0	 0.0	 1	 -30.0	 30.0;
	678	 436	 0.000963	 0.009792	 0.2541	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1303	 439	 0.002805	 0.019378	 0.0365	 515.0	 515.0	 515.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1488	 440	 0.010311	 0.068543	 0.1276	 443	 443	 443	 0.0	 0.0	 1	 -30.0	 30.0;
	1539	 440	 0.001017	 0.006912	 0.0633	 449.0	 449.0	 449.0	 0.0	 0.0	 1	 -30.0	 30.0;
	711	 441	 0.000976	 0.013206	 0.4448	 2406	 2406	 2406	 0.0	 0.0	 1	 -30.0	 30.0;
	742	 441	 0.001017	 0.010325	 0.2657	 1828.0	 1828.0	 1828.0	 0.0	 0.0	 1	 -30.0	 30.0;
	829	 441	 0.001369	 0.017997	 0.6209	 1759	 1759	 1759	 0.0	 0.0	 1	 -30.0	 30.0;
	1023	 441	 0.002352	 0.025391	 0.5704	 1245	 1245	 1245	 0.0	 0.0	 1	 -30.0	 30.0;
	1041	 441	 0.002021	 0.026575	 0.9197	 1191	 1191	 1191	 0.0	 0.0	 1	 -30.0	 30.0;
	711	 441	 0.000976	 0.013213	 0.4448	 2405	 2405	 2405	 0.0	 0.0	 1	 -30.0	 30.0;
	743	 441	 0.001017	 0.010325	 0.2657	 1828.0	 1828.0	 1828.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1355	 442	 0.005223	 0.034671	 0.076	 428.0	 428.0	 428.0	 0.0	 0.0	 1	 -30.0	 30.0;
	576	 443	 2.1e-05	 0.000301	 0.0116	 2176.0	 2176.0	 2176.0	 0.0	 0.0	 1	 -30.0	 30.0;
	719	 443	 0.000697	 0.009107	 0.3114	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	577	 443	 1.9e-05	 0.00028	 0.0108	 2176.0	 2176.0	 2176.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1352	 443	 0.001244	 0.016445	 0.5652	 1934	 1934	 1934	 0.0	 0.0	 1	 -30.0	 30.0;
	495	 444	 0.005096	 0.033837	 0.0628	 428.0	 428.0	 428.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1460	 444	 0.005057	 0.030084	 0.0567	 430.0	 430.0	 430.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1461	 445	 2e-06	 0.000198	 0.0066	 401.0	 401.0	 401.0	 0.0	 0.0	 1	 -30.0	 30.0;
	721	 446	 0.000336	 0.001481	 0.003	 348.0	 348.0	 348.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1348	 446	 0.000652	 0.004346	 0.0081	 566.0	 566.0	 566.0	 0.0	 0.0	 1	 -30.0	 30.0;
	720	 446	 0.000336	 0.001501	 0.003	 348.0	 348.0	 348.0	 0.0	 0.0	 1	 -30.0	 30.0;
	515	 448	 0.006202	 0.041343	 0.0759	 535.0	 535.0	 535.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1298	 448	 0.001205	 0.008099	 0.0152	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1298	 448	 0.001225	 0.008099	 0.0152	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1462	 449	 0.000988	 0.005709	 0.0101	 431.0	 431.0	 431.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1055	 450	 0.001877	 0.012504	 0.0223	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1101	 450	 0.001462	 0.009758	 0.0182	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1260	 452	 2.8e-05	 0.000388	 0.0087	 1842.0	 1842.0	 1842.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1260	 451	 2.8e-05	 0.000388	 0.0087	 1842.0	 1842.0	 1842.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1260	 453	 2.8e-05	 0.000388	 0.0087	 1842.0	 1842.0	 1842.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1260	 454	 2.8e-05	 0.000388	 0.0087	 1842.0	 1842.0	 1842.0	 0.0	 0.0	 1	 -30.0	 30.0;
	730	 455	 0.000672	 0.003891	 0.08	 461.0	 461.0	 461.0	 0.0	 0.0	 1	 -30.0	 30.0;
	730	 455	 0.000632	 0.003812	 0.0911	 461.0	 461.0	 461.0	 0.0	 0.0	 1	 -30.0	 30.0;
	570	 456	 0.00083	 0.005709	 0.0182	 420.0	 420.0	 420.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1096	 456	 0.001709	 0.016636	 0.0577	 866.0	 866.0	 866.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1185	 456	 0.001758	 0.017442	 0.0547	 584.0	 584.0	 584.0	 0.0	 0.0	 1	 -30.0	 30.0;
	570	 456	 0.00083	 0.005709	 0.0223	 420.0	 420.0	 420.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1008	 458	 0.000187	 0.00349	 0.0941	 2250.0	 2250.0	 2250.0	 0.0	 0.0	 1	 -30.0	 30.0;
	765	 459	 0.003773	 0.025264	 0.0466	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1189	 459	 0.005195	 0.023585	 0.0415	 364.0	 364.0	 364.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1069	 460	 4e-05	 0.000988	 0.004	 1363.0	 1363.0	 1363.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1319	 460	 5.9e-05	 0.001047	 0.004	 1363.0	 1363.0	 1363.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1307	 460	 7.9e-05	 0.001284	 0.002	 1363.0	 1363.0	 1363.0	 0.0	 0.0	 1	 -30.0	 30.0;
	775	 461	 0.028721	 0.081007	 0.1357	 358	 358	 358	 0.0	 0.0	 1	 -30.0	 30.0;
	795	 461	 0.012247	 0.062222	 0.1073	 414.0	 414.0	 414.0	 0.0	 0.0	 1	 -30.0	 30.0;
	853	 461	 0.009067	 0.042884	 0.0861	 348.0	 348.0	 348.0	 0.0	 0.0	 1	 -30.0	 30.0;
	868	 461	 0.020602	 0.068109	 0.1083	 258.0	 258.0	 258.0	 0.0	 0.0	 1	 -30.0	 30.0;
	919	 461	 0.016691	 0.075299	 0.1336	 330.0	 330.0	 330.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1218	 461	 0.008158	 0.03516	 0.0582	 379.0	 379.0	 379.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1328	 461	 0.016612	 0.078676	 0.1316	 293.0	 293.0	 293.0	 0.0	 0.0	 1	 -30.0	 30.0;
	827	 461	 0.023407	 0.110815	 0.1853	 274	 274	 274	 0.0	 0.0	 1	 -30.0	 30.0;
	776	 462	 0.001898	 0.021337	 0.4245	 1482	 1482	 1482	 0.0	 0.0	 1	 -30.0	 30.0;
	963	 462	 0.001828	 0.020533	 0.4101	 1546	 1546	 1546	 0.0	 0.0	 1	 -30.0	 30.0;
	1337	 462	 0.001053	 0.013843	 0.4765	 2287	 2287	 2287	 0.0	 0.0	 1	 -30.0	 30.0;
	1353	 462	 0.002888	 0.031752	 0.7595	 996	 996	 996	 0.0	 0.0	 1	 -30.0	 30.0;
	1337	 462	 0.001053	 0.01383	 0.4765	 2289	 2289	 2289	 0.0	 0.0	 1	 -30.0	 30.0;
	813	 464	 0.003319	 0.021472	 0.0405	 524.0	 524.0	 524.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1152	 464	 0.001205	 0.007684	 0.0142	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1197	 463	 0.002212	 0.014558	 0.0299	 381.0	 381.0	 381.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1354	 463	 0.000435	 0.002923	 0.0091	 500.0	 500.0	 500.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1840	 464	 0.000593	 0.00397	 0.4759	 530.0	 530.0	 530.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1152	 464	 0.001146	 0.007664	 0.0142	 493.0	 493.0	 493.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1463	 465	 0.000178	 0.001185	 0.002	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1464	 466	 9.9e-05	 0.000454	 0.001	 262.0	 262.0	 262.0	 0.0	 0.0	 1	 -30.0	 30.0;
	666	 468	 0.005669	 0.026094	 0.0476	 321.0	 321.0	 321.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1405	 468	 0.001719	 0.01199	 0.0213	 428.0	 428.0	 428.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1465	 471	 1.3e-05	 9.9e-05	 0.001	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	572	 472	 0.000138	 0.000336	 0.0314	 85214	 85214	 85214	 0.0	 0.0	 1	 -30.0	 30.0;
	898	 473	 0.001888	 0.013914	 0.403	 422.0	 422.0	 422.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1466	 474	 2e-05	 9.9e-05	 0.0	 272.0	 272.0	 272.0	 0.0	 0.0	 1	 -30.0	 30.0;
	490	 475	 0.002481	 0.012134	 0.0218	 344.0	 344.0	 344.0	 0.0	 0.0	 1	 -30.0	 30.0;
	793	 475	 0.003398	 0.021373	 0.04	 432.0	 432.0	 432.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1339	 475	 0.00081	 0.005551	 0.0101	 565.0	 565.0	 565.0	 0.0	 0.0	 1	 -30.0	 30.0;
	555	 1832	 0.000336	 0.000672	 0.0469	 41198	 41198	 41198	 0.0	 0.0	 1	 -30.0	 30.0;
	1540	 476	 0.005294	 0.036464	 0.0618	 492.0	 492.0	 492.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1483	 477	 0.006558	 0.029807	 0.0516	 300.0	 300.0	 300.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1492	 478	 0.001975	 0.013412	 0.0233	 488.0	 488.0	 488.0	 0.0	 0.0	 1	 -30.0	 30.0;
	473	 479	 0.005017	 0.033403	 0.0618	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	494	 479	 0.003595	 0.019635	 0.0354	 369.0	 369.0	 369.0	 0.0	 0.0	 1	 -30.0	 30.0;
	798	 479	 0.001422	 0.008217	 0.1007	 413.0	 413.0	 413.0	 0.0	 0.0	 1	 -30.0	 30.0;
	938	 479	 0.002212	 0.014044	 0.0253	 454.0	 454.0	 454.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1044	 479	 0.001408	 0.008494	 0.2344	 278.0	 278.0	 278.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1055	 479	 0.002647	 0.01762	 0.0324	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	938	 479	 0.002212	 0.013985	 0.0263	 454.0	 454.0	 454.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1444	 479	 0.000336	 0.002232	 0.004	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1200	 480	 4.8e-05	 8.8e-05	 0.1993	 320795	 320795	 320795	 0.0	 0.0	 1	 -30.0	 30.0;
	1200	 481	 4.8e-05	 8.8e-05	 0.1993	 320795	 320795	 320795	 0.0	 0.0	 1	 -30.0	 30.0;
	1199	 482	 4.8e-05	 8.8e-05	 0.001	 313831	 313831	 313831	 0.0	 0.0	 1	 -30.0	 30.0;
	1199	 483	 4.8e-05	 8.8e-05	 0.001	 313831	 313831	 313831	 0.0	 0.0	 1	 -30.0	 30.0;
	489	 487	 2e-05	 0.000198	 0.0091	 155535	 155535	 155535	 0.0	 0.0	 1	 -30.0	 30.0;
	489	 486	 2e-05	 0.000198	 0.0091	 155535	 155535	 155535	 0.0	 0.0	 1	 -30.0	 30.0;
	489	 488	 2e-05	 0.000198	 0.0091	 155535	 155535	 155535	 0.0	 0.0	 1	 -30.0	 30.0;
	489	 485	 2e-05	 0.000198	 0.0091	 155535	 155535	 155535	 0.0	 0.0	 1	 -30.0	 30.0;
	910	 489	 0.000316	 0.001067	 0.2359	 268.0	 268.0	 268.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1292	 489	 0.000395	 0.002706	 0.0253	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	910	 489	 0.000217	 0.001817	 0.1812	 430.0	 430.0	 430.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1012	 489	 0.002193	 0.014736	 0.0461	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1468	 489	 0.001225	 0.007822	 0.0324	 454.0	 454.0	 454.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1467	 489	 0.001225	 0.007822	 0.0324	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	615	 490	 0.002779	 0.013788	 0.0243	 432.0	 432.0	 432.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1468	 492	 0.000553	 0.001106	 0.163	 25032	 25032	 25032	 0.0	 0.0	 1	 -30.0	 30.0;
	1467	 491	 0.000553	 0.001106	 0.163	 25032	 25032	 25032	 0.0	 0.0	 1	 -30.0	 30.0;
	586	 493	 0.005057	 0.033561	 0.0607	 558.0	 558.0	 558.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1261	 495	 0.004913	 0.032622	 0.0608	 416.0	 416.0	 416.0	 0.0	 0.0	 1	 -30.0	 30.0;
	500	 496	 0.00033	 0.001503	 0.002	 317.0	 317.0	 317.0	 0.0	 0.0	 1	 -30.0	 30.0;
	500	 497	 0.000296	 0.001349	 0.002	 317.0	 317.0	 317.0	 0.0	 0.0	 1	 -30.0	 30.0;
	874	 499	 7e-06	 0.000132	 0.0029	 1737.0	 1737.0	 1737.0	 0.0	 0.0	 1	 -30.0	 30.0;
	874	 498	 7e-06	 0.000125	 0.0029	 1737.0	 1737.0	 1737.0	 0.0	 0.0	 1	 -30.0	 30.0;
	503	 500	 2e-06	 0.001185	 0.001	 3507.0	 3507.0	 3507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	926	 500	 0.00322	 0.014835	 0.0263	 388.0	 388.0	 388.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1402	 500	 0.00083	 0.00796	 0.0334	 337.0	 337.0	 337.0	 0.0	 0.0	 1	 -30.0	 30.0;
	502	 500	 2e-06	 0.001185	 0.001	 3507.0	 3507.0	 3507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	501	 500	 2e-06	 0.001185	 0.001	 3507.0	 3507.0	 3507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	713	 504	 0.002015	 0.013551	 0.0243	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	966	 504	 0.001094	 0.011536	 0.036	 584.0	 584.0	 584.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1090	 504	 2e-05	 9.9e-05	 0.0405	 695.0	 695.0	 695.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1099	 504	 0.001205	 0.008	 0.0152	 406.0	 406.0	 406.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1207	 504	 0.00403	 0.027496	 0.0516	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	966	 504	 0.001096	 0.011575	 0.0359	 355.0	 355.0	 355.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1090	 504	 2e-05	 0.000119	 0.0506	 695.0	 695.0	 695.0	 0.0	 0.0	 1	 -30.0	 30.0;
	669	 506	 0.001383	 0.007881	 0.0142	 3869	 3869	 3869	 0.0	 0.0	 1	 -30.0	 30.0;
	805	 507	 0.000256	 0.004377	 0.156	 1994.0	 1994.0	 1994.0	 0.0	 0.0	 1	 -30.0	 30.0;
	805	 510	 0.000263	 0.004377	 0.1574	 1994.0	 1994.0	 1994.0	 0.0	 0.0	 1	 -30.0	 30.0;
	805	 508	 0.000263	 0.004384	 0.1588	 997.0	 997.0	 997.0	 0.0	 0.0	 1	 -30.0	 30.0;
	805	 509	 0.000263	 0.004391	 0.1588	 1592.0	 1592.0	 1592.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1420	 511	 0.000134	 0.000245	 0.001	 545.0	 545.0	 545.0	 0.0	 0.0	 1	 -30.0	 30.0;
	756	 512	 0.000178	 0.000711	 0.079	 331.0	 331.0	 331.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1104	 512	 0.000316	 0.001264	 0.1417	 287.0	 287.0	 287.0	 0.0	 0.0	 1	 -30.0	 30.0;
	854	 513	 0.010943	 0.072652	 0.1347	 421	 421	 421	 0.0	 0.0	 1	 -30.0	 30.0;
	865	 513	 0.014775	 0.052267	 0.083	 568	 568	 568	 0.0	 0.0	 1	 -30.0	 30.0;
	904	 513	 0.020543	 0.073482	 0.1174	 279.0	 279.0	 279.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1144	 513	 0.015921	 0.072375	 0.1281	 329.0	 329.0	 329.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1478	 513	 0.008435	 0.056138	 0.1043	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	710	 515	 0.009912	 0.044701	 0.1817	 304.0	 304.0	 304.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1287	 515	 0.007605	 0.036603	 0.0658	 362.0	 362.0	 362.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1441	 515	 0.005114	 0.03518	 0.0668	 394.0	 394.0	 394.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1407	 516	 0.00557	 0.03362	 0.0628	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	854	 517	 0.002975	 0.019475	 0.0504	 444.0	 444.0	 444.0	 0.0	 0.0	 1	 -30.0	 30.0;
	958	 517	 0.002627	 0.017975	 0.0324	 416.0	 416.0	 416.0	 0.0	 0.0	 1	 -30.0	 30.0;
	854	 517	 0.002993	 0.019532	 0.0472	 444.0	 444.0	 444.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1240	 519	 0.002923	 0.020543	 0.0365	 422.0	 422.0	 422.0	 0.0	 0.0	 1	 -30.0	 30.0;
	995	 521	 0.000142	 0.000822	 0.1073	 37106	 37106	 37106	 0.0	 0.0	 1	 -30.0	 30.0;
	995	 520	 0.000217	 0.000849	 0.1104	 452.0	 452.0	 452.0	 0.0	 0.0	 1	 -30.0	 30.0;
	522	 1325	 0.000138	 0.000296	 0.0223	 272.0	 272.0	 272.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1092	 523	 0.005965	 0.039901	 0.0739	 344.0	 344.0	 344.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1436	 523	 0.000889	 0.006104	 0.0111	 428.0	 428.0	 428.0	 0.0	 0.0	 1	 -30.0	 30.0;
	925	 524	 0.004681	 0.021847	 0.1382	 386.0	 386.0	 386.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1262	 525	 0.002953	 0.019787	 0.0363	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1262	 525	 0.002963	 0.019733	 0.0365	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	626	 526	 0.000494	 0.002212	 0.004	 322.0	 322.0	 322.0	 0.0	 0.0	 1	 -30.0	 30.0;
	626	 526	 0.000474	 0.002193	 0.004	 322.0	 322.0	 322.0	 0.0	 0.0	 1	 -30.0	 30.0;
	559	 528	 0.002086	 0.025528	 0.4534	 1246	 1246	 1246	 0.0	 0.0	 1	 -30.0	 30.0;
	764	 528	 0.001432	 0.015665	 0.3754	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1301	 529	 0.002726	 0.018212	 0.0481	 420.0	 420.0	 420.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1301	 529	 0.002765	 0.018212	 0.0486	 420.0	 420.0	 420.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1492	 530	 0.000375	 0.002548	 0.0061	 473.0	 473.0	 473.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1505	 530	 0.001969	 0.011678	 0.0223	 473.0	 473.0	 473.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1469	 532	 2e-05	 0.000198	 0.001	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1470	 531	 2e-05	 0.000198	 0.001	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1465	 533	 0.003832	 0.019733	 0.0359	 413.0	 413.0	 413.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1054	 534	 5.9e-05	 0.000138	 0.0081	 206236	 206236	 206236	 0.0	 0.0	 1	 -30.0	 30.0;
	1471	 536	 2e-05	 0.000198	 0.001	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1472	 535	 2e-05	 0.000198	 0.001	 155535	 155535	 155535	 0.0	 0.0	 1	 -30.0	 30.0;
	758	 537	 0.000217	 0.00081	 0.1002	 428.0	 428.0	 428.0	 0.0	 0.0	 1	 -30.0	 30.0;
	542	 538	 2e-06	 0.001185	 0.001	 3507.0	 3507.0	 3507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	542	 539	 2e-06	 0.001185	 0.001	 3507.0	 3507.0	 3507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	542	 540	 2e-06	 0.001185	 0.001	 3507.0	 3507.0	 3507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	542	 541	 2e-06	 0.001185	 0.001	 3507.0	 3507.0	 3507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1167	 542	 0.00381	 0.02541	 0.0471	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	818	 544	 0.00476	 0.032099	 0.0567	 423.0	 423.0	 423.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1011	 544	 0.002825	 0.019082	 0.0344	 423.0	 423.0	 423.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1138	 544	 0.000593	 0.00403	 0.0071	 502.0	 502.0	 502.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1455	 544	 0.0016	 0.010884	 0.0192	 423.0	 423.0	 423.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1239	 545	 0.018712	 0.063684	 0.1073	 467	 467	 467	 0.0	 0.0	 1	 -30.0	 30.0;
	1377	 545	 0.01297	 0.04896	 0.079	 610	 610	 610	 0.0	 0.0	 1	 -30.0	 30.0;
	1215	 546	 0.001363	 0.009106	 0.0304	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1474	 546	 0.011437	 0.078084	 0.1377	 276.0	 276.0	 276.0	 0.0	 0.0	 1	 -30.0	 30.0;
	653	 547	 0.000869	 0.004407	 0.4212	 312.0	 312.0	 312.0	 0.0	 0.0	 1	 -30.0	 30.0;
	672	 548	 0.000217	 0.000474	 0.0445	 59375	 59375	 59375	 0.0	 0.0	 1	 -30.0	 30.0;
	1464	 549	 0.002765	 0.012998	 0.0213	 305.0	 305.0	 305.0	 0.0	 0.0	 1	 -30.0	 30.0;
	554	 550	 0.001205	 0.015845	 0.5487	 1998	 1998	 1998	 0.0	 0.0	 1	 -30.0	 30.0;
	1260	 550	 0.000623	 0.008172	 0.283	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	554	 550	 0.001205	 0.015852	 0.5487	 1997	 1997	 1997	 0.0	 0.0	 1	 -30.0	 30.0;
	1260	 550	 0.000623	 0.008172	 0.283	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	731	 551	 0.001622	 0.010949	 0.0816	 420.0	 420.0	 420.0	 0.0	 0.0	 1	 -30.0	 30.0;
	840	 551	 0.004361	 0.019407	 0.0346	 413.0	 413.0	 413.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1240	 551	 0.00644	 0.043615	 0.081	 537.0	 537.0	 537.0	 0.0	 0.0	 1	 -30.0	 30.0;
	840	 551	 0.002884	 0.019127	 0.0357	 537.0	 537.0	 537.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1126	 553	 0.003553	 0.040406	 0.8776	 787	 787	 787	 0.0	 0.0	 1	 -30.0	 30.0;
	1263	 553	 0.001413	 0.020512	 0.5314	 1552	 1552	 1552	 0.0	 0.0	 1	 -30.0	 30.0;
	1352	 553	 0.002029	 0.020568	 0.5372	 1543	 1543	 1543	 0.0	 0.0	 1	 -30.0	 30.0;
	665	 553	 0.001233	 0.012465	 0.3235	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1263	 553	 0.00141	 0.019927	 0.5463	 1597	 1597	 1597	 0.0	 0.0	 1	 -30.0	 30.0;
	1216	 554	 0.000983	 0.012909	 0.4476	 2461	 2461	 2461	 0.0	 0.0	 1	 -30.0	 30.0;
	957	 555	 0.011299	 0.051259	 0.0881	 424.0	 424.0	 424.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1348	 555	 0.002232	 0.012286	 0.0218	 424.0	 424.0	 424.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1348	 555	 0.003714	 0.017975	 0.0405	 383.0	 383.0	 383.0	 0.0	 0.0	 1	 -30.0	 30.0;
	667	 558	 0.003812	 0.018568	 0.0557	 384.0	 384.0	 384.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1175	 557	 0.003911	 0.01679	 0.0284	 250.0	 250.0	 250.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1407	 558	 0.005057	 0.031131	 0.0587	 435.0	 435.0	 435.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1456	 557	 0.002785	 0.018153	 0.0334	 296.0	 296.0	 296.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1365	 559	 0.002569	 0.036468	 0.9253	 873	 873	 873	 0.0	 0.0	 1	 -30.0	 30.0;
	1365	 559	 0.002569	 0.036468	 0.9253	 873	 873	 873	 0.0	 0.0	 1	 -30.0	 30.0;
	1365	 559	 0.005422	 0.039197	 0.841	 806	 806	 806	 0.0	 0.0	 1	 -30.0	 30.0;
	566	 565	 2e-06	 0.001185	 0.001	 3507.0	 3507.0	 3507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	566	 563	 2e-06	 0.001185	 0.001	 3507.0	 3507.0	 3507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	566	 562	 2e-06	 0.001185	 0.001	 3507.0	 3507.0	 3507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	566	 560	 2e-06	 0.001185	 0.001	 3507.0	 3507.0	 3507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	566	 561	 2e-06	 0.001185	 0.001	 3507.0	 3507.0	 3507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	566	 564	 2e-06	 0.001185	 0.001	 3507.0	 3507.0	 3507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1082	 566	 0.00164	 0.011299	 0.0213	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1251	 566	 0.002647	 0.018035	 0.0334	 408.0	 408.0	 408.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1474	 568	 2e-05	 0.000138	 0.001	 509.0	 509.0	 509.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1475	 568	 0.000395	 0.002647	 0.0051	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	718	 569	 0.003259	 0.021669	 0.0405	 502.0	 502.0	 502.0	 0.0	 0.0	 1	 -30.0	 30.0;
	718	 569	 0.00324	 0.021768	 0.0395	 502.0	 502.0	 502.0	 0.0	 0.0	 1	 -30.0	 30.0;
	755	 570	 0.002351	 0.011022	 0.0182	 2747	 2747	 2747	 0.0	 0.0	 1	 -30.0	 30.0;
	818	 570	 0.0032	 0.015901	 0.0354	 333.0	 333.0	 333.0	 0.0	 0.0	 1	 -30.0	 30.0;
	929	 570	 0.002252	 0.015842	 0.079	 311.0	 311.0	 311.0	 0.0	 0.0	 1	 -30.0	 30.0;
	820	 570	 0.00132	 0.013076	 0.0385	 448.0	 448.0	 448.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1185	 570	 0.005531	 0.027042	 0.0628	 305.0	 305.0	 305.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1294	 572	 0.000138	 0.000316	 0.0314	 89765	 89765	 89765	 0.0	 0.0	 1	 -30.0	 30.0;
	1125	 574	 0.009264	 0.038696	 0.0638	 309.0	 309.0	 309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1239	 574	 0.022084	 0.061906	 0.1013	 471	 471	 471	 0.0	 0.0	 1	 -30.0	 30.0;
	1355	 574	 0.017185	 0.07921	 0.1336	 336.0	 336.0	 336.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1476	 575	 0.000296	 0.001936	 0.0137	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1493	 578	 0.00237	 0.005748	 0.0111	 5016	 5016	 5016	 0.0	 0.0	 1	 -30.0	 30.0;
	1014	 579	 0.000336	 0.002252	 0.004	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1239	 580	 0.011556	 0.052998	 0.0942	 384.0	 384.0	 384.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1351	 580	 0.011299	 0.057086	 0.1013	 336.0	 336.0	 336.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1012	 581	 0.002173	 0.014519	 0.0273	 380.0	 380.0	 380.0	 0.0	 0.0	 1	 -30.0	 30.0;
	701	 582	 0.026449	 0.06568	 0.0207	 463	 463	 463	 0.0	 0.0	 1	 -30.0	 30.0;
	753	 582	 0.012133	 0.030178	 0.0095	 1026	 1026	 1026	 0.0	 0.0	 1	 -30.0	 30.0;
	644	 584	 0.000942	 0.004946	 0.0182	 6148	 6148	 6148	 0.0	 0.0	 1	 -30.0	 30.0;
	769	 584	 0.008533	 0.038716	 0.0678	 333.0	 333.0	 333.0	 0.0	 0.0	 1	 -30.0	 30.0;
	772	 584	 0.002977	 0.014748	 0.0263	 388.0	 388.0	 388.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1059	 584	 0.002483	 0.016496	 0.0304	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1162	 584	 0.004188	 0.019082	 0.0334	 333.0	 333.0	 333.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1192	 584	 0.001742	 0.01171	 0.038	 457.0	 457.0	 457.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1251	 584	 0.001414	 0.009527	 0.0172	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	976	 585	 0.008672	 0.04002	 0.084	 256.0	 256.0	 256.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1491	 585	 0.001237	 0.005636	 0.0256	 265.0	 265.0	 265.0	 0.0	 0.0	 1	 -30.0	 30.0;
	903	 586	 0.003062	 0.020365	 0.0385	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1219	 586	 0.000786	 0.00524	 0.0273	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1478	 586	 0.003615	 0.024336	 0.0445	 558.0	 558.0	 558.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1220	 586	 0.001274	 0.008486	 0.0152	 545.0	 545.0	 545.0	 0.0	 0.0	 1	 -30.0	 30.0;
	679	 587	 0.001634	 0.016835	 0.4361	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	979	 587	 0.000935	 0.013565	 0.3523	 2335	 2335	 2335	 0.0	 0.0	 1	 -30.0	 30.0;
	1337	 587	 0.001434	 0.01885	 0.6527	 1679	 1679	 1679	 0.0	 0.0	 1	 -30.0	 30.0;
	678	 587	 0.001634	 0.016842	 0.4361	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	978	 587	 0.000934	 0.013565	 0.3523	 2335	 2335	 2335	 0.0	 0.0	 1	 -30.0	 30.0;
	1337	 587	 0.001434	 0.01885	 0.6527	 1679	 1679	 1679	 0.0	 0.0	 1	 -30.0	 30.0;
	1416	 592	 0.000111	 0.001604	 0.0416	 1382.0	 1382.0	 1382.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1416	 593	 0.000111	 0.0016	 0.0404	 1382.0	 1382.0	 1382.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1416	 591	 0.000111	 0.0016	 0.0404	 1382.0	 1382.0	 1382.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1416	 589	 0.000111	 0.0016	 0.0404	 1382.0	 1382.0	 1382.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1416	 590	 0.000111	 0.001606	 0.0416	 1382.0	 1382.0	 1382.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1416	 588	 0.000111	 0.001616	 0.0419	 1382.0	 1382.0	 1382.0	 0.0	 0.0	 1	 -30.0	 30.0;
	820	 594	 0.000988	 0.006953	 0.0273	 378.0	 378.0	 378.0	 0.0	 0.0	 1	 -30.0	 30.0;
	610	 598	 0.005195	 0.034528	 0.0648	 416.0	 416.0	 416.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1451	 599	 0.0013	 0.005888	 0.0101	 272.0	 272.0	 272.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1450	 600	 0.001306	 0.005912	 0.0101	 314.0	 314.0	 314.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1258	 601	 0.002094	 0.013294	 0.0243	 473.0	 473.0	 473.0	 0.0	 0.0	 1	 -30.0	 30.0;
	609	 602	 0.006499	 0.043259	 0.08	 428.0	 428.0	 428.0	 0.0	 0.0	 1	 -30.0	 30.0;
	754	 602	 0.003737	 0.037823	 0.1088	 314.0	 314.0	 314.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1458	 602	 0.001254	 0.008365	 0.0152	 433.0	 433.0	 433.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1242	 603	 0.00247	 0.027208	 0.5747	 1168	 1168	 1168	 0.0	 0.0	 1	 -30.0	 30.0;
	1365	 603	 0.001766	 0.019792	 0.3957	 1605	 1605	 1605	 0.0	 0.0	 1	 -30.0	 30.0;
	664	 605	 0.000401	 0.001817	 0.003	 431.0	 431.0	 431.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1549	 604	 0.0032	 0.014637	 0.0243	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	604	 430	 2e-05	 0.000198	 0.0	 155535	 155535	 155535	 0.0	 0.0	 1	 -30.0	 30.0;
	732	 606	 0.003401	 0.022763	 0.0415	 492.0	 492.0	 492.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1403	 606	 0.004122	 0.027542	 0.0501	 492.0	 492.0	 492.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1230	 607	 0.001817	 0.008198	 0.0142	 383.0	 383.0	 383.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1515	 607	 0.001857	 0.012504	 0.0233	 558.0	 558.0	 558.0	 0.0	 0.0	 1	 -30.0	 30.0;
	744	 609	 0.002844	 0.018884	 0.0354	 402.0	 402.0	 402.0	 0.0	 0.0	 1	 -30.0	 30.0;
	570	 611	 4e-05	 0.000375	 0.0	 433.0	 433.0	 433.0	 0.0	 0.0	 1	 -30.0	 30.0;
	570	 612	 5.9e-05	 0.000395	 0.0	 350.0	 350.0	 350.0	 0.0	 0.0	 1	 -30.0	 30.0;
	570	 613	 5.9e-05	 0.000454	 0.001	 350.0	 350.0	 350.0	 0.0	 0.0	 1	 -30.0	 30.0;
	791	 615	 0.000494	 0.003319	 0.0061	 566.0	 566.0	 566.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1339	 615	 0.00318	 0.016237	 0.0289	 418.0	 418.0	 418.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1545	 615	 0.003565	 0.013003	 0.0218	 255.0	 255.0	 255.0	 0.0	 0.0	 1	 -30.0	 30.0;
	648	 615	 0.001363	 0.006104	 0.0111	 432.0	 432.0	 432.0	 0.0	 0.0	 1	 -30.0	 30.0;
	791	 615	 0.000514	 0.003496	 0.0061	 566.0	 566.0	 566.0	 0.0	 0.0	 1	 -30.0	 30.0;
	791	 615	 0.000988	 0.004879	 0.0091	 432.0	 432.0	 432.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1415	 618	 0.000356	 0.003319	 0.0121	 935.0	 935.0	 935.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1414	 617	 0.00036	 0.003356	 0.0167	 853.0	 853.0	 853.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1108	 619	 0.002844	 0.018904	 0.0344	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1236	 619	 0.001086	 0.007289	 0.0132	 545.0	 545.0	 545.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1344	 619	 0.00308	 0.020628	 0.0375	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1236	 619	 0.001067	 0.007289	 0.0132	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1345	 619	 0.003022	 0.020109	 0.0375	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1344	 619	 0.003022	 0.020168	 0.0435	 463.0	 463.0	 463.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1505	 622	 0.001705	 0.010438	 0.0304	 455.0	 455.0	 455.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1345	 624	 0.001106	 0.007546	 0.0354	 405.0	 405.0	 405.0	 0.0	 0.0	 1	 -30.0	 30.0;
	607	 625	 0.000158	 0.001343	 0.5594	 654.0	 654.0	 654.0	 0.0	 0.0	 1	 -30.0	 30.0;
	647	 626	 0.002264	 0.015056	 0.0273	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1042	 626	 0.002173	 0.014617	 0.0263	 492.0	 492.0	 492.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1119	 626	 0.000375	 0.002509	 0.004	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1415	 626	 0.001746	 0.011648	 0.0216	 487.0	 487.0	 487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1422	 626	 0.000909	 0.00478	 0.0086	 431.0	 431.0	 431.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1462	 626	 0.001936	 0.011239	 0.0203	 431.0	 431.0	 431.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1414	 626	 0.001738	 0.011635	 0.0213	 487.0	 487.0	 487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1423	 626	 0.000751	 0.004148	 0.0101	 348.0	 348.0	 348.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1414	 626	 0.001679	 0.01122	 0.0203	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	756	 629	 0.000381	 0.000697	 0.0486	 38967	 38967	 38967	 0.0	 0.0	 1	 -30.0	 30.0;
	672	 632	 0.000158	 0.000593	 0.0688	 50437	 50437	 50437	 0.0	 0.0	 1	 -30.0	 30.0;
	807	 632	 0.000336	 0.001304	 0.162	 385.0	 385.0	 385.0	 0.0	 0.0	 1	 -30.0	 30.0;
	848	 632	 4e-05	 0.000237	 0.0334	 434.0	 434.0	 434.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1135	 632	 0.000296	 0.002667	 0.1863	 426.0	 426.0	 426.0	 0.0	 0.0	 1	 -30.0	 30.0;
	671	 632	 0.000362	 0.000664	 0.0466	 40928	 40928	 40928	 0.0	 0.0	 1	 -30.0	 30.0;
	1136	 632	 0.000435	 0.001659	 0.3351	 350.0	 350.0	 350.0	 0.0	 0.0	 1	 -30.0	 30.0;
	638	 633	 2e-05	 0.000198	 0.0233	 420.0	 420.0	 420.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1033	 633	 0.000237	 0.002272	 0.0081	 935.0	 935.0	 935.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1033	 633	 0.000257	 0.002449	 0.0081	 935.0	 935.0	 935.0	 0.0	 0.0	 1	 -30.0	 30.0;
	637	 633	 2e-05	 0.000198	 0.0132	 870.0	 870.0	 870.0	 0.0	 0.0	 1	 -30.0	 30.0;
	639	 635	 1e-05	 0.0001	 0.0462	 895.0	 895.0	 895.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1110	 635	 0.001143	 0.011399	 0.2946	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1110	 635	 0.001087	 0.012375	 0.2513	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	884	 640	 0.000879	 0.0037	 0.085	 8140	 8140	 8140	 0.0	 0.0	 1	 -30.0	 30.0;
	1480	 640	 0.000533	 0.003556	 0.0061	 566.0	 566.0	 566.0	 0.0	 0.0	 1	 -30.0	 30.0;
	883	 640	 0.000869	 0.003437	 0.0851	 8731	 8731	 8731	 0.0	 0.0	 1	 -30.0	 30.0;
	1482	 641	 0.000316	 0.002153	 0.004	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1481	 642	 0.000316	 0.002153	 0.004	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	737	 643	 4e-05	 0.000237	 0.0	 483.0	 483.0	 483.0	 0.0	 0.0	 1	 -30.0	 30.0;
	709	 645	 0.000852	 0.008636	 0.2224	 1828.0	 1828.0	 1828.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1395	 645	 0.001288	 0.013033	 0.335	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1483	 646	 2e-05	 0.000198	 0.001	 393.0	 393.0	 393.0	 0.0	 0.0	 1	 -30.0	 30.0;
	738	 647	 0.001541	 0.010291	 0.0238	 413.0	 413.0	 413.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1129	 647	 0.000178	 0.001225	 0.002	 545.0	 545.0	 545.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1415	 647	 0.002489	 0.016612	 0.0304	 545.0	 545.0	 545.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1549	 647	 0.002805	 0.01282	 0.0223	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	738	 647	 0.001541	 0.010252	 0.0192	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1529	 647	 0.000158	 0.001106	 0.002	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1339	 648	 0.00243	 0.01357	 0.0248	 389.0	 389.0	 389.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1506	 650	 0.001402	 0.005452	 0.0101	 346.0	 346.0	 346.0	 0.0	 0.0	 1	 -30.0	 30.0;
	733	 651	 0.00214	 0.024723	 0.5545	 1286	 1286	 1286	 0.0	 0.0	 1	 -30.0	 30.0;
	890	 651	 0.00338	 0.034294	 0.8866	 926	 926	 926	 0.0	 0.0	 1	 -30.0	 30.0;
	911	 651	 0.000229	 0.002465	 0.0549	 1487.0	 1487.0	 1487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1375	 651	 0.000561	 0.006198	 0.1473	 1731.0	 1731.0	 1731.0	 0.0	 0.0	 1	 -30.0	 30.0;
	891	 651	 0.00338	 0.034294	 0.8866	 926	 926	 926	 0.0	 0.0	 1	 -30.0	 30.0;
	783	 652	 0.008535	 0.038929	 0.0678	 268.0	 268.0	 268.0	 0.0	 0.0	 1	 -30.0	 30.0;
	816	 652	 0.001106	 0.005136	 0.0081	 5963	 5963	 5963	 0.0	 0.0	 1	 -30.0	 30.0;
	1015	 654	 0.003081	 0.020109	 0.0375	 381.0	 381.0	 381.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1495	 654	 0.000533	 0.003536	 0.0061	 524.0	 524.0	 524.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1344	 656	 0.001067	 0.004306	 0.08	 6988	 6988	 6988	 0.0	 0.0	 1	 -30.0	 30.0;
	1345	 655	 0.001067	 0.004306	 0.08	 6988	 6988	 6988	 0.0	 0.0	 1	 -30.0	 30.0;
	1517	 657	 0.006444	 0.012667	 0.0036	 2204	 2204	 2204	 0.0	 0.0	 1	 -30.0	 30.0;
	744	 658	 0.001936	 0.01284	 0.0243	 433.0	 433.0	 433.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1458	 658	 0.001363	 0.015427	 0.0445	 433.0	 433.0	 433.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1484	 659	 0.000233	 0.00156	 0.003	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	631	 660	 0.000691	 0.003852	 0.0071	 320.0	 320.0	 320.0	 0.0	 0.0	 1	 -30.0	 30.0;
	640	 660	 0.000454	 0.003121	 0.0061	 545.0	 545.0	 545.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1419	 660	 0.001896	 0.011022	 0.0284	 265.0	 265.0	 265.0	 0.0	 0.0	 1	 -30.0	 30.0;
	630	 660	 0.000514	 0.002331	 0.0116	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	640	 660	 0.000474	 0.003101	 0.0061	 566.0	 566.0	 566.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1418	 660	 0.002272	 0.011062	 0.0263	 265.0	 265.0	 265.0	 0.0	 0.0	 1	 -30.0	 30.0;
	917	 663	 5.9e-05	 0.000988	 0.004	 1363.0	 1363.0	 1363.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1316	 663	 5.9e-05	 0.001126	 0.004	 1363.0	 1363.0	 1363.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1315	 662	 5.9e-05	 0.001047	 0.004	 1363.0	 1363.0	 1363.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1352	 665	 0.00081	 0.008193	 0.2108	 1694.0	 1694.0	 1694.0	 0.0	 0.0	 1	 -30.0	 30.0;
	728	 666	 0.002528	 0.016731	 0.0304	 469.0	 469.0	 469.0	 0.0	 0.0	 1	 -30.0	 30.0;
	799	 666	 4.8e-05	 8.8e-05	 0.0051	 308785	 308785	 308785	 0.0	 0.0	 1	 -30.0	 30.0;
	976	 666	 0.008988	 0.060563	 0.1043	 404.0	 404.0	 404.0	 0.0	 0.0	 1	 -30.0	 30.0;
	746	 668	 0.002193	 0.014716	 0.0263	 416.0	 416.0	 416.0	 0.0	 0.0	 1	 -30.0	 30.0;
	926	 668	 0.001323	 0.00883	 0.0162	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1096	 669	 0.001481	 0.007072	 0.0121	 384.0	 384.0	 384.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1185	 669	 0.001956	 0.013136	 0.0243	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	718	 670	 0.011	 0.056595	 0.1027	 384.0	 384.0	 384.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1476	 673	 0.000691	 0.004563	 0.0081	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1206	 674	 0.002449	 0.016336	 0.0354	 479.0	 479.0	 479.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1485	 674	 0.006461	 0.021728	 0.0385	 325.0	 325.0	 325.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1206	 674	 0.002568	 0.017146	 0.0405	 454.0	 454.0	 454.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1271	 675	 0.000457	 0.005035	 0.1458	 1841.0	 1841.0	 1841.0	 0.0	 0.0	 1	 -30.0	 30.0;
	811	 676	 0.003	 0.013517	 0.0243	 270.0	 270.0	 270.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1486	 676	 0.003812	 0.013017	 0.0213	 2283	 2283	 2283	 0.0	 0.0	 1	 -30.0	 30.0;
	748	 680	 0.021422	 0.075067	 0.0243	 411	 411	 411	 0.0	 0.0	 1	 -30.0	 30.0;
	815	 680	 0.0252	 0.085911	 0.0252	 359	 359	 359	 0.0	 0.0	 1	 -30.0	 30.0;
	687	 683	 2e-06	 0.001185	 0.0	 3507.0	 3507.0	 3507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	687	 684	 2e-06	 0.001185	 0.0	 3507.0	 3507.0	 3507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	687	 681	 2e-06	 0.001185	 0.0	 3507.0	 3507.0	 3507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	687	 682	 2e-06	 0.001185	 0.0	 3507.0	 3507.0	 3507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	687	 686	 2e-06	 0.001244	 0.0	 3507.0	 3507.0	 3507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	687	 685	 2e-06	 0.001185	 0.0	 3507.0	 3507.0	 3507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	926	 687	 0.002449	 0.011141	 0.0203	 293.0	 293.0	 293.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1179	 687	 0.000672	 0.003141	 0.0051	 331.0	 331.0	 331.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1314	 690	 5.9e-05	 0.000198	 0.0091	 148594	 148594	 148594	 0.0	 0.0	 1	 -30.0	 30.0;
	1314	 691	 4e-05	 0.000198	 0.0051	 151981	 151981	 151981	 0.0	 0.0	 1	 -30.0	 30.0;
	892	 693	 8e-05	 0.000147	 0.0091	 184947	 184947	 184947	 0.0	 0.0	 1	 -30.0	 30.0;
	892	 692	 8.7e-05	 0.00016	 0.0091	 169954	 169954	 169954	 0.0	 0.0	 1	 -30.0	 30.0;
	1491	 694	 0.00019	 0.00062	 0.001	 48031	 48031	 48031	 0.0	 0.0	 1	 -30.0	 30.0;
	740	 695	 0.003062	 0.020365	 0.0375	 513.0	 513.0	 513.0	 0.0	 0.0	 1	 -30.0	 30.0;
	785	 695	 0.000435	 0.002607	 0.0051	 515.0	 515.0	 515.0	 0.0	 0.0	 1	 -30.0	 30.0;
	785	 696	 0.000494	 0.002923	 0.0051	 463.0	 463.0	 463.0	 0.0	 0.0	 1	 -30.0	 30.0;
	849	 697	 0.00239	 0.015842	 0.0284	 492.0	 492.0	 492.0	 0.0	 0.0	 1	 -30.0	 30.0;
	869	 697	 0.002765	 0.018548	 0.0344	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1246	 697	 0.005539	 0.038098	 0.0719	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1366	 697	 0.005116	 0.034252	 0.0628	 492.0	 492.0	 492.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1484	 697	 0.004306	 0.019919	 0.0354	 388.0	 388.0	 388.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1252	 698	 0.007802	 0.036069	 0.0633	 388.0	 388.0	 388.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1498	 698	 0.000257	 0.00164	 0.003	 524.0	 524.0	 524.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1535	 698	 0.005077	 0.023921	 0.0425	 388.0	 388.0	 388.0	 0.0	 0.0	 1	 -30.0	 30.0;
	837	 700	 0.000514	 0.0048	 0.0172	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1490	 699	 2e-05	 0.000198	 0.001	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1507	 701	 0.010533	 0.0368	 0.0121	 841	 841	 841	 0.0	 0.0	 1	 -30.0	 30.0;
	975	 702	 0.011206	 0.050285	 0.0899	 346.0	 346.0	 346.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1493	 707	 2e-05	 0.000198	 0.001	 438.0	 438.0	 438.0	 0.0	 0.0	 1	 -30.0	 30.0;
	957	 1833	 0.001975	 0.013235	 0.0309	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1118	 1833	 0.001284	 0.00879	 0.0162	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1394	 709	 0.002119	 0.02151	 0.5545	 1476	 1476	 1476	 0.0	 0.0	 1	 -30.0	 30.0;
	1051	 710	 0.011536	 0.054933	 0.0931	 409.0	 409.0	 409.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1267	 711	 0.001136	 0.014935	 0.5198	 2130	 2130	 2130	 0.0	 0.0	 1	 -30.0	 30.0;
	1267	 711	 0.001136	 0.014935	 0.517	 2130	 2130	 2130	 0.0	 0.0	 1	 -30.0	 30.0;
	1441	 712	 0.003996	 0.027473	 0.0516	 394.0	 394.0	 394.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1452	 712	 0.007111	 0.048909	 0.0921	 535.0	 535.0	 535.0	 0.0	 0.0	 1	 -30.0	 30.0;
	966	 713	 0.000124	 0.001383	 0.0051	 935.0	 935.0	 935.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1004	 713	 0.001047	 0.006953	 0.0132	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1066	 713	 9.9e-05	 0.000277	 0.0284	 104366	 104366	 104366	 0.0	 0.0	 1	 -30.0	 30.0;
	1170	 713	 0.003417	 0.022696	 0.0425	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1065	 713	 9.9e-05	 0.000336	 0.0263	 87644	 87644	 87644	 0.0	 0.0	 1	 -30.0	 30.0;
	1064	 713	 4e-05	 9.9e-05	 0.0	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	718	 715	 0.004484	 0.021195	 0.0365	 376.0	 376.0	 376.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1035	 715	 0.00324	 0.014894	 0.0243	 376.0	 376.0	 376.0	 0.0	 0.0	 1	 -30.0	 30.0;
	946	 716	 0.017133	 0.054926	 0.0006	 529	 529	 529	 0.0	 0.0	 1	 -30.0	 30.0;
	783	 717	 0.002143	 0.014358	 0.0264	 420.0	 420.0	 420.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1355	 718	 0.00403	 0.018054	 0.0349	 336.0	 336.0	 336.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1355	 718	 0.004484	 0.021156	 0.0365	 331.0	 331.0	 331.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1352	 719	 0.000557	 0.007335	 0.2533	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	955	 725	 0.000158	 0.000289	 0.0273	 93975	 93975	 93975	 0.0	 0.0	 1	 -30.0	 30.0;
	955	 723	 0.000116	 0.000212	 0.0142	 128083	 128083	 128083	 0.0	 0.0	 1	 -30.0	 30.0;
	955	 724	 0.000123	 0.000226	 0.0152	 120296	 120296	 120296	 0.0	 0.0	 1	 -30.0	 30.0;
	734	 726	 0.001327	 0.008873	 0.0466	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1384	 726	 0.002291	 0.01521	 0.0284	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1494	 727	 0.000179	 0.000327	 0.0233	 83031	 83031	 83031	 0.0	 0.0	 1	 -30.0	 30.0;
	1127	 728	 0.001244	 0.008296	 0.0142	 483.0	 483.0	 483.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1528	 729	 0.010667	 0.034444	 0.0112	 845	 845	 845	 0.0	 0.0	 1	 -30.0	 30.0;
	1114	 730	 0.009857	 0.066884	 0.1266	 455	 455	 455	 0.0	 0.0	 1	 -30.0	 30.0;
	1327	 730	 0.000632	 0.003931	 0.0243	 383.0	 383.0	 383.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1329	 730	 0.002153	 0.009758	 0.0172	 321.0	 321.0	 321.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1240	 731	 0.003279	 0.022637	 0.0415	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1497	 732	 0.001932	 0.012802	 0.0233	 477.0	 477.0	 477.0	 0.0	 0.0	 1	 -30.0	 30.0;
	874	 733	 0.00063	 0.006413	 0.1632	 1708.0	 1708.0	 1708.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1496	 734	 0.000593	 0.003951	 0.0339	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	807	 735	 0.000198	 0.001699	 0.1731	 300.0	 300.0	 300.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1449	 736	 0.010444	 0.032756	 0.0103	 930	 930	 930	 0.0	 0.0	 1	 -30.0	 30.0;
	1412	 737	 0.000296	 0.001758	 0.003	 455.0	 455.0	 455.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1548	 737	 0.000356	 0.002054	 0.004	 379.0	 379.0	 379.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1523	 737	 0.006696	 0.029985	 0.0527	 288.0	 288.0	 288.0	 0.0	 0.0	 1	 -30.0	 30.0;
	802	 739	 0.000222	 0.002327	 0.0578	 1708.0	 1708.0	 1708.0	 0.0	 0.0	 1	 -30.0	 30.0;
	851	 739	 0.001565	 0.020568	 0.7076	 1547	 1547	 1547	 0.0	 0.0	 1	 -30.0	 30.0;
	1537	 739	 0.000914	 0.009875	 0.2238	 1704.0	 1704.0	 1704.0	 0.0	 0.0	 1	 -30.0	 30.0;
	792	 739	 0.001641	 0.021544	 0.7451	 1476	 1476	 1476	 0.0	 0.0	 1	 -30.0	 30.0;
	802	 739	 0.000229	 0.002313	 0.0578	 1708.0	 1708.0	 1708.0	 0.0	 0.0	 1	 -30.0	 30.0;
	851	 739	 0.001558	 0.020568	 0.7076	 1547	 1547	 1547	 0.0	 0.0	 1	 -30.0	 30.0;
	792	 739	 0.001634	 0.021503	 0.7451	 1479	 1479	 1479	 0.0	 0.0	 1	 -30.0	 30.0;
	785	 740	 0.003378	 0.02242	 0.0415	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	801	 745	 0.003826	 0.018665	 0.0334	 388.0	 388.0	 388.0	 0.0	 0.0	 1	 -30.0	 30.0;
	822	 745	 0.00077	 0.003536	 0.0066	 330.0	 330.0	 330.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1246	 745	 0.005037	 0.034785	 0.0653	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	801	 745	 0.003615	 0.01762	 0.0314	 388.0	 388.0	 388.0	 0.0	 0.0	 1	 -30.0	 30.0;
	823	 745	 0.000711	 0.004583	 0.0081	 270.0	 270.0	 270.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1179	 746	 0.002726	 0.018193	 0.0334	 434.0	 434.0	 434.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1288	 746	 0.002596	 0.01165	 0.0203	 326.0	 326.0	 326.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1179	 746	 0.002726	 0.018193	 0.0334	 434.0	 434.0	 434.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1191	 748	 0.004507	 0.013102	 0.0043	 2312	 2312	 2312	 0.0	 0.0	 1	 -30.0	 30.0;
	1507	 748	 0.012933	 0.044356	 0.0144	 695	 695	 695	 0.0	 0.0	 1	 -30.0	 30.0;
	1511	 748	 0.002711	 0.008889	 0.0032	 3453	 3453	 3453	 0.0	 0.0	 1	 -30.0	 30.0;
	1256	 750	 0.002252	 0.010509	 0.0187	 360.0	 360.0	 360.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1362	 750	 0.008	 0.03998	 0.0709	 362.0	 362.0	 362.0	 0.0	 0.0	 1	 -30.0	 30.0;
	987	 751	 0.000109	 0.000494	 0.001	 424.0	 424.0	 424.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1338	 752	 0.005827	 0.02703	 0.0476	 333.0	 333.0	 333.0	 0.0	 0.0	 1	 -30.0	 30.0;
	973	 753	 0.006409	 0.016431	 0.005	 1911	 1911	 1911	 0.0	 0.0	 1	 -30.0	 30.0;
	1486	 754	 0.001956	 0.020958	 0.0871	 384.0	 384.0	 384.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1499	 757	 5.9e-05	 0.000435	 0.0025	 434.0	 434.0	 434.0	 0.0	 0.0	 1	 -30.0	 30.0;
	894	 758	 0.000336	 0.001225	 0.1529	 385.0	 385.0	 385.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1105	 758	 0.000138	 0.00079	 0.1063	 428.0	 428.0	 428.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1372	 758	 0.000138	 0.000889	 0.1215	 404.0	 404.0	 404.0	 0.0	 0.0	 1	 -30.0	 30.0;
	964	 759	 0.001041	 0.006967	 0.0152	 500.0	 500.0	 500.0	 0.0	 0.0	 1	 -30.0	 30.0;
	943	 760	 0.009067	 0.029116	 0.0486	 262.0	 262.0	 262.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1127	 761	 0.000701	 0.004599	 0.0082	 484.0	 484.0	 484.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1127	 761	 0.000705	 0.00463	 0.0083	 484.0	 484.0	 484.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1121	 762	 0.001956	 0.008691	 0.0248	 3468	 3468	 3468	 0.0	 0.0	 1	 -30.0	 30.0;
	933	 763	 0.012496	 0.043621	 0.0734	 304.0	 304.0	 304.0	 0.0	 0.0	 1	 -30.0	 30.0;
	989	 763	 0.018805	 0.069215	 0.1235	 432	 432	 432	 0.0	 0.0	 1	 -30.0	 30.0;
	992	 763	 0.012306	 0.062598	 0.1109	 325.0	 325.0	 325.0	 0.0	 0.0	 1	 -30.0	 30.0;
	933	 763	 0.00717	 0.042726	 0.0749	 314.0	 314.0	 314.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1180	 764	 0.001627	 0.017031	 0.3812	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1324	 765	 0.000257	 0.000612	 0.0547	 46632	 46632	 46632	 0.0	 0.0	 1	 -30.0	 30.0;
	1323	 765	 0.000237	 0.000553	 0.0496	 51447	 51447	 51447	 0.0	 0.0	 1	 -30.0	 30.0;
	1838	 765	 0.000237	 0.000553	 0.0496	 51447	 51447	 51447	 0.0	 0.0	 1	 -30.0	 30.0;
	1202	 767	 0.005017	 0.033521	 0.0607	 418.0	 418.0	 418.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1238	 768	 0.001679	 0.007526	 0.0132	 270.0	 270.0	 270.0	 0.0	 0.0	 1	 -30.0	 30.0;
	880	 769	 2e-06	 0.001185	 0.0	 3507.0	 3507.0	 3507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1162	 769	 0.004326	 0.019694	 0.0344	 333.0	 333.0	 333.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1403	 769	 0.003338	 0.015091	 0.0263	 388.0	 388.0	 388.0	 0.0	 0.0	 1	 -30.0	 30.0;
	877	 769	 2e-06	 0.001185	 0.0	 3507.0	 3507.0	 3507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1403	 769	 0.003338	 0.015091	 0.0263	 388.0	 388.0	 388.0	 0.0	 0.0	 1	 -30.0	 30.0;
	878	 769	 2e-06	 0.001185	 0.0	 3507.0	 3507.0	 3507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	827	 770	 0.000138	 0.000593	 0.0	 321.0	 321.0	 321.0	 0.0	 0.0	 1	 -30.0	 30.0;
	976	 771	 0.007723	 0.032119	 0.0527	 939	 939	 939	 0.0	 0.0	 1	 -30.0	 30.0;
	1125	 771	 0.009541	 0.039585	 0.0648	 252.0	 252.0	 252.0	 0.0	 0.0	 1	 -30.0	 30.0;
	831	 772	 0.001519	 0.010582	 0.0162	 510.0	 510.0	 510.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1059	 772	 0.002216	 0.014805	 0.0273	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	830	 772	 0.001529	 0.010637	 0.0162	 477.0	 477.0	 477.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1059	 772	 0.002206	 0.014728	 0.0273	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1163	 774	 0.000457	 0.006025	 0.2079	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1367	 774	 0.001856	 0.025166	 0.8563	 1264	 1264	 1264	 0.0	 0.0	 1	 -30.0	 30.0;
	853	 775	 0.014914	 0.055309	 0.0896	 536	 536	 536	 0.0	 0.0	 1	 -30.0	 30.0;
	1342	 775	 0.009383	 0.042607	 0.0759	 276.0	 276.0	 276.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1260	 776	 0.002597	 0.020332	 0.4202	 1408.0	 1408.0	 1408.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1260	 776	 0.001932	 0.021399	 0.4448	 1391.0	 1391.0	 1391.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1500	 777	 0.000198	 0.000909	 0.001	 325.0	 325.0	 325.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1501	 778	 0.001106	 0.007328	 0.0132	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1487	 779	 0.071454	 0.242605	 0.0033	 126	 126	 126	 0.0	 0.0	 1	 -30.0	 30.0;
	1513	 779	 0.022525	 0.13933	 0.0018	 225	 225	 225	 0.0	 0.0	 1	 -30.0	 30.0;
	946	 779	 0.068531	 0.219955	 0.0026	 138	 138	 138	 0.0	 0.0	 1	 -30.0	 30.0;
	975	 783	 0.015488	 0.067417	 0.1205	 298.0	 298.0	 298.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1193	 785	 0.005985	 0.041383	 0.0739	 391.0	 391.0	 391.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1544	 785	 0.000243	 0.001614	 0.003	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	958	 788	 0.003737	 0.024798	 0.0456	 438.0	 438.0	 438.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1434	 788	 0.000869	 0.005886	 0.0415	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1384	 790	 0.000514	 0.004247	 0.0121	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1502	 789	 5.9e-05	 0.000474	 0.002	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	953	 791	 0.004286	 0.020405	 0.0344	 432.0	 432.0	 432.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1032	 791	 0.007625	 0.035378	 0.0668	 430.0	 430.0	 430.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1032	 793	 0.001146	 0.005551	 0.0101	 424.0	 424.0	 424.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1359	 794	 0.008296	 0.038795	 0.0648	 309.0	 309.0	 309.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1006	 795	 0.00528	 0.029102	 0.0496	 335.0	 335.0	 335.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1225	 796	 9.9e-05	 0.001007	 0.003	 545.0	 545.0	 545.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1225	 797	 0.000119	 0.001067	 0.004	 545.0	 545.0	 545.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1044	 798	 0.000395	 0.001126	 0.1043	 25728	 25728	 25728	 0.0	 0.0	 1	 -30.0	 30.0;
	1435	 800	 0.000849	 0.003812	 0.0071	 432.0	 432.0	 432.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1075	 802	 7.6e-05	 0.000554	 0.0116	 908.0	 908.0	 908.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1076	 802	 7.6e-05	 0.000554	 0.0116	 908.0	 908.0	 908.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1077	 802	 7.6e-05	 0.000554	 0.0116	 908.0	 908.0	 908.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1078	 802	 7.6e-05	 0.000568	 0.0116	 908.0	 908.0	 908.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1503	 803	 1.5e-05	 9.9e-05	 0.001	 502.0	 502.0	 502.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1504	 804	 0.000277	 0.001244	 0.0886	 461.0	 461.0	 461.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1267	 805	 0.000499	 0.006557	 0.2282	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1295	 805	 0.000298	 0.003019	 0.078	 1971.0	 1971.0	 1971.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1267	 805	 0.000505	 0.006637	 0.231	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1295	 805	 0.000298	 0.003012	 0.078	 1971.0	 1971.0	 1971.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1267	 805	 0.000499	 0.006557	 0.2282	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1267	 805	 0.000499	 0.006557	 0.2282	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	873	 806	 0.000158	 0.001284	 0.1185	 385.0	 385.0	 385.0	 0.0	 0.0	 1	 -30.0	 30.0;
	995	 806	 0.000178	 0.001521	 0.1397	 385.0	 385.0	 385.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1505	 808	 1.5e-05	 9.9e-05	 0.0	 309124	 309124	 309124	 0.0	 0.0	 1	 -30.0	 30.0;
	1506	 809	 0.000158	 0.000652	 0.001	 346.0	 346.0	 346.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1183	 810	 0.002983	 0.020385	 0.0375	 558.0	 558.0	 558.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1190	 810	 0.005136	 0.034548	 0.0628	 558.0	 558.0	 558.0	 0.0	 0.0	 1	 -30.0	 30.0;
	819	 812	 0.001323	 0.008824	 0.0339	 411.0	 411.0	 411.0	 0.0	 0.0	 1	 -30.0	 30.0;
	972	 813	 0.000731	 0.00484	 0.0091	 388.0	 388.0	 388.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1354	 813	 0.002884	 0.018686	 0.0375	 500.0	 500.0	 500.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1510	 813	 0.001817	 0.012168	 0.0223	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	909	 813	 0.002785	 0.018884	 0.0334	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	972	 813	 0.00077	 0.005136	 0.0091	 388.0	 388.0	 388.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1525	 813	 0.003121	 0.020859	 0.0385	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	972	 813	 0.000731	 0.00482	 0.0091	 381.0	 381.0	 381.0	 0.0	 0.0	 1	 -30.0	 30.0;
	968	 814	 9.7e-05	 0.00097	 0.026	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1290	 814	 0.001468	 0.014903	 0.3841	 2130	 2130	 2130	 0.0	 0.0	 1	 -30.0	 30.0;
	1426	 814	 0.00036	 0.003636	 0.0953	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	970	 814	 9.7e-05	 0.00097	 0.026	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1291	 814	 0.001461	 0.014785	 0.3812	 2147	 2147	 2147	 0.0	 0.0	 1	 -30.0	 30.0;
	1386	 814	 0.001247	 0.012673	 0.3263	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	969	 814	 9.7e-05	 0.000983	 0.026	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	971	 814	 9.7e-05	 0.001025	 0.026	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1005	 815	 0.006889	 0.018756	 0.0	 1610	 1610	 1610	 0.0	 0.0	 1	 -30.0	 30.0;
	1321	 817	 0.001644	 0.005778	 0.0018	 5340	 5340	 5340	 0.0	 0.0	 1	 -30.0	 30.0;
	825	 820	 0.011753	 0.05438	 0.0931	 294.0	 294.0	 294.0	 0.0	 0.0	 1	 -30.0	 30.0;
	844	 820	 0.00083	 0.008375	 0.0263	 866.0	 866.0	 866.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1011	 820	 0.00241	 0.016435	 0.0273	 423.0	 423.0	 423.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1241	 818	 0.007585	 0.028128	 0.0456	 1063	 1063	 1063	 0.0	 0.0	 1	 -30.0	 30.0;
	1349	 819	 0.000652	 0.005946	 0.0172	 433.0	 433.0	 433.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1479	 818	 0.000632	 0.004346	 0.0233	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	843	 818	 0.000869	 0.008514	 0.0273	 866.0	 866.0	 866.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1349	 818	 0.000632	 0.00559	 0.0476	 494.0	 494.0	 494.0	 0.0	 0.0	 1	 -30.0	 30.0;
	841	 824	 0.007862	 0.038716	 0.0658	 296.0	 296.0	 296.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1012	 824	 0.001719	 0.00881	 0.0203	 358.0	 358.0	 358.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1125	 827	 0.014262	 0.067397	 0.1124	 319.0	 319.0	 319.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1218	 827	 0.021077	 0.088869	 0.1468	 301.0	 301.0	 301.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1233	 827	 0.00016	 0.000755	 0.0013	 321.0	 321.0	 321.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1041	 829	 0.00065	 0.008537	 0.2946	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1507	 832	 0.000347	 0.000813	 0.0018	 36286	 36286	 36286	 0.0	 0.0	 1	 -30.0	 30.0;
	837	 834	 4e-05	 0.000198	 0.0223	 303.0	 303.0	 303.0	 0.0	 0.0	 1	 -30.0	 30.0;
	836	 833	 2e-05	 0.000198	 0.0152	 303.0	 303.0	 303.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1165	 836	 0.000138	 0.019753	 0.001	 354.0	 354.0	 354.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1188	 836	 0.000494	 0.003002	 0.242	 300.0	 300.0	 300.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1411	 835	 0.002726	 0.013728	 0.084	 354.0	 354.0	 354.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1512	 837	 0.000356	 0.003358	 0.0121	 935.0	 935.0	 935.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1165	 835	 9.9e-05	 0.000198	 0.0091	 446.0	 446.0	 446.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1188	 836	 0.000514	 0.003101	 0.2521	 300.0	 300.0	 300.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1490	 836	 0.000909	 0.006005	 0.0142	 362.0	 362.0	 362.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1395	 839	 0.000166	 0.002749	 0.1069	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1448	 838	 0.001004	 0.010997	 0.2339	 1774.0	 1774.0	 1774.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1394	 838	 0.000159	 0.002701	 0.0982	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1112	 842	 0.000395	 0.002686	 0.0051	 490.0	 490.0	 490.0	 0.0	 0.0	 1	 -30.0	 30.0;
	929	 844	 0.000316	 0.002351	 0.0061	 376.0	 376.0	 376.0	 0.0	 0.0	 1	 -30.0	 30.0;
	954	 844	 0.000512	 0.001327	 0.159	 317.0	 317.0	 317.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1021	 845	 0.001146	 0.008296	 0.0663	 420.0	 420.0	 420.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1266	 846	 0.000711	 0.00324	 0.2916	 293.0	 293.0	 293.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1027	 847	 0.001857	 0.008435	 0.0152	 369.0	 369.0	 369.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1279	 847	 0.002647	 0.013254	 0.0243	 369.0	 369.0	 369.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1385	 848	 0.001146	 0.010923	 0.1706	 401.0	 401.0	 401.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1385	 848	 0.001185	 0.010844	 0.1671	 401.0	 401.0	 401.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1367	 851	 0.000852	 0.011233	 0.387	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1368	 851	 0.000852	 0.011226	 0.387	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1150	 857	 0.001101	 0.012181	 0.2599	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1240	 858	 0.003356	 0.026424	 0.0458	 584.0	 584.0	 584.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1348	 859	 0.000573	 0.003832	 0.0071	 566.0	 566.0	 566.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1432	 859	 0.003615	 0.025225	 0.0486	 549.0	 549.0	 549.0	 0.0	 0.0	 1	 -30.0	 30.0;
	864	 862	 2.1e-05	 0.000127	 0.1141	 1092.0	 1092.0	 1092.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1126	 862	 0.000111	 0.001932	 0.0289	 1382.0	 1382.0	 1382.0	 0.0	 0.0	 1	 -30.0	 30.0;
	863	 862	 2.1e-05	 0.000127	 0.1155	 1053.0	 1053.0	 1053.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1508	 866	 2e-05	 0.000198	 0.0172	 290.0	 290.0	 290.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1509	 867	 2e-05	 0.000198	 0.0142	 290.0	 290.0	 290.0	 0.0	 0.0	 1	 -30.0	 30.0;
	872	 868	 0.003461	 0.013896	 0.0243	 307.0	 307.0	 307.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1223	 869	 0.003793	 0.012227	 0.0203	 2446	 2446	 2446	 0.0	 0.0	 1	 -30.0	 30.0;
	959	 870	 0.001462	 0.006677	 0.1488	 420.0	 420.0	 420.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1262	 870	 0.001231	 0.008198	 0.0587	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1518	 870	 0.000865	 0.005772	 0.0101	 436.0	 436.0	 436.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1262	 870	 0.002588	 0.015862	 0.0304	 422.0	 422.0	 422.0	 0.0	 0.0	 1	 -30.0	 30.0;
	976	 871	 0.011804	 0.05293	 0.0942	 252.0	 252.0	 252.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1163	 874	 0.001101	 0.012445	 0.3105	 1488.0	 1488.0	 1488.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1181	 874	 0.0009	 0.007479	 0.0982	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1375	 874	 0.002209	 0.024924	 0.5733	 1275	 1275	 1275	 0.0	 0.0	 1	 -30.0	 30.0;
	1180	 874	 0.0009	 0.00741	 0.13	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1510	 875	 0.000395	 0.002607	 0.0051	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1374	 876	 0.01022	 0.054673	 0.0997	 337.0	 337.0	 337.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1465	 876	 0.003488	 0.015777	 0.0284	 413.0	 413.0	 413.0	 0.0	 0.0	 1	 -30.0	 30.0;
	897	 881	 0.029978	 0.100778	 0.0366	 301	 301	 301	 0.0	 0.0	 1	 -30.0	 30.0;
	849	 885	 0.001025	 0.008148	 0.0142	 584.0	 584.0	 584.0	 0.0	 0.0	 1	 -30.0	 30.0;
	887	 886	 4.3e-05	 9e-05	 0.004	 310318	 310318	 310318	 0.0	 0.0	 1	 -30.0	 30.0;
	1156	 887	 0.00079	 0.003931	 0.0071	 339.0	 339.0	 339.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1393	 887	 0.001442	 0.006696	 0.0121	 354.0	 354.0	 354.0	 0.0	 0.0	 1	 -30.0	 30.0;
	966	 888	 3.6e-05	 9.3e-05	 0.0121	 655.0	 655.0	 655.0	 0.0	 0.0	 1	 -30.0	 30.0;
	967	 889	 2.8e-05	 0.000277	 0.0058	 2187.0	 2187.0	 2187.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1361	 891	 0.001734	 0.018573	 0.4072	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1365	 891	 0.002181	 0.031662	 0.8231	 1005	 1005	 1005	 0.0	 0.0	 1	 -30.0	 30.0;
	1448	 890	 0.001711	 0.017313	 0.4476	 1828.0	 1828.0	 1828.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1365	 890	 0.002181	 0.031648	 0.8202	 1006	 1006	 1006	 0.0	 0.0	 1	 -30.0	 30.0;
	995	 892	 0.000198	 0.000652	 0.5832	 475.0	 475.0	 475.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1124	 892	 0.000316	 0.001442	 0.1326	 290.0	 290.0	 290.0	 0.0	 0.0	 1	 -30.0	 30.0;
	995	 892	 0.000237	 0.001422	 0.1873	 434.0	 434.0	 434.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1123	 892	 0.000257	 0.001007	 0.1215	 290.0	 290.0	 290.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1387	 896	 0.003319	 0.022716	 0.0415	 1346	 1346	 1346	 0.0	 0.0	 1	 -30.0	 30.0;
	921	 897	 0.024307	 0.078747	 0.0251	 384	 384	 384	 0.0	 0.0	 1	 -30.0	 30.0;
	1356	 898	 3.4e-05	 9.4e-05	 0.002	 286.0	 286.0	 286.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1376	 898	 0.003297	 0.021902	 0.0466	 477.0	 477.0	 477.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1056	 899	 0.001496	 0.014148	 0.3697	 1537.0	 1537.0	 1537.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1302	 899	 0.000942	 0.009536	 0.2455	 1633.0	 1633.0	 1633.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1056	 899	 0.001496	 0.014148	 0.3697	 1537.0	 1537.0	 1537.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1302	 899	 0.000942	 0.009536	 0.2455	 1633.0	 1633.0	 1633.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1232	 900	 0.000277	 0.000632	 0.0607	 268.0	 268.0	 268.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1232	 901	 0.000395	 0.000731	 0.0628	 37253	 37253	 37253	 0.0	 0.0	 1	 -30.0	 30.0;
	1206	 902	 0.000178	 0.000928	 0.3564	 455.0	 455.0	 455.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1413	 904	 0.012247	 0.044385	 0.0739	 357.0	 357.0	 357.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1272	 903	 9.9e-05	 0.000988	 0.004	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	923	 905	 0.006918	 0.046044	 0.0851	 535.0	 535.0	 535.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1104	 906	 0.000158	 0.000289	 0.0203	 93975	 93975	 93975	 0.0	 0.0	 1	 -30.0	 30.0;
	1105	 907	 0.000145	 0.000265	 0.0182	 102466	 102466	 102466	 0.0	 0.0	 1	 -30.0	 30.0;
	1511	 908	 0.000222	 0.000711	 0.0004	 43088	 43088	 43088	 0.0	 0.0	 1	 -30.0	 30.0;
	1510	 909	 0.000968	 0.00644	 0.0121	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	962	 913	 0.000229	 0.000419	 0.0527	 64874	 64874	 64874	 0.0	 0.0	 1	 -30.0	 30.0;
	962	 914	 0.000229	 0.000419	 0.0527	 64874	 64874	 64874	 0.0	 0.0	 1	 -30.0	 30.0;
	962	 912	 0.000284	 0.00052	 0.0461	 52282	 52282	 52282	 0.0	 0.0	 1	 -30.0	 30.0;
	1306	 917	 4e-05	 0.001086	 0.004	 1363.0	 1363.0	 1363.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1311	 917	 5.9e-05	 0.001047	 0.004	 1363.0	 1363.0	 1363.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1184	 918	 0.009007	 0.043872	 0.0749	 384.0	 384.0	 384.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1238	 918	 0.002738	 0.018562	 0.04	 503.0	 503.0	 503.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1503	 918	 0.002078	 0.008442	 0.0152	 360.0	 360.0	 360.0	 0.0	 0.0	 1	 -30.0	 30.0;
	998	 920	 2.8e-05	 0.000172	 0.0243	 455.0	 455.0	 455.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1264	 921	 0.020569	 0.065387	 0.0217	 461	 461	 461	 0.0	 0.0	 1	 -30.0	 30.0;
	1130	 922	 0.000126	 0.000261	 0.0152	 106960	 106960	 106960	 0.0	 0.0	 1	 -30.0	 30.0;
	1203	 923	 0.00083	 0.003931	 0.0071	 413.0	 413.0	 413.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1360	 923	 0.002825	 0.018943	 0.0344	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1362	 923	 0.003338	 0.019161	 0.0349	 413.0	 413.0	 413.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1204	 923	 0.00083	 0.003832	 0.0071	 413.0	 413.0	 413.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1360	 923	 0.002588	 0.017264	 0.0314	 524.0	 524.0	 524.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1232	 924	 0.000356	 0.000988	 0.1094	 280.0	 280.0	 280.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1392	 925	 0.002568	 0.011358	 0.1539	 319.0	 319.0	 319.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1512	 925	 0.000454	 0.00399	 0.3675	 428.0	 428.0	 428.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1392	 925	 0.000909	 0.007901	 0.4445	 428.0	 428.0	 428.0	 0.0	 0.0	 1	 -30.0	 30.0;
	928	 926	 2e-06	 0.001185	 0.0	 389.0	 389.0	 389.0	 0.0	 0.0	 1	 -30.0	 30.0;
	927	 926	 2e-06	 0.001185	 0.0	 389.0	 389.0	 389.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1222	 930	 0.000425	 0.001934	 0.003	 265.0	 265.0	 265.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1125	 931	 0.005798	 0.039696	 0.0724	 420.0	 420.0	 420.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1541	 931	 0.004938	 0.033165	 0.0607	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1834	 933	 0.001058	 0.001937	 0.161	 14028	 14028	 14028	 0.0	 0.0	 1	 -30.0	 30.0;
	1170	 938	 0.001027	 0.012543	 0.0243	 584.0	 584.0	 584.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1238	 938	 0.006935	 0.036516	 0.0663	 369.0	 369.0	 369.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1170	 938	 0.001798	 0.012089	 0.0223	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	985	 938	 4.8e-05	 8.8e-05	 0.001	 308192	 308192	 308192	 0.0	 0.0	 1	 -30.0	 30.0;
	984	 938	 4.8e-05	 8.8e-05	 0.001	 308192	 308192	 308192	 0.0	 0.0	 1	 -30.0	 30.0;
	1040	 939	 0.005906	 0.026627	 0.0456	 405.0	 405.0	 405.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1040	 940	 0.005906	 0.026627	 0.0445	 405.0	 405.0	 405.0	 0.0	 0.0	 1	 -30.0	 30.0;
	981	 943	 0.004573	 0.020316	 0.0405	 289.0	 289.0	 289.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1280	 944	 0.002825	 0.019239	 0.0476	 430.0	 430.0	 430.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1513	 946	 0.030738	 0.075586	 0.0009	 373	 373	 373	 0.0	 0.0	 1	 -30.0	 30.0;
	1239	 947	 0.007723	 0.044444	 0.082	 472.0	 472.0	 472.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1225	 948	 0.001659	 0.011575	 0.0091	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1225	 948	 0.001659	 0.011575	 0.0091	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	951	 950	 2.1e-05	 0.000339	 0.0087	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	952	 950	 2.1e-05	 0.000325	 0.0087	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1176	 953	 0.004741	 0.022124	 0.038	 320.0	 320.0	 320.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1275	 955	 0.000198	 0.000751	 0.0921	 401.0	 401.0	 401.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1118	 957	 0.002133	 0.009659	 0.0162	 312.0	 312.0	 312.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1149	 958	 0.002438	 0.016458	 0.0314	 416.0	 416.0	 416.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1149	 958	 0.00243	 0.016454	 0.0319	 416.0	 416.0	 416.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1154	 959	 0.000356	 0.001422	 0.0	 368.0	 368.0	 368.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1391	 961	 0.000616	 0.006627	 0.1531	 1754.0	 1754.0	 1754.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1105	 962	 0.000776	 0.004612	 0.1736	 325.0	 325.0	 325.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1431	 962	 0.000119	 0.000691	 0.0076	 397.0	 397.0	 397.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1430	 962	 0.000119	 0.000711	 0.0071	 356.0	 356.0	 356.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1471	 962	 0.001126	 0.005965	 0.0162	 272.0	 272.0	 272.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1373	 965	 0.032364	 0.095227	 0.0297	 315	 315	 315	 0.0	 0.0	 1	 -30.0	 30.0;
	1055	 966	 0.001993	 0.020458	 0.0638	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1055	 966	 0.001993	 0.020472	 0.0638	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	991	 972	 0.002686	 0.018173	 0.0324	 381.0	 381.0	 381.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1202	 972	 0.005748	 0.03836	 0.0688	 524.0	 524.0	 524.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1239	 974	 0.000277	 0.002588	 0.0051	 584.0	 584.0	 584.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1145	 976	 0.002647	 0.011911	 0.0213	 305.0	 305.0	 305.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1173	 980	 0.001659	 0.011081	 0.0203	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1173	 980	 0.002509	 0.011319	 0.0203	 388.0	 388.0	 388.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1157	 982	 0.000928	 0.006183	 0.0111	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1536	 982	 0.000217	 0.001481	 0.003	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1546	 983	 7e-06	 0.00013	 0.0029	 2694.0	 2694.0	 2694.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1171	 987	 0.000111	 0.000741	 0.0014	 545.0	 545.0	 545.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1358	 987	 0.001857	 0.008375	 0.0142	 385.0	 385.0	 385.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1172	 987	 9.9e-05	 0.000711	 0.001	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1209	 988	 0.000198	 0.000909	 0.001	 264.0	 264.0	 264.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1103	 992	 0.013274	 0.060326	 0.1043	 331.0	 331.0	 331.0	 0.0	 0.0	 1	 -30.0	 30.0;
	995	 993	 2e-05	 0.000198	 0.0091	 257.0	 257.0	 257.0	 0.0	 0.0	 1	 -30.0	 30.0;
	995	 994	 2e-05	 0.000198	 0.0051	 257.0	 257.0	 257.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1407	 996	 0.004701	 0.030064	 0.0547	 385.0	 385.0	 385.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1155	 998	 0.001343	 0.007862	 0.0142	 455.0	 455.0	 455.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1254	 999	 2.8e-05	 0.000145	 0.0606	 855.0	 855.0	 855.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1516	 1000	 5e-06	 0.0001	 0.0	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1000	 431	 1e-05	 0.0001	 0.0	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1517	 1001	 9.9e-05	 0.000182	 0.0004	 151172	 151172	 151172	 0.0	 0.0	 1	 -30.0	 30.0;
	1496	 1002	 0.00073	 0.001335	 0.1104	 20343	 20343	 20343	 0.0	 0.0	 1	 -30.0	 30.0;
	976	 1003	 0.018038	 0.057792	 0.0916	 511	 511	 511	 0.0	 0.0	 1	 -30.0	 30.0;
	1489	 1003	 0.001798	 0.004543	 0.0081	 6284	 6284	 6284	 0.0	 0.0	 1	 -30.0	 30.0;
	1195	 1008	 8e-06	 0.0001	 0.002	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1194	 1008	 8e-06	 0.0001	 0.002	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1221	 1010	 0.000909	 0.003299	 0.0051	 310.0	 310.0	 310.0	 0.0	 0.0	 1	 -30.0	 30.0;
	956	 1014	 0.002627	 0.017284	 0.0435	 1771	 1771	 1771	 0.0	 0.0	 1	 -30.0	 30.0;
	1157	 1014	 0.002272	 0.011239	 0.0203	 413.0	 413.0	 413.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1164	 1013	 0.002574	 0.013541	 0.0349	 408.0	 408.0	 408.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1292	 1012	 0.001817	 0.012207	 0.0223	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1410	 1012	 0.000375	 0.002509	 0.0051	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1477	 1013	 0.000356	 0.002311	 0.004	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1494	 1015	 0.003081	 0.020089	 0.0375	 381.0	 381.0	 381.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1839	 1015	 0.000375	 0.002528	 0.0051	 388.0	 388.0	 388.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1438	 1014	 0.001798	 0.010133	 0.0182	 408.0	 408.0	 408.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1164	 1014	 0.00097	 0.009481	 0.037	 720.0	 720.0	 720.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1468	 1012	 0.001067	 0.007091	 0.0132	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1440	 1013	 0.000751	 0.007423	 0.0248	 833.0	 833.0	 833.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1467	 1012	 0.001067	 0.007091	 0.0132	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	949	 1018	 0.00099	 0.007576	 0.156	 1486.0	 1486.0	 1486.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1158	 1017	 0.000298	 0.003262	 0.0693	 1774.0	 1774.0	 1774.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1281	 1017	 0.000561	 0.006288	 0.1574	 1774.0	 1774.0	 1774.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1282	 1017	 0.000554	 0.006163	 0.1588	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1281	 1018	 0.000382	 0.005002	 0.1718	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1282	 1018	 0.000381	 0.005	 0.1733	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1394	 1018	 0.000547	 0.006046	 0.1242	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1107	 1022	 0.006262	 0.043595	 0.078	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1303	 1022	 0.001659	 0.011022	 0.0203	 513.0	 513.0	 513.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1453	 1022	 0.002744	 0.018746	 0.0349	 515.0	 515.0	 515.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1303	 1022	 0.001659	 0.011042	 0.0203	 538.0	 538.0	 538.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1054	 1024	 0.003694	 0.02481	 0.0456	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1108	 1024	 0.002963	 0.019793	 0.0694	 370.0	 370.0	 370.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1143	 1024	 0.002647	 0.017659	 0.0324	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1345	 1024	 0.00719	 0.033264	 0.0618	 319.0	 319.0	 319.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1121	 1027	 0.003457	 0.015704	 0.0284	 369.0	 369.0	 369.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1269	 1027	 0.00164	 0.021709	 0.0911	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1192	 1028	 2e-05	 9.9e-05	 0.0121	 457.0	 457.0	 457.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1251	 1028	 0.000435	 0.002878	 0.0051	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1146	 1029	 0.003931	 0.020365	 0.037	 388.0	 388.0	 388.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1199	 1029	 0.002805	 0.012484	 0.0319	 327.0	 327.0	 327.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1193	 1030	 0.007309	 0.049876	 0.0881	 538.0	 538.0	 538.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1285	 1031	 0.006044	 0.042114	 0.0729	 513.0	 513.0	 513.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1054	 1033	 0.000612	 0.004128	 0.0081	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1140	 1033	 0.001225	 0.006854	 0.1397	 261.0	 261.0	 261.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1143	 1033	 0.001738	 0.011615	 0.0213	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	932	 1035	 0.001059	 0.003597	 0.0458	 300.0	 300.0	 300.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1095	 1035	 0.009699	 0.044839	 0.0749	 331.0	 331.0	 331.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1231	 1035	 0.001426	 0.009276	 0.0292	 366.0	 366.0	 366.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1265	 1035	 0.014143	 0.064395	 0.1134	 470	 470	 470	 0.0	 0.0	 1	 -30.0	 30.0;
	1351	 1035	 0.003502	 0.02318	 0.0547	 366.0	 366.0	 366.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1351	 1035	 0.004543	 0.024889	 0.0435	 321.0	 321.0	 321.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1518	 1036	 2e-05	 9.8e-05	 0.0	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1519	 1037	 2e-05	 0.000198	 0.001	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1520	 1038	 5.9e-05	 0.000356	 0.001	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1522	 1039	 0.001126	 0.005037	 0.0091	 5986	 5986	 5986	 0.0	 0.0	 1	 -30.0	 30.0;
	1205	 1040	 0.004642	 0.030854	 0.0557	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1427	 1040	 0.001578	 0.010526	 0.0192	 379.0	 379.0	 379.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1521	 1040	 0.000119	 0.000889	 0.002	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1262	 1043	 0.001351	 0.008986	 0.0303	 405.0	 405.0	 405.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1444	 1044	 0.001027	 0.006123	 0.2162	 296.0	 296.0	 296.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1523	 1049	 0.000194	 0.000624	 0.0009	 47367	 47367	 47367	 0.0	 0.0	 1	 -30.0	 30.0;
	1463	 1050	 0.001146	 0.007625	 0.0142	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1047	 1052	 9.9e-05	 0.000198	 0.0142	 138682	 138682	 138682	 0.0	 0.0	 1	 -30.0	 30.0;
	1046	 1052	 9.9e-05	 0.000198	 0.0182	 138682	 138682	 138682	 0.0	 0.0	 1	 -30.0	 30.0;
	1273	 1051	 9.9e-05	 0.000988	 0.004	 473.0	 473.0	 473.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1045	 1052	 0.000111	 0.000223	 0.0213	 123245	 123245	 123245	 0.0	 0.0	 1	 -30.0	 30.0;
	1121	 1053	 0.003477	 0.023822	 0.0456	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1100	 1054	 0.000324	 0.000992	 0.0729	 29661	 29661	 29661	 0.0	 0.0	 1	 -30.0	 30.0;
	1170	 1055	 0.00081	 0.005472	 0.0101	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1170	 1055	 0.000751	 0.005057	 0.0127	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1271	 1056	 0.001884	 0.019197	 0.4621	 1633.0	 1633.0	 1633.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1271	 1056	 0.001891	 0.019134	 0.4621	 1633.0	 1633.0	 1633.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1457	 1058	 0.001462	 0.009817	 0.0177	 524.0	 524.0	 524.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1341	 1061	 0.000237	 0.001501	 0.003	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1282	 1062	 0.000402	 0.005242	 0.1791	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1281	 1062	 0.000402	 0.005242	 0.1819	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1331	 1070	 5.9e-05	 0.001047	 0.004	 1363.0	 1363.0	 1363.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1317	 1069	 5.9e-05	 0.001126	 0.004	 1363.0	 1363.0	 1363.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1313	 1070	 5.9e-05	 0.001126	 0.004	 1363.0	 1363.0	 1363.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1164	 1074	 0.000366	 0.000669	 0.0476	 40590	 40590	 40590	 0.0	 0.0	 1	 -30.0	 30.0;
	1164	 1073	 0.000352	 0.000645	 0.0466	 42124	 42124	 42124	 0.0	 0.0	 1	 -30.0	 30.0;
	1326	 1079	 0.003121	 0.020997	 0.0385	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1501	 1079	 0.004602	 0.0208	 0.0365	 337.0	 337.0	 337.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1368	 1080	 0.002694	 0.028476	 0.6599	 1115	 1115	 1115	 0.0	 0.0	 1	 -30.0	 30.0;
	1403	 1081	 0.000751	 0.003417	 0.0061	 331.0	 331.0	 331.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1085	 1082	 2e-06	 0.001185	 0.0	 26121	 26121	 26121	 0.0	 0.0	 1	 -30.0	 30.0;
	1083	 1082	 2e-06	 0.001185	 0.0	 26121	 26121	 26121	 0.0	 0.0	 1	 -30.0	 30.0;
	1084	 1082	 2e-06	 0.001185	 0.0	 26121	 26121	 26121	 0.0	 0.0	 1	 -30.0	 30.0;
	1525	 1086	 0.00083	 0.005491	 0.0101	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1188	 1088	 0.000375	 0.001422	 0.1893	 263.0	 263.0	 263.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1188	 1087	 0.000395	 0.001422	 0.1903	 20973	 20973	 20973	 0.0	 0.0	 1	 -30.0	 30.0;
	1222	 1089	 0.000494	 0.002963	 0.0051	 350.0	 350.0	 350.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1329	 1093	 0.000435	 0.0016	 0.1974	 506.0	 506.0	 506.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1329	 1093	 0.000435	 0.00162	 0.2005	 506.0	 506.0	 506.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1265	 1095	 0.006499	 0.029472	 0.0506	 301.0	 301.0	 301.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1304	 1096	 0.004879	 0.022479	 0.0375	 305.0	 305.0	 305.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1527	 1098	 9.9e-05	 0.000573	 0.0511	 53230	 53230	 53230	 0.0	 0.0	 1	 -30.0	 30.0;
	1526	 1097	 0.000138	 0.000435	 0.0445	 67824	 67824	 67824	 0.0	 0.0	 1	 -30.0	 30.0;
	1121	 1101	 0.002943	 0.019773	 0.0354	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1207	 1101	 0.001679	 0.011101	 0.0203	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1519	 1103	 0.006301	 0.028622	 0.0496	 331.0	 331.0	 331.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1393	 1104	 0.002746	 0.014183	 0.1868	 325.0	 325.0	 325.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1392	 1105	 0.002469	 0.013827	 0.1757	 325.0	 325.0	 325.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1472	 1104	 0.002094	 0.010607	 0.1822	 292.0	 292.0	 292.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1459	 1106	 0.009323	 0.046598	 0.08	 354.0	 354.0	 354.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1453	 1107	 0.004425	 0.029349	 0.0547	 578.0	 578.0	 578.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1425	 1108	 0.0032	 0.021472	 0.0385	 418.0	 418.0	 418.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1290	 1110	 0.000824	 0.008373	 0.2166	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1299	 1110	 0.001211	 0.017571	 0.4563	 1811	 1811	 1811	 0.0	 0.0	 1	 -30.0	 30.0;
	1291	 1110	 0.000824	 0.008373	 0.2166	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1299	 1110	 0.001205	 0.017438	 0.4534	 1825	 1825	 1825	 0.0	 0.0	 1	 -30.0	 30.0;
	1237	 1113	 0.021244	 0.060489	 0.0193	 481	 481	 481	 0.0	 0.0	 1	 -30.0	 30.0;
	1538	 1114	 0.000553	 0.003793	 0.0071	 502.0	 502.0	 502.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1173	 1115	 0.007546	 0.034173	 0.0607	 265.0	 265.0	 265.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1528	 1120	 0.009156	 0.040044	 0.0135	 742	 742	 742	 0.0	 0.0	 1	 -30.0	 30.0;
	1142	 1121	 0.000928	 0.004148	 0.0071	 7269	 7269	 7269	 0.0	 0.0	 1	 -30.0	 30.0;
	1217	 1121	 0.002844	 0.018627	 0.0334	 468.0	 468.0	 468.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1485	 1121	 0.00257	 0.017083	 0.0314	 482.0	 482.0	 482.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1161	 1125	 0.009936	 0.040059	 0.0658	 264.0	 264.0	 264.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1454	 1125	 0.001679	 0.011062	 0.0203	 438.0	 438.0	 438.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1491	 1125	 0.004958	 0.022716	 0.0395	 265.0	 265.0	 265.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1534	 1125	 0.000178	 0.00077	 0.5083	 271.0	 271.0	 271.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1530	 1132	 0.000237	 0.001541	 0.003	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1385	 1135	 0.000948	 0.009185	 0.0324	 426.0	 426.0	 426.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1385	 1136	 0.000889	 0.008652	 0.0304	 350.0	 350.0	 350.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1366	 1139	 0.001738	 0.011595	 0.0213	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1425	 1140	 0.008652	 0.039447	 0.0724	 374.0	 374.0	 374.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1532	 1141	 0.001067	 0.004346	 0.0182	 360.0	 360.0	 360.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1322	 1144	 0.008332	 0.037879	 0.0663	 264.0	 264.0	 264.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1304	 1145	 0.008774	 0.031285	 0.0491	 305.0	 305.0	 305.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1533	 1146	 0.002311	 0.015467	 0.0284	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1534	 1147	 0.001264	 0.005136	 0.0091	 271.0	 271.0	 271.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1534	 1147	 0.001264	 0.005136	 0.0091	 271.0	 271.0	 271.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1173	 1148	 0.005886	 0.031546	 0.0567	 380.0	 380.0	 380.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1363	 1148	 0.011239	 0.050647	 0.0901	 331.0	 331.0	 331.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1434	 1149	 0.001817	 0.012089	 0.0223	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1535	 1151	 5.9e-05	 0.000403	 0.001	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1357	 1152	 0.000316	 0.001936	 0.2551	 397.0	 397.0	 397.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1170	 1153	 0.000221	 0.001357	 0.1974	 385.0	 385.0	 385.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1262	 1154	 0.003818	 0.024421	 0.1136	 366.0	 366.0	 366.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1548	 1155	 0.00162	 0.009284	 0.0162	 379.0	 379.0	 379.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1393	 1156	 0.001956	 0.009146	 0.0152	 348.0	 348.0	 348.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1477	 1157	 0.001837	 0.008988	 0.0203	 403.0	 403.0	 403.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1536	 1157	 0.000672	 0.004543	 0.0167	 403.0	 403.0	 403.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1395	 1158	 0.000242	 0.002735	 0.0549	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1536	 1160	 0.000237	 0.000494	 0.0294	 56492	 56492	 56492	 0.0	 0.0	 1	 -30.0	 30.0;
	1232	 1164	 0.000316	 0.001132	 0.1529	 297.0	 297.0	 297.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1232	 1164	 0.000316	 0.001132	 0.1529	 297.0	 297.0	 297.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1438	 1164	 0.000563	 0.003372	 0.0116	 408.0	 408.0	 408.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1440	 1164	 0.000211	 0.002058	 0.0111	 789.0	 789.0	 789.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1296	 1173	 0.002746	 0.018746	 0.0329	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1543	 1173	 0.003002	 0.015052	 0.0268	 388.0	 388.0	 388.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1365	 1174	 0.002043	 0.022929	 0.4592	 1386	 1386	 1386	 0.0	 0.0	 1	 -30.0	 30.0;
	1383	 1174	 0.000776	 0.008497	 0.1805	 1659.0	 1659.0	 1659.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1537	 1177	 1e-05	 0.0001	 0.0029	 1708.0	 1708.0	 1708.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1483	 1179	 0.003121	 0.014183	 0.0243	 331.0	 331.0	 331.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1437	 1184	 0.003099	 0.020113	 0.0385	 473.0	 473.0	 473.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1532	 1184	 0.002528	 0.016672	 0.0304	 473.0	 473.0	 473.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1406	 1185	 0.001679	 0.011397	 0.0223	 502.0	 502.0	 502.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1228	 1188	 0.00077	 0.001659	 0.2106	 16924	 16924	 16924	 0.0	 0.0	 1	 -30.0	 30.0;
	1544	 1193	 0.005628	 0.038669	 0.0729	 391.0	 391.0	 391.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1334	 1836	 0.000652	 0.001244	 0.1833	 22038	 22038	 22038	 0.0	 0.0	 1	 -30.0	 30.0;
	1357	 1197	 0.00083	 0.002588	 0.32	 321.0	 321.0	 321.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1388	 1196	 0.000395	 0.002291	 0.0182	 368.0	 368.0	 368.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1509	 1196	 0.001659	 0.011062	 0.0203	 352.0	 352.0	 352.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1238	 1198	 0.009956	 0.035773	 0.0572	 302.0	 302.0	 302.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1503	 1198	 0.002102	 0.008286	 0.0142	 360.0	 360.0	 360.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1532	 1198	 0.001185	 0.008	 0.0152	 448.0	 448.0	 448.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1252	 1199	 0.00371	 0.01789	 0.0359	 344.0	 344.0	 344.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1366	 1199	 0.001428	 0.019629	 0.0754	 638.0	 638.0	 638.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1533	 1199	 0.001244	 0.016316	 0.0699	 935.0	 935.0	 935.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1535	 1199	 0.006728	 0.030596	 0.0587	 344.0	 344.0	 344.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1368	 1200	 0.000471	 0.006184	 0.2368	 954.0	 954.0	 954.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1208	 1206	 0.006084	 0.023072	 0.24	 282.0	 282.0	 282.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1518	 1208	 0.004454	 0.01571	 0.0253	 257.0	 257.0	 257.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1538	 1210	 0.000375	 0.001679	 0.003	 17958	 17958	 17958	 0.0	 0.0	 1	 -30.0	 30.0;
	1528	 1211	 0.019867	 0.059067	 0.0189	 489	 489	 489	 0.0	 0.0	 1	 -30.0	 30.0;
	1353	 1214	 2.8e-05	 0.000409	 0.0116	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1353	 1213	 2.8e-05	 0.000422	 0.0116	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1397	 1215	 0.010667	 0.052109	 0.0901	 317.0	 317.0	 317.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1238	 1217	 0.003931	 0.026686	 0.0506	 325.0	 325.0	 325.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1442	 1222	 0.000415	 0.002785	 0.0051	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1484	 1223	 0.001225	 0.005981	 0.0111	 388.0	 388.0	 388.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1366	 1222	 0.002133	 0.014289	 0.0263	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1473	 1223	 0.000474	 0.003149	 0.0061	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1461	 1224	 0.000644	 0.002929	 0.0051	 418.0	 418.0	 418.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1366	 1225	 0.000849	 0.005728	 0.0101	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1366	 1225	 0.000849	 0.005728	 0.0101	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1366	 1225	 0.000435	 0.002963	 0.0208	 935.0	 935.0	 935.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1539	 1226	 5.9e-05	 0.000336	 0.001	 541.0	 541.0	 541.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1540	 1229	 0.003927	 0.026153	 0.0486	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1351	 1231	 0.002035	 0.014025	 0.0263	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1325	 1232	 0.000237	 0.00083	 0.1843	 268.0	 268.0	 268.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1358	 1235	 0.000454	 0.002114	 0.0061	 312.0	 312.0	 312.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1358	 1234	 0.000454	 0.002114	 0.004	 272.0	 272.0	 272.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1522	 1238	 0.002627	 0.017778	 0.0334	 502.0	 502.0	 502.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1541	 1239	 0.001462	 0.010114	 0.0182	 442.0	 442.0	 442.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1365	 1243	 0.002749	 0.039259	 1.1855	 811	 811	 811	 0.0	 0.0	 1	 -30.0	 30.0;
	1251	 1247	 2e-06	 0.001185	 0.0	 3507.0	 3507.0	 3507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1251	 1250	 2e-06	 0.001185	 0.0	 3507.0	 3507.0	 3507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1251	 1249	 2e-06	 0.001185	 0.0	 3507.0	 3507.0	 3507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1251	 1248	 2e-06	 0.001185	 0.0	 3507.0	 3507.0	 3507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1439	 1253	 0.006533	 0.022267	 0.0072	 1313	 1313	 1313	 0.0	 0.0	 1	 -30.0	 30.0;
	1449	 1253	 0.017067	 0.058356	 0.0193	 522	 522	 522	 0.0	 0.0	 1	 -30.0	 30.0;
	1541	 1255	 1.4e-05	 9.9e-05	 0.0002	 440.0	 440.0	 440.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1530	 1256	 0.002807	 0.014445	 0.0259	 413.0	 413.0	 413.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1184	 1258	 0.006933	 0.033403	 0.0607	 333.0	 333.0	 333.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1474	 1259	 0.001383	 0.009343	 0.0172	 452.0	 452.0	 452.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1475	 1259	 0.001027	 0.006815	 0.0121	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1542	 1261	 5.9e-05	 0.000296	 0.0	 328.0	 328.0	 328.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1271	 1263	 0.00141	 0.020003	 0.4967	 1589	 1589	 1589	 0.0	 0.0	 1	 -30.0	 30.0;
	1271	 1263	 0.00141	 0.02	 0.4967	 1589	 1589	 1589	 0.0	 0.0	 1	 -30.0	 30.0;
	1506	 1265	 0.006696	 0.028583	 0.0496	 346.0	 346.0	 346.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1278	 1267	 0.000194	 0.00255	 0.0895	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1277	 1267	 0.000194	 0.00255	 0.0895	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1377	 1270	 0.005709	 0.036049	 0.0881	 454.0	 454.0	 454.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1377	 1270	 0.005748	 0.036247	 0.0997	 454.0	 454.0	 454.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1320	 1271	 0.000893	 0.008663	 0.2253	 1644.0	 1644.0	 1644.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1546	 1271	 0.001707	 0.022772	 0.7812	 1390	 1390	 1390	 0.0	 0.0	 1	 -30.0	 30.0;
	1320	 1271	 0.000893	 0.008663	 0.2253	 1644.0	 1644.0	 1644.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1320	 1271	 0.00117	 0.010658	 0.2946	 1708.0	 1708.0	 1708.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1320	 1271	 0.000409	 0.006946	 0.2513	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1320	 1271	 0.000409	 0.006946	 0.2513	 2487.0	 2487.0	 2487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1299	 1278	 0.001015	 0.014744	 0.3841	 2158	 2158	 2158	 0.0	 0.0	 1	 -30.0	 30.0;
	1299	 1277	 0.001018	 0.014778	 0.3841	 2153	 2153	 2153	 0.0	 0.0	 1	 -30.0	 30.0;
	1515	 1285	 0.008119	 0.054084	 0.1002	 558.0	 558.0	 558.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1339	 1286	 0.001067	 0.004899	 0.0081	 354.0	 354.0	 354.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1520	 1286	 0.000119	 0.00077	 0.001	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1543	 1297	 0.001244	 0.006301	 0.0111	 380.0	 380.0	 380.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1463	 1298	 0.000612	 0.004069	 0.0071	 575.0	 575.0	 575.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1376	 1301	 0.004464	 0.030933	 0.0547	 461.0	 461.0	 461.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1331	 1308	 4e-05	 0.000968	 0.003	 1363.0	 1363.0	 1363.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1545	 1309	 2e-05	 0.000198	 0.0	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1545	 1310	 2e-05	 0.000198	 0.0	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1331	 1318	 5.9e-05	 0.001047	 0.004	 1363.0	 1363.0	 1363.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1341	 1326	 0.010815	 0.050299	 0.0876	 336.0	 336.0	 336.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1504	 1329	 0.002509	 0.015921	 0.0294	 454.0	 454.0	 454.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1392	 1333	 0.000316	 0.001971	 0.0273	 584.0	 584.0	 584.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1393	 1332	 0.000245	 0.00302	 0.0061	 545.0	 545.0	 545.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1520	 1339	 0.000356	 0.00241	 0.004	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1547	 1340	 0.000375	 0.004741	 0.0121	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1425	 1344	 0.002825	 0.012998	 0.0299	 330.0	 330.0	 330.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1435	 1348	 0.001481	 0.006696	 0.0111	 424.0	 424.0	 424.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1390	 1353	 0.000561	 0.005658	 0.1444	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1391	 1353	 0.000561	 0.005665	 0.1473	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1420	 1358	 0.001501	 0.010023	 0.0182	 566.0	 566.0	 566.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1457	 1360	 0.002029	 0.013533	 0.025	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1537	 1361	 0.000693	 0.007389	 0.1617	 1704.0	 1704.0	 1704.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1459	 1364	 0.010864	 0.050469	 0.0845	 354.0	 354.0	 354.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1442	 1366	 0.001719	 0.011457	 0.0213	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1514	 1366	 0.00079	 0.00798	 0.0284	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1473	 1366	 0.001434	 0.009559	 0.0172	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1380	 1374	 0.004186	 0.02786	 0.0516	 405.0	 405.0	 405.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1476	 1374	 0.002173	 0.014242	 0.0273	 507.0	 507.0	 507.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1498	 1374	 0.004109	 0.027417	 0.0486	 492.0	 492.0	 492.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1540	 1374	 0.001106	 0.007407	 0.0132	 492.0	 492.0	 492.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1516	 1382	 0.000247	 0.003489	 0.0462	 1786.0	 1786.0	 1786.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1388	 1384	 0.00083	 0.007052	 0.0724	 368.0	 368.0	 368.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1446	 1385	 0.000731	 0.003121	 0.0051	 348.0	 348.0	 348.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1496	 1384	 0.001025	 0.006888	 0.0121	 540.0	 540.0	 540.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1508	 1384	 0.000553	 0.003595	 0.0071	 352.0	 352.0	 352.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1509	 1384	 0.000533	 0.003575	 0.0061	 352.0	 352.0	 352.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1527	 1384	 0.000849	 0.00796	 0.0284	 356.0	 356.0	 356.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1445	 1385	 0.000731	 0.003121	 0.0051	 405.0	 405.0	 405.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1526	 1385	 0.000849	 0.008237	 0.0284	 356.0	 356.0	 356.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1502	 1385	 0.000375	 0.003733	 0.0121	 833.0	 833.0	 833.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1475	 1387	 0.004109	 0.027911	 0.0516	 383.0	 383.0	 383.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1431	 1392	 0.001916	 0.009323	 0.0223	 405.0	 405.0	 405.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1512	 1392	 0.000514	 0.004859	 0.0182	 584.0	 584.0	 584.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1430	 1392	 0.002212	 0.010114	 0.0233	 272.0	 272.0	 272.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1471	 1392	 0.000948	 0.004602	 0.0081	 274.0	 274.0	 274.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1472	 1393	 0.000909	 0.004385	 0.0081	 405.0	 405.0	 405.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1402	 1400	 2e-06	 0.001185	 0.0	 26121	 26121	 26121	 0.0	 0.0	 1	 -30.0	 30.0;
	1402	 1399	 2e-06	 0.001185	 0.0	 26121	 26121	 26121	 0.0	 0.0	 1	 -30.0	 30.0;
	1403	 1398	 2e-06	 0.001185	 0.0	 26121	 26121	 26121	 0.0	 0.0	 1	 -30.0	 30.0;
	1421	 1416	 0.001127	 0.014433	 0.3408	 2203	 2203	 2203	 0.0	 0.0	 1	 -30.0	 30.0;
	1549	 1424	 0.000217	 0.000988	 0.002	 272.0	 272.0	 272.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1511	 1429	 0.002756	 0.007867	 0.0022	 3850	 3850	 3850	 0.0	 0.0	 1	 -30.0	 30.0;
	1493	 1454	 0.000356	 0.00241	 0.004	 438.0	 438.0	 438.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1538	 1522	 0.000691	 0.004681	 0.0091	 503.0	 503.0	 503.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4	 6	 0.003556	 0.120296	 0.0	 265	 265	 265	 0.978474	 0.0	 1	 -30.0	 30.0;
	6	 1576	 0.00018	 -0.006163	 0.0	 1186.0	 1186.0	 1186.0	 0.999001	 0.0	 1	 -30.0	 30.0;
	5	 1599	 0.00018	 -0.006163	 0.0	 1188.0	 1188.0	 1188.0	 0.999001	 0.0	 1	 -30.0	 30.0;
	8	 1576	 0.000291	 0.030817	 0.0	 1035	 1035	 1035	 0.0	 0.0	 1	 -30.0	 30.0;
	8	 1599	 0.000291	 0.030817	 0.0	 1035	 1035	 1035	 0.0	 0.0	 1	 -30.0	 30.0;
	36	 37	 0.000332	 0.025	 0.0	 1187.0	 1187.0	 1187.0	 1.001	 0.0	 1	 -30.0	 30.0;
	2050	 1551	 0.001787	 0.084695	 0.0	 919	 919	 919	 1.05042	 0.0	 1	 -30.0	 30.0;
	39	 1551	 0.000145	 -0.006302	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39	 1600	 0.000125	 -0.006787	 0.0	 1187.0	 1187.0	 1187.0	 1.0	 0.0	 1	 -30.0	 30.0;
	40	 1551	 0.000194	 0.031302	 0.0	 1019	 1019	 1019	 0.0	 0.0	 1	 -30.0	 30.0;
	40	 1600	 0.000215	 0.031995	 0.0	 997	 997	 997	 0.0	 0.0	 1	 -30.0	 30.0;
	53	 54	 0.000665	 0.048338	 0.0	 606.0	 606.0	 606.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	53	 54	 0.000783	 0.039612	 0.0	 606.0	 606.0	 606.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	68	 70	 0.000346	 0.025139	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	68	 70	 0.000339	 0.024931	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	69	 70	 0.000339	 0.024931	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	76	 77	 0.000803	 0.042452	 0.0	 600.0	 600.0	 600.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	85	 86	 0.000734	 0.045014	 0.0	 593.0	 593.0	 593.0	 0.956938	 0.0	 1	 -30.0	 30.0;
	85	 86	 0.000727	 0.044668	 0.0	 593.0	 593.0	 593.0	 0.956938	 0.0	 1	 -30.0	 30.0;
	107	 108	 0.000803	 0.03892	 0.0	 600.0	 600.0	 600.0	 0.994036	 0.0	 1	 -30.0	 30.0;
	107	 108	 0.000845	 0.03982	 0.0	 598.0	 598.0	 598.0	 0.994036	 0.0	 1	 -30.0	 30.0;
	107	 1601	 0.000374	 -0.009003	 0.0	 600.0	 600.0	 600.0	 0.994036	 0.0	 1	 -30.0	 30.0;
	108	 1601	 0.000471	 0.048892	 0.0	 600.0	 600.0	 600.0	 0.0	 0.0	 1	 -30.0	 30.0;
	115	 117	 0.000893	 0.043767	 0.0	 606.0	 606.0	 606.0	 1.005027	 0.0	 1	 -30.0	 30.0;
	115	 117	 0.000693	 0.048615	 0.0	 606.0	 606.0	 606.0	 1.005027	 0.0	 1	 -30.0	 30.0;
	2051	 1552	 0.003421	 0.085526	 0.0	 596	 596	 596	 1.0	 0.0	 1	 -30.0	 30.0;
	120	 1552	 0.000249	 -0.004501	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	120	 1577	 0.000152	 -0.00644	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	121	 1552	 6.9e-05	 0.029294	 0.0	 1186.0	 1186.0	 1186.0	 0.0	 0.0	 1	 -30.0	 30.0;
	121	 1577	 0.00018	 0.03151	 0.0	 1186.0	 1186.0	 1186.0	 0.0	 0.0	 1	 -30.0	 30.0;
	137	 138	 0.000319	 0.024862	 0.0	 1186.0	 1186.0	 1186.0	 0.999001	 0.0	 1	 -30.0	 30.0;
	137	 138	 0.000319	 0.024792	 0.0	 1186.0	 1186.0	 1186.0	 0.999001	 0.0	 1	 -30.0	 30.0;
	154	 152	 2e-05	 0.004741	 0.004	 935.0	 935.0	 935.0	 1.0	 4.66	 1	 -30.0	 30.0;
	154	 155	 0.000319	 0.024307	 0.0	 1186.0	 1186.0	 1186.0	 1.005027	 0.0	 1	 -30.0	 30.0;
	154	 155	 0.000319	 0.024307	 0.0	 1188.0	 1188.0	 1188.0	 1.005027	 0.0	 1	 -30.0	 30.0;
	157	 158	 0.000886	 0.043837	 0.0	 632.0	 632.0	 632.0	 1.002005	 0.0	 1	 -30.0	 30.0;
	2019	 1578	 0.003449	 0.142867	 0.0	 386	 386	 386	 1.0	 0.0	 1	 -30.0	 30.0;
	167	 1578	 0.000519	 -0.007825	 0.0	 606.0	 606.0	 606.0	 1.002005	 0.0	 1	 -30.0	 30.0;
	168	 1578	 0.000277	 0.047507	 0.0	 606.0	 606.0	 606.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2086	 1579	 0.001752	 0.083864	 0.0	 608	 608	 608	 1.0	 0.0	 1	 -30.0	 30.0;
	205	 1553	 0.000249	 -0.004501	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	205	 1579	 0.000152	 -0.00644	 0.0	 1184.0	 1184.0	 1184.0	 1.0	 0.0	 1	 -30.0	 30.0;
	206	 1553	 6.9e-05	 0.029294	 0.0	 1186.0	 1186.0	 1186.0	 0.0	 0.0	 1	 -30.0	 30.0;
	206	 1579	 0.00018	 0.03151	 0.0	 1184.0	 1184.0	 1184.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1830	 226	 0.000312	 0.024979	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	227	 228	 0.000332	 0.024931	 0.0	 1186.0	 1186.0	 1186.0	 1.001	 0.0	 1	 -30.0	 30.0;
	227	 228	 0.000332	 0.024931	 0.0	 1186.0	 1186.0	 1186.0	 1.001	 0.0	 1	 -30.0	 30.0;
	229	 230	 6.9e-05	 0.056094	 0.0	 566	 566	 566	 1.0	 0.0	 1	 -30.0	 30.0;
	241	 242	 0.006133	 0.237422	 0.0	 133	 133	 133	 0.938967	 0.0	 1	 -30.0	 30.0;
	2030	 1554	 0.003428	 0.143421	 0.0	 384	 384	 384	 1.0	 0.0	 1	 -30.0	 30.0;
	2029	 1580	 0.003366	 0.141343	 0.0	 390	 390	 390	 1.0	 0.0	 1	 -30.0	 30.0;
	249	 1554	 0.000499	 -0.008379	 0.0	 606.0	 606.0	 606.0	 1.002005	 0.0	 1	 -30.0	 30.0;
	248	 1580	 0.000325	 -0.008726	 0.0	 557.0	 557.0	 557.0	 1.002005	 0.0	 1	 -30.0	 30.0;
	250	 1554	 0.000298	 0.048407	 0.0	 606.0	 606.0	 606.0	 0.0	 0.0	 1	 -30.0	 30.0;
	250	 1580	 0.000381	 0.047715	 0.0	 557.0	 557.0	 557.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2031	 1555	 0.001758	 0.081091	 0.0	 690	 690	 690	 1.00705	 0.0	 1	 -30.0	 30.0;
	2025	 1602	 0.001801	 0.088435	 0.0	 633	 633	 633	 0.985222	 0.0	 1	 -30.0	 30.0;
	2046	 1613	 0.001807	 0.093629	 0.0	 598	 598	 598	 0.985222	 0.0	 1	 -30.0	 30.0;
	2032	 1622	 0.001821	 0.092936	 0.0	 602	 602	 602	 0.985222	 0.0	 1	 -30.0	 30.0;
	253	 1555	 0.000166	 -0.005062	 0.0	 1168.0	 1168.0	 1168.0	 1.002005	 0.0	 1	 -30.0	 30.0;
	254	 1602	 0.000166	 -0.010873	 0.0	 1184.0	 1184.0	 1184.0	 1.002005	 0.0	 1	 -30.0	 30.0;
	254	 1613	 0.000152	 -0.007756	 0.0	 1184.0	 1184.0	 1184.0	 1.002005	 0.0	 1	 -30.0	 30.0;
	253	 1622	 0.000118	 -0.007618	 0.0	 1184.0	 1184.0	 1184.0	 1.002005	 0.0	 1	 -30.0	 30.0;
	258	 1555	 0.000201	 0.026437	 0.0	 1168.0	 1168.0	 1168.0	 0.0	 0.0	 1	 -30.0	 30.0;
	257	 1602	 0.000166	 0.038296	 0.0	 956	 956	 956	 0.0	 0.0	 1	 -30.0	 30.0;
	258	 1613	 0.000187	 0.03518	 0.0	 1040	 1040	 1040	 0.0	 0.0	 1	 -30.0	 30.0;
	257	 1622	 0.00018	 0.034695	 0.0	 1055	 1055	 1055	 0.0	 0.0	 1	 -30.0	 30.0;
	267	 269	 0.000325	 0.026801	 0.0	 1177	 1177	 1177	 1.0	 0.0	 1	 -30.0	 30.0;
	267	 268	 0.000319	 0.026593	 0.0	 1184.0	 1184.0	 1184.0	 1.0	 0.0	 1	 -30.0	 30.0;
	270	 271	 0.007664	 0.250785	 0.0	 123	 123	 123	 1.0	 0.0	 1	 -30.0	 30.0;
	270	 271	 0.007664	 0.250785	 0.0	 123	 123	 123	 1.0	 0.0	 1	 -30.0	 30.0;
	270	 271	 0.007664	 0.250785	 0.0	 123	 123	 123	 1.0	 0.0	 1	 -30.0	 30.0;
	278	 1556	 0.004224	 0.148199	 0.0	 415	 415	 415	 1.0	 0.0	 1	 -30.0	 30.0;
	279	 1556	 0.000388	 -0.009003	 0.0	 606.0	 606.0	 606.0	 0.994036	 0.0	 1	 -30.0	 30.0;
	279	 1581	 0.00063	 -0.005194	 0.0	 606.0	 606.0	 606.0	 0.994036	 0.0	 1	 -30.0	 30.0;
	280	 1556	 0.000395	 0.049169	 0.0	 606.0	 606.0	 606.0	 0.0	 0.0	 1	 -30.0	 30.0;
	280	 1581	 3.5e-05	 0.048476	 0.0	 606.0	 606.0	 606.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2062	 1603	 0.003802	 0.098338	 0.0	 569	 569	 569	 1.0	 0.0	 1	 -30.0	 30.0;
	290	 291	 0.000325	 0.027147	 0.0	 1168	 1168	 1168	 0.999001	 0.0	 1	 -30.0	 30.0;
	290	 291	 0.000319	 0.027216	 0.0	 1165	 1165	 1165	 0.999001	 0.0	 1	 -30.0	 30.0;
	290	 1603	 0.000229	 -0.008102	 0.0	 1186.0	 1186.0	 1186.0	 1.002005	 0.0	 1	 -30.0	 30.0;
	292	 1603	 8.3e-05	 0.035734	 0.0	 1024	 1024	 1024	 0.0	 0.0	 1	 -30.0	 30.0;
	2047	 1604	 0.001655	 0.091413	 0.0	 612	 612	 612	 0.985222	 0.0	 1	 -30.0	 30.0;
	307	 308	 0.000339	 0.027285	 0.0	 1162	 1162	 1162	 1.0	 0.0	 1	 -30.0	 30.0;
	307	 308	 0.000339	 0.027355	 0.0	 1159	 1159	 1159	 1.0	 0.0	 1	 -30.0	 30.0;
	307	 1604	 0.000132	 -0.007479	 0.0	 1186.0	 1186.0	 1186.0	 1.002005	 0.0	 1	 -30.0	 30.0;
	308	 1604	 0.000173	 0.034764	 0.0	 1053	 1053	 1053	 0.0	 0.0	 1	 -30.0	 30.0;
	327	 328	 0.002469	 0.533333	 0.0	 118	 118	 118	 1.0	 0.0	 1	 -30.0	 30.0;
	346	 347	 0.000325	 0.025139	 0.0	 1186.0	 1186.0	 1186.0	 0.999001	 0.0	 1	 -30.0	 30.0;
	345	 347	 0.000325	 0.025346	 0.0	 1186.0	 1186.0	 1186.0	 0.999001	 0.0	 1	 -30.0	 30.0;
	348	 350	 0.000332	 0.027078	 0.0	 1165	 1165	 1165	 1.0	 0.0	 1	 -30.0	 30.0;
	348	 350	 0.000325	 0.027355	 0.0	 1153	 1153	 1153	 0.999001	 0.0	 1	 -30.0	 30.0;
	348	 350	 0.000817	 0.042313	 0.0	 606.0	 606.0	 606.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	348	 350	 0.000686	 0.043075	 0.0	 606.0	 606.0	 606.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	361	 363	 0.000319	 0.024723	 0.0	 1186.0	 1186.0	 1186.0	 0.999001	 0.0	 1	 -30.0	 30.0;
	360	 363	 0.000332	 0.024931	 0.0	 1186.0	 1186.0	 1186.0	 0.999001	 0.0	 1	 -30.0	 30.0;
	2014	 1623	 0.002216	 0.086634	 0.0	 679	 679	 679	 1.0	 0.0	 1	 -30.0	 30.0;
	1623	 368	 0.000402	 -0.007341	 0.0	 581.0	 581.0	 581.0	 1.049318	 0.0	 1	 -30.0	 30.0;
	368	 369	 0.000263	 0.025277	 0.0	 585.0	 585.0	 585.0	 0.959693	 0.0	 1	 -30.0	 30.0;
	368	 369	 0.000319	 0.024862	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	369	 1623	 0.000242	 0.03144	 0.0	 581.0	 581.0	 581.0	 0.0	 0.0	 1	 -30.0	 30.0;
	388	 390	 0.000332	 0.024654	 0.0	 1184.0	 1184.0	 1184.0	 1.001	 0.0	 1	 -30.0	 30.0;
	388	 390	 0.000312	 0.024654	 0.0	 1184.0	 1184.0	 1184.0	 1.001	 0.0	 1	 -30.0	 30.0;
	396	 397	 0.006133	 0.237422	 0.0	 133	 133	 133	 0.938967	 0.0	 1	 -30.0	 30.0;
	420	 1557	 0.000263	 -0.005471	 0.0	 1184.0	 1184.0	 1184.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	421	 1557	 6.2e-05	 0.032895	 0.0	 965	 965	 965	 0.0	 0.0	 1	 -30.0	 30.0;
	435	 436	 0.000325	 0.027355	 0.0	 1153	 1153	 1153	 0.999001	 0.0	 1	 -30.0	 30.0;
	435	 436	 0.000796	 0.041551	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	435	 436	 0.000727	 0.048753	 0.0	 607.0	 607.0	 607.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	435	 436	 0.000325	 0.027562	 0.0	 1145	 1145	 1145	 1.0	 0.0	 1	 -30.0	 30.0;
	2020	 1614	 0.001794	 0.090166	 0.0	 350	 350	 350	 1.0	 0.0	 1	 -30.0	 30.0;
	440	 1614	 0.000159	 -0.007133	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	440	 1624	 0.000277	 -0.005609	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	441	 1614	 0.000173	 0.033726	 0.0	 942	 942	 942	 0.0	 0.0	 1	 -30.0	 30.0;
	441	 1624	 6.2e-05	 0.032964	 0.0	 963	 963	 963	 0.0	 0.0	 1	 -30.0	 30.0;
	442	 443	 0.000325	 0.024792	 0.0	 1184.0	 1184.0	 1184.0	 1.001	 0.0	 1	 -30.0	 30.0;
	456	 458	 0.000332	 0.025069	 0.0	 1186.0	 1186.0	 1186.0	 0.999001	 0.0	 1	 -30.0	 30.0;
	456	 458	 0.000332	 0.024931	 0.0	 1186.0	 1186.0	 1186.0	 0.999001	 0.0	 1	 -30.0	 30.0;
	2033	 1558	 0.001814	 0.093837	 0.0	 336	 336	 336	 1.0	 0.0	 1	 -30.0	 30.0;
	461	 1558	 0.000145	 -0.007548	 0.0	 1187.0	 1187.0	 1187.0	 1.002005	 0.0	 1	 -30.0	 30.0;
	461	 1582	 0.000533	 -0.004848	 0.0	 606.0	 606.0	 606.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	462	 1558	 0.000187	 0.03428	 0.0	 926	 926	 926	 0.0	 0.0	 1	 -30.0	 30.0;
	462	 1582	 0.000173	 0.053186	 0.0	 597	 597	 597	 0.0	 0.0	 1	 -30.0	 30.0;
	527	 528	 0.000735	 0.044668	 0.0	 593.0	 593.0	 593.0	 0.959693	 0.0	 1	 -30.0	 30.0;
	2021	 1583	 0.003435	 0.08608	 0.0	 639	 639	 639	 1.0	 0.0	 1	 -30.0	 30.0;
	551	 553	 0.000803	 0.034418	 0.0	 605.0	 605.0	 605.0	 1.002005	 0.0	 1	 -30.0	 30.0;
	551	 1583	 0.000277	 -0.004709	 0.0	 1184.0	 1184.0	 1184.0	 1.001	 0.0	 1	 -30.0	 30.0;
	553	 1583	 4.8e-05	 0.029571	 0.0	 1184.0	 1184.0	 1184.0	 0.0	 0.0	 1	 -30.0	 30.0;
	555	 556	 0.000319	 0.024792	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	558	 559	 0.000332	 0.024723	 0.0	 1186.0	 1186.0	 1186.0	 0.999001	 0.0	 1	 -30.0	 30.0;
	558	 559	 0.000305	 0.025	 0.0	 1186.0	 1186.0	 1186.0	 0.999001	 0.0	 1	 -30.0	 30.0;
	586	 587	 0.000319	 0.02687	 0.0	 1174	 1174	 1174	 1.0	 0.0	 1	 -30.0	 30.0;
	586	 587	 0.000339	 0.02687	 0.0	 1174	 1174	 1174	 1.0	 0.0	 1	 -30.0	 30.0;
	586	 587	 0.00036	 0.027285	 0.0	 1156	 1156	 1156	 1.0	 0.0	 1	 -30.0	 30.0;
	595	 596	 0.002909	 0.158587	 0.0	 200	 200	 200	 1.031993	 0.0	 1	 -30.0	 30.0;
	595	 597	 0.002832	 0.157202	 0.0	 202	 202	 202	 1.021451	 0.0	 1	 -30.0	 30.0;
	2015	 1559	 0.001683	 0.083379	 0.0	 737	 737	 737	 1.0	 0.0	 1	 -30.0	 30.0;
	1559	 602	 0.000152	 -0.006163	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	603	 1559	 0.000159	 0.031163	 0.0	 1024	 1024	 1024	 0.0	 0.0	 1	 -30.0	 30.0;
	430	 605	 0.000119	 0.00796	 0.0	 418.0	 418.0	 418.0	 1.0	 -1.94	 1	 -30.0	 30.0;
	614	 615	 0.005096	 0.143921	 0.0	 221	 221	 221	 1.0	 0.0	 1	 -30.0	 30.0;
	614	 615	 0.005531	 0.188247	 0.0	 169	 169	 169	 1.012149	 0.0	 1	 -30.0	 30.0;
	622	 623	 0.000713	 0.043283	 0.0	 606.0	 606.0	 606.0	 0.994036	 0.0	 1	 -30.0	 30.0;
	622	 623	 0.000769	 0.043837	 0.0	 606.0	 606.0	 606.0	 0.994036	 0.0	 1	 -30.0	 30.0;
	633	 635	 0.000319	 0.027424	 0.0	 1157	 1157	 1157	 1.0	 0.0	 1	 -30.0	 30.0;
	633	 635	 0.000319	 0.027355	 0.0	 1159	 1159	 1159	 1.0	 0.0	 1	 -30.0	 30.0;
	649	 650	 0.002074	 0.161778	 0.0	 195	 195	 195	 0.7446	 0.0	 1	 -30.0	 30.0;
	649	 650	 0.002074	 0.161778	 0.0	 195	 195	 195	 0.875657	 0.0	 1	 -30.0	 30.0;
	657	 658	 0.005472	 0.190025	 0.0	 166	 166	 166	 1.0	 0.0	 1	 -30.0	 30.0;
	674	 675	 0.000319	 0.024307	 0.0	 1186.0	 1186.0	 1186.0	 1.005027	 0.0	 1	 -30.0	 30.0;
	677	 679	 0.000693	 0.048753	 0.0	 606.0	 606.0	 606.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	677	 678	 0.000796	 0.042452	 0.0	 606.0	 606.0	 606.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	701	 702	 0.0032	 0.124444	 0.0	 257	 257	 257	 1.0	 0.0	 1	 -30.0	 30.0;
	1833	 709	 0.000332	 0.024862	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1833	 1584	 0.000145	 -0.006371	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	708	 1605	 0.000132	 -0.006302	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	709	 1584	 0.000187	 0.031163	 0.0	 1024	 1024	 1024	 0.0	 0.0	 1	 -30.0	 30.0;
	709	 1605	 0.000187	 0.03144	 0.0	 1015	 1015	 1015	 0.0	 0.0	 1	 -30.0	 30.0;
	710	 711	 0.000845	 0.042729	 0.0	 606.0	 606.0	 606.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	716	 717	 0.001936	 0.115358	 0.0	 269	 269	 269	 1.023541	 0.0	 1	 -30.0	 30.0;
	718	 719	 0.000332	 0.024238	 0.0	 1186.0	 1186.0	 1186.0	 1.001	 0.0	 1	 -30.0	 30.0;
	718	 719	 0.000332	 0.024238	 0.0	 1184.0	 1184.0	 1184.0	 1.001	 0.0	 1	 -30.0	 30.0;
	729	 730	 0.004543	 0.137284	 0.0	 224	 224	 224	 0.952381	 0.0	 1	 -30.0	 30.0;
	732	 733	 0.00081	 0.039266	 0.0	 600.0	 600.0	 600.0	 1.005027	 0.0	 1	 -30.0	 30.0;
	732	 733	 0.00081	 0.039612	 0.0	 600.0	 600.0	 600.0	 1.005027	 0.0	 1	 -30.0	 30.0;
	736	 737	 0.003338	 0.158025	 0.0	 202	 202	 202	 0.98912	 0.0	 1	 -30.0	 30.0;
	741	 742	 0.001842	 0.101731	 0.0	 310	 310	 310	 0.984249	 0.0	 1	 -30.0	 30.0;
	741	 743	 0.001821	 0.100762	 0.0	 313	 313	 313	 0.996016	 0.0	 1	 -30.0	 30.0;
	747	 748	 0.001956	 0.003956	 0.0	 974.0	 974.0	 974.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2052	 1606	 0.004862	 0.209488	 0.0	 293	 293	 293	 1.0	 0.0	 1	 -30.0	 30.0;
	763	 764	 0.000665	 0.043075	 0.0	 600.0	 600.0	 600.0	 1.005027	 0.0	 1	 -30.0	 30.0;
	763	 764	 0.000672	 0.04356	 0.0	 600.0	 600.0	 600.0	 1.005027	 0.0	 1	 -30.0	 30.0;
	1606	 763	 0.000554	 -0.004224	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	764	 1606	 0.000118	 0.047576	 0.0	 600.0	 600.0	 600.0	 0.0	 0.0	 1	 -30.0	 30.0;
	765	 766	 0.000679	 0.04536	 0.0	 606.0	 606.0	 606.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	765	 766	 0.000686	 0.045083	 0.0	 606.0	 606.0	 606.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	772	 774	 0.000332	 0.024862	 0.0	 1186.0	 1186.0	 1186.0	 1.005027	 0.0	 1	 -30.0	 30.0;
	772	 774	 0.000319	 0.024792	 0.0	 1186.0	 1186.0	 1186.0	 1.005027	 0.0	 1	 -30.0	 30.0;
	772	 774	 0.000319	 0.025139	 0.0	 1186.0	 1186.0	 1186.0	 1.005027	 0.0	 1	 -30.0	 30.0;
	2016	 1560	 0.004993	 0.223892	 0.0	 141	 141	 141	 1.0	 0.0	 1	 -30.0	 30.0;
	775	 1560	 0.000651	 -0.005055	 0.0	 547.0	 547.0	 547.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	776	 1560	 4.2e-05	 0.05374	 0.0	 547.0	 547.0	 547.0	 0.0	 0.0	 1	 -30.0	 30.0;
	779	 783	 0.003378	 0.105679	 0.0	 301	 301	 301	 0.968054	 0.0	 1	 -30.0	 30.0;
	779	 783	 0.003299	 0.107654	 0.0	 295	 295	 295	 0.978474	 0.0	 1	 -30.0	 30.0;
	780	 784	 0.001807	 0.100831	 0.0	 317	 317	 317	 0.95602	 0.0	 1	 -30.0	 30.0;
	780	 784	 0.00178	 0.100139	 0.0	 319	 319	 319	 0.95602	 0.0	 1	 -30.0	 30.0;
	783	 784	 0.000759	 0.035838	 0.0	 886	 886	 886	 1.001	 0.0	 1	 -30.0	 30.0;
	2059	 1561	 0.001807	 0.088296	 0.0	 357	 357	 357	 1.0	 0.0	 1	 -30.0	 30.0;
	2043	 1585	 0.001794	 0.092175	 0.0	 342	 342	 342	 1.0	 0.0	 1	 -30.0	 30.0;
	785	 1561	 0.000145	 -0.011219	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	785	 1585	 0.000139	 -0.007687	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	786	 1561	 0.000194	 0.038781	 0.0	 819	 819	 819	 0.0	 0.0	 1	 -30.0	 30.0;
	787	 1585	 0.000187	 0.034903	 0.0	 910	 910	 910	 0.0	 0.0	 1	 -30.0	 30.0;
	791	 792	 0.000319	 0.024862	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	791	 792	 0.000325	 0.024862	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	801	 1562	 0.000443	 -0.004848	 0.0	 606.0	 606.0	 606.0	 1.005027	 0.0	 1	 -30.0	 30.0;
	801	 1586	 0.000305	 -0.007133	 0.0	 606.0	 606.0	 606.0	 1.005027	 0.0	 1	 -30.0	 30.0;
	801	 802	 0.000734	 0.024654	 0.0	 1188.0	 1188.0	 1188.0	 1.0	 0.0	 1	 -30.0	 30.0;
	802	 1562	 0.000249	 0.047992	 0.0	 606.0	 606.0	 606.0	 0.0	 0.0	 1	 -30.0	 30.0;
	802	 1586	 0.000506	 0.046814	 0.0	 606.0	 606.0	 606.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2064	 1587	 0.003386	 0.156994	 0.0	 357	 357	 357	 1.00705	 0.0	 1	 -30.0	 30.0;
	2063	 1607	 0.001794	 0.093906	 0.0	 596	 596	 596	 0.986193	 0.0	 1	 -30.0	 30.0;
	813	 1563	 0.000152	 -0.011219	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	813	 1587	 0.000443	 -0.011011	 0.0	 606.0	 606.0	 606.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	813	 1607	 0.000215	 -0.005194	 0.0	 1186.0	 1186.0	 1186.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	813	 1615	 0.000145	 -0.011496	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	814	 1563	 0.000187	 0.038296	 0.0	 956	 956	 956	 0.0	 0.0	 1	 -30.0	 30.0;
	814	 1587	 0.000374	 0.053463	 0.0	 606.0	 606.0	 606.0	 0.0	 0.0	 1	 -30.0	 30.0;
	814	 1607	 9.7e-05	 0.032064	 0.0	 1141	 1141	 1141	 0.0	 0.0	 1	 -30.0	 30.0;
	814	 1615	 0.000194	 0.038435	 0.0	 952	 952	 952	 0.0	 0.0	 1	 -30.0	 30.0;
	818	 1564	 0.000229	 -0.004571	 0.0	 1186.0	 1186.0	 1186.0	 0.999001	 0.0	 1	 -30.0	 30.0;
	820	 1588	 0.000215	 -0.004432	 0.0	 1186.0	 1186.0	 1186.0	 0.999001	 0.0	 1	 -30.0	 30.0;
	819	 821	 0.000312	 0.025069	 0.0	 1186.0	 1186.0	 1186.0	 0.999001	 0.0	 1	 -30.0	 30.0;
	821	 1564	 9.7e-05	 0.029363	 0.0	 1087	 1087	 1087	 0.0	 0.0	 1	 -30.0	 30.0;
	821	 1588	 9.7e-05	 0.029086	 0.0	 1097	 1097	 1097	 0.0	 0.0	 1	 -30.0	 30.0;
	2078	 1589	 0.001787	 0.089335	 0.0	 626	 626	 626	 1.0	 0.0	 1	 -30.0	 30.0;
	2065	 1616	 0.001842	 0.091205	 0.0	 614	 614	 614	 1.0	 0.0	 1	 -30.0	 30.0;
	836	 839	 0.000325	 0.027355	 0.0	 1159	 1159	 1159	 1.0	 0.0	 1	 -30.0	 30.0;
	837	 1589	 0.000152	 -0.011357	 0.0	 1187.0	 1187.0	 1187.0	 1.0	 0.0	 1	 -30.0	 30.0;
	836	 1608	 0.000145	 -0.00741	 0.0	 1187.0	 1187.0	 1187.0	 1.0	 0.0	 1	 -30.0	 30.0;
	836	 1616	 0.000125	 -0.007756	 0.0	 1187.0	 1187.0	 1187.0	 1.0	 0.0	 1	 -30.0	 30.0;
	839	 1589	 0.000187	 0.038435	 0.0	 952	 952	 952	 0.0	 0.0	 1	 -30.0	 30.0;
	838	 1608	 0.000194	 0.034626	 0.0	 1057	 1057	 1057	 0.0	 0.0	 1	 -30.0	 30.0;
	838	 1616	 0.000215	 0.034903	 0.0	 1049	 1049	 1049	 0.0	 0.0	 1	 -30.0	 30.0;
	849	 851	 0.000319	 0.024792	 0.0	 1186.0	 1186.0	 1186.0	 1.005027	 0.0	 1	 -30.0	 30.0;
	849	 851	 0.000319	 0.024792	 0.0	 1186.0	 1186.0	 1186.0	 1.005027	 0.0	 1	 -30.0	 30.0;
	2036	 1565	 0.003733	 0.147368	 0.0	 374	 374	 374	 1.0	 0.0	 1	 -30.0	 30.0;
	2037	 1590	 0.003781	 0.146814	 0.0	 375	 375	 375	 1.0	 0.0	 1	 -30.0	 30.0;
	854	 1565	 0.00045	 -0.014404	 0.0	 567.0	 567.0	 567.0	 1.0	 0.0	 1	 -30.0	 30.0;
	854	 1590	 0.000471	 -0.013712	 0.0	 581.0	 581.0	 581.0	 1.0	 0.0	 1	 -30.0	 30.0;
	854	 857	 0.000803	 0.034903	 0.0	 581.0	 581.0	 581.0	 1.0	 0.0	 1	 -30.0	 30.0;
	857	 1565	 0.000381	 0.050623	 0.0	 567.0	 567.0	 567.0	 0.0	 0.0	 1	 -30.0	 30.0;
	857	 1590	 0.000367	 0.050554	 0.0	 581.0	 581.0	 581.0	 0.0	 0.0	 1	 -30.0	 30.0;
	898	 1566	 0.000235	 -0.004294	 0.0	 1184.0	 1184.0	 1184.0	 1.0	 0.0	 1	 -30.0	 30.0;
	898	 1591	 0.000145	 -0.006233	 0.0	 1184.0	 1184.0	 1184.0	 1.0	 0.0	 1	 -30.0	 30.0;
	899	 1566	 9e-05	 0.029086	 0.0	 1184.0	 1184.0	 1184.0	 0.0	 0.0	 1	 -30.0	 30.0;
	899	 1591	 0.000194	 0.031233	 0.0	 1184.0	 1184.0	 1184.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1272	 904	 0.000119	 0.009086	 0.0	 471.0	 471.0	 471.0	 0.0	 0.0	 1	 -30.0	 30.0;
	966	 967	 0.000284	 0.024792	 0.0	 1186.0	 1186.0	 1186.0	 1.046025	 0.0	 1	 -30.0	 30.0;
	977	 979	 0.00187	 0.101731	 0.0	 310	 310	 310	 0.984249	 0.0	 1	 -30.0	 30.0;
	977	 978	 0.001773	 0.099862	 0.0	 316	 316	 316	 0.994033	 0.0	 1	 -30.0	 30.0;
	431	 999	 4.2e-05	 0.000339	 0.0061	 1184.0	 1184.0	 1184.0	 1.0	 -9.95	 1	 -30.0	 30.0;
	998	 999	 0.000679	 0.042867	 0.0	 606.0	 606.0	 606.0	 0.994036	 0.0	 1	 -30.0	 30.0;
	2053	 1567	 0.001773	 0.092729	 0.0	 603	 603	 603	 0.985222	 0.0	 1	 -30.0	 30.0;
	2054	 1609	 0.001856	 0.093213	 0.0	 600	 600	 600	 1.0	 0.0	 1	 -30.0	 30.0;
	1012	 1567	 0.000111	 -0.007895	 0.0	 1184.0	 1184.0	 1184.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1013	 1592	 0.00027	 -0.005402	 0.0	 1184.0	 1184.0	 1184.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1012	 1609	 0.000152	 -0.007964	 0.0	 1184.0	 1184.0	 1184.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1015	 1617	 0.000152	 -0.007271	 0.0	 1184.0	 1184.0	 1184.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1014	 1018	 0.000325	 0.027078	 0.0	 1171	 1171	 1171	 1.0	 0.0	 1	 -30.0	 30.0;
	1017	 1567	 0.000222	 0.03518	 0.0	 1040	 1040	 1040	 0.0	 0.0	 1	 -30.0	 30.0;
	1017	 1592	 5.5e-05	 0.032756	 0.0	 1117	 1117	 1117	 0.0	 0.0	 1	 -30.0	 30.0;
	1018	 1609	 0.000201	 0.034764	 0.0	 1053	 1053	 1053	 0.0	 0.0	 1	 -30.0	 30.0;
	1018	 1617	 0.000194	 0.034141	 0.0	 1072	 1072	 1072	 0.0	 0.0	 1	 -30.0	 30.0;
	1022	 1023	 0.000339	 0.027285	 0.0	 1156	 1156	 1156	 1.0	 0.0	 1	 -30.0	 30.0;
	1040	 1568	 0.000215	 -0.00554	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1040	 1041	 0.000325	 0.027355	 0.0	 1154	 1154	 1154	 1.0	 0.0	 1	 -30.0	 30.0;
	1041	 1568	 0.000125	 0.033241	 0.0	 955	 955	 955	 0.0	 0.0	 1	 -30.0	 30.0;
	1273	 1052	 0.000119	 0.009086	 0.0	 473.0	 473.0	 473.0	 1.0	 -6.32	 1	 -30.0	 30.0;
	1055	 1056	 0.000319	 0.024307	 0.0	 1188.0	 1188.0	 1188.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1055	 1056	 0.000339	 0.025	 0.0	 1188.0	 1188.0	 1188.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1055	 1056	 0.000325	 0.024584	 0.0	 1188.0	 1188.0	 1188.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1079	 1080	 0.000817	 0.04349	 0.0	 608.0	 608.0	 608.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1079	 1080	 0.000319	 0.027978	 0.0	 1136	 1136	 1136	 1.005027	 0.0	 1	 -30.0	 30.0;
	1108	 1110	 0.000713	 0.048546	 0.0	 606.0	 606.0	 606.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	1109	 1110	 0.000332	 0.026939	 0.0	 1177	 1177	 1177	 1.0	 0.0	 1	 -30.0	 30.0;
	1109	 1110	 0.000319	 0.026385	 0.0	 1187.0	 1187.0	 1187.0	 1.0	 0.0	 1	 -30.0	 30.0;
	2048	 1593	 0.001904	 0.155471	 0.0	 354	 354	 354	 1.0	 0.0	 1	 -30.0	 30.0;
	1125	 1569	 0.000519	 -0.00831	 0.0	 600.0	 600.0	 600.0	 1.002005	 0.0	 1	 -30.0	 30.0;
	1125	 1593	 0.000471	 -0.008033	 0.0	 600.0	 600.0	 600.0	 1.002005	 0.0	 1	 -30.0	 30.0;
	1126	 1569	 0.000277	 0.047922	 0.0	 600.0	 600.0	 600.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1126	 1593	 0.00036	 0.049584	 0.0	 600.0	 600.0	 600.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1127	 1128	 0.000796	 0.041413	 0.0	 606.0	 606.0	 606.0	 0.994036	 0.0	 1	 -30.0	 30.0;
	1127	 1128	 0.000831	 0.039681	 0.0	 606.0	 606.0	 606.0	 0.994036	 0.0	 1	 -30.0	 30.0;
	1149	 1150	 0.000332	 0.024792	 0.0	 1186.0	 1186.0	 1186.0	 1.001	 0.0	 1	 -30.0	 30.0;
	1149	 1150	 0.000332	 0.024792	 0.0	 1182.0	 1182.0	 1182.0	 1.001	 0.0	 1	 -30.0	 30.0;
	2049	 1570	 0.001655	 0.09259	 0.0	 604	 604	 604	 1.0	 0.0	 1	 -30.0	 30.0;
	1157	 1570	 0.000118	 -0.005956	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1156	 1158	 0.000325	 0.024862	 0.0	 1186.0	 1186.0	 1186.0	 1.002005	 0.0	 1	 -30.0	 30.0;
	1158	 1570	 0.000187	 0.032964	 0.0	 1110	 1110	 1110	 0.0	 0.0	 1	 -30.0	 30.0;
	1162	 1163	 0.000319	 0.024792	 0.0	 1186.0	 1186.0	 1186.0	 1.005027	 0.0	 1	 -30.0	 30.0;
	1164	 1571	 0.00081	 -0.007802	 0.0	 435.0	 435.0	 435.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1164	 1594	 0.00081	 -0.007802	 0.0	 435.0	 435.0	 435.0	 0.0	 0.0	 1	 -30.0	 30.0;
	2038	 1572	 0.003428	 0.084557	 0.0	 726	 726	 726	 1.0	 0.0	 1	 -30.0	 30.0;
	1572	 1173	 0.000277	 -0.00464	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1173	 1174	 0.000339	 0.024931	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1174	 1572	 6.2e-05	 0.029571	 0.0	 1079	 1079	 1079	 0.0	 0.0	 1	 -30.0	 30.0;
	1179	 1181	 0.001177	 0.042382	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1610	 1179	 0.000499	 -0.006925	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1618	 1179	 0.000353	 -0.010873	 0.0	 600.0	 600.0	 600.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1181	 1610	 0.000201	 0.055402	 0.0	 576	 576	 576	 0.0	 0.0	 1	 -30.0	 30.0;
	1180	 1618	 0.000429	 0.05374	 0.0	 594	 594	 594	 0.0	 0.0	 1	 -30.0	 30.0;
	1199	 1200	 0.000291	 0.024792	 0.0	 1186.0	 1186.0	 1186.0	 1.005027	 0.0	 1	 -30.0	 30.0;
	2039	 1625	 0.004813	 0.21295	 0.0	 289	 289	 289	 1.0	 0.0	 1	 -30.0	 30.0;
	1625	 1215	 0.000457	 -0.005194	 0.0	 557.0	 557.0	 557.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1215	 1216	 0.000796	 0.048199	 0.0	 557.0	 557.0	 557.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	1216	 1625	 0.000242	 0.047438	 0.0	 557.0	 557.0	 557.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1237	 1238	 0.003556	 0.127407	 0.0	 243	 243	 243	 1.02459	 0.0	 1	 -30.0	 30.0;
	1257	 1258	 0.00164	 0.118519	 0.0	 259	 259	 259	 1.007049	 0.0	 1	 -30.0	 30.0;
	1259	 1260	 0.000783	 0.042936	 0.0	 600.0	 600.0	 600.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	1259	 1260	 0.000776	 0.043075	 0.0	 600.0	 600.0	 600.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	1262	 1573	 0.000159	 -0.006025	 0.0	 1186.0	 1186.0	 1186.0	 1.001	 0.0	 1	 -30.0	 30.0;
	1262	 1595	 0.000229	 -0.004571	 0.0	 1174.0	 1174.0	 1174.0	 1.001	 0.0	 1	 -30.0	 30.0;
	1262	 1263	 0.000332	 0.025623	 0.0	 1186.0	 1186.0	 1186.0	 1.001	 0.0	 1	 -30.0	 30.0;
	1263	 1573	 0.000173	 0.031163	 0.0	 1186.0	 1186.0	 1186.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1263	 1595	 9e-05	 0.029363	 0.0	 1174.0	 1174.0	 1174.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1264	 1265	 0.003186	 0.137758	 0.0	 229	 229	 229	 1.0	 0.0	 1	 -30.0	 30.0;
	1269	 1271	 0.000686	 0.047922	 0.0	 606.0	 606.0	 606.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1270	 1271	 0.000325	 0.027493	 0.0	 1148	 1148	 1148	 1.0	 0.0	 1	 -30.0	 30.0;
	1270	 1271	 0.000325	 0.027493	 0.0	 1148	 1148	 1148	 1.0	 0.0	 1	 -30.0	 30.0;
	1276	 1278	 0.001835	 0.101524	 0.0	 312	 312	 312	 1.013171	 0.0	 1	 -30.0	 30.0;
	1276	 1277	 0.001828	 0.102078	 0.0	 310	 310	 310	 1.003009	 0.0	 1	 -30.0	 30.0;
	1280	 1282	 0.000319	 0.027355	 0.0	 1159	 1159	 1159	 1.0	 0.0	 1	 -30.0	 30.0;
	1280	 1281	 0.000339	 0.029778	 0.0	 1065	 1065	 1065	 1.0	 0.0	 1	 -30.0	 30.0;
	1289	 1291	 0.001752	 0.102285	 0.0	 310	 310	 310	 0.984249	 0.0	 1	 -30.0	 30.0;
	1289	 1290	 0.001752	 0.102285	 0.0	 310	 310	 310	 0.984249	 0.0	 1	 -30.0	 30.0;
	2040	 1619	 0.001745	 0.092867	 0.0	 603	 603	 603	 1.0	 0.0	 1	 -30.0	 30.0;
	1298	 1611	 0.00018	 -0.007687	 0.0	 1188.0	 1188.0	 1188.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1298	 1619	 0.000125	 -0.007618	 0.0	 1188.0	 1188.0	 1188.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1299	 1611	 0.000166	 0.035111	 0.0	 1042	 1042	 1042	 0.0	 0.0	 1	 -30.0	 30.0;
	1299	 1619	 0.000201	 0.034834	 0.0	 1051	 1051	 1051	 0.0	 0.0	 1	 -30.0	 30.0;
	1301	 1302	 6.2e-05	 0.031787	 0.0	 993	 993	 993	 1.0	 0.0	 1	 -30.0	 30.0;
	1301	 1302	 6.2e-05	 0.031856	 0.0	 991	 991	 991	 1.0	 0.0	 1	 -30.0	 30.0;
	1319	 1320	 0.000208	 0.016413	 0.0	 1769.0	 1769.0	 1769.0	 0.947871	 0.0	 1	 -30.0	 30.0;
	1318	 1320	 0.000208	 0.014751	 0.0	 1746.0	 1746.0	 1746.0	 0.947871	 0.0	 1	 -30.0	 30.0;
	1317	 1320	 0.000208	 0.016413	 0.0	 1922	 1922	 1922	 0.947871	 0.0	 1	 -30.0	 30.0;
	1313	 1320	 0.000208	 0.016413	 0.0	 1922	 1922	 1922	 0.947871	 0.0	 1	 -30.0	 30.0;
	1311	 1320	 0.000208	 0.016413	 0.0	 1769.0	 1769.0	 1769.0	 0.947871	 0.0	 1	 -30.0	 30.0;
	1312	 1320	 0.000208	 0.016413	 0.0	 1769.0	 1769.0	 1769.0	 0.947871	 0.0	 1	 -30.0	 30.0;
	1316	 1320	 0.000208	 0.016413	 0.0	 1922	 1922	 1922	 0.947871	 0.0	 1	 -30.0	 30.0;
	1315	 1320	 0.000208	 0.016413	 0.0	 1922	 1922	 1922	 0.947871	 0.0	 1	 -30.0	 30.0;
	1314	 1320	 0.000319	 0.024307	 0.0	 1187.0	 1187.0	 1187.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1336	 1574	 0.000699	 -0.004709	 0.0	 606.0	 606.0	 606.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	1336	 1337	 0.000686	 0.048546	 0.0	 606.0	 606.0	 606.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	1337	 1574	 1.4e-05	 0.052839	 0.0	 601	 601	 601	 0.0	 0.0	 1	 -30.0	 30.0;
	1344	 1347	 0.000339	 0.027008	 0.0	 1175	 1175	 1175	 1.0	 0.0	 1	 -30.0	 30.0;
	1344	 1347	 0.000395	 0.027216	 0.0	 1166	 1166	 1166	 1.0	 0.0	 1	 -30.0	 30.0;
	1345	 1347	 0.000325	 0.027632	 0.0	 1148	 1148	 1148	 1.0	 0.0	 1	 -30.0	 30.0;
	2055	 1596	 0.0034	 0.084557	 0.0	 651	 651	 651	 1.0	 0.0	 1	 -30.0	 30.0;
	1351	 1352	 0.000332	 0.024792	 0.0	 1186.0	 1186.0	 1186.0	 1.001	 0.0	 1	 -30.0	 30.0;
	1351	 1596	 0.000229	 -0.004363	 0.0	 1186.0	 1186.0	 1186.0	 1.001	 0.0	 1	 -30.0	 30.0;
	1352	 1596	 9.7e-05	 0.029155	 0.0	 1186.0	 1186.0	 1186.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1360	 1361	 0.000332	 0.025069	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1360	 1361	 0.000319	 0.025	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1364	 1365	 0.000803	 0.039335	 0.0	 600.0	 600.0	 600.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	1363	 1365	 0.000325	 0.025	 0.0	 1186.0	 1186.0	 1186.0	 1.005027	 0.0	 1	 -30.0	 30.0;
	1364	 1365	 0.000796	 0.039266	 0.0	 600.0	 600.0	 600.0	 0.996016	 0.0	 1	 -30.0	 30.0;
	1366	 1368	 0.000305	 0.024862	 0.0	 1186.0	 1186.0	 1186.0	 1.005027	 0.0	 1	 -30.0	 30.0;
	1373	 1374	 0.002212	 0.125432	 0.0	 251	 251	 251	 0.928505	 0.0	 1	 -30.0	 30.0;
	1374	 1375	 0.000319	 0.024792	 0.0	 1186.0	 1186.0	 1186.0	 1.005027	 0.0	 1	 -30.0	 30.0;
	1374	 1375	 0.000325	 0.025	 0.0	 1186.0	 1186.0	 1186.0	 1.005027	 0.0	 1	 -30.0	 30.0;
	2041	 1575	 0.003449	 0.092452	 0.0	 605	 605	 605	 1.0	 0.0	 1	 -30.0	 30.0;
	2073	 1612	 0.001884	 0.093352	 0.0	 599	 599	 599	 1.0	 0.0	 1	 -30.0	 30.0;
	2060	 1620	 0.001766	 0.09169	 0.0	 610	 610	 610	 1.0	 0.0	 1	 -30.0	 30.0;
	2042	 1626	 0.001821	 0.088227	 0.0	 634	 634	 634	 1.0	 0.0	 1	 -30.0	 30.0;
	1385	 1575	 0.00027	 -0.005332	 0.0	 1186.0	 1186.0	 1186.0	 1.002005	 0.0	 1	 -30.0	 30.0;
	1385	 1597	 0.000249	 -0.005471	 0.0	 1186.0	 1186.0	 1186.0	 1.002005	 0.0	 1	 -30.0	 30.0;
	1384	 1612	 0.000125	 -0.007687	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1385	 1620	 0.000173	 -0.007895	 0.0	 1186.0	 1186.0	 1186.0	 1.002005	 0.0	 1	 -30.0	 30.0;
	1385	 1626	 0.000132	 -0.010942	 0.0	 1186.0	 1186.0	 1186.0	 1.002005	 0.0	 1	 -30.0	 30.0;
	1386	 1575	 5.5e-05	 0.032756	 0.0	 1117	 1117	 1117	 0.0	 0.0	 1	 -30.0	 30.0;
	1386	 1597	 6.9e-05	 0.032895	 0.0	 1113	 1113	 1113	 0.0	 0.0	 1	 -30.0	 30.0;
	1386	 1612	 0.000201	 0.034834	 0.0	 1051	 1051	 1051	 0.0	 0.0	 1	 -30.0	 30.0;
	1386	 1620	 0.000166	 0.034834	 0.0	 1051	 1051	 1051	 0.0	 0.0	 1	 -30.0	 30.0;
	1386	 1626	 0.000208	 0.038643	 0.0	 947	 947	 947	 0.0	 0.0	 1	 -30.0	 30.0;
	1389	 1391	 0.001925	 0.101801	 0.0	 310	 310	 310	 0.939851	 0.0	 1	 -30.0	 30.0;
	1389	 1390	 0.001835	 0.101177	 0.0	 311	 311	 311	 0.956942	 0.0	 1	 -30.0	 30.0;
	2056	 1598	 0.001814	 0.090651	 0.0	 617	 617	 617	 1.0	 0.0	 1	 -30.0	 30.0;
	2079	 1621	 0.00277	 0.094945	 0.0	 589	 589	 589	 1.0	 0.0	 1	 -30.0	 30.0;
	2057	 1627	 0.004862	 0.2241	 0.0	 250	 250	 250	 1.0	 0.0	 1	 -30.0	 30.0;
	1392	 1598	 0.000145	 -0.011288	 0.0	 1184.0	 1184.0	 1184.0	 1.002005	 0.0	 1	 -30.0	 30.0;
	1393	 1394	 0.000319	 0.027355	 0.0	 1159	 1159	 1159	 1.0	 0.0	 1	 -30.0	 30.0;
	1392	 1621	 0.000291	 -0.00554	 0.0	 1184.0	 1184.0	 1184.0	 1.002005	 0.0	 1	 -30.0	 30.0;
	1393	 1395	 0.000693	 0.048615	 0.0	 605.0	 605.0	 605.0	 1.002005	 0.0	 1	 -30.0	 30.0;
	1393	 1627	 0.000471	 -0.005263	 0.0	 605.0	 605.0	 605.0	 1.002005	 0.0	 1	 -30.0	 30.0;
	1394	 1598	 0.000187	 0.038712	 0.0	 945	 945	 945	 0.0	 0.0	 1	 -30.0	 30.0;
	1395	 1621	 2.8e-05	 0.032895	 0.0	 1113	 1113	 1113	 0.0	 0.0	 1	 -30.0	 30.0;
	1395	 1627	 0.000235	 0.053324	 0.0	 605.0	 605.0	 605.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1415	 1416	 0.000332	 0.025069	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1415	 1416	 0.000332	 0.025069	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1414	 1416	 0.000339	 0.024446	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1414	 1416	 0.000332	 0.025069	 0.0	 1187.0	 1187.0	 1187.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1420	 1421	 0.000346	 0.025346	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1420	 1421	 0.000332	 0.025208	 0.0	 1186.0	 1186.0	 1186.0	 1.0	 0.0	 1	 -30.0	 30.0;
	1840	 1426	 0.000325	 0.027701	 0.0	 1145	 1145	 1145	 1.0	 0.0	 1	 -30.0	 30.0;
	29	 1628	 0.0	 0.019737	 0.0	 254.0	 254.0	 254.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	30	 1629	 0.0	 0.019737	 0.0	 550.0	 550.0	 550.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	51	 1844	 0.0	 0.54184	 0.0	 62	 62	 62	 1.044444	 0.0	 1	 -30.0	 30.0;
	61	 1630	 0.0	 0.142857	 0.0	 215	 215	 215	 1.111111	 0.0	 1	 -30.0	 30.0;
	61	 1631	 0.0	 0.219149	 0.0	 141	 141	 141	 1.111111	 0.0	 1	 -30.0	 30.0;
	73	 1846	 0.0	 0.366794	 0.0	 86	 86	 86	 1.0	 0.0	 1	 -30.0	 30.0;
	73	 1632	 0.0	 0.366794	 0.0	 86	 86	 86	 1.0	 0.0	 1	 -30.0	 30.0;
	74	 1847	 0.0	 0.366794	 0.0	 86	 86	 86	 1.0	 0.0	 1	 -30.0	 30.0;
	74	 1848	 0.0	 0.366794	 0.0	 86	 86	 86	 1.0	 0.0	 1	 -30.0	 30.0;
	103	 1852	 0.0	 0.15	 0.0	 213	 213	 213	 1.060526	 0.0	 1	 -30.0	 30.0;
	102	 1854	 0.0	 0.15	 0.0	 213	 213	 213	 1.060526	 0.0	 1	 -30.0	 30.0;
	130	 1633	 0.0	 0.012611	 0.0	 1052.0	 1052.0	 1052.0	 1.052632	 0.0	 1	 -30.0	 30.0;
	127	 1634	 0.0	 0.012611	 0.0	 1087.0	 1087.0	 1087.0	 1.052632	 0.0	 1	 -30.0	 30.0;
	128	 1635	 0.0	 0.012611	 0.0	 1088.0	 1088.0	 1088.0	 1.052632	 0.0	 1	 -30.0	 30.0;
	129	 1636	 0.0	 0.012611	 0.0	 1049.0	 1049.0	 1049.0	 1.052632	 0.0	 1	 -30.0	 30.0;
	132	 1637	 0.0	 0.048207	 0.0	 646	 646	 646	 1.080978	 0.0	 1	 -30.0	 30.0;
	131	 1638	 0.0	 0.048207	 0.0	 646	 646	 646	 1.080978	 0.0	 1	 -30.0	 30.0;
	133	 1639	 0.0	 0.043965	 0.0	 721	 721	 721	 1.065789	 0.0	 1	 -30.0	 30.0;
	133	 1640	 0.0	 0.03442	 0.0	 921	 921	 921	 1.060526	 0.0	 1	 -30.0	 30.0;
	133	 1641	 0.0	 0.06506	 0.0	 487	 487	 487	 1.060526	 0.0	 1	 -30.0	 30.0;
	140	 1642	 0.0	 0.161429	 0.0	 195	 195	 195	 1.054667	 0.0	 1	 -30.0	 30.0;
	140	 1643	 0.0	 0.17931	 0.0	 176	 176	 176	 1.054667	 0.0	 1	 -30.0	 30.0;
	140	 1855	 0.0	 0.161429	 0.0	 195	 195	 195	 1.054667	 0.0	 1	 -30.0	 30.0;
	140	 1644	 0.0	 0.17931	 0.0	 176	 176	 176	 1.054667	 0.0	 1	 -30.0	 30.0;
	140	 1645	 0.0	 0.17931	 0.0	 176	 176	 176	 1.054667	 0.0	 1	 -30.0	 30.0;
	791	 1646	 0.0	 0.044965	 0.0	 683	 683	 683	 1.080978	 0.0	 1	 -30.0	 30.0;
	165	 1647	 0.0	 0.248077	 0.0	 127	 127	 127	 1.0	 0.0	 1	 -30.0	 30.0;
	169	 1861	 0.0	 0.300114	 0.0	 106	 106	 106	 1.020096	 0.0	 1	 -30.0	 30.0;
	186	 1648	 0.0	 0.012685	 0.0	 1054.0	 1054.0	 1054.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	185	 1649	 0.0	 0.012685	 0.0	 1063.0	 1063.0	 1063.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	183	 1650	 0.0	 0.012685	 0.0	 1032.0	 1032.0	 1032.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	184	 1651	 0.0	 0.012685	 0.0	 1030.0	 1030.0	 1030.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	190	 1652	 0.0	 0.009303	 0.0	 403.0	 403.0	 403.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	191	 1862	 0.0	 0.009303	 0.0	 394.0	 394.0	 394.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	194	 1653	 0.0	 0.200062	 0.0	 158	 158	 158	 1.013333	 0.0	 1	 -30.0	 30.0;
	194	 1654	 0.0	 0.200062	 0.0	 158	 158	 158	 1.013333	 0.0	 1	 -30.0	 30.0;
	194	 1655	 0.0	 0.200062	 0.0	 158	 158	 158	 1.013333	 0.0	 1	 -30.0	 30.0;
	193	 1656	 0.0	 0.200062	 0.0	 158	 158	 158	 1.013333	 0.0	 1	 -30.0	 30.0;
	193	 1657	 0.0	 0.200062	 0.0	 158	 158	 158	 1.013333	 0.0	 1	 -30.0	 30.0;
	193	 1658	 0.0	 0.200062	 0.0	 158	 158	 158	 1.013333	 0.0	 1	 -30.0	 30.0;
	196	 1863	 0.0	 0.333434	 0.0	 95	 95	 95	 1.053333	 0.0	 1	 -30.0	 30.0;
	196	 1659	 0.0	 0.333434	 0.0	 95	 95	 95	 1.053333	 0.0	 1	 -30.0	 30.0;
	196	 1660	 0.0	 0.333434	 0.0	 95	 95	 95	 1.053333	 0.0	 1	 -30.0	 30.0;
	196	 1661	 0.0	 0.333434	 0.0	 95	 95	 95	 1.053333	 0.0	 1	 -30.0	 30.0;
	197	 1662	 0.0	 0.333434	 0.0	 95	 95	 95	 1.053333	 0.0	 1	 -30.0	 30.0;
	197	 1663	 0.0	 0.333434	 0.0	 95	 95	 95	 1.053333	 0.0	 1	 -30.0	 30.0;
	200	 1865	 0.0	 0.453182	 0.0	 70	 70	 70	 1.088889	 0.0	 1	 -30.0	 30.0;
	218	 1866	 0.0	 0.333994	 0.0	 95	 95	 95	 1.053333	 0.0	 1	 -30.0	 30.0;
	218	 1664	 0.0	 0.333994	 0.0	 95	 95	 95	 1.053333	 0.0	 1	 -30.0	 30.0;
	218	 1665	 0.0	 0.333994	 0.0	 95	 95	 95	 1.053333	 0.0	 1	 -30.0	 30.0;
	218	 1867	 0.0	 0.333994	 0.0	 95	 95	 95	 1.053333	 0.0	 1	 -30.0	 30.0;
	217	 1666	 0.0	 0.333994	 0.0	 95	 95	 95	 1.053333	 0.0	 1	 -30.0	 30.0;
	217	 1868	 0.0	 0.333994	 0.0	 95	 95	 95	 1.053333	 0.0	 1	 -30.0	 30.0;
	243	 1667	 0.0	 0.008909	 0.0	 1550.0	 1550.0	 1550.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	245	 1668	 0.0	 0.008909	 0.0	 1343.0	 1343.0	 1343.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	246	 1669	 0.0	 0.008909	 0.0	 1312.0	 1312.0	 1312.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	295	 1670	 0.0	 0.048207	 0.0	 655	 655	 655	 1.080978	 0.0	 1	 -30.0	 30.0;
	299	 1873	 0.0	 0.054074	 0.0	 589	 589	 589	 1.077631	 0.0	 1	 -30.0	 30.0;
	299	 1874	 0.0	 0.054074	 0.0	 589	 589	 589	 1.077631	 0.0	 1	 -30.0	 30.0;
	300	 1671	 0.0	 0.012685	 0.0	 1051.0	 1051.0	 1051.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	302	 1673	 0.0	 0.012611	 0.0	 1063.0	 1063.0	 1063.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	301	 1674	 0.0	 0.012611	 0.0	 1063.0	 1063.0	 1063.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	304	 1675	 0.0	 0.009257	 0.0	 723.0	 723.0	 723.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	305	 1676	 0.0	 0.009257	 0.0	 607.0	 607.0	 607.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	311	 1875	 0.0	 0.009257	 0.0	 1745.0	 1745.0	 1745.0	 1.065789	 0.0	 1	 -30.0	 30.0;
	310	 1677	 0.0	 0.009257	 0.0	 1747.0	 1747.0	 1747.0	 1.065789	 0.0	 1	 -30.0	 30.0;
	316	 2022	 0.0	 0.155059	 0.0	 206	 206	 206	 1.026316	 0.0	 1	 -30.0	 30.0;
	316	 1876	 0.0	 0.155059	 0.0	 206	 206	 206	 1.026316	 0.0	 1	 -30.0	 30.0;
	316	 1877	 0.0	 0.155059	 0.0	 206	 206	 206	 1.026316	 0.0	 1	 -30.0	 30.0;
	316	 1878	 0.0	 0.155059	 0.0	 206	 206	 206	 1.026316	 0.0	 1	 -30.0	 30.0;
	15	 1678	 0.0	 0.06579	 0.0	 467	 467	 467	 1.096667	 0.0	 1	 -30.0	 30.0;
	16	 1679	 0.0	 0.06579	 0.0	 467	 467	 467	 1.096667	 0.0	 1	 -30.0	 30.0;
	608	 1680	 0.0	 0.1	 0.0	 307	 307	 307	 1.057778	 0.0	 1	 -30.0	 30.0;
	338	 1681	 0.0	 0.01954	 0.0	 1558	 1558	 1558	 1.088844	 0.0	 1	 -30.0	 30.0;
	336	 1682	 0.0	 0.020227	 0.0	 691.0	 691.0	 691.0	 1.088844	 0.0	 1	 -30.0	 30.0;
	337	 1683	 0.0	 0.01954	 0.0	 714.0	 714.0	 714.0	 1.088844	 0.0	 1	 -30.0	 30.0;
	339	 1684	 0.0	 0.021576	 0.0	 254.0	 254.0	 254.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	416	 1881	 0.0	 0.2424	 0.0	 130	 130	 130	 1.075778	 0.0	 1	 -30.0	 30.0;
	416	 1882	 0.0	 0.2424	 0.0	 130	 130	 130	 1.075778	 0.0	 1	 -30.0	 30.0;
	416	 1685	 0.0	 0.2424	 0.0	 130	 130	 130	 1.075778	 0.0	 1	 -30.0	 30.0;
	416	 1883	 0.0	 0.2424	 0.0	 130	 130	 130	 1.075778	 0.0	 1	 -30.0	 30.0;
	416	 1884	 0.0	 0.2424	 0.0	 130	 130	 130	 1.075778	 0.0	 1	 -30.0	 30.0;
	416	 1885	 0.0	 0.2424	 0.0	 130	 130	 130	 1.075778	 0.0	 1	 -30.0	 30.0;
	382	 1686	 0.0	 0.012685	 0.0	 1116.0	 1116.0	 1116.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	381	 1687	 0.0	 0.012685	 0.0	 1117.0	 1117.0	 1117.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	383	 1688	 0.0	 0.012611	 0.0	 1119.0	 1119.0	 1119.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	384	 1689	 0.0	 0.012611	 0.0	 2512	 2512	 2512	 1.092105	 0.0	 1	 -30.0	 30.0;
	392	 1888	 0.0	 0.181818	 0.0	 173	 173	 173	 1.044444	 0.0	 1	 -30.0	 30.0;
	401	 1690	 0.0	 0.041231	 0.0	 510.0	 510.0	 510.0	 1.0948	 0.0	 1	 -30.0	 30.0;
	400	 1691	 0.0	 0.273494	 0.0	 113	 113	 113	 1.062667	 0.0	 1	 -30.0	 30.0;
	411	 1692	 0.0	 0.032831	 0.0	 302.0	 302.0	 302.0	 1.044444	 0.0	 1	 -30.0	 30.0;
	437	 1693	 0.0	 0.089389	 0.0	 396	 396	 396	 1.080356	 0.0	 1	 -30.0	 30.0;
	438	 1694	 0.0	 0.089389	 0.0	 396	 396	 396	 1.080356	 0.0	 1	 -30.0	 30.0;
	438	 1695	 0.0	 0.056597	 0.0	 626	 626	 626	 1.080356	 0.0	 1	 -30.0	 30.0;
	437	 1696	 0.0	 0.056597	 0.0	 626	 626	 626	 1.080356	 0.0	 1	 -30.0	 30.0;
	452	 1697	 0.0	 0.012685	 0.0	 2485	 2485	 2485	 1.092105	 0.0	 1	 -30.0	 30.0;
	451	 1698	 0.0	 0.012685	 0.0	 2485	 2485	 2485	 1.092105	 0.0	 1	 -30.0	 30.0;
	453	 1699	 0.0	 0.012685	 0.0	 2485	 2485	 2485	 1.092105	 0.0	 1	 -30.0	 30.0;
	454	 1700	 0.0	 0.012685	 0.0	 263.0	 263.0	 263.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	466	 1701	 0.0	 0.345838	 0.0	 91	 91	 91	 1.044444	 0.0	 1	 -30.0	 30.0;
	503	 1702	 0.0	 0.266753	 0.0	 118	 118	 118	 1.066667	 0.0	 1	 -30.0	 30.0;
	502	 1703	 0.0	 0.266753	 0.0	 118	 118	 118	 1.066667	 0.0	 1	 -30.0	 30.0;
	501	 1889	 0.0	 0.266753	 0.0	 118	 118	 118	 1.066667	 0.0	 1	 -30.0	 30.0;
	507	 1704	 0.0	 0.009303	 0.0	 1611.0	 1611.0	 1611.0	 1.065789	 0.0	 1	 -30.0	 30.0;
	510	 1705	 0.0	 0.009303	 0.0	 1608.0	 1608.0	 1608.0	 1.065789	 0.0	 1	 -30.0	 30.0;
	538	 1890	 0.0	 0.510159	 0.0	 62	 62	 62	 1.053333	 0.0	 1	 -30.0	 30.0;
	539	 1891	 0.0	 0.510159	 0.0	 62	 62	 62	 1.053333	 0.0	 1	 -30.0	 30.0;
	540	 1892	 0.0	 0.510159	 0.0	 62	 62	 62	 1.053333	 0.0	 1	 -30.0	 30.0;
	541	 1706	 0.0	 0.510159	 0.0	 62	 62	 62	 1.053333	 0.0	 1	 -30.0	 30.0;
	565	 1707	 0.0	 0.47948	 0.0	 66	 66	 66	 1.053333	 0.0	 1	 -30.0	 30.0;
	563	 2026	 0.0	 0.47948	 0.0	 66	 66	 66	 1.053333	 0.0	 1	 -30.0	 30.0;
	562	 1898	 0.0	 0.47948	 0.0	 66	 66	 66	 1.053333	 0.0	 1	 -30.0	 30.0;
	561	 1708	 0.0	 0.47948	 0.0	 66	 66	 66	 1.053333	 0.0	 1	 -30.0	 30.0;
	564	 1709	 0.0	 0.47948	 0.0	 66	 66	 66	 1.053333	 0.0	 1	 -30.0	 30.0;
	567	 1710	 0.0	 0.400125	 0.0	 79	 79	 79	 1.044444	 0.0	 1	 -30.0	 30.0;
	567	 1711	 0.0	 0.400125	 0.0	 79	 79	 79	 1.044444	 0.0	 1	 -30.0	 30.0;
	576	 1712	 0.0	 0.008909	 0.0	 1524.0	 1524.0	 1524.0	 1.065789	 0.0	 1	 -30.0	 30.0;
	577	 1713	 0.0	 0.008909	 0.0	 1525.0	 1525.0	 1525.0	 1.065789	 0.0	 1	 -30.0	 30.0;
	583	 1714	 0.0	 0.042476	 0.0	 538.0	 538.0	 538.0	 1.062222	 0.0	 1	 -30.0	 30.0;
	592	 1715	 0.0	 0.012685	 0.0	 336.0	 336.0	 336.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	593	 1716	 0.0	 0.012685	 0.0	 341.0	 341.0	 341.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	591	 1717	 0.0	 0.012685	 0.0	 377.0	 377.0	 377.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	589	 1718	 0.0	 0.012685	 0.0	 355.0	 355.0	 355.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	590	 1719	 0.0	 0.012685	 0.0	 338.0	 338.0	 338.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	588	 1720	 0.0	 0.012685	 0.0	 258.0	 258.0	 258.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	615	 1721	 0.0	 0.041112	 0.0	 747	 747	 747	 1.081067	 0.0	 1	 -30.0	 30.0;
	1343	 1906	 0.0	 0.082529	 0.0	 386	 386	 386	 1.065789	 0.0	 1	 -30.0	 30.0;
	1343	 1907	 0.0	 0.082529	 0.0	 386	 386	 386	 1.065789	 0.0	 1	 -30.0	 30.0;
	1343	 1908	 0.0	 0.082529	 0.0	 386	 386	 386	 1.065789	 0.0	 1	 -30.0	 30.0;
	1343	 1909	 0.0	 0.082529	 0.0	 386	 386	 386	 1.065789	 0.0	 1	 -30.0	 30.0;
	1343	 1910	 0.0	 0.082529	 0.0	 386	 386	 386	 1.065789	 0.0	 1	 -30.0	 30.0;
	1343	 1911	 0.0	 0.082529	 0.0	 386	 386	 386	 1.065789	 0.0	 1	 -30.0	 30.0;
	1343	 1912	 0.0	 0.082529	 0.0	 386	 386	 386	 1.065789	 0.0	 1	 -30.0	 30.0;
	1343	 1913	 0.0	 0.082529	 0.0	 386	 386	 386	 1.065789	 0.0	 1	 -30.0	 30.0;
	625	 1722	 0.0	 0.029081	 0.0	 322.0	 322.0	 322.0	 1.080888	 0.0	 1	 -30.0	 30.0;
	638	 1723	 0.0	 0.044965	 0.0	 683	 683	 683	 1.080978	 0.0	 1	 -30.0	 30.0;
	637	 1724	 0.0	 0.020227	 0.0	 1518	 1518	 1518	 1.088844	 0.0	 1	 -30.0	 30.0;
	639	 1725	 0.0	 0.021197	 0.0	 295.0	 295.0	 295.0	 1.103079	 0.0	 1	 -30.0	 30.0;
	683	 1919	 0.0	 0.30255	 0.0	 104	 104	 104	 1.022222	 0.0	 1	 -30.0	 30.0;
	684	 1920	 0.0	 0.30255	 0.0	 104	 104	 104	 1.022222	 0.0	 1	 -30.0	 30.0;
	681	 1921	 0.0	 0.30255	 0.0	 104	 104	 104	 1.022222	 0.0	 1	 -30.0	 30.0;
	682	 1922	 0.0	 0.30255	 0.0	 104	 104	 104	 1.022222	 0.0	 1	 -30.0	 30.0;
	686	 1923	 0.0	 0.333559	 0.0	 96	 96	 96	 1.022222	 0.0	 1	 -30.0	 30.0;
	685	 1924	 0.0	 0.333559	 0.0	 95	 95	 95	 1.022222	 0.0	 1	 -30.0	 30.0;
	752	 1726	 0.0	 0.312857	 0.0	 101	 101	 101	 1.054667	 0.0	 1	 -30.0	 30.0;
	752	 1727	 0.0	 0.312857	 0.0	 101	 101	 101	 1.054667	 0.0	 1	 -30.0	 30.0;
	752	 1728	 0.0	 0.312857	 0.0	 101	 101	 101	 1.054667	 0.0	 1	 -30.0	 30.0;
	752	 1928	 0.0	 0.312857	 0.0	 101	 101	 101	 1.054667	 0.0	 1	 -30.0	 30.0;
	744	 1729	 0.0	 0.048207	 0.0	 637	 637	 637	 1.080978	 0.0	 1	 -30.0	 30.0;
	760	 1931	 0.0	 0.120375	 0.0	 262	 262	 262	 1.053333	 0.0	 1	 -30.0	 30.0;
	760	 1932	 0.0	 0.17125	 0.0	 184	 184	 184	 1.053333	 0.0	 1	 -30.0	 30.0;
	760	 1934	 0.0	 0.120375	 0.0	 262	 262	 262	 1.053333	 0.0	 1	 -30.0	 30.0;
	762	 1935	 0.0	 0.329412	 0.0	 96	 96	 96	 1.053333	 0.0	 1	 -30.0	 30.0;
	762	 1936	 0.0	 0.329412	 0.0	 96	 96	 96	 1.053333	 0.0	 1	 -30.0	 30.0;
	762	 1937	 0.0	 0.329412	 0.0	 96	 96	 96	 1.053333	 0.0	 1	 -30.0	 30.0;
	768	 1938	 0.0	 0.181636	 0.0	 174	 174	 174	 1.088889	 0.0	 1	 -30.0	 30.0;
	796	 1730	 0.0	 0.044965	 0.0	 688	 688	 688	 1.080978	 0.0	 1	 -30.0	 30.0;
	797	 1731	 0.0	 0.044965	 0.0	 688	 688	 688	 1.080978	 0.0	 1	 -30.0	 30.0;
	809	 1944	 0.0	 0.482751	 0.0	 66	 66	 66	 1.137778	 0.0	 1	 -30.0	 30.0;
	107	 1732	 0.0	 0.031723	 0.0	 968	 968	 968	 1.044444	 0.0	 1	 -30.0	 30.0;
	861	 1733	 0.0	 0.0516	 0.0	 595	 595	 595	 1.07511	 0.0	 1	 -30.0	 30.0;
	860	 1734	 0.0	 0.0516	 0.0	 595	 595	 595	 1.07511	 0.0	 1	 -30.0	 30.0;
	864	 1950	 0.0	 0.0592	 0.0	 273.0	 273.0	 273.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	864	 1951	 0.0	 0.0596	 0.0	 275.0	 275.0	 275.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	863	 1952	 0.0	 0.0596	 0.0	 272.0	 272.0	 272.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	863	 1953	 0.0	 0.05972	 0.0	 272.0	 272.0	 272.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	499	 1735	 0.0	 0.012685	 0.0	 1072.0	 1072.0	 1072.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	498	 1736	 0.0	 0.012685	 0.0	 1072.0	 1072.0	 1072.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	880	 1737	 0.0	 0.295332	 0.0	 107	 107	 107	 1.066667	 0.0	 1	 -30.0	 30.0;
	877	 1738	 0.0	 0.295332	 0.0	 107	 107	 107	 1.066667	 0.0	 1	 -30.0	 30.0;
	878	 1739	 0.0	 0.295332	 0.0	 107	 107	 107	 1.066667	 0.0	 1	 -30.0	 30.0;
	888	 1740	 0.0	 0.03299	 0.0	 394.0	 394.0	 394.0	 1.04	 0.0	 1	 -30.0	 30.0;
	889	 1741	 0.0	 0.034269	 0.0	 920	 920	 920	 1.060526	 0.0	 1	 -30.0	 30.0;
	915	 1742	 0.0	 0.009303	 0.0	 371.0	 371.0	 371.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	918	 1958	 0.0	 0.144154	 0.0	 218	 218	 218	 1.066667	 0.0	 1	 -30.0	 30.0;
	918	 1959	 0.0	 0.144154	 0.0	 218	 218	 218	 1.066667	 0.0	 1	 -30.0	 30.0;
	928	 1743	 0.0	 0.287294	 0.0	 110	 110	 110	 1.022222	 0.0	 1	 -30.0	 30.0;
	934	 1744	 0.0	 0.008909	 0.0	 1322.0	 1322.0	 1322.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	935	 1745	 0.0	 0.008909	 0.0	 1195.0	 1195.0	 1195.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	937	 1746	 0.0	 0.008909	 0.0	 1203.0	 1203.0	 1203.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	936	 1961	 0.0	 0.008909	 0.0	 422.0	 422.0	 422.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	943	 1747	 0.0	 0.389792	 0.0	 81	 81	 81	 1.044444	 0.0	 1	 -30.0	 30.0;
	951	 1748	 0.0	 0.009303	 0.0	 972.0	 972.0	 972.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	952	 1749	 0.0	 0.009303	 0.0	 967.0	 967.0	 967.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	968	 1750	 0.0	 0.021485	 0.0	 1475	 1475	 1475	 1.103079	 0.0	 1	 -30.0	 30.0;
	970	 1751	 0.0	 0.021485	 0.0	 1475	 1475	 1475	 1.103079	 0.0	 1	 -30.0	 30.0;
	969	 1752	 0.0	 0.021485	 0.0	 1475	 1475	 1475	 1.103079	 0.0	 1	 -30.0	 30.0;
	971	 1753	 0.0	 0.019737	 0.0	 1605	 1605	 1605	 1.092105	 0.0	 1	 -30.0	 30.0;
	974	 2058	 0.0	 0.31817	 0.0	 99	 99	 99	 1.073333	 0.0	 1	 -30.0	 30.0;
	985	 1754	 0.0	 0.044965	 0.0	 283.0	 283.0	 283.0	 1.080978	 0.0	 1	 -30.0	 30.0;
	984	 1755	 0.0	 0.020227	 0.0	 708.0	 708.0	 708.0	 1.088844	 0.0	 1	 -30.0	 30.0;
	1010	 1756	 0.0	 0.733548	 0.0	 43	 43	 43	 1.044444	 0.0	 1	 -30.0	 30.0;
	1032	 1757	 0.0	 0.046748	 0.0	 280.0	 280.0	 280.0	 1.066667	 0.0	 1	 -30.0	 30.0;
	1047	 1758	 0.0	 0.155048	 0.0	 203	 203	 203	 1.0	 0.0	 1	 -30.0	 30.0;
	1046	 1759	 0.0	 0.155048	 0.0	 203	 203	 203	 1.0	 0.0	 1	 -30.0	 30.0;
	1045	 1760	 0.0	 0.155048	 0.0	 203	 203	 203	 1.0	 0.0	 1	 -30.0	 30.0;
	1048	 1970	 0.0	 0.327904	 0.0	 98	 98	 98	 1.05641	 0.0	 1	 -30.0	 30.0;
	1048	 1971	 0.0	 0.327904	 0.0	 98	 98	 98	 1.05641	 0.0	 1	 -30.0	 30.0;
	1048	 1972	 0.0	 0.327904	 0.0	 98	 98	 98	 1.05641	 0.0	 1	 -30.0	 30.0;
	1048	 1973	 0.0	 0.327904	 0.0	 98	 98	 98	 1.05641	 0.0	 1	 -30.0	 30.0;
	1075	 1974	 0.0	 0.0774	 0.0	 412	 412	 412	 1.052632	 0.0	 1	 -30.0	 30.0;
	1076	 1975	 0.0	 0.06037	 0.0	 529	 529	 529	 1.031422	 0.0	 1	 -30.0	 30.0;
	1077	 1976	 0.0	 0.0774	 0.0	 412	 412	 412	 1.052632	 0.0	 1	 -30.0	 30.0;
	1078	 1977	 0.0	 0.0774	 0.0	 412	 412	 412	 1.052632	 0.0	 1	 -30.0	 30.0;
	1085	 1761	 0.0	 0.285799	 0.0	 111	 111	 111	 1.066667	 0.0	 1	 -30.0	 30.0;
	1083	 1762	 0.0	 0.285799	 0.0	 111	 111	 111	 1.066667	 0.0	 1	 -30.0	 30.0;
	1084	 1978	 0.0	 0.285799	 0.0	 111	 111	 111	 1.066667	 0.0	 1	 -30.0	 30.0;
	1138	 1769	 0.0	 0.261991	 0.0	 121	 121	 121	 1.0	 0.0	 1	 -30.0	 30.0;
	1138	 1770	 0.0	 0.261991	 0.0	 121	 121	 121	 1.0	 0.0	 1	 -30.0	 30.0;
	1141	 1979	 0.0	 0.317591	 0.0	 100	 100	 100	 1.022222	 0.0	 1	 -30.0	 30.0;
	1142	 1980	 0.0	 0.329412	 0.0	 96	 96	 96	 1.044444	 0.0	 1	 -30.0	 30.0;
	1159	 1771	 0.0	 0.733625	 0.0	 43	 43	 43	 1.08	 0.0	 1	 -30.0	 30.0;
	1184	 1993	 0.0	 0.088828	 0.0	 354	 354	 354	 1.022222	 0.0	 1	 -30.0	 30.0;
	1195	 1772	 0.0	 0.009303	 0.0	 1545.0	 1545.0	 1545.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	1194	 1995	 0.0	 0.009303	 0.0	 1545.0	 1545.0	 1545.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	482	 1773	 0.0	 0.035942	 0.0	 869	 869	 869	 1.081023	 0.0	 1	 -30.0	 30.0;
	483	 1774	 0.0	 0.019697	 0.0	 259.0	 259.0	 259.0	 1.088844	 0.0	 1	 -30.0	 30.0;
	480	 1775	 0.0	 0.037419	 0.0	 855	 855	 855	 1.11579	 0.0	 1	 -30.0	 30.0;
	481	 1776	 0.0	 0.037117	 0.0	 862	 862	 862	 1.11579	 0.0	 1	 -30.0	 30.0;
	1207	 1996	 0.0	 0.244364	 0.0	 129	 129	 129	 1.044444	 0.0	 1	 -30.0	 30.0;
	1207	 1997	 0.0	 0.244364	 0.0	 129	 129	 129	 1.044444	 0.0	 1	 -30.0	 30.0;
	1210	 2000	 0.0	 0.148936	 0.0	 212	 212	 212	 1.073333	 0.0	 1	 -30.0	 30.0;
	1214	 1777	 0.0	 0.012611	 0.0	 1062.0	 1062.0	 1062.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	1213	 1778	 0.0	 0.012611	 0.0	 1066.0	 1066.0	 1066.0	 1.092105	 0.0	 1	 -30.0	 30.0;
	1217	 1779	 0.0	 0.1992	 0.0	 158	 158	 158	 1.044444	 0.0	 1	 -30.0	 30.0;
	1217	 2002	 0.0	 0.1992	 0.0	 158	 158	 158	 1.044444	 0.0	 1	 -30.0	 30.0;
	1247	 1780	 0.0	 0.428124	 0.0	 77	 77	 77	 0.977775	 0.0	 1	 -30.0	 30.0;
	1250	 2028	 0.0	 0.428124	 0.0	 77	 77	 77	 0.977775	 0.0	 1	 -30.0	 30.0;
	1249	 1781	 0.0	 0.428124	 0.0	 77	 77	 77	 0.977775	 0.0	 1	 -30.0	 30.0;
	1248	 1782	 0.0	 0.428124	 0.0	 77	 77	 77	 0.977775	 0.0	 1	 -30.0	 30.0;
	1254	 2004	 0.0	 0.092765	 0.0	 344	 344	 344	 1.065789	 0.0	 1	 -30.0	 30.0;
	1254	 2023	 0.0	 0.092765	 0.0	 344	 344	 344	 1.065789	 0.0	 1	 -30.0	 30.0;
	1254	 2024	 0.0	 0.092765	 0.0	 344	 344	 344	 1.065789	 0.0	 1	 -30.0	 30.0;
	1254	 2005	 0.0	 0.092765	 0.0	 344	 344	 344	 1.065789	 0.0	 1	 -30.0	 30.0;
	1305	 1783	 0.0	 0.012769	 0.0	 1134.0	 1134.0	 1134.0	 1.044444	 0.0	 1	 -30.0	 30.0;
	1306	 1784	 0.0	 0.012769	 0.0	 1137.0	 1137.0	 1137.0	 1.044444	 0.0	 1	 -30.0	 30.0;
	1308	 1785	 0.0	 0.012769	 0.0	 1136.0	 1136.0	 1136.0	 1.044444	 0.0	 1	 -30.0	 30.0;
	1307	 1786	 0.0	 0.012769	 0.0	 1133.0	 1133.0	 1133.0	 1.044444	 0.0	 1	 -30.0	 30.0;
	1333	 1787	 0.0	 0.050588	 0.0	 607	 607	 607	 1.048889	 0.0	 1	 -30.0	 30.0;
	1333	 1788	 0.0	 0.050588	 0.0	 607	 607	 607	 1.048889	 0.0	 1	 -30.0	 30.0;
	1332	 1789	 0.0	 0.050588	 0.0	 607	 607	 607	 1.048889	 0.0	 1	 -30.0	 30.0;
	1379	 1790	 0.0	 0.044965	 0.0	 683	 683	 683	 1.080978	 0.0	 1	 -30.0	 30.0;
	1378	 1791	 0.0	 0.044965	 0.0	 683	 683	 683	 1.080978	 0.0	 1	 -30.0	 30.0;
	1400	 1792	 0.0	 0.318049	 0.0	 99	 99	 99	 1.071111	 0.0	 1	 -30.0	 30.0;
	1399	 2011	 0.0	 0.318049	 0.0	 99	 99	 99	 1.071111	 0.0	 1	 -30.0	 30.0;
	1398	 2012	 0.0	 0.318049	 0.0	 99	 99	 99	 1.071111	 0.0	 1	 -30.0	 30.0;
	1407	 1793	 0.0	 0.15125	 0.0	 209	 209	 209	 1.044444	 0.0	 1	 -30.0	 30.0;
	1407	 1794	 0.0	 0.15125	 0.0	 209	 209	 209	 1.044444	 0.0	 1	 -30.0	 30.0;
	766	 1795	 5e-06	 5e-05	 0.0014	 1974.0	 1974.0	 1974.0	 0.0	 0.0	 1	 -30.0	 30.0;
	766	 1796	 5e-06	 5e-05	 0.0014	 1974.0	 1974.0	 1974.0	 0.0	 0.0	 1	 -30.0	 30.0;
	981	 1797	 0.002262	 0.013491	 0.0253	 401.0	 401.0	 401.0	 0.0	 0.0	 1	 -30.0	 30.0;
	739	 1798	 0.000544	 0.006842	 0.1762	 1474.0	 1474.0	 1474.0	 0.0	 0.0	 1	 -30.0	 30.0;
	36	 1799	 0.002222	 0.014124	 0.0294	 470.0	 470.0	 470.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1181	 1800	 0.000322	 0.003148	 0.1011	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	849	 1801	 0.000781	 0.006247	 0.0106	 506.0	 506.0	 506.0	 0.0	 0.0	 1	 -30.0	 30.0;
	885	 1802	 0.000232	 0.001856	 0.003	 506.0	 506.0	 506.0	 0.0	 0.0	 1	 -30.0	 30.0;
	792	 1803	 0.000661	 0.008092	 0.3004	 1474.0	 1474.0	 1474.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70	 1804	 0.00037	 0.004699	 0.1119	 1711.0	 1711.0	 1711.0	 0.0	 0.0	 1	 -30.0	 30.0;
	764	 1805	 0.000544	 0.005689	 0.1249	 1253.0	 1253.0	 1253.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1181	 1806	 0.000457	 0.005163	 0.1148	 1316.0	 1316.0	 1316.0	 0.0	 0.0	 1	 -30.0	 30.0;
	975	 1807	 0.004375	 0.020138	 0.0327	 336.0	 336.0	 336.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1504	 1808	 0.00076	 0.004523	 0.0086	 454.0	 454.0	 454.0	 0.0	 0.0	 1	 -30.0	 30.0;
	216	 1809	 0.001086	 0.016543	 0.4202	 1579.0	 1579.0	 1579.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1402	 1810	 0.00106	 0.005879	 0.0025	 502.0	 502.0	 502.0	 0.0	 0.0	 1	 -30.0	 30.0;
	874	 1811	 0.000264	 0.002841	 0.0505	 1974.0	 1974.0	 1974.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1199	 1812	 0.00165	 0.007587	 0.0253	 288.0	 288.0	 288.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1367	 1813	 0.000256	 0.003556	 0.1292	 1790.0	 1790.0	 1790.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1368	 1814	 0.000253	 0.003556	 0.1292	 1790.0	 1790.0	 1790.0	 0.0	 0.0	 1	 -30.0	 30.0;
	306	 1815	 0.003052	 0.022203	 0.0276	 461.0	 461.0	 461.0	 0.0	 0.0	 1	 -30.0	 30.0;
	37	 1816	 0.000544	 0.005865	 0.1274	 1624.0	 1624.0	 1624.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1180	 1817	 0.000469	 0.005225	 0.1126	 1487.0	 1487.0	 1487.0	 0.0	 0.0	 1	 -30.0	 30.0;
	345	 1818	 0.005588	 0.034701	 0.0643	 323.0	 323.0	 323.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7	 1819	 0.000862	 0.019598	 0.2726	 1559.0	 1559.0	 1559.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8	 1820	 0.000862	 0.019598	 0.2726	 1559.0	 1559.0	 1559.0	 0.0	 0.0	 1	 -30.0	 30.0;
	346	 1821	 0.004375	 0.026805	 0.0486	 323.0	 323.0	 323.0	 0.0	 0.0	 1	 -30.0	 30.0;
	1382	 1822	 0.000332	 0.004013	 0.0628	 1316.0	 1316.0	 1316.0	 0.0	 0.0	 1	 -30.0	 30.0;
	558	 1823	 0.001393	 0.009294	 0.0177	 428.0	 428.0	 428.0	 0.0	 0.0	 1	 -30.0	 30.0;
	558	 1824	 0.001393	 0.009304	 0.0177	 428.0	 428.0	 428.0	 0.0	 0.0	 1	 -30.0	 30.0;
	216	 1825	 6.2e-05	 0.000855	 0.0231	 1382.0	 1382.0	 1382.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86	 1826	 0.001043	 0.011382	 0.3054	 1624.0	 1624.0	 1624.0	 0.0	 0.0	 1	 -30.0	 30.0;
];

% INFO    : === Translation Options ===
% INFO    : Phase Angle Bound:           30.0 (deg.)
% INFO    : Line Capacity Model:         ub
% INFO    : Gen Active Cost Model:       stat
% INFO    : Setting Flat Start
% INFO    : Line Capacity PAB:           15.0 (deg.)
% INFO    : 
% INFO    : === Generator Classification Notes ===
% INFO    : PEL    59  -     2.84
% INFO    : NUC    11  -    10.24
% INFO    : SYNC   1   -     0.00
% INFO    : COW    85  -    68.62
% INFO    : NG     141 -    18.31
% INFO    : 
% INFO    : === Generator Active Cost Stat Model Notes ===
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.8796137986 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 102.818703137 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 123.867752621 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 106.230210442 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 111.337641818 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.2038726268 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 49.7787950427 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.5864452312 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 21.5869886664 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 102.922604625 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.3476059624 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 110.72110041 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.4198609547 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.6014380631 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.5695643787 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.9935534466 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.3355994846 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 34.9372297936 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.7577525421 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.622514591 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.4067867036 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.9118059322 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.4835164683 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.3233765854 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.7447304086 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 13.975616129 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 48.0705375163 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 111.022895927 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.7724892666 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.1547857219 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.0036626919 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.811092674 0
% INFO    : Updated Generator Cost: SYNC - 0.0 2.0 0.0 -> 0 0.0 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.3017940134 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.8609559846 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 120.918112975 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.9624671716 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 32.8595822234 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.5898075758 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.660131885 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 89.7943023526 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.0950304315 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.4732338382 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.1795326654 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 106.557899113 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 14.4075263074 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 119.630609419 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 116.533424244 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 126.01011796 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.74540814149 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 107.069234257 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.4200735476 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.8851212472 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.8336630081 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 119.43155798 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 121.989784202 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 104.195580879 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 65.052206829 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.9241153776 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 42.5646274588 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.4500816307 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.82363164 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.4147814179 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 31.2158420429 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 33.0151355981 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.5988694833 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.8290219266 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.0786055207 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 50.5214945792 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 95.0471128425 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 114.295844773 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 103.1340643 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.5795403653 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.3128180856 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.6703032954 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.5339011781 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 106.652078669 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.1437775537 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.1199920524 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.4217747203 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 15.6609034904 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 5.66766430294 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.7979165288 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 109.357262657 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 116.92570099 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.9118927751 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 103.504481211 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.8797278587 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 54.6674422513 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.6447987584 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 100.151990202 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 53.6250877353 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.773173711 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 129.451325331 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.4363129576 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.0916701873 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 99.4018585824 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.6622585433 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.5416636989 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 49.4694150848 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.3116891418 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 119.347718573 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.5473686506 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 2.85980829948 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.86497209293 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 99.4971520269 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.7892068902 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.540538811 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.79360026061 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 34.0839951414 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 54.2973405059 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.4053658928 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.7625346169 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.5456209418 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 33.6167381765 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 37.6170687411 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 107.884527902 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.7212106818 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.9110633292 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.3835654584 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.2819710192 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.2531671562 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.8538962959 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.3847888157 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.75883986377 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.45722857 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.3146997303 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.4290723451 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.2737206059 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 48.1764575306 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.2997418447 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 17.076736751 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 16.5888305912 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.3182774488 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 18.6804118856 0
% INFO    : Updated Generator Cost: NUC - 0.0 2.0 0.0 -> 0 6.6333826467 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.4753688112 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 32.0793499983 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.6658597612 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.8787142823 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 28.9523031698 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.3590335592 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.3530152468 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.1110967509 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 41.6522746898 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.4412457518 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 37.7979558507 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 13.7866733422 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 112.501633322 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.1840676196 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 35.2429974135 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.732720425 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.07294355245 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 7.1901429648 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 29.024814414 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 111.973758544 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 121.864221499 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 123.841827202 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 106.668799042 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 97.1913837591 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 101.011895303 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.4747345252 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 114.499177038 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.8897762001 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 111.696300828 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.9805339138 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.4088534671 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.1668950979 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 32.1307303814 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.1393486608 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 35.693045847 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 6.81381504624 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.239496375 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 24.0586102294 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 52.9773377567 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.0020612111 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 32.4124440826 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.3856210441 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.9376039318 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.5886439502 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 121.788285585 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.1804891259 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 15.1186677329 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.2359654399 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.3086273633 0
% INFO    : Updated Generator Cost: NG - 0.0 2.0 0.0 -> 0 43.3313284734 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 32.9236337896 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.7873851794 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 115.799925399 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 125.358723251 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 106.839231913 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.4700488439 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 113.967567549 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 115.113942365 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.2224931619 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 13.6472190087 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 103.342462877 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 38.2156851947 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 48.344190922 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.3093248169 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.4039455035 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 110.713088254 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 26.1356216247 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 121.84740693 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 46.3280975961 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.772212239 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 19.9283209991 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.0469771314 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 38.2154228893 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.1516773834 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 37.2565896892 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.2657713027 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 24.3860475809 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 39.4338259491 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.5513926566 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.394640018 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 21.6578125324 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 10.8256535034 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.4445184137 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 77.2098224265 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 40.7183915877 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.3695779704 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.44328777997 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 27.4444141451 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 45.3073703873 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.8844726272 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 37.7035378818 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 16.1215479531 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 22.5812952967 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.669454458 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 9.14246681475 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 34.9064035476 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.2492726928 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 29.6626389514 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 23.3204952444 0
% INFO    : Updated Generator Cost: NUC - 0.0 1.0 0.0 -> 0 7.50835369544 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 40.5213800836 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.1239451419 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 15.6366073742 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.5350483235 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 108.347589692 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 20.4048446998 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 51.1862066138 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.2227808356 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.5389225903 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.8221518223 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 36.5708487223 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 117.606153566 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 103.660534565 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.9744706567 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.9580458405 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 41.0290095055 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 39.3243848387 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 30.3609405441 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.8463379209 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 99.5464778572 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.5130568091 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 25.8275092372 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 10.0453735002 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 105.987833228 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 99.9780026846 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.8650772798 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 20.1420436192 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 23.3090314117 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 13.3592161001 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.012933013 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 30.381701096 0
% INFO    : Updated Generator Cost: COW - 0.0 2.0 0.0 -> 0 37.9903945241 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.0596416206 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 6.47426959581 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 44.8618960466 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 28.4298195141 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 10.6933322081 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.4467105839 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 64.4616747874 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 118.875628359 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 122.385004191 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 126.688114317 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.6409650427 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 18.0348605566 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 34.601688073 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 34.7559441668 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 40.3794881088 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 19.1978452508 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 25.9610590064 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 32.1338232603 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 27.7901652823 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 52.4058772328 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 43.1442245198 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 26.6436635772 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 35.29360485 0
% INFO    : Updated Generator Cost: COW - 0.0 1.0 0.0 -> 0 33.5894523334 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 32.3361694398 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 22.0222356482 0
% INFO    : Updated Generator Cost: PEL - 0.0 1.0 0.0 -> 0 99.7192122831 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 31.2690799181 0
% INFO    : Updated Generator Cost: NG - 0.0 1.0 0.0 -> 0 38.6524893459 0
% INFO    : 
% INFO    : === Generator Bounds Update Notes ===
% INFO    : 
% INFO    : === Base KV Replacement Notes ===
% INFO    : 
% INFO    : === Transformer Setting Replacement Notes ===
% WARNING : Transformer 1833-1 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 29-2 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 675-2 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1271-2 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 30-2 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 142-3 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 677-3 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1048-4 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 101-5 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 286-6 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 329-6 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 737-5 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 760-5 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1330-6 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1350-5 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1523-6 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 102-8 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 316-8 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 623-8 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 882-8 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 103-7 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 623-8 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 623-7 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 113-9 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1134-9 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 346-10 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 345-10 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 106-11 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 758-12 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 962-12 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 955-13 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 995-13 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 39-14 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1428-14 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1054-16 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1054-15 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1428-17 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1432-17 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 39-17 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 869-18 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1089-18 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1164-20 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1164-19 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 972-21 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 476-22 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1497-22 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 69-23 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 446-23 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 605-23 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 987-23 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 845-25 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 845-25 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 123-27 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1479-27 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1500-27 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 289-28 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 307-28 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1451-28 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 289-28 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 307-28 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1450-28 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 307-28 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 842-31 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 960-31 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1269-31 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1270-31 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1270-31 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 212-33 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 326-33 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1153-33 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1170-33 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 343-34 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 955-34 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1257-35 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1439-35 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 846-36 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 846-36 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 228-37 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 477-38 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1179-38 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 134-39 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 195-39 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 208-39 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 296-40 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 766-40 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 950-40 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1282-40 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 296-40 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 766-40 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 950-40 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1281-40 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1282-40 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 558-41 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1420-42 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1420-43 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1040-44 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1521-44 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1040-44 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1524-45 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1525-45 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1321-46 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1429-46 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 49-48 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 49-47 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 298-49 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 318-49 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 370-49 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 608-49 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 836-49 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1227-49 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1381-49 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1411-49 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 836-49 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1379-49 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1378-49 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1169-50 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 704-51 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1265-51 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 404-52 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 427-52 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 459-53 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 765-53 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1529-53 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 766-54 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1416-54 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1101-56 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1101-55 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 320-1827 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 813-1827 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1287-1827 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 461-57 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 827-57 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1429-58 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1090-60 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1090-59 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 713-61 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1032-62 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 998-63 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 342-65 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 894-64 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1265-66 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1397-67 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1543-67 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 404-69 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 469-68 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 791-68 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1348-69 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1480-68 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 470-68 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 640-68 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 556-70 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 792-70 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1421-70 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 792-70 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1416-70 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 203-72 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 375-71 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 403-71 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 982-71 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1104-72 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 842-73 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 842-74 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 387-75 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 842-75 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 78-76 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 300-77 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 436-77 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 705-77 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 436-77 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 705-77 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 302-77 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 301-77 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 435-78 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1040-78 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1431-79 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1430-80 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 745-81 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1432-82 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 626-83 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 181-84 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 854-84 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1186-85 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1187-85 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 553-86 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 553-86 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 519-87 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 870-87 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1300-88 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1351-88 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1351-88 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 283-89 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 467-89 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 729-89 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1335-89 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1433-90 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 376-91 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1489-91 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 934-93 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 950-93 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1062-92 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1110-93 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1282-92 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1347-92 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 935-92 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 950-92 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1062-93 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1110-92 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1281-93 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1347-93 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 937-92 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 936-93 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1149-96 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 149-97 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 680-98 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 701-98 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 702-99 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1232-100 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 616-101 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 231-104 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 955-104 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 232-1828 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 542-105 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 628-105 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 772-105 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1059-105 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 627-105 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 955-106 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 122-107 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 872-107 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1127-107 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1168-107 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1405-107 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1436-107 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 554-108 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 596-108 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 776-108 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1128-108 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 597-108 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 776-108 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1216-108 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 854-109 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 145-110 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 227-111 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 783-111 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 772-112 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1533-112 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 297-113 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 371-113 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1348-114 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1435-114 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 394-115 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 413-115 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1341-115 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1514-115 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 132-115 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1341-115 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 131-115 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 651-117 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 774-117 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1367-117 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 651-117 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1368-117 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 133-117 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 990-119 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1031-119 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 845-120 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1021-120 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1302-121 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1302-121 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 622-123 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 716-124 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1487-124 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1437-125 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 157-126 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 158-130 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 158-127 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 158-128 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 158-129 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 845-135 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 839-136 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 890-136 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 915-136 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 838-136 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 891-136 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 916-136 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 395-137 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 408-137 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 811-137 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 812-137 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1241-137 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1486-137 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 395-137 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 263-138 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 821-138 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 376-140 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 416-140 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1279-141 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1314-140 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 376-140 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 986-140 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1314-141 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 919-142 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1336-142 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1336-142 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 395-143 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 395-144 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 813-145 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1524-145 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 827-146 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 827-147 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 517-148 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1108-149 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 416-150 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 871-150 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 181-151 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 354-153 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 494-154 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 918-154 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1027-154 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1238-154 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 153-152 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 983-155 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 438-156 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 626-156 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 437-156 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 626-156 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 857-158 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 979-158 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 390-158 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 978-158 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 390-158 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 390-158 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 980-159 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 947-160 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1351-160 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 164-163 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 164-161 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 164-162 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 785-164 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1007-164 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1453-164 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1500-165 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 658-166 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 574-167 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 827-167 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1006-167 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1460-167 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1464-167 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1542-167 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 827-167 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 282-167 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 776-168 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1126-168 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 760-169 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1439-170 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1438-172 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1440-171 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1415-173 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 958-181 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 769-182 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1082-182 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1242-186 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1243-185 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1242-183 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1243-184 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1032-187 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 477-188 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 763-188 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1441-189 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 554-190 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 554-191 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1274-192 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 674-194 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 674-193 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1443-197 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1452-198 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 493-199 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 586-199 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1183-199 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1478-199 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1238-200 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 267-201 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1212-201 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1328-201 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 229-202 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 708-202 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 750-202 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1176-202 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1530-202 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1833-202 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1833-202 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 447-203 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1156-203 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 477-204 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 763-204 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 730-205 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1329-205 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 730-205 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1329-205 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 121-206 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 121-206 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1025-207 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1104-207 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 208-1829 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1189-208 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 440-209 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1052-209 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1071-209 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1072-209 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1539-209 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1442-210 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 479-211 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 196-213 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 218-213 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 251-213 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 567-213 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1338-213 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1447-213 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1455-213 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 544-213 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1443-213 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 263-215 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 357-215 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 260-216 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 559-216 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1443-217 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 425-220 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 425-219 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1055-221 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 448-222 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1050-222 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 479-223 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1444-224 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 614-225 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1030-1830 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 350-226 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 787-226 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 783-227 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 846-227 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 893-227 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 893-227 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1150-228 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1150-228 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1032-229 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 739-230 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 792-230 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 910-232 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 942-232 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1173-233 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1173-234 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1446-235 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1445-236 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 581-237 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 841-238 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1012-237 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1280-237 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1547-238 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1280-238 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 632-239 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 848-240 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1178-240 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 386-242 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1367-243 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1367-244 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1368-245 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1368-246 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 997-247 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1164-247 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 670-249 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 702-248 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 702-248 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 702-249 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 784-250 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1352-250 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 784-250 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1352-250 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 891-252 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 949-252 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 972-255 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 991-255 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1482-253 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1494-255 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1495-255 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1481-253 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1469-254 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1470-254 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 814-258 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1282-258 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 814-257 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1281-257 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1360-259 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1360-259 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 295-261 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 348-261 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1447-262 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 357-263 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 363-263 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 623-263 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 821-263 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1008-263 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1243-263 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 363-263 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 623-263 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 821-263 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1008-263 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1242-263 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1242-263 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1243-263 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 420-267 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 420-267 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 420-267 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1353-269 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1353-268 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 500-271 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1179-271 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 365-272 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 602-272 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 602-272 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 436-273 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 705-273 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1041-273 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1390-273 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 705-273 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1041-273 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1079-274 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1236-275 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 318-276 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 341-276 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1371-276 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1381-276 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1334-279 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 596-280 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1008-280 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1243-280 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 458-280 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 597-280 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1242-280 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1460-281 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1120-283 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1527-285 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1526-284 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 557-286 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 398-288 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 398-287 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1169-289 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 406-290 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 896-290 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 945-290 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1115-290 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1409-290 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 406-290 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1408-290 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 406-290 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1067-290 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 861-290 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 860-290 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 294-291 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 308-291 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1068-293 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1260-292 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1383-293 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1448-292 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 294-292 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 308-291 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 839-293 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 891-293 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1260-293 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1260-293 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 348-295 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 810-295 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1057-295 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1359-295 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1461-295 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1488-295 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 556-296 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 709-296 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1416-296 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 556-296 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 709-296 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1416-296 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 342-297 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 371-297 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 895-297 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1130-297 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1385-297 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1411-298 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 370-298 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1131-298 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1385-297 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1385-297 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1502-297 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 623-299 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 435-303 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 794-303 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1057-303 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1413-303 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 435-303 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 739-304 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 739-305 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 801-306 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 801-306 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 734-307 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 759-307 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 734-307 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 550-308 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1386-308 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 550-308 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1386-308 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1386-308 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 854-309 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1337-311 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1337-310 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 516-312 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 667-312 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 619-313 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 767-313 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 619-313 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 427-314 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 427-315 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 999-316 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 442-317 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 610-317 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1449-319 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 359-320 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1427-320 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 658-321 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1364-321 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 708-323 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 841-323 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1405-324 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1030-325 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1193-325 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1044-326 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 361-328 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 825-328 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 941-328 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 616-329 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 760-329 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 703-330 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 848-330 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1451-331 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1450-332 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1109-333 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1298-2072 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1109-2072 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 427-334 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 555-334 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 435-335 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1201-335 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1452-335 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 435-335 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 435-335 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1010-340 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1159-340 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1531-340 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 988-340 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 484-341 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 892-343 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 955-343 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1482-343 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 892-343 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 955-343 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1481-343 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 892-343 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1469-343 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1470-343 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 981-345 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1456-346 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 557-345 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 559-347 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 882-347 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 607-348 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 990-348 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1031-348 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1224-348 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1515-348 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 338-348 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 990-348 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1488-348 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 336-348 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 337-348 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 436-350 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 742-350 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 436-350 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 743-350 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 786-350 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 339-350 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 352-351 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 836-351 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 826-352 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 365-353 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1363-353 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 473-354 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 547-354 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 898-354 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 547-354 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 898-354 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1454-355 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 858-356 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1239-356 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 382-357 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1008-357 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1271-357 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1320-357 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 381-357 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1008-357 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1320-357 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 383-357 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1320-357 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 384-357 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1455-358 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 478-361 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 601-360 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 825-361 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 941-362 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1137-360 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1166-360 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1182-361 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1258-361 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1531-361 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 478-360 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 988-360 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1166-362 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1343-363 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1343-363 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 527-364 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 557-364 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 933-364 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 996-365 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1268-365 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1499-365 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 657-366 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 605-367 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 722-367 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1420-367 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1420-367 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 533-368 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1106-368 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1433-368 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1501-368 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1519-368 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 890-369 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1080-369 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1365-369 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 573-371 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1133-371 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1294-370 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 559-372 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 623-372 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1242-372 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 559-373 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1243-373 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 512-374 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1274-375 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 660-377 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1026-377 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1117-377 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1358-377 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1420-377 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 660-377 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1026-377 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1116-377 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 530-378 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 574-379 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 752-380 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1456-385 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 397-386 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 467-386 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1113-386 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1485-387 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 598-388 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 854-388 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 865-388 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1322-388 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 443-390 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 963-390 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1150-390 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 443-390 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 857-390 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1150-390 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1360-391 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 601-392 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1437-392 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 602-393 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1835-395 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 420-398 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1466-398 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1058-399 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1079-399 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1090-401 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1090-400 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 520-402 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1164-403 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1348-404 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 964-405 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1169-405 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1393-407 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1427-409 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1521-409 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 573-410 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 413-411 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 730-412 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 845-412 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 698-413 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1404-413 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1363-414 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1499-414 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1364-414 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 752-416 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1314-416 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 752-416 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 279-418 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1334-418 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1459-419 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 620-420 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 621-420 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1466-420 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 550-421 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1353-421 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1426-421 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 550-421 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1353-421 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1386-421 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 905-422 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1360-422 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1322-423 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1355-423 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 619-424 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 504-425 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 583-425 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1053-425 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1060-425 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 504-425 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1060-425 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 614-426 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 791-427 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1349-428 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1414-429 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 772-432 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 662-433 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1305-433 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1312-433 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1544-434 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 919-435 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 679-436 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 961-436 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 678-436 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1303-439 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1488-440 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1539-440 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 711-441 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 742-441 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 829-441 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1023-441 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1041-441 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 711-441 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 743-441 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1355-442 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 576-443 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 719-443 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 577-443 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1352-443 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 495-444 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1460-444 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1461-445 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 721-446 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1348-446 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 720-446 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 515-448 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1298-448 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1298-448 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1462-449 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1055-450 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1101-450 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1260-452 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1260-451 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1260-453 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1260-454 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 730-455 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 730-455 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 570-456 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1096-456 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1185-456 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 570-456 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1008-458 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 765-459 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1189-459 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1069-460 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1319-460 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1307-460 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 775-461 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 795-461 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 853-461 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 868-461 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 919-461 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1218-461 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1328-461 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 827-461 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 776-462 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 963-462 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1337-462 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1353-462 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1337-462 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 813-464 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1152-464 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1197-463 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1354-463 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1840-464 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1152-464 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1463-465 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1464-466 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 666-468 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1405-468 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1465-471 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 572-472 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 898-473 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1466-474 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 490-475 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 793-475 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1339-475 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 555-1832 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1540-476 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1483-477 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1492-478 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 473-479 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 494-479 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 798-479 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 938-479 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1044-479 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1055-479 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 938-479 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1444-479 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1200-480 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1200-481 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1199-482 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1199-483 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 489-487 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 489-486 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 489-488 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 489-485 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 910-489 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1292-489 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 910-489 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1012-489 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1468-489 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1467-489 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 615-490 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1468-492 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1467-491 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 586-493 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1261-495 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 500-496 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 500-497 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 874-499 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 874-498 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 503-500 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 926-500 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1402-500 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 502-500 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 501-500 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 713-504 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 966-504 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1090-504 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1099-504 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1207-504 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 966-504 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1090-504 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 669-506 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 805-507 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 805-510 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 805-508 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 805-509 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1420-511 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 756-512 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1104-512 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 854-513 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 865-513 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 904-513 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1144-513 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1478-513 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 710-515 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1287-515 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1441-515 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1407-516 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 854-517 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 958-517 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 854-517 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1240-519 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 995-521 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 995-520 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 522-1325 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1092-523 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1436-523 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 925-524 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1262-525 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1262-525 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 626-526 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 626-526 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 559-528 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 764-528 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1301-529 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1301-529 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1492-530 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1505-530 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1469-532 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1470-531 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1465-533 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1054-534 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1471-536 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1472-535 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 758-537 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 542-538 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 542-539 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 542-540 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 542-541 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1167-542 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 818-544 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1011-544 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1138-544 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1455-544 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1239-545 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1377-545 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1215-546 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1474-546 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 653-547 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 672-548 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1464-549 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 554-550 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1260-550 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 554-550 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1260-550 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 731-551 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 840-551 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1240-551 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 840-551 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1126-553 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1263-553 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1352-553 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 665-553 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1263-553 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1216-554 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 957-555 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1348-555 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1348-555 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 667-558 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1175-557 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1407-558 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1456-557 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1365-559 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1365-559 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1365-559 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 566-565 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 566-563 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 566-562 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 566-560 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 566-561 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 566-564 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1082-566 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1251-566 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1474-568 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1475-568 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 718-569 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 718-569 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 755-570 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 818-570 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 929-570 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 820-570 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1185-570 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1294-572 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1125-574 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1239-574 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1355-574 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1476-575 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1493-578 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1014-579 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1239-580 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1351-580 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1012-581 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 701-582 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 753-582 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 644-584 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 769-584 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 772-584 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1059-584 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1162-584 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1192-584 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1251-584 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 976-585 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1491-585 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 903-586 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1219-586 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1478-586 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1220-586 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 679-587 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 979-587 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1337-587 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 678-587 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 978-587 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1337-587 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1416-592 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1416-593 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1416-591 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1416-589 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1416-590 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1416-588 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 820-594 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 610-598 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1451-599 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1450-600 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1258-601 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 609-602 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 754-602 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1458-602 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1242-603 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1365-603 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 664-605 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1549-604 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 604-430 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 732-606 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1403-606 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1230-607 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1515-607 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 744-609 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 570-611 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 570-612 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 570-613 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 791-615 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1339-615 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1545-615 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 648-615 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 791-615 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 791-615 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1415-618 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1414-617 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1108-619 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1236-619 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1344-619 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1236-619 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1345-619 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1344-619 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1505-622 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1345-624 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 607-625 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 647-626 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1042-626 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1119-626 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1415-626 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1422-626 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1462-626 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1414-626 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1423-626 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1414-626 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 756-629 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 672-632 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 807-632 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 848-632 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1135-632 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 671-632 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1136-632 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 638-633 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1033-633 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1033-633 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 637-633 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 639-635 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1110-635 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1110-635 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 884-640 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1480-640 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 883-640 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1482-641 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1481-642 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 737-643 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 709-645 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1395-645 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1483-646 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 738-647 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1129-647 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1415-647 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1549-647 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 738-647 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1529-647 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1339-648 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1506-650 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 733-651 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 890-651 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 911-651 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1375-651 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 891-651 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 783-652 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 816-652 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1015-654 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1495-654 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1344-656 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1345-655 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1517-657 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 744-658 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1458-658 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1484-659 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 631-660 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 640-660 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1419-660 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 630-660 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 640-660 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1418-660 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 917-663 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1316-663 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1315-662 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1352-665 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 728-666 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 799-666 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 976-666 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 746-668 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 926-668 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1096-669 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1185-669 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 718-670 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1476-673 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1206-674 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1485-674 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1206-674 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1271-675 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 811-676 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1486-676 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 748-680 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 815-680 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 687-683 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 687-684 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 687-681 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 687-682 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 687-686 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 687-685 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 926-687 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1179-687 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1314-690 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1314-691 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 892-693 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 892-692 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1491-694 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 740-695 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 785-695 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 785-696 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 849-697 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 869-697 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1246-697 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1366-697 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1484-697 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1252-698 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1498-698 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1535-698 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 837-700 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1490-699 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1507-701 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 975-702 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1493-707 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 957-1833 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1118-1833 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1394-709 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1051-710 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1267-711 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1267-711 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1441-712 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1452-712 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 966-713 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1004-713 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1066-713 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1170-713 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1065-713 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1064-713 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 718-715 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1035-715 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 946-716 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 783-717 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1355-718 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1355-718 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1352-719 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 955-725 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 955-723 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 955-724 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 734-726 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1384-726 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1494-727 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1127-728 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1528-729 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1114-730 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1327-730 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1329-730 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1240-731 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1497-732 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 874-733 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1496-734 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 807-735 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1449-736 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1412-737 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1548-737 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1523-737 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 802-739 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 851-739 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1537-739 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 792-739 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 802-739 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 851-739 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 792-739 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 785-740 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 801-745 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 822-745 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1246-745 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 801-745 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 823-745 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1179-746 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1288-746 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1179-746 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1191-748 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1507-748 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1511-748 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1256-750 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1362-750 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 987-751 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1338-752 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 973-753 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1486-754 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1499-757 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 894-758 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1105-758 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1372-758 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 964-759 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 943-760 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1127-761 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1127-761 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1121-762 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 933-763 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 989-763 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 992-763 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 933-763 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1180-764 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1324-765 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1323-765 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1838-765 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1202-767 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1238-768 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 880-769 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1162-769 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1403-769 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 877-769 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1403-769 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 878-769 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 827-770 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 976-771 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1125-771 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 831-772 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1059-772 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 830-772 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1059-772 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1163-774 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1367-774 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 853-775 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1342-775 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1260-776 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1260-776 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1500-777 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1501-778 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1487-779 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1513-779 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 946-779 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 975-783 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1193-785 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1544-785 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 958-788 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1434-788 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1384-790 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1502-789 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 953-791 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1032-791 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1032-793 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1359-794 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1006-795 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1225-796 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1225-797 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1044-798 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1435-800 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1075-802 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1076-802 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1077-802 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1078-802 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1503-803 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1504-804 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1267-805 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1295-805 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1267-805 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1295-805 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1267-805 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1267-805 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 873-806 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 995-806 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1505-808 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1506-809 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1183-810 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1190-810 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 819-812 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 972-813 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1354-813 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1510-813 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 909-813 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 972-813 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1525-813 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 972-813 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 968-814 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1290-814 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1426-814 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 970-814 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1291-814 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1386-814 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 969-814 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 971-814 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1005-815 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1321-817 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 825-820 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 844-820 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1011-820 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1241-818 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1349-819 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1479-818 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 843-818 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1349-818 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 841-824 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1012-824 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1125-827 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1218-827 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1233-827 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1041-829 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1507-832 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 837-834 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 836-833 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1165-836 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1188-836 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1411-835 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1512-837 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1165-835 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1188-836 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1490-836 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1395-839 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1448-838 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1394-838 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1112-842 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 929-844 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 954-844 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1021-845 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1266-846 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1027-847 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1279-847 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1385-848 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1385-848 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1367-851 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1368-851 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1150-857 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1240-858 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1348-859 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1432-859 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 864-862 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1126-862 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 863-862 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1508-866 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1509-867 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 872-868 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1223-869 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 959-870 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1262-870 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1518-870 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1262-870 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 976-871 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1163-874 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1181-874 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1375-874 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1180-874 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1510-875 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1374-876 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1465-876 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 897-881 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 849-885 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 887-886 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1156-887 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1393-887 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 966-888 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 967-889 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1361-891 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1365-891 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1448-890 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1365-890 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 995-892 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1124-892 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 995-892 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1123-892 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1387-896 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 921-897 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1356-898 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1376-898 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1056-899 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1302-899 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1056-899 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1302-899 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1232-900 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1232-901 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1206-902 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1413-904 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1272-903 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 923-905 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1104-906 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1105-907 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1511-908 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1510-909 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 962-913 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 962-914 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 962-912 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1306-917 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1311-917 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1184-918 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1238-918 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1503-918 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 998-920 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1264-921 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1130-922 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1203-923 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1360-923 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1362-923 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1204-923 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1360-923 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1232-924 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1392-925 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1512-925 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1392-925 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 928-926 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 927-926 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1222-930 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1125-931 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1541-931 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1834-933 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1170-938 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1238-938 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1170-938 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 985-938 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 984-938 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1040-939 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1040-940 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 981-943 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1280-944 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1513-946 connects the same voltage levels (63.0, 63.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1239-947 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1225-948 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1225-948 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 951-950 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 952-950 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1176-953 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1275-955 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1118-957 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1149-958 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1149-958 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1154-959 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1391-961 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1105-962 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1431-962 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1430-962 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1471-962 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1373-965 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1055-966 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1055-966 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 991-972 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1202-972 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1239-974 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1145-976 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1173-980 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1173-980 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1157-982 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1536-982 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1546-983 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1171-987 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1358-987 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1172-987 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1209-988 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1103-992 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 995-993 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 995-994 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1407-996 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1155-998 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1254-999 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1516-1000 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1000-431 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1517-1001 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1496-1002 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 976-1003 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1489-1003 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1195-1008 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1194-1008 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1221-1010 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 956-1014 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1157-1014 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1164-1013 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1292-1012 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1410-1012 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1477-1013 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1494-1015 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1839-1015 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1438-1014 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1164-1014 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1468-1012 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1440-1013 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1467-1012 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 949-1018 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1158-1017 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1281-1017 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1282-1017 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1281-1018 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1282-1018 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1394-1018 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1107-1022 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1303-1022 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1453-1022 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1303-1022 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1054-1024 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1108-1024 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1143-1024 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1345-1024 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1121-1027 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1269-1027 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1192-1028 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1251-1028 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1146-1029 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1199-1029 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1193-1030 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1285-1031 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1054-1033 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1140-1033 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1143-1033 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 932-1035 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1095-1035 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1231-1035 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1265-1035 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1351-1035 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1351-1035 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1518-1036 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1519-1037 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1520-1038 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1522-1039 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1205-1040 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1427-1040 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1521-1040 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1262-1043 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1444-1044 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1523-1049 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1463-1050 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1047-1052 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1046-1052 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1273-1051 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1045-1052 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1121-1053 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1100-1054 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1170-1055 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1170-1055 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1271-1056 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1271-1056 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1457-1058 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1341-1061 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1282-1062 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1281-1062 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1331-1070 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1317-1069 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1313-1070 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1164-1074 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1164-1073 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1326-1079 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1501-1079 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1368-1080 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1403-1081 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1085-1082 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1083-1082 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1084-1082 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1525-1086 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1188-1088 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1188-1087 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1222-1089 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1329-1093 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1329-1093 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1265-1095 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1304-1096 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1527-1098 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1526-1097 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1121-1101 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1207-1101 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1519-1103 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1393-1104 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1392-1105 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1472-1104 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1459-1106 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1453-1107 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1425-1108 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1290-1110 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1299-1110 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1291-1110 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1299-1110 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1237-1113 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1538-1114 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1173-1115 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1528-1120 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1142-1121 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1217-1121 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1485-1121 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1161-1125 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1454-1125 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1491-1125 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1534-1125 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1530-1132 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1385-1135 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1385-1136 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1366-1139 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1425-1140 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1532-1141 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1322-1144 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1304-1145 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1533-1146 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1534-1147 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1534-1147 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1173-1148 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1363-1148 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1434-1149 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1535-1151 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1357-1152 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1170-1153 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1262-1154 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1548-1155 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1393-1156 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1477-1157 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1536-1157 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1395-1158 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1536-1160 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1232-1164 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1232-1164 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1438-1164 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1440-1164 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1296-1173 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1543-1173 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1365-1174 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1383-1174 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1537-1177 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1483-1179 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1437-1184 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1532-1184 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1406-1185 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1228-1188 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1544-1193 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1334-1836 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1357-1197 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1388-1196 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1509-1196 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1238-1198 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1503-1198 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1532-1198 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1252-1199 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1366-1199 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1533-1199 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1535-1199 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1368-1200 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1208-1206 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1518-1208 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1538-1210 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1528-1211 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1353-1214 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1353-1213 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1397-1215 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1238-1217 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1442-1222 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1484-1223 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1366-1222 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1473-1223 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1461-1224 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1366-1225 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1366-1225 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1366-1225 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1539-1226 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1540-1229 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1351-1231 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1325-1232 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1358-1235 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1358-1234 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1522-1238 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1541-1239 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1365-1243 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1251-1247 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1251-1250 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1251-1249 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1251-1248 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1439-1253 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1449-1253 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1541-1255 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1530-1256 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1184-1258 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1474-1259 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1475-1259 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1542-1261 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1271-1263 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1271-1263 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1506-1265 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1278-1267 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1277-1267 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1377-1270 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1377-1270 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1320-1271 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1546-1271 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1320-1271 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1320-1271 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1320-1271 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1320-1271 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1299-1278 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1299-1277 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1515-1285 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1339-1286 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1520-1286 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1543-1297 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1463-1298 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1376-1301 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1331-1308 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1545-1309 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1545-1310 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1331-1318 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1341-1326 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1504-1329 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1392-1333 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1393-1332 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1520-1339 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1547-1340 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1425-1344 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1435-1348 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1390-1353 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1391-1353 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1420-1358 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1457-1360 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1537-1361 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1459-1364 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1442-1366 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1514-1366 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1473-1366 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1380-1374 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1476-1374 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1498-1374 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1540-1374 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1516-1382 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1388-1384 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1446-1385 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1496-1384 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1508-1384 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1509-1384 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1527-1384 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1445-1385 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1526-1385 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1502-1385 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1475-1387 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1431-1392 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1512-1392 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1430-1392 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1471-1392 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1472-1393 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1402-1400 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1402-1399 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1403-1398 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1421-1416 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1549-1424 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1511-1429 connects the same voltage levels (150.0, 150.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1493-1454 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1538-1522 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 8-1576 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 8-1599 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 40-1551 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 40-1600 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 108-1601 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 121-1552 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 121-1577 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 168-1578 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 206-1553 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 206-1579 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 250-1554 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 250-1580 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 258-1555 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 257-1602 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 258-1613 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 257-1622 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 280-1556 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 280-1581 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 292-1603 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 308-1604 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 369-1623 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 421-1557 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 441-1614 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 441-1624 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 462-1558 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 462-1582 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 553-1583 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 603-1559 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 709-1584 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 709-1605 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 764-1606 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 776-1560 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 786-1561 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 787-1585 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 802-1562 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 802-1586 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 814-1563 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 814-1587 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 814-1607 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 814-1615 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 821-1564 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 821-1588 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 839-1589 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 838-1608 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 838-1616 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 857-1565 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 857-1590 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 899-1566 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 899-1591 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1272-904 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1017-1567 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1017-1592 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1018-1609 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1018-1617 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1041-1568 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1126-1569 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1126-1593 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1158-1570 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1164-1571 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1164-1594 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1174-1572 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1181-1610 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1180-1618 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1216-1625 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1263-1573 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1263-1595 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1299-1611 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1299-1619 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1337-1574 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1352-1596 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1386-1575 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1386-1597 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1386-1612 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1386-1620 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1386-1626 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1394-1598 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1395-1621 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1395-1627 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 766-1795 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 766-1796 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 981-1797 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 739-1798 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 36-1799 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1181-1800 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 849-1801 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 885-1802 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 792-1803 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 70-1804 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 764-1805 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1181-1806 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 975-1807 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1504-1808 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 216-1809 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1402-1810 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 874-1811 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1199-1812 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1367-1813 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1368-1814 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 306-1815 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 37-1816 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1180-1817 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 345-1818 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 7-1819 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 8-1820 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 346-1821 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 1382-1822 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 558-1823 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 558-1824 connects the same voltage levels (225.0, 225.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 216-1825 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% WARNING : Transformer 86-1826 connects the same voltage levels (380.0, 380.0) and has no phase shift, changing tap ratio 1.0 => 0.0
% INFO    : 
% INFO    : === Line Capacity UB Model Notes ===
% INFO    : Updated Thermal Rating: on line 1048-4 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 905
% INFO    : Updated Thermal Rating: on line 1330-6 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3441
% INFO    : Updated Thermal Rating: on line 1350-5 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9629
% INFO    : Updated Thermal Rating: on line 106-11 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 53862
% INFO    : Updated Thermal Rating: on line 123-27 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1479
% INFO    : Updated Thermal Rating: on line 212-33 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 29203
% INFO    : Updated Thermal Rating: on line 1257-35 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 270
% INFO    : Updated Thermal Rating: on line 1439-35 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1408
% INFO    : Updated Thermal Rating: on line 766-40 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 1470
% INFO    : Updated Thermal Rating: on line 950-40 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 2227
% INFO    : Updated Thermal Rating: on line 1282-40 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 2077
% INFO    : Updated Thermal Rating: on line 766-40 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 1470
% INFO    : Updated Thermal Rating: on line 950-40 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 2229
% INFO    : Updated Thermal Rating: on line 1281-40 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 2074
% INFO    : Updated Thermal Rating: on line 1525-45 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2348
% INFO    : Updated Thermal Rating: on line 1321-46 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3004
% INFO    : Updated Thermal Rating: on line 1429-46 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4003
% INFO    : Updated Thermal Rating: on line 608-49 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 169660
% INFO    : Updated Thermal Rating: on line 1429-58 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 24825
% INFO    : Updated Thermal Rating: on line 1090-60 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17970
% INFO    : Updated Thermal Rating: on line 1090-59 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17970
% INFO    : Updated Thermal Rating: on line 713-61 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 48541
% INFO    : Updated Thermal Rating: on line 342-65 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 46138
% INFO    : Updated Thermal Rating: on line 1416-70 : Rate A, Rate B, Rate C , 2275.0, 2275.0, 2275.0 -> 1648
% INFO    : Updated Thermal Rating: on line 1430-80 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 306724
% INFO    : Updated Thermal Rating: on line 1186-85 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11556
% INFO    : Updated Thermal Rating: on line 1187-85 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 11556
% INFO    : Updated Thermal Rating: on line 283-89 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1227
% INFO    : Updated Thermal Rating: on line 467-89 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 355
% INFO    : Updated Thermal Rating: on line 729-89 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 516
% INFO    : Updated Thermal Rating: on line 1335-89 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1069
% INFO    : Updated Thermal Rating: on line 376-91 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 903
% INFO    : Updated Thermal Rating: on line 1489-91 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1123
% INFO    : Updated Thermal Rating: on line 1062-92 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 2026
% INFO    : Updated Thermal Rating: on line 1282-92 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 1636
% INFO    : Updated Thermal Rating: on line 1062-93 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 2043
% INFO    : Updated Thermal Rating: on line 1281-93 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 1634
% INFO    : Updated Thermal Rating: on line 680-98 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 291
% INFO    : Updated Thermal Rating: on line 701-98 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 459
% INFO    : Updated Thermal Rating: on line 1232-100 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 155143
% INFO    : Updated Thermal Rating: on line 231-104 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 155535
% INFO    : Updated Thermal Rating: on line 554-108 : Rate A, Rate B, Rate C , 2040.0, 2040.0, 2040.0 -> 1087
% INFO    : Updated Thermal Rating: on line 776-108 : Rate A, Rate B, Rate C , 1487.0, 1487.0, 1487.0 -> 1128
% INFO    : Updated Thermal Rating: on line 776-108 : Rate A, Rate B, Rate C , 1487.0, 1487.0, 1487.0 -> 1127
% INFO    : Updated Thermal Rating: on line 1216-108 : Rate A, Rate B, Rate C , 2040.0, 2040.0, 2040.0 -> 1979
% INFO    : Updated Thermal Rating: on line 854-109 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 13045
% INFO    : Updated Thermal Rating: on line 774-117 : Rate A, Rate B, Rate C , 1579.0, 1579.0, 1579.0 -> 899
% INFO    : Updated Thermal Rating: on line 716-124 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1010
% INFO    : Updated Thermal Rating: on line 1487-124 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2109
% INFO    : Updated Thermal Rating: on line 839-136 : Rate A, Rate B, Rate C , 2389.0, 2389.0, 2389.0 -> 2232
% INFO    : Updated Thermal Rating: on line 838-136 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 2175
% INFO    : Updated Thermal Rating: on line 986-140 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5617
% INFO    : Updated Thermal Rating: on line 517-148 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20021
% INFO    : Updated Thermal Rating: on line 181-151 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19054
% INFO    : Updated Thermal Rating: on line 354-153 : Rate A, Rate B, Rate C , 935.0, 935.0, 935.0 -> 892
% INFO    : Updated Thermal Rating: on line 438-156 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1954
% INFO    : Updated Thermal Rating: on line 437-156 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1954
% INFO    : Updated Thermal Rating: on line 1500-165 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 153231
% INFO    : Updated Thermal Rating: on line 776-168 : Rate A, Rate B, Rate C , 1188.0, 1188.0, 1188.0 -> 639
% INFO    : Updated Thermal Rating: on line 760-169 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2065
% INFO    : Updated Thermal Rating: on line 1439-170 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8880
% INFO    : Updated Thermal Rating: on line 1438-172 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 155535
% INFO    : Updated Thermal Rating: on line 1440-171 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 99170
% INFO    : Updated Thermal Rating: on line 1242-186 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 183736
% INFO    : Updated Thermal Rating: on line 1243-185 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 170060
% INFO    : Updated Thermal Rating: on line 1242-183 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 158275
% INFO    : Updated Thermal Rating: on line 1243-184 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 158275
% INFO    : Updated Thermal Rating: on line 1238-200 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6053
% INFO    : Updated Thermal Rating: on line 1212-201 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3054
% INFO    : Updated Thermal Rating: on line 447-203 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 308785
% INFO    : Updated Thermal Rating: on line 1025-207 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 39366
% INFO    : Updated Thermal Rating: on line 1104-207 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22986
% INFO    : Updated Thermal Rating: on line 614-225 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4554
% INFO    : Updated Thermal Rating: on line 350-226 : Rate A, Rate B, Rate C , 1579.0, 1579.0, 1579.0 -> 1075
% INFO    : Updated Thermal Rating: on line 787-226 : Rate A, Rate B, Rate C , 1987.0, 1987.0, 1987.0 -> 1524
% INFO    : Updated Thermal Rating: on line 846-227 : Rate A, Rate B, Rate C , 736.0, 736.0, 736.0 -> 467
% INFO    : Updated Thermal Rating: on line 1150-228 : Rate A, Rate B, Rate C , 1932.0, 1932.0, 1932.0 -> 1807
% INFO    : Updated Thermal Rating: on line 1150-228 : Rate A, Rate B, Rate C , 1932.0, 1932.0, 1932.0 -> 1827
% INFO    : Updated Thermal Rating: on line 632-239 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 21471
% INFO    : Updated Thermal Rating: on line 848-240 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27618
% INFO    : Updated Thermal Rating: on line 1178-240 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 42153
% INFO    : Updated Thermal Rating: on line 386-242 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 4057
% INFO    : Updated Thermal Rating: on line 997-247 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20979
% INFO    : Updated Thermal Rating: on line 784-250 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 1573
% INFO    : Updated Thermal Rating: on line 1352-250 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 1434
% INFO    : Updated Thermal Rating: on line 784-250 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 1578
% INFO    : Updated Thermal Rating: on line 1352-250 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 1435
% INFO    : Updated Thermal Rating: on line 357-263 : Rate A, Rate B, Rate C , 1611.0, 1611.0, 1611.0 -> 1100
% INFO    : Updated Thermal Rating: on line 363-263 : Rate A, Rate B, Rate C , 1567.0, 1567.0, 1567.0 -> 1311
% INFO    : Updated Thermal Rating: on line 623-263 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 2245
% INFO    : Updated Thermal Rating: on line 623-263 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 2244
% INFO    : Updated Thermal Rating: on line 1120-283 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3362
% INFO    : Updated Thermal Rating: on line 398-288 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 154266
% INFO    : Updated Thermal Rating: on line 398-287 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 151981
% INFO    : Updated Thermal Rating: on line 945-290 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3425
% INFO    : Updated Thermal Rating: on line 1409-290 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5192
% INFO    : Updated Thermal Rating: on line 1408-290 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5314
% INFO    : Updated Thermal Rating: on line 1260-292 : Rate A, Rate B, Rate C , 1566.0, 1566.0, 1566.0 -> 1490
% INFO    : Updated Thermal Rating: on line 1260-293 : Rate A, Rate B, Rate C , 1842.0, 1842.0, 1842.0 -> 1720
% INFO    : Updated Thermal Rating: on line 1260-293 : Rate A, Rate B, Rate C , 1842.0, 1842.0, 1842.0 -> 1735
% INFO    : Updated Thermal Rating: on line 1416-296 : Rate A, Rate B, Rate C , 1917.0, 1917.0, 1917.0 -> 1451
% INFO    : Updated Thermal Rating: on line 1416-296 : Rate A, Rate B, Rate C , 1917.0, 1917.0, 1917.0 -> 1451
% INFO    : Updated Thermal Rating: on line 342-297 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 9991
% INFO    : Updated Thermal Rating: on line 895-297 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 10322
% INFO    : Updated Thermal Rating: on line 1449-319 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 320583
% INFO    : Updated Thermal Rating: on line 1405-324 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2077
% INFO    : Updated Thermal Rating: on line 1010-340 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1110
% INFO    : Updated Thermal Rating: on line 1159-340 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8488
% INFO    : Updated Thermal Rating: on line 1531-340 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1054
% INFO    : Updated Thermal Rating: on line 1031-348 : Rate A, Rate B, Rate C , 558.0, 558.0, 558.0 -> 297
% INFO    : Updated Thermal Rating: on line 436-350 : Rate A, Rate B, Rate C , 1579.0, 1579.0, 1579.0 -> 1002
% INFO    : Updated Thermal Rating: on line 436-350 : Rate A, Rate B, Rate C , 1579.0, 1579.0, 1579.0 -> 996
% INFO    : Updated Thermal Rating: on line 786-350 : Rate A, Rate B, Rate C , 1579.0, 1579.0, 1579.0 -> 633
% INFO    : Updated Thermal Rating: on line 1531-361 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19617
% INFO    : Updated Thermal Rating: on line 1166-362 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 155535
% INFO    : Updated Thermal Rating: on line 557-364 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 417
% INFO    : Updated Thermal Rating: on line 933-364 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 555
% INFO    : Updated Thermal Rating: on line 657-366 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 167
% INFO    : Updated Thermal Rating: on line 1080-369 : Rate A, Rate B, Rate C , 1711.0, 1711.0, 1711.0 -> 1648
% INFO    : Updated Thermal Rating: on line 1365-369 : Rate A, Rate B, Rate C , 1307.0, 1307.0, 1307.0 -> 1080
% INFO    : Updated Thermal Rating: on line 512-374 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 155535
% INFO    : Updated Thermal Rating: on line 1117-377 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27378
% INFO    : Updated Thermal Rating: on line 1116-377 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 27596
% INFO    : Updated Thermal Rating: on line 530-378 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23964
% INFO    : Updated Thermal Rating: on line 397-386 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23302
% INFO    : Updated Thermal Rating: on line 467-386 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 479
% INFO    : Updated Thermal Rating: on line 1113-386 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 461
% INFO    : Updated Thermal Rating: on line 443-390 : Rate A, Rate B, Rate C , 2280.0, 2280.0, 2280.0 -> 932
% INFO    : Updated Thermal Rating: on line 963-390 : Rate A, Rate B, Rate C , 1559.0, 1559.0, 1559.0 -> 944
% INFO    : Updated Thermal Rating: on line 443-390 : Rate A, Rate B, Rate C , 2280.0, 2280.0, 2280.0 -> 932
% INFO    : Updated Thermal Rating: on line 1835-395 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 19787
% INFO    : Updated Thermal Rating: on line 1090-401 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22551
% INFO    : Updated Thermal Rating: on line 1090-400 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 23186
% INFO    : Updated Thermal Rating: on line 520-402 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26532
% INFO    : Updated Thermal Rating: on line 573-410 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 38142
% INFO    : Updated Thermal Rating: on line 413-411 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 314576
% INFO    : Updated Thermal Rating: on line 1426-421 : Rate A, Rate B, Rate C , 1828.0, 1828.0, 1828.0 -> 1297
% INFO    : Updated Thermal Rating: on line 614-426 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1044
% INFO    : Updated Thermal Rating: on line 961-436 : Rate A, Rate B, Rate C , 1579.0, 1579.0, 1579.0 -> 1517
% INFO    : Updated Thermal Rating: on line 1488-440 : Rate A, Rate B, Rate C , 541.0, 541.0, 541.0 -> 443
% INFO    : Updated Thermal Rating: on line 711-441 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 2406
% INFO    : Updated Thermal Rating: on line 829-441 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 1759
% INFO    : Updated Thermal Rating: on line 1023-441 : Rate A, Rate B, Rate C , 1579.0, 1579.0, 1579.0 -> 1245
% INFO    : Updated Thermal Rating: on line 1041-441 : Rate A, Rate B, Rate C , 2389.0, 2389.0, 2389.0 -> 1191
% INFO    : Updated Thermal Rating: on line 711-441 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 2405
% INFO    : Updated Thermal Rating: on line 1352-443 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 1934
% INFO    : Updated Thermal Rating: on line 775-461 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 358
% INFO    : Updated Thermal Rating: on line 827-461 : Rate A, Rate B, Rate C , 325.0, 325.0, 325.0 -> 274
% INFO    : Updated Thermal Rating: on line 776-462 : Rate A, Rate B, Rate C , 1579.0, 1579.0, 1579.0 -> 1482
% INFO    : Updated Thermal Rating: on line 963-462 : Rate A, Rate B, Rate C , 1579.0, 1579.0, 1579.0 -> 1546
% INFO    : Updated Thermal Rating: on line 1337-462 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 2287
% INFO    : Updated Thermal Rating: on line 1353-462 : Rate A, Rate B, Rate C , 1579.0, 1579.0, 1579.0 -> 996
% INFO    : Updated Thermal Rating: on line 1337-462 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 2289
% INFO    : Updated Thermal Rating: on line 572-472 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 85214
% INFO    : Updated Thermal Rating: on line 555-1832 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 41198
% INFO    : Updated Thermal Rating: on line 1200-480 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 320795
% INFO    : Updated Thermal Rating: on line 1200-481 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 320795
% INFO    : Updated Thermal Rating: on line 1199-482 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 313831
% INFO    : Updated Thermal Rating: on line 1199-483 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 313831
% INFO    : Updated Thermal Rating: on line 489-487 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 155535
% INFO    : Updated Thermal Rating: on line 489-486 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 155535
% INFO    : Updated Thermal Rating: on line 489-488 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 155535
% INFO    : Updated Thermal Rating: on line 489-485 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 155535
% INFO    : Updated Thermal Rating: on line 1468-492 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25032
% INFO    : Updated Thermal Rating: on line 1467-491 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25032
% INFO    : Updated Thermal Rating: on line 669-506 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3869
% INFO    : Updated Thermal Rating: on line 854-513 : Rate A, Rate B, Rate C , 509.0, 509.0, 509.0 -> 421
% INFO    : Updated Thermal Rating: on line 865-513 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 568
% INFO    : Updated Thermal Rating: on line 995-521 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 37106
% INFO    : Updated Thermal Rating: on line 559-528 : Rate A, Rate B, Rate C , 1253.0, 1253.0, 1253.0 -> 1246
% INFO    : Updated Thermal Rating: on line 1054-534 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 206236
% INFO    : Updated Thermal Rating: on line 1472-535 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 155535
% INFO    : Updated Thermal Rating: on line 1239-545 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 467
% INFO    : Updated Thermal Rating: on line 1377-545 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 610
% INFO    : Updated Thermal Rating: on line 672-548 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 59375
% INFO    : Updated Thermal Rating: on line 554-550 : Rate A, Rate B, Rate C , 2389.0, 2389.0, 2389.0 -> 1998
% INFO    : Updated Thermal Rating: on line 554-550 : Rate A, Rate B, Rate C , 2389.0, 2389.0, 2389.0 -> 1997
% INFO    : Updated Thermal Rating: on line 1126-553 : Rate A, Rate B, Rate C , 1695.0, 1695.0, 1695.0 -> 787
% INFO    : Updated Thermal Rating: on line 1263-553 : Rate A, Rate B, Rate C , 2362.0, 2362.0, 2362.0 -> 1552
% INFO    : Updated Thermal Rating: on line 1352-553 : Rate A, Rate B, Rate C , 1579.0, 1579.0, 1579.0 -> 1543
% INFO    : Updated Thermal Rating: on line 1263-553 : Rate A, Rate B, Rate C , 2362.0, 2362.0, 2362.0 -> 1597
% INFO    : Updated Thermal Rating: on line 1216-554 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 2461
% INFO    : Updated Thermal Rating: on line 1365-559 : Rate A, Rate B, Rate C , 1750.0, 1750.0, 1750.0 -> 873
% INFO    : Updated Thermal Rating: on line 1365-559 : Rate A, Rate B, Rate C , 2197.0, 2197.0, 2197.0 -> 873
% INFO    : Updated Thermal Rating: on line 1365-559 : Rate A, Rate B, Rate C , 1192.0, 1192.0, 1192.0 -> 806
% INFO    : Updated Thermal Rating: on line 755-570 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2747
% INFO    : Updated Thermal Rating: on line 1294-572 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 89765
% INFO    : Updated Thermal Rating: on line 1239-574 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 471
% INFO    : Updated Thermal Rating: on line 1493-578 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5016
% INFO    : Updated Thermal Rating: on line 701-582 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 463
% INFO    : Updated Thermal Rating: on line 753-582 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1026
% INFO    : Updated Thermal Rating: on line 644-584 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6148
% INFO    : Updated Thermal Rating: on line 979-587 : Rate A, Rate B, Rate C , 2368.0, 2368.0, 2368.0 -> 2335
% INFO    : Updated Thermal Rating: on line 1337-587 : Rate A, Rate B, Rate C , 2389.0, 2389.0, 2389.0 -> 1679
% INFO    : Updated Thermal Rating: on line 978-587 : Rate A, Rate B, Rate C , 2368.0, 2368.0, 2368.0 -> 2335
% INFO    : Updated Thermal Rating: on line 1337-587 : Rate A, Rate B, Rate C , 2389.0, 2389.0, 2389.0 -> 1679
% INFO    : Updated Thermal Rating: on line 1242-603 : Rate A, Rate B, Rate C , 1662.0, 1662.0, 1662.0 -> 1168
% INFO    : Updated Thermal Rating: on line 1365-603 : Rate A, Rate B, Rate C , 1659.0, 1659.0, 1659.0 -> 1605
% INFO    : Updated Thermal Rating: on line 604-430 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 155535
% INFO    : Updated Thermal Rating: on line 756-629 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 38967
% INFO    : Updated Thermal Rating: on line 672-632 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 50437
% INFO    : Updated Thermal Rating: on line 671-632 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 40928
% INFO    : Updated Thermal Rating: on line 884-640 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8140
% INFO    : Updated Thermal Rating: on line 883-640 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 8731
% INFO    : Updated Thermal Rating: on line 733-651 : Rate A, Rate B, Rate C , 1617.0, 1617.0, 1617.0 -> 1286
% INFO    : Updated Thermal Rating: on line 890-651 : Rate A, Rate B, Rate C , 1828.0, 1828.0, 1828.0 -> 926
% INFO    : Updated Thermal Rating: on line 891-651 : Rate A, Rate B, Rate C , 1828.0, 1828.0, 1828.0 -> 926
% INFO    : Updated Thermal Rating: on line 816-652 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5963
% INFO    : Updated Thermal Rating: on line 1344-656 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6988
% INFO    : Updated Thermal Rating: on line 1345-655 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6988
% INFO    : Updated Thermal Rating: on line 1517-657 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2204
% INFO    : Updated Thermal Rating: on line 799-666 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 308785
% INFO    : Updated Thermal Rating: on line 1486-676 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2283
% INFO    : Updated Thermal Rating: on line 748-680 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 411
% INFO    : Updated Thermal Rating: on line 815-680 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 359
% INFO    : Updated Thermal Rating: on line 1314-690 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 148594
% INFO    : Updated Thermal Rating: on line 1314-691 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 151981
% INFO    : Updated Thermal Rating: on line 892-693 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 184947
% INFO    : Updated Thermal Rating: on line 892-692 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 169954
% INFO    : Updated Thermal Rating: on line 1491-694 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 48031
% INFO    : Updated Thermal Rating: on line 1507-701 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 841
% INFO    : Updated Thermal Rating: on line 1394-709 : Rate A, Rate B, Rate C , 1579.0, 1579.0, 1579.0 -> 1476
% INFO    : Updated Thermal Rating: on line 1267-711 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 2130
% INFO    : Updated Thermal Rating: on line 1267-711 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 2130
% INFO    : Updated Thermal Rating: on line 1066-713 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 104366
% INFO    : Updated Thermal Rating: on line 1065-713 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 87644
% INFO    : Updated Thermal Rating: on line 946-716 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 529
% INFO    : Updated Thermal Rating: on line 955-725 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 93975
% INFO    : Updated Thermal Rating: on line 955-723 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 128083
% INFO    : Updated Thermal Rating: on line 955-724 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 120296
% INFO    : Updated Thermal Rating: on line 1494-727 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 83031
% INFO    : Updated Thermal Rating: on line 1528-729 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 845
% INFO    : Updated Thermal Rating: on line 1114-730 : Rate A, Rate B, Rate C , 482.0, 482.0, 482.0 -> 455
% INFO    : Updated Thermal Rating: on line 1449-736 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 930
% INFO    : Updated Thermal Rating: on line 851-739 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 1547
% INFO    : Updated Thermal Rating: on line 792-739 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 1476
% INFO    : Updated Thermal Rating: on line 851-739 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 1547
% INFO    : Updated Thermal Rating: on line 792-739 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 1479
% INFO    : Updated Thermal Rating: on line 1191-748 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2312
% INFO    : Updated Thermal Rating: on line 1507-748 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 695
% INFO    : Updated Thermal Rating: on line 1511-748 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3453
% INFO    : Updated Thermal Rating: on line 973-753 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1911
% INFO    : Updated Thermal Rating: on line 1121-762 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3468
% INFO    : Updated Thermal Rating: on line 989-763 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 432
% INFO    : Updated Thermal Rating: on line 1324-765 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 46632
% INFO    : Updated Thermal Rating: on line 1323-765 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 51447
% INFO    : Updated Thermal Rating: on line 1838-765 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 51447
% INFO    : Updated Thermal Rating: on line 976-771 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 939
% INFO    : Updated Thermal Rating: on line 1367-774 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 1264
% INFO    : Updated Thermal Rating: on line 853-775 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 536
% INFO    : Updated Thermal Rating: on line 1487-779 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 126
% INFO    : Updated Thermal Rating: on line 1513-779 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 225
% INFO    : Updated Thermal Rating: on line 946-779 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 138
% INFO    : Updated Thermal Rating: on line 1044-798 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 25728
% INFO    : Updated Thermal Rating: on line 1505-808 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 309124
% INFO    : Updated Thermal Rating: on line 1290-814 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2130
% INFO    : Updated Thermal Rating: on line 1291-814 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2147
% INFO    : Updated Thermal Rating: on line 1005-815 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1610
% INFO    : Updated Thermal Rating: on line 1321-817 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5340
% INFO    : Updated Thermal Rating: on line 1241-818 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1063
% INFO    : Updated Thermal Rating: on line 1507-832 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 36286
% INFO    : Updated Thermal Rating: on line 1223-869 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2446
% INFO    : Updated Thermal Rating: on line 1375-874 : Rate A, Rate B, Rate C , 1617.0, 1617.0, 1617.0 -> 1275
% INFO    : Updated Thermal Rating: on line 897-881 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 301
% INFO    : Updated Thermal Rating: on line 887-886 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 310318
% INFO    : Updated Thermal Rating: on line 1365-891 : Rate A, Rate B, Rate C , 1842.0, 1842.0, 1842.0 -> 1005
% INFO    : Updated Thermal Rating: on line 1365-890 : Rate A, Rate B, Rate C , 1842.0, 1842.0, 1842.0 -> 1006
% INFO    : Updated Thermal Rating: on line 1387-896 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1346
% INFO    : Updated Thermal Rating: on line 921-897 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 384
% INFO    : Updated Thermal Rating: on line 1232-901 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 37253
% INFO    : Updated Thermal Rating: on line 1104-906 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 93975
% INFO    : Updated Thermal Rating: on line 1105-907 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 102466
% INFO    : Updated Thermal Rating: on line 1511-908 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 43088
% INFO    : Updated Thermal Rating: on line 962-913 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 64874
% INFO    : Updated Thermal Rating: on line 962-914 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 64874
% INFO    : Updated Thermal Rating: on line 962-912 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 52282
% INFO    : Updated Thermal Rating: on line 1264-921 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 461
% INFO    : Updated Thermal Rating: on line 1130-922 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 106960
% INFO    : Updated Thermal Rating: on line 1834-933 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 14028
% INFO    : Updated Thermal Rating: on line 985-938 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 308192
% INFO    : Updated Thermal Rating: on line 984-938 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 308192
% INFO    : Updated Thermal Rating: on line 1513-946 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 373
% INFO    : Updated Thermal Rating: on line 1373-965 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 315
% INFO    : Updated Thermal Rating: on line 1517-1001 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 151172
% INFO    : Updated Thermal Rating: on line 1496-1002 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20343
% INFO    : Updated Thermal Rating: on line 976-1003 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 511
% INFO    : Updated Thermal Rating: on line 1489-1003 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 6284
% INFO    : Updated Thermal Rating: on line 956-1014 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1771
% INFO    : Updated Thermal Rating: on line 1265-1035 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 470
% INFO    : Updated Thermal Rating: on line 1522-1039 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 5986
% INFO    : Updated Thermal Rating: on line 1523-1049 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 47367
% INFO    : Updated Thermal Rating: on line 1047-1052 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 138682
% INFO    : Updated Thermal Rating: on line 1046-1052 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 138682
% INFO    : Updated Thermal Rating: on line 1045-1052 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 123245
% INFO    : Updated Thermal Rating: on line 1100-1054 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 29661
% INFO    : Updated Thermal Rating: on line 1164-1074 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 40590
% INFO    : Updated Thermal Rating: on line 1164-1073 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 42124
% INFO    : Updated Thermal Rating: on line 1368-1080 : Rate A, Rate B, Rate C , 1708.0, 1708.0, 1708.0 -> 1115
% INFO    : Updated Thermal Rating: on line 1085-1082 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26121
% INFO    : Updated Thermal Rating: on line 1083-1082 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26121
% INFO    : Updated Thermal Rating: on line 1084-1082 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26121
% INFO    : Updated Thermal Rating: on line 1188-1087 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 20973
% INFO    : Updated Thermal Rating: on line 1527-1098 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 53230
% INFO    : Updated Thermal Rating: on line 1526-1097 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 67824
% INFO    : Updated Thermal Rating: on line 1299-1110 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 1811
% INFO    : Updated Thermal Rating: on line 1299-1110 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 1825
% INFO    : Updated Thermal Rating: on line 1237-1113 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 481
% INFO    : Updated Thermal Rating: on line 1528-1120 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 742
% INFO    : Updated Thermal Rating: on line 1142-1121 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 7269
% INFO    : Updated Thermal Rating: on line 1536-1160 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 56492
% INFO    : Updated Thermal Rating: on line 1365-1174 : Rate A, Rate B, Rate C , 1659.0, 1659.0, 1659.0 -> 1386
% INFO    : Updated Thermal Rating: on line 1228-1188 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 16924
% INFO    : Updated Thermal Rating: on line 1334-1836 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 22038
% INFO    : Updated Thermal Rating: on line 1538-1210 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 17958
% INFO    : Updated Thermal Rating: on line 1528-1211 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 489
% INFO    : Updated Thermal Rating: on line 1365-1243 : Rate A, Rate B, Rate C , 1711.0, 1711.0, 1711.0 -> 811
% INFO    : Updated Thermal Rating: on line 1439-1253 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1313
% INFO    : Updated Thermal Rating: on line 1449-1253 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 522
% INFO    : Updated Thermal Rating: on line 1271-1263 : Rate A, Rate B, Rate C , 2961.0, 2961.0, 2961.0 -> 1589
% INFO    : Updated Thermal Rating: on line 1271-1263 : Rate A, Rate B, Rate C , 2961.0, 2961.0, 2961.0 -> 1589
% INFO    : Updated Thermal Rating: on line 1546-1271 : Rate A, Rate B, Rate C , 2450.0, 2450.0, 2450.0 -> 1390
% INFO    : Updated Thermal Rating: on line 1299-1278 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 2158
% INFO    : Updated Thermal Rating: on line 1299-1277 : Rate A, Rate B, Rate C , 2487.0, 2487.0, 2487.0 -> 2153
% INFO    : Updated Thermal Rating: on line 1402-1400 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26121
% INFO    : Updated Thermal Rating: on line 1402-1399 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26121
% INFO    : Updated Thermal Rating: on line 1403-1398 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 26121
% INFO    : Updated Thermal Rating: on line 1421-1416 : Rate A, Rate B, Rate C , 2275.0, 2275.0, 2275.0 -> 2203
% INFO    : Updated Thermal Rating: on line 1511-1429 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 3850
% INFO    : Updated Thermal Rating: on transformer 4-6 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 265
% INFO    : Updated Thermal Rating: on line 8-1576 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1035
% INFO    : Updated Thermal Rating: on line 8-1599 : Rate A, Rate B, Rate C , 1188.0, 1188.0, 1188.0 -> 1035
% INFO    : Updated Thermal Rating: on transformer 2050-1551 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 919
% INFO    : Updated Thermal Rating: on line 40-1551 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1019
% INFO    : Updated Thermal Rating: on line 40-1600 : Rate A, Rate B, Rate C , 1187.0, 1187.0, 1187.0 -> 997
% INFO    : Updated Thermal Rating: on transformer 2051-1552 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 596
% INFO    : Updated Thermal Rating: on transformer 2019-1578 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 386
% INFO    : Updated Thermal Rating: on transformer 2086-1579 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 608
% INFO    : Updated Thermal Rating: on transformer 229-230 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 566
% INFO    : Updated Thermal Rating: on transformer 241-242 : Rate A, Rate B, Rate C , 2164.0, 2164.0, 2164.0 -> 133
% INFO    : Updated Thermal Rating: on transformer 2030-1554 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 384
% INFO    : Updated Thermal Rating: on transformer 2029-1580 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 390
% INFO    : Updated Thermal Rating: on transformer 2031-1555 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 690
% INFO    : Updated Thermal Rating: on transformer 2025-1602 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 633
% INFO    : Updated Thermal Rating: on transformer 2046-1613 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 598
% INFO    : Updated Thermal Rating: on transformer 2032-1622 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 602
% INFO    : Updated Thermal Rating: on line 257-1602 : Rate A, Rate B, Rate C , 1184.0, 1184.0, 1184.0 -> 956
% INFO    : Updated Thermal Rating: on line 258-1613 : Rate A, Rate B, Rate C , 1184.0, 1184.0, 1184.0 -> 1040
% INFO    : Updated Thermal Rating: on line 257-1622 : Rate A, Rate B, Rate C , 1184.0, 1184.0, 1184.0 -> 1055
% INFO    : Updated Thermal Rating: on transformer 267-269 : Rate A, Rate B, Rate C , 1184.0, 1184.0, 1184.0 -> 1177
% INFO    : Updated Thermal Rating: on transformer 270-271 : Rate A, Rate B, Rate C , 639.0, 639.0, 639.0 -> 123
% INFO    : Updated Thermal Rating: on transformer 270-271 : Rate A, Rate B, Rate C , 639.0, 639.0, 639.0 -> 123
% INFO    : Updated Thermal Rating: on transformer 270-271 : Rate A, Rate B, Rate C , 639.0, 639.0, 639.0 -> 123
% INFO    : Updated Thermal Rating: on transformer 278-1556 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 415
% INFO    : Updated Thermal Rating: on transformer 2062-1603 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 569
% INFO    : Updated Thermal Rating: on transformer 290-291 : Rate A, Rate B, Rate C , 1184.0, 1184.0, 1184.0 -> 1168
% INFO    : Updated Thermal Rating: on transformer 290-291 : Rate A, Rate B, Rate C , 1187.0, 1187.0, 1187.0 -> 1165
% INFO    : Updated Thermal Rating: on line 292-1603 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1024
% INFO    : Updated Thermal Rating: on transformer 2047-1604 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 612
% INFO    : Updated Thermal Rating: on transformer 307-308 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1162
% INFO    : Updated Thermal Rating: on transformer 307-308 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1159
% INFO    : Updated Thermal Rating: on line 308-1604 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1053
% INFO    : Updated Thermal Rating: on transformer 327-328 : Rate A, Rate B, Rate C , 1038.0, 1038.0, 1038.0 -> 118
% INFO    : Updated Thermal Rating: on transformer 348-350 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1165
% INFO    : Updated Thermal Rating: on transformer 348-350 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1153
% INFO    : Updated Thermal Rating: on transformer 2014-1623 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 679
% INFO    : Updated Thermal Rating: on transformer 396-397 : Rate A, Rate B, Rate C , 2164.0, 2164.0, 2164.0 -> 133
% INFO    : Updated Thermal Rating: on line 421-1557 : Rate A, Rate B, Rate C , 1184.0, 1184.0, 1184.0 -> 965
% INFO    : Updated Thermal Rating: on transformer 435-436 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1153
% INFO    : Updated Thermal Rating: on transformer 435-436 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1145
% INFO    : Updated Thermal Rating: on transformer 2020-1614 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 350
% INFO    : Updated Thermal Rating: on line 441-1614 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 942
% INFO    : Updated Thermal Rating: on line 441-1624 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 963
% INFO    : Updated Thermal Rating: on transformer 2033-1558 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 336
% INFO    : Updated Thermal Rating: on line 462-1558 : Rate A, Rate B, Rate C , 1187.0, 1187.0, 1187.0 -> 926
% INFO    : Updated Thermal Rating: on line 462-1582 : Rate A, Rate B, Rate C , 606.0, 606.0, 606.0 -> 597
% INFO    : Updated Thermal Rating: on transformer 2021-1583 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 639
% INFO    : Updated Thermal Rating: on transformer 586-587 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1174
% INFO    : Updated Thermal Rating: on transformer 586-587 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1174
% INFO    : Updated Thermal Rating: on transformer 586-587 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1156
% INFO    : Updated Thermal Rating: on transformer 595-596 : Rate A, Rate B, Rate C , 1017.0, 1017.0, 1017.0 -> 200
% INFO    : Updated Thermal Rating: on transformer 595-597 : Rate A, Rate B, Rate C , 1017.0, 1017.0, 1017.0 -> 202
% INFO    : Updated Thermal Rating: on transformer 2015-1559 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 737
% INFO    : Updated Thermal Rating: on line 603-1559 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1024
% INFO    : Updated Thermal Rating: on transformer 614-615 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 221
% INFO    : Updated Thermal Rating: on transformer 614-615 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 169
% INFO    : Updated Thermal Rating: on transformer 633-635 : Rate A, Rate B, Rate C , 1187.0, 1187.0, 1187.0 -> 1157
% INFO    : Updated Thermal Rating: on transformer 633-635 : Rate A, Rate B, Rate C , 1187.0, 1187.0, 1187.0 -> 1159
% INFO    : Updated Thermal Rating: on transformer 649-650 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 195
% INFO    : Updated Thermal Rating: on transformer 649-650 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 195
% INFO    : Updated Thermal Rating: on transformer 657-658 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 166
% INFO    : Updated Thermal Rating: on transformer 701-702 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 257
% INFO    : Updated Thermal Rating: on line 709-1584 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1024
% INFO    : Updated Thermal Rating: on line 709-1605 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1015
% INFO    : Updated Thermal Rating: on transformer 716-717 : Rate A, Rate B, Rate C , 724.0, 724.0, 724.0 -> 269
% INFO    : Updated Thermal Rating: on transformer 729-730 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 224
% INFO    : Updated Thermal Rating: on transformer 736-737 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 202
% INFO    : Updated Thermal Rating: on transformer 741-742 : Rate A, Rate B, Rate C , 1139.0, 1139.0, 1139.0 -> 310
% INFO    : Updated Thermal Rating: on transformer 741-743 : Rate A, Rate B, Rate C , 1139.0, 1139.0, 1139.0 -> 313
% INFO    : Updated Thermal Rating: on transformer 2052-1606 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 293
% INFO    : Updated Thermal Rating: on transformer 2016-1560 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 141
% INFO    : Updated Thermal Rating: on transformer 779-783 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 301
% INFO    : Updated Thermal Rating: on transformer 779-783 : Rate A, Rate B, Rate C , 446.0, 446.0, 446.0 -> 295
% INFO    : Updated Thermal Rating: on transformer 780-784 : Rate A, Rate B, Rate C , 1628.0, 1628.0, 1628.0 -> 317
% INFO    : Updated Thermal Rating: on transformer 780-784 : Rate A, Rate B, Rate C , 1628.0, 1628.0, 1628.0 -> 319
% INFO    : Updated Thermal Rating: on transformer 783-784 : Rate A, Rate B, Rate C , 1188.0, 1188.0, 1188.0 -> 886
% INFO    : Updated Thermal Rating: on transformer 2059-1561 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 357
% INFO    : Updated Thermal Rating: on transformer 2043-1585 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 342
% INFO    : Updated Thermal Rating: on line 786-1561 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 819
% INFO    : Updated Thermal Rating: on line 787-1585 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 910
% INFO    : Updated Thermal Rating: on transformer 2064-1587 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 357
% INFO    : Updated Thermal Rating: on transformer 2063-1607 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 596
% INFO    : Updated Thermal Rating: on line 814-1563 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 956
% INFO    : Updated Thermal Rating: on line 814-1607 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1141
% INFO    : Updated Thermal Rating: on line 814-1615 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 952
% INFO    : Updated Thermal Rating: on line 821-1564 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1087
% INFO    : Updated Thermal Rating: on line 821-1588 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1097
% INFO    : Updated Thermal Rating: on transformer 2078-1589 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 626
% INFO    : Updated Thermal Rating: on transformer 2065-1616 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 614
% INFO    : Updated Thermal Rating: on transformer 836-839 : Rate A, Rate B, Rate C , 1184.0, 1184.0, 1184.0 -> 1159
% INFO    : Updated Thermal Rating: on line 839-1589 : Rate A, Rate B, Rate C , 1187.0, 1187.0, 1187.0 -> 952
% INFO    : Updated Thermal Rating: on line 838-1608 : Rate A, Rate B, Rate C , 1187.0, 1187.0, 1187.0 -> 1057
% INFO    : Updated Thermal Rating: on line 838-1616 : Rate A, Rate B, Rate C , 1187.0, 1187.0, 1187.0 -> 1049
% INFO    : Updated Thermal Rating: on transformer 2036-1565 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 374
% INFO    : Updated Thermal Rating: on transformer 2037-1590 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 375
% INFO    : Updated Thermal Rating: on transformer 977-979 : Rate A, Rate B, Rate C , 1139.0, 1139.0, 1139.0 -> 310
% INFO    : Updated Thermal Rating: on transformer 977-978 : Rate A, Rate B, Rate C , 1139.0, 1139.0, 1139.0 -> 316
% INFO    : Updated Thermal Rating: on transformer 2053-1567 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 603
% INFO    : Updated Thermal Rating: on transformer 2054-1609 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 600
% INFO    : Updated Thermal Rating: on transformer 1014-1018 : Rate A, Rate B, Rate C , 1184.0, 1184.0, 1184.0 -> 1171
% INFO    : Updated Thermal Rating: on line 1017-1567 : Rate A, Rate B, Rate C , 1184.0, 1184.0, 1184.0 -> 1040
% INFO    : Updated Thermal Rating: on line 1017-1592 : Rate A, Rate B, Rate C , 1184.0, 1184.0, 1184.0 -> 1117
% INFO    : Updated Thermal Rating: on line 1018-1609 : Rate A, Rate B, Rate C , 1184.0, 1184.0, 1184.0 -> 1053
% INFO    : Updated Thermal Rating: on line 1018-1617 : Rate A, Rate B, Rate C , 1184.0, 1184.0, 1184.0 -> 1072
% INFO    : Updated Thermal Rating: on transformer 1022-1023 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1156
% INFO    : Updated Thermal Rating: on transformer 1040-1041 : Rate A, Rate B, Rate C , 1188.0, 1188.0, 1188.0 -> 1154
% INFO    : Updated Thermal Rating: on line 1041-1568 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 955
% INFO    : Updated Thermal Rating: on transformer 1079-1080 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1136
% INFO    : Updated Thermal Rating: on transformer 1109-1110 : Rate A, Rate B, Rate C , 1187.0, 1187.0, 1187.0 -> 1177
% INFO    : Updated Thermal Rating: on transformer 2048-1593 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 354
% INFO    : Updated Thermal Rating: on transformer 2049-1570 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 604
% INFO    : Updated Thermal Rating: on line 1158-1570 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1110
% INFO    : Updated Thermal Rating: on transformer 2038-1572 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 726
% INFO    : Updated Thermal Rating: on line 1174-1572 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1079
% INFO    : Updated Thermal Rating: on line 1181-1610 : Rate A, Rate B, Rate C , 600.0, 600.0, 600.0 -> 576
% INFO    : Updated Thermal Rating: on line 1180-1618 : Rate A, Rate B, Rate C , 600.0, 600.0, 600.0 -> 594
% INFO    : Updated Thermal Rating: on transformer 2039-1625 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 289
% INFO    : Updated Thermal Rating: on transformer 1237-1238 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 243
% INFO    : Updated Thermal Rating: on transformer 1257-1258 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 259
% INFO    : Updated Thermal Rating: on transformer 1264-1265 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 229
% INFO    : Updated Thermal Rating: on transformer 1270-1271 : Rate A, Rate B, Rate C , 1266.0, 1266.0, 1266.0 -> 1148
% INFO    : Updated Thermal Rating: on transformer 1270-1271 : Rate A, Rate B, Rate C , 1266.0, 1266.0, 1266.0 -> 1148
% INFO    : Updated Thermal Rating: on transformer 1276-1278 : Rate A, Rate B, Rate C , 1139.0, 1139.0, 1139.0 -> 312
% INFO    : Updated Thermal Rating: on transformer 1276-1277 : Rate A, Rate B, Rate C , 1139.0, 1139.0, 1139.0 -> 310
% INFO    : Updated Thermal Rating: on transformer 1280-1282 : Rate A, Rate B, Rate C , 1184.0, 1184.0, 1184.0 -> 1159
% INFO    : Updated Thermal Rating: on transformer 1280-1281 : Rate A, Rate B, Rate C , 1184.0, 1184.0, 1184.0 -> 1065
% INFO    : Updated Thermal Rating: on transformer 1289-1291 : Rate A, Rate B, Rate C , 1140.0, 1140.0, 1140.0 -> 310
% INFO    : Updated Thermal Rating: on transformer 1289-1290 : Rate A, Rate B, Rate C , 1140.0, 1140.0, 1140.0 -> 310
% INFO    : Updated Thermal Rating: on transformer 2040-1619 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 603
% INFO    : Updated Thermal Rating: on line 1299-1611 : Rate A, Rate B, Rate C , 1188.0, 1188.0, 1188.0 -> 1042
% INFO    : Updated Thermal Rating: on line 1299-1619 : Rate A, Rate B, Rate C , 1188.0, 1188.0, 1188.0 -> 1051
% INFO    : Updated Thermal Rating: on transformer 1301-1302 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 993
% INFO    : Updated Thermal Rating: on transformer 1301-1302 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 991
% INFO    : Updated Thermal Rating: on transformer 1317-1320 : Rate A, Rate B, Rate C , 2258.0, 2258.0, 2258.0 -> 1922
% INFO    : Updated Thermal Rating: on transformer 1313-1320 : Rate A, Rate B, Rate C , 2258.0, 2258.0, 2258.0 -> 1922
% INFO    : Updated Thermal Rating: on transformer 1316-1320 : Rate A, Rate B, Rate C , 2258.0, 2258.0, 2258.0 -> 1922
% INFO    : Updated Thermal Rating: on transformer 1315-1320 : Rate A, Rate B, Rate C , 2258.0, 2258.0, 2258.0 -> 1922
% INFO    : Updated Thermal Rating: on line 1337-1574 : Rate A, Rate B, Rate C , 606.0, 606.0, 606.0 -> 601
% INFO    : Updated Thermal Rating: on transformer 1344-1347 : Rate A, Rate B, Rate C , 1187.0, 1187.0, 1187.0 -> 1175
% INFO    : Updated Thermal Rating: on transformer 1344-1347 : Rate A, Rate B, Rate C , 1188.0, 1188.0, 1188.0 -> 1166
% INFO    : Updated Thermal Rating: on transformer 1345-1347 : Rate A, Rate B, Rate C , 1188.0, 1188.0, 1188.0 -> 1148
% INFO    : Updated Thermal Rating: on transformer 2055-1596 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 651
% INFO    : Updated Thermal Rating: on transformer 1373-1374 : Rate A, Rate B, Rate C , 358.0, 358.0, 358.0 -> 251
% INFO    : Updated Thermal Rating: on transformer 2041-1575 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 605
% INFO    : Updated Thermal Rating: on transformer 2073-1612 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 599
% INFO    : Updated Thermal Rating: on transformer 2060-1620 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 610
% INFO    : Updated Thermal Rating: on transformer 2042-1626 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 634
% INFO    : Updated Thermal Rating: on line 1386-1575 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1117
% INFO    : Updated Thermal Rating: on line 1386-1597 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1113
% INFO    : Updated Thermal Rating: on line 1386-1612 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1051
% INFO    : Updated Thermal Rating: on line 1386-1620 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1051
% INFO    : Updated Thermal Rating: on line 1386-1626 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 947
% INFO    : Updated Thermal Rating: on transformer 1389-1391 : Rate A, Rate B, Rate C , 1139.0, 1139.0, 1139.0 -> 310
% INFO    : Updated Thermal Rating: on transformer 1389-1390 : Rate A, Rate B, Rate C , 1139.0, 1139.0, 1139.0 -> 311
% INFO    : Updated Thermal Rating: on transformer 2056-1598 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 617
% INFO    : Updated Thermal Rating: on transformer 2079-1621 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 589
% INFO    : Updated Thermal Rating: on transformer 2057-1627 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 250
% INFO    : Updated Thermal Rating: on transformer 1393-1394 : Rate A, Rate B, Rate C , 1184.0, 1184.0, 1184.0 -> 1159
% INFO    : Updated Thermal Rating: on line 1394-1598 : Rate A, Rate B, Rate C , 1184.0, 1184.0, 1184.0 -> 945
% INFO    : Updated Thermal Rating: on line 1395-1621 : Rate A, Rate B, Rate C , 1184.0, 1184.0, 1184.0 -> 1113
% INFO    : Updated Thermal Rating: on transformer 1840-1426 : Rate A, Rate B, Rate C , 1186.0, 1186.0, 1186.0 -> 1145
% INFO    : Updated Thermal Rating: on transformer 51-1844 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 62
% INFO    : Updated Thermal Rating: on transformer 61-1630 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 215
% INFO    : Updated Thermal Rating: on transformer 61-1631 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 141
% INFO    : Updated Thermal Rating: on transformer 73-1846 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 86
% INFO    : Updated Thermal Rating: on transformer 73-1632 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 86
% INFO    : Updated Thermal Rating: on transformer 74-1847 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 86
% INFO    : Updated Thermal Rating: on transformer 74-1848 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 86
% INFO    : Updated Thermal Rating: on transformer 103-1852 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 213
% INFO    : Updated Thermal Rating: on transformer 102-1854 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 213
% INFO    : Updated Thermal Rating: on transformer 132-1637 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 646
% INFO    : Updated Thermal Rating: on transformer 131-1638 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 646
% INFO    : Updated Thermal Rating: on transformer 133-1639 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 721
% INFO    : Updated Thermal Rating: on transformer 133-1640 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 921
% INFO    : Updated Thermal Rating: on transformer 133-1641 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 487
% INFO    : Updated Thermal Rating: on transformer 140-1642 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 195
% INFO    : Updated Thermal Rating: on transformer 140-1643 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 176
% INFO    : Updated Thermal Rating: on transformer 140-1855 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 195
% INFO    : Updated Thermal Rating: on transformer 140-1644 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 176
% INFO    : Updated Thermal Rating: on transformer 140-1645 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 176
% INFO    : Updated Thermal Rating: on transformer 791-1646 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 683
% INFO    : Updated Thermal Rating: on transformer 165-1647 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 127
% INFO    : Updated Thermal Rating: on transformer 169-1861 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 106
% INFO    : Updated Thermal Rating: on transformer 194-1653 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 158
% INFO    : Updated Thermal Rating: on transformer 194-1654 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 158
% INFO    : Updated Thermal Rating: on transformer 194-1655 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 158
% INFO    : Updated Thermal Rating: on transformer 193-1656 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 158
% INFO    : Updated Thermal Rating: on transformer 193-1657 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 158
% INFO    : Updated Thermal Rating: on transformer 193-1658 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 158
% INFO    : Updated Thermal Rating: on transformer 196-1863 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 95
% INFO    : Updated Thermal Rating: on transformer 196-1659 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 95
% INFO    : Updated Thermal Rating: on transformer 196-1660 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 95
% INFO    : Updated Thermal Rating: on transformer 196-1661 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 95
% INFO    : Updated Thermal Rating: on transformer 197-1662 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 95
% INFO    : Updated Thermal Rating: on transformer 197-1663 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 95
% INFO    : Updated Thermal Rating: on transformer 200-1865 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 70
% INFO    : Updated Thermal Rating: on transformer 218-1866 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 95
% INFO    : Updated Thermal Rating: on transformer 218-1664 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 95
% INFO    : Updated Thermal Rating: on transformer 218-1665 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 95
% INFO    : Updated Thermal Rating: on transformer 218-1867 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 95
% INFO    : Updated Thermal Rating: on transformer 217-1666 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 95
% INFO    : Updated Thermal Rating: on transformer 217-1868 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 95
% INFO    : Updated Thermal Rating: on transformer 295-1670 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 655
% INFO    : Updated Thermal Rating: on transformer 299-1873 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 589
% INFO    : Updated Thermal Rating: on transformer 299-1874 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 589
% INFO    : Updated Thermal Rating: on transformer 316-2022 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 206
% INFO    : Updated Thermal Rating: on transformer 316-1876 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 206
% INFO    : Updated Thermal Rating: on transformer 316-1877 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 206
% INFO    : Updated Thermal Rating: on transformer 316-1878 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 206
% INFO    : Updated Thermal Rating: on transformer 15-1678 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 467
% INFO    : Updated Thermal Rating: on transformer 16-1679 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 467
% INFO    : Updated Thermal Rating: on transformer 608-1680 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 307
% INFO    : Updated Thermal Rating: on transformer 338-1681 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1558
% INFO    : Updated Thermal Rating: on transformer 416-1881 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 130
% INFO    : Updated Thermal Rating: on transformer 416-1882 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 130
% INFO    : Updated Thermal Rating: on transformer 416-1685 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 130
% INFO    : Updated Thermal Rating: on transformer 416-1883 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 130
% INFO    : Updated Thermal Rating: on transformer 416-1884 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 130
% INFO    : Updated Thermal Rating: on transformer 416-1885 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 130
% INFO    : Updated Thermal Rating: on transformer 384-1689 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2512
% INFO    : Updated Thermal Rating: on transformer 392-1888 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 173
% INFO    : Updated Thermal Rating: on transformer 400-1691 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 113
% INFO    : Updated Thermal Rating: on transformer 437-1693 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 396
% INFO    : Updated Thermal Rating: on transformer 438-1694 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 396
% INFO    : Updated Thermal Rating: on transformer 438-1695 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 626
% INFO    : Updated Thermal Rating: on transformer 437-1696 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 626
% INFO    : Updated Thermal Rating: on transformer 452-1697 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2485
% INFO    : Updated Thermal Rating: on transformer 451-1698 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2485
% INFO    : Updated Thermal Rating: on transformer 453-1699 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 2485
% INFO    : Updated Thermal Rating: on transformer 466-1701 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 91
% INFO    : Updated Thermal Rating: on transformer 503-1702 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 118
% INFO    : Updated Thermal Rating: on transformer 502-1703 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 118
% INFO    : Updated Thermal Rating: on transformer 501-1889 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 118
% INFO    : Updated Thermal Rating: on transformer 538-1890 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 62
% INFO    : Updated Thermal Rating: on transformer 539-1891 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 62
% INFO    : Updated Thermal Rating: on transformer 540-1892 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 62
% INFO    : Updated Thermal Rating: on transformer 541-1706 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 62
% INFO    : Updated Thermal Rating: on transformer 565-1707 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 66
% INFO    : Updated Thermal Rating: on transformer 563-2026 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 66
% INFO    : Updated Thermal Rating: on transformer 562-1898 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 66
% INFO    : Updated Thermal Rating: on transformer 561-1708 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 66
% INFO    : Updated Thermal Rating: on transformer 564-1709 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 66
% INFO    : Updated Thermal Rating: on transformer 567-1710 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 79
% INFO    : Updated Thermal Rating: on transformer 567-1711 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 79
% INFO    : Updated Thermal Rating: on transformer 615-1721 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 747
% INFO    : Updated Thermal Rating: on transformer 1343-1906 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 386
% INFO    : Updated Thermal Rating: on transformer 1343-1907 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 386
% INFO    : Updated Thermal Rating: on transformer 1343-1908 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 386
% INFO    : Updated Thermal Rating: on transformer 1343-1909 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 386
% INFO    : Updated Thermal Rating: on transformer 1343-1910 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 386
% INFO    : Updated Thermal Rating: on transformer 1343-1911 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 386
% INFO    : Updated Thermal Rating: on transformer 1343-1912 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 386
% INFO    : Updated Thermal Rating: on transformer 1343-1913 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 386
% INFO    : Updated Thermal Rating: on transformer 638-1723 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 683
% INFO    : Updated Thermal Rating: on transformer 637-1724 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1518
% INFO    : Updated Thermal Rating: on transformer 683-1919 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 104
% INFO    : Updated Thermal Rating: on transformer 684-1920 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 104
% INFO    : Updated Thermal Rating: on transformer 681-1921 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 104
% INFO    : Updated Thermal Rating: on transformer 682-1922 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 104
% INFO    : Updated Thermal Rating: on transformer 686-1923 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 96
% INFO    : Updated Thermal Rating: on transformer 685-1924 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 95
% INFO    : Updated Thermal Rating: on transformer 752-1726 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 101
% INFO    : Updated Thermal Rating: on transformer 752-1727 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 101
% INFO    : Updated Thermal Rating: on transformer 752-1728 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 101
% INFO    : Updated Thermal Rating: on transformer 752-1928 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 101
% INFO    : Updated Thermal Rating: on transformer 744-1729 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 637
% INFO    : Updated Thermal Rating: on transformer 760-1931 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 262
% INFO    : Updated Thermal Rating: on transformer 760-1932 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 184
% INFO    : Updated Thermal Rating: on transformer 760-1934 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 262
% INFO    : Updated Thermal Rating: on transformer 762-1935 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 96
% INFO    : Updated Thermal Rating: on transformer 762-1936 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 96
% INFO    : Updated Thermal Rating: on transformer 762-1937 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 96
% INFO    : Updated Thermal Rating: on transformer 768-1938 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 174
% INFO    : Updated Thermal Rating: on transformer 796-1730 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 688
% INFO    : Updated Thermal Rating: on transformer 797-1731 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 688
% INFO    : Updated Thermal Rating: on transformer 809-1944 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 66
% INFO    : Updated Thermal Rating: on transformer 107-1732 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 968
% INFO    : Updated Thermal Rating: on transformer 861-1733 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 595
% INFO    : Updated Thermal Rating: on transformer 860-1734 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 595
% INFO    : Updated Thermal Rating: on transformer 880-1737 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 107
% INFO    : Updated Thermal Rating: on transformer 877-1738 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 107
% INFO    : Updated Thermal Rating: on transformer 878-1739 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 107
% INFO    : Updated Thermal Rating: on transformer 889-1741 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 920
% INFO    : Updated Thermal Rating: on transformer 918-1958 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 218
% INFO    : Updated Thermal Rating: on transformer 918-1959 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 218
% INFO    : Updated Thermal Rating: on transformer 928-1743 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 110
% INFO    : Updated Thermal Rating: on transformer 943-1747 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 81
% INFO    : Updated Thermal Rating: on transformer 968-1750 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1475
% INFO    : Updated Thermal Rating: on transformer 970-1751 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1475
% INFO    : Updated Thermal Rating: on transformer 969-1752 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1475
% INFO    : Updated Thermal Rating: on transformer 971-1753 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 1605
% INFO    : Updated Thermal Rating: on transformer 974-2058 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 99
% INFO    : Updated Thermal Rating: on transformer 1010-1756 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 43
% INFO    : Updated Thermal Rating: on transformer 1047-1758 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 203
% INFO    : Updated Thermal Rating: on transformer 1046-1759 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 203
% INFO    : Updated Thermal Rating: on transformer 1045-1760 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 203
% INFO    : Updated Thermal Rating: on transformer 1048-1970 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 98
% INFO    : Updated Thermal Rating: on transformer 1048-1971 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 98
% INFO    : Updated Thermal Rating: on transformer 1048-1972 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 98
% INFO    : Updated Thermal Rating: on transformer 1048-1973 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 98
% INFO    : Updated Thermal Rating: on transformer 1075-1974 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 412
% INFO    : Updated Thermal Rating: on transformer 1076-1975 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 529
% INFO    : Updated Thermal Rating: on transformer 1077-1976 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 412
% INFO    : Updated Thermal Rating: on transformer 1078-1977 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 412
% INFO    : Updated Thermal Rating: on transformer 1085-1761 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 111
% INFO    : Updated Thermal Rating: on transformer 1083-1762 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 111
% INFO    : Updated Thermal Rating: on transformer 1084-1978 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 111
% INFO    : Updated Thermal Rating: on transformer 1138-1769 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 121
% INFO    : Updated Thermal Rating: on transformer 1138-1770 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 121
% INFO    : Updated Thermal Rating: on transformer 1141-1979 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 100
% INFO    : Updated Thermal Rating: on transformer 1142-1980 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 96
% INFO    : Updated Thermal Rating: on transformer 1159-1771 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 43
% INFO    : Updated Thermal Rating: on transformer 1184-1993 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 354
% INFO    : Updated Thermal Rating: on transformer 482-1773 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 869
% INFO    : Updated Thermal Rating: on transformer 480-1775 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 855
% INFO    : Updated Thermal Rating: on transformer 481-1776 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 862
% INFO    : Updated Thermal Rating: on transformer 1207-1996 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 129
% INFO    : Updated Thermal Rating: on transformer 1207-1997 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 129
% INFO    : Updated Thermal Rating: on transformer 1210-2000 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 212
% INFO    : Updated Thermal Rating: on transformer 1217-1779 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 158
% INFO    : Updated Thermal Rating: on transformer 1217-2002 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 158
% INFO    : Updated Thermal Rating: on transformer 1247-1780 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 77
% INFO    : Updated Thermal Rating: on transformer 1250-2028 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 77
% INFO    : Updated Thermal Rating: on transformer 1249-1781 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 77
% INFO    : Updated Thermal Rating: on transformer 1248-1782 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 77
% INFO    : Updated Thermal Rating: on transformer 1254-2004 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 344
% INFO    : Updated Thermal Rating: on transformer 1254-2023 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 344
% INFO    : Updated Thermal Rating: on transformer 1254-2024 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 344
% INFO    : Updated Thermal Rating: on transformer 1254-2005 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 344
% INFO    : Updated Thermal Rating: on transformer 1333-1787 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 607
% INFO    : Updated Thermal Rating: on transformer 1333-1788 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 607
% INFO    : Updated Thermal Rating: on transformer 1332-1789 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 607
% INFO    : Updated Thermal Rating: on transformer 1379-1790 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 683
% INFO    : Updated Thermal Rating: on transformer 1378-1791 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 683
% INFO    : Updated Thermal Rating: on transformer 1400-1792 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 99
% INFO    : Updated Thermal Rating: on transformer 1399-2011 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 99
% INFO    : Updated Thermal Rating: on transformer 1398-2012 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 99
% INFO    : Updated Thermal Rating: on transformer 1407-1793 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 209
% INFO    : Updated Thermal Rating: on transformer 1407-1794 : Rate A, Rate B, Rate C , 0.0, 0.0, 0.0 -> 209
% INFO    : 
% INFO    : === Line Capacity Monotonicity Notes ===
% INFO    : 
% INFO    : === Voltage Setpoint Replacement Notes ===
% INFO    : Bus 1	: V=1.03149333, theta=-43.4924134 -> V=0.9888895, theta=0.0
% INFO    : Bus 2	: V=1.05203485, theta=-1.69989632 -> V=1.07552, theta=0.0
% INFO    : Bus 3	: V=1.0448381, theta=-18.2673882 -> V=1.04444, theta=0.0
% INFO    : Bus 4	: V=1.06460516, theta=-20.5923155 -> V=1.003335, theta=0.0
% INFO    : Bus 5	: V=1.06160466, theta=-24.974129 -> V=1.0111115, theta=0.0
% INFO    : Bus 6	: V=1.06056279, theta=-25.2851419 -> V=1.0111115, theta=0.0
% INFO    : Bus 7	: V=1.05380777, theta=-21.4555758 -> V=1.072365, theta=0.0
% INFO    : Bus 8	: V=1.05708339, theta=-22.5908652 -> V=1.072365, theta=0.0
% INFO    : Bus 9	: V=1.04785952, theta=-36.52218 -> V=1.047395, theta=0.0
% INFO    : Bus 10	: V=1.04436458, theta=-29.2139973 -> V=1.0111115, theta=0.0
% INFO    : Bus 11	: V=1.04319498, theta=-40.8700924 -> V=1.046665, theta=0.0
% INFO    : Bus 12	: V=1.02281295, theta=-40.3898303 -> V=1.046665, theta=0.0
% INFO    : Bus 13	: V=1.04317979, theta=-40.8672304 -> V=1.046665, theta=0.0
% INFO    : Bus 14	: V=1.02894304, theta=-42.5999043 -> V=1.01626, theta=0.0
% INFO    : Bus 15	: V=1.05264309, theta=-32.8339736 -> V=1.046665, theta=0.0
% INFO    : Bus 16	: V=1.05264349, theta=-32.8339765 -> V=1.046665, theta=0.0
% INFO    : Bus 17	: V=1.02901493, theta=-42.627265 -> V=0.9888895, theta=0.0
% INFO    : Bus 18	: V=1.03827721, theta=-34.821698 -> V=1.0414985, theta=0.0
% INFO    : Bus 19	: V=1.03589153, theta=-40.9750755 -> V=1.046665, theta=0.0
% INFO    : Bus 20	: V=1.03591814, theta=-40.9727768 -> V=1.046665, theta=0.0
% INFO    : Bus 21	: V=1.04563856, theta=-37.729861 -> V=1.046665, theta=0.0
% INFO    : Bus 22	: V=1.04526149, theta=-38.013764 -> V=1.0377785, theta=0.0
% INFO    : Bus 23	: V=1.02132076, theta=-46.8550416 -> V=0.9888895, theta=0.0
% INFO    : Bus 25	: V=1.05341127, theta=-16.9569828 -> V=1.046665, theta=0.0
% INFO    : Bus 27	: V=1.02093389, theta=-19.8876317 -> V=1.0111115, theta=0.0
% INFO    : Bus 28	: V=1.03730024, theta=-35.8773947 -> V=1.046665, theta=0.0
% INFO    : Bus 29	: V=1.05200172, theta=-1.68628576 -> V=1.07684, theta=0.0
% INFO    : Bus 30	: V=1.05203048, theta=-1.66991411 -> V=1.07684, theta=0.0
% INFO    : Bus 31	: V=1.04882932, theta=-5.02836666 -> V=1.046665, theta=0.0
% INFO    : Bus 33	: V=1.03238586, theta=-5.81622313 -> V=1.046665, theta=0.0
% INFO    : Bus 34	: V=1.04308498, theta=-40.784603 -> V=1.046665, theta=0.0
% INFO    : Bus 35	: V=1.02288941, theta=-21.6110255 -> V=1.0233335, theta=0.0
% INFO    : Bus 36	: V=1.06155485, theta=-30.7719291 -> V=1.04606, theta=0.0
% INFO    : Bus 37	: V=1.06914917, theta=-28.3384744 -> V=1.076555, theta=0.0
% INFO    : Bus 38	: V=1.04384914, theta=-38.1605038 -> V=1.0377785, theta=0.0
% INFO    : Bus 2050	: V=1.02504482, theta=-43.1806456 -> V=1.15, theta=0.0
% INFO    : Bus 39	: V=1.0289438, theta=-42.3593003 -> V=1.0288895, theta=0.0
% INFO    : Bus 40	: V=1.03444741, theta=-38.8153203 -> V=1.05263, theta=0.0
% INFO    : Bus 41	: V=1.04164115, theta=-27.3301536 -> V=1.0111115, theta=0.0
% INFO    : Bus 42	: V=1.02663818, theta=-46.6229704 -> V=0.9888895, theta=0.0
% INFO    : Bus 43	: V=1.0264638, theta=-46.6671033 -> V=0.9888895, theta=0.0
% INFO    : Bus 44	: V=1.05486257, theta=-26.1320802 -> V=1.0447, theta=0.0
% INFO    : Bus 45	: V=1.04812576, theta=-38.9307223 -> V=1.046665, theta=0.0
% INFO    : Bus 46	: V=1.038, theta=-7.667229 -> V=1.004215, theta=0.0
% INFO    : Bus 47	: V=1.0263661, theta=-41.311783 -> V=1.046665, theta=0.0
% INFO    : Bus 48	: V=1.02636589, theta=-41.3117818 -> V=1.046665, theta=0.0
% INFO    : Bus 49	: V=1.02636466, theta=-41.3117749 -> V=1.046665, theta=0.0
% INFO    : Bus 50	: V=1.03638741, theta=-36.2197213 -> V=1.046665, theta=0.0
% INFO    : Bus 51	: V=1.05188712, theta=-17.4043224 -> V=1.044445, theta=0.0
% INFO    : Bus 52	: V=1.01896671, theta=-46.9184464 -> V=0.9888895, theta=0.0
% INFO    : Bus 53	: V=1.01034096, theta=-45.5670543 -> V=1.0288895, theta=0.0
% INFO    : Bus 54	: V=1.01362701, theta=-43.3936365 -> V=1.05263, theta=0.0
% INFO    : Bus 55	: V=1.02696752, theta=-5.12919002 -> V=1.046665, theta=0.0
% INFO    : Bus 56	: V=1.0271573, theta=-5.13060801 -> V=1.046665, theta=0.0
% INFO    : Bus 1827	: V=1.04260248, theta=-34.6579535 -> V=1.046665, theta=0.0
% INFO    : Bus 57	: V=1.05354664, theta=-20.3612759 -> V=1.0113915, theta=0.0
% INFO    : Bus 58	: V=1.03648193, theta=-7.87858801 -> V=1.00431, theta=0.0
% INFO    : Bus 59	: V=1.02314002, theta=-2.05815662 -> V=1.046665, theta=0.0
% INFO    : Bus 60	: V=1.02296855, theta=-2.05607045 -> V=1.046665, theta=0.0
% INFO    : Bus 61	: V=1.02486847, theta=-2.91097833 -> V=1.033334, theta=0.0
% INFO    : Bus 62	: V=1.02838774, theta=-44.8442595 -> V=0.9888895, theta=0.0
% INFO    : Bus 63	: V=1.06744633, theta=-26.4263846 -> V=1.0111115, theta=0.0
% INFO    : Bus 64	: V=1.02235895, theta=-40.5268336 -> V=1.046665, theta=0.0
% INFO    : Bus 65	: V=1.04797022, theta=-36.5723751 -> V=1.046665, theta=0.0
% INFO    : Bus 66	: V=1.05467372, theta=-17.6792601 -> V=1.044445, theta=0.0
% INFO    : Bus 67	: V=1.03887262, theta=-32.7145163 -> V=1.0377785, theta=0.0
% INFO    : Bus 68	: V=1.02951107, theta=-46.2333151 -> V=0.9888895, theta=0.0
% INFO    : Bus 69	: V=1.02342882, theta=-46.4249539 -> V=0.9888895, theta=0.0
% INFO    : Bus 70	: V=1.0318011, theta=-44.4602666 -> V=1.05921, theta=0.0
% INFO    : Bus 71	: V=1.03661923, theta=-41.0915733 -> V=1.046665, theta=0.0
% INFO    : Bus 72	: V=1.03559998, theta=-40.0611412 -> V=1.046665, theta=0.0
% INFO    : Bus 73	: V=1.04335905, theta=-5.37629191 -> V=1.033334, theta=0.0
% INFO    : Bus 74	: V=1.0433684, theta=-5.3756094 -> V=1.033334, theta=0.0
% INFO    : Bus 75	: V=1.04166114, theta=-5.85761588 -> V=1.046665, theta=0.0
% INFO    : Bus 76	: V=1.05127602, theta=-21.5672592 -> V=1.04444, theta=0.0
% INFO    : Bus 77	: V=1.04792325, theta=-16.6550615 -> V=1.07237, theta=0.0
% INFO    : Bus 78	: V=1.05118552, theta=-21.616673 -> V=1.04444, theta=0.0
% INFO    : Bus 79	: V=1.02331098, theta=-40.2941188 -> V=1.0469, theta=0.0
% INFO    : Bus 80	: V=1.02331121, theta=-40.2982078 -> V=1.0469, theta=0.0
% INFO    : Bus 81	: V=1.03217693, theta=-41.4880591 -> V=0.9888895, theta=0.0
% INFO    : Bus 82	: V=1.02481856, theta=-45.0281473 -> V=1.01562, theta=0.0
% INFO    : Bus 83	: V=1.01752839, theta=-46.2166908 -> V=0.9888895, theta=0.0
% INFO    : Bus 84	: V=1.05114958, theta=-18.5175825 -> V=1.044445, theta=0.0
% INFO    : Bus 85	: V=1.02932206, theta=-16.3727754 -> V=1.044445, theta=0.0
% INFO    : Bus 86	: V=1.06749173, theta=-16.360036 -> V=1.07798, theta=0.0
% INFO    : Bus 87	: V=1.04562791, theta=-13.9985911 -> V=1.044445, theta=0.0
% INFO    : Bus 88	: V=1.05684667, theta=-17.6200243 -> V=1.044445, theta=0.0
% INFO    : Bus 89	: V=1.02, theta=-12.0782361 -> V=1.0, theta=0.0
% INFO    : Bus 90	: V=1.01562498, theta=-34.6787681 -> V=1.0377785, theta=0.0
% INFO    : Bus 91	: V=1.0442032, theta=-9.20439526 -> V=1.046665, theta=0.0
% INFO    : Bus 92	: V=1.04784091, theta=-30.3617823 -> V=1.073685, theta=0.0
% INFO    : Bus 93	: V=1.04819669, theta=-30.7872457 -> V=1.073685, theta=0.0
% INFO    : Bus 96	: V=1.05246647, theta=-18.3716113 -> V=1.044445, theta=0.0
% INFO    : Bus 97	: V=1.05271498, theta=-34.1174229 -> V=1.046665, theta=0.0
% INFO    : Bus 98	: V=1.02595701, theta=-10.633136 -> V=1.0, theta=0.0
% INFO    : Bus 99	: V=1.05109262, theta=-20.0623153 -> V=1.044445, theta=0.0
% INFO    : Bus 100	: V=1.036, theta=-41.0134772 -> V=1.01647, theta=0.0
% INFO    : Bus 101	: V=1.06130462, theta=-25.0525845 -> V=1.0111115, theta=0.0
% INFO    : Bus 102	: V=1.05730728, theta=-22.5507174 -> V=1.072365, theta=0.0
% INFO    : Bus 103	: V=1.05390093, theta=-21.4221244 -> V=1.072365, theta=0.0
% INFO    : Bus 104	: V=1.04342734, theta=-40.8553116 -> V=1.046665, theta=0.0
% INFO    : Bus 1828	: V=1.03331865, theta=-42.0075156 -> V=1.046665, theta=0.0
% INFO    : Bus 105	: V=1.0153912, theta=-37.0396936 -> V=1.0377785, theta=0.0
% INFO    : Bus 106	: V=1.04327481, theta=-40.8636252 -> V=1.046665, theta=0.0
% INFO    : Bus 107	: V=1.03317069, theta=-24.414835 -> V=1.0111115, theta=0.0
% INFO    : Bus 108	: V=1.0448452, theta=-22.5790651 -> V=1.072365, theta=0.0
% INFO    : Bus 109	: V=1.05363596, theta=-16.874679 -> V=1.044445, theta=0.0
% INFO    : Bus 110	: V=1.04972999, theta=-38.4350145 -> V=1.04715, theta=0.0
% INFO    : Bus 111	: V=1.07047513, theta=-24.3641392 -> V=1.04806, theta=0.0
% INFO    : Bus 112	: V=1.036317, theta=-35.8006563 -> V=1.0377785, theta=0.0
% INFO    : Bus 113	: V=1.04783962, theta=-36.5197778 -> V=1.0474, theta=0.0
% INFO    : Bus 114	: V=1.01859218, theta=-46.9856319 -> V=1.006667, theta=0.0
% INFO    : Bus 115	: V=1.04478539, theta=-31.9620766 -> V=1.0414035, theta=0.0
% INFO    : Bus 117	: V=1.04949781, theta=-30.8376086 -> V=1.072365, theta=0.0
% INFO    : Bus 119	: V=1.02694981, theta=-29.5018375 -> V=1.04444, theta=0.0
% INFO    : Bus 2051	: V=1.00159779, theta=-16.1870396 -> V=1.1, theta=0.0
% INFO    : Bus 120	: V=1.05166038, theta=-15.901803 -> V=1.046665, theta=0.0
% INFO    : Bus 121	: V=1.04809244, theta=-13.5762141 -> V=1.06579, theta=0.0
% INFO    : Bus 122	: V=1.03371202, theta=-24.4313009 -> V=1.0111115, theta=0.0
% INFO    : Bus 123	: V=1.02448071, theta=-20.6158774 -> V=1.0111115, theta=0.0
% INFO    : Bus 124	: V=1.07264692, theta=-28.2815068 -> V=1.0000025, theta=0.0
% INFO    : Bus 125	: V=1.034, theta=-11.0182488 -> V=1.01238, theta=0.0
% INFO    : Bus 126	: V=1.05886575, theta=-9.67090844 -> V=1.04884, theta=0.0
% INFO    : Bus 127	: V=1.0534005, theta=-9.63558802 -> V=1.078945, theta=0.0
% INFO    : Bus 128	: V=1.05345569, theta=-9.63199227 -> V=1.078945, theta=0.0
% INFO    : Bus 129	: V=1.05346235, theta=-9.62850865 -> V=1.078945, theta=0.0
% INFO    : Bus 130	: V=1.05348025, theta=-9.64413157 -> V=1.078945, theta=0.0
% INFO    : Bus 131	: V=1.04463475, theta=-31.8804036 -> V=1.0415585, theta=0.0
% INFO    : Bus 132	: V=1.04466247, theta=-31.8527006 -> V=1.0415585, theta=0.0
% INFO    : Bus 133	: V=1.04943382, theta=-30.7682197 -> V=1.072365, theta=0.0
% INFO    : Bus 134	: V=1.02932303, theta=-43.7529806 -> V=1.0288895, theta=0.0
% INFO    : Bus 135	: V=1.05322278, theta=-16.9207932 -> V=1.046665, theta=0.0
% INFO    : Bus 136	: V=1.04793054, theta=-34.5469331 -> V=1.072365, theta=0.0
% INFO    : Bus 137	: V=1.04090791, theta=-18.3030267 -> V=1.0111115, theta=0.0
% INFO    : Bus 138	: V=1.0403026, theta=-14.6191905 -> V=1.072365, theta=0.0
% INFO    : Bus 140	: V=1.04785941, theta=-5.81393081 -> V=1.046665, theta=0.0
% INFO    : Bus 141	: V=1.04713663, theta=-5.59951129 -> V=1.046665, theta=0.0
% INFO    : Bus 142	: V=1.03825771, theta=-17.2895964 -> V=1.04444, theta=0.0
% INFO    : Bus 143	: V=1.04357747, theta=-18.7041615 -> V=1.0111115, theta=0.0
% INFO    : Bus 144	: V=1.04355185, theta=-18.7086771 -> V=1.0111115, theta=0.0
% INFO    : Bus 145	: V=1.04972043, theta=-38.4186184 -> V=1.04698, theta=0.0
% INFO    : Bus 146	: V=1.04889424, theta=-19.7144055 -> V=1.04739, theta=0.0
% INFO    : Bus 147	: V=1.04889232, theta=-19.7143836 -> V=1.04739, theta=0.0
% INFO    : Bus 148	: V=1.05119071, theta=-18.2332466 -> V=1.044445, theta=0.0
% INFO    : Bus 149	: V=1.05270739, theta=-34.0423111 -> V=1.046665, theta=0.0
% INFO    : Bus 150	: V=1.03628049, theta=-9.30143923 -> V=1.046665, theta=0.0
% INFO    : Bus 151	: V=1.05024615, theta=-19.0576322 -> V=1.044445, theta=0.0
% INFO    : Bus 152	: V=1.04381179, theta=-11.0161734 -> V=1.046665, theta=0.0
% INFO    : Bus 153	: V=1.04380088, theta=-11.0190648 -> V=1.046665, theta=0.0
% INFO    : Bus 154	: V=1.04306522, theta=-6.22228475 -> V=1.046665, theta=0.0
% INFO    : Bus 155	: V=1.04527756, theta=-4.86384421 -> V=1.06579, theta=0.0
% INFO    : Bus 156	: V=1.01779227, theta=-46.1312561 -> V=0.9888895, theta=0.0
% INFO    : Bus 157	: V=1.05885154, theta=-9.67076425 -> V=1.04883, theta=0.0
% INFO    : Bus 158	: V=1.05343984, theta=-9.71002957 -> V=1.078945, theta=0.0
% INFO    : Bus 159	: V=1.03810341, theta=-33.7186436 -> V=1.0377785, theta=0.0
% INFO    : Bus 160	: V=1.05228533, theta=-17.9863346 -> V=1.044445, theta=0.0
% INFO    : Bus 161	: V=1.05124322, theta=-33.8015412 -> V=1.04444, theta=0.0
% INFO    : Bus 162	: V=1.05124322, theta=-33.8015412 -> V=1.04444, theta=0.0
% INFO    : Bus 163	: V=1.05125059, theta=-33.8017381 -> V=1.04444, theta=0.0
% INFO    : Bus 164	: V=1.05124218, theta=-33.8015135 -> V=1.04444, theta=0.0
% INFO    : Bus 165	: V=1.02155415, theta=-19.8388855 -> V=1.0111115, theta=0.0
% INFO    : Bus 166	: V=1.02862428, theta=-28.96034 -> V=1.0377785, theta=0.0
% INFO    : Bus 2019	: V=0.961263558, theta=-20.2495099 -> V=1.15, theta=0.0
% INFO    : Bus 167	: V=1.04509756, theta=-19.645302 -> V=1.044705, theta=0.0
% INFO    : Bus 168	: V=1.04962397, theta=-15.8950978 -> V=1.078945, theta=0.0
% INFO    : Bus 169	: V=1.065, theta=-24.8986609 -> V=1.0, theta=0.0
% INFO    : Bus 170	: V=1.02141398, theta=-22.2635234 -> V=1.0233335, theta=0.0
% INFO    : Bus 171	: V=1.03619839, theta=-40.8869822 -> V=1.046665, theta=0.0
% INFO    : Bus 172	: V=1.03651623, theta=-40.8372725 -> V=1.046665, theta=0.0
% INFO    : Bus 173	: V=1.01494319, theta=-46.3423742 -> V=0.9888895, theta=0.0
% INFO    : Bus 181	: V=1.05024862, theta=-19.0356156 -> V=1.044445, theta=0.0
% INFO    : Bus 182	: V=1.03299656, theta=-36.3585668 -> V=1.0377785, theta=0.0
% INFO    : Bus 183	: V=1.04359513, theta=-13.9192469 -> V=1.072365, theta=0.0
% INFO    : Bus 184	: V=1.04013214, theta=-13.7300714 -> V=1.072365, theta=0.0
% INFO    : Bus 185	: V=1.04015033, theta=-13.7337203 -> V=1.072365, theta=0.0
% INFO    : Bus 186	: V=1.04358655, theta=-13.930155 -> V=1.072365, theta=0.0
% INFO    : Bus 187	: V=1.03151341, theta=-45.3907842 -> V=1.006667, theta=0.0
% INFO    : Bus 188	: V=1.04498229, theta=-37.598826 -> V=1.0377785, theta=0.0
% INFO    : Bus 189	: V=1.03675304, theta=-31.5354079 -> V=1.04444, theta=0.0
% INFO    : Bus 190	: V=1.04290358, theta=-25.4957831 -> V=1.07237, theta=0.0
% INFO    : Bus 191	: V=1.04296248, theta=-25.5006182 -> V=1.07237, theta=0.0
% INFO    : Bus 192	: V=1.03637178, theta=-41.2331636 -> V=1.046665, theta=0.0
% INFO    : Bus 193	: V=1.04649206, theta=-6.21730893 -> V=1.033334, theta=0.0
% INFO    : Bus 194	: V=1.04649206, theta=-6.21730893 -> V=1.033334, theta=0.0
% INFO    : Bus 195	: V=1.02847573, theta=-44.3382842 -> V=1.0288895, theta=0.0
% INFO    : Bus 196	: V=1.03410731, theta=-7.69153925 -> V=1.0111115, theta=0.0
% INFO    : Bus 197	: V=1.0330817, theta=-8.15990324 -> V=1.0111115, theta=0.0
% INFO    : Bus 198	: V=1.04150541, theta=-26.0654439 -> V=1.04444, theta=0.0
% INFO    : Bus 199	: V=1.05205842, theta=-21.9682498 -> V=1.04444, theta=0.0
% INFO    : Bus 200	: V=1.03755574, theta=-6.61250563 -> V=1.033334, theta=0.0
% INFO    : Bus 201	: V=1.04241006, theta=-24.9412088 -> V=1.04444, theta=0.0
% INFO    : Bus 202	: V=1.03201187, theta=-44.2344049 -> V=1.0200005, theta=0.0
% INFO    : Bus 203	: V=1.03608558, theta=-40.0215909 -> V=1.046665, theta=0.0
% INFO    : Bus 204	: V=1.04471086, theta=-37.5003512 -> V=1.0377785, theta=0.0
% INFO    : Bus 2086	: V=0.996621657, theta=-16.7356538 -> V=1.1, theta=0.0
% INFO    : Bus 205	: V=1.04509955, theta=-16.3140845 -> V=1.046665, theta=0.0
% INFO    : Bus 206	: V=1.04768569, theta=-14.4079203 -> V=1.06579, theta=0.0
% INFO    : Bus 207	: V=1.03612184, theta=-40.1303784 -> V=1.046665, theta=0.0
% INFO    : Bus 1829	: V=1.022, theta=-44.3479996 -> V=1.014295, theta=0.0
% INFO    : Bus 208	: V=1.02199257, theta=-44.347975 -> V=0.9888895, theta=0.0
% INFO    : Bus 209	: V=1.040209, theta=-25.1062979 -> V=1.04444, theta=0.0
% INFO    : Bus 210	: V=1.03764499, theta=-34.4201536 -> V=1.0408535, theta=0.0
% INFO    : Bus 211	: V=1.03244361, theta=-6.36536844 -> V=1.046665, theta=0.0
% INFO    : Bus 212	: V=1.03235576, theta=-5.82468192 -> V=1.046665, theta=0.0
% INFO    : Bus 213	: V=1.02998343, theta=-9.32815402 -> V=1.0111115, theta=0.0
% INFO    : Bus 215	: V=1.0455137, theta=-6.6625824 -> V=1.072365, theta=0.0
% INFO    : Bus 216	: V=1.04870156, theta=-26.3936087 -> V=1.072365, theta=0.0
% INFO    : Bus 217	: V=1.0321618, theta=-8.54492937 -> V=1.0111115, theta=0.0
% INFO    : Bus 218	: V=1.03122769, theta=-8.86545038 -> V=1.0111115, theta=0.0
% INFO    : Bus 219	: V=1.02304577, theta=-1.66151517 -> V=1.046665, theta=0.0
% INFO    : Bus 220	: V=1.02345648, theta=-1.60458457 -> V=1.046665, theta=0.0
% INFO    : Bus 221	: V=1.0328122, theta=-5.34348219 -> V=1.046665, theta=0.0
% INFO    : Bus 222	: V=1.03905929, theta=-29.8220598 -> V=1.046665, theta=0.0
% INFO    : Bus 223	: V=1.03243842, theta=-6.32262309 -> V=1.046665, theta=0.0
% INFO    : Bus 224	: V=1.0326978, theta=-6.27180555 -> V=1.046665, theta=0.0
% INFO    : Bus 225	: V=1.03365361, theta=-45.6380881 -> V=1.0266685, theta=0.0
% INFO    : Bus 1830	: V=1.06227711, theta=-32.2990554 -> V=1.04444, theta=0.0
% INFO    : Bus 226	: V=1.06019112, theta=-29.1311656 -> V=1.07237, theta=0.0
% INFO    : Bus 227	: V=1.06985336, theta=-23.9909785 -> V=1.048975, theta=0.0
% INFO    : Bus 228	: V=1.05888933, theta=-21.1295389 -> V=1.077725, theta=0.0
% INFO    : Bus 229	: V=1.03128404, theta=-44.4234727 -> V=1.0000005, theta=0.0
% INFO    : Bus 230	: V=1.03598896, theta=-41.4983577 -> V=1.05263, theta=0.0
% INFO    : Bus 231	: V=1.04342149, theta=-40.8569739 -> V=1.046665, theta=0.0
% INFO    : Bus 232	: V=1.03334873, theta=-42.0044442 -> V=1.046665, theta=0.0
% INFO    : Bus 233	: V=1.03969026, theta=-33.3605813 -> V=1.0377785, theta=0.0
% INFO    : Bus 234	: V=1.03973495, theta=-33.3441463 -> V=1.0377785, theta=0.0
% INFO    : Bus 235	: V=1.04502913, theta=-36.1330445 -> V=1.046665, theta=0.0
% INFO    : Bus 236	: V=1.04482471, theta=-36.1316076 -> V=1.046665, theta=0.0
% INFO    : Bus 237	: V=1.03627947, theta=-40.8611556 -> V=1.046665, theta=0.0
% INFO    : Bus 238	: V=1.03854671, theta=-40.7344138 -> V=1.046665, theta=0.0
% INFO    : Bus 239	: V=1.04517879, theta=-36.8237273 -> V=1.046665, theta=0.0
% INFO    : Bus 240	: V=1.04487739, theta=-36.849769 -> V=1.046665, theta=0.0
% INFO    : Bus 241	: V=1.011, theta=-8.63606974 -> V=1.0, theta=0.0
% INFO    : Bus 242	: V=1.06211368, theta=-9.34171973 -> V=1.0233335, theta=0.0
% INFO    : Bus 243	: V=1.04141458, theta=-26.5881218 -> V=1.076745, theta=0.0
% INFO    : Bus 244	: V=1.04587, theta=-29.9837591 -> V=1.077145, theta=0.0
% INFO    : Bus 245	: V=1.04399006, theta=-26.2253222 -> V=1.076055, theta=0.0
% INFO    : Bus 246	: V=1.04518775, theta=-26.2040558 -> V=1.07715, theta=0.0
% INFO    : Bus 247	: V=1.03576523, theta=-41.01896 -> V=1.046665, theta=0.0
% INFO    : Bus 2029	: V=0.962090008, theta=-18.575064 -> V=1.15, theta=0.0
% INFO    : Bus 2030	: V=0.961543601, theta=-18.5469847 -> V=1.15, theta=0.0
% INFO    : Bus 248	: V=1.04908958, theta=-18.3537025 -> V=1.044445, theta=0.0
% INFO    : Bus 249	: V=1.04958566, theta=-18.3533941 -> V=1.044445, theta=0.0
% INFO    : Bus 250	: V=1.06880941, theta=-16.8799529 -> V=1.077725, theta=0.0
% INFO    : Bus 251	: V=1.03018018, theta=-9.33152881 -> V=1.0111115, theta=0.0
% INFO    : Bus 252	: V=1.04534636, theta=-36.9717361 -> V=1.070315, theta=0.0
% INFO    : Bus 2025	: V=0.979749565, theta=-40.7185465 -> V=1.15, theta=0.0
% INFO    : Bus 2031	: V=0.947797056, theta=-39.9866808 -> V=1.15, theta=0.0
% INFO    : Bus 2032	: V=0.971365072, theta=-40.2282816 -> V=1.15, theta=0.0
% INFO    : Bus 2046	: V=0.974446559, theta=-40.325371 -> V=1.15, theta=0.0
% INFO    : Bus 253	: V=1.03549947, theta=-39.4321485 -> V=1.046665, theta=0.0
% INFO    : Bus 254	: V=1.03817794, theta=-39.5383002 -> V=1.046665, theta=0.0
% INFO    : Bus 255	: V=1.04391731, theta=-38.5088841 -> V=1.046665, theta=0.0
% INFO    : Bus 257	: V=1.04144071, theta=-36.4149746 -> V=1.073685, theta=0.0
% INFO    : Bus 258	: V=1.04121501, theta=-36.5497768 -> V=1.073685, theta=0.0
% INFO    : Bus 259	: V=1.03334453, theta=-41.2613005 -> V=1.0088895, theta=0.0
% INFO    : Bus 260	: V=1.04872496, theta=-26.403969 -> V=1.072365, theta=0.0
% INFO    : Bus 261	: V=1.03353507, theta=-24.2749314 -> V=1.04444, theta=0.0
% INFO    : Bus 262	: V=1.03105247, theta=-9.44469616 -> V=1.0111115, theta=0.0
% INFO    : Bus 263	: V=1.0418326, theta=-13.60069 -> V=1.072365, theta=0.0
% INFO    : Bus 267	: V=1.03992295, theta=-25.5854378 -> V=1.04444, theta=0.0
% INFO    : Bus 268	: V=1.04163969, theta=-22.2295096 -> V=1.07237, theta=0.0
% INFO    : Bus 269	: V=1.0416508, theta=-22.2260114 -> V=1.07237, theta=0.0
% INFO    : Bus 270	: V=1.029, theta=-36.8384186 -> V=1.00923, theta=0.0
% INFO    : Bus 271	: V=1.05003045, theta=-36.9444769 -> V=1.0377785, theta=0.0
% INFO    : Bus 272	: V=1.02448357, theta=-28.3951309 -> V=1.0377785, theta=0.0
% INFO    : Bus 273	: V=1.0518845, theta=-20.3121661 -> V=1.07237, theta=0.0
% INFO    : Bus 274	: V=1.04378103, theta=-35.4834477 -> V=1.0413885, theta=0.0
% INFO    : Bus 275	: V=1.05240488, theta=-35.0903477 -> V=1.046665, theta=0.0
% INFO    : Bus 276	: V=1.02644109, theta=-41.4026087 -> V=1.046665, theta=0.0
% INFO    : Bus 278	: V=1.059863, theta=-16.5753836 -> V=1.15, theta=0.0
% INFO    : Bus 279	: V=1.04956335, theta=-16.0894758 -> V=1.0111115, theta=0.0
% INFO    : Bus 280	: V=1.0415378, theta=-13.8280978 -> V=1.072365, theta=0.0
% INFO    : Bus 281	: V=1.04319165, theta=-20.3477053 -> V=1.044795, theta=0.0
% INFO    : Bus 282	: V=1.04531825, theta=-19.6480062 -> V=1.044795, theta=0.0
% INFO    : Bus 283	: V=1.01711853, theta=-12.4807509 -> V=1.0233335, theta=0.0
% INFO    : Bus 284	: V=1.04694781, theta=-36.3981629 -> V=1.046665, theta=0.0
% INFO    : Bus 285	: V=1.0361855, theta=-36.6002762 -> V=1.046665, theta=0.0
% INFO    : Bus 286	: V=1.05334501, theta=-27.4970562 -> V=1.0111115, theta=0.0
% INFO    : Bus 287	: V=1.03326134, theta=-28.7153834 -> V=1.04444, theta=0.0
% INFO    : Bus 288	: V=1.03326009, theta=-28.7151176 -> V=1.04444, theta=0.0
% INFO    : Bus 289	: V=1.03721054, theta=-35.9529232 -> V=1.046665, theta=0.0
% INFO    : Bus 2062	: V=0.975621056, theta=-35.478218 -> V=1.15, theta=0.0
% INFO    : Bus 290	: V=1.03489545, theta=-35.2050074 -> V=1.046665, theta=0.0
% INFO    : Bus 291	: V=1.04203567, theta=-33.7846573 -> V=1.073685, theta=0.0
% INFO    : Bus 292	: V=1.04220692, theta=-33.8119094 -> V=1.073685, theta=0.0
% INFO    : Bus 293	: V=1.0465199, theta=-32.7530966 -> V=1.073685, theta=0.0
% INFO    : Bus 294	: V=1.0421219, theta=-33.798288 -> V=1.073685, theta=0.0
% INFO    : Bus 295	: V=1.03329278, theta=-24.6286344 -> V=1.04444, theta=0.0
% INFO    : Bus 296	: V=1.03432942, theta=-41.1768755 -> V=1.05263, theta=0.0
% INFO    : Bus 297	: V=1.04778293, theta=-36.4793657 -> V=1.046665, theta=0.0
% INFO    : Bus 298	: V=1.02603449, theta=-41.465496 -> V=1.046665, theta=0.0
% INFO    : Bus 299	: V=1.05367914, theta=-19.2454162 -> V=1.072365, theta=0.0
% INFO    : Bus 300	: V=1.04781242, theta=-16.6079488 -> V=1.07237, theta=0.0
% INFO    : Bus 301	: V=1.04784951, theta=-16.6070391 -> V=1.07237, theta=0.0
% INFO    : Bus 302	: V=1.04785701, theta=-16.6070126 -> V=1.07237, theta=0.0
% INFO    : Bus 303	: V=1.04317401, theta=-24.9081175 -> V=1.04444, theta=0.0
% INFO    : Bus 304	: V=1.03655416, theta=-36.6604064 -> V=1.05809, theta=0.0
% INFO    : Bus 305	: V=1.03863778, theta=-37.1489609 -> V=1.058515, theta=0.0
% INFO    : Bus 306	: V=1.02763374, theta=-42.8375011 -> V=0.9888895, theta=0.0
% INFO    : Bus 2047	: V=0.970198803, theta=-36.2179767 -> V=1.15, theta=0.0
% INFO    : Bus 307	: V=1.03766192, theta=-35.4829185 -> V=1.046665, theta=0.0
% INFO    : Bus 308	: V=1.04149179, theta=-32.5924807 -> V=1.073685, theta=0.0
% INFO    : Bus 309	: V=1.05917325, theta=-18.3898455 -> V=1.047225, theta=0.0
% INFO    : Bus 310	: V=1.04203267, theta=-9.39432884 -> V=1.07237, theta=0.0
% INFO    : Bus 311	: V=1.04203556, theta=-9.42009383 -> V=1.07237, theta=0.0
% INFO    : Bus 312	: V=1.03652957, theta=-28.2486869 -> V=1.0111415, theta=0.0
% INFO    : Bus 313	: V=1.05266157, theta=-35.194054 -> V=1.046665, theta=0.0
% INFO    : Bus 314	: V=1.01866308, theta=-46.8248646 -> V=0.9888895, theta=0.0
% INFO    : Bus 315	: V=1.01882246, theta=-46.8214928 -> V=0.9888895, theta=0.0
% INFO    : Bus 316	: V=1.07479932, theta=-23.3761869 -> V=1.072365, theta=0.0
% INFO    : Bus 317	: V=1.04538143, theta=-16.1108595 -> V=1.044445, theta=0.0
% INFO    : Bus 318	: V=1.0265199, theta=-41.3863846 -> V=1.046665, theta=0.0
% INFO    : Bus 319	: V=1.02238932, theta=-23.8739632 -> V=1.003335, theta=0.0
% INFO    : Bus 320	: V=1.04272735, theta=-32.0653693 -> V=1.0451, theta=0.0
% INFO    : Bus 321	: V=1.03602468, theta=-29.2882767 -> V=1.0377785, theta=0.0
% INFO    : Bus 323	: V=1.03377266, theta=-43.0116429 -> V=1.046665, theta=0.0
% INFO    : Bus 324	: V=1.0160028, theta=-26.6879276 -> V=1.0111115, theta=0.0
% INFO    : Bus 325	: V=1.05727485, theta=-34.1407275 -> V=1.04444, theta=0.0
% INFO    : Bus 326	: V=1.03273625, theta=-6.04807795 -> V=1.046665, theta=0.0
% INFO    : Bus 327	: V=1.06509742, theta=-22.6857321 -> V=1.15, theta=0.0
% INFO    : Bus 328	: V=1.04247167, theta=-16.5846321 -> V=1.0111115, theta=0.0
% INFO    : Bus 329	: V=1.05914763, theta=-25.6398355 -> V=1.0111115, theta=0.0
% INFO    : Bus 330	: V=1.04491106, theta=-36.8307039 -> V=1.046665, theta=0.0
% INFO    : Bus 331	: V=1.03724704, theta=-35.9666428 -> V=1.046665, theta=0.0
% INFO    : Bus 332	: V=1.03733167, theta=-35.9479392 -> V=1.046665, theta=0.0
% INFO    : Bus 333	: V=1.04957883, theta=-31.904571 -> V=1.046665, theta=0.0
% INFO    : Bus 2072	: V=1.04245117, theta=-30.9540462 -> V=1.046665, theta=0.0
% INFO    : Bus 334	: V=1.01766011, theta=-46.6337265 -> V=0.9888895, theta=0.0
% INFO    : Bus 335	: V=1.04546696, theta=-24.8086397 -> V=1.04444, theta=0.0
% INFO    : Bus 336	: V=1.03511799, theta=-22.3561288 -> V=1.04444, theta=0.0
% INFO    : Bus 337	: V=1.03534263, theta=-22.4024106 -> V=1.04444, theta=0.0
% INFO    : Bus 338	: V=1.03585737, theta=-22.5234722 -> V=1.04444, theta=0.0
% INFO    : Bus 339	: V=1.05372654, theta=-22.9444351 -> V=1.07237, theta=0.0
% INFO    : Bus 340	: V=1.04859447, theta=-15.3910857 -> V=1.0111115, theta=0.0
% INFO    : Bus 341	: V=1.02629092, theta=-41.429107 -> V=1.046665, theta=0.0
% INFO    : Bus 342	: V=1.04799131, theta=-36.5644797 -> V=1.046665, theta=0.0
% INFO    : Bus 343	: V=1.04294701, theta=-40.7269469 -> V=1.046665, theta=0.0
% INFO    : Bus 345	: V=1.04979203, theta=-27.8428585 -> V=1.0111115, theta=0.0
% INFO    : Bus 346	: V=1.04860582, theta=-28.3825174 -> V=1.0111115, theta=0.0
% INFO    : Bus 347	: V=1.04955147, theta=-25.3061732 -> V=1.072365, theta=0.0
% INFO    : Bus 348	: V=1.03584268, theta=-22.60962 -> V=1.04444, theta=0.0
% INFO    : Bus 350	: V=1.05381704, theta=-22.971569 -> V=1.07237, theta=0.0
% INFO    : Bus 351	: V=1.03355448, theta=-40.4794871 -> V=1.046665, theta=0.0
% INFO    : Bus 352	: V=1.03432572, theta=-40.4718281 -> V=1.046665, theta=0.0
% INFO    : Bus 353	: V=1.04081664, theta=-31.6534845 -> V=1.0386635, theta=0.0
% INFO    : Bus 354	: V=1.04517843, theta=-11.9987005 -> V=1.046665, theta=0.0
% INFO    : Bus 355	: V=1.05, theta=-15.1386729 -> V=1.0, theta=0.0
% INFO    : Bus 356	: V=1.047, theta=-16.31985 -> V=1.01705, theta=0.0
% INFO    : Bus 357	: V=1.05497496, theta=-1.08876209 -> V=1.078945, theta=0.0
% INFO    : Bus 358	: V=1.02743426, theta=-11.6070507 -> V=1.0111115, theta=0.0
% INFO    : Bus 359	: V=1.04421469, theta=-32.5802794 -> V=1.04531, theta=0.0
% INFO    : Bus 360	: V=1.04407181, theta=-16.0410153 -> V=1.0111115, theta=0.0
% INFO    : Bus 361	: V=1.04436675, theta=-16.0525428 -> V=1.0111115, theta=0.0
% INFO    : Bus 362	: V=1.043655, theta=-16.4109962 -> V=1.0111115, theta=0.0
% INFO    : Bus 363	: V=1.05137211, theta=-13.9490827 -> V=1.069965, theta=0.0
% INFO    : Bus 364	: V=1.03508623, theta=-33.1394779 -> V=1.0377785, theta=0.0
% INFO    : Bus 365	: V=1.02983545, theta=-31.3546099 -> V=1.0377785, theta=0.0
% INFO    : Bus 366	: V=0.982852259, theta=-27.7477783 -> V=1.0, theta=0.0
% INFO    : Bus 367	: V=1.02487426, theta=-46.806499 -> V=1.0111115, theta=0.0
% INFO    : Bus 2014	: V=1.01757231, theta=-34.3364133 -> V=1.15, theta=0.0
% INFO    : Bus 368	: V=1.02179864, theta=-34.1437191 -> V=1.0377785, theta=0.0
% INFO    : Bus 369	: V=1.05356851, theta=-33.0950859 -> V=1.072365, theta=0.0
% INFO    : Bus 370	: V=1.02609155, theta=-41.4558861 -> V=1.046665, theta=0.0
% INFO    : Bus 371	: V=1.04797281, theta=-36.5064028 -> V=1.046665, theta=0.0
% INFO    : Bus 372	: V=1.04390915, theta=-17.4195878 -> V=1.072365, theta=0.0
% INFO    : Bus 373	: V=1.03927192, theta=-16.7949422 -> V=1.072365, theta=0.0
% INFO    : Bus 374	: V=1.03587232, theta=-40.1561621 -> V=1.046665, theta=0.0
% INFO    : Bus 375	: V=1.03652509, theta=-41.2045261 -> V=1.046665, theta=0.0
% INFO    : Bus 376	: V=1.048279, theta=-5.99003845 -> V=1.046665, theta=0.0
% INFO    : Bus 377	: V=1.027206, theta=-47.2877336 -> V=0.9888895, theta=0.0
% INFO    : Bus 378	: V=1.03633919, theta=-18.5939885 -> V=1.0111115, theta=0.0
% INFO    : Bus 379	: V=1.05048395, theta=-17.6697897 -> V=1.044445, theta=0.0
% INFO    : Bus 380	: V=1.03863842, theta=-6.74047348 -> V=1.046665, theta=0.0
% INFO    : Bus 381	: V=1.055245, theta=-0.847767978 -> V=1.078945, theta=0.0
% INFO    : Bus 382	: V=1.05520842, theta=-0.844769322 -> V=1.078945, theta=0.0
% INFO    : Bus 383	: V=1.05528319, theta=-0.828404347 -> V=1.078945, theta=0.0
% INFO    : Bus 384	: V=1.05487113, theta=-1.09971239 -> V=1.078945, theta=0.0
% INFO    : Bus 385	: V=1.04884628, theta=-28.5701178 -> V=1.0111115, theta=0.0
% INFO    : Bus 386	: V=1.06154822, theta=-9.3564425 -> V=1.0233335, theta=0.0
% INFO    : Bus 387	: V=1.04034875, theta=-6.0693636 -> V=1.046665, theta=0.0
% INFO    : Bus 388	: V=1.05428654, theta=-16.2901534 -> V=1.044445, theta=0.0
% INFO    : Bus 390	: V=1.05431527, theta=-11.9941404 -> V=1.078945, theta=0.0
% INFO    : Bus 391	: V=1.03600472, theta=-40.8936165 -> V=0.9888895, theta=0.0
% INFO    : Bus 392	: V=1.03367158, theta=-11.3681521 -> V=1.046665, theta=0.0
% INFO    : Bus 393	: V=1.02659701, theta=-27.4549881 -> V=1.0377785, theta=0.0
% INFO    : Bus 394	: V=1.04297535, theta=-32.3253444 -> V=1.0409085, theta=0.0
% INFO    : Bus 395	: V=1.0436117, theta=-18.6913284 -> V=1.0111115, theta=0.0
% INFO    : Bus 396	: V=1.015, theta=-7.00067553 -> V=1.0, theta=0.0
% INFO    : Bus 397	: V=1.06171386, theta=-9.345379 -> V=1.0233335, theta=0.0
% INFO    : Bus 398	: V=1.03326681, theta=-28.7132659 -> V=1.04444, theta=0.0
% INFO    : Bus 399	: V=1.03581471, theta=-38.1581391 -> V=0.9989585, theta=0.0
% INFO    : Bus 400	: V=1.02365719, theta=-2.01285925 -> V=1.033334, theta=0.0
% INFO    : Bus 401	: V=1.02331198, theta=-1.71049309 -> V=1.033334, theta=0.0
% INFO    : Bus 402	: V=1.04277188, theta=-40.8988758 -> V=1.046665, theta=0.0
% INFO    : Bus 403	: V=1.03645414, theta=-41.0868708 -> V=1.046665, theta=0.0
% INFO    : Bus 404	: V=1.02126516, theta=-46.7037262 -> V=1.004445, theta=0.0
% INFO    : Bus 405	: V=1.03665096, theta=-36.1986631 -> V=1.046665, theta=0.0
% INFO    : Bus 406	: V=1.03345984, theta=-35.636685 -> V=1.046665, theta=0.0
% INFO    : Bus 407	: V=1.03620862, theta=-39.6930493 -> V=1.046665, theta=0.0
% INFO    : Bus 408	: V=1.04179822, theta=-18.5314134 -> V=1.0111115, theta=0.0
% INFO    : Bus 409	: V=1.05344603, theta=-27.0444609 -> V=1.044465, theta=0.0
% INFO    : Bus 410	: V=1.04800495, theta=-36.5412713 -> V=1.04736, theta=0.0
% INFO    : Bus 411	: V=1.04321874, theta=-32.0162934 -> V=1.0422685, theta=0.0
% INFO    : Bus 412	: V=1.04895316, theta=-16.7245822 -> V=1.046665, theta=0.0
% INFO    : Bus 413	: V=1.04320539, theta=-32.0295149 -> V=1.0422235, theta=0.0
% INFO    : Bus 414	: V=1.04136174, theta=-31.633125 -> V=1.0383035, theta=0.0
% INFO    : Bus 416	: V=1.04196835, theta=-6.23255181 -> V=1.046665, theta=0.0
% INFO    : Bus 418	: V=1.04979103, theta=-16.4313786 -> V=1.0111115, theta=0.0
% INFO    : Bus 419	: V=1.04173306, theta=-32.1865937 -> V=1.0377785, theta=0.0
% INFO    : Bus 420	: V=1.03800752, theta=-26.7145706 -> V=1.04444, theta=0.0
% INFO    : Bus 421	: V=1.04210967, theta=-27.3526155 -> V=1.07237, theta=0.0
% INFO    : Bus 422	: V=1.02767034, theta=-42.4357199 -> V=0.9977785, theta=0.0
% INFO    : Bus 423	: V=1.05641553, theta=-19.7748757 -> V=1.044445, theta=0.0
% INFO    : Bus 424	: V=1.05269937, theta=-34.9194366 -> V=1.046665, theta=0.0
% INFO    : Bus 425	: V=1.02346824, theta=-1.60478678 -> V=1.046665, theta=0.0
% INFO    : Bus 426	: V=1.03376004, theta=-45.6311977 -> V=1.0266685, theta=0.0
% INFO    : Bus 427	: V=1.01905074, theta=-46.779964 -> V=0.9888895, theta=0.0
% INFO    : Bus 428	: V=1.03868027, theta=-16.7726106 -> V=1.0111115, theta=0.0
% INFO    : Bus 429	: V=1.02234301, theta=-45.1731451 -> V=0.9888895, theta=0.0
% INFO    : Bus 430	: V=1.01523707, theta=-48.4747253 -> V=0.9888895, theta=0.0
% INFO    : Bus 431	: V=1.09635089, theta=-35.0510453 -> V=1.072365, theta=0.0
% INFO    : Bus 432	: V=1.02953042, theta=-36.8837636 -> V=1.0377785, theta=0.0
% INFO    : Bus 433	: V=1.00966365, theta=4.05903491 -> V=1.013331, theta=0.0
% INFO    : Bus 434	: V=1.04968848, theta=-32.8711477 -> V=1.04444, theta=0.0
% INFO    : Bus 435	: V=1.05036927, theta=-21.5838012 -> V=1.04444, theta=0.0
% INFO    : Bus 436	: V=1.050547, theta=-18.1877714 -> V=1.07237, theta=0.0
% INFO    : Bus 437	: V=1.02068687, theta=-45.0047771 -> V=1.0222245, theta=0.0
% INFO    : Bus 438	: V=1.02070102, theta=-44.8890289 -> V=1.0222245, theta=0.0
% INFO    : Bus 439	: V=1.04802884, theta=-33.741221 -> V=1.04444, theta=0.0
% INFO    : Bus 2020	: V=0.988936986, theta=-25.017837 -> V=1.0206375, theta=0.0
% INFO    : Bus 440	: V=1.04359527, theta=-24.792985 -> V=1.04444, theta=0.0
% INFO    : Bus 441	: V=1.05687243, theta=-23.7282292 -> V=1.07237, theta=0.0
% INFO    : Bus 442	: V=1.05500646, theta=-13.4403913 -> V=1.044445, theta=0.0
% INFO    : Bus 443	: V=1.05367707, theta=-8.09588103 -> V=1.078945, theta=0.0
% INFO    : Bus 444	: V=1.03986838, theta=-21.6449774 -> V=1.044445, theta=0.0
% INFO    : Bus 445	: V=1.03145209, theta=-24.747299 -> V=1.04444, theta=0.0
% INFO    : Bus 446	: V=1.02055061, theta=-46.7670739 -> V=0.9888895, theta=0.0
% INFO    : Bus 447	: V=1.03608377, theta=-40.0217375 -> V=1.046665, theta=0.0
% INFO    : Bus 448	: V=1.0389357, theta=-29.6893072 -> V=1.01761, theta=0.0
% INFO    : Bus 449	: V=1.02062545, theta=-46.2610822 -> V=0.9888895, theta=0.0
% INFO    : Bus 450	: V=1.02935431, theta=-5.32266249 -> V=1.046665, theta=0.0
% INFO    : Bus 451	: V=1.04290286, theta=-28.4352101 -> V=1.07237, theta=0.0
% INFO    : Bus 452	: V=1.04290286, theta=-28.4352101 -> V=1.07237, theta=0.0
% INFO    : Bus 453	: V=1.04290399, theta=-28.4337767 -> V=1.07237, theta=0.0
% INFO    : Bus 454	: V=1.04290679, theta=-28.4300696 -> V=1.07237, theta=0.0
% INFO    : Bus 455	: V=1.04639089, theta=-16.5159116 -> V=1.046665, theta=0.0
% INFO    : Bus 456	: V=1.0359785, theta=-15.3883318 -> V=1.0111115, theta=0.0
% INFO    : Bus 458	: V=1.03855916, theta=-11.2765357 -> V=1.072365, theta=0.0
% INFO    : Bus 459	: V=1.01057241, theta=-46.0951056 -> V=1.0288895, theta=0.0
% INFO    : Bus 460	: V=1.0102918, theta=4.02426311 -> V=1.013331, theta=0.0
% INFO    : Bus 2033	: V=0.99652532, theta=-21.3019168 -> V=0.993299, theta=0.0
% INFO    : Bus 461	: V=1.04966417, theta=-20.0573931 -> V=1.04444, theta=0.0
% INFO    : Bus 462	: V=1.04542697, theta=-15.3572386 -> V=1.07237, theta=0.0
% INFO    : Bus 463	: V=1.04820268, theta=-38.6285051 -> V=1.046665, theta=0.0
% INFO    : Bus 464	: V=1.04898177, theta=-38.4042582 -> V=1.046665, theta=0.0
% INFO    : Bus 465	: V=1.03996427, theta=-29.4230567 -> V=1.046665, theta=0.0
% INFO    : Bus 466	: V=1.04224869, theta=-19.7864484 -> V=1.044445, theta=0.0
% INFO    : Bus 467	: V=1.046385, theta=-10.6872073 -> V=1.0233335, theta=0.0
% INFO    : Bus 468	: V=1.01486629, theta=-26.8076581 -> V=1.0111115, theta=0.0
% INFO    : Bus 469	: V=1.02906771, theta=-46.3072966 -> V=0.9888895, theta=0.0
% INFO    : Bus 470	: V=1.02926832, theta=-46.2808051 -> V=0.9888895, theta=0.0
% INFO    : Bus 471	: V=1.037, theta=-36.3223153 -> V=1.017105, theta=0.0
% INFO    : Bus 472	: V=1.02580626, theta=-41.5163693 -> V=1.046665, theta=0.0
% INFO    : Bus 473	: V=1.04253595, theta=-11.4944534 -> V=1.046665, theta=0.0
% INFO    : Bus 474	: V=1.036, theta=-27.3079248 -> V=1.015335, theta=0.0
% INFO    : Bus 475	: V=1.02247424, theta=-45.9803907 -> V=0.9888895, theta=0.0
% INFO    : Bus 1832	: V=1.02192092, theta=-45.9629308 -> V=0.9888895, theta=0.0
% INFO    : Bus 476	: V=1.04283967, theta=-38.0012639 -> V=1.0377785, theta=0.0
% INFO    : Bus 477	: V=1.04444664, theta=-37.9076465 -> V=1.0377785, theta=0.0
% INFO    : Bus 478	: V=1.04262529, theta=-16.5637298 -> V=1.0111115, theta=0.0
% INFO    : Bus 479	: V=1.03258701, theta=-6.28188244 -> V=1.046665, theta=0.0
% INFO    : Bus 480	: V=1.04809044, theta=-29.4945797 -> V=1.074695, theta=0.0
% INFO    : Bus 481	: V=1.04801381, theta=-29.4997932 -> V=1.074695, theta=0.0
% INFO    : Bus 482	: V=1.04480067, theta=-32.9469775 -> V=1.0422835, theta=0.0
% INFO    : Bus 483	: V=1.0448284, theta=-32.9438399 -> V=1.0422835, theta=0.0
% INFO    : Bus 484	: V=1.02621162, theta=-41.4404746 -> V=1.046665, theta=0.0
% INFO    : Bus 485	: V=1.03369172, theta=-41.8792134 -> V=1.045235, theta=0.0
% INFO    : Bus 486	: V=1.03365255, theta=-41.8803242 -> V=1.045235, theta=0.0
% INFO    : Bus 487	: V=1.03367158, theta=-41.8790149 -> V=1.045235, theta=0.0
% INFO    : Bus 488	: V=1.03365901, theta=-41.8799635 -> V=1.045235, theta=0.0
% INFO    : Bus 489	: V=1.03366723, theta=-41.875998 -> V=1.04525, theta=0.0
% INFO    : Bus 490	: V=1.02096753, theta=-46.0629486 -> V=1.015556, theta=0.0
% INFO    : Bus 491	: V=1.03376457, theta=-41.5646571 -> V=1.046665, theta=0.0
% INFO    : Bus 492	: V=1.0336102, theta=-41.570866 -> V=1.046665, theta=0.0
% INFO    : Bus 493	: V=1.05170306, theta=-21.0621529 -> V=1.04444, theta=0.0
% INFO    : Bus 494	: V=1.03740524, theta=-6.35117078 -> V=1.046665, theta=0.0
% INFO    : Bus 495	: V=1.04054464, theta=-22.0410247 -> V=1.044445, theta=0.0
% INFO    : Bus 496	: V=1.05213517, theta=-36.7021959 -> V=1.0377785, theta=0.0
% INFO    : Bus 497	: V=1.05213857, theta=-36.7022618 -> V=1.0377785, theta=0.0
% INFO    : Bus 498	: V=1.05350988, theta=-34.0912803 -> V=1.072365, theta=0.0
% INFO    : Bus 499	: V=1.05350292, theta=-34.088075 -> V=1.072365, theta=0.0
% INFO    : Bus 500	: V=1.05216836, theta=-36.7028373 -> V=1.0377785, theta=0.0
% INFO    : Bus 501	: V=1.05212896, theta=-36.6795275 -> V=1.0377785, theta=0.0
% INFO    : Bus 502	: V=1.05212896, theta=-36.6795275 -> V=1.0377785, theta=0.0
% INFO    : Bus 503	: V=1.05212896, theta=-36.6795275 -> V=1.0377785, theta=0.0
% INFO    : Bus 504	: V=1.02357715, theta=-2.03897669 -> V=1.046665, theta=0.0
% INFO    : Bus 506	: V=1.03067044, theta=-17.1810066 -> V=1.0111115, theta=0.0
% INFO    : Bus 507	: V=1.04458784, theta=-14.5140331 -> V=1.073685, theta=0.0
% INFO    : Bus 508	: V=1.04261438, theta=-17.5416189 -> V=1.073685, theta=0.0
% INFO    : Bus 509	: V=1.04269515, theta=-17.5418835 -> V=1.073685, theta=0.0
% INFO    : Bus 510	: V=1.04305134, theta=-14.4954857 -> V=1.073685, theta=0.0
% INFO    : Bus 511	: V=1.02684105, theta=-46.5942063 -> V=0.9888895, theta=0.0
% INFO    : Bus 512	: V=1.03588747, theta=-40.1535126 -> V=1.046665, theta=0.0
% INFO    : Bus 513	: V=1.04529866, theta=-21.3086809 -> V=1.04567, theta=0.0
% INFO    : Bus 515	: V=1.036294, theta=-31.0818478 -> V=1.046665, theta=0.0
% INFO    : Bus 516	: V=1.03348651, theta=-28.4813342 -> V=1.0111115, theta=0.0
% INFO    : Bus 517	: V=1.05135975, theta=-18.2046048 -> V=1.044445, theta=0.0
% INFO    : Bus 519	: V=1.04570084, theta=-15.6160778 -> V=1.044445, theta=0.0
% INFO    : Bus 520	: V=1.04302283, theta=-40.8832937 -> V=1.046665, theta=0.0
% INFO    : Bus 521	: V=1.04316854, theta=-40.8690899 -> V=1.046665, theta=0.0
% INFO    : Bus 522	: V=1.03585462, theta=-41.0436017 -> V=1.046665, theta=0.0
% INFO    : Bus 523	: V=1.03092244, theta=-25.2633268 -> V=1.0111115, theta=0.0
% INFO    : Bus 524	: V=1.01982736, theta=-41.1493982 -> V=1.046665, theta=0.0
% INFO    : Bus 525	: V=1.05304276, theta=-12.131351 -> V=1.044445, theta=0.0
% INFO    : Bus 526	: V=1.01770323, theta=-46.2082613 -> V=0.9888895, theta=0.0
% INFO    : Bus 527	: V=1.0285777, theta=-32.5434995 -> V=1.0377785, theta=0.0
% INFO    : Bus 528	: V=1.05385133, theta=-30.9616745 -> V=1.072365, theta=0.0
% INFO    : Bus 529	: V=1.04247021, theta=-14.6380642 -> V=1.046665, theta=0.0
% INFO    : Bus 530	: V=1.03679758, theta=-18.5663079 -> V=1.0111115, theta=0.0
% INFO    : Bus 531	: V=1.04168215, theta=-40.5337848 -> V=1.046665, theta=0.0
% INFO    : Bus 532	: V=1.04211383, theta=-40.4845684 -> V=1.046665, theta=0.0
% INFO    : Bus 533	: V=1.03188999, theta=-36.34869 -> V=1.0377785, theta=0.0
% INFO    : Bus 534	: V=1.05259702, theta=-32.8722075 -> V=1.046665, theta=0.0
% INFO    : Bus 535	: V=1.03685723, theta=-39.7512628 -> V=1.046665, theta=0.0
% INFO    : Bus 536	: V=1.02378587, theta=-40.069936 -> V=1.046665, theta=0.0
% INFO    : Bus 537	: V=1.0222077, theta=-40.5174428 -> V=1.046665, theta=0.0
% INFO    : Bus 538	: V=1.01530099, theta=-36.9572553 -> V=1.0377785, theta=0.0
% INFO    : Bus 539	: V=1.01530099, theta=-36.9572553 -> V=1.0377785, theta=0.0
% INFO    : Bus 540	: V=1.01530097, theta=-36.9572158 -> V=1.0377785, theta=0.0
% INFO    : Bus 541	: V=1.01529219, theta=-36.9519655 -> V=1.0377785, theta=0.0
% INFO    : Bus 542	: V=1.0153008, theta=-36.9604168 -> V=1.0377785, theta=0.0
% INFO    : Bus 544	: V=1.02988975, theta=-12.6954032 -> V=1.0111115, theta=0.0
% INFO    : Bus 545	: V=1.04894881, theta=-11.9070188 -> V=1.044445, theta=0.0
% INFO    : Bus 546	: V=1.03320037, theta=-29.648798 -> V=1.0377785, theta=0.0
% INFO    : Bus 547	: V=1.04528992, theta=-12.1831082 -> V=1.046665, theta=0.0
% INFO    : Bus 548	: V=1.04509524, theta=-36.8253721 -> V=1.046665, theta=0.0
% INFO    : Bus 549	: V=1.04027718, theta=-20.1452047 -> V=1.044445, theta=0.0
% INFO    : Bus 550	: V=1.04330855, theta=-28.724878 -> V=1.07237, theta=0.0
% INFO    : Bus 2021	: V=0.999878714, theta=-16.1231829 -> V=1.15, theta=0.0
% INFO    : Bus 551	: V=1.05387072, theta=-15.8846073 -> V=1.044445, theta=0.0
% INFO    : Bus 553	: V=1.06363872, theta=-13.9802364 -> V=1.078945, theta=0.0
% INFO    : Bus 554	: V=1.04301913, theta=-25.5184519 -> V=1.07237, theta=0.0
% INFO    : Bus 555	: V=1.0218647, theta=-45.9605252 -> V=1.015556, theta=0.0
% INFO    : Bus 556	: V=1.03238096, theta=-42.5833021 -> V=1.05263, theta=0.0
% INFO    : Bus 557	: V=1.049233, theta=-28.7073252 -> V=1.0111115, theta=0.0
% INFO    : Bus 558	: V=1.04257131, theta=-27.2170803 -> V=1.0111115, theta=0.0
% INFO    : Bus 559	: V=1.04693733, theta=-24.2048532 -> V=1.072365, theta=0.0
% INFO    : Bus 560	: V=1.02780257, theta=-36.2428099 -> V=1.0377785, theta=0.0
% INFO    : Bus 561	: V=1.02781947, theta=-36.2367379 -> V=1.0377785, theta=0.0
% INFO    : Bus 562	: V=1.02780255, theta=-36.2397249 -> V=1.0377785, theta=0.0
% INFO    : Bus 563	: V=1.02780255, theta=-36.2397249 -> V=1.0377785, theta=0.0
% INFO    : Bus 564	: V=1.02779851, theta=-36.2368965 -> V=1.0377785, theta=0.0
% INFO    : Bus 565	: V=1.02779851, theta=-36.2368965 -> V=1.0377785, theta=0.0
% INFO    : Bus 566	: V=1.02780196, theta=-36.2428099 -> V=1.0377785, theta=0.0
% INFO    : Bus 567	: V=1.03085243, theta=-8.98916705 -> V=1.0111115, theta=0.0
% INFO    : Bus 568	: V=1.03474756, theta=-31.6406285 -> V=1.04444, theta=0.0
% INFO    : Bus 569	: V=1.05687746, theta=-17.5590782 -> V=1.044445, theta=0.0
% INFO    : Bus 570	: V=1.03582709, theta=-15.7891755 -> V=1.0111115, theta=0.0
% INFO    : Bus 572	: V=1.02583642, theta=-41.5110959 -> V=1.046665, theta=0.0
% INFO    : Bus 573	: V=1.048068, theta=-36.5345053 -> V=1.046665, theta=0.0
% INFO    : Bus 574	: V=1.05048365, theta=-17.6697857 -> V=1.044445, theta=0.0
% INFO    : Bus 575	: V=1.03766662, theta=-37.2448326 -> V=1.0377785, theta=0.0
% INFO    : Bus 576	: V=1.05349008, theta=-7.89642283 -> V=1.078945, theta=0.0
% INFO    : Bus 577	: V=1.05347587, theta=-7.91234658 -> V=1.078945, theta=0.0
% INFO    : Bus 578	: V=1.05003515, theta=-15.1359894 -> V=1.04596, theta=0.0
% INFO    : Bus 579	: V=1.03793132, theta=-40.4500412 -> V=1.046665, theta=0.0
% INFO    : Bus 580	: V=1.05721888, theta=-17.9898247 -> V=1.04465, theta=0.0
% INFO    : Bus 581	: V=1.03550899, theta=-41.0005829 -> V=1.046665, theta=0.0
% INFO    : Bus 582	: V=1.03560333, theta=-9.15163824 -> V=1.01149, theta=0.0
% INFO    : Bus 583	: V=1.0229919, theta=-1.19581455 -> V=1.033334, theta=0.0
% INFO    : Bus 584	: V=1.02448633, theta=-36.8820016 -> V=1.0377785, theta=0.0
% INFO    : Bus 585	: V=1.04330627, theta=-16.0937876 -> V=1.044445, theta=0.0
% INFO    : Bus 586	: V=1.05325323, theta=-18.0641328 -> V=1.04444, theta=0.0
% INFO    : Bus 587	: V=1.05043183, theta=-14.076716 -> V=1.07237, theta=0.0
% INFO    : Bus 588	: V=1.02832285, theta=-42.3490115 -> V=1.05263, theta=0.0
% INFO    : Bus 589	: V=1.02814097, theta=-42.2748025 -> V=1.05263, theta=0.0
% INFO    : Bus 590	: V=1.0283479, theta=-42.2899711 -> V=1.05263, theta=0.0
% INFO    : Bus 591	: V=1.02783364, theta=-42.2553598 -> V=1.05263, theta=0.0
% INFO    : Bus 592	: V=1.02834634, theta=-42.2915513 -> V=1.05263, theta=0.0
% INFO    : Bus 593	: V=1.02834482, theta=-42.2887977 -> V=1.05263, theta=0.0
% INFO    : Bus 594	: V=1.03754014, theta=-15.4689285 -> V=1.0111115, theta=0.0
% INFO    : Bus 595	: V=1.0607009, theta=-24.4545903 -> V=1.002644, theta=0.0
% INFO    : Bus 596	: V=1.04162749, theta=-18.1661642 -> V=1.072365, theta=0.0
% INFO    : Bus 597	: V=1.04160151, theta=-18.0160638 -> V=1.072365, theta=0.0
% INFO    : Bus 598	: V=1.05073727, theta=-17.6185335 -> V=1.044445, theta=0.0
% INFO    : Bus 599	: V=1.03756931, theta=-36.1204331 -> V=1.046665, theta=0.0
% INFO    : Bus 600	: V=1.03739744, theta=-36.0547693 -> V=1.046665, theta=0.0
% INFO    : Bus 601	: V=1.0321568, theta=-12.8492657 -> V=1.046665, theta=0.0
% INFO    : Bus 2015	: V=0.977452063, theta=-28.2226303 -> V=1.15, theta=0.0
% INFO    : Bus 602	: V=1.02655198, theta=-27.4064212 -> V=1.0377785, theta=0.0
% INFO    : Bus 603	: V=1.0384528, theta=-23.8855968 -> V=1.072365, theta=0.0
% INFO    : Bus 604	: V=1.01521029, theta=-48.4653147 -> V=1.0000005, theta=0.0
% INFO    : Bus 605	: V=1.01689747, theta=-46.9040008 -> V=1.0000005, theta=0.0
% INFO    : Bus 606	: V=1.04018496, theta=-37.5958023 -> V=1.0377785, theta=0.0
% INFO    : Bus 607	: V=1.03690437, theta=-22.5448982 -> V=1.04444, theta=0.0
% INFO    : Bus 608	: V=1.02635042, theta=-41.3115962 -> V=1.046665, theta=0.0
% INFO    : Bus 609	: V=1.02939808, theta=-28.7935905 -> V=1.0377785, theta=0.0
% INFO    : Bus 610	: V=1.04936182, theta=-17.9474718 -> V=1.044445, theta=0.0
% INFO    : Bus 611	: V=1.03581333, theta=-15.7972565 -> V=1.0111115, theta=0.0
% INFO    : Bus 612	: V=1.03580933, theta=-15.7979134 -> V=1.0111115, theta=0.0
% INFO    : Bus 613	: V=1.03577552, theta=-15.7994558 -> V=1.0111115, theta=0.0
% INFO    : Bus 614	: V=1.03361557, theta=-45.6288726 -> V=1.0266685, theta=0.0
% INFO    : Bus 615	: V=1.0262278, theta=-45.5354158 -> V=1.022223, theta=0.0
% INFO    : Bus 616	: V=1.05917257, theta=-25.5504732 -> V=1.0111115, theta=0.0
% INFO    : Bus 617	: V=1.02217043, theta=-45.1587334 -> V=0.9888895, theta=0.0
% INFO    : Bus 618	: V=1.0104362, theta=-46.9518097 -> V=0.9888895, theta=0.0
% INFO    : Bus 619	: V=1.05289027, theta=-34.8871119 -> V=1.046665, theta=0.0
% INFO    : Bus 620	: V=1.03793998, theta=-26.6845736 -> V=1.04444, theta=0.0
% INFO    : Bus 621	: V=1.03797124, theta=-26.7288575 -> V=1.04444, theta=0.0
% INFO    : Bus 622	: V=1.03406802, theta=-20.0145976 -> V=1.0111115, theta=0.0
% INFO    : Bus 623	: V=1.05109821, theta=-19.3619942 -> V=1.072365, theta=0.0
% INFO    : Bus 624	: V=1.05365574, theta=-34.1153718 -> V=1.04681, theta=0.0
% INFO    : Bus 625	: V=1.03713981, theta=-22.3538584 -> V=1.04444, theta=0.0
% INFO    : Bus 626	: V=1.01774214, theta=-46.1936076 -> V=1.0288895, theta=0.0
% INFO    : Bus 627	: V=1.01327727, theta=-37.1032302 -> V=1.0377785, theta=0.0
% INFO    : Bus 628	: V=1.01289135, theta=-37.0975076 -> V=1.0377785, theta=0.0
% INFO    : Bus 629	: V=1.0357424, theta=-40.1806137 -> V=1.046665, theta=0.0
% INFO    : Bus 630	: V=1.02705402, theta=-47.3597641 -> V=0.9888895, theta=0.0
% INFO    : Bus 631	: V=1.02716067, theta=-47.3556112 -> V=0.9888895, theta=0.0
% INFO    : Bus 632	: V=1.04517193, theta=-36.803887 -> V=1.046665, theta=0.0
% INFO    : Bus 633	: V=1.05212955, theta=-32.5867964 -> V=1.046665, theta=0.0
% INFO    : Bus 635	: V=1.05075506, theta=-30.7172613 -> V=1.073685, theta=0.0
% INFO    : Bus 637	: V=1.05212675, theta=-32.5864911 -> V=1.046665, theta=0.0
% INFO    : Bus 638	: V=1.05212807, theta=-32.5752139 -> V=1.046665, theta=0.0
% INFO    : Bus 639	: V=1.0507602, theta=-30.7052292 -> V=1.073685, theta=0.0
% INFO    : Bus 640	: V=1.02774539, theta=-47.1857822 -> V=0.9888895, theta=0.0
% INFO    : Bus 641	: V=1.03946239, theta=-40.2269587 -> V=1.046665, theta=0.0
% INFO    : Bus 642	: V=1.03913857, theta=-40.1891256 -> V=1.046665, theta=0.0
% INFO    : Bus 643	: V=1.05590632, theta=-26.5460117 -> V=1.0111115, theta=0.0
% INFO    : Bus 644	: V=1.02313974, theta=-37.0257045 -> V=1.0377785, theta=0.0
% INFO    : Bus 645	: V=1.03815177, theta=-39.7745098 -> V=1.07002, theta=0.0
% INFO    : Bus 646	: V=1.04739585, theta=-37.7047837 -> V=1.0377785, theta=0.0
% INFO    : Bus 647	: V=1.0139836, theta=-47.0953416 -> V=1.0288895, theta=0.0
% INFO    : Bus 648	: V=1.02473221, theta=-45.7372267 -> V=0.9888895, theta=0.0
% INFO    : Bus 649	: V=0.842829146, theta=-17.8235502 -> V=0.83, theta=0.0
% INFO    : Bus 650	: V=1.05352718, theta=-17.8231732 -> V=1.04581, theta=0.0
% INFO    : Bus 651	: V=1.05390464, theta=-32.6043831 -> V=1.072365, theta=0.0
% INFO    : Bus 652	: V=1.07124864, theta=-23.4141172 -> V=1.04775, theta=0.0
% INFO    : Bus 653	: V=1.04488548, theta=-12.4077103 -> V=1.046665, theta=0.0
% INFO    : Bus 654	: V=1.04378422, theta=-38.6651056 -> V=1.046665, theta=0.0
% INFO    : Bus 655	: V=1.05378323, theta=-34.0049319 -> V=1.046915, theta=0.0
% INFO    : Bus 656	: V=1.05162394, theta=-33.769739 -> V=1.046915, theta=0.0
% INFO    : Bus 657	: V=0.992736988, theta=-29.6044244 -> V=1.0, theta=0.0
% INFO    : Bus 658	: V=1.02960996, theta=-28.8786018 -> V=1.0377785, theta=0.0
% INFO    : Bus 659	: V=1.03823339, theta=-35.2018629 -> V=1.0400785, theta=0.0
% INFO    : Bus 660	: V=1.02725976, theta=-47.317955 -> V=1.006667, theta=0.0
% INFO    : Bus 662	: V=1.00942333, theta=3.85553785 -> V=1.013331, theta=0.0
% INFO    : Bus 663	: V=1.00965125, theta=3.76951332 -> V=1.013331, theta=0.0
% INFO    : Bus 664	: V=1.01636506, theta=-46.94344 -> V=0.9888895, theta=0.0
% INFO    : Bus 665	: V=1.06292165, theta=-14.2150175 -> V=1.078945, theta=0.0
% INFO    : Bus 666	: V=1.02030918, theta=-25.347664 -> V=1.0111115, theta=0.0
% INFO    : Bus 667	: V=1.0368886, theta=-28.1817475 -> V=1.0111115, theta=0.0
% INFO    : Bus 668	: V=1.0501009, theta=-37.5568032 -> V=1.0377785, theta=0.0
% INFO    : Bus 669	: V=1.0309525, theta=-17.1627308 -> V=1.0111115, theta=0.0
% INFO    : Bus 670	: V=1.05356696, theta=-19.5605006 -> V=1.044445, theta=0.0
% INFO    : Bus 671	: V=1.0450327, theta=-36.8137786 -> V=1.046665, theta=0.0
% INFO    : Bus 672	: V=1.04514363, theta=-36.8190979 -> V=1.046665, theta=0.0
% INFO    : Bus 673	: V=1.03800276, theta=-37.2459367 -> V=1.0377785, theta=0.0
% INFO    : Bus 674	: V=1.04598188, theta=-6.42267475 -> V=1.046665, theta=0.0
% INFO    : Bus 675	: V=1.05176126, theta=-2.06782892 -> V=1.07515, theta=0.0
% INFO    : Bus 676	: V=1.03607509, theta=-20.3006083 -> V=1.0111115, theta=0.0
% INFO    : Bus 677	: V=1.04570128, theta=-18.0379876 -> V=1.04444, theta=0.0
% INFO    : Bus 678	: V=1.05160757, theta=-16.8594428 -> V=1.07237, theta=0.0
% INFO    : Bus 679	: V=1.05165257, theta=-16.8384755 -> V=1.07237, theta=0.0
% INFO    : Bus 680	: V=1.02786429, theta=-8.37600129 -> V=1.00321, theta=0.0
% INFO    : Bus 681	: V=1.05055555, theta=-37.35378 -> V=1.0377785, theta=0.0
% INFO    : Bus 682	: V=1.05055555, theta=-37.35378 -> V=1.0377785, theta=0.0
% INFO    : Bus 683	: V=1.05054271, theta=-37.3450431 -> V=1.0377785, theta=0.0
% INFO    : Bus 684	: V=1.05053624, theta=-37.3425816 -> V=1.0377785, theta=0.0
% INFO    : Bus 685	: V=1.05055505, theta=-37.35378 -> V=1.0377785, theta=0.0
% INFO    : Bus 686	: V=1.05055525, theta=-37.353633 -> V=1.0377785, theta=0.0
% INFO    : Bus 687	: V=1.05055091, theta=-37.3567325 -> V=1.0377785, theta=0.0
% INFO    : Bus 690	: V=1.04828541, theta=-5.36048357 -> V=1.046665, theta=0.0
% INFO    : Bus 691	: V=1.0482846, theta=-5.3609073 -> V=1.046665, theta=0.0
% INFO    : Bus 692	: V=1.04308304, theta=-40.7944499 -> V=1.046665, theta=0.0
% INFO    : Bus 693	: V=1.04308123, theta=-40.7946971 -> V=1.046665, theta=0.0
% INFO    : Bus 694	: V=1.04471571, theta=-16.0015318 -> V=1.044445, theta=0.0
% INFO    : Bus 695	: V=1.0496682, theta=-32.9775117 -> V=1.04444, theta=0.0
% INFO    : Bus 696	: V=1.0491083, theta=-32.9126526 -> V=1.04444, theta=0.0
% INFO    : Bus 697	: V=1.03549533, theta=-36.0686001 -> V=1.0394235, theta=0.0
% INFO    : Bus 698	: V=1.03945418, theta=-34.7065317 -> V=1.0377785, theta=0.0
% INFO    : Bus 699	: V=1.03322332, theta=-40.337837 -> V=1.046665, theta=0.0
% INFO    : Bus 700	: V=1.02365868, theta=-39.781492 -> V=1.046665, theta=0.0
% INFO    : Bus 701	: V=1.0310751, theta=-10.9149385 -> V=1.005165, theta=0.0
% INFO    : Bus 702	: V=1.04940863, theta=-18.5486567 -> V=1.044445, theta=0.0
% INFO    : Bus 703	: V=1.04487459, theta=-36.8371682 -> V=1.046665, theta=0.0
% INFO    : Bus 704	: V=1.05193103, theta=-17.4048366 -> V=1.044445, theta=0.0
% INFO    : Bus 705	: V=1.05026735, theta=-19.3814449 -> V=1.07237, theta=0.0
% INFO    : Bus 707	: V=1.05, theta=-15.1331476 -> V=1.0, theta=0.0
% INFO    : Bus 708	: V=1.03558373, theta=-42.7679593 -> V=0.9888895, theta=0.0
% INFO    : Bus 1833	: V=1.03036692, theta=-43.4272403 -> V=0.9888895, theta=0.0
% INFO    : Bus 709	: V=1.03607862, theta=-40.9982062 -> V=1.05263, theta=0.0
% INFO    : Bus 710	: V=1.04526315, theta=-27.0708975 -> V=1.046665, theta=0.0
% INFO    : Bus 711	: V=1.05414117, theta=-22.4804009 -> V=1.073685, theta=0.0
% INFO    : Bus 712	: V=1.04315698, theta=-30.95075 -> V=1.046155, theta=0.0
% INFO    : Bus 713	: V=1.02460274, theta=-2.93958554 -> V=1.046665, theta=0.0
% INFO    : Bus 715	: V=1.05582234, theta=-18.0370109 -> V=1.044445, theta=0.0
% INFO    : Bus 716	: V=1.0750473, theta=-27.9611762 -> V=1.0000025, theta=0.0
% INFO    : Bus 717	: V=1.06741282, theta=-23.6477518 -> V=1.04551, theta=0.0
% INFO    : Bus 718	: V=1.058925, theta=-16.5386356 -> V=1.044445, theta=0.0
% INFO    : Bus 719	: V=1.05596632, theta=-12.6930742 -> V=1.078945, theta=0.0
% INFO    : Bus 720	: V=1.02042809, theta=-46.7751602 -> V=0.9888895, theta=0.0
% INFO    : Bus 721	: V=1.0204615, theta=-46.775363 -> V=0.9888895, theta=0.0
% INFO    : Bus 722	: V=1.02488395, theta=-46.8065819 -> V=0.9888895, theta=0.0
% INFO    : Bus 723	: V=1.0433497, theta=-40.8468828 -> V=1.046665, theta=0.0
% INFO    : Bus 724	: V=1.04332842, theta=-40.8484422 -> V=1.046665, theta=0.0
% INFO    : Bus 725	: V=1.0433253, theta=-40.848482 -> V=1.046665, theta=0.0
% INFO    : Bus 726	: V=1.03624037, theta=-36.0763623 -> V=1.046665, theta=0.0
% INFO    : Bus 727	: V=1.04444397, theta=-38.5091427 -> V=1.046665, theta=0.0
% INFO    : Bus 728	: V=1.02442771, theta=-25.6479859 -> V=1.0111115, theta=0.0
% INFO    : Bus 729	: V=1.00511383, theta=-13.6490679 -> V=1.0233335, theta=0.0
% INFO    : Bus 730	: V=1.04647355, theta=-16.4723173 -> V=1.046665, theta=0.0
% INFO    : Bus 731	: V=1.05216842, theta=-16.5296877 -> V=1.044445, theta=0.0
% INFO    : Bus 732	: V=1.04705279, theta=-37.136288 -> V=1.0377785, theta=0.0
% INFO    : Bus 733	: V=1.05170987, theta=-34.5022554 -> V=1.072365, theta=0.0
% INFO    : Bus 734	: V=1.0371678, theta=-35.8117803 -> V=1.046665, theta=0.0
% INFO    : Bus 735	: V=1.04507919, theta=-36.8679776 -> V=1.046665, theta=0.0
% INFO    : Bus 736	: V=1.02422206, theta=-24.4105438 -> V=1.003335, theta=0.0
% INFO    : Bus 737	: V=1.05590632, theta=-26.5460117 -> V=1.0111115, theta=0.0
% INFO    : Bus 738	: V=1.01267442, theta=-47.5008372 -> V=1.0288895, theta=0.0
% INFO    : Bus 739	: V=1.03802642, theta=-38.9605329 -> V=1.05263, theta=0.0
% INFO    : Bus 740	: V=1.05171254, theta=-33.5851379 -> V=1.04444, theta=0.0
% INFO    : Bus 741	: V=1.03567028, theta=-28.1008198 -> V=1.029894, theta=0.0
% INFO    : Bus 742	: V=1.05630527, theta=-23.6237149 -> V=1.07237, theta=0.0
% INFO    : Bus 743	: V=1.05565644, theta=-23.6195337 -> V=1.07237, theta=0.0
% INFO    : Bus 744	: V=1.02936674, theta=-28.3715331 -> V=1.0377785, theta=0.0
% INFO    : Bus 745	: V=1.03264027, theta=-41.442085 -> V=1.0288895, theta=0.0
% INFO    : Bus 746	: V=1.04912984, theta=-37.8134474 -> V=1.0377785, theta=0.0
% INFO    : Bus 747	: V=1.03306079, theta=-8.45198015 -> V=1.00405, theta=0.0
% INFO    : Bus 748	: V=1.03319316, theta=-8.4344664 -> V=1.00396, theta=0.0
% INFO    : Bus 750	: V=1.0339521, theta=-44.3818887 -> V=0.9888895, theta=0.0
% INFO    : Bus 751	: V=1.02150222, theta=-47.2882952 -> V=0.9888895, theta=0.0
% INFO    : Bus 752	: V=1.03862612, theta=-6.73991764 -> V=1.046665, theta=0.0
% INFO    : Bus 753	: V=1.03753278, theta=-8.3362287 -> V=1.016135, theta=0.0
% INFO    : Bus 754	: V=1.03057681, theta=-23.7538323 -> V=1.0377785, theta=0.0
% INFO    : Bus 755	: V=1.03477124, theta=-15.8598861 -> V=1.0111115, theta=0.0
% INFO    : Bus 756	: V=1.03581966, theta=-40.1732321 -> V=1.046665, theta=0.0
% INFO    : Bus 757	: V=1.03795017, theta=-31.7923442 -> V=1.0379635, theta=0.0
% INFO    : Bus 758	: V=1.02234779, theta=-40.4948426 -> V=1.046665, theta=0.0
% INFO    : Bus 759	: V=1.03633937, theta=-36.0346508 -> V=1.046665, theta=0.0
% INFO    : Bus 760	: V=1.06310933, theta=-25.1754259 -> V=1.0111115, theta=0.0
% INFO    : Bus 761	: V=1.02787612, theta=-25.713762 -> V=1.0111115, theta=0.0
% INFO    : Bus 762	: V=1.03329613, theta=-4.90221508 -> V=1.033334, theta=0.0
% INFO    : Bus 2052	: V=0.924426093, theta=-36.9521083 -> V=1.15, theta=0.0
% INFO    : Bus 763	: V=1.04548978, theta=-36.8902991 -> V=1.0377785, theta=0.0
% INFO    : Bus 764	: V=1.05158492, theta=-34.4648588 -> V=1.072365, theta=0.0
% INFO    : Bus 765	: V=1.00965381, theta=-45.3528599 -> V=0.9888895, theta=0.0
% INFO    : Bus 766	: V=1.00596381, theta=-43.710333 -> V=1.05263, theta=0.0
% INFO    : Bus 767	: V=1.05280936, theta=-36.2077284 -> V=1.046665, theta=0.0
% INFO    : Bus 768	: V=1.03741797, theta=-6.4619103 -> V=1.033334, theta=0.0
% INFO    : Bus 769	: V=1.03351182, theta=-36.3670464 -> V=1.0377785, theta=0.0
% INFO    : Bus 770	: V=1.04880795, theta=-19.7133608 -> V=1.04579, theta=0.0
% INFO    : Bus 771	: V=1.03990657, theta=-16.792249 -> V=1.0115265, theta=0.0
% INFO    : Bus 772	: V=1.03112609, theta=-36.3068465 -> V=1.0377785, theta=0.0
% INFO    : Bus 774	: V=1.03923545, theta=-34.2828156 -> V=1.072365, theta=0.0
% INFO    : Bus 2016	: V=1.04873459, theta=-23.1786096 -> V=0.987526, theta=0.0
% INFO    : Bus 775	: V=1.04457289, theta=-23.2004735 -> V=1.04444, theta=0.0
% INFO    : Bus 776	: V=1.04837279, theta=-23.408532 -> V=1.07237, theta=0.0
% INFO    : Bus 777	: V=1.02139265, theta=-19.861413 -> V=1.0111115, theta=0.0
% INFO    : Bus 778	: V=1.03980709, theta=-35.0857423 -> V=1.0385535, theta=0.0
% INFO    : Bus 779	: V=1.06132693, theta=-26.558901 -> V=1.0130925, theta=0.0
% INFO    : Bus 780	: V=1.01686929, theta=-21.2501672 -> V=1.0130925, theta=0.0
% INFO    : Bus 783	: V=1.07105835, theta=-23.1366769 -> V=1.04659, theta=0.0
% INFO    : Bus 784	: V=1.07097624, theta=-18.6743416 -> V=1.07642, theta=0.0
% INFO    : Bus 2043	: V=0.9948712, theta=-33.359138 -> V=1.0150485, theta=0.0
% INFO    : Bus 2059	: V=1.00012405, theta=-34.1776083 -> V=1.0150485, theta=0.0
% INFO    : Bus 785	: V=1.04940481, theta=-32.8276007 -> V=1.04444, theta=0.0
% INFO    : Bus 786	: V=1.06076311, theta=-29.3849681 -> V=1.07237, theta=0.0
% INFO    : Bus 787	: V=1.0589884, theta=-30.7312161 -> V=1.07237, theta=0.0
% INFO    : Bus 788	: V=1.04957526, theta=-19.4085857 -> V=1.044445, theta=0.0
% INFO    : Bus 789	: V=1.04599641, theta=-36.376698 -> V=1.046665, theta=0.0
% INFO    : Bus 790	: V=1.03505118, theta=-36.3117821 -> V=1.046665, theta=0.0
% INFO    : Bus 791	: V=1.02735852, theta=-45.3991844 -> V=1.022223, theta=0.0
% INFO    : Bus 792	: V=1.03414427, theta=-43.690005 -> V=1.05263, theta=0.0
% INFO    : Bus 793	: V=1.02609689, theta=-45.1886436 -> V=0.9888895, theta=0.0
% INFO    : Bus 794	: V=1.04261247, theta=-25.6159007 -> V=1.04444, theta=0.0
% INFO    : Bus 795	: V=1.0361682, theta=-21.4141003 -> V=1.044445, theta=0.0
% INFO    : Bus 796	: V=1.04179651, theta=-33.2922133 -> V=1.0396085, theta=0.0
% INFO    : Bus 797	: V=1.04185645, theta=-33.2859247 -> V=1.0396085, theta=0.0
% INFO    : Bus 798	: V=1.03262897, theta=-6.19102259 -> V=1.046665, theta=0.0
% INFO    : Bus 799	: V=1.02028611, theta=-25.3489748 -> V=1.0111115, theta=0.0
% INFO    : Bus 800	: V=1.01958553, theta=-46.8654746 -> V=0.9888895, theta=0.0
% INFO    : Bus 801	: V=1.03372493, theta=-41.2750554 -> V=0.9900945, theta=0.0
% INFO    : Bus 802	: V=1.03708549, theta=-39.0921987 -> V=1.05263, theta=0.0
% INFO    : Bus 803	: V=1.036, theta=-7.34670438 -> V=1.012885, theta=0.0
% INFO    : Bus 804	: V=1.03942288, theta=-18.1830775 -> V=1.046665, theta=0.0
% INFO    : Bus 805	: V=1.0421555, theta=-17.5394095 -> V=1.073685, theta=0.0
% INFO    : Bus 806	: V=1.04319601, theta=-40.9029927 -> V=1.046665, theta=0.0
% INFO    : Bus 807	: V=1.04511664, theta=-36.8414767 -> V=1.046665, theta=0.0
% INFO    : Bus 808	: V=1.03650178, theta=-19.3374772 -> V=1.0111115, theta=0.0
% INFO    : Bus 809	: V=1.05315396, theta=-17.7277924 -> V=1.04496, theta=0.0
% INFO    : Bus 810	: V=1.04647225, theta=-27.2601729 -> V=1.04444, theta=0.0
% INFO    : Bus 811	: V=1.03880659, theta=-19.2653704 -> V=1.0111115, theta=0.0
% INFO    : Bus 812	: V=1.04044191, theta=-17.7045951 -> V=1.0111115, theta=0.0
% INFO    : Bus 2063	: V=0.98835146, theta=-37.9162825 -> V=1.15, theta=0.0
% INFO    : Bus 2064	: V=1.05992553, theta=-38.1667321 -> V=1.15, theta=0.0
% INFO    : Bus 813	: V=1.04577218, theta=-37.4335995 -> V=1.046665, theta=0.0
% INFO    : Bus 814	: V=1.04487408, theta=-34.561167 -> V=1.073685, theta=0.0
% INFO    : Bus 815	: V=1.02121325, theta=-6.39832801 -> V=1.004385, theta=0.0
% INFO    : Bus 816	: V=1.0712109, theta=-23.3981199 -> V=1.04762, theta=0.0
% INFO    : Bus 817	: V=1.039, theta=-7.49247706 -> V=1.004235, theta=0.0
% INFO    : Bus 818	: V=1.03744816, theta=-16.3408256 -> V=1.0111115, theta=0.0
% INFO    : Bus 819	: V=1.04014061, theta=-16.7527206 -> V=1.0111115, theta=0.0
% INFO    : Bus 820	: V=1.0368308, theta=-15.4558023 -> V=1.0111115, theta=0.0
% INFO    : Bus 821	: V=1.04082542, theta=-14.092127 -> V=1.072365, theta=0.0
% INFO    : Bus 822	: V=1.03260392, theta=-41.5164838 -> V=0.9888895, theta=0.0
% INFO    : Bus 823	: V=1.03230894, theta=-41.5345977 -> V=0.9888895, theta=0.0
% INFO    : Bus 824	: V=1.03315594, theta=-41.4458374 -> V=1.046665, theta=0.0
% INFO    : Bus 825	: V=1.04140446, theta=-16.6038971 -> V=1.0111115, theta=0.0
% INFO    : Bus 826	: V=1.03462735, theta=-40.4738982 -> V=1.046665, theta=0.0
% INFO    : Bus 827	: V=1.04880795, theta=-19.7133608 -> V=1.04574, theta=0.0
% INFO    : Bus 829	: V=1.05953799, theta=-23.0766328 -> V=1.07237, theta=0.0
% INFO    : Bus 830	: V=1.02948624, theta=-36.6349326 -> V=1.0377785, theta=0.0
% INFO    : Bus 831	: V=1.0284104, theta=-36.6225975 -> V=1.0377785, theta=0.0
% INFO    : Bus 832	: V=1.03149009, theta=-9.81364932 -> V=1.00422, theta=0.0
% INFO    : Bus 833	: V=1.03352629, theta=-40.2381484 -> V=1.046665, theta=0.0
% INFO    : Bus 834	: V=1.02431089, theta=-39.6104355 -> V=1.046665, theta=0.0
% INFO    : Bus 2065	: V=0.984774426, theta=-41.0729268 -> V=1.15, theta=0.0
% INFO    : Bus 2078	: V=0.976465388, theta=-40.6810074 -> V=1.15, theta=0.0
% INFO    : Bus 835	: V=1.03069254, theta=-40.9542935 -> V=1.046665, theta=0.0
% INFO    : Bus 836	: V=1.03352685, theta=-40.2365529 -> V=1.046665, theta=0.0
% INFO    : Bus 837	: V=1.02429677, theta=-39.6091279 -> V=1.046665, theta=0.0
% INFO    : Bus 838	: V=1.03980312, theta=-37.0983515 -> V=1.07116, theta=0.0
% INFO    : Bus 839	: V=1.0389071, theta=-36.9554237 -> V=1.07116, theta=0.0
% INFO    : Bus 840	: V=1.05248117, theta=-16.4552869 -> V=1.044445, theta=0.0
% INFO    : Bus 841	: V=1.03440922, theta=-42.2501203 -> V=1.046665, theta=0.0
% INFO    : Bus 842	: V=1.04335458, theta=-5.42082424 -> V=1.046665, theta=0.0
% INFO    : Bus 843	: V=1.03756874, theta=-16.3415053 -> V=1.0111115, theta=0.0
% INFO    : Bus 844	: V=1.03578634, theta=-16.0356105 -> V=1.0111115, theta=0.0
% INFO    : Bus 845	: V=1.05311774, theta=-16.8881129 -> V=1.046665, theta=0.0
% INFO    : Bus 846	: V=1.06199333, theta=-30.8620542 -> V=1.046885, theta=0.0
% INFO    : Bus 847	: V=1.03859949, theta=-6.36274867 -> V=1.046665, theta=0.0
% INFO    : Bus 848	: V=1.04502807, theta=-36.8028888 -> V=1.046665, theta=0.0
% INFO    : Bus 849	: V=1.03347852, theta=-37.0053866 -> V=1.0386735, theta=0.0
% INFO    : Bus 851	: V=1.03925724, theta=-33.7464359 -> V=1.072365, theta=0.0
% INFO    : Bus 853	: V=1.03874574, theta=-22.3277686 -> V=1.04444, theta=0.0
% INFO    : Bus 2036	: V=1.05760608, theta=-18.4671543 -> V=1.15, theta=0.0
% INFO    : Bus 2037	: V=1.05743214, theta=-18.3617404 -> V=1.15, theta=0.0
% INFO    : Bus 854	: V=1.05401185, theta=-16.8249374 -> V=1.044445, theta=0.0
% INFO    : Bus 857	: V=1.05298894, theta=-12.6579659 -> V=1.078945, theta=0.0
% INFO    : Bus 858	: V=1.04759956, theta=-16.3104314 -> V=1.019305, theta=0.0
% INFO    : Bus 859	: V=1.02143068, theta=-46.4716417 -> V=0.9888895, theta=0.0
% INFO    : Bus 860	: V=1.03466502, theta=-35.1994856 -> V=1.046665, theta=0.0
% INFO    : Bus 861	: V=1.03466314, theta=-35.1994368 -> V=1.046665, theta=0.0
% INFO    : Bus 862	: V=1.04360085, theta=-11.3045431 -> V=1.080065, theta=0.0
% INFO    : Bus 863	: V=1.04358107, theta=-11.2743003 -> V=1.080025, theta=0.0
% INFO    : Bus 864	: V=1.04356704, theta=-11.2741726 -> V=1.080025, theta=0.0
% INFO    : Bus 865	: V=1.04605517, theta=-19.1194009 -> V=1.04444, theta=0.0
% INFO    : Bus 866	: V=1.03518637, theta=-36.2664623 -> V=1.046665, theta=0.0
% INFO    : Bus 867	: V=1.03530058, theta=-36.2523765 -> V=1.046665, theta=0.0
% INFO    : Bus 868	: V=1.03354644, theta=-24.404842 -> V=1.0111115, theta=0.0
% INFO    : Bus 869	: V=1.0366758, theta=-35.295547 -> V=1.0407335, theta=0.0
% INFO    : Bus 870	: V=1.04896986, theta=-12.4430244 -> V=1.044445, theta=0.0
% INFO    : Bus 871	: V=1.03482368, theta=-11.1165119 -> V=1.0111115, theta=0.0
% INFO    : Bus 872	: V=1.0331001, theta=-24.6743571 -> V=1.0111115, theta=0.0
% INFO    : Bus 873	: V=1.04319394, theta=-40.9208902 -> V=1.046665, theta=0.0
% INFO    : Bus 874	: V=1.05357568, theta=-34.1488923 -> V=1.072365, theta=0.0
% INFO    : Bus 875	: V=1.04560664, theta=-37.9260968 -> V=1.046665, theta=0.0
% INFO    : Bus 876	: V=1.04015813, theta=-36.3035624 -> V=1.018115, theta=0.0
% INFO    : Bus 877	: V=1.03347992, theta=-36.3471282 -> V=1.0377785, theta=0.0
% INFO    : Bus 878	: V=1.03347992, theta=-36.3471282 -> V=1.0377785, theta=0.0
% INFO    : Bus 880	: V=1.03347992, theta=-36.3471282 -> V=1.0377785, theta=0.0
% INFO    : Bus 881	: V=0.996207566, theta=-6.46682856 -> V=1.0, theta=0.0
% INFO    : Bus 882	: V=1.05410669, theta=-24.0335892 -> V=1.072365, theta=0.0
% INFO    : Bus 883	: V=1.02757042, theta=-47.2422443 -> V=0.9888895, theta=0.0
% INFO    : Bus 884	: V=1.02806696, theta=-47.2377385 -> V=0.9888895, theta=0.0
% INFO    : Bus 885	: V=1.02824405, theta=-38.2056534 -> V=1.018935, theta=0.0
% INFO    : Bus 886	: V=1.03613427, theta=-39.7833243 -> V=1.046665, theta=0.0
% INFO    : Bus 887	: V=1.03613718, theta=-39.7830353 -> V=1.046665, theta=0.0
% INFO    : Bus 888	: V=1.02473466, theta=-2.74855188 -> V=1.033334, theta=0.0
% INFO    : Bus 889	: V=0.988209799, theta=-0.548241569 -> V=1.0454345, theta=0.0
% INFO    : Bus 890	: V=1.05286531, theta=-33.3484424 -> V=1.072365, theta=0.0
% INFO    : Bus 891	: V=1.05112619, theta=-34.5454643 -> V=1.072365, theta=0.0
% INFO    : Bus 892	: V=1.04308159, theta=-40.7940354 -> V=1.046665, theta=0.0
% INFO    : Bus 893	: V=1.07508592, theta=-24.8750414 -> V=1.05096, theta=0.0
% INFO    : Bus 894	: V=1.02237292, theta=-40.5213682 -> V=1.046665, theta=0.0
% INFO    : Bus 895	: V=1.04828132, theta=-36.5217392 -> V=1.046665, theta=0.0
% INFO    : Bus 896	: V=1.03057281, theta=-35.3593039 -> V=1.046665, theta=0.0
% INFO    : Bus 897	: V=1.027, theta=-5.90195486 -> V=1.0, theta=0.0
% INFO    : Bus 898	: V=1.04599904, theta=-11.6406977 -> V=1.046665, theta=0.0
% INFO    : Bus 899	: V=1.04588001, theta=-10.3027881 -> V=1.06579, theta=0.0
% INFO    : Bus 900	: V=1.03600854, theta=-41.0161664 -> V=1.046665, theta=0.0
% INFO    : Bus 901	: V=1.035997, theta=-41.0169783 -> V=1.046665, theta=0.0
% INFO    : Bus 902	: V=1.0444133, theta=-8.13345491 -> V=1.046665, theta=0.0
% INFO    : Bus 903	: V=1.05029574, theta=-20.1847812 -> V=1.04444, theta=0.0
% INFO    : Bus 904	: V=1.05156588, theta=-21.2227324 -> V=1.04444, theta=0.0
% INFO    : Bus 905	: V=1.02784018, theta=-42.9344694 -> V=0.995556, theta=0.0
% INFO    : Bus 906	: V=1.03600166, theta=-40.100779 -> V=1.046665, theta=0.0
% INFO    : Bus 907	: V=1.02216075, theta=-40.4480369 -> V=1.046665, theta=0.0
% INFO    : Bus 908	: V=1.035, theta=-8.09364273 -> V=1.004395, theta=0.0
% INFO    : Bus 909	: V=1.04494534, theta=-37.90419 -> V=1.046665, theta=0.0
% INFO    : Bus 910	: V=1.03348792, theta=-41.9382575 -> V=1.044805, theta=0.0
% INFO    : Bus 911	: V=1.05423524, theta=-32.6378506 -> V=1.072365, theta=0.0
% INFO    : Bus 912	: V=1.02311655, theta=-40.3363931 -> V=1.046835, theta=0.0
% INFO    : Bus 913	: V=1.02314459, theta=-40.3334234 -> V=1.046835, theta=0.0
% INFO    : Bus 914	: V=1.02314968, theta=-40.3342642 -> V=1.046835, theta=0.0
% INFO    : Bus 915	: V=1.0478029, theta=-34.5236413 -> V=1.072365, theta=0.0
% INFO    : Bus 916	: V=1.04793151, theta=-34.5468386 -> V=1.072365, theta=0.0
% INFO    : Bus 917	: V=1.0103538, theta=4.00585281 -> V=1.013331, theta=0.0
% INFO    : Bus 918	: V=1.03844794, theta=-6.90295839 -> V=1.046665, theta=0.0
% INFO    : Bus 919	: V=1.04420968, theta=-19.8515304 -> V=1.04444, theta=0.0
% INFO    : Bus 920	: V=1.06713647, theta=-26.3619973 -> V=1.0111115, theta=0.0
% INFO    : Bus 921	: V=1.045, theta=-7.03461293 -> V=1.0, theta=0.0
% INFO    : Bus 922	: V=1.04753977, theta=-36.526887 -> V=1.04721, theta=0.0
% INFO    : Bus 923	: V=1.03337596, theta=-42.0804481 -> V=1.002223, theta=0.0
% INFO    : Bus 924	: V=1.03585723, theta=-41.0382286 -> V=1.046665, theta=0.0
% INFO    : Bus 925	: V=1.02527487, theta=-40.0314814 -> V=1.04757, theta=0.0
% INFO    : Bus 926	: V=1.05094231, theta=-37.205287 -> V=1.0377785, theta=0.0
% INFO    : Bus 927	: V=1.05094231, theta=-37.205287 -> V=1.0377785, theta=0.0
% INFO    : Bus 928	: V=1.05091271, theta=-37.1843829 -> V=1.0377785, theta=0.0
% INFO    : Bus 929	: V=1.03568274, theta=-16.0393136 -> V=1.0111115, theta=0.0
% INFO    : Bus 930	: V=1.03799481, theta=-34.4682957 -> V=1.0415285, theta=0.0
% INFO    : Bus 931	: V=1.04308623, theta=-16.8144591 -> V=1.044445, theta=0.0
% INFO    : Bus 932	: V=1.05477482, theta=-18.2935226 -> V=1.044445, theta=0.0
% INFO    : Bus 933	: V=1.03429952, theta=-37.4254448 -> V=1.0377785, theta=0.0
% INFO    : Bus 934	: V=1.04678084, theta=-26.9548025 -> V=1.0773, theta=0.0
% INFO    : Bus 935	: V=1.04928047, theta=-27.043447 -> V=1.0773, theta=0.0
% INFO    : Bus 936	: V=1.05234917, theta=-29.6108602 -> V=1.0773, theta=0.0
% INFO    : Bus 937	: V=1.04932821, theta=-27.023164 -> V=1.0773, theta=0.0
% INFO    : Bus 938	: V=1.02967468, theta=-4.86160273 -> V=1.046665, theta=0.0
% INFO    : Bus 939	: V=1.0559133, theta=-25.9492011 -> V=1.04524, theta=0.0
% INFO    : Bus 940	: V=1.05469915, theta=-26.0021777 -> V=1.04524, theta=0.0
% INFO    : Bus 941	: V=1.04247718, theta=-16.5878888 -> V=1.0111115, theta=0.0
% INFO    : Bus 942	: V=1.03324011, theta=-42.0134925 -> V=1.044271, theta=0.0
% INFO    : Bus 943	: V=1.05097669, theta=-26.8257167 -> V=1.0111115, theta=0.0
% INFO    : Bus 944	: V=1.03561885, theta=-40.6477973 -> V=1.046665, theta=0.0
% INFO    : Bus 945	: V=1.0360775, theta=-35.3252114 -> V=1.046665, theta=0.0
% INFO    : Bus 946	: V=1.06362611, theta=-28.7442094 -> V=1.0000025, theta=0.0
% INFO    : Bus 947	: V=1.05054899, theta=-18.1181668 -> V=1.044445, theta=0.0
% INFO    : Bus 948	: V=1.04212728, theta=-33.3607415 -> V=1.0394935, theta=0.0
% INFO    : Bus 949	: V=1.04490007, theta=-37.0377694 -> V=1.07048, theta=0.0
% INFO    : Bus 950	: V=1.04448696, theta=-31.4847652 -> V=1.073685, theta=0.0
% INFO    : Bus 951	: V=1.04462267, theta=-31.3407893 -> V=1.074185, theta=0.0
% INFO    : Bus 952	: V=1.04465219, theta=-31.3428438 -> V=1.074185, theta=0.0
% INFO    : Bus 953	: V=1.02668479, theta=-45.9668305 -> V=0.9888895, theta=0.0
% INFO    : Bus 954	: V=1.03584185, theta=-16.0568246 -> V=1.0111115, theta=0.0
% INFO    : Bus 955	: V=1.04336891, theta=-40.8452272 -> V=1.046665, theta=0.0
% INFO    : Bus 956	: V=1.03776291, theta=-40.639566 -> V=1.046665, theta=0.0
% INFO    : Bus 957	: V=1.0287473, theta=-44.0787542 -> V=1.024445, theta=0.0
% INFO    : Bus 958	: V=1.04980214, theta=-18.9940687 -> V=1.044445, theta=0.0
% INFO    : Bus 959	: V=1.04939305, theta=-12.6222473 -> V=1.044445, theta=0.0
% INFO    : Bus 960	: V=1.0487686, theta=-5.04609903 -> V=1.033334, theta=0.0
% INFO    : Bus 961	: V=1.04881718, theta=-20.4646086 -> V=1.07237, theta=0.0
% INFO    : Bus 962	: V=1.0231981, theta=-40.3288364 -> V=1.046895, theta=0.0
% INFO    : Bus 963	: V=1.05523219, theta=-14.8958276 -> V=1.078945, theta=0.0
% INFO    : Bus 964	: V=1.0364154, theta=-36.1861676 -> V=1.046665, theta=0.0
% INFO    : Bus 965	: V=0.989439674, theta=-40.5063044 -> V=0.95, theta=0.0
% INFO    : Bus 966	: V=1.02473765, theta=-2.76641137 -> V=1.046665, theta=0.0
% INFO    : Bus 967	: V=0.988070726, theta=-0.572039863 -> V=1.0454355, theta=0.0
% INFO    : Bus 968	: V=1.04511862, theta=-34.47256 -> V=1.073685, theta=0.0
% INFO    : Bus 969	: V=1.04512599, theta=-34.464632 -> V=1.073685, theta=0.0
% INFO    : Bus 970	: V=1.04511862, theta=-34.47256 -> V=1.073685, theta=0.0
% INFO    : Bus 971	: V=1.04479396, theta=-34.4657722 -> V=1.073685, theta=0.0
% INFO    : Bus 972	: V=1.04533575, theta=-37.7203078 -> V=1.046665, theta=0.0
% INFO    : Bus 973	: V=1.039, theta=-7.85546199 -> V=1.01855, theta=0.0
% INFO    : Bus 974	: V=1.04866284, theta=-16.4826712 -> V=1.044445, theta=0.0
% INFO    : Bus 975	: V=1.05, theta=-21.0567952 -> V=1.0, theta=0.0
% INFO    : Bus 976	: V=1.03112344, theta=-16.731104 -> V=1.0111115, theta=0.0
% INFO    : Bus 977	: V=1.0235915, theta=-19.800919 -> V=1.022224, theta=0.0
% INFO    : Bus 978	: V=1.05103978, theta=-12.0003304 -> V=1.07237, theta=0.0
% INFO    : Bus 979	: V=1.05162415, theta=-11.9983065 -> V=1.07237, theta=0.0
% INFO    : Bus 980	: V=1.03849227, theta=-33.6680804 -> V=1.0377785, theta=0.0
% INFO    : Bus 981	: V=1.0479922, theta=-27.6252651 -> V=1.0111115, theta=0.0
% INFO    : Bus 982	: V=1.03646553, theta=-40.8175423 -> V=1.046665, theta=0.0
% INFO    : Bus 983	: V=1.04644137, theta=-4.68548641 -> V=1.06579, theta=0.0
% INFO    : Bus 984	: V=1.02983525, theta=-4.8309109 -> V=1.033334, theta=0.0
% INFO    : Bus 985	: V=1.02972655, theta=-4.84917763 -> V=1.033334, theta=0.0
% INFO    : Bus 986	: V=1.04776888, theta=-5.82659831 -> V=1.046665, theta=0.0
% INFO    : Bus 987	: V=1.02149259, theta=-47.2873227 -> V=1.0088895, theta=0.0
% INFO    : Bus 988	: V=1.04763347, theta=-15.5500145 -> V=1.0111115, theta=0.0
% INFO    : Bus 989	: V=1.03994866, theta=-38.5378071 -> V=1.0377785, theta=0.0
% INFO    : Bus 990	: V=1.03035461, theta=-24.2816067 -> V=1.04444, theta=0.0
% INFO    : Bus 991	: V=1.04321947, theta=-38.5751413 -> V=1.046665, theta=0.0
% INFO    : Bus 992	: V=1.04054334, theta=-38.2568357 -> V=1.0396035, theta=0.0
% INFO    : Bus 993	: V=1.04315294, theta=-40.8632564 -> V=1.046665, theta=0.0
% INFO    : Bus 994	: V=1.04316865, theta=-40.863354 -> V=1.046665, theta=0.0
% INFO    : Bus 995	: V=1.04315653, theta=-40.8606855 -> V=1.046665, theta=0.0
% INFO    : Bus 996	: V=1.03065861, theta=-29.8217815 -> V=1.0377785, theta=0.0
% INFO    : Bus 997	: V=1.03553587, theta=-41.0435916 -> V=1.046665, theta=0.0
% INFO    : Bus 998	: V=1.06713424, theta=-26.3619778 -> V=1.0111115, theta=0.0
% INFO    : Bus 999	: V=1.09618115, theta=-25.045695 -> V=1.072365, theta=0.0
% INFO    : Bus 1000	: V=1.09640802, theta=-35.0672583 -> V=1.072365, theta=0.0
% INFO    : Bus 1001	: V=0.991511057, theta=-29.6418661 -> V=1.0, theta=0.0
% INFO    : Bus 1002	: V=1.03677739, theta=-35.9546378 -> V=1.046665, theta=0.0
% INFO    : Bus 1003	: V=1.0391101, theta=-12.0279816 -> V=1.046665, theta=0.0
% INFO    : Bus 1004	: V=1.02477608, theta=-3.06988838 -> V=1.046665, theta=0.0
% INFO    : Bus 1005	: V=1.02018661, theta=-5.94468634 -> V=1.00521, theta=0.0
% INFO    : Bus 1006	: V=1.04066755, theta=-20.9445208 -> V=1.044445, theta=0.0
% INFO    : Bus 1007	: V=1.05128008, theta=-34.2237782 -> V=1.04444, theta=0.0
% INFO    : Bus 1008	: V=1.03998479, theta=-8.80715984 -> V=1.072365, theta=0.0
% INFO    : Bus 1010	: V=1.05545281, theta=-14.6676073 -> V=1.0111115, theta=0.0
% INFO    : Bus 1011	: V=1.03256649, theta=-14.4147961 -> V=1.0111115, theta=0.0
% INFO    : Bus 2053	: V=0.97090541, theta=-42.0230338 -> V=1.15, theta=0.0
% INFO    : Bus 2054	: V=0.983628272, theta=-42.1340569 -> V=1.15, theta=0.0
% INFO    : Bus 1012	: V=1.03335669, theta=-41.102213 -> V=1.046665, theta=0.0
% INFO    : Bus 1013	: V=1.03708214, theta=-40.4581855 -> V=1.046665, theta=0.0
% INFO    : Bus 1014	: V=1.03774255, theta=-40.4483637 -> V=1.046665, theta=0.0
% INFO    : Bus 1015	: V=1.04375324, theta=-38.4375824 -> V=1.046665, theta=0.0
% INFO    : Bus 1017	: V=1.03905238, theta=-37.7255013 -> V=1.07122, theta=0.0
% INFO    : Bus 1018	: V=1.04101555, theta=-37.4313542 -> V=1.07122, theta=0.0
% INFO    : Bus 1021	: V=1.05187594, theta=-16.7129717 -> V=1.046665, theta=0.0
% INFO    : Bus 1022	: V=1.04929707, theta=-32.547501 -> V=1.04444, theta=0.0
% INFO    : Bus 1023	: V=1.05081375, theta=-27.975002 -> V=1.071885, theta=0.0
% INFO    : Bus 1024	: V=1.05027346, theta=-33.917811 -> V=1.046665, theta=0.0
% INFO    : Bus 1025	: V=1.0361316, theta=-40.1306733 -> V=1.046665, theta=0.0
% INFO    : Bus 1026	: V=1.02714803, theta=-47.3235545 -> V=0.9888895, theta=0.0
% INFO    : Bus 1027	: V=1.03944375, theta=-6.02770681 -> V=1.046665, theta=0.0
% INFO    : Bus 1028	: V=1.01915567, theta=-36.9324489 -> V=1.0377785, theta=0.0
% INFO    : Bus 1029	: V=1.04044077, theta=-33.6164097 -> V=1.0392435, theta=0.0
% INFO    : Bus 1030	: V=1.06189419, theta=-32.5660312 -> V=1.04444, theta=0.0
% INFO    : Bus 1031	: V=1.02144392, theta=-29.8262519 -> V=1.04444, theta=0.0
% INFO    : Bus 1032	: V=1.02843974, theta=-44.8218366 -> V=1.006667, theta=0.0
% INFO    : Bus 1033	: V=1.05205401, theta=-32.8141759 -> V=1.046665, theta=0.0
% INFO    : Bus 1035	: V=1.05478014, theta=-18.2764966 -> V=1.044445, theta=0.0
% INFO    : Bus 1036	: V=1.04621829, theta=-12.1153043 -> V=1.044445, theta=0.0
% INFO    : Bus 1037	: V=1.03095525, theta=-36.3625087 -> V=1.0377785, theta=0.0
% INFO    : Bus 1038	: V=1.02070206, theta=-46.3244837 -> V=0.9888895, theta=0.0
% INFO    : Bus 1834	: V=1.03452859, theta=-37.4303562 -> V=1.0378685, theta=0.0
% INFO    : Bus 1039	: V=1.03533633, theta=-8.00607123 -> V=1.033334, theta=0.0
% INFO    : Bus 1040	: V=1.05535352, theta=-25.9410237 -> V=1.044815, theta=0.0
% INFO    : Bus 1041	: V=1.05608189, theta=-22.386827 -> V=1.07237, theta=0.0
% INFO    : Bus 1042	: V=1.01636019, theta=-46.5885695 -> V=0.9888895, theta=0.0
% INFO    : Bus 1043	: V=1.05277106, theta=-12.2184398 -> V=1.044445, theta=0.0
% INFO    : Bus 1044	: V=1.03281798, theta=-6.14518917 -> V=1.046665, theta=0.0
% INFO    : Bus 1045	: V=1.04178104, theta=-21.7209684 -> V=1.04444, theta=0.0
% INFO    : Bus 1046	: V=1.04177354, theta=-21.7220204 -> V=1.04444, theta=0.0
% INFO    : Bus 1047	: V=1.04177313, theta=-21.7220091 -> V=1.04444, theta=0.0
% INFO    : Bus 1048	: V=1.07999446, theta=-19.3657916 -> V=1.004505, theta=0.0
% INFO    : Bus 1049	: V=1.06030313, theta=-25.7152126 -> V=1.0111115, theta=0.0
% INFO    : Bus 1050	: V=1.03986766, theta=-29.8041333 -> V=1.046665, theta=0.0
% INFO    : Bus 1051	: V=1.04225131, theta=-27.8991531 -> V=1.04444, theta=0.0
% INFO    : Bus 1052	: V=1.04171399, theta=-21.7304441 -> V=1.04444, theta=0.0
% INFO    : Bus 1053	: V=1.02582778, theta=-3.0800609 -> V=1.046665, theta=0.0
% INFO    : Bus 1054	: V=1.05258035, theta=-32.8689497 -> V=1.046665, theta=0.0
% INFO    : Bus 1055	: V=1.0328253, theta=-5.33626253 -> V=1.046665, theta=0.0
% INFO    : Bus 1056	: V=1.04525391, theta=-6.33445527 -> V=1.06579, theta=0.0
% INFO    : Bus 1057	: V=1.0394162, theta=-24.9420632 -> V=1.04444, theta=0.0
% INFO    : Bus 1058	: V=1.03476541, theta=-39.6641942 -> V=0.9895695, theta=0.0
% INFO    : Bus 1059	: V=1.0244299, theta=-36.9673931 -> V=1.0377785, theta=0.0
% INFO    : Bus 1060	: V=1.02347345, theta=-1.61224138 -> V=1.046665, theta=0.0
% INFO    : Bus 1061	: V=1.04481955, theta=-32.3294781 -> V=1.0409085, theta=0.0
% INFO    : Bus 1062	: V=1.04284588, theta=-35.3669411 -> V=1.073685, theta=0.0
% INFO    : Bus 1064	: V=1.02458302, theta=-2.94057297 -> V=1.046665, theta=0.0
% INFO    : Bus 1065	: V=1.02463349, theta=-2.94401821 -> V=1.046665, theta=0.0
% INFO    : Bus 1066	: V=1.02448203, theta=-2.94615891 -> V=1.046665, theta=0.0
% INFO    : Bus 1067	: V=1.03492243, theta=-35.2071321 -> V=1.046665, theta=0.0
% INFO    : Bus 1068	: V=1.04651801, theta=-32.7549452 -> V=1.073685, theta=0.0
% INFO    : Bus 1069	: V=1.00966711, theta=3.78638709 -> V=1.04323, theta=0.0
% INFO    : Bus 1070	: V=1.00941922, theta=3.58980825 -> V=1.04323, theta=0.0
% INFO    : Bus 1071	: V=1.04022344, theta=-25.1064747 -> V=1.04444, theta=0.0
% INFO    : Bus 1072	: V=1.04005582, theta=-25.1294197 -> V=1.04444, theta=0.0
% INFO    : Bus 1073	: V=1.03593811, theta=-40.9730344 -> V=1.046665, theta=0.0
% INFO    : Bus 1074	: V=1.0358904, theta=-40.9774951 -> V=1.046665, theta=0.0
% INFO    : Bus 1075	: V=1.03709042, theta=-39.0814118 -> V=1.05263, theta=0.0
% INFO    : Bus 1076	: V=1.03709091, theta=-39.0814155 -> V=1.05263, theta=0.0
% INFO    : Bus 1077	: V=1.03709042, theta=-39.0814118 -> V=1.05263, theta=0.0
% INFO    : Bus 1078	: V=1.03708988, theta=-39.0811434 -> V=1.05263, theta=0.0
% INFO    : Bus 1079	: V=1.04558666, theta=-35.1524675 -> V=1.0410285, theta=0.0
% INFO    : Bus 1080	: V=1.04907661, theta=-32.9484398 -> V=1.07092, theta=0.0
% INFO    : Bus 1081	: V=1.03536606, theta=-36.8505142 -> V=1.0377785, theta=0.0
% INFO    : Bus 1082	: V=1.03079999, theta=-36.1331484 -> V=1.0377785, theta=0.0
% INFO    : Bus 1083	: V=1.03078061, theta=-36.1174463 -> V=1.0377785, theta=0.0
% INFO    : Bus 1084	: V=1.03080156, theta=-36.1283369 -> V=1.0377785, theta=0.0
% INFO    : Bus 1085	: V=1.03078161, theta=-36.1182196 -> V=1.0377785, theta=0.0
% INFO    : Bus 1086	: V=1.04764417, theta=-38.5547308 -> V=1.046665, theta=0.0
% INFO    : Bus 1087	: V=1.03452148, theta=-40.3639779 -> V=1.046665, theta=0.0
% INFO    : Bus 1088	: V=1.03434215, theta=-40.3785636 -> V=1.046665, theta=0.0
% INFO    : Bus 1089	: V=1.03830727, theta=-34.6793474 -> V=1.0416985, theta=0.0
% INFO    : Bus 1090	: V=1.02357046, theta=-2.02768843 -> V=1.046665, theta=0.0
% INFO    : Bus 1092	: V=1.02863306, theta=-26.2506672 -> V=1.0111115, theta=0.0
% INFO    : Bus 1093	: V=1.04487504, theta=-16.9685678 -> V=1.046665, theta=0.0
% INFO    : Bus 1095	: V=1.05447207, theta=-18.436277 -> V=1.044445, theta=0.0
% INFO    : Bus 1096	: V=1.03114536, theta=-17.1028446 -> V=1.0111115, theta=0.0
% INFO    : Bus 1097	: V=1.04687204, theta=-36.394632 -> V=1.046665, theta=0.0
% INFO    : Bus 1098	: V=1.03624406, theta=-36.5833049 -> V=1.046665, theta=0.0
% INFO    : Bus 1099	: V=1.02242925, theta=-2.16414337 -> V=1.046665, theta=0.0
% INFO    : Bus 1100	: V=1.05255801, theta=-32.8706532 -> V=1.046665, theta=0.0
% INFO    : Bus 1101	: V=1.02733452, theta=-5.09663278 -> V=1.046665, theta=0.0
% INFO    : Bus 1103	: V=1.03577237, theta=-37.3858172 -> V=1.0377785, theta=0.0
% INFO    : Bus 1104	: V=1.03600515, theta=-40.100063 -> V=1.046665, theta=0.0
% INFO    : Bus 1105	: V=1.02216264, theta=-40.447963 -> V=1.046665, theta=0.0
% INFO    : Bus 1106	: V=1.03018126, theta=-33.6616556 -> V=1.0377785, theta=0.0
% INFO    : Bus 1107	: V=1.04659031, theta=-33.7921063 -> V=1.04444, theta=0.0
% INFO    : Bus 1108	: V=1.05223307, theta=-33.8823976 -> V=1.046665, theta=0.0
% INFO    : Bus 1109	: V=1.04906278, theta=-30.9570252 -> V=1.046665, theta=0.0
% INFO    : Bus 1110	: V=1.04955784, theta=-30.607963 -> V=1.073685, theta=0.0
% INFO    : Bus 1112	: V=1.04294593, theta=-5.43269531 -> V=1.046665, theta=0.0
% INFO    : Bus 1113	: V=1.06206797, theta=-8.64817971 -> V=1.0233335, theta=0.0
% INFO    : Bus 1114	: V=1.03508523, theta=-8.82129665 -> V=1.046665, theta=0.0
% INFO    : Bus 1115	: V=1.03255662, theta=-35.4211444 -> V=1.0377785, theta=0.0
% INFO    : Bus 1116	: V=1.02719538, theta=-47.3032508 -> V=0.9888895, theta=0.0
% INFO    : Bus 1117	: V=1.0272028, theta=-47.2997054 -> V=0.9888895, theta=0.0
% INFO    : Bus 1118	: V=1.02890224, theta=-43.9215236 -> V=1.013845, theta=0.0
% INFO    : Bus 1119	: V=1.01822712, theta=-46.250875 -> V=0.9888895, theta=0.0
% INFO    : Bus 1120	: V=1.01625932, theta=-12.6270897 -> V=1.0233335, theta=0.0
% INFO    : Bus 1121	: V=1.03283435, theta=-5.32260255 -> V=1.046665, theta=0.0
% INFO    : Bus 1123	: V=1.04309421, theta=-40.8178797 -> V=1.046665, theta=0.0
% INFO    : Bus 1124	: V=1.04315997, theta=-40.8198082 -> V=1.046665, theta=0.0
% INFO    : Bus 2048	: V=0.959579416, theta=-16.190209 -> V=1.15, theta=0.0
% INFO    : Bus 1125	: V=1.04961776, theta=-15.6221457 -> V=1.0457, theta=0.0
% INFO    : Bus 1126	: V=1.04603819, theta=-12.2029829 -> V=1.0793, theta=0.0
% INFO    : Bus 1127	: V=1.02867012, theta=-25.4503538 -> V=1.0111115, theta=0.0
% INFO    : Bus 1128	: V=1.04183979, theta=-23.4846314 -> V=1.072365, theta=0.0
% INFO    : Bus 1129	: V=1.01393655, theta=-47.0983013 -> V=0.9888895, theta=0.0
% INFO    : Bus 1130	: V=1.0475565, theta=-36.5253289 -> V=1.046665, theta=0.0
% INFO    : Bus 1131	: V=1.02527854, theta=-41.5429527 -> V=1.046665, theta=0.0
% INFO    : Bus 1132	: V=1.03272447, theta=-44.590381 -> V=0.9888895, theta=0.0
% INFO    : Bus 1133	: V=1.04803908, theta=-36.5080924 -> V=1.047485, theta=0.0
% INFO    : Bus 1134	: V=1.04785738, theta=-36.522459 -> V=1.047485, theta=0.0
% INFO    : Bus 1135	: V=1.0453526, theta=-36.6530959 -> V=1.046665, theta=0.0
% INFO    : Bus 1136	: V=1.04564681, theta=-36.6963851 -> V=1.046665, theta=0.0
% INFO    : Bus 1137	: V=1.04318137, theta=-16.1616759 -> V=1.0111115, theta=0.0
% INFO    : Bus 1138	: V=1.03013195, theta=-12.5284316 -> V=1.0111115, theta=0.0
% INFO    : Bus 1139	: V=1.04496648, theta=-33.3605311 -> V=1.0397185, theta=0.0
% INFO    : Bus 1140	: V=1.05193741, theta=-33.2231375 -> V=1.046665, theta=0.0
% INFO    : Bus 1141	: V=1.03445492, theta=-8.16353954 -> V=1.033334, theta=0.0
% INFO    : Bus 1142	: V=1.03283568, theta=-5.2547846 -> V=1.033334, theta=0.0
% INFO    : Bus 1143	: V=1.05043585, theta=-33.4664877 -> V=1.046665, theta=0.0
% INFO    : Bus 1144	: V=1.03922399, theta=-22.7458411 -> V=1.044445, theta=0.0
% INFO    : Bus 1145	: V=1.02833334, theta=-17.1982933 -> V=1.0111115, theta=0.0
% INFO    : Bus 1146	: V=1.0374126, theta=-34.3040413 -> V=1.0377785, theta=0.0
% INFO    : Bus 1147	: V=1.04986246, theta=-15.6252534 -> V=1.04612, theta=0.0
% INFO    : Bus 1148	: V=1.04563922, theta=-32.4655006 -> V=1.0379585, theta=0.0
% INFO    : Bus 1149	: V=1.0526704, theta=-18.298715 -> V=1.044445, theta=0.0
% INFO    : Bus 1150	: V=1.05302519, theta=-15.761398 -> V=1.078945, theta=0.0
% INFO    : Bus 1151	: V=1.04144814, theta=-34.0545681 -> V=1.0377785, theta=0.0
% INFO    : Bus 1152	: V=1.04864972, theta=-38.7985757 -> V=1.046665, theta=0.0
% INFO    : Bus 1153	: V=1.0321893, theta=-5.64688044 -> V=1.046665, theta=0.0
% INFO    : Bus 1154	: V=1.04962933, theta=-12.6118801 -> V=1.044445, theta=0.0
% INFO    : Bus 1155	: V=1.06319986, theta=-26.4660128 -> V=1.0111115, theta=0.0
% INFO    : Bus 2049	: V=0.987300764, theta=-40.9938045 -> V=1.15, theta=0.0
% INFO    : Bus 1156	: V=1.03688826, theta=-39.749186 -> V=1.046665, theta=0.0
% INFO    : Bus 1157	: V=1.03603193, theta=-40.5092031 -> V=1.046665, theta=0.0
% INFO    : Bus 1158	: V=1.03800301, theta=-38.0520961 -> V=1.06945, theta=0.0
% INFO    : Bus 1159	: V=1.04865889, theta=-15.3309663 -> V=1.0111115, theta=0.0
% INFO    : Bus 1160	: V=1.03639651, theta=-40.746665 -> V=1.046665, theta=0.0
% INFO    : Bus 1161	: V=1.05509043, theta=-15.9538877 -> V=1.0128415, theta=0.0
% INFO    : Bus 1162	: V=1.03598321, theta=-36.0614227 -> V=1.0377785, theta=0.0
% INFO    : Bus 1163	: V=1.04267002, theta=-34.4885346 -> V=1.072365, theta=0.0
% INFO    : Bus 1164	: V=1.03591926, theta=-40.9722419 -> V=1.046665, theta=0.0
% INFO    : Bus 1165	: V=1.03078376, theta=-40.9478796 -> V=1.046665, theta=0.0
% INFO    : Bus 1166	: V=1.04366811, theta=-16.4064416 -> V=1.0111115, theta=0.0
% INFO    : Bus 1167	: V=1.01328048, theta=-37.2168856 -> V=1.0377785, theta=0.0
% INFO    : Bus 1168	: V=1.02877953, theta=-25.3549765 -> V=1.0111115, theta=0.0
% INFO    : Bus 1169	: V=1.03646266, theta=-36.2150096 -> V=1.046665, theta=0.0
% INFO    : Bus 1170	: V=1.03194976, theta=-5.49113459 -> V=1.046665, theta=0.0
% INFO    : Bus 1171	: V=1.02147105, theta=-47.294755 -> V=0.9888895, theta=0.0
% INFO    : Bus 1172	: V=1.02137307, theta=-47.3070075 -> V=0.9888895, theta=0.0
% INFO    : Bus 2038	: V=0.988828906, theta=-33.4824884 -> V=1.15, theta=0.0
% INFO    : Bus 1173	: V=1.03981039, theta=-33.3410718 -> V=1.0377785, theta=0.0
% INFO    : Bus 1174	: V=1.04722339, theta=-31.9034864 -> V=1.072365, theta=0.0
% INFO    : Bus 1175	: V=1.04777863, theta=-28.8909279 -> V=1.0111115, theta=0.0
% INFO    : Bus 1176	: V=1.0280404, theta=-45.3363426 -> V=1.0111115, theta=0.0
% INFO    : Bus 1177	: V=1.03970623, theta=-38.8273513 -> V=1.05263, theta=0.0
% INFO    : Bus 1178	: V=1.04472814, theta=-36.8667174 -> V=1.046665, theta=0.0
% INFO    : Bus 1179	: V=1.05037907, theta=-37.4133126 -> V=1.0377785, theta=0.0
% INFO    : Bus 1180	: V=1.05426617, theta=-35.4436827 -> V=1.072365, theta=0.0
% INFO    : Bus 1181	: V=1.05463012, theta=-37.5130148 -> V=1.072365, theta=0.0
% INFO    : Bus 1182	: V=1.04522644, theta=-16.1384601 -> V=1.0111115, theta=0.0
% INFO    : Bus 1183	: V=1.04960989, theta=-27.0261032 -> V=1.04444, theta=0.0
% INFO    : Bus 1184	: V=1.03459986, theta=-9.50497494 -> V=1.046665, theta=0.0
% INFO    : Bus 1185	: V=1.03207496, theta=-16.9283719 -> V=1.0111115, theta=0.0
% INFO    : Bus 1186	: V=1.02964153, theta=-16.3778233 -> V=1.044445, theta=0.0
% INFO    : Bus 1187	: V=1.02955627, theta=-16.3767061 -> V=1.044445, theta=0.0
% INFO    : Bus 1188	: V=1.03445943, theta=-40.3492456 -> V=1.046665, theta=0.0
% INFO    : Bus 1189	: V=1.01516155, theta=-45.928028 -> V=1.0288895, theta=0.0
% INFO    : Bus 1190	: V=1.05541459, theta=-28.4651789 -> V=1.04538, theta=0.0
% INFO    : Bus 1191	: V=1.03209998, theta=-8.46715072 -> V=1.003505, theta=0.0
% INFO    : Bus 1192	: V=1.01919907, theta=-36.9328543 -> V=1.0377785, theta=0.0
% INFO    : Bus 1193	: V=1.05369293, theta=-33.8835406 -> V=1.04444, theta=0.0
% INFO    : Bus 1194	: V=1.03999917, theta=-8.73887386 -> V=1.072365, theta=0.0
% INFO    : Bus 1195	: V=1.03999927, theta=-8.73887429 -> V=1.072365, theta=0.0
% INFO    : Bus 1835	: V=1.04363503, theta=-18.7251472 -> V=1.0111115, theta=0.0
% INFO    : Bus 1836	: V=1.04952693, theta=-16.4808661 -> V=1.0111115, theta=0.0
% INFO    : Bus 1196	: V=1.03566572, theta=-36.2524015 -> V=1.046665, theta=0.0
% INFO    : Bus 1197	: V=1.04847675, theta=-38.9922578 -> V=1.046665, theta=0.0
% INFO    : Bus 1198	: V=1.0338531, theta=-7.85013889 -> V=1.046665, theta=0.0
% INFO    : Bus 1199	: V=1.04472741, theta=-32.9537761 -> V=1.0419835, theta=0.0
% INFO    : Bus 1200	: V=1.04800707, theta=-29.4994374 -> V=1.07458, theta=0.0
% INFO    : Bus 1201	: V=1.04540108, theta=-24.8349962 -> V=1.04444, theta=0.0
% INFO    : Bus 1202	: V=1.04757294, theta=-37.5323295 -> V=1.046665, theta=0.0
% INFO    : Bus 1203	: V=1.03329747, theta=-42.1330758 -> V=0.9888895, theta=0.0
% INFO    : Bus 1204	: V=1.03326064, theta=-42.1057583 -> V=0.9888895, theta=0.0
% INFO    : Bus 1205	: V=1.05543263, theta=-26.8175257 -> V=1.046805, theta=0.0
% INFO    : Bus 1206	: V=1.04457562, theta=-8.12434909 -> V=1.046665, theta=0.0
% INFO    : Bus 1207	: V=1.02468476, theta=-3.910592 -> V=1.046665, theta=0.0
% INFO    : Bus 1208	: V=1.04214895, theta=-11.0033535 -> V=1.044445, theta=0.0
% INFO    : Bus 1209	: V=1.04763395, theta=-15.5500202 -> V=1.0111115, theta=0.0
% INFO    : Bus 1210	: V=1.0344059, theta=-8.27777944 -> V=1.033334, theta=0.0
% INFO    : Bus 1211	: V=1.01180961, theta=-13.810946 -> V=1.0233335, theta=0.0
% INFO    : Bus 1212	: V=1.04221425, theta=-24.9449057 -> V=1.04444, theta=0.0
% INFO    : Bus 1213	: V=1.0428322, theta=-21.3985041 -> V=1.07237, theta=0.0
% INFO    : Bus 1214	: V=1.04284608, theta=-21.4051968 -> V=1.07237, theta=0.0
% INFO    : Bus 2039	: V=0.912502783, theta=-29.3573071 -> V=1.15, theta=0.0
% INFO    : Bus 1215	: V=1.03347337, theta=-29.0697664 -> V=1.0377785, theta=0.0
% INFO    : Bus 1216	: V=1.04297913, theta=-25.3785621 -> V=1.072365, theta=0.0
% INFO    : Bus 1217	: V=1.03314098, theta=-5.6731455 -> V=1.046665, theta=0.0
% INFO    : Bus 1218	: V=1.05377274, theta=-20.626331 -> V=1.044445, theta=0.0
% INFO    : Bus 1219	: V=1.05244245, theta=-18.2619505 -> V=1.04444, theta=0.0
% INFO    : Bus 1220	: V=1.05270388, theta=-18.4126991 -> V=1.04444, theta=0.0
% INFO    : Bus 1221	: V=1.056, theta=-14.6743324 -> V=1.0, theta=0.0
% INFO    : Bus 1222	: V=1.0379918, theta=-34.4682591 -> V=1.0409335, theta=0.0
% INFO    : Bus 1223	: V=1.03888268, theta=-34.940697 -> V=1.0409335, theta=0.0
% INFO    : Bus 1224	: V=1.03117909, theta=-24.7292718 -> V=1.04444, theta=0.0
% INFO    : Bus 1225	: V=1.04183359, theta=-33.3584266 -> V=1.0396085, theta=0.0
% INFO    : Bus 1226	: V=1.04176666, theta=-25.0227363 -> V=1.04444, theta=0.0
% INFO    : Bus 1227	: V=1.02636867, theta=-41.3779224 -> V=1.046665, theta=0.0
% INFO    : Bus 1228	: V=1.03451594, theta=-40.3735874 -> V=1.046665, theta=0.0
% INFO    : Bus 1229	: V=1.04481756, theta=-37.8337091 -> V=1.0379885, theta=0.0
% INFO    : Bus 1230	: V=1.03581781, theta=-22.694054 -> V=1.04444, theta=0.0
% INFO    : Bus 1231	: V=1.0555628, theta=-18.0665001 -> V=1.044445, theta=0.0
% INFO    : Bus 1232	: V=1.03598012, theta=-41.016121 -> V=1.046665, theta=0.0
% INFO    : Bus 1233	: V=1.04880846, theta=-19.7133668 -> V=1.04574, theta=0.0
% INFO    : Bus 1234	: V=1.02475124, theta=-47.1695501 -> V=0.9888895, theta=0.0
% INFO    : Bus 1235	: V=1.02485831, theta=-47.1692648 -> V=0.9888895, theta=0.0
% INFO    : Bus 1236	: V=1.05240594, theta=-35.0800648 -> V=1.046665, theta=0.0
% INFO    : Bus 1237	: V=1.06517162, theta=-8.02093694 -> V=1.0273785, theta=0.0
% INFO    : Bus 1238	: V=1.03747982, theta=-6.66447081 -> V=1.046665, theta=0.0
% INFO    : Bus 1239	: V=1.04865299, theta=-16.5317099 -> V=1.044445, theta=0.0
% INFO    : Bus 1240	: V=1.04730411, theta=-16.5446111 -> V=1.044445, theta=0.0
% INFO    : Bus 1241	: V=1.03634911, theta=-18.2583216 -> V=1.0111115, theta=0.0
% INFO    : Bus 1242	: V=1.04345616, theta=-14.0094658 -> V=1.072365, theta=0.0
% INFO    : Bus 1243	: V=1.04021029, theta=-13.8214939 -> V=1.072365, theta=0.0
% INFO    : Bus 1246	: V=1.03328725, theta=-39.3232278 -> V=1.0288895, theta=0.0
% INFO    : Bus 1247	: V=1.02134002, theta=-36.7696949 -> V=1.0377785, theta=0.0
% INFO    : Bus 1248	: V=1.02134002, theta=-36.7696949 -> V=1.0377785, theta=0.0
% INFO    : Bus 1249	: V=1.02134003, theta=-36.7697015 -> V=1.0377785, theta=0.0
% INFO    : Bus 1250	: V=1.02135541, theta=-36.7785548 -> V=1.0377785, theta=0.0
% INFO    : Bus 1251	: V=1.02135461, theta=-36.7816398 -> V=1.0377785, theta=0.0
% INFO    : Bus 1252	: V=1.04405072, theta=-33.5660539 -> V=1.0388735, theta=0.0
% INFO    : Bus 1253	: V=1.02201326, theta=-22.6902753 -> V=1.0233335, theta=0.0
% INFO    : Bus 1254	: V=1.09643503, theta=-25.0390225 -> V=1.072365, theta=0.0
% INFO    : Bus 1255	: V=1.046, theta=-16.5215055 -> V=1.01587, theta=0.0
% INFO    : Bus 1256	: V=1.03355977, theta=-44.6576506 -> V=1.013334, theta=0.0
% INFO    : Bus 1257	: V=1.04133178, theta=-17.4596567 -> V=1.0233335, theta=0.0
% INFO    : Bus 1258	: V=1.03166839, theta=-12.9456761 -> V=1.046665, theta=0.0
% INFO    : Bus 1259	: V=1.03648165, theta=-31.1778114 -> V=1.04444, theta=0.0
% INFO    : Bus 1260	: V=1.04299835, theta=-28.4745574 -> V=1.07237, theta=0.0
% INFO    : Bus 1261	: V=1.04277555, theta=-21.2164217 -> V=1.044445, theta=0.0
% INFO    : Bus 1262	: V=1.05334473, theta=-11.7166796 -> V=1.044445, theta=0.0
% INFO    : Bus 1263	: V=1.05501102, theta=-9.44494092 -> V=1.07416, theta=0.0
% INFO    : Bus 1264	: V=1.03738433, theta=-10.5839134 -> V=1.0, theta=0.0
% INFO    : Bus 1265	: V=1.0537153, theta=-17.5868172 -> V=1.044445, theta=0.0
% INFO    : Bus 1266	: V=1.06167127, theta=-30.929524 -> V=1.04708, theta=0.0
% INFO    : Bus 1267	: V=1.04418036, theta=-19.6347819 -> V=1.073685, theta=0.0
% INFO    : Bus 1268	: V=1.027, theta=-31.4226123 -> V=1.01773, theta=0.0
% INFO    : Bus 1269	: V=1.04764275, theta=-4.94992816 -> V=1.046665, theta=0.0
% INFO    : Bus 1270	: V=1.05131723, theta=-4.86301946 -> V=1.046665, theta=0.0
% INFO    : Bus 1271	: V=1.05446599, theta=-2.17217032 -> V=1.07568, theta=0.0
% INFO    : Bus 1272	: V=1.05026042, theta=-20.2873424 -> V=1.04444, theta=0.0
% INFO    : Bus 1273	: V=1.04217887, theta=-27.9137898 -> V=1.04444, theta=0.0
% INFO    : Bus 1274	: V=1.03634862, theta=-41.232634 -> V=1.046665, theta=0.0
% INFO    : Bus 1275	: V=1.04330058, theta=-40.8620369 -> V=1.046665, theta=0.0
% INFO    : Bus 1276	: V=1.05163282, theta=-26.0413814 -> V=1.027779, theta=0.0
% INFO    : Bus 1277	: V=1.04359797, theta=-20.7095196 -> V=1.073685, theta=0.0
% INFO    : Bus 1278	: V=1.04337672, theta=-20.7101399 -> V=1.073685, theta=0.0
% INFO    : Bus 1279	: V=1.03823971, theta=-6.61073106 -> V=1.046665, theta=0.0
% INFO    : Bus 1280	: V=1.03885454, theta=-39.9626866 -> V=1.046665, theta=0.0
% INFO    : Bus 1281	: V=1.04142346, theta=-36.6468454 -> V=1.073685, theta=0.0
% INFO    : Bus 1282	: V=1.04112046, theta=-36.7930565 -> V=1.073685, theta=0.0
% INFO    : Bus 1285	: V=1.01735152, theta=-30.1707984 -> V=1.04444, theta=0.0
% INFO    : Bus 1286	: V=1.02107498, theta=-46.3168551 -> V=0.9888895, theta=0.0
% INFO    : Bus 1287	: V=1.04031027, theta=-32.7673074 -> V=1.046665, theta=0.0
% INFO    : Bus 1288	: V=1.04814925, theta=-37.9646695 -> V=1.0377785, theta=0.0
% INFO    : Bus 1289	: V=1.03119389, theta=-36.5708164 -> V=1.030139, theta=0.0
% INFO    : Bus 1290	: V=1.04844961, theta=-32.2601081 -> V=1.073685, theta=0.0
% INFO    : Bus 1291	: V=1.0484348, theta=-32.2663176 -> V=1.073685, theta=0.0
% INFO    : Bus 1292	: V=1.03329672, theta=-41.7925328 -> V=1.045575, theta=0.0
% INFO    : Bus 1294	: V=1.02587055, theta=-41.5036108 -> V=1.046665, theta=0.0
% INFO    : Bus 1295	: V=1.04177682, theta=-17.7161493 -> V=1.073685, theta=0.0
% INFO    : Bus 1296	: V=1.0398319, theta=-33.7178805 -> V=1.0377785, theta=0.0
% INFO    : Bus 1297	: V=1.0396595, theta=-33.5273563 -> V=1.0377785, theta=0.0
% INFO    : Bus 2040	: V=0.994957581, theta=-30.0119032 -> V=1.15, theta=0.0
% INFO    : Bus 1298	: V=1.03977646, theta=-29.2111534 -> V=1.046665, theta=0.0
% INFO    : Bus 1299	: V=1.04383083, theta=-26.1565051 -> V=1.073685, theta=0.0
% INFO    : Bus 1300	: V=1.05713328, theta=-17.6481993 -> V=1.044445, theta=0.0
% INFO    : Bus 1301	: V=1.0437826, theta=-14.042332 -> V=1.046665, theta=0.0
% INFO    : Bus 1302	: V=1.0468484, theta=-12.4401823 -> V=1.06579, theta=0.0
% INFO    : Bus 1303	: V=1.04726967, theta=-33.123312 -> V=1.04444, theta=0.0
% INFO    : Bus 1304	: V=1.02544626, theta=-17.7758365 -> V=1.0111115, theta=0.0
% INFO    : Bus 1305	: V=1.01157486, theta=4.66325267 -> V=1.033334, theta=0.0
% INFO    : Bus 1306	: V=1.01210548, theta=4.55962746 -> V=1.033334, theta=0.0
% INFO    : Bus 1307	: V=1.01250492, theta=4.67687632 -> V=1.033334, theta=0.0
% INFO    : Bus 1308	: V=1.01167245, theta=4.32242792 -> V=1.033334, theta=0.0
% INFO    : Bus 1309	: V=1.02331698, theta=-45.8253193 -> V=0.9888895, theta=0.0
% INFO    : Bus 1310	: V=1.02333684, theta=-45.8211416 -> V=0.9888895, theta=0.0
% INFO    : Bus 1311	: V=1.0095601, theta=3.73847252 -> V=1.046665, theta=0.0
% INFO    : Bus 1312	: V=1.00901537, theta=3.80184904 -> V=1.046665, theta=0.0
% INFO    : Bus 1313	: V=1.00870826, theta=3.33242103 -> V=1.046665, theta=0.0
% INFO    : Bus 1314	: V=1.04829938, theta=-5.35984555 -> V=1.046665, theta=0.0
% INFO    : Bus 1315	: V=1.00870987, theta=3.59765817 -> V=1.046665, theta=0.0
% INFO    : Bus 1316	: V=1.00890199, theta=3.49957848 -> V=1.046665, theta=0.0
% INFO    : Bus 1317	: V=1.00891464, theta=3.51527215 -> V=1.046665, theta=0.0
% INFO    : Bus 1318	: V=1.00928537, theta=3.54606296 -> V=1.046665, theta=0.0
% INFO    : Bus 1319	: V=1.00949992, theta=3.7556498 -> V=1.046665, theta=0.0
% INFO    : Bus 1320	: V=1.05884172, theta=-0.0734779374 -> V=1.078945, theta=0.0
% INFO    : Bus 1321	: V=1.039, theta=-7.53556681 -> V=1.004235, theta=0.0
% INFO    : Bus 1322	: V=1.0478023, theta=-20.6805812 -> V=1.044445, theta=0.0
% INFO    : Bus 1323	: V=1.00965921, theta=-45.3532855 -> V=0.9888895, theta=0.0
% INFO    : Bus 1324	: V=1.00956842, theta=-45.3608206 -> V=0.9888895, theta=0.0
% INFO    : Bus 1838	: V=1.00965701, theta=-45.35555 -> V=0.9888895, theta=0.0
% INFO    : Bus 1325	: V=1.03589409, theta=-41.0401173 -> V=1.046665, theta=0.0
% INFO    : Bus 1326	: V=1.04639943, theta=-34.3800374 -> V=1.0410985, theta=0.0
% INFO    : Bus 1327	: V=1.04621826, theta=-16.5253658 -> V=1.046665, theta=0.0
% INFO    : Bus 1328	: V=1.04715952, theta=-23.3905967 -> V=1.04469, theta=0.0
% INFO    : Bus 1329	: V=1.04480536, theta=-16.9426009 -> V=1.046665, theta=0.0
% INFO    : Bus 1330	: V=1.05869803, theta=-25.4616897 -> V=1.0111115, theta=0.0
% INFO    : Bus 1331	: V=1.01011107, theta=3.82871766 -> V=1.013331, theta=0.0
% INFO    : Bus 1332	: V=1.03632414, theta=-39.4550185 -> V=1.046665, theta=0.0
% INFO    : Bus 1333	: V=1.023979, theta=-39.6655299 -> V=1.046665, theta=0.0
% INFO    : Bus 1334	: V=1.0497912, theta=-16.4448797 -> V=1.0111115, theta=0.0
% INFO    : Bus 1335	: V=1.021, theta=-11.741276 -> V=1.0, theta=0.0
% INFO    : Bus 1336	: V=1.03539369, theta=-15.0003593 -> V=1.04444, theta=0.0
% INFO    : Bus 1337	: V=1.04213998, theta=-9.5810523 -> V=1.07237, theta=0.0
% INFO    : Bus 1338	: V=1.03051377, theta=-8.89830024 -> V=1.0111115, theta=0.0
% INFO    : Bus 1339	: V=1.02183078, theta=-46.1761654 -> V=0.9888895, theta=0.0
% INFO    : Bus 1340	: V=1.03921321, theta=-41.4026074 -> V=1.047735, theta=0.0
% INFO    : Bus 1341	: V=1.04486249, theta=-32.3270239 -> V=1.0409085, theta=0.0
% INFO    : Bus 1342	: V=1.0459134, theta=-24.4874158 -> V=1.04444, theta=0.0
% INFO    : Bus 1343	: V=1.05447357, theta=-13.5082454 -> V=1.067355, theta=0.0
% INFO    : Bus 1344	: V=1.05175847, theta=-33.7152007 -> V=1.047095, theta=0.0
% INFO    : Bus 1345	: V=1.05394015, theta=-33.9473861 -> V=1.047095, theta=0.0
% INFO    : Bus 1347	: V=1.04825223, theta=-31.1569993 -> V=1.073685, theta=0.0
% INFO    : Bus 1348	: V=1.02087958, theta=-46.6225843 -> V=0.9888895, theta=0.0
% INFO    : Bus 1349	: V=1.0386544, theta=-16.748725 -> V=1.0111115, theta=0.0
% INFO    : Bus 1350	: V=1.06214748, theta=-24.9500654 -> V=1.0111115, theta=0.0
% INFO    : Bus 2055	: V=1.00486885, theta=-17.6914446 -> V=1.15, theta=0.0
% INFO    : Bus 1351	: V=1.05698252, theta=-17.2507541 -> V=1.044445, theta=0.0
% INFO    : Bus 1352	: V=1.06164898, theta=-14.0363839 -> V=1.078945, theta=0.0
% INFO    : Bus 1353	: V=1.04303004, theta=-21.5961276 -> V=1.07237, theta=0.0
% INFO    : Bus 1354	: V=1.04805112, theta=-38.5055915 -> V=1.046665, theta=0.0
% INFO    : Bus 1355	: V=1.05892539, theta=-16.9779646 -> V=1.044445, theta=0.0
% INFO    : Bus 1356	: V=1.046, theta=-11.6395477 -> V=1.014075, theta=0.0
% INFO    : Bus 1357	: V=1.04870089, theta=-38.9252738 -> V=1.046665, theta=0.0
% INFO    : Bus 1358	: V=1.02494876, theta=-47.1473101 -> V=0.9888895, theta=0.0
% INFO    : Bus 1359	: V=1.03584296, theta=-25.1834594 -> V=1.04444, theta=0.0
% INFO    : Bus 1360	: V=1.03564256, theta=-40.8765214 -> V=0.9888895, theta=0.0
% INFO    : Bus 1361	: V=1.04011921, theta=-38.5662739 -> V=1.039472, theta=0.0
% INFO    : Bus 1362	: V=1.0340925, theta=-42.8710786 -> V=0.9888895, theta=0.0
% INFO    : Bus 1363	: V=1.04903588, theta=-30.937779 -> V=1.0390935, theta=0.0
% INFO    : Bus 1364	: V=1.04476096, theta=-30.0494131 -> V=1.0390935, theta=0.0
% INFO    : Bus 1365	: V=1.05107758, theta=-28.2378886 -> V=1.072365, theta=0.0
% INFO    : Bus 1366	: V=1.04221943, theta=-33.4588814 -> V=1.0398285, theta=0.0
% INFO    : Bus 1367	: V=1.04584759, theta=-29.9042302 -> V=1.072365, theta=0.0
% INFO    : Bus 1368	: V=1.04659589, theta=-29.0237451 -> V=1.072365, theta=0.0
% INFO    : Bus 1371	: V=1.0265076, theta=-41.417998 -> V=1.046665, theta=0.0
% INFO    : Bus 1372	: V=1.02225674, theta=-40.5146647 -> V=1.046665, theta=0.0
% INFO    : Bus 1373	: V=0.98671275, theta=-38.3813546 -> V=1.0, theta=0.0
% INFO    : Bus 1374	: V=1.04652104, theta=-36.2033962 -> V=1.0377785, theta=0.0
% INFO    : Bus 1375	: V=1.05025368, theta=-33.8375541 -> V=1.072365, theta=0.0
% INFO    : Bus 1376	: V=1.04409316, theta=-13.2413028 -> V=1.046665, theta=0.0
% INFO    : Bus 1377	: V=1.04898485, theta=-7.69242902 -> V=1.046665, theta=0.0
% INFO    : Bus 1378	: V=1.0263798, theta=-41.2967953 -> V=1.046665, theta=0.0
% INFO    : Bus 1379	: V=1.02639349, theta=-41.2970033 -> V=1.046665, theta=0.0
% INFO    : Bus 1380	: V=1.04497488, theta=-36.9451857 -> V=1.0377785, theta=0.0
% INFO    : Bus 1381	: V=1.02632653, theta=-41.3742922 -> V=1.046665, theta=0.0
% INFO    : Bus 1382	: V=1.09874948, theta=-35.6426875 -> V=1.072365, theta=0.0
% INFO    : Bus 1383	: V=1.04937348, theta=-32.2971406 -> V=1.072365, theta=0.0
% INFO    : Bus 2041	: V=0.992812778, theta=-36.5883743 -> V=1.15, theta=0.0
% INFO    : Bus 2042	: V=1.00228409, theta=-37.2531858 -> V=1.15, theta=0.0
% INFO    : Bus 2060	: V=0.997206345, theta=-36.946734 -> V=1.15, theta=0.0
% INFO    : Bus 2073	: V=0.985034906, theta=-36.9968508 -> V=1.15, theta=0.0
% INFO    : Bus 1384	: V=1.03515346, theta=-36.1834046 -> V=1.046665, theta=0.0
% INFO    : Bus 1385	: V=1.04490796, theta=-36.1278755 -> V=1.046665, theta=0.0
% INFO    : Bus 1386	: V=1.04142078, theta=-33.0932442 -> V=1.073685, theta=0.0
% INFO    : Bus 1387	: V=1.03122196, theta=-34.338489 -> V=1.04444, theta=0.0
% INFO    : Bus 1388	: V=1.03570575, theta=-36.2378918 -> V=1.046665, theta=0.0
% INFO    : Bus 1389	: V=0.99999899, theta=-25.5869567 -> V=1.022224, theta=0.0
% INFO    : Bus 1390	: V=1.04611492, theta=-21.4016634 -> V=1.07237, theta=0.0
% INFO    : Bus 1391	: V=1.04640243, theta=-21.2114136 -> V=1.07237, theta=0.0
% INFO    : Bus 2056	: V=0.969845413, theta=-40.64007 -> V=1.15, theta=0.0
% INFO    : Bus 2057	: V=0.921969534, theta=-39.604015 -> V=1.15, theta=0.0
% INFO    : Bus 2079	: V=0.968579053, theta=-40.1345729 -> V=1.15, theta=0.0
% INFO    : Bus 1392	: V=1.02447504, theta=-39.8289421 -> V=1.046665, theta=0.0
% INFO    : Bus 1393	: V=1.03669953, theta=-39.5734164 -> V=1.046665, theta=0.0
% INFO    : Bus 1394	: V=1.03941743, theta=-37.7462757 -> V=1.07063, theta=0.0
% INFO    : Bus 1395	: V=1.0379336, theta=-37.8914874 -> V=1.07063, theta=0.0
% INFO    : Bus 1397	: V=1.03733356, theta=-31.8704948 -> V=1.0377785, theta=0.0
% INFO    : Bus 1398	: V=1.03502011, theta=-36.7949707 -> V=1.0377785, theta=0.0
% INFO    : Bus 1399	: V=1.05340499, theta=-36.7113203 -> V=1.0377785, theta=0.0
% INFO    : Bus 1400	: V=1.05340499, theta=-36.7113203 -> V=1.0377785, theta=0.0
% INFO    : Bus 1402	: V=1.05344377, theta=-36.7315145 -> V=1.0377785, theta=0.0
% INFO    : Bus 1403	: V=1.03504305, theta=-36.8105764 -> V=1.0377785, theta=0.0
% INFO    : Bus 1404	: V=1.0436609, theta=-32.5102837 -> V=1.0435585, theta=0.0
% INFO    : Bus 1405	: V=1.017072, theta=-26.5487672 -> V=1.0111115, theta=0.0
% INFO    : Bus 1406	: V=1.03085193, theta=-17.3280682 -> V=1.0111115, theta=0.0
% INFO    : Bus 1407	: V=1.03155087, theta=-27.4782924 -> V=1.0111115, theta=0.0
% INFO    : Bus 1408	: V=1.03486659, theta=-35.209482 -> V=1.046665, theta=0.0
% INFO    : Bus 1409	: V=1.03578835, theta=-35.1916665 -> V=1.046665, theta=0.0
% INFO    : Bus 1410	: V=1.03332116, theta=-41.1481671 -> V=1.046665, theta=0.0
% INFO    : Bus 1839	: V=1.04359926, theta=-38.4959933 -> V=1.046665, theta=0.0
% INFO    : Bus 1411	: V=1.02643615, theta=-41.4248624 -> V=1.046665, theta=0.0
% INFO    : Bus 1412	: V=1.05440531, theta=-26.6908618 -> V=1.0111115, theta=0.0
% INFO    : Bus 1413	: V=1.04293875, theta=-24.0525612 -> V=1.04444, theta=0.0
% INFO    : Bus 1414	: V=1.02242937, theta=-45.1212067 -> V=0.9888895, theta=0.0
% INFO    : Bus 1415	: V=1.01528657, theta=-46.2130146 -> V=0.9888895, theta=0.0
% INFO    : Bus 1416	: V=1.02713805, theta=-42.5252703 -> V=1.05263, theta=0.0
% INFO    : Bus 1418	: V=1.02672918, theta=-47.3669933 -> V=0.9888895, theta=0.0
% INFO    : Bus 1419	: V=1.02692764, theta=-47.407233 -> V=0.9888895, theta=0.0
% INFO    : Bus 1420	: V=1.02683801, theta=-46.5934563 -> V=0.9888895, theta=0.0
% INFO    : Bus 1421	: V=1.02969799, theta=-44.5555094 -> V=1.05263, theta=0.0
% INFO    : Bus 1422	: V=1.01703045, theta=-46.2605679 -> V=0.9888895, theta=0.0
% INFO    : Bus 1423	: V=1.01721995, theta=-46.2252731 -> V=0.9888895, theta=0.0
% INFO    : Bus 1424	: V=1.01452655, theta=-47.7469103 -> V=0.9888895, theta=0.0
% INFO    : Bus 1425	: V=1.05126798, theta=-33.8638668 -> V=1.046665, theta=0.0
% INFO    : Bus 1840	: V=1.05014444, theta=-37.8628374 -> V=1.046665, theta=0.0
% INFO    : Bus 1426	: V=1.04446137, theta=-34.0754945 -> V=1.073685, theta=0.0
% INFO    : Bus 1427	: V=1.0534191, theta=-27.1286116 -> V=1.04463, theta=0.0
% INFO    : Bus 1428	: V=1.0290322, theta=-42.6214979 -> V=0.9933315, theta=0.0
% INFO    : Bus 1429	: V=1.03648169, theta=-7.87858138 -> V=1.0376435, theta=0.0
% INFO    : Bus 1430	: V=1.02330495, theta=-40.297934 -> V=1.046895, theta=0.0
% INFO    : Bus 1431	: V=1.02330611, theta=-40.2941549 -> V=1.046925, theta=0.0
% INFO    : Bus 1432	: V=1.0248225, theta=-45.0266638 -> V=0.9933315, theta=0.0
% INFO    : Bus 1433	: V=1.01620897, theta=-34.6351813 -> V=0.9888895, theta=0.0
% INFO    : Bus 1434	: V=1.05066606, theta=-19.0455135 -> V=1.046665, theta=0.0
% INFO    : Bus 1435	: V=1.0195583, theta=-46.8419773 -> V=0.9933315, theta=0.0
% INFO    : Bus 1436	: V=1.03181559, theta=-24.9396365 -> V=1.0111115, theta=0.0
% INFO    : Bus 1437	: V=1.03399252, theta=-11.0193599 -> V=1.046665, theta=0.0
% INFO    : Bus 1438	: V=1.03650941, theta=-40.8376291 -> V=1.046665, theta=0.0
% INFO    : Bus 1439	: V=1.02168799, theta=-22.2333615 -> V=1.0233335, theta=0.0
% INFO    : Bus 1440	: V=1.03621281, theta=-40.8828056 -> V=1.046665, theta=0.0
% INFO    : Bus 1441	: V=1.03678397, theta=-31.5321392 -> V=1.04444, theta=0.0
% INFO    : Bus 1442	: V=1.03842547, theta=-34.323566 -> V=0.9922395, theta=0.0
% INFO    : Bus 1443	: V=1.03187661, theta=-8.64842574 -> V=1.0111115, theta=0.0
% INFO    : Bus 1444	: V=1.03275177, theta=-6.26138395 -> V=1.046665, theta=0.0
% INFO    : Bus 1445	: V=1.04482966, theta=-36.131362 -> V=1.046665, theta=0.0
% INFO    : Bus 1446	: V=1.04502202, theta=-36.1327953 -> V=1.046665, theta=0.0
% INFO    : Bus 1447	: V=1.03012598, theta=-9.33697988 -> V=1.0111115, theta=0.0
% INFO    : Bus 1448	: V=1.0422969, theta=-33.8617022 -> V=1.073685, theta=0.0
% INFO    : Bus 1449	: V=1.02239673, theta=-23.8736708 -> V=1.003335, theta=0.0
% INFO    : Bus 1450	: V=1.03733168, theta=-35.9469819 -> V=1.046665, theta=0.0
% INFO    : Bus 1451	: V=1.03725477, theta=-35.9656569 -> V=1.046665, theta=0.0
% INFO    : Bus 1452	: V=1.04415441, theta=-25.5974395 -> V=1.04444, theta=0.0
% INFO    : Bus 1453	: V=1.04962838, theta=-33.2051548 -> V=1.04444, theta=0.0
% INFO    : Bus 1454	: V=1.04996608, theta=-15.1605444 -> V=1.046665, theta=0.0
% INFO    : Bus 1455	: V=1.02849687, theta=-11.5452204 -> V=1.0111115, theta=0.0
% INFO    : Bus 1456	: V=1.04885143, theta=-28.5688127 -> V=1.0111115, theta=0.0
% INFO    : Bus 1457	: V=1.03520868, theta=-40.1751227 -> V=0.9933315, theta=0.0
% INFO    : Bus 1458	: V=1.02735429, theta=-27.930736 -> V=0.9888895, theta=0.0
% INFO    : Bus 1459	: V=1.04100695, theta=-32.1338765 -> V=0.9888895, theta=0.0
% INFO    : Bus 1460	: V=1.04319148, theta=-20.3477031 -> V=1.046665, theta=0.0
% INFO    : Bus 1461	: V=1.03145403, theta=-24.7445487 -> V=1.04444, theta=0.0
% INFO    : Bus 1462	: V=1.01971284, theta=-46.2389352 -> V=0.9933315, theta=0.0
% INFO    : Bus 1463	: V=1.03992202, theta=-29.4214232 -> V=1.046665, theta=0.0
% INFO    : Bus 1464	: V=1.0422747, theta=-19.7942853 -> V=1.046665, theta=0.0
% INFO    : Bus 1465	: V=1.03699745, theta=-36.3223456 -> V=0.9888895, theta=0.0
% INFO    : Bus 1466	: V=1.03600698, theta=-27.30873 -> V=1.04444, theta=0.0
% INFO    : Bus 1467	: V=1.03389346, theta=-41.5429542 -> V=1.046665, theta=0.0
% INFO    : Bus 1468	: V=1.03378302, theta=-41.5481501 -> V=1.046665, theta=0.0
% INFO    : Bus 1469	: V=1.04210531, theta=-40.485703 -> V=1.046665, theta=0.0
% INFO    : Bus 1470	: V=1.04172149, theta=-40.5300852 -> V=1.046665, theta=0.0
% INFO    : Bus 1471	: V=1.02379166, theta=-40.0682958 -> V=1.046935, theta=0.0
% INFO    : Bus 1472	: V=1.03685039, theta=-39.7500946 -> V=1.046665, theta=0.0
% INFO    : Bus 1473	: V=1.03967583, theta=-34.5728705 -> V=0.9913045, theta=0.0
% INFO    : Bus 1474	: V=1.03477899, theta=-31.6305235 -> V=1.04444, theta=0.0
% INFO    : Bus 1475	: V=1.03494858, theta=-31.69161 -> V=1.04444, theta=0.0
% INFO    : Bus 1476	: V=1.03854719, theta=-37.1539701 -> V=0.9888895, theta=0.0
% INFO    : Bus 1477	: V=1.03689933, theta=-40.469202 -> V=1.046665, theta=0.0
% INFO    : Bus 1478	: V=1.05193591, theta=-20.102661 -> V=1.04444, theta=0.0
% INFO    : Bus 1479	: V=1.0363644, theta=-16.6289848 -> V=1.0111115, theta=0.0
% INFO    : Bus 1480	: V=1.0282467, theta=-46.9152597 -> V=0.9933315, theta=0.0
% INFO    : Bus 1481	: V=1.03924371, theta=-40.1424809 -> V=1.046665, theta=0.0
% INFO    : Bus 1482	: V=1.03943745, theta=-40.1641207 -> V=1.046665, theta=0.0
% INFO    : Bus 1483	: V=1.04741907, theta=-37.702081 -> V=0.9888895, theta=0.0
% INFO    : Bus 1484	: V=1.03823096, theta=-35.2018429 -> V=0.9911945, theta=0.0
% INFO    : Bus 1485	: V=1.03991303, theta=-5.93815586 -> V=1.046665, theta=0.0
% INFO    : Bus 1486	: V=1.0357428, theta=-20.4586099 -> V=1.0111115, theta=0.0
% INFO    : Bus 1487	: V=1.07242669, theta=-28.1877346 -> V=1.0000025, theta=0.0
% INFO    : Bus 1488	: V=1.03659121, theta=-23.1674863 -> V=1.04444, theta=0.0
% INFO    : Bus 1489	: V=1.04005487, theta=-11.6017298 -> V=1.046665, theta=0.0
% INFO    : Bus 1490	: V=1.03323161, theta=-40.3346093 -> V=1.046665, theta=0.0
% INFO    : Bus 1491	: V=1.04471539, theta=-16.0015263 -> V=1.046665, theta=0.0
% INFO    : Bus 1492	: V=1.03770614, theta=-18.2376143 -> V=1.0111115, theta=0.0
% INFO    : Bus 1493	: V=1.05000166, theta=-15.1352357 -> V=1.046665, theta=0.0
% INFO    : Bus 1494	: V=1.04441345, theta=-38.5074005 -> V=1.046665, theta=0.0
% INFO    : Bus 1495	: V=1.04386061, theta=-38.596491 -> V=1.046665, theta=0.0
% INFO    : Bus 1496	: V=1.03673157, theta=-35.951774 -> V=1.046665, theta=0.0
% INFO    : Bus 1497	: V=1.04622497, theta=-37.5964101 -> V=0.9888895, theta=0.0
% INFO    : Bus 1498	: V=1.03986617, theta=-34.7921202 -> V=0.9888895, theta=0.0
% INFO    : Bus 1499	: V=1.03795072, theta=-31.7793901 -> V=0.9890595, theta=0.0
% INFO    : Bus 1500	: V=1.02152278, theta=-19.8433954 -> V=1.0111115, theta=0.0
% INFO    : Bus 1501	: V=1.03950882, theta=-35.0077677 -> V=0.9892445, theta=0.0
% INFO    : Bus 1502	: V=1.04603323, theta=-36.3586744 -> V=1.046665, theta=0.0
% INFO    : Bus 1503	: V=1.03600563, theta=-7.34745436 -> V=1.046665, theta=0.0
% INFO    : Bus 1504	: V=1.03937868, theta=-18.1651536 -> V=1.046665, theta=0.0
% INFO    : Bus 1505	: V=1.03648219, theta=-19.3373887 -> V=1.0111115, theta=0.0
% INFO    : Bus 1506	: V=1.05322495, theta=-17.7351463 -> V=1.046665, theta=0.0
% INFO    : Bus 1507	: V=1.03151363, theta=-9.81301689 -> V=1.0375685, theta=0.0
% INFO    : Bus 1508	: V=1.03518314, theta=-36.2621771 -> V=1.046665, theta=0.0
% INFO    : Bus 1509	: V=1.03530011, theta=-36.2488668 -> V=1.046665, theta=0.0
% INFO    : Bus 1510	: V=1.04549402, theta=-37.8556867 -> V=1.046665, theta=0.0
% INFO    : Bus 1511	: V=1.03497609, theta=-8.10028285 -> V=1.0377285, theta=0.0
% INFO    : Bus 1512	: V=1.02494562, theta=-39.8110167 -> V=1.04719, theta=0.0
% INFO    : Bus 1513	: V=1.06481177, theta=-27.9423602 -> V=1.0000025, theta=0.0
% INFO    : Bus 1514	: V=1.04317625, theta=-32.9852006 -> V=0.9915545, theta=0.0
% INFO    : Bus 1515	: V=1.03451331, theta=-23.172689 -> V=1.04444, theta=0.0
% INFO    : Bus 1516	: V=1.09648031, theta=-35.0832413 -> V=1.072365, theta=0.0
% INFO    : Bus 1517	: V=0.991529272, theta=-29.6413665 -> V=1.0227975, theta=0.0
% INFO    : Bus 1518	: V=1.04622599, theta=-12.1144445 -> V=1.046665, theta=0.0
% INFO    : Bus 1519	: V=1.03096286, theta=-36.3615703 -> V=0.9888895, theta=0.0
% INFO    : Bus 1520	: V=1.02091677, theta=-46.3087618 -> V=0.9933315, theta=0.0
% INFO    : Bus 1521	: V=1.05522116, theta=-26.027242 -> V=1.044795, theta=0.0
% INFO    : Bus 1522	: V=1.0353126, theta=-8.00577768 -> V=1.046665, theta=0.0
% INFO    : Bus 1523	: V=1.06023741, theta=-25.7159221 -> V=1.0111115, theta=0.0
% INFO    : Bus 1524	: V=1.04899185, theta=-38.745727 -> V=1.046665, theta=0.0
% INFO    : Bus 1525	: V=1.04756274, theta=-38.4748801 -> V=1.046665, theta=0.0
% INFO    : Bus 1526	: V=1.04689709, theta=-36.3872826 -> V=1.046665, theta=0.0
% INFO    : Bus 1527	: V=1.03625192, theta=-36.5757917 -> V=1.046665, theta=0.0
% INFO    : Bus 1528	: V=1.01132176, theta=-13.3334242 -> V=1.0233335, theta=0.0
% INFO    : Bus 1529	: V=1.01380518, theta=-47.0371044 -> V=0.9933315, theta=0.0
% INFO    : Bus 1530	: V=1.03281541, theta=-44.5792936 -> V=0.9933315, theta=0.0
% INFO    : Bus 1531	: V=1.04454926, theta=-16.0179355 -> V=1.0111115, theta=0.0
% INFO    : Bus 1532	: V=1.03424589, theta=-8.26431913 -> V=1.046665, theta=0.0
% INFO    : Bus 1533	: V=1.03977149, theta=-34.3286872 -> V=0.9888895, theta=0.0
% INFO    : Bus 1534	: V=1.04983792, theta=-15.6249239 -> V=1.04586, theta=0.0
% INFO    : Bus 1535	: V=1.04146888, theta=-34.0512995 -> V=0.9888895, theta=0.0
% INFO    : Bus 1536	: V=1.03639781, theta=-40.745111 -> V=1.046665, theta=0.0
% INFO    : Bus 1537	: V=1.03971482, theta=-38.8253162 -> V=1.05263, theta=0.0
% INFO    : Bus 1538	: V=1.0346903, theta=-8.35866383 -> V=1.046665, theta=0.0
% INFO    : Bus 1539	: V=1.04179149, theta=-25.0164665 -> V=1.04444, theta=0.0
% INFO    : Bus 1540	: V=1.04590415, theta=-36.7614214 -> V=0.9888895, theta=0.0
% INFO    : Bus 1541	: V=1.04602117, theta=-16.5224949 -> V=1.046665, theta=0.0
% INFO    : Bus 1542	: V=1.04279584, theta=-21.2032318 -> V=1.046665, theta=0.0
% INFO    : Bus 1543	: V=1.03973024, theta=-33.3785316 -> V=0.9888895, theta=0.0
% INFO    : Bus 1544	: V=1.04964758, theta=-32.8708121 -> V=1.04444, theta=0.0
% INFO    : Bus 1545	: V=1.02334265, theta=-45.8209556 -> V=0.9933315, theta=0.0
% INFO    : Bus 1546	: V=1.04652869, theta=-4.67124927 -> V=1.07057, theta=0.0
% INFO    : Bus 1547	: V=1.03897279, theta=-41.2914262 -> V=1.04712, theta=0.0
% INFO    : Bus 1548	: V=1.05724496, theta=-26.5315417 -> V=1.0111115, theta=0.0
% INFO    : Bus 1549	: V=1.01454237, theta=-47.7457229 -> V=0.9933315, theta=0.0
% INFO    : Bus 1551	: V=1.03420736, theta=-43.2488677 -> V=1.06579, theta=0.0
% INFO    : Bus 1552	: V=1.05642417, theta=-16.305975 -> V=1.057895, theta=0.0
% INFO    : Bus 1553	: V=1.04518595, theta=-16.6619589 -> V=1.057895, theta=0.0
% INFO    : Bus 1554	: V=1.04980527, theta=-18.6621188 -> V=1.0, theta=0.0
% INFO    : Bus 1555	: V=1.04023565, theta=-40.1049812 -> V=1.0526315, theta=0.0
% INFO    : Bus 1556	: V=1.059863, theta=-16.5753836 -> V=1.071685, theta=0.0
% INFO    : Bus 1557	: V=1.04406222, theta=-26.5805095 -> V=1.07237, theta=0.0
% INFO    : Bus 1558	: V=1.05637296, theta=-21.3646664 -> V=1.07237, theta=0.0
% INFO    : Bus 1559	: V=1.02961195, theta=-28.2812183 -> V=1.06579, theta=0.0
% INFO    : Bus 1560	: V=1.04873459, theta=-23.1786096 -> V=1.07237, theta=0.0
% INFO    : Bus 1561	: V=1.05664113, theta=-34.2403256 -> V=1.070585, theta=0.0
% INFO    : Bus 1562	: V=1.02816846, theta=-41.5272113 -> V=1.06579, theta=0.0
% INFO    : Bus 1563	: V=1.04747746, theta=-38.6186903 -> V=1.0526315, theta=0.0
% INFO    : Bus 1564	: V=1.03870575, theta=-16.7568142 -> V=1.072365, theta=0.0
% INFO    : Bus 1565	: V=1.05760608, theta=-18.4671543 -> V=1.0, theta=0.0
% INFO    : Bus 1566	: V=1.04636436, theta=-11.8718314 -> V=1.057895, theta=0.0
% INFO    : Bus 1567	: V=1.03868953, theta=-42.0791655 -> V=1.0526315, theta=0.0
% INFO    : Bus 1568	: V=1.05636355, theta=-26.6500432 -> V=1.07237, theta=0.0
% INFO    : Bus 1569	: V=1.04937786, theta=-16.3324026 -> V=1.0, theta=0.0
% INFO    : Bus 1570	: V=1.04032142, theta=-41.0459997 -> V=1.0526315, theta=0.0
% INFO    : Bus 1571	: V=1.04015715, theta=-40.9801959 -> V=1.0666645, theta=0.0
% INFO    : Bus 1572	: V=1.0423431, theta=-33.6017373 -> V=1.06579, theta=0.0
% INFO    : Bus 1573	: V=1.0522845, theta=-12.2631299 -> V=1.0, theta=0.0
% INFO    : Bus 1574	: V=1.04479022, theta=-15.4956482 -> V=1.07237, theta=0.0
% INFO    : Bus 1575	: V=1.04788731, theta=-36.7007106 -> V=1.0526315, theta=0.0
% INFO    : Bus 1576	: V=1.06372051, theta=-25.949893 -> V=1.070635, theta=0.0
% INFO    : Bus 1577	: V=1.05325675, theta=-16.4935491 -> V=1.057895, theta=0.0
% INFO    : Bus 1578	: V=1.04915872, theta=-20.365387 -> V=1.0, theta=0.0
% INFO    : Bus 1579	: V=1.05011389, theta=-16.7966258 -> V=1.057895, theta=0.0
% INFO    : Bus 1580	: V=1.04912226, theta=-18.6882536 -> V=1.0, theta=0.0
% INFO    : Bus 1581	: V=1.05835694, theta=-16.3424752 -> V=1.069765, theta=0.0
% INFO    : Bus 1582	: V=1.05616267, theta=-20.5145346 -> V=1.07237, theta=0.0
% INFO    : Bus 1583	: V=1.05496552, theta=-16.2425648 -> V=1.0, theta=0.0
% INFO    : Bus 1584	: V=1.03494649, theta=-44.0479754 -> V=1.033267, theta=0.0
% INFO    : Bus 1585	: V=1.05356126, theta=-33.4212581 -> V=1.070555, theta=0.0
% INFO    : Bus 1586	: V=1.02763157, theta=-41.6753736 -> V=1.06579, theta=0.0
% INFO    : Bus 1587	: V=1.05250537, theta=-38.1667321 -> V=1.0526315, theta=0.0
% INFO    : Bus 1588	: V=1.03767126, theta=-15.7030964 -> V=1.072365, theta=0.0
% INFO    : Bus 1589	: V=1.02880544, theta=-40.7393146 -> V=1.0526315, theta=0.0
% INFO    : Bus 1590	: V=1.05743214, theta=-18.3617404 -> V=1.0, theta=0.0
% INFO    : Bus 1591	: V=1.04634158, theta=-11.9737201 -> V=1.057895, theta=0.0
% INFO    : Bus 1592	: V=1.03757777, theta=-40.9985543 -> V=1.0526315, theta=0.0
% INFO    : Bus 1593	: V=1.0550596, theta=-16.2537089 -> V=1.0, theta=0.0
% INFO    : Bus 1594	: V=1.04322948, theta=-40.9603684 -> V=1.0666645, theta=0.0
% INFO    : Bus 1595	: V=1.05245813, theta=-12.1372928 -> V=1.0, theta=0.0
% INFO    : Bus 1596	: V=1.05925107, theta=-17.8097194 -> V=1.0, theta=0.0
% INFO    : Bus 1597	: V=1.04407219, theta=-36.7292805 -> V=1.0526315, theta=0.0
% INFO    : Bus 1598	: V=1.0261132, theta=-40.7029406 -> V=1.0526315, theta=0.0
% INFO    : Bus 1599	: V=1.06487539, theta=-25.5606112 -> V=1.065225, theta=0.0
% INFO    : Bus 1600	: V=1.02868869, theta=-43.3195299 -> V=1.06579, theta=0.0
% INFO    : Bus 1601	: V=1.03875769, theta=-24.8348332 -> V=1.072365, theta=0.0
% INFO    : Bus 1602	: V=1.04395693, theta=-40.7738855 -> V=1.0526315, theta=0.0
% INFO    : Bus 1603	: V=1.03702577, theta=-35.6093796 -> V=1.0526315, theta=0.0
% INFO    : Bus 1604	: V=1.04067396, theta=-36.2737185 -> V=1.0526315, theta=0.0
% INFO    : Bus 1605	: V=1.03588436, theta=-43.2114577 -> V=1.061965, theta=0.0
% INFO    : Bus 1606	: V=1.04836999, theta=-37.1093167 -> V=1.06579, theta=0.0
% INFO    : Bus 1607	: V=1.05527696, theta=-37.9713481 -> V=1.0526315, theta=0.0
% INFO    : Bus 1608	: V=1.03285615, theta=-41.098267 -> V=1.0526315, theta=0.0
% INFO    : Bus 1609	: V=1.03864101, theta=-42.194482 -> V=1.0526315, theta=0.0
% INFO    : Bus 1610	: V=1.04975013, theta=-37.4018869 -> V=1.06579, theta=0.0
% INFO    : Bus 1611	: V=1.03973497, theta=-30.0714157 -> V=1.0526315, theta=0.0
% INFO    : Bus 1612	: V=1.04020849, theta=-37.0581826 -> V=1.0526315, theta=0.0
% INFO    : Bus 1613	: V=1.04119855, theta=-40.3807401 -> V=1.0526315, theta=0.0
% INFO    : Bus 1614	: V=1.04600544, theta=-25.0800326 -> V=1.07237, theta=0.0
% INFO    : Bus 1615	: V=1.04751598, theta=-38.6541879 -> V=1.0526315, theta=0.0
% INFO    : Bus 1616	: V=1.03866481, theta=-41.1329646 -> V=1.0526315, theta=0.0
% INFO    : Bus 1617	: V=1.04471582, theta=-38.7073189 -> V=1.0526315, theta=0.0
% INFO    : Bus 1618	: V=1.05005829, theta=-37.9166353 -> V=1.06579, theta=0.0
% INFO    : Bus 1619	: V=1.04485331, theta=-30.0633148 -> V=1.0526315, theta=0.0
% INFO    : Bus 1620	: V=1.05023847, theta=-37.0024575 -> V=1.0526315, theta=0.0
% INFO    : Bus 1621	: V=1.02375736, theta=-40.2246661 -> V=1.0526315, theta=0.0
% INFO    : Bus 1622	: V=1.03752132, theta=-40.2841004 -> V=1.0526315, theta=0.0
% INFO    : Bus 1623	: V=1.0880989, theta=-34.4314036 -> V=1.083, theta=0.0
% INFO    : Bus 1624	: V=1.04116949, theta=-25.0235451 -> V=1.07237, theta=0.0
% INFO    : Bus 1625	: V=1.03686977, theta=-29.5126276 -> V=1.06579, theta=0.0
% INFO    : Bus 1626	: V=1.05357316, theta=-37.3107545 -> V=1.0526315, theta=0.0
% INFO    : Bus 1627	: V=1.03767606, theta=-39.7426206 -> V=1.0526315, theta=0.0
% INFO    : Bus 1628	: V=0.95, theta=0.785967059 -> V=1.0, theta=0.0
% INFO    : Bus 1629	: V=0.95, theta=3.89991599 -> V=1.0, theta=0.0
% INFO    : Bus 1844	: V=0.885, theta=-8.31011447 -> V=1.0077585, theta=0.0
% INFO    : Bus 1630	: V=0.928, theta=5.05139212 -> V=0.9887625, theta=0.0
% INFO    : Bus 1631	: V=0.93, theta=-1.4763482 -> V=0.989957, theta=0.0
% INFO    : Bus 1846	: V=1.034, theta=0.477910041 -> V=1.0, theta=0.0
% INFO    : Bus 1632	: V=1.034, theta=0.477910041 -> V=1.0, theta=0.0
% INFO    : Bus 1847	: V=1.034, theta=0.478539929 -> V=1.0, theta=0.0
% INFO    : Bus 1848	: V=1.034, theta=0.478539929 -> V=1.0, theta=0.0
% INFO    : Bus 1852	: V=1.01, theta=-13.8649983 -> V=1.0, theta=0.0
% INFO    : Bus 1854	: V=1.031, theta=-15.1723716 -> V=1.0, theta=0.0
% INFO    : Bus 1633	: V=1.0, theta=-3.31397778 -> V=1.001355, theta=0.0
% INFO    : Bus 1634	: V=0.999, theta=-3.08838721 -> V=1.000525, theta=0.0
% INFO    : Bus 1635	: V=0.999, theta=-3.07713384 -> V=1.00053, theta=0.0
% INFO    : Bus 1636	: V=1.0, theta=-3.312775 -> V=1.0, theta=0.0
% INFO    : Bus 1637	: V=0.954, theta=-27.6547057 -> V=1.0, theta=0.0
% INFO    : Bus 1638	: V=0.954, theta=-27.6822971 -> V=1.0, theta=0.0
% INFO    : Bus 1639	: V=0.977, theta=-27.0762093 -> V=1.0, theta=0.0
% INFO    : Bus 1640	: V=0.983, theta=-28.293984 -> V=1.0, theta=0.0
% INFO    : Bus 1641	: V=0.986, theta=-27.3659298 -> V=1.003735, theta=0.0
% INFO    : Bus 1642	: V=0.988, theta=-4.72087102 -> V=1.0, theta=0.0
% INFO    : Bus 1643	: V=0.988, theta=-1.84097747 -> V=1.0, theta=0.0
% INFO    : Bus 1855	: V=0.988, theta=-4.72087102 -> V=1.0, theta=0.0
% INFO    : Bus 1644	: V=0.988, theta=-1.82838786 -> V=1.0, theta=0.0
% INFO    : Bus 1645	: V=0.988, theta=-1.89762831 -> V=1.0, theta=0.0
% INFO    : Bus 1646	: V=0.95, theta=-41.9730172 -> V=1.00036, theta=0.0
% INFO    : Bus 1647	: V=1.045, theta=-14.1039925 -> V=1.0, theta=0.0
% INFO    : Bus 1861	: V=1.048, theta=-20.1785561 -> V=1.0, theta=0.0
% INFO    : Bus 1648	: V=0.963, theta=-7.02631603 -> V=0.990834, theta=0.0
% INFO    : Bus 1649	: V=0.946, theta=-6.62495906 -> V=0.9895395, theta=0.0
% INFO    : Bus 1650	: V=0.964, theta=-7.16569218 -> V=0.9875395, theta=0.0
% INFO    : Bus 1651	: V=0.946, theta=-6.84062234 -> V=0.994603, theta=0.0
% INFO    : Bus 1652	: V=0.945, theta=-23.6171627 -> V=0.9975895, theta=0.0
% INFO    : Bus 1862	: V=0.948, theta=-23.6280508 -> V=0.99881, theta=0.0
% INFO    : Bus 1653	: V=1.029, theta=-2.65540809 -> V=1.0, theta=0.0
% INFO    : Bus 1654	: V=1.029, theta=-2.65540809 -> V=1.0, theta=0.0
% INFO    : Bus 1655	: V=1.029, theta=-2.65540809 -> V=1.0, theta=0.0
% INFO    : Bus 1656	: V=1.029, theta=-2.65540809 -> V=1.0, theta=0.0
% INFO    : Bus 1657	: V=1.029, theta=-2.65540809 -> V=1.0, theta=0.0
% INFO    : Bus 1658	: V=1.029, theta=-2.65540809 -> V=1.0, theta=0.0
% INFO    : Bus 1863	: V=0.979, theta=-0.717395211 -> V=1.0, theta=0.0
% INFO    : Bus 1659	: V=0.979, theta=-0.717395211 -> V=1.0, theta=0.0
% INFO    : Bus 1660	: V=0.979, theta=-0.717395211 -> V=1.0, theta=0.0
% INFO    : Bus 1661	: V=0.979, theta=-0.717395211 -> V=1.0, theta=0.0
% INFO    : Bus 1662	: V=0.978, theta=-1.1716273 -> V=1.0, theta=0.0
% INFO    : Bus 1663	: V=0.978, theta=-1.1716273 -> V=1.0, theta=0.0
% INFO    : Bus 1865	: V=0.942, theta=-1.10774425 -> V=1.0, theta=0.0
% INFO    : Bus 1866	: V=0.978, theta=-3.05947653 -> V=1.0, theta=0.0
% INFO    : Bus 1664	: V=0.978, theta=-3.05947653 -> V=1.0, theta=0.0
% INFO    : Bus 1665	: V=0.978, theta=-3.05947653 -> V=1.0, theta=0.0
% INFO    : Bus 1867	: V=0.978, theta=-3.05947653 -> V=1.0, theta=0.0
% INFO    : Bus 1666	: V=0.979, theta=-2.75017342 -> V=1.0, theta=0.0
% INFO    : Bus 1868	: V=0.979, theta=-2.75017342 -> V=1.0, theta=0.0
% INFO    : Bus 1667	: V=0.947, theta=-19.3164289 -> V=0.996488, theta=0.0
% INFO    : Bus 1668	: V=0.952, theta=-19.962904 -> V=0.995021, theta=0.0
% INFO    : Bus 1669	: V=0.953, theta=-20.0988116 -> V=0.993275, theta=0.0
% INFO    : Bus 1670	: V=0.916, theta=-24.6270571 -> V=1.0094195, theta=0.0
% INFO    : Bus 1873	: V=1.003, theta=-17.7288413 -> V=1.0, theta=0.0
% INFO    : Bus 1874	: V=1.003, theta=-17.7288413 -> V=1.0, theta=0.0
% INFO    : Bus 1671	: V=0.95, theta=-9.6776982 -> V=1.0, theta=0.0
% INFO    : Bus 1673	: V=0.95, theta=-9.63782819 -> V=1.0, theta=0.0
% INFO    : Bus 1674	: V=0.949, theta=-9.63841894 -> V=0.9995685, theta=0.0
% INFO    : Bus 1675	: V=0.944, theta=-33.1166206 -> V=0.9996345, theta=0.0
% INFO    : Bus 1676	: V=0.95, theta=-34.1783691 -> V=1.00522, theta=0.0
% INFO    : Bus 1875	: V=0.973, theta=-1.33135873 -> V=1.0, theta=0.0
% INFO    : Bus 1677	: V=0.971, theta=-1.28879858 -> V=1.0, theta=0.0
% INFO    : Bus 2022	: V=1.077, theta=-22.1945619 -> V=1.0, theta=0.0
% INFO    : Bus 1876	: V=1.077, theta=-22.1945619 -> V=1.0, theta=0.0
% INFO    : Bus 1877	: V=1.077, theta=-22.1945619 -> V=1.0, theta=0.0
% INFO    : Bus 1878	: V=1.077, theta=-22.1945619 -> V=1.0, theta=0.0
% INFO    : Bus 1678	: V=0.957, theta=-29.2409759 -> V=1.0, theta=0.0
% INFO    : Bus 1679	: V=0.957, theta=-29.2409801 -> V=1.0, theta=0.0
% INFO    : Bus 1680	: V=0.961, theta=-41.3115962 -> V=1.0, theta=0.0
% INFO    : Bus 1681	: V=0.95, theta=-20.2931301 -> V=1.0, theta=0.0
% INFO    : Bus 1682	: V=0.928, theta=-15.0057785 -> V=0.9802185, theta=0.0
% INFO    : Bus 1683	: V=0.933, theta=-15.0324228 -> V=0.980023, theta=0.0
% INFO    : Bus 1684	: V=0.954, theta=-20.1901887 -> V=1.0, theta=0.0
% INFO    : Bus 1881	: V=0.957, theta=0.978519986 -> V=1.0, theta=0.0
% INFO    : Bus 1882	: V=0.957, theta=0.978519986 -> V=1.0, theta=0.0
% INFO    : Bus 1685	: V=0.957, theta=0.978519986 -> V=1.0, theta=0.0
% INFO    : Bus 1883	: V=0.957, theta=0.978519986 -> V=1.0, theta=0.0
% INFO    : Bus 1884	: V=0.957, theta=0.978519986 -> V=1.0, theta=0.0
% INFO    : Bus 1885	: V=0.957, theta=0.978519986 -> V=1.0, theta=0.0
% INFO    : Bus 1686	: V=0.972, theta=6.33236515 -> V=1.0, theta=0.0
% INFO    : Bus 1687	: V=0.973, theta=6.32170159 -> V=1.0, theta=0.0
% INFO    : Bus 1688	: V=0.974, theta=6.29140858 -> V=1.0, theta=0.0
% INFO    : Bus 1689	: V=0.963536254, theta=-1.41026216 -> V=1.0, theta=0.0
% INFO    : Bus 1888	: V=0.983, theta=-5.46832863 -> V=1.0, theta=0.0
% INFO    : Bus 1690	: V=0.922, theta=9.86164236 -> V=0.9858785, theta=0.0
% INFO    : Bus 1691	: V=0.95, theta=1.5854153 -> V=1.0, theta=0.0
% INFO    : Bus 1692	: V=0.99, theta=-27.2779464 -> V=1.01132, theta=0.0
% INFO    : Bus 1693	: V=0.95, theta=-40.3312415 -> V=1.0, theta=0.0
% INFO    : Bus 1694	: V=0.95, theta=-40.1886488 -> V=1.0, theta=0.0
% INFO    : Bus 1695	: V=0.95, theta=-43.2517829 -> V=1.0, theta=0.0
% INFO    : Bus 1696	: V=0.95, theta=-43.7773504 -> V=1.0, theta=0.0
% INFO    : Bus 1697	: V=0.95, theta=-26.9153438 -> V=1.0, theta=0.0
% INFO    : Bus 1698	: V=0.95, theta=-26.9153438 -> V=1.0, theta=0.0
% INFO    : Bus 1699	: V=0.95, theta=-26.8578115 -> V=1.0, theta=0.0
% INFO    : Bus 1700	: V=0.95, theta=-26.7090423 -> V=1.0, theta=0.0
% INFO    : Bus 1701	: V=0.96, theta=-13.5690051 -> V=1.0, theta=0.0
% INFO    : Bus 1702	: V=0.982, theta=-30.6724968 -> V=1.0, theta=0.0
% INFO    : Bus 1703	: V=0.982, theta=-30.6724968 -> V=1.0, theta=0.0
% INFO    : Bus 1889	: V=0.982, theta=-30.6724968 -> V=1.0, theta=0.0
% INFO    : Bus 1704	: V=0.988, theta=-7.16192846 -> V=1.0, theta=0.0
% INFO    : Bus 1705	: V=0.985, theta=-7.10994065 -> V=1.0, theta=0.0
% INFO    : Bus 1890	: V=0.964, theta=-35.447128 -> V=1.0, theta=0.0
% INFO    : Bus 1891	: V=0.964, theta=-35.447128 -> V=1.0, theta=0.0
% INFO    : Bus 1892	: V=0.964, theta=-35.4282074 -> V=1.0, theta=0.0
% INFO    : Bus 1706	: V=0.962, theta=-32.9041963 -> V=1.0, theta=0.0
% INFO    : Bus 1707	: V=0.975, theta=-33.5792954 -> V=1.0, theta=0.0
% INFO    : Bus 2026	: V=0.976, theta=-34.8549383 -> V=1.0, theta=0.0
% INFO    : Bus 1898	: V=0.976, theta=-34.8549383 -> V=1.0, theta=0.0
% INFO    : Bus 1708	: V=0.984, theta=-33.5319076 -> V=1.0, theta=0.0
% INFO    : Bus 1709	: V=0.975, theta=-33.5792954 -> V=1.0, theta=0.0
% INFO    : Bus 1710	: V=0.984, theta=-2.60248362 -> V=1.0, theta=0.0
% INFO    : Bus 1711	: V=0.984, theta=-2.60248362 -> V=1.0, theta=0.0
% INFO    : Bus 1712	: V=0.981, theta=-1.23816443 -> V=1.0, theta=0.0
% INFO    : Bus 1713	: V=0.98, theta=-1.24717291 -> V=1.001985, theta=0.0
% INFO    : Bus 1714	: V=0.95, theta=10.656486 -> V=1.01466, theta=0.0
% INFO    : Bus 1715	: V=0.95, theta=-40.0752752 -> V=1.0, theta=0.0
% INFO    : Bus 1716	: V=0.95, theta=-40.0412952 -> V=1.0, theta=0.0
% INFO    : Bus 1717	: V=0.945, theta=-39.7009594 -> V=0.993595, theta=0.0
% INFO    : Bus 1718	: V=0.948, theta=-39.899122 -> V=0.9987595, theta=0.0
% INFO    : Bus 1719	: V=0.95, theta=-40.0617459 -> V=1.0, theta=0.0
% INFO    : Bus 1720	: V=0.95, theta=-40.6807092 -> V=1.0, theta=0.0
% INFO    : Bus 1721	: V=0.95, theta=-42.6609884 -> V=1.0, theta=0.0
% INFO    : Bus 1906	: V=0.997, theta=-11.883927 -> V=1.0, theta=0.0
% INFO    : Bus 1907	: V=0.997, theta=-11.883927 -> V=1.0, theta=0.0
% INFO    : Bus 1908	: V=0.996, theta=-11.8822957 -> V=1.0, theta=0.0
% INFO    : Bus 1909	: V=0.996, theta=-11.8822957 -> V=1.0, theta=0.0
% INFO    : Bus 1910	: V=0.997, theta=-11.883927 -> V=1.0, theta=0.0
% INFO    : Bus 1911	: V=0.997, theta=-11.883927 -> V=1.0, theta=0.0
% INFO    : Bus 1912	: V=0.996, theta=-11.8822957 -> V=1.0, theta=0.0
% INFO    : Bus 1913	: V=0.996, theta=-11.8822957 -> V=1.0, theta=0.0
% INFO    : Bus 1722	: V=0.95, theta=-17.4947862 -> V=1.0, theta=0.0
% INFO    : Bus 1723	: V=0.969, theta=-29.2516897 -> V=1.005505, theta=0.0
% INFO    : Bus 1724	: V=0.966278691, theta=-32.5864911 -> V=1.0, theta=0.0
% INFO    : Bus 1725	: V=0.951, theta=-27.405375 -> V=1.0, theta=0.0
% INFO    : Bus 1919	: V=1.027, theta=-34.2229244 -> V=1.0, theta=0.0
% INFO    : Bus 1920	: V=1.026, theta=-33.5585897 -> V=1.0, theta=0.0
% INFO    : Bus 1921	: V=1.029, theta=-36.5669417 -> V=1.0, theta=0.0
% INFO    : Bus 1922	: V=1.029, theta=-36.5669417 -> V=1.0, theta=0.0
% INFO    : Bus 1923	: V=1.029, theta=-36.4861438 -> V=1.003055, theta=0.0
% INFO    : Bus 1924	: V=1.029, theta=-36.4862906 -> V=1.000705, theta=0.0
% INFO    : Bus 1726	: V=0.979, theta=-0.592546587 -> V=1.0, theta=0.0
% INFO    : Bus 1727	: V=0.979, theta=-0.592546587 -> V=1.0, theta=0.0
% INFO    : Bus 1728	: V=0.978, theta=-0.586236664 -> V=1.0, theta=0.0
% INFO    : Bus 1928	: V=0.979, theta=-0.592546587 -> V=1.0, theta=0.0
% INFO    : Bus 1729	: V=0.943, theta=-24.936807 -> V=0.9963875, theta=0.0
% INFO    : Bus 1931	: V=1.024, theta=-20.4988596 -> V=1.0, theta=0.0
% INFO    : Bus 1932	: V=1.033, theta=-18.9518651 -> V=0.9964755, theta=0.0
% INFO    : Bus 1934	: V=1.023, theta=-20.2261346 -> V=1.0, theta=0.0
% INFO    : Bus 1935	: V=0.969, theta=0.865594602 -> V=1.0, theta=0.0
% INFO    : Bus 1936	: V=0.969, theta=0.865594602 -> V=1.0, theta=0.0
% INFO    : Bus 1937	: V=0.969, theta=0.865594602 -> V=1.0, theta=0.0
% INFO    : Bus 1938	: V=0.934, theta=-0.839195379 -> V=1.0, theta=0.0
% INFO    : Bus 1730	: V=0.958, theta=-29.8579715 -> V=1.0, theta=0.0
% INFO    : Bus 1731	: V=0.96, theta=-29.7363016 -> V=1.0, theta=0.0
% INFO    : Bus 1944	: V=0.848, theta=-11.3718605 -> V=0.9740405, theta=0.0
% INFO    : Bus 1732	: V=0.988, theta=-20.6573203 -> V=1.0, theta=0.0
% INFO    : Bus 1733	: V=0.95, theta=-35.0377505 -> V=1.0, theta=0.0
% INFO    : Bus 1734	: V=0.95, theta=-35.0377996 -> V=1.0, theta=0.0
% INFO    : Bus 1950	: V=0.935, theta=-2.93050587 -> V=1.0, theta=0.0
% INFO    : Bus 1951	: V=0.93, theta=-2.82823089 -> V=1.0, theta=0.0
% INFO    : Bus 1952	: V=0.936, theta=-2.8830046 -> V=1.0, theta=0.0
% INFO    : Bus 1953	: V=0.936, theta=-2.86598716 -> V=1.0, theta=0.0
% INFO    : Bus 1735	: V=0.958, theta=-27.0948304 -> V=0.9992375, theta=0.0
% INFO    : Bus 1736	: V=0.958, theta=-27.0980821 -> V=0.9989805, theta=0.0
% INFO    : Bus 1737	: V=0.965, theta=-30.6677018 -> V=1.0, theta=0.0
% INFO    : Bus 1738	: V=0.965, theta=-30.6677018 -> V=1.0, theta=0.0
% INFO    : Bus 1739	: V=0.965, theta=-30.6677018 -> V=1.0, theta=0.0
% INFO    : Bus 1740	: V=0.95, theta=3.42227015 -> V=1.00019, theta=0.0
% INFO    : Bus 1741	: V=0.946, theta=2.79257662 -> V=0.990919, theta=0.0
% INFO    : Bus 1742	: V=0.95, theta=-32.8333262 -> V=1.0, theta=0.0
% INFO    : Bus 1958	: V=0.961, theta=-1.77578694 -> V=1.0, theta=0.0
% INFO    : Bus 1959	: V=0.961, theta=-1.77578694 -> V=1.0, theta=0.0
% INFO    : Bus 1743	: V=1.025, theta=-31.8656677 -> V=1.001565, theta=0.0
% INFO    : Bus 1744	: V=0.958, theta=-20.8274793 -> V=1.0, theta=0.0
% INFO    : Bus 1745	: V=0.965, theta=-21.5751758 -> V=0.9990525, theta=0.0
% INFO    : Bus 1746	: V=0.965, theta=-21.5149349 -> V=1.0, theta=0.0
% INFO    : Bus 1961	: V=0.967, theta=-27.6931686 -> V=1.005325, theta=0.0
% INFO    : Bus 1747	: V=1.006, theta=-15.9500264 -> V=1.0, theta=0.0
% INFO    : Bus 1748	: V=0.959, theta=-26.638511 -> V=1.0, theta=0.0
% INFO    : Bus 1749	: V=0.959, theta=-26.663436 -> V=1.0, theta=0.0
% INFO    : Bus 1750	: V=0.95, theta=-32.0784735 -> V=1.0, theta=0.0
% INFO    : Bus 1751	: V=0.95, theta=-32.0784735 -> V=1.0, theta=0.0
% INFO    : Bus 1752	: V=0.95, theta=-31.8926017 -> V=1.0, theta=0.0
% INFO    : Bus 1753	: V=0.952, theta=-32.2923566 -> V=1.0, theta=0.0
% INFO    : Bus 2058	: V=0.972, theta=-9.55519013 -> V=1.0, theta=0.0
% INFO    : Bus 1754	: V=0.929, theta=1.77112372 -> V=0.989297, theta=0.0
% INFO    : Bus 1755	: V=0.927, theta=2.8125606 -> V=0.988606, theta=0.0
% INFO    : Bus 1756	: V=1.014, theta=8.51924606 -> V=1.0, theta=0.0
% INFO    : Bus 1757	: V=0.958, theta=-38.0641119 -> V=1.014235, theta=0.0
% INFO    : Bus 1758	: V=1.036, theta=-15.371094 -> V=1.0, theta=0.0
% INFO    : Bus 1759	: V=1.036, theta=-15.3711078 -> V=1.0, theta=0.0
% INFO    : Bus 1760	: V=1.036, theta=-15.3701016 -> V=1.0, theta=0.0
% INFO    : Bus 1970	: V=1.036, theta=-14.0365156 -> V=1.0, theta=0.0
% INFO    : Bus 1971	: V=1.037, theta=-18.2315387 -> V=1.0, theta=0.0
% INFO    : Bus 1972	: V=1.036, theta=-14.0365156 -> V=1.0, theta=0.0
% INFO    : Bus 1973	: V=1.034, theta=-14.3598915 -> V=1.0, theta=0.0
% INFO    : Bus 1974	: V=0.982, theta=-37.4310673 -> V=1.0, theta=0.0
% INFO    : Bus 1975	: V=1.003, theta=-37.84661 -> V=1.003145, theta=0.0
% INFO    : Bus 1976	: V=0.982, theta=-37.4310673 -> V=1.0, theta=0.0
% INFO    : Bus 1977	: V=0.982, theta=-37.430798 -> V=1.00145, theta=0.0
% INFO    : Bus 1761	: V=0.964, theta=-32.0084847 -> V=1.0, theta=0.0
% INFO    : Bus 1762	: V=0.964, theta=-31.7944365 -> V=1.0, theta=0.0
% INFO    : Bus 1978	: V=0.967, theta=-34.8087317 -> V=1.0, theta=0.0
% INFO    : Bus 1769	: V=1.028, theta=-7.13396573 -> V=1.0, theta=0.0
% INFO    : Bus 1770	: V=1.028, theta=-7.13396573 -> V=1.0, theta=0.0
% INFO    : Bus 1979	: V=1.001, theta=-0.596904071 -> V=1.0, theta=0.0
% INFO    : Bus 1980	: V=0.971, theta=0.454922012 -> V=1.0, theta=0.0
% INFO    : Bus 1771	: V=0.948, theta=-1.02687066 -> V=1.0, theta=0.0
% INFO    : Bus 1993	: V=1.003, theta=-3.22548767 -> V=1.0, theta=0.0
% INFO    : Bus 1772	: V=0.952, theta=-1.16165499 -> V=0.997577, theta=0.0
% INFO    : Bus 1995	: V=0.952, theta=-1.16165387 -> V=0.9964485, theta=0.0
% INFO    : Bus 1773	: V=0.97, theta=-29.650231 -> V=1.0, theta=0.0
% INFO    : Bus 1774	: V=0.961, theta=-30.2969847 -> V=0.9985055, theta=0.0
% INFO    : Bus 1775	: V=0.949, theta=-26.5277715 -> V=0.997161, theta=0.0
% INFO    : Bus 1776	: V=0.938663518, theta=-29.5625086 -> V=0.9944205, theta=0.0
% INFO    : Bus 1996	: V=0.962, theta=3.22853751 -> V=1.0, theta=0.0
% INFO    : Bus 1997	: V=0.961, theta=3.23600512 -> V=1.0, theta=0.0
% INFO    : Bus 2000	: V=0.917, theta=-0.334452667 -> V=1.0, theta=0.0
% INFO    : Bus 1777	: V=0.948, theta=-14.3714251 -> V=0.9967005, theta=0.0
% INFO    : Bus 1778	: V=0.948, theta=-14.3405098 -> V=0.9991795, theta=0.0
% INFO    : Bus 1779	: V=0.977, theta=-0.113815005 -> V=1.0, theta=0.0
% INFO    : Bus 2002	: V=0.977, theta=-0.113815005 -> V=1.0, theta=0.0
% INFO    : Bus 1780	: V=1.042, theta=-32.6305851 -> V=1.0106, theta=0.0
% INFO    : Bus 2028	: V=1.045, theta=-35.7133299 -> V=1.01086, theta=0.0
% INFO    : Bus 1781	: V=1.042, theta=-32.6328513 -> V=1.010775, theta=0.0
% INFO    : Bus 1782	: V=1.042, theta=-32.6305851 -> V=1.010715, theta=0.0
% INFO    : Bus 2004	: V=1.066, theta=-23.4782216 -> V=1.0, theta=0.0
% INFO    : Bus 2023	: V=1.066, theta=-23.4782216 -> V=1.0, theta=0.0
% INFO    : Bus 2024	: V=1.066, theta=-23.4782216 -> V=1.0, theta=0.0
% INFO    : Bus 2005	: V=1.066, theta=-23.4782216 -> V=1.0, theta=0.0
% INFO    : Bus 1783	: V=0.992, theta=11.6480259 -> V=1.0, theta=0.0
% INFO    : Bus 1784	: V=0.994, theta=11.5266043 -> V=1.0, theta=0.0
% INFO    : Bus 1785	: V=0.993, theta=11.2994557 -> V=1.0, theta=0.0
% INFO    : Bus 1786	: V=0.993, theta=11.6481391 -> V=1.0, theta=0.0
% INFO    : Bus 1787	: V=0.964, theta=-37.4474736 -> V=1.0, theta=0.0
% INFO    : Bus 1788	: V=0.964, theta=-37.4474736 -> V=1.0, theta=0.0
% INFO    : Bus 1789	: V=0.979, theta=-37.2969931 -> V=1.0, theta=0.0
% INFO    : Bus 1790	: V=0.941, theta=-37.8347714 -> V=0.9973695, theta=0.0
% INFO    : Bus 1791	: V=0.938, theta=-37.8234302 -> V=0.994026, theta=0.0
% INFO    : Bus 1792	: V=0.978, theta=-30.4466743 -> V=1.0, theta=0.0
% INFO    : Bus 2011	: V=0.978, theta=-30.4466743 -> V=1.0, theta=0.0
% INFO    : Bus 2012	: V=0.963, theta=-31.9679632 -> V=1.0, theta=0.0
% INFO    : Bus 1793	: V=0.959, theta=-15.4033571 -> V=1.00069, theta=0.0
% INFO    : Bus 1794	: V=0.962, theta=-16.1866404 -> V=1.00072, theta=0.0
% INFO    : Bus 1795	: V=1.00576895, theta=-43.7239712 -> V=1.05263, theta=0.0
% INFO    : Bus 1796	: V=1.00578054, theta=-43.7239513 -> V=1.05263, theta=0.0
% INFO    : Bus 1797	: V=1.04936336, theta=-27.2030604 -> V=1.0111115, theta=0.0
% INFO    : Bus 1798	: V=1.03701809, theta=-41.44442 -> V=1.05263, theta=0.0
% INFO    : Bus 1799	: V=1.05134137, theta=-31.3536721 -> V=1.04606, theta=0.0
% INFO    : Bus 1800	: V=1.05544204, theta=-38.1027109 -> V=1.072365, theta=0.0
% INFO    : Bus 1801	: V=1.02970412, theta=-37.8545355 -> V=1.0386735, theta=0.0
% INFO    : Bus 1802	: V=1.02711689, theta=-38.4571086 -> V=1.018935, theta=0.0
% INFO    : Bus 1803	: V=1.03581394, theta=-45.1964741 -> V=1.05263, theta=0.0
% INFO    : Bus 1804	: V=1.03385473, theta=-46.203322 -> V=1.05921, theta=0.0
% INFO    : Bus 1805	: V=1.05310615, theta=-34.4686261 -> V=1.072365, theta=0.0
% INFO    : Bus 1806	: V=1.0568488, theta=-38.8733706 -> V=1.072365, theta=0.0
% INFO    : Bus 1807	: V=1.04407811, theta=-21.3129575 -> V=1.0, theta=0.0
% INFO    : Bus 1808	: V=1.03733256, theta=-18.4478346 -> V=1.046665, theta=0.0
% INFO    : Bus 1809	: V=1.04542438, theta=-25.940881 -> V=1.072365, theta=0.0
% INFO    : Bus 1810	: V=1.0539887, theta=-36.9596522 -> V=1.0377785, theta=0.0
% INFO    : Bus 1811	: V=1.05583507, theta=-34.8009278 -> V=1.072365, theta=0.0
% INFO    : Bus 1812	: V=1.04503824, theta=-32.9574835 -> V=1.0419835, theta=0.0
% INFO    : Bus 1813	: V=1.04855742, theta=-30.0120368 -> V=1.072365, theta=0.0
% INFO    : Bus 1814	: V=1.05037135, theta=-29.4698058 -> V=1.072365, theta=0.0
% INFO    : Bus 1815	: V=1.01135053, theta=-46.2481673 -> V=0.9888895, theta=0.0
% INFO    : Bus 1816	: V=1.07650805, theta=-29.9088346 -> V=1.076555, theta=0.0
% INFO    : Bus 1817	: V=1.05566001, theta=-36.4035496 -> V=1.072365, theta=0.0
% INFO    : Bus 1818	: V=1.05052068, theta=-28.3675415 -> V=1.0111115, theta=0.0
% INFO    : Bus 1819	: V=1.05719872, theta=-25.4152963 -> V=1.072365, theta=0.0
% INFO    : Bus 1820	: V=1.03884937, theta=-29.8662923 -> V=1.072365, theta=0.0
% INFO    : Bus 1821	: V=1.05040608, theta=-28.845506 -> V=1.0111115, theta=0.0
% INFO    : Bus 1822	: V=1.10110433, theta=-36.2846105 -> V=1.072365, theta=0.0
% INFO    : Bus 1823	: V=1.04264022, theta=-27.9080001 -> V=1.0111115, theta=0.0
% INFO    : Bus 1824	: V=1.04263617, theta=-27.9076743 -> V=1.0111115, theta=0.0
% INFO    : Bus 1825	: V=1.04883796, theta=-26.553688 -> V=1.072365, theta=0.0
% INFO    : Bus 1826	: V=1.07082476, theta=-18.6715741 -> V=1.07798, theta=0.0
% INFO    : 
% INFO    : === Generator Setpoint Replacement Notes ===
% INFO    : Gen at bus 1268	: Pg=44.5, Qg=-1.55 -> Pg=44.5, Qg=9.0
% INFO    : Gen at bus 1268	: Vg=1.027 -> Vg=1.01773
% INFO    : Gen at bus 1268	: Pg=44.5, Qg=-1.55 -> Pg=44.5, Qg=9.0
% INFO    : Gen at bus 1268	: Vg=1.027 -> Vg=1.01773
% INFO    : Gen at bus 1356	: Pg=21.0, Qg=-0.4 -> Pg=13.2, Qg=-2.5
% INFO    : Gen at bus 1356	: Vg=1.046 -> Vg=1.014075
% INFO    : Gen at bus 89	: Pg=24.0, Qg=-1.48 -> Pg=15.0, Qg=2.0
% INFO    : Gen at bus 89	: Vg=1.02 -> Vg=1.0
% INFO    : Gen at bus 125	: Pg=22.0, Qg=-0.19 -> Pg=14.04, Qg=-4.5
% INFO    : Gen at bus 125	: Vg=1.034 -> Vg=1.01238
% INFO    : Gen at bus 908	: Pg=19.0, Qg=1.9 -> Pg=12.0, Qg=1.95
% INFO    : Gen at bus 908	: Vg=1.035 -> Vg=1.004395
% INFO    : Gen at bus 817	: Vg=1.039 -> Vg=1.004235
% INFO    : Gen at bus 817	: Pg=13.0, Qg=0.9 -> Pg=8.4, Qg=0.95
% INFO    : Gen at bus 817	: Vg=1.039 -> Vg=1.004235
% INFO    : Gen at bus 817	: Vg=1.039 -> Vg=1.004235
% INFO    : Gen at bus 1335	: Pg=28.0, Qg=-0.87 -> Pg=18.0, Qg=0.0
% INFO    : Gen at bus 1335	: Vg=1.021 -> Vg=1.0
% INFO    : Gen at bus 396	: Pg=10.0, Qg=1.0 -> Pg=6.6, Qg=3.0
% INFO    : Gen at bus 396	: Vg=1.015 -> Vg=1.0
% INFO    : Gen at bus 396	: Pg=10.0, Qg=1.0 -> Pg=6.6, Qg=3.0
% INFO    : Gen at bus 396	: Vg=1.015 -> Vg=1.0
% INFO    : Gen at bus 975	: Pg=7.0, Qg=-15.0 -> Pg=21.0, Qg=0.0
% INFO    : Gen at bus 975	: Vg=1.05 -> Vg=1.0
% INFO    : Gen at bus 858	: Pg=16.92, Qg=0.0 -> Pg=33.24, Qg=0.0
% INFO    : Gen at bus 858	: Vg=1.048 -> Vg=1.019305
% INFO    : Gen at bus 921	: Pg=40.0, Qg=-20.0 -> Pg=25.2, Qg=2.5
% INFO    : Gen at bus 921	: Vg=1.045 -> Vg=1.0
% INFO    : Gen at bus 921	: Pg=40.0, Qg=-20.0 -> Pg=25.2, Qg=2.5
% INFO    : Gen at bus 921	: Vg=1.045 -> Vg=1.0
% INFO    : Gen at bus 1255	: Pg=15.61, Qg=-24.36 -> Pg=52.2, Qg=0.87
% INFO    : Gen at bus 1255	: Vg=1.046 -> Vg=1.01587
% INFO    : Gen at bus 169	: Pg=8.0, Qg=0.49 -> Pg=4.98, Qg=0.0
% INFO    : Gen at bus 169	: Vg=1.065 -> Vg=1.0
% INFO    : Gen at bus 448	: Pg=0.85, Qg=0.0 -> Pg=2.0, Qg=0.0
% INFO    : Gen at bus 448	: Vg=1.04 -> Vg=1.01761
% INFO    : Gen at bus 241	: Pg=2.6, Qg=-0.21 -> Pg=7.8, Qg=0.0
% INFO    : Gen at bus 241	: Vg=1.011 -> Vg=1.0
% INFO    : Gen at bus 241	: Pg=2.6, Qg=-0.21 -> Pg=7.8, Qg=0.0
% INFO    : Gen at bus 241	: Vg=1.011 -> Vg=1.0
% INFO    : Gen at bus 241	: Pg=2.6, Qg=-0.21 -> Pg=7.8, Qg=0.0
% INFO    : Gen at bus 241	: Vg=1.011 -> Vg=1.0
% INFO    : Gen at bus 241	: Pg=2.6, Qg=-0.21 -> Pg=7.8, Qg=0.0
% INFO    : Gen at bus 241	: Vg=1.011 -> Vg=1.0
% INFO    : Gen at bus 270	: Pg=48.0, Qg=0.15 -> Pg=30.0, Qg=9.0
% INFO    : Gen at bus 270	: Vg=1.029 -> Vg=1.00923
% INFO    : Gen at bus 885	: Pg=0.29, Qg=0.0 -> Pg=4.8, Qg=0.0
% INFO    : Gen at bus 885	: Vg=1.029 -> Vg=1.018935
% INFO    : Gen at bus 885	: Pg=0.29, Qg=0.0 -> Pg=4.8, Qg=0.0
% INFO    : Gen at bus 885	: Vg=1.029 -> Vg=1.018935
% INFO    : Gen at bus 876	: Pg=-1.22, Qg=0.0 -> Pg=32.4, Qg=0.0
% INFO    : Gen at bus 876	: Vg=1.04 -> Vg=1.018115
% INFO    : Gen at bus 46	: Pg=28.0, Qg=-4.0 -> Pg=18.0, Qg=3.0
% INFO    : Gen at bus 46	: Vg=1.038 -> Vg=1.004215
% INFO    : Gen at bus 803	: Pg=13.0, Qg=-0.14 -> Pg=8.28, Qg=-0.465
% INFO    : Gen at bus 803	: Vg=1.036 -> Vg=1.012885
% INFO    : Gen at bus 356	: Pg=11.82, Qg=-11.59 -> Pg=24.84, Qg=0.415
% INFO    : Gen at bus 356	: Vg=1.047 -> Vg=1.01705
% INFO    : Gen at bus 100	: Pg=26.0, Qg=-3.91 -> Pg=78.0, Qg=16.5
% INFO    : Gen at bus 100	: Vg=1.036 -> Vg=1.01647
% INFO    : Gen at bus 707	: Pg=20.0, Qg=-3.74 -> Pg=12.6, Qg=0.0
% INFO    : Gen at bus 707	: Vg=1.05 -> Vg=1.0
% INFO    : Gen at bus 973	: Vg=1.039 -> Vg=1.01855
% INFO    : Gen at bus 973	: Pg=51.0, Qg=-10.0 -> Pg=31.8, Qg=3.5
% INFO    : Gen at bus 973	: Vg=1.039 -> Vg=1.01855
% INFO    : Gen at bus 1118	: Pg=2.77, Qg=0.0 -> Pg=33.0, Qg=0.0
% INFO    : Gen at bus 1118	: Vg=1.03 -> Vg=1.013845
% INFO    : Gen at bus 897	: Pg=17.92, Qg=-3.0 -> Pg=16.2, Qg=3.5
% INFO    : Gen at bus 897	: Vg=1.027 -> Vg=1.0
% INFO    : Gen at bus 897	: Pg=17.92, Qg=-3.0 -> Pg=16.2, Qg=3.5
% INFO    : Gen at bus 897	: Vg=1.027 -> Vg=1.0
% INFO    : Gen at bus 58	: Vg=1.037 -> Vg=1.00431
% INFO    : Gen at bus 82	: Pg=1.3, Qg=0.0 -> Pg=15.18, Qg=0.0
% INFO    : Gen at bus 82	: Vg=1.025 -> Vg=1.01562
% INFO    : Gen at bus 474	: Pg=13.22, Qg=-13.0 -> Pg=31.2, Qg=-1.5
% INFO    : Gen at bus 474	: Vg=1.036 -> Vg=1.015335
% INFO    : Gen at bus 1221	: Pg=11.6, Qg=3.43 -> Pg=34.8, Qg=0.0
% INFO    : Gen at bus 1221	: Vg=1.056 -> Vg=1.0
% INFO    : Gen at bus 355	: Pg=59.0, Qg=-40.0 -> Pg=37.2, Qg=0.0
% INFO    : Gen at bus 355	: Vg=1.05 -> Vg=1.0
% INFO    : Gen at bus 471	: Pg=0.91, Qg=0.0 -> Pg=46.8, Qg=0.5
% INFO    : Gen at bus 471	: Vg=1.037 -> Vg=1.017105
% INFO    : Gen at bus 1321	: Pg=10.0, Qg=0.9 -> Pg=6.6, Qg=0.95
% INFO    : Gen at bus 1321	: Vg=1.039 -> Vg=1.004235
% INFO    : Gen at bus 1321	: Pg=2.0, Qg=-0.01 -> Pg=1.25, Qg=0.0
% INFO    : Gen at bus 1321	: Vg=1.039 -> Vg=1.004235
% INFO    : Gen at bus 1829	: Pg=0.16, Qg=0.06 -> Pg=14.1, Qg=0.0
% INFO    : Gen at bus 1829	: Vg=1.022 -> Vg=1.014295
% INFO    : Gen at bus 1005	: Pg=37.0, Qg=-19.0 -> Pg=23.4, Qg=0.0
% INFO    : Gen at bus 1005	: Vg=1.02 -> Vg=1.00521
% INFO    : Gen at bus 14	: Pg=2.38, Qg=0.0 -> Pg=16.56, Qg=0.0
% INFO    : Gen at bus 14	: Vg=1.029 -> Vg=1.01626
% INFO    : Gen at bus 14	: Pg=0.64, Qg=0.0 -> Pg=14.4, Qg=0.0
% INFO    : Gen at bus 14	: Vg=1.029 -> Vg=1.01626
% INFO    : Gen at bus 1628	: Pg=200.0, Qg=-60.27 -> Pg=435.0, Qg=-31.125
% INFO    : Gen at bus 1628	: Vg=0.95 -> Vg=1.0
% INFO    : Gen at bus 1629	: Pg=450.03, Qg=-42.82 -> Pg=420.0, Qg=20.405
% INFO    : Gen at bus 1629	: Vg=0.95 -> Vg=1.0
% INFO    : Gen at bus 1844	: Pg=26.0, Qg=-13.69 -> Pg=16.2, Qg=4.62
% INFO    : Gen at bus 1844	: Vg=0.885 -> Vg=1.0077585
% INFO    : Gen at bus 1630	: Pg=83.0, Qg=8.77 -> Pg=51.6, Qg=17.68
% INFO    : Gen at bus 1630	: Vg=0.928 -> Vg=0.9887625
% INFO    : Gen at bus 1631	: Pg=9.8, Qg=3.09 -> Pg=29.4, Qg=6.23
% INFO    : Gen at bus 1631	: Vg=0.93 -> Vg=0.989957
% INFO    : Gen at bus 1846	: Pg=30.0, Qg=-1.12 -> Pg=19.2, Qg=0.0
% INFO    : Gen at bus 1846	: Vg=1.034 -> Vg=1.0
% INFO    : Gen at bus 1632	: Pg=30.0, Qg=-1.12 -> Pg=19.2, Qg=0.0
% INFO    : Gen at bus 1632	: Vg=1.034 -> Vg=1.0
% INFO    : Gen at bus 1847	: Pg=30.0, Qg=-1.06 -> Pg=19.2, Qg=-0.21
% INFO    : Gen at bus 1847	: Vg=1.034 -> Vg=1.0
% INFO    : Gen at bus 1848	: Pg=30.0, Qg=-1.06 -> Pg=19.2, Qg=-0.21
% INFO    : Gen at bus 1848	: Vg=1.034 -> Vg=1.0
% INFO    : Gen at bus 1852	: Pg=88.0, Qg=16.22 -> Pg=55.2, Qg=9.57
% INFO    : Gen at bus 1852	: Vg=1.01 -> Vg=1.0
% INFO    : Gen at bus 1854	: Pg=88.0, Qg=28.45 -> Pg=55.2, Qg=11.48
% INFO    : Gen at bus 1854	: Vg=1.031 -> Vg=1.0
% INFO    : Gen at bus 1633	: Pg=912.0, Qg=55.65 -> Pg=600.075, Qg=22.385
% INFO    : Gen at bus 1633	: Vg=1.0 -> Vg=1.001355
% INFO    : Gen at bus 1634	: Pg=944.0, Qg=57.67 -> Pg=633.045, Qg=29.81
% INFO    : Gen at bus 1634	: Vg=0.999 -> Vg=1.000525
% INFO    : Gen at bus 1635	: Pg=942.0, Qg=57.52 -> Pg=616.08, Qg=29.075
% INFO    : Gen at bus 1635	: Vg=0.999 -> Vg=1.00053
% INFO    : Gen at bus 1636	: Pg=910.0, Qg=55.51 -> Pg=598.075, Qg=21.865
% INFO    : Gen at bus 1636	: Vg=1.0 -> Vg=1.0
% INFO    : Gen at bus 1637	: Pg=156.0, Qg=-8.21 -> Pg=204.0, Qg=31.4
% INFO    : Gen at bus 1637	: Vg=0.954 -> Vg=1.0
% INFO    : Gen at bus 1638	: Pg=154.0, Qg=-8.17 -> Pg=202.0, Qg=30.815
% INFO    : Gen at bus 1638	: Vg=0.954 -> Vg=1.0
% INFO    : Gen at bus 1639	: Pg=154.0, Qg=-3.53 -> Pg=202.0, Qg=23.7
% INFO    : Gen at bus 1639	: Vg=0.977 -> Vg=1.0
% INFO    : Gen at bus 1640	: Pg=122.0, Qg=-16.51 -> Pg=213.5, Qg=34.45
% INFO    : Gen at bus 1640	: Vg=0.983 -> Vg=1.0
% INFO    : Gen at bus 1641	: Pg=89.0, Qg=-2.78 -> Pg=122.0, Qg=9.84
% INFO    : Gen at bus 1641	: Vg=0.986 -> Vg=1.003735
% INFO    : Gen at bus 1642	: Pg=11.6, Qg=-3.44 -> Pg=34.8, Qg=1.44
% INFO    : Gen at bus 1642	: Vg=0.988 -> Vg=1.0
% INFO    : Gen at bus 1643	: Pg=37.93, Qg=-1.89 -> Pg=34.8, Qg=2.675
% INFO    : Gen at bus 1643	: Vg=0.988 -> Vg=1.0
% INFO    : Gen at bus 1855	: Pg=11.6, Qg=-3.39 -> Pg=34.8, Qg=1.26
% INFO    : Gen at bus 1855	: Vg=0.988 -> Vg=1.0
% INFO    : Gen at bus 1644	: Pg=38.05, Qg=-1.9 -> Pg=34.8, Qg=2.715
% INFO    : Gen at bus 1644	: Vg=0.988 -> Vg=1.0
% INFO    : Gen at bus 1645	: Pg=37.39, Qg=-1.84 -> Pg=34.8, Qg=2.475
% INFO    : Gen at bus 1645	: Vg=0.988 -> Vg=1.0
% INFO    : Gen at bus 1646	: Pg=133.0, Qg=8.92 -> Pg=198.0, Qg=28.135
% INFO    : Gen at bus 1646	: Vg=0.95 -> Vg=1.00036
% INFO    : Gen at bus 1647	: Pg=43.0, Qg=11.27 -> Pg=26.975, Qg=6.29
% INFO    : Gen at bus 1647	: Vg=1.045 -> Vg=1.0
% INFO    : Gen at bus 1861	: Pg=30.0, Qg=2.78 -> Pg=19.2, Qg=1.75
% INFO    : Gen at bus 1861	: Vg=1.048 -> Vg=1.0
% INFO    : Gen at bus 1648	: Pg=903.0, Qg=119.3 -> Pg=601.29, Qg=186.38
% INFO    : Gen at bus 1648	: Vg=0.963 -> Vg=0.990834
% INFO    : Gen at bus 1649	: Pg=910.0, Qg=9.35 -> Pg=607.82, Qg=188.81
% INFO    : Gen at bus 1649	: Vg=0.946 -> Vg=0.9895395
% INFO    : Gen at bus 1650	: Pg=892.0, Qg=122.18 -> Pg=599.28, Qg=192.43
% INFO    : Gen at bus 1650	: Vg=0.964 -> Vg=0.9875395
% INFO    : Gen at bus 1651	: Pg=890.0, Qg=9.21 -> Pg=597.8, Qg=184.5
% INFO    : Gen at bus 1651	: Vg=0.946 -> Vg=0.994603
% INFO    : Gen at bus 1652	: Pg=318.0, Qg=-97.83 -> Pg=813.0, Qg=264.02
% INFO    : Gen at bus 1652	: Vg=0.945 -> Vg=0.9975895
% INFO    : Gen at bus 1862	: Pg=318.0, Qg=-73.74 -> Pg=813.0, Qg=264.015
% INFO    : Gen at bus 1862	: Vg=0.948 -> Vg=0.99881
% INFO    : Gen at bus 1653	: Pg=33.0, Qg=-0.83 -> Pg=21.0, Qg=2.08
% INFO    : Gen at bus 1653	: Vg=1.029 -> Vg=1.0
% INFO    : Gen at bus 1654	: Pg=33.0, Qg=-0.86 -> Pg=21.0, Qg=2.21
% INFO    : Gen at bus 1654	: Vg=1.029 -> Vg=1.0
% INFO    : Gen at bus 1655	: Pg=33.0, Qg=-0.86 -> Pg=21.0, Qg=2.21
% INFO    : Gen at bus 1655	: Vg=1.029 -> Vg=1.0
% INFO    : Gen at bus 1656	: Pg=33.0, Qg=-0.83 -> Pg=21.0, Qg=2.11
% INFO    : Gen at bus 1656	: Vg=1.029 -> Vg=1.0
% INFO    : Gen at bus 1657	: Pg=33.0, Qg=-0.83 -> Pg=21.0, Qg=2.11
% INFO    : Gen at bus 1657	: Vg=1.029 -> Vg=1.0
% INFO    : Gen at bus 1658	: Pg=33.0, Qg=-0.83 -> Pg=21.0, Qg=2.11
% INFO    : Gen at bus 1658	: Vg=1.029 -> Vg=1.0
% INFO    : Gen at bus 1863	: Pg=35.0, Qg=1.08 -> Pg=22.18, Qg=2.645
% INFO    : Gen at bus 1863	: Vg=0.979 -> Vg=1.0
% INFO    : Gen at bus 1659	: Pg=35.0, Qg=1.08 -> Pg=22.18, Qg=2.645
% INFO    : Gen at bus 1659	: Vg=0.979 -> Vg=1.0
% INFO    : Gen at bus 1660	: Pg=35.0, Qg=1.08 -> Pg=22.18, Qg=3.55
% INFO    : Gen at bus 1660	: Vg=0.979 -> Vg=1.0
% INFO    : Gen at bus 1661	: Pg=35.0, Qg=1.05 -> Pg=22.18, Qg=3.205
% INFO    : Gen at bus 1661	: Vg=0.979 -> Vg=1.0
% INFO    : Gen at bus 1662	: Pg=35.0, Qg=1.05 -> Pg=22.18, Qg=2.4
% INFO    : Gen at bus 1662	: Vg=0.978 -> Vg=1.0
% INFO    : Gen at bus 1663	: Pg=35.0, Qg=1.09 -> Pg=22.18, Qg=2.75
% INFO    : Gen at bus 1663	: Vg=0.978 -> Vg=1.0
% INFO    : Gen at bus 1865	: Pg=19.0, Qg=-1.21 -> Pg=12.0, Qg=2.32
% INFO    : Gen at bus 1865	: Vg=0.942 -> Vg=1.0
% INFO    : Gen at bus 1866	: Pg=29.0, Qg=0.99 -> Pg=18.59, Qg=2.03
% INFO    : Gen at bus 1866	: Vg=0.978 -> Vg=1.0
% INFO    : Gen at bus 1664	: Pg=29.0, Qg=0.99 -> Pg=18.59, Qg=2.03
% INFO    : Gen at bus 1664	: Vg=0.978 -> Vg=1.0
% INFO    : Gen at bus 1665	: Pg=29.0, Qg=1.0 -> Pg=18.59, Qg=2.195
% INFO    : Gen at bus 1665	: Vg=0.978 -> Vg=1.0
% INFO    : Gen at bus 1867	: Pg=29.0, Qg=1.0 -> Pg=18.59, Qg=2.195
% INFO    : Gen at bus 1867	: Vg=0.978 -> Vg=1.0
% INFO    : Gen at bus 1666	: Pg=29.0, Qg=0.99 -> Pg=18.59, Qg=2.07
% INFO    : Gen at bus 1666	: Vg=0.979 -> Vg=1.0
% INFO    : Gen at bus 1868	: Pg=29.0, Qg=0.98 -> Pg=18.59, Qg=1.915
% INFO    : Gen at bus 1868	: Vg=0.979 -> Vg=1.0
% INFO    : Gen at bus 1667	: Pg=1283.0, Qg=7.98 -> Pg=833.5, Qg=235.585
% INFO    : Gen at bus 1667	: Vg=0.947 -> Vg=0.996488
% INFO    : Gen at bus 1668	: Pg=1114.28, Qg=16.37 -> Pg=863.5, Qg=236.51
% INFO    : Gen at bus 1668	: Vg=0.952 -> Vg=0.995021
% INFO    : Gen at bus 1669	: Pg=1088.81, Qg=14.75 -> Pg=863.5, Qg=227.615
% INFO    : Gen at bus 1669	: Vg=0.953 -> Vg=0.993275
% INFO    : Gen at bus 1670	: Pg=1.45, Qg=-75.51 -> Pg=1.45, Qg=88.775
% INFO    : Gen at bus 1670	: Vg=0.916 -> Vg=1.0094195
% INFO    : Gen at bus 1873	: Pg=48.0, Qg=45.94 -> Pg=144.0, Qg=24.03
% INFO    : Gen at bus 1873	: Vg=1.003 -> Vg=1.0
% INFO    : Gen at bus 1874	: Pg=48.0, Qg=46.96 -> Pg=144.0, Qg=25.11
% INFO    : Gen at bus 1874	: Vg=1.003 -> Vg=1.0
% INFO    : Gen at bus 1671	: Pg=910.0, Qg=-1.46 -> Pg=587.72, Qg=208.7
% INFO    : Gen at bus 1671	: Vg=0.95 -> Vg=1.0
% INFO    : Gen at bus 1673	: Pg=920.0, Qg=-1.3 -> Pg=598.74, Qg=206.28
% INFO    : Gen at bus 1673	: Vg=0.95 -> Vg=1.0
% INFO    : Gen at bus 1674	: Pg=919.0, Qg=-7.76 -> Pg=597.74, Qg=228.045
% INFO    : Gen at bus 1674	: Vg=0.949 -> Vg=0.9995685
% INFO    : Gen at bus 1675	: Pg=598.27, Qg=-35.9 -> Pg=953.0, Qg=277.96
% INFO    : Gen at bus 1675	: Vg=0.944 -> Vg=0.9996345
% INFO    : Gen at bus 1676	: Pg=505.8, Qg=1.41 -> Pg=953.0, Qg=282.755
% INFO    : Gen at bus 1676	: Vg=0.95 -> Vg=1.00522
% INFO    : Gen at bus 1875	: Pg=1446.0, Qg=48.05 -> Pg=948.0, Qg=28.58
% INFO    : Gen at bus 1875	: Vg=0.973 -> Vg=1.0
% INFO    : Gen at bus 1677	: Pg=1446.0, Qg=30.08 -> Pg=948.0, Qg=28.545
% INFO    : Gen at bus 1677	: Vg=0.971 -> Vg=1.0
% INFO    : Gen at bus 2022	: Pg=15.0, Qg=20.78 -> Pg=45.0, Qg=6.72
% INFO    : Gen at bus 2022	: Vg=1.077 -> Vg=1.0
% INFO    : Gen at bus 1876	: Pg=15.0, Qg=20.78 -> Pg=45.0, Qg=6.72
% INFO    : Gen at bus 1876	: Vg=1.077 -> Vg=1.0
% INFO    : Gen at bus 1877	: Pg=15.0, Qg=20.78 -> Pg=45.0, Qg=6.72
% INFO    : Gen at bus 1877	: Vg=1.077 -> Vg=1.0
% INFO    : Gen at bus 1878	: Pg=15.0, Qg=20.78 -> Pg=45.0, Qg=6.72
% INFO    : Gen at bus 1878	: Vg=1.077 -> Vg=1.0
% INFO    : Gen at bus 1678	: Pg=91.0, Qg=-0.46 -> Pg=51.75, Qg=21.36
% INFO    : Gen at bus 1678	: Vg=0.957 -> Vg=1.0
% INFO    : Gen at bus 1679	: Pg=91.0, Qg=-0.45 -> Pg=51.75, Qg=21.18
% INFO    : Gen at bus 1679	: Vg=0.957 -> Vg=1.0
% INFO    : Gen at bus 1680	: Pg=4.2, Qg=-10.65 -> Pg=76.2, Qg=38.01
% INFO    : Gen at bus 1680	: Vg=0.961 -> Vg=1.0
% INFO    : Gen at bus 1681	: Pg=180.0, Qg=-3.8 -> Pg=432.5, Qg=80.525
% INFO    : Gen at bus 1681	: Vg=0.95 -> Vg=1.0
% INFO    : Gen at bus 1682	: Pg=588.0, Qg=-56.14 -> Pg=460.0, Qg=82.52
% INFO    : Gen at bus 1682	: Vg=0.928 -> Vg=0.9802185
% INFO    : Gen at bus 1683	: Pg=588.0, Qg=-45.22 -> Pg=460.0, Qg=52.92
% INFO    : Gen at bus 1683	: Vg=0.933 -> Vg=0.980023
% INFO    : Gen at bus 1684	: Pg=205.0, Qg=-45.01 -> Pg=452.5, Qg=-19.415
% INFO    : Gen at bus 1684	: Vg=0.954 -> Vg=1.0
% INFO    : Gen at bus 1881	: Pg=48.0, Qg=-1.86 -> Pg=30.0, Qg=0.9
% INFO    : Gen at bus 1881	: Vg=0.957 -> Vg=1.0
% INFO    : Gen at bus 1882	: Pg=48.0, Qg=-1.76 -> Pg=30.0, Qg=0.5
% INFO    : Gen at bus 1882	: Vg=0.957 -> Vg=1.0
% INFO    : Gen at bus 1685	: Pg=48.0, Qg=-1.91 -> Pg=30.0, Qg=1.105
% INFO    : Gen at bus 1685	: Vg=0.957 -> Vg=1.0
% INFO    : Gen at bus 1883	: Pg=48.0, Qg=-1.91 -> Pg=30.0, Qg=1.105
% INFO    : Gen at bus 1883	: Vg=0.957 -> Vg=1.0
% INFO    : Gen at bus 1884	: Pg=48.0, Qg=-1.91 -> Pg=30.0, Qg=1.105
% INFO    : Gen at bus 1884	: Vg=0.957 -> Vg=1.0
% INFO    : Gen at bus 1885	: Pg=48.0, Qg=-1.86 -> Pg=30.0, Qg=0.9
% INFO    : Gen at bus 1885	: Vg=0.957 -> Vg=1.0
% INFO    : Gen at bus 1686	: Pg=965.0, Qg=121.03 -> Pg=640.0, Qg=221.385
% INFO    : Gen at bus 1686	: Vg=0.972 -> Vg=1.0
% INFO    : Gen at bus 1687	: Pg=965.0, Qg=122.14 -> Pg=640.0, Qg=223.92
% INFO    : Gen at bus 1687	: Vg=0.973 -> Vg=1.0
% INFO    : Gen at bus 1688	: Pg=965.0, Qg=136.63 -> Pg=640.0, Qg=239.705
% INFO    : Gen at bus 1688	: Vg=0.974 -> Vg=1.0
% INFO    : Gen at bus 1689	: Vg=0.964 -> Vg=1.0
% INFO    : Gen at bus 1888	: Pg=55.0, Qg=-0.84 -> Pg=34.2, Qg=0.0
% INFO    : Gen at bus 1888	: Vg=0.983 -> Vg=1.0
% INFO    : Gen at bus 1690	: Pg=420.09, Qg=13.26 -> Pg=345.0, Qg=32.025
% INFO    : Gen at bus 1690	: Vg=0.922 -> Vg=0.9858785
% INFO    : Gen at bus 1691	: Pg=21.0, Qg=-4.1 -> Pg=42.0, Qg=20.31
% INFO    : Gen at bus 1691	: Vg=0.95 -> Vg=1.0
% INFO    : Gen at bus 1692	: Pg=248.8, Qg=-17.55 -> Pg=341.3, Qg=37.96
% INFO    : Gen at bus 1692	: Vg=0.99 -> Vg=1.01132
% INFO    : Gen at bus 1693	: Pg=81.81, Qg=8.75 -> Pg=124.99, Qg=13.48
% INFO    : Gen at bus 1693	: Vg=0.95 -> Vg=1.0
% INFO    : Gen at bus 1694	: Pg=82.28, Qg=8.77 -> Pg=125.44, Qg=17.825
% INFO    : Gen at bus 1694	: Vg=0.95 -> Vg=1.0
% INFO    : Gen at bus 1695	: Pg=53.91, Qg=14.32 -> Pg=151.06, Qg=34.915
% INFO    : Gen at bus 1695	: Vg=0.95 -> Vg=1.0
% INFO    : Gen at bus 1696	: Pg=43.97, Qg=14.91 -> Pg=141.03, Qg=20.78
% INFO    : Gen at bus 1696	: Vg=0.95 -> Vg=1.0
% INFO    : Gen at bus 1697	: Pg=229.69, Qg=-21.95 -> Pg=574.69, Qg=218.265
% INFO    : Gen at bus 1697	: Vg=0.95 -> Vg=1.0
% INFO    : Gen at bus 1698	: Pg=229.69, Qg=-21.95 -> Pg=574.69, Qg=218.265
% INFO    : Gen at bus 1698	: Vg=0.95 -> Vg=1.0
% INFO    : Gen at bus 1699	: Pg=236.69, Qg=-21.76 -> Pg=581.69, Qg=219.89
% INFO    : Gen at bus 1699	: Vg=0.95 -> Vg=1.0
% INFO    : Gen at bus 1700	: Pg=251.69, Qg=-22.47 -> Pg=596.69, Qg=223.405
% INFO    : Gen at bus 1700	: Vg=0.95 -> Vg=1.0
% INFO    : Gen at bus 1701	: Pg=30.0, Qg=-9.68 -> Pg=19.2, Qg=0.32
% INFO    : Gen at bus 1701	: Vg=0.96 -> Vg=1.0
% INFO    : Gen at bus 1702	: Pg=38.0, Qg=0.07 -> Pg=23.93, Qg=0.775
% INFO    : Gen at bus 1702	: Vg=0.982 -> Vg=1.0
% INFO    : Gen at bus 1703	: Pg=38.0, Qg=0.07 -> Pg=23.93, Qg=0.8
% INFO    : Gen at bus 1703	: Vg=0.982 -> Vg=1.0
% INFO    : Gen at bus 1889	: Pg=38.0, Qg=0.07 -> Pg=23.93, Qg=0.79
% INFO    : Gen at bus 1889	: Vg=0.982 -> Vg=1.0
% INFO    : Gen at bus 1704	: Pg=1332.0, Qg=168.76 -> Pg=860.0, Qg=0.765
% INFO    : Gen at bus 1704	: Vg=0.988 -> Vg=1.0
% INFO    : Gen at bus 1705	: Pg=1332.0, Qg=148.25 -> Pg=860.0, Qg=-26.54
% INFO    : Gen at bus 1705	: Vg=0.985 -> Vg=1.0
% INFO    : Gen at bus 1890	: Pg=4.8, Qg=0.02 -> Pg=14.4, Qg=1.39
% INFO    : Gen at bus 1890	: Vg=0.964 -> Vg=1.0
% INFO    : Gen at bus 1891	: Pg=4.8, Qg=0.03 -> Pg=14.4, Qg=1.525
% INFO    : Gen at bus 1891	: Vg=0.964 -> Vg=1.0
% INFO    : Gen at bus 1892	: Pg=4.86, Qg=0.02 -> Pg=14.4, Qg=1.035
% INFO    : Gen at bus 1892	: Vg=0.964 -> Vg=1.0
% INFO    : Gen at bus 1706	: Pg=12.83, Qg=0.02 -> Pg=14.4, Qg=1.33
% INFO    : Gen at bus 1706	: Vg=0.962 -> Vg=1.0
% INFO    : Gen at bus 1707	: Pg=9.2, Qg=0.07 -> Pg=14.395, Qg=2.51
% INFO    : Gen at bus 1707	: Vg=0.975 -> Vg=1.0
% INFO    : Gen at bus 2026	: Pg=4.8, Qg=0.05 -> Pg=14.395, Qg=0.735
% INFO    : Gen at bus 2026	: Vg=0.976 -> Vg=1.0
% INFO    : Gen at bus 1898	: Pg=4.8, Qg=0.07 -> Pg=14.395, Qg=2.685
% INFO    : Gen at bus 1898	: Vg=0.976 -> Vg=1.0
% INFO    : Gen at bus 1708	: Pg=9.45, Qg=1.8 -> Pg=14.395, Qg=1.805
% INFO    : Gen at bus 1708	: Vg=0.984 -> Vg=1.0
% INFO    : Gen at bus 1709	: Pg=9.2, Qg=0.07 -> Pg=14.395, Qg=2.675
% INFO    : Gen at bus 1709	: Vg=0.975 -> Vg=1.0
% INFO    : Gen at bus 1710	: Pg=27.0, Qg=0.47 -> Pg=17.39, Qg=2.34
% INFO    : Gen at bus 1710	: Vg=0.984 -> Vg=1.0
% INFO    : Gen at bus 1711	: Pg=27.0, Qg=0.47 -> Pg=17.39, Qg=2.425
% INFO    : Gen at bus 1711	: Vg=0.984 -> Vg=1.0
% INFO    : Gen at bus 1712	: Pg=1262.0, Qg=0.64 -> Pg=798.0, Qg=87.935
% INFO    : Gen at bus 1712	: Vg=0.981 -> Vg=1.0
% INFO    : Gen at bus 1713	: Pg=1262.0, Qg=-6.77 -> Pg=798.0, Qg=87.48
% INFO    : Gen at bus 1713	: Vg=0.98 -> Vg=1.001985
% INFO    : Gen at bus 1714	: Pg=442.0, Qg=15.78 -> Pg=273.76, Qg=85.9
% INFO    : Gen at bus 1714	: Vg=0.95 -> Vg=1.01466
% INFO    : Gen at bus 1715	: Pg=309.71, Qg=81.22 -> Pg=592.0, Qg=213.325
% INFO    : Gen at bus 1715	: Vg=0.95 -> Vg=1.0
% INFO    : Gen at bus 1716	: Pg=313.55, Qg=81.38 -> Pg=607.0, Qg=216.68
% INFO    : Gen at bus 1716	: Vg=0.95 -> Vg=1.0
% INFO    : Gen at bus 1717	: Pg=349.48, Qg=50.21 -> Pg=592.0, Qg=217.915
% INFO    : Gen at bus 1717	: Vg=0.945 -> Vg=0.993595
% INFO    : Gen at bus 1718	: Pg=328.64, Qg=65.05 -> Pg=592.0, Qg=217.03
% INFO    : Gen at bus 1718	: Vg=0.948 -> Vg=0.9987595
% INFO    : Gen at bus 1719	: Pg=311.18, Qg=81.26 -> Pg=592.0, Qg=217.94
% INFO    : Gen at bus 1719	: Vg=0.95 -> Vg=1.0
% INFO    : Gen at bus 1720	: Pg=237.0, Qg=78.79 -> Pg=592.0, Qg=192.575
% INFO    : Gen at bus 1720	: Vg=0.95 -> Vg=1.0
% INFO    : Gen at bus 1721	: Pg=125.0, Qg=3.56 -> Pg=182.5, Qg=33.75
% INFO    : Gen at bus 1721	: Vg=0.95 -> Vg=1.0
% INFO    : Gen at bus 1906	: Pg=33.88, Qg=8.52 -> Pg=101.64, Qg=-3.68
% INFO    : Gen at bus 1906	: Vg=0.997 -> Vg=1.0
% INFO    : Gen at bus 1907	: Pg=33.88, Qg=8.53 -> Pg=101.64, Qg=-3.71
% INFO    : Gen at bus 1907	: Vg=0.997 -> Vg=1.0
% INFO    : Gen at bus 1908	: Pg=33.88, Qg=8.49 -> Pg=101.64, Qg=-3.785
% INFO    : Gen at bus 1908	: Vg=0.996 -> Vg=1.0
% INFO    : Gen at bus 1909	: Pg=33.88, Qg=8.5 -> Pg=101.64, Qg=-3.86
% INFO    : Gen at bus 1909	: Vg=0.996 -> Vg=1.0
% INFO    : Gen at bus 1910	: Pg=33.88, Qg=8.53 -> Pg=101.64, Qg=-3.74
% INFO    : Gen at bus 1910	: Vg=0.997 -> Vg=1.0
% INFO    : Gen at bus 1911	: Pg=33.88, Qg=8.53 -> Pg=101.64, Qg=-3.72
% INFO    : Gen at bus 1911	: Vg=0.997 -> Vg=1.0
% INFO    : Gen at bus 1912	: Pg=33.88, Qg=8.43 -> Pg=101.64, Qg=-4.09
% INFO    : Gen at bus 1912	: Vg=0.996 -> Vg=1.0
% INFO    : Gen at bus 1913	: Pg=33.88, Qg=8.43 -> Pg=101.64, Qg=-4.115
% INFO    : Gen at bus 1913	: Vg=0.996 -> Vg=1.0
% INFO    : Gen at bus 1722	: Pg=265.51, Qg=-20.28 -> Pg=336.8, Qg=72.9
% INFO    : Gen at bus 1722	: Vg=0.95 -> Vg=1.0
% INFO    : Gen at bus 1723	: Pg=130.0, Qg=-1.13 -> Pg=195.0, Qg=39.71
% INFO    : Gen at bus 1723	: Vg=0.969 -> Vg=1.005505
% INFO    : Gen at bus 1724	: Vg=0.967 -> Vg=1.0
% INFO    : Gen at bus 1725	: Pg=250.0, Qg=-1.92 -> Pg=417.5, Qg=4.815
% INFO    : Gen at bus 1725	: Vg=0.951 -> Vg=1.0
% INFO    : Gen at bus 1919	: Pg=19.0, Qg=0.06 -> Pg=11.99, Qg=0.745
% INFO    : Gen at bus 1919	: Vg=1.027 -> Vg=1.0
% INFO    : Gen at bus 1920	: Pg=23.0, Qg=0.06 -> Pg=14.39, Qg=0.525
% INFO    : Gen at bus 1920	: Vg=1.026 -> Vg=1.0
% INFO    : Gen at bus 1921	: Pg=4.8, Qg=0.06 -> Pg=14.39, Qg=1.17
% INFO    : Gen at bus 1921	: Vg=1.029 -> Vg=1.0
% INFO    : Gen at bus 1922	: Pg=4.8, Qg=0.06 -> Pg=14.39, Qg=0.865
% INFO    : Gen at bus 1922	: Vg=1.029 -> Vg=1.0
% INFO    : Gen at bus 1923	: Pg=4.8, Qg=0.06 -> Pg=14.39, Qg=1.445
% INFO    : Gen at bus 1923	: Vg=1.029 -> Vg=1.003055
% INFO    : Gen at bus 1924	: Pg=4.8, Qg=0.06 -> Pg=14.39, Qg=1.445
% INFO    : Gen at bus 1924	: Vg=1.029 -> Vg=1.000705
% INFO    : Gen at bus 1726	: Pg=33.0, Qg=-0.43 -> Pg=21.0, Qg=0.48
% INFO    : Gen at bus 1726	: Vg=0.979 -> Vg=1.0
% INFO    : Gen at bus 1727	: Pg=33.0, Qg=-0.41 -> Pg=21.0, Qg=0.29
% INFO    : Gen at bus 1727	: Vg=0.979 -> Vg=1.0
% INFO    : Gen at bus 1728	: Pg=33.0, Qg=-0.51 -> Pg=21.0, Qg=-1.465
% INFO    : Gen at bus 1728	: Vg=0.978 -> Vg=1.0
% INFO    : Gen at bus 1928	: Pg=33.0, Qg=-0.43 -> Pg=21.0, Qg=0.48
% INFO    : Gen at bus 1928	: Vg=0.979 -> Vg=1.0
% INFO    : Gen at bus 1729	: Pg=120.0, Qg=-16.3 -> Pg=177.5, Qg=-20.12
% INFO    : Gen at bus 1729	: Vg=0.943 -> Vg=0.9963875
% INFO    : Gen at bus 1931	: Pg=70.0, Qg=15.58 -> Pg=43.8, Qg=5.56
% INFO    : Gen at bus 1931	: Vg=1.024 -> Vg=1.0
% INFO    : Gen at bus 1932	: Pg=66.0, Qg=17.99 -> Pg=41.4, Qg=9.295
% INFO    : Gen at bus 1932	: Vg=1.033 -> Vg=0.9964755
% INFO    : Gen at bus 1934	: Pg=74.0, Qg=14.98 -> Pg=46.5, Qg=5.685
% INFO    : Gen at bus 1934	: Vg=1.023 -> Vg=1.0
% INFO    : Gen at bus 1935	: Pg=29.0, Qg=-1.86 -> Pg=18.6, Qg=1.24
% INFO    : Gen at bus 1935	: Vg=0.969 -> Vg=1.0
% INFO    : Gen at bus 1936	: Pg=29.0, Qg=-1.91 -> Pg=18.6, Qg=1.39
% INFO    : Gen at bus 1936	: Vg=0.969 -> Vg=1.0
% INFO    : Gen at bus 1937	: Pg=29.0, Qg=-1.95 -> Pg=18.6, Qg=1.55
% INFO    : Gen at bus 1937	: Vg=0.969 -> Vg=1.0
% INFO    : Gen at bus 1938	: Pg=48.0, Qg=-6.76 -> Pg=30.0, Qg=6.185
% INFO    : Gen at bus 1938	: Vg=0.934 -> Vg=1.0
% INFO    : Gen at bus 1730	: Pg=137.0, Qg=-0.17 -> Pg=193.5, Qg=68.385
% INFO    : Gen at bus 1730	: Vg=0.958 -> Vg=1.0
% INFO    : Gen at bus 1731	: Pg=137.0, Qg=-0.16 -> Pg=193.5, Qg=66.855
% INFO    : Gen at bus 1731	: Vg=0.96 -> Vg=1.0
% INFO    : Gen at bus 1944	: Pg=18.0, Qg=-8.58 -> Pg=11.4, Qg=1.15
% INFO    : Gen at bus 1944	: Vg=0.848 -> Vg=0.9740405
% INFO    : Gen at bus 1732	: Pg=201.9, Qg=-0.51 -> Pg=310.9, Qg=14.29
% INFO    : Gen at bus 1732	: Vg=0.988 -> Vg=1.0
% INFO    : Gen at bus 1733	: Pg=5.0, Qg=-24.33 -> Pg=95.0, Qg=20.015
% INFO    : Gen at bus 1733	: Vg=0.95 -> Vg=1.0
% INFO    : Gen at bus 1734	: Pg=5.0, Qg=-24.34 -> Pg=95.0, Qg=20.015
% INFO    : Gen at bus 1734	: Vg=0.95 -> Vg=1.0
% INFO    : Gen at bus 1950	: Pg=219.0, Qg=-29.21 -> Pg=136.2, Qg=37.94
% INFO    : Gen at bus 1950	: Vg=0.935 -> Vg=1.0
% INFO    : Gen at bus 1951	: Pg=219.0, Qg=-35.7 -> Pg=136.2, Qg=54.21
% INFO    : Gen at bus 1951	: Vg=0.93 -> Vg=1.0
% INFO    : Gen at bus 1952	: Pg=219.0, Qg=-27.07 -> Pg=136.2, Qg=31.98
% INFO    : Gen at bus 1952	: Vg=0.936 -> Vg=1.0
% INFO    : Gen at bus 1953	: Pg=219.0, Qg=-27.2 -> Pg=136.2, Qg=32.315
% INFO    : Gen at bus 1953	: Vg=0.936 -> Vg=1.0
% INFO    : Gen at bus 1735	: Pg=917.0, Qg=11.83 -> Pg=593.5, Qg=204.83
% INFO    : Gen at bus 1735	: Vg=0.958 -> Vg=0.9992375
% INFO    : Gen at bus 1736	: Pg=917.0, Qg=12.03 -> Pg=593.5, Qg=209.005
% INFO    : Gen at bus 1736	: Vg=0.958 -> Vg=0.9989805
% INFO    : Gen at bus 1737	: Pg=31.33, Qg=0.24 -> Pg=22.705, Qg=0.09
% INFO    : Gen at bus 1737	: Vg=0.965 -> Vg=1.0
% INFO    : Gen at bus 1738	: Pg=31.33, Qg=0.25 -> Pg=22.705, Qg=0.64
% INFO    : Gen at bus 1738	: Vg=0.965 -> Vg=1.0
% INFO    : Gen at bus 1739	: Pg=31.33, Qg=0.23 -> Pg=22.71, Qg=0.285
% INFO    : Gen at bus 1739	: Vg=0.965 -> Vg=1.0
% INFO    : Gen at bus 1740	: Pg=305.0, Qg=-86.95 -> Pg=242.0, Qg=2.83
% INFO    : Gen at bus 1740	: Vg=0.95 -> Vg=1.00019
% INFO    : Gen at bus 1741	: Pg=156.0, Qg=43.41 -> Pg=230.0, Qg=-12.955
% INFO    : Gen at bus 1741	: Vg=0.946 -> Vg=0.990919
% INFO    : Gen at bus 1742	: Pg=289.0, Qg=-100.6 -> Pg=824.5, Qg=272.075
% INFO    : Gen at bus 1742	: Vg=0.95 -> Vg=1.0
% INFO    : Gen at bus 1958	: Pg=58.0, Qg=-5.35 -> Pg=36.6, Qg=0.48
% INFO    : Gen at bus 1958	: Vg=0.961 -> Vg=1.0
% INFO    : Gen at bus 1959	: Pg=58.0, Qg=-5.41 -> Pg=36.6, Qg=0.64
% INFO    : Gen at bus 1959	: Vg=0.961 -> Vg=1.0
% INFO    : Gen at bus 1743	: Pg=34.0, Qg=0.06 -> Pg=21.57, Qg=2.095
% INFO    : Gen at bus 1743	: Vg=1.025 -> Vg=1.001565
% INFO    : Gen at bus 1744	: Pg=1100.14, Qg=50.37 -> Pg=865.0, Qg=229.47
% INFO    : Gen at bus 1744	: Vg=0.958 -> Vg=1.0
% INFO    : Gen at bus 1745	: Pg=991.73, Qg=91.38 -> Pg=865.0, Qg=231.67
% INFO    : Gen at bus 1745	: Vg=0.965 -> Vg=0.9990525
% INFO    : Gen at bus 1746	: Pg=999.0, Qg=89.07 -> Pg=865.0, Qg=228.305
% INFO    : Gen at bus 1746	: Vg=0.965 -> Vg=1.0
% INFO    : Gen at bus 1961	: Pg=350.0, Qg=39.22 -> Pg=820.0, Qg=229.305
% INFO    : Gen at bus 1961	: Vg=0.967 -> Vg=1.005325
% INFO    : Gen at bus 1747	: Pg=49.0, Qg=4.38 -> Pg=25.9, Qg=2.57
% INFO    : Gen at bus 1747	: Vg=1.006 -> Vg=1.0
% INFO    : Gen at bus 1748	: Pg=808.33, Qg=57.07 -> Pg=860.0, Qg=242.775
% INFO    : Gen at bus 1748	: Vg=0.959 -> Vg=1.0
% INFO    : Gen at bus 1749	: Pg=804.43, Qg=55.66 -> Pg=860.0, Qg=234.935
% INFO    : Gen at bus 1749	: Vg=0.959 -> Vg=1.0
% INFO    : Gen at bus 1750	: Pg=175.0, Qg=11.92 -> Pg=380.0, Qg=58.21
% INFO    : Gen at bus 1750	: Vg=0.95 -> Vg=1.0
% INFO    : Gen at bus 1751	: Pg=175.0, Qg=11.92 -> Pg=380.0, Qg=58.21
% INFO    : Gen at bus 1751	: Vg=0.95 -> Vg=1.0
% INFO    : Gen at bus 1752	: Pg=188.0, Qg=12.45 -> Pg=393.0, Qg=140.7
% INFO    : Gen at bus 1752	: Vg=0.95 -> Vg=1.0
% INFO    : Gen at bus 1753	: Pg=175.0, Qg=-22.88 -> Pg=380.0, Qg=57.39
% INFO    : Gen at bus 1753	: Vg=0.952 -> Vg=1.0
% INFO    : Gen at bus 2058	: Pg=36.0, Qg=0.9 -> Pg=22.8, Qg=0.95
% INFO    : Gen at bus 2058	: Vg=0.972 -> Vg=1.0
% INFO    : Gen at bus 1754	: Pg=236.0, Qg=-37.82 -> Pg=165.0, Qg=18.665
% INFO    : Gen at bus 1754	: Vg=0.929 -> Vg=0.989297
% INFO    : Gen at bus 1755	: Pg=582.74, Qg=-49.82 -> Pg=450.0, Qg=25.65
% INFO    : Gen at bus 1755	: Vg=0.927 -> Vg=0.988606
% INFO    : Gen at bus 1756	: Pg=55.0, Qg=11.75 -> Pg=34.8, Qg=14.63
% INFO    : Gen at bus 1756	: Vg=1.014 -> Vg=1.0
% INFO    : Gen at bus 1757	: Pg=230.8, Qg=-1.27 -> Pg=335.3, Qg=93.085
% INFO    : Gen at bus 1757	: Vg=0.958 -> Vg=1.014235
% INFO    : Gen at bus 1758	: Pg=77.0, Qg=0.42 -> Pg=48.0, Qg=-4.18
% INFO    : Gen at bus 1758	: Vg=1.036 -> Vg=1.0
% INFO    : Gen at bus 1759	: Pg=77.0, Qg=0.42 -> Pg=48.0, Qg=-4.18
% INFO    : Gen at bus 1759	: Vg=1.036 -> Vg=1.0
% INFO    : Gen at bus 1760	: Pg=77.0, Qg=0.42 -> Pg=48.0, Qg=-4.22
% INFO    : Gen at bus 1760	: Vg=1.036 -> Vg=1.0
% INFO    : Gen at bus 1970	: Pg=30.0, Qg=2.82 -> Pg=19.2, Qg=4.16
% INFO    : Gen at bus 1970	: Vg=1.036 -> Vg=1.0
% INFO    : Gen at bus 1971	: Pg=6.4, Qg=1.88 -> Pg=19.2, Qg=0.75
% INFO    : Gen at bus 1971	: Vg=1.037 -> Vg=1.0
% INFO    : Gen at bus 1972	: Pg=30.0, Qg=2.82 -> Pg=19.2, Qg=4.16
% INFO    : Gen at bus 1972	: Vg=1.036 -> Vg=1.0
% INFO    : Gen at bus 1973	: Pg=28.13, Qg=1.91 -> Pg=19.2, Qg=0.75
% INFO    : Gen at bus 1973	: Vg=1.034 -> Vg=1.0
% INFO    : Gen at bus 1974	: Pg=36.0, Qg=-4.24 -> Pg=108.0, Qg=8.27
% INFO    : Gen at bus 1974	: Vg=0.982 -> Vg=1.0
% INFO    : Gen at bus 1975	: Pg=36.0, Qg=-3.8 -> Pg=108.0, Qg=1.96
% INFO    : Gen at bus 1975	: Vg=1.003 -> Vg=1.003145
% INFO    : Gen at bus 1976	: Pg=36.0, Qg=-4.21 -> Pg=108.0, Qg=7.975
% INFO    : Gen at bus 1976	: Vg=0.982 -> Vg=1.0
% INFO    : Gen at bus 1977	: Pg=36.0, Qg=-4.21 -> Pg=108.0, Qg=7.955
% INFO    : Gen at bus 1977	: Vg=0.982 -> Vg=1.00145
% INFO    : Gen at bus 1761	: Pg=23.36, Qg=0.09 -> Pg=22.59, Qg=1.605
% INFO    : Gen at bus 1761	: Vg=0.964 -> Vg=1.0
% INFO    : Gen at bus 1762	: Pg=24.57, Qg=0.09 -> Pg=22.59, Qg=1.545
% INFO    : Gen at bus 1762	: Vg=0.964 -> Vg=1.0
% INFO    : Gen at bus 1978	: Pg=7.53, Qg=0.08 -> Pg=22.585, Qg=1.425
% INFO    : Gen at bus 1978	: Vg=0.967 -> Vg=1.0
% INFO    : Gen at bus 1769	: Pg=38.0, Qg=0.3 -> Pg=20.485, Qg=-2.625
% INFO    : Gen at bus 1769	: Vg=1.028 -> Vg=1.0
% INFO    : Gen at bus 1770	: Pg=38.0, Qg=0.32 -> Pg=20.485, Qg=-2.375
% INFO    : Gen at bus 1770	: Vg=1.028 -> Vg=1.0
% INFO    : Gen at bus 1979	: Pg=42.0, Qg=-0.67 -> Pg=26.4, Qg=0.27
% INFO    : Gen at bus 1979	: Vg=1.001 -> Vg=1.0
% INFO    : Gen at bus 1980	: Pg=29.0, Qg=-3.82 -> Pg=18.6, Qg=2.41
% INFO    : Gen at bus 1980	: Vg=0.971 -> Vg=1.0
% INFO    : Gen at bus 1771	: Pg=31.0, Qg=0.89 -> Pg=19.8, Qg=1.72
% INFO    : Gen at bus 1771	: Vg=0.948 -> Vg=1.0
% INFO    : Gen at bus 1993	: Pg=125.0, Qg=-3.29 -> Pg=78.0, Qg=4.765
% INFO    : Gen at bus 1993	: Vg=1.003 -> Vg=1.0
% INFO    : Gen at bus 1772	: Pg=1285.0, Qg=79.78 -> Pg=807.0, Qg=245.74
% INFO    : Gen at bus 1772	: Vg=0.952 -> Vg=0.997577
% INFO    : Gen at bus 1995	: Pg=1285.0, Qg=78.25 -> Pg=807.0, Qg=239.41
% INFO    : Gen at bus 1995	: Vg=0.952 -> Vg=0.9964485
% INFO    : Gen at bus 1773	: Pg=150.0, Qg=14.19 -> Pg=217.5, Qg=89.165
% INFO    : Gen at bus 1773	: Vg=0.97 -> Vg=1.0
% INFO    : Gen at bus 1774	: Pg=225.0, Qg=11.04 -> Pg=410.0, Qg=37.3
% INFO    : Gen at bus 1774	: Vg=0.961 -> Vg=0.9985055
% INFO    : Gen at bus 1775	: Pg=127.0, Qg=29.22 -> Pg=285.0, Qg=59.22
% INFO    : Gen at bus 1775	: Vg=0.949 -> Vg=0.997161
% INFO    : Gen at bus 1776	: Vg=0.939 -> Vg=0.9944205
% INFO    : Gen at bus 1996	: Pg=48.0, Qg=-4.65 -> Pg=30.0, Qg=-0.585
% INFO    : Gen at bus 1996	: Vg=0.962 -> Vg=1.0
% INFO    : Gen at bus 1997	: Pg=48.0, Qg=-4.88 -> Pg=30.0, Qg=0.04
% INFO    : Gen at bus 1997	: Vg=0.961 -> Vg=1.0
% INFO    : Gen at bus 2000	: Pg=82.0, Qg=-23.37 -> Pg=51.0, Qg=12.91
% INFO    : Gen at bus 2000	: Vg=0.917 -> Vg=1.0
% INFO    : Gen at bus 1777	: Pg=920.0, Qg=15.08 -> Pg=593.37, Qg=216.67
% INFO    : Gen at bus 1777	: Vg=0.948 -> Vg=0.9967005
% INFO    : Gen at bus 1778	: Pg=923.0, Qg=17.07 -> Pg=596.37, Qg=213.27
% INFO    : Gen at bus 1778	: Vg=0.948 -> Vg=0.9991795
% INFO    : Gen at bus 1779	: Pg=47.0, Qg=-3.31 -> Pg=29.4, Qg=-0.25
% INFO    : Gen at bus 1779	: Vg=0.977 -> Vg=1.0
% INFO    : Gen at bus 2002	: Pg=47.0, Qg=-3.31 -> Pg=29.4, Qg=-0.25
% INFO    : Gen at bus 2002	: Vg=0.977 -> Vg=1.0
% INFO    : Gen at bus 1780	: Pg=18.35, Qg=0.06 -> Pg=14.215, Qg=3.59
% INFO    : Gen at bus 1780	: Vg=1.042 -> Vg=1.0106
% INFO    : Gen at bus 2028	: Pg=4.74, Qg=0.06 -> Pg=14.215, Qg=3.59
% INFO    : Gen at bus 2028	: Vg=1.045 -> Vg=1.01086
% INFO    : Gen at bus 1781	: Pg=18.34, Qg=0.06 -> Pg=14.215, Qg=3.59
% INFO    : Gen at bus 1781	: Vg=1.042 -> Vg=1.010775
% INFO    : Gen at bus 1782	: Pg=18.35, Qg=0.06 -> Pg=14.215, Qg=3.515
% INFO    : Gen at bus 1782	: Vg=1.042 -> Vg=1.010715
% INFO    : Gen at bus 2004	: Pg=32.2, Qg=43.6 -> Pg=96.6, Qg=6.74
% INFO    : Gen at bus 2004	: Vg=1.066 -> Vg=1.0
% INFO    : Gen at bus 2023	: Pg=32.2, Qg=43.6 -> Pg=96.6, Qg=6.74
% INFO    : Gen at bus 2023	: Vg=1.066 -> Vg=1.0
% INFO    : Gen at bus 2024	: Pg=32.2, Qg=43.6 -> Pg=96.6, Qg=6.74
% INFO    : Gen at bus 2024	: Vg=1.066 -> Vg=1.0
% INFO    : Gen at bus 2005	: Pg=32.2, Qg=43.6 -> Pg=96.6, Qg=6.74
% INFO    : Gen at bus 2005	: Vg=1.066 -> Vg=1.0
% INFO    : Gen at bus 1783	: Pg=950.0, Qg=256.24 -> Pg=630.0, Qg=157.545
% INFO    : Gen at bus 1783	: Vg=0.992 -> Vg=1.0
% INFO    : Gen at bus 1784	: Pg=950.0, Qg=260.32 -> Pg=630.0, Qg=146.6
% INFO    : Gen at bus 1784	: Vg=0.994 -> Vg=1.0
% INFO    : Gen at bus 1785	: Pg=950.0, Qg=258.43 -> Pg=630.0, Qg=159.9
% INFO    : Gen at bus 1785	: Vg=0.993 -> Vg=1.0
% INFO    : Gen at bus 1786	: Pg=950.0, Qg=249.2 -> Pg=630.0, Qg=160.115
% INFO    : Gen at bus 1786	: Vg=0.993 -> Vg=1.0
% INFO    : Gen at bus 1787	: Pg=72.0, Qg=-23.15 -> Pg=128.5, Qg=18.895
% INFO    : Gen at bus 1787	: Vg=0.964 -> Vg=1.0
% INFO    : Gen at bus 1788	: Pg=72.0, Qg=-23.15 -> Pg=128.5, Qg=19.845
% INFO    : Gen at bus 1788	: Vg=0.964 -> Vg=1.0
% INFO    : Gen at bus 1789	: Pg=72.0, Qg=-17.87 -> Pg=128.5, Qg=19.845
% INFO    : Gen at bus 1789	: Vg=0.979 -> Vg=1.0
% INFO    : Gen at bus 1790	: Pg=138.0, Qg=-13.16 -> Pg=203.0, Qg=36.265
% INFO    : Gen at bus 1790	: Vg=0.941 -> Vg=0.9973695
% INFO    : Gen at bus 1791	: Pg=138.0, Qg=-19.53 -> Pg=203.0, Qg=31.265
% INFO    : Gen at bus 1791	: Vg=0.938 -> Vg=0.994026
% INFO    : Gen at bus 1792	: Pg=33.0, Qg=0.03 -> Pg=20.98, Qg=-3.94
% INFO    : Gen at bus 1792	: Vg=0.978 -> Vg=1.0
% INFO    : Gen at bus 2011	: Pg=33.0, Qg=0.03 -> Pg=20.98, Qg=-3.94
% INFO    : Gen at bus 2011	: Vg=0.978 -> Vg=1.0
% INFO    : Gen at bus 2012	: Pg=24.62, Qg=0.08 -> Pg=20.975, Qg=-3.96
% INFO    : Gen at bus 2012	: Vg=0.963 -> Vg=1.0
% INFO    : Gen at bus 1793	: Pg=131.0, Qg=-5.06 -> Pg=81.6, Qg=16.95
% INFO    : Gen at bus 1793	: Vg=0.959 -> Vg=1.00069
% INFO    : Gen at bus 1794	: Pg=123.0, Qg=-4.43 -> Pg=76.8, Qg=15.68
% INFO    : Gen at bus 1794	: Vg=0.962 -> Vg=1.00072
% INFO    : 
% INFO    : === Writing Matpower Case File Notes ===
